/*****************************************************************************
 * Copyright (c) 2014-2025 OpenRCT2 developers
 *
 * For a complete list of all authors, please refer to contributors.md
 * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
 *
 * OpenRCT2 is licensed under the GNU General Public License version 3.
 *****************************************************************************/

#include "VehicleSubpositionData.h"

#include "Vehicle.h"

using namespace OpenRCT2;

#define CREATE_VEHICLE_INFO(VAR, ...)                                                                                          \
    static constexpr VehicleInfo VAR##_data[] = __VA_ARGS__;                                                                   \
    static constexpr VehicleInfoList VAR = { static_cast<uint16_t>(std::size(VAR##_data)), VAR##_data };

// clang-format off
#define MINI_GOLF_STATE(STATE)                                                                                                 \
    {                                                                                                                          \
        kLocationNull, EnumValue(MiniGolfState::STATE), 0, 0, 0, 0                                                             \
    }
#define MINI_GOLF_ANIMATION(VALUE)                                                                                             \
    {                                                                                                                          \
        kLocationNull, EnumValue(MiniGolfState::Unk4), EnumValue(MiniGolfAnimation::VALUE), 0, 0, 0                            \
    }

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BE57A, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     21,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 },
    {     11,   16,    0,  0,  0,  0 }, {     10,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 },
    {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 },
})


CREATE_VEHICLE_INFO(TrackVehicleInfo_8BE69C, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   15,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   17,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   19,    0,  8,  0,  0 },
    {     16,   20,    0,  8,  0,  0 }, {     16,   21,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   29,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BE7BE, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 }, {      9,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     13,   16,    0, 16,  0,  0 }, {     14,   16,    0, 16,  0,  0 },
    {     15,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     17,   16,    0, 16,  0,  0 }, {     18,   16,    0, 16,  0,  0 }, {     19,   16,    0, 16,  0,  0 },
    {     20,   16,    0, 16,  0,  0 }, {     21,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 },
    {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 }, {     29,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BE8E0, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   21,    0, 24,  0,  0 }, {     16,   20,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 }, {     16,   17,    0, 24,  0,  0 },
    {     16,   16,    0, 24,  0,  0 }, {     16,   15,    0, 24,  0,  0 }, {     16,   14,    0, 24,  0,  0 }, {     16,   13,    0, 24,  0,  0 }, {     16,   12,    0, 24,  0,  0 },
    {     16,   11,    0, 24,  0,  0 }, {     16,   10,    0, 24,  0,  0 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 }, {     16,    7,    0, 24,  0,  0 },
    {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C232A, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    1,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    2,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    3,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    4,  0,  2,  0 }, {     23,   16,    4,  0,  2,  0 }, {     22,   16,    5,  0,  2,  0 },
    {     21,   16,    5,  0,  2,  0 }, {     20,   16,    6,  0,  2,  0 }, {     19,   16,    6,  0,  2,  0 }, {     18,   16,    7,  0,  2,  0 }, {     17,   16,    7,  0,  2,  0 },
    {     16,   16,    8,  0,  2,  0 }, {     15,   16,    8,  0,  2,  0 }, {     14,   16,    9,  0,  2,  0 }, {     13,   16,    9,  0,  2,  0 }, {     12,   16,   10,  0,  2,  0 },
    {     11,   16,   10,  0,  2,  0 }, {     10,   16,   11,  0,  2,  0 }, {      9,   16,   11,  0,  2,  0 }, {      8,   16,   12,  0,  2,  0 }, {      7,   16,   12,  0,  2,  0 },
    {      6,   16,   13,  0,  2,  0 }, {      5,   16,   13,  0,  2,  0 }, {      4,   16,   14,  0,  2,  0 }, {      3,   16,   14,  0,  2,  0 }, {      2,   16,   15,  0,  2,  0 },
    {      1,   16,   15,  0,  2,  0 }, {      0,   16,   16,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C244C, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    2,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    3,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    4,  8,  2,  0 }, {     16,    9,    4,  8,  2,  0 },
    {     16,   10,    5,  8,  2,  0 }, {     16,   11,    5,  8,  2,  0 }, {     16,   12,    6,  8,  2,  0 }, {     16,   13,    6,  8,  2,  0 }, {     16,   14,    7,  8,  2,  0 },
    {     16,   15,    7,  8,  2,  0 }, {     16,   16,    8,  8,  2,  0 }, {     16,   17,    8,  8,  2,  0 }, {     16,   18,    9,  8,  2,  0 }, {     16,   19,    9,  8,  2,  0 },
    {     16,   20,   10,  8,  2,  0 }, {     16,   21,   10,  8,  2,  0 }, {     16,   22,   11,  8,  2,  0 }, {     16,   23,   11,  8,  2,  0 }, {     16,   24,   12,  8,  2,  0 },
    {     16,   25,   12,  8,  2,  0 }, {     16,   26,   13,  8,  2,  0 }, {     16,   27,   13,  8,  2,  0 }, {     16,   28,   14,  8,  2,  0 }, {     16,   29,   14,  8,  2,  0 },
    {     16,   30,   15,  8,  2,  0 }, {     16,   31,   15,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C256E, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    2, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    3, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    4, 16,  2,  0 }, {      9,   16,    4, 16,  2,  0 },
    {     10,   16,    5, 16,  2,  0 }, {     11,   16,    5, 16,  2,  0 }, {     12,   16,    6, 16,  2,  0 }, {     13,   16,    6, 16,  2,  0 }, {     14,   16,    7, 16,  2,  0 },
    {     15,   16,    7, 16,  2,  0 }, {     16,   16,    8, 16,  2,  0 }, {     17,   16,    8, 16,  2,  0 }, {     18,   16,    9, 16,  2,  0 }, {     19,   16,    9, 16,  2,  0 },
    {     20,   16,   10, 16,  2,  0 }, {     21,   16,   10, 16,  2,  0 }, {     22,   16,   11, 16,  2,  0 }, {     23,   16,   11, 16,  2,  0 }, {     24,   16,   12, 16,  2,  0 },
    {     25,   16,   12, 16,  2,  0 }, {     26,   16,   13, 16,  2,  0 }, {     27,   16,   13, 16,  2,  0 }, {     28,   16,   14, 16,  2,  0 }, {     29,   16,   14, 16,  2,  0 },
    {     30,   16,   15, 16,  2,  0 }, {     31,   16,   15, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C2690, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    1, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    2, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    3, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    4, 24,  2,  0 }, {     16,   23,    4, 24,  2,  0 }, {     16,   22,    5, 24,  2,  0 },
    {     16,   21,    5, 24,  2,  0 }, {     16,   20,    6, 24,  2,  0 }, {     16,   19,    6, 24,  2,  0 }, {     16,   18,    7, 24,  2,  0 }, {     16,   17,    7, 24,  2,  0 },
    {     16,   16,    8, 24,  2,  0 }, {     16,   15,    8, 24,  2,  0 }, {     16,   14,    9, 24,  2,  0 }, {     16,   13,    9, 24,  2,  0 }, {     16,   12,   10, 24,  2,  0 },
    {     16,   11,   10, 24,  2,  0 }, {     16,   10,   11, 24,  2,  0 }, {     16,    9,   11, 24,  2,  0 }, {     16,    8,   12, 24,  2,  0 }, {     16,    7,   12, 24,  2,  0 },
    {     16,    6,   13, 24,  2,  0 }, {     16,    5,   13, 24,  2,  0 }, {     16,    4,   14, 24,  2,  0 }, {     16,    3,   14, 24,  2,  0 }, {     16,    2,   15, 24,  2,  0 },
    {     16,    1,   15, 24,  2,  0 }, {     16,    0,   16, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BF312, {
    {     31,   16,    0,  0,  4,  0 }, {     31,   16,    1,  0,  4,  0 }, {     30,   16,    2,  0,  4,  0 }, {     30,   16,    3,  0,  4,  0 }, {     29,   16,    4,  0,  4,  0 },
    {     29,   16,    5,  0,  4,  0 }, {     28,   16,    6,  0,  4,  0 }, {     28,   16,    7,  0,  4,  0 }, {     27,   16,    8,  0,  4,  0 }, {     27,   16,    9,  0,  4,  0 },
    {     26,   16,   10,  0,  4,  0 }, {     26,   16,   11,  0,  4,  0 }, {     25,   16,   12,  0,  4,  0 }, {     25,   16,   13,  0,  4,  0 }, {     24,   16,   14,  0,  4,  0 },
    {     24,   16,   15,  0,  4,  0 }, {     23,   16,   16,  0,  4,  0 }, {     23,   16,   17,  0,  4,  0 }, {     22,   16,   18,  0,  4,  0 }, {     22,   16,   19,  0,  4,  0 },
    {     21,   16,   20,  0,  4,  0 }, {     21,   16,   21,  0,  4,  0 }, {     20,   16,   22,  0,  4,  0 }, {     20,   16,   23,  0,  4,  0 }, {     19,   16,   24,  0,  4,  0 },
    {     19,   16,   25,  0,  4,  0 }, {     18,   16,   26,  0,  4,  0 }, {     18,   16,   27,  0,  4,  0 }, {     17,   16,   28,  0,  4,  0 }, {     17,   16,   29,  0,  4,  0 },
    {     16,   16,   30,  0,  4,  0 }, {     16,   16,   31,  0,  4,  0 }, {     15,   16,   32,  0,  4,  0 }, {     15,   16,   33,  0,  4,  0 }, {     14,   16,   34,  0,  4,  0 },
    {     14,   16,   35,  0,  4,  0 }, {     13,   16,   36,  0,  4,  0 }, {     13,   16,   37,  0,  4,  0 }, {     12,   16,   38,  0,  4,  0 }, {     12,   16,   39,  0,  4,  0 },
    {     11,   16,   40,  0,  4,  0 }, {     11,   16,   41,  0,  4,  0 }, {     10,   16,   42,  0,  4,  0 }, {     10,   16,   43,  0,  4,  0 }, {      9,   16,   44,  0,  4,  0 },
    {      9,   16,   45,  0,  4,  0 }, {      8,   16,   46,  0,  4,  0 }, {      8,   16,   47,  0,  4,  0 }, {      7,   16,   48,  0,  4,  0 }, {      7,   16,   49,  0,  4,  0 },
    {      6,   16,   50,  0,  4,  0 }, {      6,   16,   51,  0,  4,  0 }, {      5,   16,   52,  0,  4,  0 }, {      5,   16,   53,  0,  4,  0 }, {      4,   16,   54,  0,  4,  0 },
    {      4,   16,   55,  0,  4,  0 }, {      3,   16,   56,  0,  4,  0 }, {      3,   16,   57,  0,  4,  0 }, {      2,   16,   58,  0,  4,  0 }, {      2,   16,   59,  0,  4,  0 },
    {      1,   16,   60,  0,  4,  0 }, {      1,   16,   61,  0,  4,  0 }, {      0,   16,   62,  0,  4,  0 }, {      0,   16,   63,  0,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BF554, {
    {     16,    0,    0,  8,  4,  0 }, {     16,    0,    1,  8,  4,  0 }, {     16,    1,    2,  8,  4,  0 }, {     16,    1,    3,  8,  4,  0 }, {     16,    2,    4,  8,  4,  0 },
    {     16,    2,    5,  8,  4,  0 }, {     16,    3,    6,  8,  4,  0 }, {     16,    3,    7,  8,  4,  0 }, {     16,    4,    8,  8,  4,  0 }, {     16,    4,    9,  8,  4,  0 },
    {     16,    5,   10,  8,  4,  0 }, {     16,    5,   11,  8,  4,  0 }, {     16,    6,   12,  8,  4,  0 }, {     16,    6,   13,  8,  4,  0 }, {     16,    7,   14,  8,  4,  0 },
    {     16,    7,   15,  8,  4,  0 }, {     16,    8,   16,  8,  4,  0 }, {     16,    8,   17,  8,  4,  0 }, {     16,    9,   18,  8,  4,  0 }, {     16,    9,   19,  8,  4,  0 },
    {     16,   10,   20,  8,  4,  0 }, {     16,   10,   21,  8,  4,  0 }, {     16,   11,   22,  8,  4,  0 }, {     16,   11,   23,  8,  4,  0 }, {     16,   12,   24,  8,  4,  0 },
    {     16,   12,   25,  8,  4,  0 }, {     16,   13,   26,  8,  4,  0 }, {     16,   13,   27,  8,  4,  0 }, {     16,   14,   28,  8,  4,  0 }, {     16,   14,   29,  8,  4,  0 },
    {     16,   15,   30,  8,  4,  0 }, {     16,   15,   31,  8,  4,  0 }, {     16,   16,   32,  8,  4,  0 }, {     16,   16,   33,  8,  4,  0 }, {     16,   17,   34,  8,  4,  0 },
    {     16,   17,   35,  8,  4,  0 }, {     16,   18,   36,  8,  4,  0 }, {     16,   18,   37,  8,  4,  0 }, {     16,   19,   38,  8,  4,  0 }, {     16,   19,   39,  8,  4,  0 },
    {     16,   20,   40,  8,  4,  0 }, {     16,   20,   41,  8,  4,  0 }, {     16,   21,   42,  8,  4,  0 }, {     16,   21,   43,  8,  4,  0 }, {     16,   22,   44,  8,  4,  0 },
    {     16,   22,   45,  8,  4,  0 }, {     16,   23,   46,  8,  4,  0 }, {     16,   23,   47,  8,  4,  0 }, {     16,   24,   48,  8,  4,  0 }, {     16,   24,   49,  8,  4,  0 },
    {     16,   25,   50,  8,  4,  0 }, {     16,   25,   51,  8,  4,  0 }, {     16,   26,   52,  8,  4,  0 }, {     16,   26,   53,  8,  4,  0 }, {     16,   27,   54,  8,  4,  0 },
    {     16,   27,   55,  8,  4,  0 }, {     16,   28,   56,  8,  4,  0 }, {     16,   28,   57,  8,  4,  0 }, {     16,   29,   58,  8,  4,  0 }, {     16,   29,   59,  8,  4,  0 },
    {     16,   30,   60,  8,  4,  0 }, {     16,   30,   61,  8,  4,  0 }, {     16,   31,   62,  8,  4,  0 }, {     16,   31,   63,  8,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BF796, {
    {      0,   16,    0, 16,  4,  0 }, {      0,   16,    1, 16,  4,  0 }, {      1,   16,    2, 16,  4,  0 }, {      1,   16,    3, 16,  4,  0 }, {      2,   16,    4, 16,  4,  0 },
    {      2,   16,    5, 16,  4,  0 }, {      3,   16,    6, 16,  4,  0 }, {      3,   16,    7, 16,  4,  0 }, {      4,   16,    8, 16,  4,  0 }, {      4,   16,    9, 16,  4,  0 },
    {      5,   16,   10, 16,  4,  0 }, {      5,   16,   11, 16,  4,  0 }, {      6,   16,   12, 16,  4,  0 }, {      6,   16,   13, 16,  4,  0 }, {      7,   16,   14, 16,  4,  0 },
    {      7,   16,   15, 16,  4,  0 }, {      8,   16,   16, 16,  4,  0 }, {      8,   16,   17, 16,  4,  0 }, {      9,   16,   18, 16,  4,  0 }, {      9,   16,   19, 16,  4,  0 },
    {     10,   16,   20, 16,  4,  0 }, {     10,   16,   21, 16,  4,  0 }, {     11,   16,   22, 16,  4,  0 }, {     11,   16,   23, 16,  4,  0 }, {     12,   16,   24, 16,  4,  0 },
    {     12,   16,   25, 16,  4,  0 }, {     13,   16,   26, 16,  4,  0 }, {     13,   16,   27, 16,  4,  0 }, {     14,   16,   28, 16,  4,  0 }, {     14,   16,   29, 16,  4,  0 },
    {     15,   16,   30, 16,  4,  0 }, {     15,   16,   31, 16,  4,  0 }, {     16,   16,   32, 16,  4,  0 }, {     16,   16,   33, 16,  4,  0 }, {     17,   16,   34, 16,  4,  0 },
    {     17,   16,   35, 16,  4,  0 }, {     18,   16,   36, 16,  4,  0 }, {     18,   16,   37, 16,  4,  0 }, {     19,   16,   38, 16,  4,  0 }, {     19,   16,   39, 16,  4,  0 },
    {     20,   16,   40, 16,  4,  0 }, {     20,   16,   41, 16,  4,  0 }, {     21,   16,   42, 16,  4,  0 }, {     21,   16,   43, 16,  4,  0 }, {     22,   16,   44, 16,  4,  0 },
    {     22,   16,   45, 16,  4,  0 }, {     23,   16,   46, 16,  4,  0 }, {     23,   16,   47, 16,  4,  0 }, {     24,   16,   48, 16,  4,  0 }, {     24,   16,   49, 16,  4,  0 },
    {     25,   16,   50, 16,  4,  0 }, {     25,   16,   51, 16,  4,  0 }, {     26,   16,   52, 16,  4,  0 }, {     26,   16,   53, 16,  4,  0 }, {     27,   16,   54, 16,  4,  0 },
    {     27,   16,   55, 16,  4,  0 }, {     28,   16,   56, 16,  4,  0 }, {     28,   16,   57, 16,  4,  0 }, {     29,   16,   58, 16,  4,  0 }, {     29,   16,   59, 16,  4,  0 },
    {     30,   16,   60, 16,  4,  0 }, {     30,   16,   61, 16,  4,  0 }, {     31,   16,   62, 16,  4,  0 }, {     31,   16,   63, 16,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BF9D8, {
    {     16,   31,    0, 24,  4,  0 }, {     16,   31,    1, 24,  4,  0 }, {     16,   30,    2, 24,  4,  0 }, {     16,   30,    3, 24,  4,  0 }, {     16,   29,    4, 24,  4,  0 },
    {     16,   29,    5, 24,  4,  0 }, {     16,   28,    6, 24,  4,  0 }, {     16,   28,    7, 24,  4,  0 }, {     16,   27,    8, 24,  4,  0 }, {     16,   27,    9, 24,  4,  0 },
    {     16,   26,   10, 24,  4,  0 }, {     16,   26,   11, 24,  4,  0 }, {     16,   25,   12, 24,  4,  0 }, {     16,   25,   13, 24,  4,  0 }, {     16,   24,   14, 24,  4,  0 },
    {     16,   24,   15, 24,  4,  0 }, {     16,   23,   16, 24,  4,  0 }, {     16,   23,   17, 24,  4,  0 }, {     16,   22,   18, 24,  4,  0 }, {     16,   22,   19, 24,  4,  0 },
    {     16,   21,   20, 24,  4,  0 }, {     16,   21,   21, 24,  4,  0 }, {     16,   20,   22, 24,  4,  0 }, {     16,   20,   23, 24,  4,  0 }, {     16,   19,   24, 24,  4,  0 },
    {     16,   19,   25, 24,  4,  0 }, {     16,   18,   26, 24,  4,  0 }, {     16,   18,   27, 24,  4,  0 }, {     16,   17,   28, 24,  4,  0 }, {     16,   17,   29, 24,  4,  0 },
    {     16,   16,   30, 24,  4,  0 }, {     16,   16,   31, 24,  4,  0 }, {     16,   15,   32, 24,  4,  0 }, {     16,   15,   33, 24,  4,  0 }, {     16,   14,   34, 24,  4,  0 },
    {     16,   14,   35, 24,  4,  0 }, {     16,   13,   36, 24,  4,  0 }, {     16,   13,   37, 24,  4,  0 }, {     16,   12,   38, 24,  4,  0 }, {     16,   12,   39, 24,  4,  0 },
    {     16,   11,   40, 24,  4,  0 }, {     16,   11,   41, 24,  4,  0 }, {     16,   10,   42, 24,  4,  0 }, {     16,   10,   43, 24,  4,  0 }, {     16,    9,   44, 24,  4,  0 },
    {     16,    9,   45, 24,  4,  0 }, {     16,    8,   46, 24,  4,  0 }, {     16,    8,   47, 24,  4,  0 }, {     16,    7,   48, 24,  4,  0 }, {     16,    7,   49, 24,  4,  0 },
    {     16,    6,   50, 24,  4,  0 }, {     16,    6,   51, 24,  4,  0 }, {     16,    5,   52, 24,  4,  0 }, {     16,    5,   53, 24,  4,  0 }, {     16,    4,   54, 24,  4,  0 },
    {     16,    4,   55, 24,  4,  0 }, {     16,    3,   56, 24,  4,  0 }, {     16,    3,   57, 24,  4,  0 }, {     16,    2,   58, 24,  4,  0 }, {     16,    2,   59, 24,  4,  0 },
    {     16,    1,   60, 24,  4,  0 }, {     16,    1,   61, 24,  4,  0 }, {     16,    0,   62, 24,  4,  0 }, {     16,    0,   63, 24,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BFC1A, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  1,  0 }, {     22,   16,    0,  0,  1,  0 },
    {     21,   16,    1,  0,  1,  0 }, {     20,   16,    1,  0,  1,  0 }, {     19,   16,    1,  0,  1,  0 }, {     18,   16,    1,  0,  1,  0 }, {     17,   16,    1,  0,  1,  0 },
    {     16,   16,    1,  0,  1,  0 }, {     15,   16,    2,  0,  1,  0 }, {     14,   16,    2,  0,  1,  0 }, {     13,   16,    2,  0,  1,  0 }, {     12,   16,    2,  0,  1,  0 },
    {     11,   16,    3,  0,  1,  0 }, {     10,   16,    3,  0,  1,  0 }, {      9,   16,    3,  0,  1,  0 }, {      8,   16,    4,  0,  1,  0 }, {      7,   16,    4,  0,  2,  0 },
    {      6,   16,    5,  0,  2,  0 }, {      5,   16,    5,  0,  2,  0 }, {      4,   16,    6,  0,  2,  0 }, {      3,   16,    6,  0,  2,  0 }, {      2,   16,    7,  0,  2,  0 },
    {      1,   16,    7,  0,  2,  0 }, {      0,   16,    8,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BFD3C, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  1,  0 }, {     16,    9,    0,  8,  1,  0 },
    {     16,   10,    1,  8,  1,  0 }, {     16,   11,    1,  8,  1,  0 }, {     16,   12,    1,  8,  1,  0 }, {     16,   13,    1,  8,  1,  0 }, {     16,   14,    1,  8,  1,  0 },
    {     16,   15,    1,  8,  1,  0 }, {     16,   16,    2,  8,  1,  0 }, {     16,   17,    2,  8,  1,  0 }, {     16,   18,    2,  8,  1,  0 }, {     16,   19,    2,  8,  1,  0 },
    {     16,   20,    3,  8,  1,  0 }, {     16,   21,    3,  8,  1,  0 }, {     16,   22,    3,  8,  1,  0 }, {     16,   23,    4,  8,  1,  0 }, {     16,   24,    4,  8,  2,  0 },
    {     16,   25,    4,  8,  2,  0 }, {     16,   26,    5,  8,  2,  0 }, {     16,   27,    5,  8,  2,  0 }, {     16,   28,    6,  8,  2,  0 }, {     16,   29,    6,  8,  2,  0 },
    {     16,   30,    7,  8,  2,  0 }, {     16,   31,    7,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BFE5E, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  1,  0 }, {      9,   16,    0, 16,  1,  0 },
    {     10,   16,    1, 16,  1,  0 }, {     11,   16,    1, 16,  1,  0 }, {     12,   16,    1, 16,  1,  0 }, {     13,   16,    1, 16,  1,  0 }, {     14,   16,    1, 16,  1,  0 },
    {     15,   16,    1, 16,  1,  0 }, {     16,   16,    2, 16,  1,  0 }, {     17,   16,    2, 16,  1,  0 }, {     18,   16,    2, 16,  1,  0 }, {     19,   16,    2, 16,  1,  0 },
    {     20,   16,    3, 16,  1,  0 }, {     21,   16,    3, 16,  1,  0 }, {     22,   16,    3, 16,  1,  0 }, {     23,   16,    4, 16,  1,  0 }, {     24,   16,    4, 16,  2,  0 },
    {     25,   16,    4, 16,  2,  0 }, {     26,   16,    5, 16,  2,  0 }, {     27,   16,    5, 16,  2,  0 }, {     28,   16,    6, 16,  2,  0 }, {     29,   16,    6, 16,  2,  0 },
    {     30,   16,    7, 16,  2,  0 }, {     31,   16,    7, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BFF80, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  1,  0 }, {     16,   22,    0, 24,  1,  0 },
    {     16,   21,    1, 24,  1,  0 }, {     16,   20,    1, 24,  1,  0 }, {     16,   19,    1, 24,  1,  0 }, {     16,   18,    1, 24,  1,  0 }, {     16,   17,    1, 24,  1,  0 },
    {     16,   16,    1, 24,  1,  0 }, {     16,   15,    2, 24,  1,  0 }, {     16,   14,    2, 24,  1,  0 }, {     16,   13,    2, 24,  1,  0 }, {     16,   12,    2, 24,  1,  0 },
    {     16,   11,    3, 24,  1,  0 }, {     16,   10,    3, 24,  1,  0 }, {     16,    9,    3, 24,  1,  0 }, {     16,    8,    4, 24,  1,  0 }, {     16,    7,    4, 24,  2,  0 },
    {     16,    6,    5, 24,  2,  0 }, {     16,    5,    5, 24,  2,  0 }, {     16,    4,    6, 24,  2,  0 }, {     16,    3,    6, 24,  2,  0 }, {     16,    2,    7, 24,  2,  0 },
    {     16,    1,    7, 24,  2,  0 }, {     16,    0,    8, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C0E3A, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    0,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    1,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    3,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    4,  0,  2,  0 }, {     23,   16,    5,  0,  2,  0 }, {     22,   16,    5,  0,  2,  0 },
    {     21,   16,    6,  0,  3,  0 }, {     20,   16,    7,  0,  3,  0 }, {     19,   16,    8,  0,  3,  0 }, {     18,   16,    8,  0,  3,  0 }, {     17,   16,    9,  0,  3,  0 },
    {     16,   16,   10,  0,  3,  0 }, {     15,   16,   11,  0,  3,  0 }, {     14,   16,   12,  0,  3,  0 }, {     13,   16,   13,  0,  3,  0 }, {     12,   16,   14,  0,  3,  0 },
    {     11,   16,   15,  0,  3,  0 }, {     10,   16,   16,  0,  3,  0 }, {      9,   16,   17,  0,  3,  0 }, {      8,   16,   18,  0,  3,  0 }, {      8,   16,   19,  0,  3,  0 },
    {      7,   16,   20,  0,  3,  0 }, {      6,   16,   21,  0,  3,  0 }, {      5,   16,   22,  0,  4,  0 }, {      5,   16,   23,  0,  4,  0 }, {      4,   16,   24,  0,  4,  0 },
    {      3,   16,   25,  0,  4,  0 }, {      3,   16,   26,  0,  4,  0 }, {      2,   16,   27,  0,  4,  0 }, {      1,   16,   28,  0,  4,  0 }, {      1,   16,   29,  0,  4,  0 },
    {      0,   16,   30,  0,  4,  0 }, {      0,   16,   31,  0,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C0F89, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    2,  8,  2,  0 },
    {     16,    5,    3,  8,  2,  0 }, {     16,    6,    3,  8,  2,  0 }, {     16,    7,    4,  8,  2,  0 }, {     16,    8,    5,  8,  2,  0 }, {     16,    9,    5,  8,  2,  0 },
    {     16,   10,    6,  8,  3,  0 }, {     16,   11,    7,  8,  3,  0 }, {     16,   12,    8,  8,  3,  0 }, {     16,   13,    8,  8,  3,  0 }, {     16,   14,    9,  8,  3,  0 },
    {     16,   15,   10,  8,  3,  0 }, {     16,   16,   11,  8,  3,  0 }, {     16,   17,   12,  8,  3,  0 }, {     16,   18,   13,  8,  3,  0 }, {     16,   19,   14,  8,  3,  0 },
    {     16,   20,   15,  8,  3,  0 }, {     16,   21,   16,  8,  3,  0 }, {     16,   22,   17,  8,  3,  0 }, {     16,   23,   18,  8,  3,  0 }, {     16,   23,   19,  8,  3,  0 },
    {     16,   24,   20,  8,  3,  0 }, {     16,   25,   21,  8,  3,  0 }, {     16,   26,   22,  8,  4,  0 }, {     16,   26,   23,  8,  4,  0 }, {     16,   27,   24,  8,  4,  0 },
    {     16,   28,   25,  8,  4,  0 }, {     16,   28,   26,  8,  4,  0 }, {     16,   29,   27,  8,  4,  0 }, {     16,   30,   28,  8,  4,  0 }, {     16,   30,   29,  8,  4,  0 },
    {     16,   31,   30,  8,  4,  0 }, {     16,   31,   31,  8,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C10D8, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    2, 16,  2,  0 },
    {      5,   16,    3, 16,  2,  0 }, {      6,   16,    3, 16,  2,  0 }, {      7,   16,    4, 16,  2,  0 }, {      8,   16,    5, 16,  2,  0 }, {      9,   16,    5, 16,  2,  0 },
    {     10,   16,    6, 16,  3,  0 }, {     11,   16,    7, 16,  3,  0 }, {     12,   16,    8, 16,  3,  0 }, {     13,   16,    8, 16,  3,  0 }, {     14,   16,    9, 16,  3,  0 },
    {     15,   16,   10, 16,  3,  0 }, {     16,   16,   11, 16,  3,  0 }, {     17,   16,   12, 16,  3,  0 }, {     18,   16,   13, 16,  3,  0 }, {     19,   16,   14, 16,  3,  0 },
    {     20,   16,   15, 16,  3,  0 }, {     21,   16,   16, 16,  3,  0 }, {     22,   16,   17, 16,  3,  0 }, {     23,   16,   18, 16,  3,  0 }, {     23,   16,   19, 16,  3,  0 },
    {     24,   16,   20, 16,  3,  0 }, {     25,   16,   21, 16,  3,  0 }, {     26,   16,   22, 16,  4,  0 }, {     26,   16,   23, 16,  4,  0 }, {     27,   16,   24, 16,  4,  0 },
    {     28,   16,   25, 16,  4,  0 }, {     28,   16,   26, 16,  4,  0 }, {     29,   16,   27, 16,  4,  0 }, {     30,   16,   28, 16,  4,  0 }, {     30,   16,   29, 16,  4,  0 },
    {     31,   16,   30, 16,  4,  0 }, {     31,   16,   31, 16,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C1227, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    0, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    1, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    3, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    4, 24,  2,  0 }, {     16,   23,    5, 24,  2,  0 }, {     16,   22,    5, 24,  2,  0 },
    {     16,   21,    6, 24,  3,  0 }, {     16,   20,    7, 24,  3,  0 }, {     16,   19,    8, 24,  3,  0 }, {     16,   18,    8, 24,  3,  0 }, {     16,   17,    9, 24,  3,  0 },
    {     16,   16,   10, 24,  3,  0 }, {     16,   15,   11, 24,  3,  0 }, {     16,   14,   12, 24,  3,  0 }, {     16,   13,   13, 24,  3,  0 }, {     16,   12,   14, 24,  3,  0 },
    {     16,   11,   15, 24,  3,  0 }, {     16,   10,   16, 24,  3,  0 }, {     16,    9,   17, 24,  3,  0 }, {     16,    8,   18, 24,  3,  0 }, {     16,    8,   19, 24,  3,  0 },
    {     16,    7,   20, 24,  3,  0 }, {     16,    6,   21, 24,  3,  0 }, {     16,    5,   22, 24,  4,  0 }, {     16,    5,   23, 24,  4,  0 }, {     16,    4,   24, 24,  4,  0 },
    {     16,    3,   25, 24,  4,  0 }, {     16,    3,   26, 24,  4,  0 }, {     16,    2,   27, 24,  4,  0 }, {     16,    1,   28, 24,  4,  0 }, {     16,    1,   29, 24,  4,  0 },
    {     16,    0,   30, 24,  4,  0 }, {     16,    0,   31, 24,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C1376, {
    {     31,   16,    0,  0,  4,  0 }, {     31,   16,    1,  0,  4,  0 }, {     30,   16,    2,  0,  4,  0 }, {     30,   16,    3,  0,  4,  0 }, {     29,   16,    4,  0,  4,  0 },
    {     28,   16,    5,  0,  4,  0 }, {     28,   16,    6,  0,  4,  0 }, {     27,   16,    7,  0,  4,  0 }, {     26,   16,    8,  0,  4,  0 }, {     26,   16,    9,  0,  4,  0 },
    {     25,   16,   10,  0,  3,  0 }, {     24,   16,   11,  0,  3,  0 }, {     23,   16,   12,  0,  3,  0 }, {     23,   16,   13,  0,  3,  0 }, {     22,   16,   14,  0,  3,  0 },
    {     21,   16,   15,  0,  3,  0 }, {     20,   16,   16,  0,  3,  0 }, {     19,   16,   17,  0,  3,  0 }, {     18,   16,   18,  0,  3,  0 }, {     17,   16,   19,  0,  3,  0 },
    {     16,   16,   20,  0,  3,  0 }, {     15,   16,   21,  0,  3,  0 }, {     14,   16,   22,  0,  3,  0 }, {     13,   16,   23,  0,  3,  0 }, {     12,   16,   23,  0,  3,  0 },
    {     11,   16,   24,  0,  3,  0 }, {     10,   16,   25,  0,  3,  0 }, {      9,   16,   26,  0,  2,  0 }, {      8,   16,   26,  0,  2,  0 }, {      7,   16,   27,  0,  2,  0 },
    {      6,   16,   28,  0,  2,  0 }, {      5,   16,   28,  0,  2,  0 }, {      4,   16,   29,  0,  2,  0 }, {      3,   16,   30,  0,  2,  0 }, {      2,   16,   30,  0,  2,  0 },
    {      1,   16,   31,  0,  2,  0 }, {      0,   16,   31,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C14C5, {
    {     16,    0,    0,  8,  4,  0 }, {     16,    0,    1,  8,  4,  0 }, {     16,    1,    2,  8,  4,  0 }, {     16,    1,    3,  8,  4,  0 }, {     16,    2,    4,  8,  4,  0 },
    {     16,    3,    5,  8,  4,  0 }, {     16,    3,    6,  8,  4,  0 }, {     16,    4,    7,  8,  4,  0 }, {     16,    5,    8,  8,  4,  0 }, {     16,    5,    9,  8,  4,  0 },
    {     16,    6,   10,  8,  3,  0 }, {     16,    7,   11,  8,  3,  0 }, {     16,    8,   12,  8,  3,  0 }, {     16,    8,   13,  8,  3,  0 }, {     16,    9,   14,  8,  3,  0 },
    {     16,   10,   15,  8,  3,  0 }, {     16,   11,   16,  8,  3,  0 }, {     16,   12,   17,  8,  3,  0 }, {     16,   13,   18,  8,  3,  0 }, {     16,   14,   19,  8,  3,  0 },
    {     16,   15,   20,  8,  3,  0 }, {     16,   16,   21,  8,  3,  0 }, {     16,   17,   22,  8,  3,  0 }, {     16,   18,   23,  8,  3,  0 }, {     16,   19,   23,  8,  3,  0 },
    {     16,   20,   24,  8,  3,  0 }, {     16,   21,   25,  8,  3,  0 }, {     16,   22,   26,  8,  2,  0 }, {     16,   23,   26,  8,  2,  0 }, {     16,   24,   27,  8,  2,  0 },
    {     16,   25,   28,  8,  2,  0 }, {     16,   26,   28,  8,  2,  0 }, {     16,   27,   29,  8,  2,  0 }, {     16,   28,   30,  8,  2,  0 }, {     16,   29,   30,  8,  2,  0 },
    {     16,   30,   31,  8,  2,  0 }, {     16,   31,   31,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C1614, {
    {      0,   16,    0, 16,  4,  0 }, {      0,   16,    1, 16,  4,  0 }, {      1,   16,    2, 16,  4,  0 }, {      1,   16,    3, 16,  4,  0 }, {      2,   16,    4, 16,  4,  0 },
    {      3,   16,    5, 16,  4,  0 }, {      3,   16,    6, 16,  4,  0 }, {      4,   16,    7, 16,  4,  0 }, {      5,   16,    8, 16,  4,  0 }, {      5,   16,    9, 16,  4,  0 },
    {      6,   16,   10, 16,  3,  0 }, {      7,   16,   11, 16,  3,  0 }, {      8,   16,   12, 16,  3,  0 }, {      8,   16,   13, 16,  3,  0 }, {      9,   16,   14, 16,  3,  0 },
    {     10,   16,   15, 16,  3,  0 }, {     11,   16,   16, 16,  3,  0 }, {     12,   16,   17, 16,  3,  0 }, {     13,   16,   18, 16,  3,  0 }, {     14,   16,   19, 16,  3,  0 },
    {     15,   16,   20, 16,  3,  0 }, {     16,   16,   21, 16,  3,  0 }, {     17,   16,   22, 16,  3,  0 }, {     18,   16,   23, 16,  3,  0 }, {     19,   16,   23, 16,  3,  0 },
    {     20,   16,   24, 16,  3,  0 }, {     21,   16,   25, 16,  3,  0 }, {     22,   16,   26, 16,  2,  0 }, {     23,   16,   26, 16,  2,  0 }, {     24,   16,   27, 16,  2,  0 },
    {     25,   16,   28, 16,  2,  0 }, {     26,   16,   28, 16,  2,  0 }, {     27,   16,   29, 16,  2,  0 }, {     28,   16,   30, 16,  2,  0 }, {     29,   16,   30, 16,  2,  0 },
    {     30,   16,   31, 16,  2,  0 }, {     31,   16,   31, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C1763, {
    {     16,   31,    0, 24,  4,  0 }, {     16,   31,    1, 24,  4,  0 }, {     16,   30,    2, 24,  4,  0 }, {     16,   30,    3, 24,  4,  0 }, {     16,   29,    4, 24,  4,  0 },
    {     16,   28,    5, 24,  4,  0 }, {     16,   28,    6, 24,  4,  0 }, {     16,   27,    7, 24,  4,  0 }, {     16,   26,    8, 24,  4,  0 }, {     16,   26,    9, 24,  4,  0 },
    {     16,   25,   10, 24,  3,  0 }, {     16,   24,   11, 24,  3,  0 }, {     16,   23,   12, 24,  3,  0 }, {     16,   23,   13, 24,  3,  0 }, {     16,   22,   14, 24,  3,  0 },
    {     16,   21,   15, 24,  3,  0 }, {     16,   20,   16, 24,  3,  0 }, {     16,   19,   17, 24,  3,  0 }, {     16,   18,   18, 24,  3,  0 }, {     16,   17,   19, 24,  3,  0 },
    {     16,   16,   20, 24,  3,  0 }, {     16,   15,   21, 24,  3,  0 }, {     16,   14,   22, 24,  3,  0 }, {     16,   13,   23, 24,  3,  0 }, {     16,   12,   23, 24,  3,  0 },
    {     16,   11,   24, 24,  3,  0 }, {     16,   10,   25, 24,  3,  0 }, {     16,    9,   26, 24,  2,  0 }, {     16,    8,   26, 24,  2,  0 }, {     16,    7,   27, 24,  2,  0 },
    {     16,    6,   28, 24,  2,  0 }, {     16,    5,   28, 24,  2,  0 }, {     16,    4,   29, 24,  2,  0 }, {     16,    3,   30, 24,  2,  0 }, {     16,    2,   30, 24,  2,  0 },
    {     16,    1,   31, 24,  2,  0 }, {     16,    0,   31, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C00A2, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    1,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    2,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    3,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    3,  0,  2,  0 }, {     23,   16,    4,  0,  1,  0 }, {     22,   16,    4,  0,  1,  0 },
    {     21,   16,    4,  0,  1,  0 }, {     20,   16,    5,  0,  1,  0 }, {     19,   16,    5,  0,  1,  0 }, {     18,   16,    5,  0,  1,  0 }, {     17,   16,    6,  0,  1,  0 },
    {     16,   16,    6,  0,  1,  0 }, {     15,   16,    6,  0,  1,  0 }, {     14,   16,    6,  0,  1,  0 }, {     13,   16,    7,  0,  1,  0 }, {     12,   16,    7,  0,  1,  0 },
    {     11,   16,    7,  0,  1,  0 }, {     10,   16,    7,  0,  1,  0 }, {      9,   16,    7,  0,  0,  0 }, {      8,   16,    7,  0,  0,  0 }, {      7,   16,    8,  0,  0,  0 },
    {      6,   16,    8,  0,  0,  0 }, {      5,   16,    8,  0,  0,  0 }, {      4,   16,    8,  0,  0,  0 }, {      3,   16,    8,  0,  0,  0 }, {      2,   16,    8,  0,  0,  0 },
    {      1,   16,    8,  0,  0,  0 }, {      0,   16,    8,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C01C4, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    2,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    3,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    4,  8,  1,  0 }, {     16,    9,    4,  8,  1,  0 },
    {     16,   10,    4,  8,  1,  0 }, {     16,   11,    5,  8,  1,  0 }, {     16,   12,    5,  8,  1,  0 }, {     16,   13,    5,  8,  1,  0 }, {     16,   14,    6,  8,  1,  0 },
    {     16,   15,    6,  8,  1,  0 }, {     16,   16,    6,  8,  1,  0 }, {     16,   17,    6,  8,  1,  0 }, {     16,   18,    7,  8,  1,  0 }, {     16,   19,    7,  8,  1,  0 },
    {     16,   20,    7,  8,  1,  0 }, {     16,   21,    7,  8,  1,  0 }, {     16,   22,    7,  8,  0,  0 }, {     16,   23,    7,  8,  0,  0 }, {     16,   24,    8,  8,  0,  0 },
    {     16,   25,    8,  8,  0,  0 }, {     16,   26,    8,  8,  0,  0 }, {     16,   27,    8,  8,  0,  0 }, {     16,   28,    8,  8,  0,  0 }, {     16,   29,    8,  8,  0,  0 },
    {     16,   30,    8,  8,  0,  0 }, {     16,   31,    8,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C02E6, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    2, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    3, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    4, 16,  1,  0 }, {      9,   16,    4, 16,  1,  0 },
    {     10,   16,    4, 16,  1,  0 }, {     11,   16,    5, 16,  1,  0 }, {     12,   16,    5, 16,  1,  0 }, {     13,   16,    5, 16,  1,  0 }, {     14,   16,    6, 16,  1,  0 },
    {     15,   16,    6, 16,  1,  0 }, {     16,   16,    6, 16,  1,  0 }, {     17,   16,    6, 16,  1,  0 }, {     18,   16,    7, 16,  1,  0 }, {     19,   16,    7, 16,  1,  0 },
    {     20,   16,    7, 16,  1,  0 }, {     21,   16,    7, 16,  1,  0 }, {     22,   16,    7, 16,  0,  0 }, {     23,   16,    7, 16,  0,  0 }, {     24,   16,    8, 16,  0,  0 },
    {     25,   16,    8, 16,  0,  0 }, {     26,   16,    8, 16,  0,  0 }, {     27,   16,    8, 16,  0,  0 }, {     28,   16,    8, 16,  0,  0 }, {     29,   16,    8, 16,  0,  0 },
    {     30,   16,    8, 16,  0,  0 }, {     31,   16,    8, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C0408, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    1, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    2, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    3, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    3, 24,  2,  0 }, {     16,   23,    4, 24,  1,  0 }, {     16,   22,    4, 24,  1,  0 },
    {     16,   21,    4, 24,  1,  0 }, {     16,   20,    5, 24,  1,  0 }, {     16,   19,    5, 24,  1,  0 }, {     16,   18,    5, 24,  1,  0 }, {     16,   17,    6, 24,  1,  0 },
    {     16,   16,    6, 24,  1,  0 }, {     16,   15,    6, 24,  1,  0 }, {     16,   14,    6, 24,  1,  0 }, {     16,   13,    7, 24,  1,  0 }, {     16,   12,    7, 24,  1,  0 },
    {     16,   11,    7, 24,  1,  0 }, {     16,   10,    7, 24,  1,  0 }, {     16,    9,    7, 24,  0,  0 }, {     16,    8,    7, 24,  0,  0 }, {     16,    7,    8, 24,  0,  0 },
    {     16,    6,    8, 24,  0,  0 }, {     16,    5,    8, 24,  0,  0 }, {     16,    4,    8, 24,  0,  0 }, {     16,    3,    8, 24,  0,  0 }, {     16,    2,    8, 24,  0,  0 },
    {     16,    1,    8, 24,  0,  0 }, {     16,    0,    8, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C27B2, {
    {     31,   16,   15,  0,  6,  0 }, {     30,   16,   15,  0,  6,  0 }, {     29,   16,   14,  0,  6,  0 }, {     28,   16,   14,  0,  6,  0 }, {     27,   16,   13,  0,  6,  0 },
    {     26,   16,   13,  0,  6,  0 }, {     25,   16,   12,  0,  6,  0 }, {     24,   16,   12,  0,  6,  0 }, {     23,   16,   11,  0,  6,  0 }, {     22,   16,   11,  0,  6,  0 },
    {     21,   16,   10,  0,  6,  0 }, {     20,   16,   10,  0,  6,  0 }, {     19,   16,    9,  0,  6,  0 }, {     18,   16,    9,  0,  6,  0 }, {     17,   16,    8,  0,  6,  0 },
    {     16,   16,    8,  0,  6,  0 }, {     15,   16,    7,  0,  6,  0 }, {     14,   16,    7,  0,  6,  0 }, {     13,   16,    6,  0,  6,  0 }, {     12,   16,    6,  0,  6,  0 },
    {     11,   16,    5,  0,  6,  0 }, {     10,   16,    5,  0,  6,  0 }, {      9,   16,    4,  0,  6,  0 }, {      8,   16,    4,  0,  6,  0 }, {      7,   16,    3,  0,  6,  0 },
    {      6,   16,    3,  0,  6,  0 }, {      5,   16,    2,  0,  6,  0 }, {      4,   16,    2,  0,  6,  0 }, {      3,   16,    1,  0,  6,  0 }, {      2,   16,    1,  0,  6,  0 },
    {      1,   16,    0,  0,  6,  0 }, {      0,   16,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C28D4, {
    {     16,    0,   15,  8,  6,  0 }, {     16,    1,   14,  8,  6,  0 }, {     16,    2,   14,  8,  6,  0 }, {     16,    3,   13,  8,  6,  0 }, {     16,    4,   13,  8,  6,  0 },
    {     16,    5,   12,  8,  6,  0 }, {     16,    6,   12,  8,  6,  0 }, {     16,    7,   11,  8,  6,  0 }, {     16,    8,   11,  8,  6,  0 }, {     16,    9,   10,  8,  6,  0 },
    {     16,   10,   10,  8,  6,  0 }, {     16,   11,    9,  8,  6,  0 }, {     16,   12,    9,  8,  6,  0 }, {     16,   13,    8,  8,  6,  0 }, {     16,   14,    8,  8,  6,  0 },
    {     16,   15,    7,  8,  6,  0 }, {     16,   16,    7,  8,  6,  0 }, {     16,   17,    6,  8,  6,  0 }, {     16,   18,    6,  8,  6,  0 }, {     16,   19,    5,  8,  6,  0 },
    {     16,   20,    5,  8,  6,  0 }, {     16,   21,    4,  8,  6,  0 }, {     16,   22,    4,  8,  6,  0 }, {     16,   23,    3,  8,  6,  0 }, {     16,   24,    3,  8,  6,  0 },
    {     16,   25,    2,  8,  6,  0 }, {     16,   26,    2,  8,  6,  0 }, {     16,   27,    1,  8,  6,  0 }, {     16,   28,    1,  8,  6,  0 }, {     16,   29,    0,  8,  6,  0 },
    {     16,   30,    0,  8,  6,  0 }, {     16,   31,   -1,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C29F6, {
    {      0,   16,   15, 16,  6,  0 }, {      1,   16,   14, 16,  6,  0 }, {      2,   16,   14, 16,  6,  0 }, {      3,   16,   13, 16,  6,  0 }, {      4,   16,   13, 16,  6,  0 },
    {      5,   16,   12, 16,  6,  0 }, {      6,   16,   12, 16,  6,  0 }, {      7,   16,   11, 16,  6,  0 }, {      8,   16,   11, 16,  6,  0 }, {      9,   16,   10, 16,  6,  0 },
    {     10,   16,   10, 16,  6,  0 }, {     11,   16,    9, 16,  6,  0 }, {     12,   16,    9, 16,  6,  0 }, {     13,   16,    8, 16,  6,  0 }, {     14,   16,    8, 16,  6,  0 },
    {     15,   16,    7, 16,  6,  0 }, {     16,   16,    7, 16,  6,  0 }, {     17,   16,    6, 16,  6,  0 }, {     18,   16,    6, 16,  6,  0 }, {     19,   16,    5, 16,  6,  0 },
    {     20,   16,    5, 16,  6,  0 }, {     21,   16,    4, 16,  6,  0 }, {     22,   16,    4, 16,  6,  0 }, {     23,   16,    3, 16,  6,  0 }, {     24,   16,    3, 16,  6,  0 },
    {     25,   16,    2, 16,  6,  0 }, {     26,   16,    2, 16,  6,  0 }, {     27,   16,    1, 16,  6,  0 }, {     28,   16,    1, 16,  6,  0 }, {     29,   16,    0, 16,  6,  0 },
    {     30,   16,    0, 16,  6,  0 }, {     31,   16,   -1, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C2B18, {
    {     16,   31,   15, 24,  6,  0 }, {     16,   30,   15, 24,  6,  0 }, {     16,   29,   14, 24,  6,  0 }, {     16,   28,   14, 24,  6,  0 }, {     16,   27,   13, 24,  6,  0 },
    {     16,   26,   13, 24,  6,  0 }, {     16,   25,   12, 24,  6,  0 }, {     16,   24,   12, 24,  6,  0 }, {     16,   23,   11, 24,  6,  0 }, {     16,   22,   11, 24,  6,  0 },
    {     16,   21,   10, 24,  6,  0 }, {     16,   20,   10, 24,  6,  0 }, {     16,   19,    9, 24,  6,  0 }, {     16,   18,    9, 24,  6,  0 }, {     16,   17,    8, 24,  6,  0 },
    {     16,   16,    8, 24,  6,  0 }, {     16,   15,    7, 24,  6,  0 }, {     16,   14,    7, 24,  6,  0 }, {     16,   13,    6, 24,  6,  0 }, {     16,   12,    6, 24,  6,  0 },
    {     16,   11,    5, 24,  6,  0 }, {     16,   10,    5, 24,  6,  0 }, {     16,    9,    4, 24,  6,  0 }, {     16,    8,    4, 24,  6,  0 }, {     16,    7,    3, 24,  6,  0 },
    {     16,    6,    3, 24,  6,  0 }, {     16,    5,    2, 24,  6,  0 }, {     16,    4,    2, 24,  6,  0 }, {     16,    3,    1, 24,  6,  0 }, {     16,    2,    1, 24,  6,  0 },
    {     16,    1,    0, 24,  6,  0 }, {     16,    0,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C2C3A, {
    {     31,   16,   63,  0,  8,  0 }, {     31,   16,   62,  0,  8,  0 }, {     30,   16,   61,  0,  8,  0 }, {     30,   16,   60,  0,  8,  0 }, {     29,   16,   59,  0,  8,  0 },
    {     29,   16,   58,  0,  8,  0 }, {     28,   16,   57,  0,  8,  0 }, {     28,   16,   56,  0,  8,  0 }, {     27,   16,   55,  0,  8,  0 }, {     27,   16,   54,  0,  8,  0 },
    {     26,   16,   53,  0,  8,  0 }, {     26,   16,   52,  0,  8,  0 }, {     25,   16,   51,  0,  8,  0 }, {     25,   16,   50,  0,  8,  0 }, {     24,   16,   49,  0,  8,  0 },
    {     24,   16,   48,  0,  8,  0 }, {     23,   16,   47,  0,  8,  0 }, {     23,   16,   46,  0,  8,  0 }, {     22,   16,   45,  0,  8,  0 }, {     22,   16,   44,  0,  8,  0 },
    {     21,   16,   43,  0,  8,  0 }, {     21,   16,   42,  0,  8,  0 }, {     20,   16,   41,  0,  8,  0 }, {     20,   16,   40,  0,  8,  0 }, {     19,   16,   39,  0,  8,  0 },
    {     19,   16,   38,  0,  8,  0 }, {     18,   16,   37,  0,  8,  0 }, {     18,   16,   36,  0,  8,  0 }, {     17,   16,   35,  0,  8,  0 }, {     17,   16,   34,  0,  8,  0 },
    {     16,   16,   33,  0,  8,  0 }, {     16,   16,   32,  0,  8,  0 }, {     15,   16,   31,  0,  8,  0 }, {     15,   16,   30,  0,  8,  0 }, {     14,   16,   29,  0,  8,  0 },
    {     14,   16,   28,  0,  8,  0 }, {     13,   16,   27,  0,  8,  0 }, {     13,   16,   26,  0,  8,  0 }, {     12,   16,   25,  0,  8,  0 }, {     12,   16,   24,  0,  8,  0 },
    {     11,   16,   23,  0,  8,  0 }, {     11,   16,   22,  0,  8,  0 }, {     10,   16,   21,  0,  8,  0 }, {     10,   16,   20,  0,  8,  0 }, {      9,   16,   19,  0,  8,  0 },
    {      9,   16,   18,  0,  8,  0 }, {      8,   16,   17,  0,  8,  0 }, {      8,   16,   16,  0,  8,  0 }, {      7,   16,   15,  0,  8,  0 }, {      7,   16,   14,  0,  8,  0 },
    {      6,   16,   13,  0,  8,  0 }, {      6,   16,   12,  0,  8,  0 }, {      5,   16,   11,  0,  8,  0 }, {      5,   16,   10,  0,  8,  0 }, {      4,   16,    9,  0,  8,  0 },
    {      4,   16,    8,  0,  8,  0 }, {      3,   16,    7,  0,  8,  0 }, {      3,   16,    6,  0,  8,  0 }, {      2,   16,    5,  0,  8,  0 }, {      2,   16,    4,  0,  8,  0 },
    {      1,   16,    3,  0,  8,  0 }, {      1,   16,    2,  0,  8,  0 }, {      0,   16,    1,  0,  8,  0 }, {      0,   16,    0,  0,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C2E7C, {
    {     16,    0,   63,  8,  8,  0 }, {     16,    0,   62,  8,  8,  0 }, {     16,    1,   61,  8,  8,  0 }, {     16,    1,   60,  8,  8,  0 }, {     16,    2,   59,  8,  8,  0 },
    {     16,    2,   58,  8,  8,  0 }, {     16,    3,   57,  8,  8,  0 }, {     16,    3,   56,  8,  8,  0 }, {     16,    4,   55,  8,  8,  0 }, {     16,    4,   54,  8,  8,  0 },
    {     16,    5,   53,  8,  8,  0 }, {     16,    5,   52,  8,  8,  0 }, {     16,    6,   51,  8,  8,  0 }, {     16,    6,   50,  8,  8,  0 }, {     16,    7,   49,  8,  8,  0 },
    {     16,    7,   48,  8,  8,  0 }, {     16,    8,   47,  8,  8,  0 }, {     16,    8,   46,  8,  8,  0 }, {     16,    9,   45,  8,  8,  0 }, {     16,    9,   44,  8,  8,  0 },
    {     16,   10,   43,  8,  8,  0 }, {     16,   10,   42,  8,  8,  0 }, {     16,   11,   41,  8,  8,  0 }, {     16,   11,   40,  8,  8,  0 }, {     16,   12,   39,  8,  8,  0 },
    {     16,   12,   38,  8,  8,  0 }, {     16,   13,   37,  8,  8,  0 }, {     16,   13,   36,  8,  8,  0 }, {     16,   14,   35,  8,  8,  0 }, {     16,   14,   34,  8,  8,  0 },
    {     16,   15,   33,  8,  8,  0 }, {     16,   15,   32,  8,  8,  0 }, {     16,   16,   31,  8,  8,  0 }, {     16,   16,   30,  8,  8,  0 }, {     16,   17,   29,  8,  8,  0 },
    {     16,   17,   28,  8,  8,  0 }, {     16,   18,   27,  8,  8,  0 }, {     16,   18,   26,  8,  8,  0 }, {     16,   19,   25,  8,  8,  0 }, {     16,   19,   24,  8,  8,  0 },
    {     16,   20,   23,  8,  8,  0 }, {     16,   20,   22,  8,  8,  0 }, {     16,   21,   21,  8,  8,  0 }, {     16,   21,   20,  8,  8,  0 }, {     16,   22,   19,  8,  8,  0 },
    {     16,   22,   18,  8,  8,  0 }, {     16,   23,   17,  8,  8,  0 }, {     16,   23,   16,  8,  8,  0 }, {     16,   24,   15,  8,  8,  0 }, {     16,   24,   14,  8,  8,  0 },
    {     16,   25,   13,  8,  8,  0 }, {     16,   25,   12,  8,  8,  0 }, {     16,   26,   11,  8,  8,  0 }, {     16,   26,   10,  8,  8,  0 }, {     16,   27,    9,  8,  8,  0 },
    {     16,   27,    8,  8,  8,  0 }, {     16,   28,    7,  8,  8,  0 }, {     16,   28,    6,  8,  8,  0 }, {     16,   29,    5,  8,  8,  0 }, {     16,   29,    4,  8,  8,  0 },
    {     16,   30,    3,  8,  8,  0 }, {     16,   30,    2,  8,  8,  0 }, {     16,   31,    1,  8,  8,  0 }, {     16,   31,    0,  8,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C30BE, {
    {      0,   16,   63, 16,  8,  0 }, {      0,   16,   62, 16,  8,  0 }, {      1,   16,   61, 16,  8,  0 }, {      1,   16,   60, 16,  8,  0 }, {      2,   16,   59, 16,  8,  0 },
    {      2,   16,   58, 16,  8,  0 }, {      3,   16,   57, 16,  8,  0 }, {      3,   16,   56, 16,  8,  0 }, {      4,   16,   55, 16,  8,  0 }, {      4,   16,   54, 16,  8,  0 },
    {      5,   16,   53, 16,  8,  0 }, {      5,   16,   52, 16,  8,  0 }, {      6,   16,   51, 16,  8,  0 }, {      6,   16,   50, 16,  8,  0 }, {      7,   16,   49, 16,  8,  0 },
    {      7,   16,   48, 16,  8,  0 }, {      8,   16,   47, 16,  8,  0 }, {      8,   16,   46, 16,  8,  0 }, {      9,   16,   45, 16,  8,  0 }, {      9,   16,   44, 16,  8,  0 },
    {     10,   16,   43, 16,  8,  0 }, {     10,   16,   42, 16,  8,  0 }, {     11,   16,   41, 16,  8,  0 }, {     11,   16,   40, 16,  8,  0 }, {     12,   16,   39, 16,  8,  0 },
    {     12,   16,   38, 16,  8,  0 }, {     13,   16,   37, 16,  8,  0 }, {     13,   16,   36, 16,  8,  0 }, {     14,   16,   35, 16,  8,  0 }, {     14,   16,   34, 16,  8,  0 },
    {     15,   16,   33, 16,  8,  0 }, {     15,   16,   32, 16,  8,  0 }, {     16,   16,   31, 16,  8,  0 }, {     16,   16,   30, 16,  8,  0 }, {     17,   16,   29, 16,  8,  0 },
    {     17,   16,   28, 16,  8,  0 }, {     18,   16,   27, 16,  8,  0 }, {     18,   16,   26, 16,  8,  0 }, {     19,   16,   25, 16,  8,  0 }, {     19,   16,   24, 16,  8,  0 },
    {     20,   16,   23, 16,  8,  0 }, {     20,   16,   22, 16,  8,  0 }, {     21,   16,   21, 16,  8,  0 }, {     21,   16,   20, 16,  8,  0 }, {     22,   16,   19, 16,  8,  0 },
    {     22,   16,   18, 16,  8,  0 }, {     23,   16,   17, 16,  8,  0 }, {     23,   16,   16, 16,  8,  0 }, {     24,   16,   15, 16,  8,  0 }, {     24,   16,   14, 16,  8,  0 },
    {     25,   16,   13, 16,  8,  0 }, {     25,   16,   12, 16,  8,  0 }, {     26,   16,   11, 16,  8,  0 }, {     26,   16,   10, 16,  8,  0 }, {     27,   16,    9, 16,  8,  0 },
    {     27,   16,    8, 16,  8,  0 }, {     28,   16,    7, 16,  8,  0 }, {     28,   16,    6, 16,  8,  0 }, {     29,   16,    5, 16,  8,  0 }, {     29,   16,    4, 16,  8,  0 },
    {     30,   16,    3, 16,  8,  0 }, {     30,   16,    2, 16,  8,  0 }, {     31,   16,    1, 16,  8,  0 }, {     31,   16,    0, 16,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C3300, {
    {     16,   31,   63, 24,  8,  0 }, {     16,   31,   62, 24,  8,  0 }, {     16,   30,   61, 24,  8,  0 }, {     16,   30,   60, 24,  8,  0 }, {     16,   29,   59, 24,  8,  0 },
    {     16,   29,   58, 24,  8,  0 }, {     16,   28,   57, 24,  8,  0 }, {     16,   28,   56, 24,  8,  0 }, {     16,   27,   55, 24,  8,  0 }, {     16,   27,   54, 24,  8,  0 },
    {     16,   26,   53, 24,  8,  0 }, {     16,   26,   52, 24,  8,  0 }, {     16,   25,   51, 24,  8,  0 }, {     16,   25,   50, 24,  8,  0 }, {     16,   24,   49, 24,  8,  0 },
    {     16,   24,   48, 24,  8,  0 }, {     16,   23,   47, 24,  8,  0 }, {     16,   23,   46, 24,  8,  0 }, {     16,   22,   45, 24,  8,  0 }, {     16,   22,   44, 24,  8,  0 },
    {     16,   21,   43, 24,  8,  0 }, {     16,   21,   42, 24,  8,  0 }, {     16,   20,   41, 24,  8,  0 }, {     16,   20,   40, 24,  8,  0 }, {     16,   19,   39, 24,  8,  0 },
    {     16,   19,   38, 24,  8,  0 }, {     16,   18,   37, 24,  8,  0 }, {     16,   18,   36, 24,  8,  0 }, {     16,   17,   35, 24,  8,  0 }, {     16,   17,   34, 24,  8,  0 },
    {     16,   16,   33, 24,  8,  0 }, {     16,   16,   32, 24,  8,  0 }, {     16,   15,   31, 24,  8,  0 }, {     16,   15,   30, 24,  8,  0 }, {     16,   14,   29, 24,  8,  0 },
    {     16,   14,   28, 24,  8,  0 }, {     16,   13,   27, 24,  8,  0 }, {     16,   13,   26, 24,  8,  0 }, {     16,   12,   25, 24,  8,  0 }, {     16,   12,   24, 24,  8,  0 },
    {     16,   11,   23, 24,  8,  0 }, {     16,   11,   22, 24,  8,  0 }, {     16,   10,   21, 24,  8,  0 }, {     16,   10,   20, 24,  8,  0 }, {     16,    9,   19, 24,  8,  0 },
    {     16,    9,   18, 24,  8,  0 }, {     16,    8,   17, 24,  8,  0 }, {     16,    8,   16, 24,  8,  0 }, {     16,    7,   15, 24,  8,  0 }, {     16,    7,   14, 24,  8,  0 },
    {     16,    6,   13, 24,  8,  0 }, {     16,    6,   12, 24,  8,  0 }, {     16,    5,   11, 24,  8,  0 }, {     16,    5,   10, 24,  8,  0 }, {     16,    4,    9, 24,  8,  0 },
    {     16,    4,    8, 24,  8,  0 }, {     16,    3,    7, 24,  8,  0 }, {     16,    3,    6, 24,  8,  0 }, {     16,    2,    5, 24,  8,  0 }, {     16,    2,    4, 24,  8,  0 },
    {     16,    1,    3, 24,  8,  0 }, {     16,    1,    2, 24,  8,  0 }, {     16,    0,    1, 24,  8,  0 }, {     16,    0,    0, 24,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C09B2, {
    {     31,   16,    8,  0,  0,  0 }, {     30,   16,    8,  0,  0,  0 }, {     29,   16,    8,  0,  0,  0 }, {     28,   16,    8,  0,  0,  0 }, {     27,   16,    8,  0,  0,  0 },
    {     26,   16,    8,  0,  0,  0 }, {     25,   16,    8,  0,  0,  0 }, {     24,   16,    8,  0,  0,  0 }, {     23,   16,    7,  0,  5,  0 }, {     22,   16,    7,  0,  5,  0 },
    {     21,   16,    7,  0,  5,  0 }, {     20,   16,    7,  0,  5,  0 }, {     19,   16,    7,  0,  5,  0 }, {     18,   16,    7,  0,  5,  0 }, {     17,   16,    6,  0,  5,  0 },
    {     16,   16,    6,  0,  5,  0 }, {     15,   16,    6,  0,  5,  0 }, {     14,   16,    6,  0,  5,  0 }, {     13,   16,    5,  0,  5,  0 }, {     12,   16,    5,  0,  5,  0 },
    {     11,   16,    5,  0,  5,  0 }, {     10,   16,    4,  0,  5,  0 }, {      9,   16,    4,  0,  5,  0 }, {      8,   16,    4,  0,  5,  0 }, {      7,   16,    3,  0,  6,  0 },
    {      6,   16,    3,  0,  6,  0 }, {      5,   16,    2,  0,  6,  0 }, {      4,   16,    2,  0,  6,  0 }, {      3,   16,    1,  0,  6,  0 }, {      2,   16,    1,  0,  6,  0 },
    {      1,   16,    0,  0,  6,  0 }, {      0,   16,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C0AD4, {
    {     16,    0,    8,  8,  0,  0 }, {     16,    1,    8,  8,  0,  0 }, {     16,    2,    8,  8,  0,  0 }, {     16,    3,    8,  8,  0,  0 }, {     16,    4,    8,  8,  0,  0 },
    {     16,    5,    8,  8,  0,  0 }, {     16,    6,    8,  8,  0,  0 }, {     16,    7,    8,  8,  0,  0 }, {     16,    8,    7,  8,  5,  0 }, {     16,    9,    7,  8,  5,  0 },
    {     16,   10,    7,  8,  5,  0 }, {     16,   11,    7,  8,  5,  0 }, {     16,   12,    7,  8,  5,  0 }, {     16,   13,    7,  8,  5,  0 }, {     16,   14,    6,  8,  5,  0 },
    {     16,   15,    6,  8,  5,  0 }, {     16,   16,    6,  8,  5,  0 }, {     16,   17,    6,  8,  5,  0 }, {     16,   18,    5,  8,  5,  0 }, {     16,   19,    5,  8,  5,  0 },
    {     16,   20,    5,  8,  5,  0 }, {     16,   21,    4,  8,  5,  0 }, {     16,   22,    4,  8,  5,  0 }, {     16,   23,    4,  8,  5,  0 }, {     16,   24,    3,  8,  6,  0 },
    {     16,   25,    3,  8,  6,  0 }, {     16,   26,    3,  8,  6,  0 }, {     16,   27,    2,  8,  6,  0 }, {     16,   28,    2,  8,  6,  0 }, {     16,   29,    1,  8,  6,  0 },
    {     16,   30,    1,  8,  6,  0 }, {     16,   31,    0,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C0BF6, {
    {      0,   16,    8, 16,  0,  0 }, {      1,   16,    8, 16,  0,  0 }, {      2,   16,    8, 16,  0,  0 }, {      3,   16,    8, 16,  0,  0 }, {      4,   16,    8, 16,  0,  0 },
    {      5,   16,    8, 16,  0,  0 }, {      6,   16,    8, 16,  0,  0 }, {      7,   16,    8, 16,  0,  0 }, {      8,   16,    7, 16,  5,  0 }, {      9,   16,    7, 16,  5,  0 },
    {     10,   16,    7, 16,  5,  0 }, {     11,   16,    7, 16,  5,  0 }, {     12,   16,    7, 16,  5,  0 }, {     13,   16,    7, 16,  5,  0 }, {     14,   16,    6, 16,  5,  0 },
    {     15,   16,    6, 16,  5,  0 }, {     16,   16,    6, 16,  5,  0 }, {     17,   16,    6, 16,  5,  0 }, {     18,   16,    5, 16,  5,  0 }, {     19,   16,    5, 16,  5,  0 },
    {     20,   16,    5, 16,  5,  0 }, {     21,   16,    4, 16,  5,  0 }, {     22,   16,    4, 16,  5,  0 }, {     23,   16,    4, 16,  5,  0 }, {     24,   16,    3, 16,  6,  0 },
    {     25,   16,    3, 16,  6,  0 }, {     26,   16,    3, 16,  6,  0 }, {     27,   16,    2, 16,  6,  0 }, {     28,   16,    2, 16,  6,  0 }, {     29,   16,    1, 16,  6,  0 },
    {     30,   16,    1, 16,  6,  0 }, {     31,   16,    0, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C0D18, {
    {     16,   31,    8, 24,  0,  0 }, {     16,   30,    8, 24,  0,  0 }, {     16,   29,    8, 24,  0,  0 }, {     16,   28,    8, 24,  0,  0 }, {     16,   27,    8, 24,  0,  0 },
    {     16,   26,    8, 24,  0,  0 }, {     16,   25,    8, 24,  0,  0 }, {     16,   24,    8, 24,  0,  0 }, {     16,   23,    7, 24,  5,  0 }, {     16,   22,    7, 24,  5,  0 },
    {     16,   21,    7, 24,  5,  0 }, {     16,   20,    7, 24,  5,  0 }, {     16,   19,    7, 24,  5,  0 }, {     16,   18,    7, 24,  5,  0 }, {     16,   17,    6, 24,  5,  0 },
    {     16,   16,    6, 24,  5,  0 }, {     16,   15,    6, 24,  5,  0 }, {     16,   14,    6, 24,  5,  0 }, {     16,   13,    5, 24,  5,  0 }, {     16,   12,    5, 24,  5,  0 },
    {     16,   11,    5, 24,  5,  0 }, {     16,   10,    4, 24,  5,  0 }, {     16,    9,    4, 24,  5,  0 }, {     16,    8,    4, 24,  5,  0 }, {     16,    7,    3, 24,  6,  0 },
    {     16,    6,    3, 24,  6,  0 }, {     16,    5,    2, 24,  6,  0 }, {     16,    4,    2, 24,  6,  0 }, {     16,    3,    1, 24,  6,  0 }, {     16,    2,    1, 24,  6,  0 },
    {     16,    1,    0, 24,  6,  0 }, {     16,    0,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C1DEE, {
    {     31,   16,   31,  0,  6,  0 }, {     30,   16,   31,  0,  6,  0 }, {     29,   16,   30,  0,  6,  0 }, {     28,   16,   30,  0,  6,  0 }, {     27,   16,   29,  0,  6,  0 },
    {     26,   16,   28,  0,  6,  0 }, {     25,   16,   28,  0,  6,  0 }, {     24,   16,   27,  0,  6,  0 }, {     23,   16,   26,  0,  6,  0 }, {     22,   16,   26,  0,  6,  0 },
    {     21,   16,   25,  0,  7,  0 }, {     20,   16,   24,  0,  7,  0 }, {     19,   16,   23,  0,  7,  0 }, {     18,   16,   23,  0,  7,  0 }, {     17,   16,   22,  0,  7,  0 },
    {     16,   16,   21,  0,  7,  0 }, {     15,   16,   20,  0,  7,  0 }, {     14,   16,   19,  0,  7,  0 }, {     13,   16,   18,  0,  7,  0 }, {     12,   16,   16,  0,  7,  0 },
    {     11,   16,   15,  0,  7,  0 }, {     10,   16,   14,  0,  7,  0 }, {      9,   16,   13,  0,  7,  0 }, {      8,   16,   12,  0,  7,  0 }, {      8,   16,   11,  0,  7,  0 },
    {      7,   16,   10,  0,  7,  0 }, {      6,   16,    9,  0,  7,  0 }, {      5,   16,    8,  0,  8,  0 }, {      5,   16,    7,  0,  8,  0 }, {      4,   16,    6,  0,  8,  0 },
    {      3,   16,    5,  0,  8,  0 }, {      3,   16,    4,  0,  8,  0 }, {      2,   16,    3,  0,  8,  0 }, {      1,   16,    2,  0,  8,  0 }, {      1,   16,    1,  0,  8,  0 },
    {      0,   16,    0,  0,  8,  0 }, {      0,   16,   -1,  0,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C1F3D, {
    {     16,    0,   31,  8,  6,  0 }, {     16,    1,   31,  8,  6,  0 }, {     16,    2,   30,  8,  6,  0 }, {     16,    3,   30,  8,  6,  0 }, {     16,    4,   29,  8,  6,  0 },
    {     16,    5,   28,  8,  6,  0 }, {     16,    6,   28,  8,  6,  0 }, {     16,    7,   27,  8,  6,  0 }, {     16,    8,   26,  8,  6,  0 }, {     16,    9,   26,  8,  6,  0 },
    {     16,   10,   25,  8,  7,  0 }, {     16,   11,   24,  8,  7,  0 }, {     16,   12,   23,  8,  7,  0 }, {     16,   13,   23,  8,  7,  0 }, {     16,   14,   22,  8,  7,  0 },
    {     16,   15,   21,  8,  7,  0 }, {     16,   16,   20,  8,  7,  0 }, {     16,   17,   19,  8,  7,  0 }, {     16,   18,   18,  8,  7,  0 }, {     16,   19,   16,  8,  7,  0 },
    {     16,   20,   15,  8,  7,  0 }, {     16,   21,   14,  8,  7,  0 }, {     16,   22,   13,  8,  7,  0 }, {     16,   23,   12,  8,  7,  0 }, {     16,   23,   11,  8,  7,  0 },
    {     16,   24,   10,  8,  7,  0 }, {     16,   25,    9,  8,  7,  0 }, {     16,   26,    8,  8,  8,  0 }, {     16,   26,    7,  8,  8,  0 }, {     16,   27,    6,  8,  8,  0 },
    {     16,   28,    5,  8,  8,  0 }, {     16,   28,    4,  8,  8,  0 }, {     16,   29,    3,  8,  8,  0 }, {     16,   30,    2,  8,  8,  0 }, {     16,   30,    1,  8,  8,  0 },
    {     16,   31,    0,  8,  8,  0 }, {     16,   31,   -1,  8,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C208C, {
    {      0,   16,   31, 16,  6,  0 }, {      1,   16,   31, 16,  6,  0 }, {      2,   16,   30, 16,  6,  0 }, {      3,   16,   30, 16,  6,  0 }, {      4,   16,   29, 16,  6,  0 },
    {      5,   16,   28, 16,  6,  0 }, {      6,   16,   28, 16,  6,  0 }, {      7,   16,   27, 16,  6,  0 }, {      8,   16,   26, 16,  6,  0 }, {      9,   16,   26, 16,  6,  0 },
    {     10,   16,   25, 16,  7,  0 }, {     11,   16,   24, 16,  7,  0 }, {     12,   16,   23, 16,  7,  0 }, {     13,   16,   23, 16,  7,  0 }, {     14,   16,   22, 16,  7,  0 },
    {     15,   16,   21, 16,  7,  0 }, {     16,   16,   20, 16,  7,  0 }, {     17,   16,   19, 16,  7,  0 }, {     18,   16,   18, 16,  7,  0 }, {     19,   16,   16, 16,  7,  0 },
    {     20,   16,   15, 16,  7,  0 }, {     21,   16,   14, 16,  7,  0 }, {     22,   16,   13, 16,  7,  0 }, {     23,   16,   12, 16,  7,  0 }, {     23,   16,   11, 16,  7,  0 },
    {     24,   16,   10, 16,  7,  0 }, {     25,   16,    9, 16,  7,  0 }, {     26,   16,    8, 16,  8,  0 }, {     26,   16,    7, 16,  8,  0 }, {     27,   16,    6, 16,  8,  0 },
    {     28,   16,    5, 16,  8,  0 }, {     28,   16,    4, 16,  8,  0 }, {     29,   16,    3, 16,  8,  0 }, {     30,   16,    2, 16,  8,  0 }, {     30,   16,    1, 16,  8,  0 },
    {     31,   16,    0, 16,  8,  0 }, {     31,   16,   -1, 16,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C21DB, {
    {     16,   31,   31, 24,  6,  0 }, {     16,   30,   31, 24,  6,  0 }, {     16,   29,   30, 24,  6,  0 }, {     16,   28,   30, 24,  6,  0 }, {     16,   27,   29, 24,  6,  0 },
    {     16,   26,   28, 24,  6,  0 }, {     16,   25,   28, 24,  6,  0 }, {     16,   24,   27, 24,  6,  0 }, {     16,   23,   26, 24,  6,  0 }, {     16,   22,   26, 24,  6,  0 },
    {     16,   21,   25, 24,  7,  0 }, {     16,   20,   24, 24,  7,  0 }, {     16,   19,   23, 24,  7,  0 }, {     16,   18,   23, 24,  7,  0 }, {     16,   17,   22, 24,  7,  0 },
    {     16,   16,   21, 24,  7,  0 }, {     16,   15,   20, 24,  7,  0 }, {     16,   14,   19, 24,  7,  0 }, {     16,   13,   18, 24,  7,  0 }, {     16,   12,   16, 24,  7,  0 },
    {     16,   11,   15, 24,  7,  0 }, {     16,   10,   14, 24,  7,  0 }, {     16,    9,   13, 24,  7,  0 }, {     16,    8,   12, 24,  7,  0 }, {     16,    8,   11, 24,  7,  0 },
    {     16,    7,   10, 24,  7,  0 }, {     16,    6,    9, 24,  7,  0 }, {     16,    5,    8, 24,  8,  0 }, {     16,    5,    7, 24,  8,  0 }, {     16,    4,    6, 24,  8,  0 },
    {     16,    3,    5, 24,  8,  0 }, {     16,    3,    4, 24,  8,  0 }, {     16,    2,    3, 24,  8,  0 }, {     16,    1,    2, 24,  8,  0 }, {     16,    1,    1, 24,  8,  0 },
    {     16,    0,    0, 24,  8,  0 }, {     16,    0,   -1, 24,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C18B2, {
    {     31,   16,   31,  0,  8,  0 }, {     31,   16,   30,  0,  8,  0 }, {     30,   16,   29,  0,  8,  0 }, {     30,   16,   28,  0,  8,  0 }, {     29,   16,   27,  0,  8,  0 },
    {     28,   16,   26,  0,  8,  0 }, {     28,   16,   25,  0,  8,  0 }, {     27,   16,   24,  0,  8,  0 }, {     26,   16,   23,  0,  8,  0 }, {     26,   16,   22,  0,  8,  0 },
    {     25,   16,   21,  0,  7,  0 }, {     24,   16,   20,  0,  7,  0 }, {     23,   16,   19,  0,  7,  0 }, {     23,   16,   18,  0,  7,  0 }, {     22,   16,   17,  0,  7,  0 },
    {     21,   16,   16,  0,  7,  0 }, {     20,   16,   15,  0,  7,  0 }, {     19,   16,   14,  0,  7,  0 }, {     18,   16,   13,  0,  7,  0 }, {     16,   16,   12,  0,  7,  0 },
    {     15,   16,   11,  0,  7,  0 }, {     14,   16,   10,  0,  7,  0 }, {     13,   16,    9,  0,  7,  0 }, {     12,   16,    8,  0,  7,  0 }, {     11,   16,    8,  0,  7,  0 },
    {     10,   16,    7,  0,  7,  0 }, {      9,   16,    6,  0,  7,  0 }, {      8,   16,    5,  0,  6,  0 }, {      7,   16,    5,  0,  6,  0 }, {      6,   16,    4,  0,  6,  0 },
    {      5,   16,    3,  0,  6,  0 }, {      4,   16,    3,  0,  6,  0 }, {      3,   16,    2,  0,  6,  0 }, {      2,   16,    1,  0,  6,  0 }, {      1,   16,    1,  0,  6,  0 },
    {      0,   16,    0,  0,  6,  0 }, {     -1,   16,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C1A01, {
    {     16,    0,   31,  8,  8,  0 }, {     16,    0,   30,  8,  8,  0 }, {     16,    1,   29,  8,  8,  0 }, {     16,    1,   28,  8,  8,  0 }, {     16,    2,   27,  8,  8,  0 },
    {     16,    3,   26,  8,  8,  0 }, {     16,    3,   25,  8,  8,  0 }, {     16,    4,   24,  8,  8,  0 }, {     16,    5,   23,  8,  8,  0 }, {     16,    5,   22,  8,  8,  0 },
    {     16,    6,   21,  8,  7,  0 }, {     16,    7,   20,  8,  7,  0 }, {     16,    8,   19,  8,  7,  0 }, {     16,    8,   18,  8,  7,  0 }, {     16,    9,   17,  8,  7,  0 },
    {     16,   10,   16,  8,  7,  0 }, {     16,   11,   15,  8,  7,  0 }, {     16,   12,   14,  8,  7,  0 }, {     16,   13,   13,  8,  7,  0 }, {     16,   15,   12,  8,  7,  0 },
    {     16,   16,   11,  8,  7,  0 }, {     16,   17,   10,  8,  7,  0 }, {     16,   18,    9,  8,  7,  0 }, {     16,   19,    8,  8,  7,  0 }, {     16,   20,    8,  8,  7,  0 },
    {     16,   21,    7,  8,  7,  0 }, {     16,   22,    6,  8,  7,  0 }, {     16,   23,    5,  8,  6,  0 }, {     16,   24,    5,  8,  6,  0 }, {     16,   25,    4,  8,  6,  0 },
    {     16,   26,    3,  8,  6,  0 }, {     16,   27,    3,  8,  6,  0 }, {     16,   28,    2,  8,  6,  0 }, {     16,   29,    1,  8,  6,  0 }, {     16,   30,    1,  8,  6,  0 },
    {     16,   31,    0,  8,  6,  0 }, {     16,   32,    0,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C1B50, {
    {      0,   16,   31, 16,  8,  0 }, {      0,   16,   30, 16,  8,  0 }, {      1,   16,   29, 16,  8,  0 }, {      1,   16,   28, 16,  8,  0 }, {      2,   16,   27, 16,  8,  0 },
    {      3,   16,   26, 16,  8,  0 }, {      3,   16,   25, 16,  8,  0 }, {      4,   16,   24, 16,  8,  0 }, {      5,   16,   23, 16,  8,  0 }, {      5,   16,   22, 16,  8,  0 },
    {      6,   16,   21, 16,  7,  0 }, {      7,   16,   20, 16,  7,  0 }, {      8,   16,   19, 16,  7,  0 }, {      8,   16,   18, 16,  7,  0 }, {      9,   16,   17, 16,  7,  0 },
    {     10,   16,   16, 16,  7,  0 }, {     11,   16,   15, 16,  7,  0 }, {     12,   16,   14, 16,  7,  0 }, {     13,   16,   13, 16,  7,  0 }, {     15,   16,   12, 16,  7,  0 },
    {     16,   16,   11, 16,  7,  0 }, {     17,   16,   10, 16,  7,  0 }, {     18,   16,    9, 16,  7,  0 }, {     19,   16,    8, 16,  7,  0 }, {     20,   16,    8, 16,  7,  0 },
    {     21,   16,    7, 16,  7,  0 }, {     22,   16,    6, 16,  7,  0 }, {     23,   16,    5, 16,  6,  0 }, {     24,   16,    5, 16,  6,  0 }, {     25,   16,    4, 16,  6,  0 },
    {     26,   16,    3, 16,  6,  0 }, {     27,   16,    3, 16,  6,  0 }, {     28,   16,    2, 16,  6,  0 }, {     29,   16,    1, 16,  6,  0 }, {     30,   16,    1, 16,  6,  0 },
    {     31,   16,    0, 16,  6,  0 }, {     32,   16,    0, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C1C9F, {
    {     16,   31,   31, 24,  8,  0 }, {     16,   31,   30, 24,  8,  0 }, {     16,   30,   29, 24,  8,  0 }, {     16,   30,   28, 24,  8,  0 }, {     16,   29,   27, 24,  8,  0 },
    {     16,   28,   26, 24,  8,  0 }, {     16,   28,   25, 24,  8,  0 }, {     16,   27,   24, 24,  8,  0 }, {     16,   26,   23, 24,  8,  0 }, {     16,   26,   22, 24,  8,  0 },
    {     16,   25,   21, 24,  7,  0 }, {     16,   24,   20, 24,  7,  0 }, {     16,   23,   19, 24,  7,  0 }, {     16,   23,   18, 24,  7,  0 }, {     16,   22,   17, 24,  7,  0 },
    {     16,   21,   16, 24,  7,  0 }, {     16,   20,   15, 24,  7,  0 }, {     16,   19,   14, 24,  7,  0 }, {     16,   18,   13, 24,  7,  0 }, {     16,   16,   12, 24,  7,  0 },
    {     16,   15,   11, 24,  7,  0 }, {     16,   14,   10, 24,  7,  0 }, {     16,   13,    9, 24,  7,  0 }, {     16,   12,    8, 24,  7,  0 }, {     16,   11,    8, 24,  7,  0 },
    {     16,   10,    7, 24,  7,  0 }, {     16,    9,    6, 24,  7,  0 }, {     16,    8,    5, 24,  6,  0 }, {     16,    7,    5, 24,  6,  0 }, {     16,    6,    4, 24,  6,  0 },
    {     16,    5,    3, 24,  6,  0 }, {     16,    4,    3, 24,  6,  0 }, {     16,    3,    2, 24,  6,  0 }, {     16,    2,    1, 24,  6,  0 }, {     16,    1,    1, 24,  6,  0 },
    {     16,    0,    0, 24,  6,  0 }, {     16,   -1,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C052A, {
    {     31,   16,    7,  0,  6,  0 }, {     30,   16,    7,  0,  6,  0 }, {     29,   16,    6,  0,  6,  0 }, {     28,   16,    6,  0,  6,  0 }, {     27,   16,    5,  0,  6,  0 },
    {     26,   16,    5,  0,  6,  0 }, {     25,   16,    4,  0,  6,  0 }, {     24,   16,    4,  0,  6,  0 }, {     23,   16,    4,  0,  5,  0 }, {     22,   16,    3,  0,  5,  0 },
    {     21,   16,    3,  0,  5,  0 }, {     20,   16,    3,  0,  5,  0 }, {     19,   16,    2,  0,  5,  0 }, {     18,   16,    2,  0,  5,  0 }, {     17,   16,    2,  0,  5,  0 },
    {     16,   16,    2,  0,  5,  0 }, {     15,   16,    1,  0,  5,  0 }, {     14,   16,    1,  0,  5,  0 }, {     13,   16,    1,  0,  5,  0 }, {     12,   16,    1,  0,  5,  0 },
    {     11,   16,    1,  0,  5,  0 }, {     10,   16,    1,  0,  5,  0 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 },
    {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C064C, {
    {     16,    0,    8,  8,  6,  0 }, {     16,    1,    7,  8,  6,  0 }, {     16,    2,    7,  8,  6,  0 }, {     16,    3,    6,  8,  6,  0 }, {     16,    4,    6,  8,  6,  0 },
    {     16,    5,    5,  8,  6,  0 }, {     16,    6,    5,  8,  6,  0 }, {     16,    7,    4,  8,  6,  0 }, {     16,    8,    4,  8,  5,  0 }, {     16,    9,    3,  8,  5,  0 },
    {     16,   10,    3,  8,  5,  0 }, {     16,   11,    3,  8,  5,  0 }, {     16,   12,    2,  8,  5,  0 }, {     16,   13,    2,  8,  5,  0 }, {     16,   14,    2,  8,  5,  0 },
    {     16,   15,    2,  8,  5,  0 }, {     16,   16,    1,  8,  5,  0 }, {     16,   17,    1,  8,  5,  0 }, {     16,   18,    1,  8,  5,  0 }, {     16,   19,    1,  8,  5,  0 },
    {     16,   20,    1,  8,  5,  0 }, {     16,   21,    1,  8,  5,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   29,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C076E, {
    {      0,   16,    8, 16,  6,  0 }, {      1,   16,    7, 16,  6,  0 }, {      2,   16,    7, 16,  6,  0 }, {      3,   16,    6, 16,  6,  0 }, {      4,   16,    6, 16,  6,  0 },
    {      5,   16,    5, 16,  6,  0 }, {      6,   16,    5, 16,  6,  0 }, {      7,   16,    4, 16,  6,  0 }, {      8,   16,    4, 16,  5,  0 }, {      9,   16,    3, 16,  5,  0 },
    {     10,   16,    3, 16,  5,  0 }, {     11,   16,    3, 16,  5,  0 }, {     12,   16,    2, 16,  5,  0 }, {     13,   16,    2, 16,  5,  0 }, {     14,   16,    2, 16,  5,  0 },
    {     15,   16,    2, 16,  5,  0 }, {     16,   16,    1, 16,  5,  0 }, {     17,   16,    1, 16,  5,  0 }, {     18,   16,    1, 16,  5,  0 }, {     19,   16,    1, 16,  5,  0 },
    {     20,   16,    1, 16,  5,  0 }, {     21,   16,    1, 16,  5,  0 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 },
    {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 }, {     29,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C0890, {
    {     16,   31,    7, 24,  6,  0 }, {     16,   30,    7, 24,  6,  0 }, {     16,   29,    6, 24,  6,  0 }, {     16,   28,    6, 24,  6,  0 }, {     16,   27,    5, 24,  6,  0 },
    {     16,   26,    5, 24,  6,  0 }, {     16,   25,    4, 24,  6,  0 }, {     16,   24,    4, 24,  6,  0 }, {     16,   23,    4, 24,  5,  0 }, {     16,   22,    3, 24,  5,  0 },
    {     16,   21,    3, 24,  5,  0 }, {     16,   20,    3, 24,  5,  0 }, {     16,   19,    2, 24,  5,  0 }, {     16,   18,    2, 24,  5,  0 }, {     16,   17,    2, 24,  5,  0 },
    {     16,   16,    2, 24,  5,  0 }, {     16,   15,    1, 24,  5,  0 }, {     16,   14,    1, 24,  5,  0 }, {     16,   13,    1, 24,  5,  0 }, {     16,   12,    1, 24,  5,  0 },
    {     16,   11,    1, 24,  5,  0 }, {     16,   10,    1, 24,  5,  0 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 }, {     16,    7,    0, 24,  0,  0 },
    {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C8092, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0, 31,  0,  0 }, {     23,   15,    0, 31,  0,  0 }, {     22,   15,    0, 31,  0,  0 },
    {     21,   15,    0, 31,  0,  0 }, {     20,   15,    0, 31,  0,  0 }, {     19,   15,    0, 31,  0,  0 }, {     18,   15,    0, 31,  0,  0 }, {     17,   14,    0, 31,  0,  0 },
    {     16,   14,    0, 31,  0,  0 }, {     15,   14,    0, 31,  0,  0 }, {     14,   14,    0, 31,  0,  0 }, {     13,   14,    0, 31,  0,  0 }, {     12,   13,    0, 31,  0,  0 },
    {     11,   13,    0, 31,  0,  0 }, {     10,   13,    0, 30,  0,  0 }, {      9,   13,    0, 30,  0,  0 }, {      8,   12,    0, 30,  0,  0 }, {      7,   12,    0, 30,  0,  0 },
    {      6,   12,    0, 30,  0,  0 }, {      5,   11,    0, 30,  0,  0 }, {      4,   11,    0, 30,  0,  0 }, {      3,   11,    0, 30,  0,  0 }, {      2,   10,    0, 30,  0,  0 },
    {      1,   10,    0, 30,  0,  0 }, {      0,    9,    0, 30,  0,  0 }, {     -1,    9,    0, 30,  0,  0 }, {     -2,    8,    0, 30,  0,  0 }, {     -3,    8,    0, 30,  0,  0 },
    {     -4,    7,    0, 30,  0,  0 }, {     -5,    7,    0, 29,  0,  0 }, {     -6,    6,    0, 29,  0,  0 }, {     -7,    6,    0, 29,  0,  0 }, {     -8,    5,    0, 29,  0,  0 },
    {     -9,    4,    0, 29,  0,  0 }, {    -10,    4,    0, 29,  0,  0 }, {    -11,    3,    0, 29,  0,  0 }, {    -12,    2,    0, 29,  0,  0 }, {    -13,    2,    0, 29,  0,  0 },
    {    -14,    1,    0, 29,  0,  0 }, {    -15,    0,    0, 29,  0,  0 }, {    -16,    0,    0, 29,  0,  0 }, {    -17,   -1,    0, 29,  0,  0 }, {    -18,   -2,    0, 28,  0,  0 },
    {    -19,   -3,    0, 28,  0,  0 }, {    -20,   -3,    0, 28,  0,  0 }, {    -21,   -4,    0, 28,  0,  0 }, {    -22,   -5,    0, 28,  0,  0 }, {    -23,   -6,    0, 28,  0,  0 },
    {    -24,   -7,    0, 28,  0,  0 }, {    -25,   -7,    0, 28,  0,  0 }, {    -26,   -8,    0, 28,  0,  0 }, {    -27,   -9,    0, 28,  0,  0 }, {    -28,  -10,    0, 28,  0,  0 },
    {    -29,  -11,    0, 28,  0,  0 }, {    -29,  -12,    0, 28,  0,  0 }, {    -30,  -13,    0, 27,  0,  0 }, {    -31,  -14,    0, 27,  0,  0 }, {    -32,  -15,    0, 27,  0,  0 },
    {    -32,  -16,    0, 27,  0,  0 }, {    -33,  -17,    0, 27,  0,  0 }, {    -34,  -18,    0, 27,  0,  0 }, {    -34,  -19,    0, 27,  0,  0 }, {    -35,  -20,    0, 27,  0,  0 },
    {    -36,  -21,    0, 27,  0,  0 }, {    -36,  -22,    0, 27,  0,  0 }, {    -37,  -23,    0, 27,  0,  0 }, {    -38,  -24,    0, 27,  0,  0 }, {    -38,  -25,    0, 27,  0,  0 },
    {    -39,  -26,    0, 26,  0,  0 }, {    -39,  -27,    0, 26,  0,  0 }, {    -40,  -28,    0, 26,  0,  0 }, {    -40,  -29,    0, 26,  0,  0 }, {    -41,  -30,    0, 26,  0,  0 },
    {    -41,  -31,    0, 26,  0,  0 }, {    -42,  -32,    0, 26,  0,  0 }, {    -42,  -33,    0, 26,  0,  0 }, {    -43,  -34,    0, 26,  0,  0 }, {    -43,  -35,    0, 26,  0,  0 },
    {    -43,  -36,    0, 26,  0,  0 }, {    -44,  -37,    0, 26,  0,  0 }, {    -44,  -38,    0, 26,  0,  0 }, {    -44,  -39,    0, 26,  0,  0 }, {    -45,  -40,    0, 25,  0,  0 },
    {    -45,  -41,    0, 25,  0,  0 }, {    -45,  -42,    0, 25,  0,  0 }, {    -45,  -43,    0, 25,  0,  0 }, {    -46,  -44,    0, 25,  0,  0 }, {    -46,  -45,    0, 25,  0,  0 },
    {    -46,  -46,    0, 25,  0,  0 }, {    -46,  -47,    0, 25,  0,  0 }, {    -46,  -48,    0, 25,  0,  0 }, {    -47,  -49,    0, 25,  0,  0 }, {    -47,  -50,    0, 25,  0,  0 },
    {    -47,  -51,    0, 25,  0,  0 }, {    -47,  -52,    0, 25,  0,  0 }, {    -47,  -53,    0, 25,  0,  0 }, {    -47,  -54,    0, 25,  0,  0 }, {    -48,  -55,    0, 25,  0,  0 },
    {    -48,  -56,    0, 24,  0,  0 }, {    -48,  -57,    0, 24,  0,  0 }, {    -48,  -58,    0, 24,  0,  0 }, {    -48,  -59,    0, 24,  0,  0 }, {    -48,  -60,    0, 24,  0,  0 },
    {    -48,  -61,    0, 24,  0,  0 }, {    -48,  -62,    0, 24,  0,  0 }, {    -48,  -63,    0, 24,  0,  0 }, {    -48,  -64,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C8496, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  7,  0,  0 }, {     15,    9,    0,  7,  0,  0 },
    {     15,   10,    0,  7,  0,  0 }, {     15,   11,    0,  7,  0,  0 }, {     15,   12,    0,  7,  0,  0 }, {     15,   13,    0,  7,  0,  0 }, {     15,   14,    0,  7,  0,  0 },
    {     14,   15,    0,  7,  0,  0 }, {     14,   16,    0,  7,  0,  0 }, {     14,   17,    0,  7,  0,  0 }, {     14,   18,    0,  7,  0,  0 }, {     14,   19,    0,  7,  0,  0 },
    {     13,   20,    0,  7,  0,  0 }, {     13,   21,    0,  7,  0,  0 }, {     13,   22,    0,  6,  0,  0 }, {     13,   23,    0,  6,  0,  0 }, {     12,   24,    0,  6,  0,  0 },
    {     12,   25,    0,  6,  0,  0 }, {     12,   26,    0,  6,  0,  0 }, {     11,   27,    0,  6,  0,  0 }, {     11,   28,    0,  6,  0,  0 }, {     11,   29,    0,  6,  0,  0 },
    {     10,   30,    0,  6,  0,  0 }, {     10,   31,    0,  6,  0,  0 }, {      9,   32,    0,  6,  0,  0 }, {      9,   33,    0,  6,  0,  0 }, {      8,   34,    0,  6,  0,  0 },
    {      8,   35,    0,  6,  0,  0 }, {      7,   36,    0,  6,  0,  0 }, {      7,   37,    0,  5,  0,  0 }, {      6,   38,    0,  5,  0,  0 }, {      6,   39,    0,  5,  0,  0 },
    {      5,   40,    0,  5,  0,  0 }, {      4,   41,    0,  5,  0,  0 }, {      4,   42,    0,  5,  0,  0 }, {      3,   43,    0,  5,  0,  0 }, {      2,   44,    0,  5,  0,  0 },
    {      2,   45,    0,  5,  0,  0 }, {      1,   46,    0,  5,  0,  0 }, {      0,   47,    0,  5,  0,  0 }, {      0,   48,    0,  5,  0,  0 }, {     -1,   49,    0,  5,  0,  0 },
    {     -2,   50,    0,  4,  0,  0 }, {     -3,   51,    0,  4,  0,  0 }, {     -3,   52,    0,  4,  0,  0 }, {     -4,   53,    0,  4,  0,  0 }, {     -5,   54,    0,  4,  0,  0 },
    {     -6,   55,    0,  4,  0,  0 }, {     -7,   56,    0,  4,  0,  0 }, {     -7,   57,    0,  4,  0,  0 }, {     -8,   58,    0,  4,  0,  0 }, {     -9,   59,    0,  4,  0,  0 },
    {    -10,   60,    0,  4,  0,  0 }, {    -11,   61,    0,  4,  0,  0 }, {    -12,   61,    0,  4,  0,  0 }, {    -13,   62,    0,  3,  0,  0 }, {    -14,   63,    0,  3,  0,  0 },
    {    -15,   64,    0,  3,  0,  0 }, {    -16,   64,    0,  3,  0,  0 }, {    -17,   65,    0,  3,  0,  0 }, {    -18,   66,    0,  3,  0,  0 }, {    -19,   66,    0,  3,  0,  0 },
    {    -20,   67,    0,  3,  0,  0 }, {    -21,   68,    0,  3,  0,  0 }, {    -22,   68,    0,  3,  0,  0 }, {    -23,   69,    0,  3,  0,  0 }, {    -24,   70,    0,  3,  0,  0 },
    {    -25,   70,    0,  3,  0,  0 }, {    -26,   71,    0,  2,  0,  0 }, {    -27,   71,    0,  2,  0,  0 }, {    -28,   72,    0,  2,  0,  0 }, {    -29,   72,    0,  2,  0,  0 },
    {    -30,   73,    0,  2,  0,  0 }, {    -31,   73,    0,  2,  0,  0 }, {    -32,   74,    0,  2,  0,  0 }, {    -33,   74,    0,  2,  0,  0 }, {    -34,   75,    0,  2,  0,  0 },
    {    -35,   75,    0,  2,  0,  0 }, {    -36,   75,    0,  2,  0,  0 }, {    -37,   76,    0,  2,  0,  0 }, {    -38,   76,    0,  2,  0,  0 }, {    -39,   76,    0,  2,  0,  0 },
    {    -40,   77,    0,  1,  0,  0 }, {    -41,   77,    0,  1,  0,  0 }, {    -42,   77,    0,  1,  0,  0 }, {    -43,   77,    0,  1,  0,  0 }, {    -44,   78,    0,  1,  0,  0 },
    {    -45,   78,    0,  1,  0,  0 }, {    -46,   78,    0,  1,  0,  0 }, {    -47,   78,    0,  1,  0,  0 }, {    -48,   78,    0,  1,  0,  0 }, {    -49,   79,    0,  1,  0,  0 },
    {    -50,   79,    0,  1,  0,  0 }, {    -51,   79,    0,  1,  0,  0 }, {    -52,   79,    0,  1,  0,  0 }, {    -53,   79,    0,  1,  0,  0 }, {    -54,   79,    0,  1,  0,  0 },
    {    -55,   80,    0,  1,  0,  0 }, {    -56,   80,    0,  0,  0,  0 }, {    -57,   80,    0,  0,  0,  0 }, {    -58,   80,    0,  0,  0,  0 }, {    -59,   80,    0,  0,  0,  0 },
    {    -60,   80,    0,  0,  0,  0 }, {    -61,   80,    0,  0,  0,  0 }, {    -62,   80,    0,  0,  0,  0 }, {    -63,   80,    0,  0,  0,  0 }, {    -64,   80,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C88A3, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 15,  0,  0 }, {      9,   17,    0, 15,  0,  0 },
    {     10,   17,    0, 15,  0,  0 }, {     11,   17,    0, 15,  0,  0 }, {     12,   17,    0, 15,  0,  0 }, {     13,   17,    0, 15,  0,  0 }, {     14,   17,    0, 15,  0,  0 },
    {     15,   18,    0, 15,  0,  0 }, {     16,   18,    0, 15,  0,  0 }, {     17,   18,    0, 15,  0,  0 }, {     18,   18,    0, 15,  0,  0 }, {     19,   18,    0, 15,  0,  0 },
    {     20,   19,    0, 15,  0,  0 }, {     21,   19,    0, 15,  0,  0 }, {     22,   19,    0, 14,  0,  0 }, {     23,   19,    0, 14,  0,  0 }, {     24,   20,    0, 14,  0,  0 },
    {     25,   20,    0, 14,  0,  0 }, {     26,   20,    0, 14,  0,  0 }, {     27,   21,    0, 14,  0,  0 }, {     28,   21,    0, 14,  0,  0 }, {     29,   21,    0, 14,  0,  0 },
    {     30,   22,    0, 14,  0,  0 }, {     31,   22,    0, 14,  0,  0 }, {     32,   23,    0, 14,  0,  0 }, {     33,   23,    0, 14,  0,  0 }, {     34,   24,    0, 14,  0,  0 },
    {     35,   24,    0, 14,  0,  0 }, {     36,   25,    0, 14,  0,  0 }, {     37,   25,    0, 13,  0,  0 }, {     38,   26,    0, 13,  0,  0 }, {     39,   26,    0, 13,  0,  0 },
    {     40,   27,    0, 13,  0,  0 }, {     41,   28,    0, 13,  0,  0 }, {     42,   28,    0, 13,  0,  0 }, {     43,   29,    0, 13,  0,  0 }, {     44,   30,    0, 13,  0,  0 },
    {     45,   30,    0, 13,  0,  0 }, {     46,   31,    0, 13,  0,  0 }, {     47,   32,    0, 13,  0,  0 }, {     48,   32,    0, 13,  0,  0 }, {     49,   33,    0, 13,  0,  0 },
    {     50,   34,    0, 12,  0,  0 }, {     51,   35,    0, 12,  0,  0 }, {     52,   35,    0, 12,  0,  0 }, {     53,   36,    0, 12,  0,  0 }, {     54,   37,    0, 12,  0,  0 },
    {     55,   38,    0, 12,  0,  0 }, {     56,   39,    0, 12,  0,  0 }, {     57,   39,    0, 12,  0,  0 }, {     58,   40,    0, 12,  0,  0 }, {     59,   41,    0, 12,  0,  0 },
    {     60,   42,    0, 12,  0,  0 }, {     61,   43,    0, 12,  0,  0 }, {     61,   44,    0, 12,  0,  0 }, {     62,   45,    0, 11,  0,  0 }, {     63,   46,    0, 11,  0,  0 },
    {     64,   47,    0, 11,  0,  0 }, {     64,   48,    0, 11,  0,  0 }, {     65,   49,    0, 11,  0,  0 }, {     66,   50,    0, 11,  0,  0 }, {     66,   51,    0, 11,  0,  0 },
    {     67,   52,    0, 11,  0,  0 }, {     68,   53,    0, 11,  0,  0 }, {     68,   54,    0, 11,  0,  0 }, {     69,   55,    0, 11,  0,  0 }, {     70,   56,    0, 11,  0,  0 },
    {     70,   57,    0, 11,  0,  0 }, {     71,   58,    0, 10,  0,  0 }, {     71,   59,    0, 10,  0,  0 }, {     72,   60,    0, 10,  0,  0 }, {     72,   61,    0, 10,  0,  0 },
    {     73,   62,    0, 10,  0,  0 }, {     73,   63,    0, 10,  0,  0 }, {     74,   64,    0, 10,  0,  0 }, {     74,   65,    0, 10,  0,  0 }, {     75,   66,    0, 10,  0,  0 },
    {     75,   67,    0, 10,  0,  0 }, {     75,   68,    0, 10,  0,  0 }, {     76,   69,    0, 10,  0,  0 }, {     76,   70,    0, 10,  0,  0 }, {     76,   71,    0, 10,  0,  0 },
    {     77,   72,    0,  9,  0,  0 }, {     77,   73,    0,  9,  0,  0 }, {     77,   74,    0,  9,  0,  0 }, {     77,   75,    0,  9,  0,  0 }, {     78,   76,    0,  9,  0,  0 },
    {     78,   77,    0,  9,  0,  0 }, {     78,   78,    0,  9,  0,  0 }, {     78,   79,    0,  9,  0,  0 }, {     78,   80,    0,  9,  0,  0 }, {     79,   81,    0,  9,  0,  0 },
    {     79,   82,    0,  9,  0,  0 }, {     79,   83,    0,  9,  0,  0 }, {     79,   84,    0,  9,  0,  0 }, {     79,   85,    0,  9,  0,  0 }, {     79,   86,    0,  9,  0,  0 },
    {     80,   87,    0,  9,  0,  0 }, {     80,   88,    0,  8,  0,  0 }, {     80,   89,    0,  8,  0,  0 }, {     80,   90,    0,  8,  0,  0 }, {     80,   91,    0,  8,  0,  0 },
    {     80,   92,    0,  8,  0,  0 }, {     80,   93,    0,  8,  0,  0 }, {     80,   94,    0,  8,  0,  0 }, {     80,   95,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C8CA7, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 23,  0,  0 }, {     17,   23,    0, 23,  0,  0 }, {     17,   22,    0, 23,  0,  0 },
    {     17,   21,    0, 23,  0,  0 }, {     17,   20,    0, 23,  0,  0 }, {     17,   19,    0, 23,  0,  0 }, {     17,   18,    0, 23,  0,  0 }, {     18,   17,    0, 23,  0,  0 },
    {     18,   16,    0, 23,  0,  0 }, {     18,   15,    0, 23,  0,  0 }, {     18,   14,    0, 23,  0,  0 }, {     18,   13,    0, 23,  0,  0 }, {     19,   12,    0, 23,  0,  0 },
    {     19,   11,    0, 23,  0,  0 }, {     19,   10,    0, 22,  0,  0 }, {     19,    9,    0, 22,  0,  0 }, {     20,    8,    0, 22,  0,  0 }, {     20,    7,    0, 22,  0,  0 },
    {     20,    6,    0, 22,  0,  0 }, {     21,    5,    0, 22,  0,  0 }, {     21,    4,    0, 22,  0,  0 }, {     21,    3,    0, 22,  0,  0 }, {     22,    2,    0, 22,  0,  0 },
    {     22,    1,    0, 22,  0,  0 }, {     23,    0,    0, 22,  0,  0 }, {     23,   -1,    0, 22,  0,  0 }, {     24,   -2,    0, 22,  0,  0 }, {     24,   -3,    0, 22,  0,  0 },
    {     25,   -4,    0, 22,  0,  0 }, {     25,   -5,    0, 21,  0,  0 }, {     26,   -6,    0, 21,  0,  0 }, {     26,   -7,    0, 21,  0,  0 }, {     27,   -8,    0, 21,  0,  0 },
    {     28,   -9,    0, 21,  0,  0 }, {     28,  -10,    0, 21,  0,  0 }, {     29,  -11,    0, 21,  0,  0 }, {     30,  -12,    0, 21,  0,  0 }, {     30,  -13,    0, 21,  0,  0 },
    {     31,  -14,    0, 21,  0,  0 }, {     32,  -15,    0, 21,  0,  0 }, {     32,  -16,    0, 21,  0,  0 }, {     33,  -17,    0, 21,  0,  0 }, {     34,  -18,    0, 20,  0,  0 },
    {     35,  -19,    0, 20,  0,  0 }, {     35,  -20,    0, 20,  0,  0 }, {     36,  -21,    0, 20,  0,  0 }, {     37,  -22,    0, 20,  0,  0 }, {     38,  -23,    0, 20,  0,  0 },
    {     39,  -24,    0, 20,  0,  0 }, {     39,  -25,    0, 20,  0,  0 }, {     40,  -26,    0, 20,  0,  0 }, {     41,  -27,    0, 20,  0,  0 }, {     42,  -28,    0, 20,  0,  0 },
    {     43,  -29,    0, 20,  0,  0 }, {     44,  -29,    0, 20,  0,  0 }, {     45,  -30,    0, 19,  0,  0 }, {     46,  -31,    0, 19,  0,  0 }, {     47,  -32,    0, 19,  0,  0 },
    {     48,  -32,    0, 19,  0,  0 }, {     49,  -33,    0, 19,  0,  0 }, {     50,  -34,    0, 19,  0,  0 }, {     51,  -34,    0, 19,  0,  0 }, {     52,  -35,    0, 19,  0,  0 },
    {     53,  -36,    0, 19,  0,  0 }, {     54,  -36,    0, 19,  0,  0 }, {     55,  -37,    0, 19,  0,  0 }, {     56,  -38,    0, 19,  0,  0 }, {     57,  -38,    0, 19,  0,  0 },
    {     58,  -39,    0, 18,  0,  0 }, {     59,  -39,    0, 18,  0,  0 }, {     60,  -40,    0, 18,  0,  0 }, {     61,  -40,    0, 18,  0,  0 }, {     62,  -41,    0, 18,  0,  0 },
    {     63,  -41,    0, 18,  0,  0 }, {     64,  -42,    0, 18,  0,  0 }, {     65,  -42,    0, 18,  0,  0 }, {     66,  -43,    0, 18,  0,  0 }, {     67,  -43,    0, 18,  0,  0 },
    {     68,  -43,    0, 18,  0,  0 }, {     69,  -44,    0, 18,  0,  0 }, {     70,  -44,    0, 18,  0,  0 }, {     71,  -44,    0, 18,  0,  0 }, {     72,  -45,    0, 17,  0,  0 },
    {     73,  -45,    0, 17,  0,  0 }, {     74,  -45,    0, 17,  0,  0 }, {     75,  -45,    0, 17,  0,  0 }, {     76,  -46,    0, 17,  0,  0 }, {     77,  -46,    0, 17,  0,  0 },
    {     78,  -46,    0, 17,  0,  0 }, {     79,  -46,    0, 17,  0,  0 }, {     80,  -46,    0, 17,  0,  0 }, {     81,  -47,    0, 17,  0,  0 }, {     82,  -47,    0, 17,  0,  0 },
    {     83,  -47,    0, 17,  0,  0 }, {     84,  -47,    0, 17,  0,  0 }, {     85,  -47,    0, 17,  0,  0 }, {     86,  -47,    0, 17,  0,  0 }, {     87,  -48,    0, 17,  0,  0 },
    {     88,  -48,    0, 16,  0,  0 }, {     89,  -48,    0, 16,  0,  0 }, {     90,  -48,    0, 16,  0,  0 }, {     91,  -48,    0, 16,  0,  0 }, {     92,  -48,    0, 16,  0,  0 },
    {     93,  -48,    0, 16,  0,  0 }, {     94,  -48,    0, 16,  0,  0 }, {     95,  -48,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C90A2, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  1,  0,  0 }, {     23,   17,    0,  1,  0,  0 }, {     22,   17,    0,  1,  0,  0 },
    {     21,   17,    0,  1,  0,  0 }, {     20,   17,    0,  1,  0,  0 }, {     19,   17,    0,  1,  0,  0 }, {     18,   17,    0,  1,  0,  0 }, {     17,   18,    0,  1,  0,  0 },
    {     16,   18,    0,  1,  0,  0 }, {     15,   18,    0,  1,  0,  0 }, {     14,   18,    0,  1,  0,  0 }, {     13,   18,    0,  1,  0,  0 }, {     12,   19,    0,  1,  0,  0 },
    {     11,   19,    0,  1,  0,  0 }, {     10,   19,    0,  2,  0,  0 }, {      9,   19,    0,  2,  0,  0 }, {      8,   20,    0,  2,  0,  0 }, {      7,   20,    0,  2,  0,  0 },
    {      6,   20,    0,  2,  0,  0 }, {      5,   21,    0,  2,  0,  0 }, {      4,   21,    0,  2,  0,  0 }, {      3,   21,    0,  2,  0,  0 }, {      2,   22,    0,  2,  0,  0 },
    {      1,   22,    0,  2,  0,  0 }, {      0,   23,    0,  2,  0,  0 }, {     -1,   23,    0,  2,  0,  0 }, {     -2,   24,    0,  2,  0,  0 }, {     -3,   24,    0,  2,  0,  0 },
    {     -4,   25,    0,  2,  0,  0 }, {     -5,   25,    0,  3,  0,  0 }, {     -6,   26,    0,  3,  0,  0 }, {     -7,   26,    0,  3,  0,  0 }, {     -8,   27,    0,  3,  0,  0 },
    {     -9,   28,    0,  3,  0,  0 }, {    -10,   28,    0,  3,  0,  0 }, {    -11,   29,    0,  3,  0,  0 }, {    -12,   30,    0,  3,  0,  0 }, {    -13,   30,    0,  3,  0,  0 },
    {    -14,   31,    0,  3,  0,  0 }, {    -15,   32,    0,  3,  0,  0 }, {    -16,   32,    0,  3,  0,  0 }, {    -17,   33,    0,  3,  0,  0 }, {    -18,   34,    0,  4,  0,  0 },
    {    -19,   35,    0,  4,  0,  0 }, {    -20,   35,    0,  4,  0,  0 }, {    -21,   36,    0,  4,  0,  0 }, {    -22,   37,    0,  4,  0,  0 }, {    -23,   38,    0,  4,  0,  0 },
    {    -24,   39,    0,  4,  0,  0 }, {    -25,   39,    0,  4,  0,  0 }, {    -26,   40,    0,  4,  0,  0 }, {    -27,   41,    0,  4,  0,  0 }, {    -28,   42,    0,  4,  0,  0 },
    {    -29,   43,    0,  4,  0,  0 }, {    -29,   44,    0,  4,  0,  0 }, {    -30,   45,    0,  5,  0,  0 }, {    -31,   46,    0,  5,  0,  0 }, {    -32,   47,    0,  5,  0,  0 },
    {    -32,   48,    0,  5,  0,  0 }, {    -33,   49,    0,  5,  0,  0 }, {    -34,   50,    0,  5,  0,  0 }, {    -34,   51,    0,  5,  0,  0 }, {    -35,   52,    0,  5,  0,  0 },
    {    -36,   53,    0,  5,  0,  0 }, {    -36,   54,    0,  5,  0,  0 }, {    -37,   55,    0,  5,  0,  0 }, {    -38,   56,    0,  5,  0,  0 }, {    -38,   57,    0,  5,  0,  0 },
    {    -39,   58,    0,  6,  0,  0 }, {    -39,   59,    0,  6,  0,  0 }, {    -40,   60,    0,  6,  0,  0 }, {    -40,   61,    0,  6,  0,  0 }, {    -41,   62,    0,  6,  0,  0 },
    {    -41,   63,    0,  6,  0,  0 }, {    -42,   64,    0,  6,  0,  0 }, {    -42,   65,    0,  6,  0,  0 }, {    -43,   66,    0,  6,  0,  0 }, {    -43,   67,    0,  6,  0,  0 },
    {    -43,   68,    0,  6,  0,  0 }, {    -44,   69,    0,  6,  0,  0 }, {    -44,   70,    0,  6,  0,  0 }, {    -44,   71,    0,  6,  0,  0 }, {    -45,   72,    0,  7,  0,  0 },
    {    -45,   73,    0,  7,  0,  0 }, {    -45,   74,    0,  7,  0,  0 }, {    -45,   75,    0,  7,  0,  0 }, {    -46,   76,    0,  7,  0,  0 }, {    -46,   77,    0,  7,  0,  0 },
    {    -46,   78,    0,  7,  0,  0 }, {    -46,   79,    0,  7,  0,  0 }, {    -46,   80,    0,  7,  0,  0 }, {    -47,   81,    0,  7,  0,  0 }, {    -47,   82,    0,  7,  0,  0 },
    {    -47,   83,    0,  7,  0,  0 }, {    -47,   84,    0,  7,  0,  0 }, {    -47,   85,    0,  7,  0,  0 }, {    -47,   86,    0,  7,  0,  0 }, {    -48,   87,    0,  7,  0,  0 },
    {    -48,   88,    0,  8,  0,  0 }, {    -48,   89,    0,  8,  0,  0 }, {    -48,   90,    0,  8,  0,  0 }, {    -48,   91,    0,  8,  0,  0 }, {    -48,   92,    0,  8,  0,  0 },
    {    -48,   93,    0,  8,  0,  0 }, {    -48,   94,    0,  8,  0,  0 }, {    -48,   95,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C949D, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  9,  0,  0 }, {     17,    9,    0,  9,  0,  0 },
    {     17,   10,    0,  9,  0,  0 }, {     17,   11,    0,  9,  0,  0 }, {     17,   12,    0,  9,  0,  0 }, {     17,   13,    0,  9,  0,  0 }, {     17,   14,    0,  9,  0,  0 },
    {     18,   15,    0,  9,  0,  0 }, {     18,   16,    0,  9,  0,  0 }, {     18,   17,    0,  9,  0,  0 }, {     18,   18,    0,  9,  0,  0 }, {     18,   19,    0,  9,  0,  0 },
    {     19,   20,    0,  9,  0,  0 }, {     19,   21,    0,  9,  0,  0 }, {     19,   22,    0, 10,  0,  0 }, {     19,   23,    0, 10,  0,  0 }, {     20,   24,    0, 10,  0,  0 },
    {     20,   25,    0, 10,  0,  0 }, {     20,   26,    0, 10,  0,  0 }, {     21,   27,    0, 10,  0,  0 }, {     21,   28,    0, 10,  0,  0 }, {     21,   29,    0, 10,  0,  0 },
    {     22,   30,    0, 10,  0,  0 }, {     22,   31,    0, 10,  0,  0 }, {     23,   32,    0, 10,  0,  0 }, {     23,   33,    0, 10,  0,  0 }, {     24,   34,    0, 10,  0,  0 },
    {     24,   35,    0, 10,  0,  0 }, {     25,   36,    0, 10,  0,  0 }, {     25,   37,    0, 11,  0,  0 }, {     26,   38,    0, 11,  0,  0 }, {     26,   39,    0, 11,  0,  0 },
    {     27,   40,    0, 11,  0,  0 }, {     28,   41,    0, 11,  0,  0 }, {     28,   42,    0, 11,  0,  0 }, {     29,   43,    0, 11,  0,  0 }, {     30,   44,    0, 11,  0,  0 },
    {     30,   45,    0, 11,  0,  0 }, {     31,   46,    0, 11,  0,  0 }, {     32,   47,    0, 11,  0,  0 }, {     32,   48,    0, 11,  0,  0 }, {     33,   49,    0, 11,  0,  0 },
    {     34,   50,    0, 12,  0,  0 }, {     35,   51,    0, 12,  0,  0 }, {     35,   52,    0, 12,  0,  0 }, {     36,   53,    0, 12,  0,  0 }, {     37,   54,    0, 12,  0,  0 },
    {     38,   55,    0, 12,  0,  0 }, {     39,   56,    0, 12,  0,  0 }, {     39,   57,    0, 12,  0,  0 }, {     40,   58,    0, 12,  0,  0 }, {     41,   59,    0, 12,  0,  0 },
    {     42,   60,    0, 12,  0,  0 }, {     43,   61,    0, 12,  0,  0 }, {     44,   61,    0, 12,  0,  0 }, {     45,   62,    0, 13,  0,  0 }, {     46,   63,    0, 13,  0,  0 },
    {     47,   64,    0, 13,  0,  0 }, {     48,   64,    0, 13,  0,  0 }, {     49,   65,    0, 13,  0,  0 }, {     50,   66,    0, 13,  0,  0 }, {     51,   66,    0, 13,  0,  0 },
    {     52,   67,    0, 13,  0,  0 }, {     53,   68,    0, 13,  0,  0 }, {     54,   68,    0, 13,  0,  0 }, {     55,   69,    0, 13,  0,  0 }, {     56,   70,    0, 13,  0,  0 },
    {     57,   70,    0, 13,  0,  0 }, {     58,   71,    0, 14,  0,  0 }, {     59,   71,    0, 14,  0,  0 }, {     60,   72,    0, 14,  0,  0 }, {     61,   72,    0, 14,  0,  0 },
    {     62,   73,    0, 14,  0,  0 }, {     63,   73,    0, 14,  0,  0 }, {     64,   74,    0, 14,  0,  0 }, {     65,   74,    0, 14,  0,  0 }, {     66,   75,    0, 14,  0,  0 },
    {     67,   75,    0, 14,  0,  0 }, {     68,   75,    0, 14,  0,  0 }, {     69,   76,    0, 14,  0,  0 }, {     70,   76,    0, 14,  0,  0 }, {     71,   76,    0, 14,  0,  0 },
    {     72,   77,    0, 15,  0,  0 }, {     73,   77,    0, 15,  0,  0 }, {     74,   77,    0, 15,  0,  0 }, {     75,   77,    0, 15,  0,  0 }, {     76,   78,    0, 15,  0,  0 },
    {     77,   78,    0, 15,  0,  0 }, {     78,   78,    0, 15,  0,  0 }, {     79,   78,    0, 15,  0,  0 }, {     80,   78,    0, 15,  0,  0 }, {     81,   79,    0, 15,  0,  0 },
    {     82,   79,    0, 15,  0,  0 }, {     83,   79,    0, 15,  0,  0 }, {     84,   79,    0, 15,  0,  0 }, {     85,   79,    0, 15,  0,  0 }, {     86,   79,    0, 15,  0,  0 },
    {     87,   80,    0, 15,  0,  0 }, {     88,   80,    0, 16,  0,  0 }, {     89,   80,    0, 16,  0,  0 }, {     90,   80,    0, 16,  0,  0 }, {     91,   80,    0, 16,  0,  0 },
    {     92,   80,    0, 16,  0,  0 }, {     93,   80,    0, 16,  0,  0 }, {     94,   80,    0, 16,  0,  0 }, {     95,   80,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C98A1, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 17,  0,  0 }, {      9,   15,    0, 17,  0,  0 },
    {     10,   15,    0, 17,  0,  0 }, {     11,   15,    0, 17,  0,  0 }, {     12,   15,    0, 17,  0,  0 }, {     13,   15,    0, 17,  0,  0 }, {     14,   15,    0, 17,  0,  0 },
    {     15,   14,    0, 17,  0,  0 }, {     16,   14,    0, 17,  0,  0 }, {     17,   14,    0, 17,  0,  0 }, {     18,   14,    0, 17,  0,  0 }, {     19,   14,    0, 17,  0,  0 },
    {     20,   13,    0, 17,  0,  0 }, {     21,   13,    0, 17,  0,  0 }, {     22,   13,    0, 18,  0,  0 }, {     23,   13,    0, 18,  0,  0 }, {     24,   12,    0, 18,  0,  0 },
    {     25,   12,    0, 18,  0,  0 }, {     26,   12,    0, 18,  0,  0 }, {     27,   11,    0, 18,  0,  0 }, {     28,   11,    0, 18,  0,  0 }, {     29,   11,    0, 18,  0,  0 },
    {     30,   10,    0, 18,  0,  0 }, {     31,   10,    0, 18,  0,  0 }, {     32,    9,    0, 18,  0,  0 }, {     33,    9,    0, 18,  0,  0 }, {     34,    8,    0, 18,  0,  0 },
    {     35,    8,    0, 18,  0,  0 }, {     36,    7,    0, 18,  0,  0 }, {     37,    7,    0, 19,  0,  0 }, {     38,    6,    0, 19,  0,  0 }, {     39,    6,    0, 19,  0,  0 },
    {     40,    5,    0, 19,  0,  0 }, {     41,    4,    0, 19,  0,  0 }, {     42,    4,    0, 19,  0,  0 }, {     43,    3,    0, 19,  0,  0 }, {     44,    2,    0, 19,  0,  0 },
    {     45,    2,    0, 19,  0,  0 }, {     46,    1,    0, 19,  0,  0 }, {     47,    0,    0, 19,  0,  0 }, {     48,    0,    0, 19,  0,  0 }, {     49,   -1,    0, 19,  0,  0 },
    {     50,   -2,    0, 20,  0,  0 }, {     51,   -3,    0, 20,  0,  0 }, {     52,   -3,    0, 20,  0,  0 }, {     53,   -4,    0, 20,  0,  0 }, {     54,   -5,    0, 20,  0,  0 },
    {     55,   -6,    0, 20,  0,  0 }, {     56,   -7,    0, 20,  0,  0 }, {     57,   -7,    0, 20,  0,  0 }, {     58,   -8,    0, 20,  0,  0 }, {     59,   -9,    0, 20,  0,  0 },
    {     60,  -10,    0, 20,  0,  0 }, {     61,  -11,    0, 20,  0,  0 }, {     61,  -12,    0, 20,  0,  0 }, {     62,  -13,    0, 21,  0,  0 }, {     63,  -14,    0, 21,  0,  0 },
    {     64,  -15,    0, 21,  0,  0 }, {     64,  -16,    0, 21,  0,  0 }, {     65,  -17,    0, 21,  0,  0 }, {     66,  -18,    0, 21,  0,  0 }, {     66,  -19,    0, 21,  0,  0 },
    {     67,  -20,    0, 21,  0,  0 }, {     68,  -21,    0, 21,  0,  0 }, {     68,  -22,    0, 21,  0,  0 }, {     69,  -23,    0, 21,  0,  0 }, {     70,  -24,    0, 21,  0,  0 },
    {     70,  -25,    0, 21,  0,  0 }, {     71,  -26,    0, 22,  0,  0 }, {     71,  -27,    0, 22,  0,  0 }, {     72,  -28,    0, 22,  0,  0 }, {     72,  -29,    0, 22,  0,  0 },
    {     73,  -30,    0, 22,  0,  0 }, {     73,  -31,    0, 22,  0,  0 }, {     74,  -32,    0, 22,  0,  0 }, {     74,  -33,    0, 22,  0,  0 }, {     75,  -34,    0, 22,  0,  0 },
    {     75,  -35,    0, 22,  0,  0 }, {     75,  -36,    0, 22,  0,  0 }, {     76,  -37,    0, 22,  0,  0 }, {     76,  -38,    0, 22,  0,  0 }, {     76,  -39,    0, 22,  0,  0 },
    {     77,  -40,    0, 23,  0,  0 }, {     77,  -41,    0, 23,  0,  0 }, {     77,  -42,    0, 23,  0,  0 }, {     77,  -43,    0, 23,  0,  0 }, {     78,  -44,    0, 23,  0,  0 },
    {     78,  -45,    0, 23,  0,  0 }, {     78,  -46,    0, 23,  0,  0 }, {     78,  -47,    0, 23,  0,  0 }, {     78,  -48,    0, 23,  0,  0 }, {     79,  -49,    0, 23,  0,  0 },
    {     79,  -50,    0, 23,  0,  0 }, {     79,  -51,    0, 23,  0,  0 }, {     79,  -52,    0, 23,  0,  0 }, {     79,  -53,    0, 23,  0,  0 }, {     79,  -54,    0, 23,  0,  0 },
    {     80,  -55,    0, 23,  0,  0 }, {     80,  -56,    0, 24,  0,  0 }, {     80,  -57,    0, 24,  0,  0 }, {     80,  -58,    0, 24,  0,  0 }, {     80,  -59,    0, 24,  0,  0 },
    {     80,  -60,    0, 24,  0,  0 }, {     80,  -61,    0, 24,  0,  0 }, {     80,  -62,    0, 24,  0,  0 }, {     80,  -63,    0, 24,  0,  0 }, {     80,  -64,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C9CAE, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 25,  0,  0 }, {     15,   23,    0, 25,  0,  0 }, {     15,   22,    0, 25,  0,  0 },
    {     15,   21,    0, 25,  0,  0 }, {     15,   20,    0, 25,  0,  0 }, {     15,   19,    0, 25,  0,  0 }, {     15,   18,    0, 25,  0,  0 }, {     14,   17,    0, 25,  0,  0 },
    {     14,   16,    0, 25,  0,  0 }, {     14,   15,    0, 25,  0,  0 }, {     14,   14,    0, 25,  0,  0 }, {     14,   13,    0, 25,  0,  0 }, {     13,   12,    0, 25,  0,  0 },
    {     13,   11,    0, 25,  0,  0 }, {     13,   10,    0, 26,  0,  0 }, {     13,    9,    0, 26,  0,  0 }, {     12,    8,    0, 26,  0,  0 }, {     12,    7,    0, 26,  0,  0 },
    {     12,    6,    0, 26,  0,  0 }, {     11,    5,    0, 26,  0,  0 }, {     11,    4,    0, 26,  0,  0 }, {     11,    3,    0, 26,  0,  0 }, {     10,    2,    0, 26,  0,  0 },
    {     10,    1,    0, 26,  0,  0 }, {      9,    0,    0, 26,  0,  0 }, {      9,   -1,    0, 26,  0,  0 }, {      8,   -2,    0, 26,  0,  0 }, {      8,   -3,    0, 26,  0,  0 },
    {      7,   -4,    0, 26,  0,  0 }, {      7,   -5,    0, 27,  0,  0 }, {      6,   -6,    0, 27,  0,  0 }, {      6,   -7,    0, 27,  0,  0 }, {      5,   -8,    0, 27,  0,  0 },
    {      4,   -9,    0, 27,  0,  0 }, {      4,  -10,    0, 27,  0,  0 }, {      3,  -11,    0, 27,  0,  0 }, {      2,  -12,    0, 27,  0,  0 }, {      2,  -13,    0, 27,  0,  0 },
    {      1,  -14,    0, 27,  0,  0 }, {      0,  -15,    0, 27,  0,  0 }, {      0,  -16,    0, 27,  0,  0 }, {     -1,  -17,    0, 27,  0,  0 }, {     -2,  -18,    0, 28,  0,  0 },
    {     -3,  -19,    0, 28,  0,  0 }, {     -3,  -20,    0, 28,  0,  0 }, {     -4,  -21,    0, 28,  0,  0 }, {     -5,  -22,    0, 28,  0,  0 }, {     -6,  -23,    0, 28,  0,  0 },
    {     -7,  -24,    0, 28,  0,  0 }, {     -7,  -25,    0, 28,  0,  0 }, {     -8,  -26,    0, 28,  0,  0 }, {     -9,  -27,    0, 28,  0,  0 }, {    -10,  -28,    0, 28,  0,  0 },
    {    -11,  -29,    0, 28,  0,  0 }, {    -12,  -29,    0, 28,  0,  0 }, {    -13,  -30,    0, 29,  0,  0 }, {    -14,  -31,    0, 29,  0,  0 }, {    -15,  -32,    0, 29,  0,  0 },
    {    -16,  -32,    0, 29,  0,  0 }, {    -17,  -33,    0, 29,  0,  0 }, {    -18,  -34,    0, 29,  0,  0 }, {    -19,  -34,    0, 29,  0,  0 }, {    -20,  -35,    0, 29,  0,  0 },
    {    -21,  -36,    0, 29,  0,  0 }, {    -22,  -36,    0, 29,  0,  0 }, {    -23,  -37,    0, 29,  0,  0 }, {    -24,  -38,    0, 29,  0,  0 }, {    -25,  -38,    0, 29,  0,  0 },
    {    -26,  -39,    0, 30,  0,  0 }, {    -27,  -39,    0, 30,  0,  0 }, {    -28,  -40,    0, 30,  0,  0 }, {    -29,  -40,    0, 30,  0,  0 }, {    -30,  -41,    0, 30,  0,  0 },
    {    -31,  -41,    0, 30,  0,  0 }, {    -32,  -42,    0, 30,  0,  0 }, {    -33,  -42,    0, 30,  0,  0 }, {    -34,  -43,    0, 30,  0,  0 }, {    -35,  -43,    0, 30,  0,  0 },
    {    -36,  -43,    0, 30,  0,  0 }, {    -37,  -44,    0, 30,  0,  0 }, {    -38,  -44,    0, 30,  0,  0 }, {    -39,  -44,    0, 30,  0,  0 }, {    -40,  -45,    0, 31,  0,  0 },
    {    -41,  -45,    0, 31,  0,  0 }, {    -42,  -45,    0, 31,  0,  0 }, {    -43,  -45,    0, 31,  0,  0 }, {    -44,  -46,    0, 31,  0,  0 }, {    -45,  -46,    0, 31,  0,  0 },
    {    -46,  -46,    0, 31,  0,  0 }, {    -47,  -46,    0, 31,  0,  0 }, {    -48,  -46,    0, 31,  0,  0 }, {    -49,  -47,    0, 31,  0,  0 }, {    -50,  -47,    0, 31,  0,  0 },
    {    -51,  -47,    0, 31,  0,  0 }, {    -52,  -47,    0, 31,  0,  0 }, {    -53,  -47,    0, 31,  0,  0 }, {    -54,  -47,    0, 31,  0,  0 }, {    -55,  -48,    0, 31,  0,  0 },
    {    -56,  -48,    0,  0,  0,  0 }, {    -57,  -48,    0,  0,  0,  0 }, {    -58,  -48,    0,  0,  0,  0 }, {    -59,  -48,    0,  0,  0,  0 }, {    -60,  -48,    0,  0,  0,  0 },
    {    -61,  -48,    0,  0,  0,  0 }, {    -62,  -48,    0,  0,  0,  0 }, {    -63,  -48,    0,  0,  0,  0 }, {    -64,  -48,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C3542, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  1 }, {     22,   16,    0,  0,  0,  1 },
    {     21,   16,    0,  0,  0,  1 }, {     20,   16,    0,  0,  0,  1 }, {     19,   16,    0,  0,  0,  1 }, {     18,   16,    0,  0,  0,  1 }, {     17,   16,    0,  0,  0,  1 },
    {     16,   16,    0,  0,  0,  1 }, {     15,   16,    0,  0,  0,  1 }, {     14,   16,    0,  0,  0,  1 }, {     13,   16,    0,  0,  0,  1 }, {     12,   16,    0,  0,  0,  1 },
    {     11,   16,    0,  0,  0,  1 }, {     10,   16,    0,  0,  0,  1 }, {      9,   16,    0,  0,  0,  1 }, {      8,   16,    0,  0,  0,  1 }, {      7,   16,    0,  0,  0,  2 },
    {      6,   16,    0,  0,  0,  2 }, {      5,   16,    0,  0,  0,  2 }, {      4,   16,    0,  0,  0,  2 }, {      3,   16,    0,  0,  0,  2 }, {      2,   16,    0,  0,  0,  2 },
    {      1,   16,    0,  0,  0,  2 }, {      0,   16,    0,  0,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C3664, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  1 }, {     16,    9,    0,  8,  0,  1 },
    {     16,   10,    0,  8,  0,  1 }, {     16,   11,    0,  8,  0,  1 }, {     16,   12,    0,  8,  0,  1 }, {     16,   13,    0,  8,  0,  1 }, {     16,   14,    0,  8,  0,  1 },
    {     16,   15,    0,  8,  0,  1 }, {     16,   16,    0,  8,  0,  1 }, {     16,   17,    0,  8,  0,  1 }, {     16,   18,    0,  8,  0,  1 }, {     16,   19,    0,  8,  0,  1 },
    {     16,   20,    0,  8,  0,  1 }, {     16,   21,    0,  8,  0,  1 }, {     16,   22,    0,  8,  0,  1 }, {     16,   23,    0,  8,  0,  1 }, {     16,   24,    0,  8,  0,  2 },
    {     16,   25,    0,  8,  0,  2 }, {     16,   26,    0,  8,  0,  2 }, {     16,   27,    0,  8,  0,  2 }, {     16,   28,    0,  8,  0,  2 }, {     16,   29,    0,  8,  0,  2 },
    {     16,   30,    0,  8,  0,  2 }, {     16,   31,    0,  8,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C3786, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  1 }, {      9,   16,    0, 16,  0,  1 },
    {     10,   16,    0, 16,  0,  1 }, {     11,   16,    0, 16,  0,  1 }, {     12,   16,    0, 16,  0,  1 }, {     13,   16,    0, 16,  0,  1 }, {     14,   16,    0, 16,  0,  1 },
    {     15,   16,    0, 16,  0,  1 }, {     16,   16,    0, 16,  0,  1 }, {     17,   16,    0, 16,  0,  1 }, {     18,   16,    0, 16,  0,  1 }, {     19,   16,    0, 16,  0,  1 },
    {     20,   16,    0, 16,  0,  1 }, {     21,   16,    0, 16,  0,  1 }, {     22,   16,    0, 16,  0,  1 }, {     23,   16,    0, 16,  0,  1 }, {     24,   16,    0, 16,  0,  2 },
    {     25,   16,    0, 16,  0,  2 }, {     26,   16,    0, 16,  0,  2 }, {     27,   16,    0, 16,  0,  2 }, {     28,   16,    0, 16,  0,  2 }, {     29,   16,    0, 16,  0,  2 },
    {     30,   16,    0, 16,  0,  2 }, {     31,   16,    0, 16,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C38A8, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  1 }, {     16,   22,    0, 24,  0,  1 },
    {     16,   21,    0, 24,  0,  1 }, {     16,   20,    0, 24,  0,  1 }, {     16,   19,    0, 24,  0,  1 }, {     16,   18,    0, 24,  0,  1 }, {     16,   17,    0, 24,  0,  1 },
    {     16,   16,    0, 24,  0,  1 }, {     16,   15,    0, 24,  0,  1 }, {     16,   14,    0, 24,  0,  1 }, {     16,   13,    0, 24,  0,  1 }, {     16,   12,    0, 24,  0,  1 },
    {     16,   11,    0, 24,  0,  1 }, {     16,   10,    0, 24,  0,  1 }, {     16,    9,    0, 24,  0,  1 }, {     16,    8,    0, 24,  0,  1 }, {     16,    7,    0, 24,  0,  2 },
    {     16,    6,    0, 24,  0,  2 }, {     16,    5,    0, 24,  0,  2 }, {     16,    4,    0, 24,  0,  2 }, {     16,    3,    0, 24,  0,  2 }, {     16,    2,    0, 24,  0,  2 },
    {     16,    1,    0, 24,  0,  2 }, {     16,    0,    0, 24,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C39CA, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  3 }, {     22,   16,    0,  0,  0,  3 },
    {     21,   16,    0,  0,  0,  3 }, {     20,   16,    0,  0,  0,  3 }, {     19,   16,    0,  0,  0,  3 }, {     18,   16,    0,  0,  0,  3 }, {     17,   16,    0,  0,  0,  3 },
    {     16,   16,    0,  0,  0,  3 }, {     15,   16,    0,  0,  0,  3 }, {     14,   16,    0,  0,  0,  3 }, {     13,   16,    0,  0,  0,  3 }, {     12,   16,    0,  0,  0,  3 },
    {     11,   16,    0,  0,  0,  3 }, {     10,   16,    0,  0,  0,  3 }, {      9,   16,    0,  0,  0,  3 }, {      8,   16,    0,  0,  0,  3 }, {      7,   16,    0,  0,  0,  4 },
    {      6,   16,    0,  0,  0,  4 }, {      5,   16,    0,  0,  0,  4 }, {      4,   16,    0,  0,  0,  4 }, {      3,   16,    0,  0,  0,  4 }, {      2,   16,    0,  0,  0,  4 },
    {      1,   16,    0,  0,  0,  4 }, {      0,   16,    0,  0,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C3AEC, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  3 }, {     16,    9,    0,  8,  0,  3 },
    {     16,   10,    0,  8,  0,  3 }, {     16,   11,    0,  8,  0,  3 }, {     16,   12,    0,  8,  0,  3 }, {     16,   13,    0,  8,  0,  3 }, {     16,   14,    0,  8,  0,  3 },
    {     16,   15,    0,  8,  0,  3 }, {     16,   16,    0,  8,  0,  3 }, {     16,   17,    0,  8,  0,  3 }, {     16,   18,    0,  8,  0,  3 }, {     16,   19,    0,  8,  0,  3 },
    {     16,   20,    0,  8,  0,  3 }, {     16,   21,    0,  8,  0,  3 }, {     16,   22,    0,  8,  0,  3 }, {     16,   23,    0,  8,  0,  3 }, {     16,   24,    0,  8,  0,  4 },
    {     16,   25,    0,  8,  0,  4 }, {     16,   26,    0,  8,  0,  4 }, {     16,   27,    0,  8,  0,  4 }, {     16,   28,    0,  8,  0,  4 }, {     16,   29,    0,  8,  0,  4 },
    {     16,   30,    0,  8,  0,  4 }, {     16,   31,    0,  8,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C3C0E, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  3 }, {      9,   16,    0, 16,  0,  3 },
    {     10,   16,    0, 16,  0,  3 }, {     11,   16,    0, 16,  0,  3 }, {     12,   16,    0, 16,  0,  3 }, {     13,   16,    0, 16,  0,  3 }, {     14,   16,    0, 16,  0,  3 },
    {     15,   16,    0, 16,  0,  3 }, {     16,   16,    0, 16,  0,  3 }, {     17,   16,    0, 16,  0,  3 }, {     18,   16,    0, 16,  0,  3 }, {     19,   16,    0, 16,  0,  3 },
    {     20,   16,    0, 16,  0,  3 }, {     21,   16,    0, 16,  0,  3 }, {     22,   16,    0, 16,  0,  3 }, {     23,   16,    0, 16,  0,  3 }, {     24,   16,    0, 16,  0,  4 },
    {     25,   16,    0, 16,  0,  4 }, {     26,   16,    0, 16,  0,  4 }, {     27,   16,    0, 16,  0,  4 }, {     28,   16,    0, 16,  0,  4 }, {     29,   16,    0, 16,  0,  4 },
    {     30,   16,    0, 16,  0,  4 }, {     31,   16,    0, 16,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C3D30, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  3 }, {     16,   22,    0, 24,  0,  3 },
    {     16,   21,    0, 24,  0,  3 }, {     16,   20,    0, 24,  0,  3 }, {     16,   19,    0, 24,  0,  3 }, {     16,   18,    0, 24,  0,  3 }, {     16,   17,    0, 24,  0,  3 },
    {     16,   16,    0, 24,  0,  3 }, {     16,   15,    0, 24,  0,  3 }, {     16,   14,    0, 24,  0,  3 }, {     16,   13,    0, 24,  0,  3 }, {     16,   12,    0, 24,  0,  3 },
    {     16,   11,    0, 24,  0,  3 }, {     16,   10,    0, 24,  0,  3 }, {     16,    9,    0, 24,  0,  3 }, {     16,    8,    0, 24,  0,  3 }, {     16,    7,    0, 24,  0,  4 },
    {     16,    6,    0, 24,  0,  4 }, {     16,    5,    0, 24,  0,  4 }, {     16,    4,    0, 24,  0,  4 }, {     16,    3,    0, 24,  0,  4 }, {     16,    2,    0, 24,  0,  4 },
    {     16,    1,    0, 24,  0,  4 }, {     16,    0,    0, 24,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C3E52, {
    {     31,   16,    0,  0,  0,  2 }, {     30,   16,    0,  0,  0,  2 }, {     29,   16,    0,  0,  0,  2 }, {     28,   16,    0,  0,  0,  2 }, {     27,   16,    0,  0,  0,  2 },
    {     26,   16,    0,  0,  0,  2 }, {     25,   16,    0,  0,  0,  2 }, {     24,   16,    0,  0,  0,  2 }, {     23,   16,    0,  0,  0,  1 }, {     22,   16,    0,  0,  0,  1 },
    {     21,   16,    0,  0,  0,  1 }, {     20,   16,    0,  0,  0,  1 }, {     19,   16,    0,  0,  0,  1 }, {     18,   16,    0,  0,  0,  1 }, {     17,   16,    0,  0,  0,  1 },
    {     16,   16,    0,  0,  0,  1 }, {     15,   16,    0,  0,  0,  1 }, {     14,   16,    0,  0,  0,  1 }, {     13,   16,    0,  0,  0,  1 }, {     12,   16,    0,  0,  0,  1 },
    {     11,   16,    0,  0,  0,  1 }, {     10,   16,    0,  0,  0,  1 }, {      9,   16,    0,  0,  0,  1 }, {      8,   16,    0,  0,  0,  1 }, {      7,   16,    0,  0,  0,  0 },
    {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C3F74, {
    {     16,    0,    0,  8,  0,  2 }, {     16,    1,    0,  8,  0,  2 }, {     16,    2,    0,  8,  0,  2 }, {     16,    3,    0,  8,  0,  2 }, {     16,    4,    0,  8,  0,  2 },
    {     16,    5,    0,  8,  0,  2 }, {     16,    6,    0,  8,  0,  2 }, {     16,    7,    0,  8,  0,  2 }, {     16,    8,    0,  8,  0,  1 }, {     16,    9,    0,  8,  0,  1 },
    {     16,   10,    0,  8,  0,  1 }, {     16,   11,    0,  8,  0,  1 }, {     16,   12,    0,  8,  0,  1 }, {     16,   13,    0,  8,  0,  1 }, {     16,   14,    0,  8,  0,  1 },
    {     16,   15,    0,  8,  0,  1 }, {     16,   16,    0,  8,  0,  1 }, {     16,   17,    0,  8,  0,  1 }, {     16,   18,    0,  8,  0,  1 }, {     16,   19,    0,  8,  0,  1 },
    {     16,   20,    0,  8,  0,  1 }, {     16,   21,    0,  8,  0,  1 }, {     16,   22,    0,  8,  0,  1 }, {     16,   23,    0,  8,  0,  1 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   29,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C4096, {
    {      0,   16,    0, 16,  0,  2 }, {      1,   16,    0, 16,  0,  2 }, {      2,   16,    0, 16,  0,  2 }, {      3,   16,    0, 16,  0,  2 }, {      4,   16,    0, 16,  0,  2 },
    {      5,   16,    0, 16,  0,  2 }, {      6,   16,    0, 16,  0,  2 }, {      7,   16,    0, 16,  0,  2 }, {      8,   16,    0, 16,  0,  1 }, {      9,   16,    0, 16,  0,  1 },
    {     10,   16,    0, 16,  0,  1 }, {     11,   16,    0, 16,  0,  1 }, {     12,   16,    0, 16,  0,  1 }, {     13,   16,    0, 16,  0,  1 }, {     14,   16,    0, 16,  0,  1 },
    {     15,   16,    0, 16,  0,  1 }, {     16,   16,    0, 16,  0,  1 }, {     17,   16,    0, 16,  0,  1 }, {     18,   16,    0, 16,  0,  1 }, {     19,   16,    0, 16,  0,  1 },
    {     20,   16,    0, 16,  0,  1 }, {     21,   16,    0, 16,  0,  1 }, {     22,   16,    0, 16,  0,  1 }, {     23,   16,    0, 16,  0,  1 }, {     24,   16,    0, 16,  0,  0 },
    {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 }, {     29,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C41B8, {
    {     16,   31,    0, 24,  0,  2 }, {     16,   30,    0, 24,  0,  2 }, {     16,   29,    0, 24,  0,  2 }, {     16,   28,    0, 24,  0,  2 }, {     16,   27,    0, 24,  0,  2 },
    {     16,   26,    0, 24,  0,  2 }, {     16,   25,    0, 24,  0,  2 }, {     16,   24,    0, 24,  0,  2 }, {     16,   23,    0, 24,  0,  1 }, {     16,   22,    0, 24,  0,  1 },
    {     16,   21,    0, 24,  0,  1 }, {     16,   20,    0, 24,  0,  1 }, {     16,   19,    0, 24,  0,  1 }, {     16,   18,    0, 24,  0,  1 }, {     16,   17,    0, 24,  0,  1 },
    {     16,   16,    0, 24,  0,  1 }, {     16,   15,    0, 24,  0,  1 }, {     16,   14,    0, 24,  0,  1 }, {     16,   13,    0, 24,  0,  1 }, {     16,   12,    0, 24,  0,  1 },
    {     16,   11,    0, 24,  0,  1 }, {     16,   10,    0, 24,  0,  1 }, {     16,    9,    0, 24,  0,  1 }, {     16,    8,    0, 24,  0,  1 }, {     16,    7,    0, 24,  0,  0 },
    {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C42DA, {
    {     31,   16,    0,  0,  0,  4 }, {     30,   16,    0,  0,  0,  4 }, {     29,   16,    0,  0,  0,  4 }, {     28,   16,    0,  0,  0,  4 }, {     27,   16,    0,  0,  0,  4 },
    {     26,   16,    0,  0,  0,  4 }, {     25,   16,    0,  0,  0,  4 }, {     24,   16,    0,  0,  0,  4 }, {     23,   16,    0,  0,  0,  3 }, {     22,   16,    0,  0,  0,  3 },
    {     21,   16,    0,  0,  0,  3 }, {     20,   16,    0,  0,  0,  3 }, {     19,   16,    0,  0,  0,  3 }, {     18,   16,    0,  0,  0,  3 }, {     17,   16,    0,  0,  0,  3 },
    {     16,   16,    0,  0,  0,  3 }, {     15,   16,    0,  0,  0,  3 }, {     14,   16,    0,  0,  0,  3 }, {     13,   16,    0,  0,  0,  3 }, {     12,   16,    0,  0,  0,  3 },
    {     11,   16,    0,  0,  0,  3 }, {     10,   16,    0,  0,  0,  3 }, {      9,   16,    0,  0,  0,  3 }, {      8,   16,    0,  0,  0,  3 }, {      7,   16,    0,  0,  0,  0 },
    {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C43FC, {
    {     16,    0,    0,  8,  0,  4 }, {     16,    1,    0,  8,  0,  4 }, {     16,    2,    0,  8,  0,  4 }, {     16,    3,    0,  8,  0,  4 }, {     16,    4,    0,  8,  0,  4 },
    {     16,    5,    0,  8,  0,  4 }, {     16,    6,    0,  8,  0,  4 }, {     16,    7,    0,  8,  0,  4 }, {     16,    8,    0,  8,  0,  3 }, {     16,    9,    0,  8,  0,  3 },
    {     16,   10,    0,  8,  0,  3 }, {     16,   11,    0,  8,  0,  3 }, {     16,   12,    0,  8,  0,  3 }, {     16,   13,    0,  8,  0,  3 }, {     16,   14,    0,  8,  0,  3 },
    {     16,   15,    0,  8,  0,  3 }, {     16,   16,    0,  8,  0,  3 }, {     16,   17,    0,  8,  0,  3 }, {     16,   18,    0,  8,  0,  3 }, {     16,   19,    0,  8,  0,  3 },
    {     16,   20,    0,  8,  0,  3 }, {     16,   21,    0,  8,  0,  3 }, {     16,   22,    0,  8,  0,  3 }, {     16,   23,    0,  8,  0,  3 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   29,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C451E, {
    {      0,   16,    0, 16,  0,  4 }, {      1,   16,    0, 16,  0,  4 }, {      2,   16,    0, 16,  0,  4 }, {      3,   16,    0, 16,  0,  4 }, {      4,   16,    0, 16,  0,  4 },
    {      5,   16,    0, 16,  0,  4 }, {      6,   16,    0, 16,  0,  4 }, {      7,   16,    0, 16,  0,  4 }, {      8,   16,    0, 16,  0,  3 }, {      9,   16,    0, 16,  0,  3 },
    {     10,   16,    0, 16,  0,  3 }, {     11,   16,    0, 16,  0,  3 }, {     12,   16,    0, 16,  0,  3 }, {     13,   16,    0, 16,  0,  3 }, {     14,   16,    0, 16,  0,  3 },
    {     15,   16,    0, 16,  0,  3 }, {     16,   16,    0, 16,  0,  3 }, {     17,   16,    0, 16,  0,  3 }, {     18,   16,    0, 16,  0,  3 }, {     19,   16,    0, 16,  0,  3 },
    {     20,   16,    0, 16,  0,  3 }, {     21,   16,    0, 16,  0,  3 }, {     22,   16,    0, 16,  0,  3 }, {     23,   16,    0, 16,  0,  3 }, {     24,   16,    0, 16,  0,  0 },
    {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 }, {     29,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C4640, {
    {     16,   31,    0, 24,  0,  4 }, {     16,   30,    0, 24,  0,  4 }, {     16,   29,    0, 24,  0,  4 }, {     16,   28,    0, 24,  0,  4 }, {     16,   27,    0, 24,  0,  4 },
    {     16,   26,    0, 24,  0,  4 }, {     16,   25,    0, 24,  0,  4 }, {     16,   24,    0, 24,  0,  4 }, {     16,   23,    0, 24,  0,  3 }, {     16,   22,    0, 24,  0,  3 },
    {     16,   21,    0, 24,  0,  3 }, {     16,   20,    0, 24,  0,  3 }, {     16,   19,    0, 24,  0,  3 }, {     16,   18,    0, 24,  0,  3 }, {     16,   17,    0, 24,  0,  3 },
    {     16,   16,    0, 24,  0,  3 }, {     16,   15,    0, 24,  0,  3 }, {     16,   14,    0, 24,  0,  3 }, {     16,   13,    0, 24,  0,  3 }, {     16,   12,    0, 24,  0,  3 },
    {     16,   11,    0, 24,  0,  3 }, {     16,   10,    0, 24,  0,  3 }, {     16,    9,    0, 24,  0,  3 }, {     16,    8,    0, 24,  0,  3 }, {     16,    7,    0, 24,  0,  0 },
    {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CA0B2, {
    {     31,   16,    0,  0,  0,  2 }, {     30,   16,    0,  0,  0,  2 }, {     29,   16,    0,  0,  0,  2 }, {     28,   16,    0,  0,  0,  2 }, {     27,   16,    0,  0,  0,  2 },
    {     26,   16,    0,  0,  0,  2 }, {     25,   16,    0,  0,  0,  2 }, {     24,   16,    0, 31,  0,  2 }, {     23,   15,    0, 31,  0,  2 }, {     22,   15,    0, 31,  0,  2 },
    {     21,   15,    0, 31,  0,  2 }, {     20,   15,    0, 31,  0,  2 }, {     19,   15,    0, 31,  0,  2 }, {     18,   15,    0, 31,  0,  2 }, {     17,   14,    0, 31,  0,  2 },
    {     16,   14,    0, 31,  0,  2 }, {     15,   14,    0, 31,  0,  2 }, {     14,   14,    0, 31,  0,  2 }, {     13,   14,    0, 31,  0,  2 }, {     12,   13,    0, 31,  0,  2 },
    {     11,   13,    0, 31,  0,  2 }, {     10,   13,    0, 30,  0,  2 }, {      9,   13,    0, 30,  0,  2 }, {      8,   12,    0, 30,  0,  2 }, {      7,   12,    0, 30,  0,  2 },
    {      6,   12,    0, 30,  0,  2 }, {      5,   11,    0, 30,  0,  2 }, {      4,   11,    0, 30,  0,  2 }, {      3,   11,    0, 30,  0,  2 }, {      2,   10,    0, 30,  0,  2 },
    {      1,   10,    0, 30,  0,  2 }, {      0,    9,    0, 30,  0,  2 }, {     -1,    9,    0, 30,  0,  2 }, {     -2,    8,    0, 30,  0,  2 }, {     -3,    8,    0, 30,  0,  2 },
    {     -4,    7,    0, 30,  0,  2 }, {     -5,    7,    0, 29,  0,  2 }, {     -6,    6,    0, 29,  0,  2 }, {     -7,    6,    0, 29,  0,  2 }, {     -8,    5,    0, 29,  0,  2 },
    {     -9,    4,    0, 29,  0,  2 }, {    -10,    4,    0, 29,  0,  2 }, {    -11,    3,    0, 29,  0,  2 }, {    -12,    2,    0, 29,  0,  2 }, {    -13,    2,    0, 29,  0,  2 },
    {    -14,    1,    0, 29,  0,  2 }, {    -15,    0,    0, 29,  0,  2 }, {    -16,    0,    0, 29,  0,  2 }, {    -17,   -1,    0, 29,  0,  2 }, {    -18,   -2,    0, 28,  0,  2 },
    {    -19,   -3,    0, 28,  0,  2 }, {    -20,   -3,    0, 28,  0,  2 }, {    -21,   -4,    0, 28,  0,  2 }, {    -22,   -5,    0, 28,  0,  2 }, {    -23,   -6,    0, 28,  0,  2 },
    {    -24,   -7,    0, 28,  0,  2 }, {    -25,   -7,    0, 28,  0,  2 }, {    -26,   -8,    0, 28,  0,  2 }, {    -27,   -9,    0, 28,  0,  2 }, {    -28,  -10,    0, 28,  0,  2 },
    {    -29,  -11,    0, 28,  0,  2 }, {    -29,  -12,    0, 28,  0,  2 }, {    -30,  -13,    0, 27,  0,  2 }, {    -31,  -14,    0, 27,  0,  2 }, {    -32,  -15,    0, 27,  0,  2 },
    {    -32,  -16,    0, 27,  0,  2 }, {    -33,  -17,    0, 27,  0,  2 }, {    -34,  -18,    0, 27,  0,  2 }, {    -34,  -19,    0, 27,  0,  2 }, {    -35,  -20,    0, 27,  0,  2 },
    {    -36,  -21,    0, 27,  0,  2 }, {    -36,  -22,    0, 27,  0,  2 }, {    -37,  -23,    0, 27,  0,  2 }, {    -38,  -24,    0, 27,  0,  2 }, {    -38,  -25,    0, 27,  0,  2 },
    {    -39,  -26,    0, 26,  0,  2 }, {    -39,  -27,    0, 26,  0,  2 }, {    -40,  -28,    0, 26,  0,  2 }, {    -40,  -29,    0, 26,  0,  2 }, {    -41,  -30,    0, 26,  0,  2 },
    {    -41,  -31,    0, 26,  0,  2 }, {    -42,  -32,    0, 26,  0,  2 }, {    -42,  -33,    0, 26,  0,  2 }, {    -43,  -34,    0, 26,  0,  2 }, {    -43,  -35,    0, 26,  0,  2 },
    {    -43,  -36,    0, 26,  0,  2 }, {    -44,  -37,    0, 26,  0,  2 }, {    -44,  -38,    0, 26,  0,  2 }, {    -44,  -39,    0, 26,  0,  2 }, {    -45,  -40,    0, 25,  0,  2 },
    {    -45,  -41,    0, 25,  0,  2 }, {    -45,  -42,    0, 25,  0,  2 }, {    -45,  -43,    0, 25,  0,  2 }, {    -46,  -44,    0, 25,  0,  2 }, {    -46,  -45,    0, 25,  0,  2 },
    {    -46,  -46,    0, 25,  0,  2 }, {    -46,  -47,    0, 25,  0,  2 }, {    -46,  -48,    0, 25,  0,  2 }, {    -47,  -49,    0, 25,  0,  2 }, {    -47,  -50,    0, 25,  0,  2 },
    {    -47,  -51,    0, 25,  0,  2 }, {    -47,  -52,    0, 25,  0,  2 }, {    -47,  -53,    0, 25,  0,  2 }, {    -47,  -54,    0, 25,  0,  2 }, {    -48,  -55,    0, 25,  0,  2 },
    {    -48,  -56,    0, 24,  0,  2 }, {    -48,  -57,    0, 24,  0,  2 }, {    -48,  -58,    0, 24,  0,  2 }, {    -48,  -59,    0, 24,  0,  2 }, {    -48,  -60,    0, 24,  0,  2 },
    {    -48,  -61,    0, 24,  0,  2 }, {    -48,  -62,    0, 24,  0,  2 }, {    -48,  -63,    0, 24,  0,  2 }, {    -48,  -64,    0, 24,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CA4B6, {
    {     16,    0,    0,  8,  0,  2 }, {     16,    1,    0,  8,  0,  2 }, {     16,    2,    0,  8,  0,  2 }, {     16,    3,    0,  8,  0,  2 }, {     16,    4,    0,  8,  0,  2 },
    {     16,    5,    0,  8,  0,  2 }, {     16,    6,    0,  8,  0,  2 }, {     16,    7,    0,  8,  0,  2 }, {     16,    8,    0,  7,  0,  2 }, {     15,    9,    0,  7,  0,  2 },
    {     15,   10,    0,  7,  0,  2 }, {     15,   11,    0,  7,  0,  2 }, {     15,   12,    0,  7,  0,  2 }, {     15,   13,    0,  7,  0,  2 }, {     15,   14,    0,  7,  0,  2 },
    {     14,   15,    0,  7,  0,  2 }, {     14,   16,    0,  7,  0,  2 }, {     14,   17,    0,  7,  0,  2 }, {     14,   18,    0,  7,  0,  2 }, {     14,   19,    0,  7,  0,  2 },
    {     13,   20,    0,  7,  0,  2 }, {     13,   21,    0,  7,  0,  2 }, {     13,   22,    0,  6,  0,  2 }, {     13,   23,    0,  6,  0,  2 }, {     12,   24,    0,  6,  0,  2 },
    {     12,   25,    0,  6,  0,  2 }, {     12,   26,    0,  6,  0,  2 }, {     11,   27,    0,  6,  0,  2 }, {     11,   28,    0,  6,  0,  2 }, {     11,   29,    0,  6,  0,  2 },
    {     10,   30,    0,  6,  0,  2 }, {     10,   31,    0,  6,  0,  2 }, {      9,   32,    0,  6,  0,  2 }, {      9,   33,    0,  6,  0,  2 }, {      8,   34,    0,  6,  0,  2 },
    {      8,   35,    0,  6,  0,  2 }, {      7,   36,    0,  6,  0,  2 }, {      7,   37,    0,  5,  0,  2 }, {      6,   38,    0,  5,  0,  2 }, {      6,   39,    0,  5,  0,  2 },
    {      5,   40,    0,  5,  0,  2 }, {      4,   41,    0,  5,  0,  2 }, {      4,   42,    0,  5,  0,  2 }, {      3,   43,    0,  5,  0,  2 }, {      2,   44,    0,  5,  0,  2 },
    {      2,   45,    0,  5,  0,  2 }, {      1,   46,    0,  5,  0,  2 }, {      0,   47,    0,  5,  0,  2 }, {      0,   48,    0,  5,  0,  2 }, {     -1,   49,    0,  5,  0,  2 },
    {     -2,   50,    0,  4,  0,  2 }, {     -3,   51,    0,  4,  0,  2 }, {     -3,   52,    0,  4,  0,  2 }, {     -4,   53,    0,  4,  0,  2 }, {     -5,   54,    0,  4,  0,  2 },
    {     -6,   55,    0,  4,  0,  2 }, {     -7,   56,    0,  4,  0,  2 }, {     -7,   57,    0,  4,  0,  2 }, {     -8,   58,    0,  4,  0,  2 }, {     -9,   59,    0,  4,  0,  2 },
    {    -10,   60,    0,  4,  0,  2 }, {    -11,   61,    0,  4,  0,  2 }, {    -12,   61,    0,  4,  0,  2 }, {    -13,   62,    0,  3,  0,  2 }, {    -14,   63,    0,  3,  0,  2 },
    {    -15,   64,    0,  3,  0,  2 }, {    -16,   64,    0,  3,  0,  2 }, {    -17,   65,    0,  3,  0,  2 }, {    -18,   66,    0,  3,  0,  2 }, {    -19,   66,    0,  3,  0,  2 },
    {    -20,   67,    0,  3,  0,  2 }, {    -21,   68,    0,  3,  0,  2 }, {    -22,   68,    0,  3,  0,  2 }, {    -23,   69,    0,  3,  0,  2 }, {    -24,   70,    0,  3,  0,  2 },
    {    -25,   70,    0,  3,  0,  2 }, {    -26,   71,    0,  2,  0,  2 }, {    -27,   71,    0,  2,  0,  2 }, {    -28,   72,    0,  2,  0,  2 }, {    -29,   72,    0,  2,  0,  2 },
    {    -30,   73,    0,  2,  0,  2 }, {    -31,   73,    0,  2,  0,  2 }, {    -32,   74,    0,  2,  0,  2 }, {    -33,   74,    0,  2,  0,  2 }, {    -34,   75,    0,  2,  0,  2 },
    {    -35,   75,    0,  2,  0,  2 }, {    -36,   75,    0,  2,  0,  2 }, {    -37,   76,    0,  2,  0,  2 }, {    -38,   76,    0,  2,  0,  2 }, {    -39,   76,    0,  2,  0,  2 },
    {    -40,   77,    0,  1,  0,  2 }, {    -41,   77,    0,  1,  0,  2 }, {    -42,   77,    0,  1,  0,  2 }, {    -43,   77,    0,  1,  0,  2 }, {    -44,   78,    0,  1,  0,  2 },
    {    -45,   78,    0,  1,  0,  2 }, {    -46,   78,    0,  1,  0,  2 }, {    -47,   78,    0,  1,  0,  2 }, {    -48,   78,    0,  1,  0,  2 }, {    -49,   79,    0,  1,  0,  2 },
    {    -50,   79,    0,  1,  0,  2 }, {    -51,   79,    0,  1,  0,  2 }, {    -52,   79,    0,  1,  0,  2 }, {    -53,   79,    0,  1,  0,  2 }, {    -54,   79,    0,  1,  0,  2 },
    {    -55,   80,    0,  1,  0,  2 }, {    -56,   80,    0,  0,  0,  2 }, {    -57,   80,    0,  0,  0,  2 }, {    -58,   80,    0,  0,  0,  2 }, {    -59,   80,    0,  0,  0,  2 },
    {    -60,   80,    0,  0,  0,  2 }, {    -61,   80,    0,  0,  0,  2 }, {    -62,   80,    0,  0,  0,  2 }, {    -63,   80,    0,  0,  0,  2 }, {    -64,   80,    0,  0,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CA8C3, {
    {      0,   16,    0, 16,  0,  2 }, {      1,   16,    0, 16,  0,  2 }, {      2,   16,    0, 16,  0,  2 }, {      3,   16,    0, 16,  0,  2 }, {      4,   16,    0, 16,  0,  2 },
    {      5,   16,    0, 16,  0,  2 }, {      6,   16,    0, 16,  0,  2 }, {      7,   16,    0, 16,  0,  2 }, {      8,   16,    0, 15,  0,  2 }, {      9,   17,    0, 15,  0,  2 },
    {     10,   17,    0, 15,  0,  2 }, {     11,   17,    0, 15,  0,  2 }, {     12,   17,    0, 15,  0,  2 }, {     13,   17,    0, 15,  0,  2 }, {     14,   17,    0, 15,  0,  2 },
    {     15,   18,    0, 15,  0,  2 }, {     16,   18,    0, 15,  0,  2 }, {     17,   18,    0, 15,  0,  2 }, {     18,   18,    0, 15,  0,  2 }, {     19,   18,    0, 15,  0,  2 },
    {     20,   19,    0, 15,  0,  2 }, {     21,   19,    0, 15,  0,  2 }, {     22,   19,    0, 14,  0,  2 }, {     23,   19,    0, 14,  0,  2 }, {     24,   20,    0, 14,  0,  2 },
    {     25,   20,    0, 14,  0,  2 }, {     26,   20,    0, 14,  0,  2 }, {     27,   21,    0, 14,  0,  2 }, {     28,   21,    0, 14,  0,  2 }, {     29,   21,    0, 14,  0,  2 },
    {     30,   22,    0, 14,  0,  2 }, {     31,   22,    0, 14,  0,  2 }, {     32,   23,    0, 14,  0,  2 }, {     33,   23,    0, 14,  0,  2 }, {     34,   24,    0, 14,  0,  2 },
    {     35,   24,    0, 14,  0,  2 }, {     36,   25,    0, 14,  0,  2 }, {     37,   25,    0, 13,  0,  2 }, {     38,   26,    0, 13,  0,  2 }, {     39,   26,    0, 13,  0,  2 },
    {     40,   27,    0, 13,  0,  2 }, {     41,   28,    0, 13,  0,  2 }, {     42,   28,    0, 13,  0,  2 }, {     43,   29,    0, 13,  0,  2 }, {     44,   30,    0, 13,  0,  2 },
    {     45,   30,    0, 13,  0,  2 }, {     46,   31,    0, 13,  0,  2 }, {     47,   32,    0, 13,  0,  2 }, {     48,   32,    0, 13,  0,  2 }, {     49,   33,    0, 13,  0,  2 },
    {     50,   34,    0, 12,  0,  2 }, {     51,   35,    0, 12,  0,  2 }, {     52,   35,    0, 12,  0,  2 }, {     53,   36,    0, 12,  0,  2 }, {     54,   37,    0, 12,  0,  2 },
    {     55,   38,    0, 12,  0,  2 }, {     56,   39,    0, 12,  0,  2 }, {     57,   39,    0, 12,  0,  2 }, {     58,   40,    0, 12,  0,  2 }, {     59,   41,    0, 12,  0,  2 },
    {     60,   42,    0, 12,  0,  2 }, {     61,   43,    0, 12,  0,  2 }, {     61,   44,    0, 12,  0,  2 }, {     62,   45,    0, 11,  0,  2 }, {     63,   46,    0, 11,  0,  2 },
    {     64,   47,    0, 11,  0,  2 }, {     64,   48,    0, 11,  0,  2 }, {     65,   49,    0, 11,  0,  2 }, {     66,   50,    0, 11,  0,  2 }, {     66,   51,    0, 11,  0,  2 },
    {     67,   52,    0, 11,  0,  2 }, {     68,   53,    0, 11,  0,  2 }, {     68,   54,    0, 11,  0,  2 }, {     69,   55,    0, 11,  0,  2 }, {     70,   56,    0, 11,  0,  2 },
    {     70,   57,    0, 11,  0,  2 }, {     71,   58,    0, 10,  0,  2 }, {     71,   59,    0, 10,  0,  2 }, {     72,   60,    0, 10,  0,  2 }, {     72,   61,    0, 10,  0,  2 },
    {     73,   62,    0, 10,  0,  2 }, {     73,   63,    0, 10,  0,  2 }, {     74,   64,    0, 10,  0,  2 }, {     74,   65,    0, 10,  0,  2 }, {     75,   66,    0, 10,  0,  2 },
    {     75,   67,    0, 10,  0,  2 }, {     75,   68,    0, 10,  0,  2 }, {     76,   69,    0, 10,  0,  2 }, {     76,   70,    0, 10,  0,  2 }, {     76,   71,    0, 10,  0,  2 },
    {     77,   72,    0,  9,  0,  2 }, {     77,   73,    0,  9,  0,  2 }, {     77,   74,    0,  9,  0,  2 }, {     77,   75,    0,  9,  0,  2 }, {     78,   76,    0,  9,  0,  2 },
    {     78,   77,    0,  9,  0,  2 }, {     78,   78,    0,  9,  0,  2 }, {     78,   79,    0,  9,  0,  2 }, {     78,   80,    0,  9,  0,  2 }, {     79,   81,    0,  9,  0,  2 },
    {     79,   82,    0,  9,  0,  2 }, {     79,   83,    0,  9,  0,  2 }, {     79,   84,    0,  9,  0,  2 }, {     79,   85,    0,  9,  0,  2 }, {     79,   86,    0,  9,  0,  2 },
    {     80,   87,    0,  9,  0,  2 }, {     80,   88,    0,  8,  0,  2 }, {     80,   89,    0,  8,  0,  2 }, {     80,   90,    0,  8,  0,  2 }, {     80,   91,    0,  8,  0,  2 },
    {     80,   92,    0,  8,  0,  2 }, {     80,   93,    0,  8,  0,  2 }, {     80,   94,    0,  8,  0,  2 }, {     80,   95,    0,  8,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CACC7, {
    {     16,   31,    0, 24,  0,  2 }, {     16,   30,    0, 24,  0,  2 }, {     16,   29,    0, 24,  0,  2 }, {     16,   28,    0, 24,  0,  2 }, {     16,   27,    0, 24,  0,  2 },
    {     16,   26,    0, 24,  0,  2 }, {     16,   25,    0, 24,  0,  2 }, {     16,   24,    0, 23,  0,  2 }, {     17,   23,    0, 23,  0,  2 }, {     17,   22,    0, 23,  0,  2 },
    {     17,   21,    0, 23,  0,  2 }, {     17,   20,    0, 23,  0,  2 }, {     17,   19,    0, 23,  0,  2 }, {     17,   18,    0, 23,  0,  2 }, {     18,   17,    0, 23,  0,  2 },
    {     18,   16,    0, 23,  0,  2 }, {     18,   15,    0, 23,  0,  2 }, {     18,   14,    0, 23,  0,  2 }, {     18,   13,    0, 23,  0,  2 }, {     19,   12,    0, 23,  0,  2 },
    {     19,   11,    0, 23,  0,  2 }, {     19,   10,    0, 22,  0,  2 }, {     19,    9,    0, 22,  0,  2 }, {     20,    8,    0, 22,  0,  2 }, {     20,    7,    0, 22,  0,  2 },
    {     20,    6,    0, 22,  0,  2 }, {     21,    5,    0, 22,  0,  2 }, {     21,    4,    0, 22,  0,  2 }, {     21,    3,    0, 22,  0,  2 }, {     22,    2,    0, 22,  0,  2 },
    {     22,    1,    0, 22,  0,  2 }, {     23,    0,    0, 22,  0,  2 }, {     23,   -1,    0, 22,  0,  2 }, {     24,   -2,    0, 22,  0,  2 }, {     24,   -3,    0, 22,  0,  2 },
    {     25,   -4,    0, 22,  0,  2 }, {     25,   -5,    0, 21,  0,  2 }, {     26,   -6,    0, 21,  0,  2 }, {     26,   -7,    0, 21,  0,  2 }, {     27,   -8,    0, 21,  0,  2 },
    {     28,   -9,    0, 21,  0,  2 }, {     28,  -10,    0, 21,  0,  2 }, {     29,  -11,    0, 21,  0,  2 }, {     30,  -12,    0, 21,  0,  2 }, {     30,  -13,    0, 21,  0,  2 },
    {     31,  -14,    0, 21,  0,  2 }, {     32,  -15,    0, 21,  0,  2 }, {     32,  -16,    0, 21,  0,  2 }, {     33,  -17,    0, 21,  0,  2 }, {     34,  -18,    0, 20,  0,  2 },
    {     35,  -19,    0, 20,  0,  2 }, {     35,  -20,    0, 20,  0,  2 }, {     36,  -21,    0, 20,  0,  2 }, {     37,  -22,    0, 20,  0,  2 }, {     38,  -23,    0, 20,  0,  2 },
    {     39,  -24,    0, 20,  0,  2 }, {     39,  -25,    0, 20,  0,  2 }, {     40,  -26,    0, 20,  0,  2 }, {     41,  -27,    0, 20,  0,  2 }, {     42,  -28,    0, 20,  0,  2 },
    {     43,  -29,    0, 20,  0,  2 }, {     44,  -29,    0, 20,  0,  2 }, {     45,  -30,    0, 19,  0,  2 }, {     46,  -31,    0, 19,  0,  2 }, {     47,  -32,    0, 19,  0,  2 },
    {     48,  -32,    0, 19,  0,  2 }, {     49,  -33,    0, 19,  0,  2 }, {     50,  -34,    0, 19,  0,  2 }, {     51,  -34,    0, 19,  0,  2 }, {     52,  -35,    0, 19,  0,  2 },
    {     53,  -36,    0, 19,  0,  2 }, {     54,  -36,    0, 19,  0,  2 }, {     55,  -37,    0, 19,  0,  2 }, {     56,  -38,    0, 19,  0,  2 }, {     57,  -38,    0, 19,  0,  2 },
    {     58,  -39,    0, 18,  0,  2 }, {     59,  -39,    0, 18,  0,  2 }, {     60,  -40,    0, 18,  0,  2 }, {     61,  -40,    0, 18,  0,  2 }, {     62,  -41,    0, 18,  0,  2 },
    {     63,  -41,    0, 18,  0,  2 }, {     64,  -42,    0, 18,  0,  2 }, {     65,  -42,    0, 18,  0,  2 }, {     66,  -43,    0, 18,  0,  2 }, {     67,  -43,    0, 18,  0,  2 },
    {     68,  -43,    0, 18,  0,  2 }, {     69,  -44,    0, 18,  0,  2 }, {     70,  -44,    0, 18,  0,  2 }, {     71,  -44,    0, 18,  0,  2 }, {     72,  -45,    0, 17,  0,  2 },
    {     73,  -45,    0, 17,  0,  2 }, {     74,  -45,    0, 17,  0,  2 }, {     75,  -45,    0, 17,  0,  2 }, {     76,  -46,    0, 17,  0,  2 }, {     77,  -46,    0, 17,  0,  2 },
    {     78,  -46,    0, 17,  0,  2 }, {     79,  -46,    0, 17,  0,  2 }, {     80,  -46,    0, 17,  0,  2 }, {     81,  -47,    0, 17,  0,  2 }, {     82,  -47,    0, 17,  0,  2 },
    {     83,  -47,    0, 17,  0,  2 }, {     84,  -47,    0, 17,  0,  2 }, {     85,  -47,    0, 17,  0,  2 }, {     86,  -47,    0, 17,  0,  2 }, {     87,  -48,    0, 17,  0,  2 },
    {     88,  -48,    0, 16,  0,  2 }, {     89,  -48,    0, 16,  0,  2 }, {     90,  -48,    0, 16,  0,  2 }, {     91,  -48,    0, 16,  0,  2 }, {     92,  -48,    0, 16,  0,  2 },
    {     93,  -48,    0, 16,  0,  2 }, {     94,  -48,    0, 16,  0,  2 }, {     95,  -48,    0, 16,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CB0C2, {
    {     31,   16,    0,  0,  0,  4 }, {     30,   16,    0,  0,  0,  4 }, {     29,   16,    0,  0,  0,  4 }, {     28,   16,    0,  0,  0,  4 }, {     27,   16,    0,  0,  0,  4 },
    {     26,   16,    0,  0,  0,  4 }, {     25,   16,    0,  0,  0,  4 }, {     24,   16,    0,  1,  0,  4 }, {     23,   17,    0,  1,  0,  4 }, {     22,   17,    0,  1,  0,  4 },
    {     21,   17,    0,  1,  0,  4 }, {     20,   17,    0,  1,  0,  4 }, {     19,   17,    0,  1,  0,  4 }, {     18,   17,    0,  1,  0,  4 }, {     17,   18,    0,  1,  0,  4 },
    {     16,   18,    0,  1,  0,  4 }, {     15,   18,    0,  1,  0,  4 }, {     14,   18,    0,  1,  0,  4 }, {     13,   18,    0,  1,  0,  4 }, {     12,   19,    0,  1,  0,  4 },
    {     11,   19,    0,  1,  0,  4 }, {     10,   19,    0,  2,  0,  4 }, {      9,   19,    0,  2,  0,  4 }, {      8,   20,    0,  2,  0,  4 }, {      7,   20,    0,  2,  0,  4 },
    {      6,   20,    0,  2,  0,  4 }, {      5,   21,    0,  2,  0,  4 }, {      4,   21,    0,  2,  0,  4 }, {      3,   21,    0,  2,  0,  4 }, {      2,   22,    0,  2,  0,  4 },
    {      1,   22,    0,  2,  0,  4 }, {      0,   23,    0,  2,  0,  4 }, {     -1,   23,    0,  2,  0,  4 }, {     -2,   24,    0,  2,  0,  4 }, {     -3,   24,    0,  2,  0,  4 },
    {     -4,   25,    0,  2,  0,  4 }, {     -5,   25,    0,  3,  0,  4 }, {     -6,   26,    0,  3,  0,  4 }, {     -7,   26,    0,  3,  0,  4 }, {     -8,   27,    0,  3,  0,  4 },
    {     -9,   28,    0,  3,  0,  4 }, {    -10,   28,    0,  3,  0,  4 }, {    -11,   29,    0,  3,  0,  4 }, {    -12,   30,    0,  3,  0,  4 }, {    -13,   30,    0,  3,  0,  4 },
    {    -14,   31,    0,  3,  0,  4 }, {    -15,   32,    0,  3,  0,  4 }, {    -16,   32,    0,  3,  0,  4 }, {    -17,   33,    0,  3,  0,  4 }, {    -18,   34,    0,  4,  0,  4 },
    {    -19,   35,    0,  4,  0,  4 }, {    -20,   35,    0,  4,  0,  4 }, {    -21,   36,    0,  4,  0,  4 }, {    -22,   37,    0,  4,  0,  4 }, {    -23,   38,    0,  4,  0,  4 },
    {    -24,   39,    0,  4,  0,  4 }, {    -25,   39,    0,  4,  0,  4 }, {    -26,   40,    0,  4,  0,  4 }, {    -27,   41,    0,  4,  0,  4 }, {    -28,   42,    0,  4,  0,  4 },
    {    -29,   43,    0,  4,  0,  4 }, {    -29,   44,    0,  4,  0,  4 }, {    -30,   45,    0,  5,  0,  4 }, {    -31,   46,    0,  5,  0,  4 }, {    -32,   47,    0,  5,  0,  4 },
    {    -32,   48,    0,  5,  0,  4 }, {    -33,   49,    0,  5,  0,  4 }, {    -34,   50,    0,  5,  0,  4 }, {    -34,   51,    0,  5,  0,  4 }, {    -35,   52,    0,  5,  0,  4 },
    {    -36,   53,    0,  5,  0,  4 }, {    -36,   54,    0,  5,  0,  4 }, {    -37,   55,    0,  5,  0,  4 }, {    -38,   56,    0,  5,  0,  4 }, {    -38,   57,    0,  5,  0,  4 },
    {    -39,   58,    0,  6,  0,  4 }, {    -39,   59,    0,  6,  0,  4 }, {    -40,   60,    0,  6,  0,  4 }, {    -40,   61,    0,  6,  0,  4 }, {    -41,   62,    0,  6,  0,  4 },
    {    -41,   63,    0,  6,  0,  4 }, {    -42,   64,    0,  6,  0,  4 }, {    -42,   65,    0,  6,  0,  4 }, {    -43,   66,    0,  6,  0,  4 }, {    -43,   67,    0,  6,  0,  4 },
    {    -43,   68,    0,  6,  0,  4 }, {    -44,   69,    0,  6,  0,  4 }, {    -44,   70,    0,  6,  0,  4 }, {    -44,   71,    0,  6,  0,  4 }, {    -45,   72,    0,  7,  0,  4 },
    {    -45,   73,    0,  7,  0,  4 }, {    -45,   74,    0,  7,  0,  4 }, {    -45,   75,    0,  7,  0,  4 }, {    -46,   76,    0,  7,  0,  4 }, {    -46,   77,    0,  7,  0,  4 },
    {    -46,   78,    0,  7,  0,  4 }, {    -46,   79,    0,  7,  0,  4 }, {    -46,   80,    0,  7,  0,  4 }, {    -47,   81,    0,  7,  0,  4 }, {    -47,   82,    0,  7,  0,  4 },
    {    -47,   83,    0,  7,  0,  4 }, {    -47,   84,    0,  7,  0,  4 }, {    -47,   85,    0,  7,  0,  4 }, {    -47,   86,    0,  7,  0,  4 }, {    -48,   87,    0,  7,  0,  4 },
    {    -48,   88,    0,  8,  0,  4 }, {    -48,   89,    0,  8,  0,  4 }, {    -48,   90,    0,  8,  0,  4 }, {    -48,   91,    0,  8,  0,  4 }, {    -48,   92,    0,  8,  0,  4 },
    {    -48,   93,    0,  8,  0,  4 }, {    -48,   94,    0,  8,  0,  4 }, {    -48,   95,    0,  8,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CB4BD, {
    {     16,    0,    0,  8,  0,  4 }, {     16,    1,    0,  8,  0,  4 }, {     16,    2,    0,  8,  0,  4 }, {     16,    3,    0,  8,  0,  4 }, {     16,    4,    0,  8,  0,  4 },
    {     16,    5,    0,  8,  0,  4 }, {     16,    6,    0,  8,  0,  4 }, {     16,    7,    0,  8,  0,  4 }, {     16,    8,    0,  9,  0,  4 }, {     17,    9,    0,  9,  0,  4 },
    {     17,   10,    0,  9,  0,  4 }, {     17,   11,    0,  9,  0,  4 }, {     17,   12,    0,  9,  0,  4 }, {     17,   13,    0,  9,  0,  4 }, {     17,   14,    0,  9,  0,  4 },
    {     18,   15,    0,  9,  0,  4 }, {     18,   16,    0,  9,  0,  4 }, {     18,   17,    0,  9,  0,  4 }, {     18,   18,    0,  9,  0,  4 }, {     18,   19,    0,  9,  0,  4 },
    {     19,   20,    0,  9,  0,  4 }, {     19,   21,    0,  9,  0,  4 }, {     19,   22,    0, 10,  0,  4 }, {     19,   23,    0, 10,  0,  4 }, {     20,   24,    0, 10,  0,  4 },
    {     20,   25,    0, 10,  0,  4 }, {     20,   26,    0, 10,  0,  4 }, {     21,   27,    0, 10,  0,  4 }, {     21,   28,    0, 10,  0,  4 }, {     21,   29,    0, 10,  0,  4 },
    {     22,   30,    0, 10,  0,  4 }, {     22,   31,    0, 10,  0,  4 }, {     23,   32,    0, 10,  0,  4 }, {     23,   33,    0, 10,  0,  4 }, {     24,   34,    0, 10,  0,  4 },
    {     24,   35,    0, 10,  0,  4 }, {     25,   36,    0, 10,  0,  4 }, {     25,   37,    0, 11,  0,  4 }, {     26,   38,    0, 11,  0,  4 }, {     26,   39,    0, 11,  0,  4 },
    {     27,   40,    0, 11,  0,  4 }, {     28,   41,    0, 11,  0,  4 }, {     28,   42,    0, 11,  0,  4 }, {     29,   43,    0, 11,  0,  4 }, {     30,   44,    0, 11,  0,  4 },
    {     30,   45,    0, 11,  0,  4 }, {     31,   46,    0, 11,  0,  4 }, {     32,   47,    0, 11,  0,  4 }, {     32,   48,    0, 11,  0,  4 }, {     33,   49,    0, 11,  0,  4 },
    {     34,   50,    0, 12,  0,  4 }, {     35,   51,    0, 12,  0,  4 }, {     35,   52,    0, 12,  0,  4 }, {     36,   53,    0, 12,  0,  4 }, {     37,   54,    0, 12,  0,  4 },
    {     38,   55,    0, 12,  0,  4 }, {     39,   56,    0, 12,  0,  4 }, {     39,   57,    0, 12,  0,  4 }, {     40,   58,    0, 12,  0,  4 }, {     41,   59,    0, 12,  0,  4 },
    {     42,   60,    0, 12,  0,  4 }, {     43,   61,    0, 12,  0,  4 }, {     44,   61,    0, 12,  0,  4 }, {     45,   62,    0, 13,  0,  4 }, {     46,   63,    0, 13,  0,  4 },
    {     47,   64,    0, 13,  0,  4 }, {     48,   64,    0, 13,  0,  4 }, {     49,   65,    0, 13,  0,  4 }, {     50,   66,    0, 13,  0,  4 }, {     51,   66,    0, 13,  0,  4 },
    {     52,   67,    0, 13,  0,  4 }, {     53,   68,    0, 13,  0,  4 }, {     54,   68,    0, 13,  0,  4 }, {     55,   69,    0, 13,  0,  4 }, {     56,   70,    0, 13,  0,  4 },
    {     57,   70,    0, 13,  0,  4 }, {     58,   71,    0, 14,  0,  4 }, {     59,   71,    0, 14,  0,  4 }, {     60,   72,    0, 14,  0,  4 }, {     61,   72,    0, 14,  0,  4 },
    {     62,   73,    0, 14,  0,  4 }, {     63,   73,    0, 14,  0,  4 }, {     64,   74,    0, 14,  0,  4 }, {     65,   74,    0, 14,  0,  4 }, {     66,   75,    0, 14,  0,  4 },
    {     67,   75,    0, 14,  0,  4 }, {     68,   75,    0, 14,  0,  4 }, {     69,   76,    0, 14,  0,  4 }, {     70,   76,    0, 14,  0,  4 }, {     71,   76,    0, 14,  0,  4 },
    {     72,   77,    0, 15,  0,  4 }, {     73,   77,    0, 15,  0,  4 }, {     74,   77,    0, 15,  0,  4 }, {     75,   77,    0, 15,  0,  4 }, {     76,   78,    0, 15,  0,  4 },
    {     77,   78,    0, 15,  0,  4 }, {     78,   78,    0, 15,  0,  4 }, {     79,   78,    0, 15,  0,  4 }, {     80,   78,    0, 15,  0,  4 }, {     81,   79,    0, 15,  0,  4 },
    {     82,   79,    0, 15,  0,  4 }, {     83,   79,    0, 15,  0,  4 }, {     84,   79,    0, 15,  0,  4 }, {     85,   79,    0, 15,  0,  4 }, {     86,   79,    0, 15,  0,  4 },
    {     87,   80,    0, 15,  0,  4 }, {     88,   80,    0, 16,  0,  4 }, {     89,   80,    0, 16,  0,  4 }, {     90,   80,    0, 16,  0,  4 }, {     91,   80,    0, 16,  0,  4 },
    {     92,   80,    0, 16,  0,  4 }, {     93,   80,    0, 16,  0,  4 }, {     94,   80,    0, 16,  0,  4 }, {     95,   80,    0, 16,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CB8C1, {
    {      0,   16,    0, 16,  0,  4 }, {      1,   16,    0, 16,  0,  4 }, {      2,   16,    0, 16,  0,  4 }, {      3,   16,    0, 16,  0,  4 }, {      4,   16,    0, 16,  0,  4 },
    {      5,   16,    0, 16,  0,  4 }, {      6,   16,    0, 16,  0,  4 }, {      7,   16,    0, 16,  0,  4 }, {      8,   16,    0, 17,  0,  4 }, {      9,   15,    0, 17,  0,  4 },
    {     10,   15,    0, 17,  0,  4 }, {     11,   15,    0, 17,  0,  4 }, {     12,   15,    0, 17,  0,  4 }, {     13,   15,    0, 17,  0,  4 }, {     14,   15,    0, 17,  0,  4 },
    {     15,   14,    0, 17,  0,  4 }, {     16,   14,    0, 17,  0,  4 }, {     17,   14,    0, 17,  0,  4 }, {     18,   14,    0, 17,  0,  4 }, {     19,   14,    0, 17,  0,  4 },
    {     20,   13,    0, 17,  0,  4 }, {     21,   13,    0, 17,  0,  4 }, {     22,   13,    0, 18,  0,  4 }, {     23,   13,    0, 18,  0,  4 }, {     24,   12,    0, 18,  0,  4 },
    {     25,   12,    0, 18,  0,  4 }, {     26,   12,    0, 18,  0,  4 }, {     27,   11,    0, 18,  0,  4 }, {     28,   11,    0, 18,  0,  4 }, {     29,   11,    0, 18,  0,  4 },
    {     30,   10,    0, 18,  0,  4 }, {     31,   10,    0, 18,  0,  4 }, {     32,    9,    0, 18,  0,  4 }, {     33,    9,    0, 18,  0,  4 }, {     34,    8,    0, 18,  0,  4 },
    {     35,    8,    0, 18,  0,  4 }, {     36,    7,    0, 18,  0,  4 }, {     37,    7,    0, 19,  0,  4 }, {     38,    6,    0, 19,  0,  4 }, {     39,    6,    0, 19,  0,  4 },
    {     40,    5,    0, 19,  0,  4 }, {     41,    4,    0, 19,  0,  4 }, {     42,    4,    0, 19,  0,  4 }, {     43,    3,    0, 19,  0,  4 }, {     44,    2,    0, 19,  0,  4 },
    {     45,    2,    0, 19,  0,  4 }, {     46,    1,    0, 19,  0,  4 }, {     47,    0,    0, 19,  0,  4 }, {     48,    0,    0, 19,  0,  4 }, {     49,   -1,    0, 19,  0,  4 },
    {     50,   -2,    0, 20,  0,  4 }, {     51,   -3,    0, 20,  0,  4 }, {     52,   -3,    0, 20,  0,  4 }, {     53,   -4,    0, 20,  0,  4 }, {     54,   -5,    0, 20,  0,  4 },
    {     55,   -6,    0, 20,  0,  4 }, {     56,   -7,    0, 20,  0,  4 }, {     57,   -7,    0, 20,  0,  4 }, {     58,   -8,    0, 20,  0,  4 }, {     59,   -9,    0, 20,  0,  4 },
    {     60,  -10,    0, 20,  0,  4 }, {     61,  -11,    0, 20,  0,  4 }, {     61,  -12,    0, 20,  0,  4 }, {     62,  -13,    0, 21,  0,  4 }, {     63,  -14,    0, 21,  0,  4 },
    {     64,  -15,    0, 21,  0,  4 }, {     64,  -16,    0, 21,  0,  4 }, {     65,  -17,    0, 21,  0,  4 }, {     66,  -18,    0, 21,  0,  4 }, {     66,  -19,    0, 21,  0,  4 },
    {     67,  -20,    0, 21,  0,  4 }, {     68,  -21,    0, 21,  0,  4 }, {     68,  -22,    0, 21,  0,  4 }, {     69,  -23,    0, 21,  0,  4 }, {     70,  -24,    0, 21,  0,  4 },
    {     70,  -25,    0, 21,  0,  4 }, {     71,  -26,    0, 22,  0,  4 }, {     71,  -27,    0, 22,  0,  4 }, {     72,  -28,    0, 22,  0,  4 }, {     72,  -29,    0, 22,  0,  4 },
    {     73,  -30,    0, 22,  0,  4 }, {     73,  -31,    0, 22,  0,  4 }, {     74,  -32,    0, 22,  0,  4 }, {     74,  -33,    0, 22,  0,  4 }, {     75,  -34,    0, 22,  0,  4 },
    {     75,  -35,    0, 22,  0,  4 }, {     75,  -36,    0, 22,  0,  4 }, {     76,  -37,    0, 22,  0,  4 }, {     76,  -38,    0, 22,  0,  4 }, {     76,  -39,    0, 22,  0,  4 },
    {     77,  -40,    0, 23,  0,  4 }, {     77,  -41,    0, 23,  0,  4 }, {     77,  -42,    0, 23,  0,  4 }, {     77,  -43,    0, 23,  0,  4 }, {     78,  -44,    0, 23,  0,  4 },
    {     78,  -45,    0, 23,  0,  4 }, {     78,  -46,    0, 23,  0,  4 }, {     78,  -47,    0, 23,  0,  4 }, {     78,  -48,    0, 23,  0,  4 }, {     79,  -49,    0, 23,  0,  4 },
    {     79,  -50,    0, 23,  0,  4 }, {     79,  -51,    0, 23,  0,  4 }, {     79,  -52,    0, 23,  0,  4 }, {     79,  -53,    0, 23,  0,  4 }, {     79,  -54,    0, 23,  0,  4 },
    {     80,  -55,    0, 23,  0,  4 }, {     80,  -56,    0, 24,  0,  4 }, {     80,  -57,    0, 24,  0,  4 }, {     80,  -58,    0, 24,  0,  4 }, {     80,  -59,    0, 24,  0,  4 },
    {     80,  -60,    0, 24,  0,  4 }, {     80,  -61,    0, 24,  0,  4 }, {     80,  -62,    0, 24,  0,  4 }, {     80,  -63,    0, 24,  0,  4 }, {     80,  -64,    0, 24,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CBCCE, {
    {     16,   31,    0, 24,  0,  4 }, {     16,   30,    0, 24,  0,  4 }, {     16,   29,    0, 24,  0,  4 }, {     16,   28,    0, 24,  0,  4 }, {     16,   27,    0, 24,  0,  4 },
    {     16,   26,    0, 24,  0,  4 }, {     16,   25,    0, 24,  0,  4 }, {     16,   24,    0, 25,  0,  4 }, {     15,   23,    0, 25,  0,  4 }, {     15,   22,    0, 25,  0,  4 },
    {     15,   21,    0, 25,  0,  4 }, {     15,   20,    0, 25,  0,  4 }, {     15,   19,    0, 25,  0,  4 }, {     15,   18,    0, 25,  0,  4 }, {     14,   17,    0, 25,  0,  4 },
    {     14,   16,    0, 25,  0,  4 }, {     14,   15,    0, 25,  0,  4 }, {     14,   14,    0, 25,  0,  4 }, {     14,   13,    0, 25,  0,  4 }, {     13,   12,    0, 25,  0,  4 },
    {     13,   11,    0, 25,  0,  4 }, {     13,   10,    0, 26,  0,  4 }, {     13,    9,    0, 26,  0,  4 }, {     12,    8,    0, 26,  0,  4 }, {     12,    7,    0, 26,  0,  4 },
    {     12,    6,    0, 26,  0,  4 }, {     11,    5,    0, 26,  0,  4 }, {     11,    4,    0, 26,  0,  4 }, {     11,    3,    0, 26,  0,  4 }, {     10,    2,    0, 26,  0,  4 },
    {     10,    1,    0, 26,  0,  4 }, {      9,    0,    0, 26,  0,  4 }, {      9,   -1,    0, 26,  0,  4 }, {      8,   -2,    0, 26,  0,  4 }, {      8,   -3,    0, 26,  0,  4 },
    {      7,   -4,    0, 26,  0,  4 }, {      7,   -5,    0, 27,  0,  4 }, {      6,   -6,    0, 27,  0,  4 }, {      6,   -7,    0, 27,  0,  4 }, {      5,   -8,    0, 27,  0,  4 },
    {      4,   -9,    0, 27,  0,  4 }, {      4,  -10,    0, 27,  0,  4 }, {      3,  -11,    0, 27,  0,  4 }, {      2,  -12,    0, 27,  0,  4 }, {      2,  -13,    0, 27,  0,  4 },
    {      1,  -14,    0, 27,  0,  4 }, {      0,  -15,    0, 27,  0,  4 }, {      0,  -16,    0, 27,  0,  4 }, {     -1,  -17,    0, 27,  0,  4 }, {     -2,  -18,    0, 28,  0,  4 },
    {     -3,  -19,    0, 28,  0,  4 }, {     -3,  -20,    0, 28,  0,  4 }, {     -4,  -21,    0, 28,  0,  4 }, {     -5,  -22,    0, 28,  0,  4 }, {     -6,  -23,    0, 28,  0,  4 },
    {     -7,  -24,    0, 28,  0,  4 }, {     -7,  -25,    0, 28,  0,  4 }, {     -8,  -26,    0, 28,  0,  4 }, {     -9,  -27,    0, 28,  0,  4 }, {    -10,  -28,    0, 28,  0,  4 },
    {    -11,  -29,    0, 28,  0,  4 }, {    -12,  -29,    0, 28,  0,  4 }, {    -13,  -30,    0, 29,  0,  4 }, {    -14,  -31,    0, 29,  0,  4 }, {    -15,  -32,    0, 29,  0,  4 },
    {    -16,  -32,    0, 29,  0,  4 }, {    -17,  -33,    0, 29,  0,  4 }, {    -18,  -34,    0, 29,  0,  4 }, {    -19,  -34,    0, 29,  0,  4 }, {    -20,  -35,    0, 29,  0,  4 },
    {    -21,  -36,    0, 29,  0,  4 }, {    -22,  -36,    0, 29,  0,  4 }, {    -23,  -37,    0, 29,  0,  4 }, {    -24,  -38,    0, 29,  0,  4 }, {    -25,  -38,    0, 29,  0,  4 },
    {    -26,  -39,    0, 30,  0,  4 }, {    -27,  -39,    0, 30,  0,  4 }, {    -28,  -40,    0, 30,  0,  4 }, {    -29,  -40,    0, 30,  0,  4 }, {    -30,  -41,    0, 30,  0,  4 },
    {    -31,  -41,    0, 30,  0,  4 }, {    -32,  -42,    0, 30,  0,  4 }, {    -33,  -42,    0, 30,  0,  4 }, {    -34,  -43,    0, 30,  0,  4 }, {    -35,  -43,    0, 30,  0,  4 },
    {    -36,  -43,    0, 30,  0,  4 }, {    -37,  -44,    0, 30,  0,  4 }, {    -38,  -44,    0, 30,  0,  4 }, {    -39,  -44,    0, 30,  0,  4 }, {    -40,  -45,    0, 31,  0,  4 },
    {    -41,  -45,    0, 31,  0,  4 }, {    -42,  -45,    0, 31,  0,  4 }, {    -43,  -45,    0, 31,  0,  4 }, {    -44,  -46,    0, 31,  0,  4 }, {    -45,  -46,    0, 31,  0,  4 },
    {    -46,  -46,    0, 31,  0,  4 }, {    -47,  -46,    0, 31,  0,  4 }, {    -48,  -46,    0, 31,  0,  4 }, {    -49,  -47,    0, 31,  0,  4 }, {    -50,  -47,    0, 31,  0,  4 },
    {    -51,  -47,    0, 31,  0,  4 }, {    -52,  -47,    0, 31,  0,  4 }, {    -53,  -47,    0, 31,  0,  4 }, {    -54,  -47,    0, 31,  0,  4 }, {    -55,  -48,    0, 31,  0,  4 },
    {    -56,  -48,    0,  0,  0,  4 }, {    -57,  -48,    0,  0,  0,  4 }, {    -58,  -48,    0,  0,  0,  4 }, {    -59,  -48,    0,  0,  0,  4 }, {    -60,  -48,    0,  0,  0,  4 },
    {    -61,  -48,    0,  0,  0,  4 }, {    -62,  -48,    0,  0,  0,  4 }, {    -63,  -48,    0,  0,  0,  4 }, {    -64,  -48,    0,  0,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C4762, {
    {     31,   16,    0,  0,  0,  2 }, {     30,   16,    0,  0,  0,  2 }, {     29,   16,    0,  0,  0,  2 }, {     28,   16,    0,  0,  0,  2 }, {     27,   16,    0,  0,  0,  2 },
    {     26,   16,    0,  0,  0,  2 }, {     25,   16,    0,  0,  0,  2 }, {     24,   16,    0,  0,  0,  2 }, {     23,   16,    0,  0,  1,  1 }, {     22,   16,    0,  0,  1,  1 },
    {     21,   16,    1,  0,  1,  1 }, {     20,   16,    1,  0,  1,  1 }, {     19,   16,    1,  0,  1,  1 }, {     18,   16,    1,  0,  1,  1 }, {     17,   16,    1,  0,  1,  1 },
    {     16,   16,    1,  0,  1,  1 }, {     15,   16,    2,  0,  1,  1 }, {     14,   16,    2,  0,  1,  1 }, {     13,   16,    2,  0,  1,  1 }, {     12,   16,    2,  0,  1,  1 },
    {     11,   16,    3,  0,  1,  1 }, {     10,   16,    3,  0,  1,  1 }, {      9,   16,    3,  0,  1,  1 }, {      8,   16,    4,  0,  1,  1 }, {      7,   16,    4,  0,  2,  0 },
    {      6,   16,    4,  0,  2,  0 }, {      5,   16,    5,  0,  2,  0 }, {      4,   16,    5,  0,  2,  0 }, {      3,   16,    6,  0,  2,  0 }, {      2,   16,    6,  0,  2,  0 },
    {      1,   16,    7,  0,  2,  0 }, {      0,   16,    7,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C4884, {
    {     16,    0,    0,  8,  0,  2 }, {     16,    1,    0,  8,  0,  2 }, {     16,    2,    0,  8,  0,  2 }, {     16,    3,    0,  8,  0,  2 }, {     16,    4,    0,  8,  0,  2 },
    {     16,    5,    0,  8,  0,  2 }, {     16,    6,    0,  8,  0,  2 }, {     16,    7,    0,  8,  0,  2 }, {     16,    8,    0,  8,  1,  1 }, {     16,    9,    0,  8,  1,  1 },
    {     16,   10,    1,  8,  1,  1 }, {     16,   11,    1,  8,  1,  1 }, {     16,   12,    1,  8,  1,  1 }, {     16,   13,    1,  8,  1,  1 }, {     16,   14,    1,  8,  1,  1 },
    {     16,   15,    1,  8,  1,  1 }, {     16,   16,    2,  8,  1,  1 }, {     16,   17,    2,  8,  1,  1 }, {     16,   18,    2,  8,  1,  1 }, {     16,   19,    2,  8,  1,  1 },
    {     16,   20,    3,  8,  1,  1 }, {     16,   21,    3,  8,  1,  1 }, {     16,   22,    3,  8,  1,  1 }, {     16,   23,    4,  8,  1,  1 }, {     16,   24,    4,  8,  2,  0 },
    {     16,   25,    4,  8,  2,  0 }, {     16,   26,    5,  8,  2,  0 }, {     16,   27,    5,  8,  2,  0 }, {     16,   28,    6,  8,  2,  0 }, {     16,   29,    6,  8,  2,  0 },
    {     16,   30,    7,  8,  2,  0 }, {     16,   31,    7,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C49A6, {
    {      0,   16,    0, 16,  0,  2 }, {      1,   16,    0, 16,  0,  2 }, {      2,   16,    0, 16,  0,  2 }, {      3,   16,    0, 16,  0,  2 }, {      4,   16,    0, 16,  0,  2 },
    {      5,   16,    0, 16,  0,  2 }, {      6,   16,    0, 16,  0,  2 }, {      7,   16,    0, 16,  0,  2 }, {      8,   16,    0, 16,  1,  1 }, {      9,   16,    0, 16,  1,  1 },
    {     10,   16,    1, 16,  1,  1 }, {     11,   16,    1, 16,  1,  1 }, {     12,   16,    1, 16,  1,  1 }, {     13,   16,    1, 16,  1,  1 }, {     14,   16,    1, 16,  1,  1 },
    {     15,   16,    1, 16,  1,  1 }, {     16,   16,    2, 16,  1,  1 }, {     17,   16,    2, 16,  1,  1 }, {     18,   16,    2, 16,  1,  1 }, {     19,   16,    2, 16,  1,  1 },
    {     20,   16,    3, 16,  1,  1 }, {     21,   16,    3, 16,  1,  1 }, {     22,   16,    3, 16,  1,  1 }, {     23,   16,    4, 16,  1,  1 }, {     24,   16,    4, 16,  2,  0 },
    {     25,   16,    4, 16,  2,  0 }, {     26,   16,    5, 16,  2,  0 }, {     27,   16,    5, 16,  2,  0 }, {     28,   16,    6, 16,  2,  0 }, {     29,   16,    6, 16,  2,  0 },
    {     30,   16,    7, 16,  2,  0 }, {     31,   16,    7, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C4AC8, {
    {     16,   31,    0, 24,  0,  2 }, {     16,   30,    0, 24,  0,  2 }, {     16,   29,    0, 24,  0,  2 }, {     16,   28,    0, 24,  0,  2 }, {     16,   27,    0, 24,  0,  2 },
    {     16,   26,    0, 24,  0,  2 }, {     16,   25,    0, 24,  0,  2 }, {     16,   24,    0, 24,  0,  2 }, {     16,   23,    0, 24,  1,  1 }, {     16,   22,    0, 24,  1,  1 },
    {     16,   21,    1, 24,  1,  1 }, {     16,   20,    1, 24,  1,  1 }, {     16,   19,    1, 24,  1,  1 }, {     16,   18,    1, 24,  1,  1 }, {     16,   17,    1, 24,  1,  1 },
    {     16,   16,    1, 24,  1,  1 }, {     16,   15,    2, 24,  1,  1 }, {     16,   14,    2, 24,  1,  1 }, {     16,   13,    2, 24,  1,  1 }, {     16,   12,    2, 24,  1,  1 },
    {     16,   11,    3, 24,  1,  1 }, {     16,   10,    3, 24,  1,  1 }, {     16,    9,    3, 24,  1,  1 }, {     16,    8,    4, 24,  1,  1 }, {     16,    7,    4, 24,  2,  0 },
    {     16,    6,    4, 24,  2,  0 }, {     16,    5,    5, 24,  2,  0 }, {     16,    4,    5, 24,  2,  0 }, {     16,    3,    6, 24,  2,  0 }, {     16,    2,    6, 24,  2,  0 },
    {     16,    1,    7, 24,  2,  0 }, {     16,    0,    7, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C4BEA, {
    {     31,   16,    0,  0,  0,  4 }, {     30,   16,    0,  0,  0,  4 }, {     29,   16,    0,  0,  0,  4 }, {     28,   16,    0,  0,  0,  4 }, {     27,   16,    0,  0,  0,  4 },
    {     26,   16,    0,  0,  0,  4 }, {     25,   16,    0,  0,  0,  4 }, {     24,   16,    0,  0,  0,  4 }, {     23,   16,    0,  0,  1,  3 }, {     22,   16,    0,  0,  1,  3 },
    {     21,   16,    1,  0,  1,  3 }, {     20,   16,    1,  0,  1,  3 }, {     19,   16,    1,  0,  1,  3 }, {     18,   16,    1,  0,  1,  3 }, {     17,   16,    1,  0,  1,  3 },
    {     16,   16,    1,  0,  1,  3 }, {     15,   16,    2,  0,  1,  3 }, {     14,   16,    2,  0,  1,  3 }, {     13,   16,    2,  0,  1,  3 }, {     12,   16,    2,  0,  1,  3 },
    {     11,   16,    3,  0,  1,  3 }, {     10,   16,    3,  0,  1,  3 }, {      9,   16,    3,  0,  1,  3 }, {      8,   16,    4,  0,  1,  3 }, {      7,   16,    4,  0,  2,  0 },
    {      6,   16,    4,  0,  2,  0 }, {      5,   16,    5,  0,  2,  0 }, {      4,   16,    5,  0,  2,  0 }, {      3,   16,    6,  0,  2,  0 }, {      2,   16,    6,  0,  2,  0 },
    {      1,   16,    7,  0,  2,  0 }, {      0,   16,    7,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C4D0C, {
    {     16,    0,    0,  8,  0,  4 }, {     16,    1,    0,  8,  0,  4 }, {     16,    2,    0,  8,  0,  4 }, {     16,    3,    0,  8,  0,  4 }, {     16,    4,    0,  8,  0,  4 },
    {     16,    5,    0,  8,  0,  4 }, {     16,    6,    0,  8,  0,  4 }, {     16,    7,    0,  8,  0,  4 }, {     16,    8,    0,  8,  1,  3 }, {     16,    9,    0,  8,  1,  3 },
    {     16,   10,    1,  8,  1,  3 }, {     16,   11,    1,  8,  1,  3 }, {     16,   12,    1,  8,  1,  3 }, {     16,   13,    1,  8,  1,  3 }, {     16,   14,    1,  8,  1,  3 },
    {     16,   15,    1,  8,  1,  3 }, {     16,   16,    2,  8,  1,  3 }, {     16,   17,    2,  8,  1,  3 }, {     16,   18,    2,  8,  1,  3 }, {     16,   19,    2,  8,  1,  3 },
    {     16,   20,    3,  8,  1,  3 }, {     16,   21,    3,  8,  1,  3 }, {     16,   22,    3,  8,  1,  3 }, {     16,   23,    4,  8,  1,  3 }, {     16,   24,    4,  8,  2,  0 },
    {     16,   25,    4,  8,  2,  0 }, {     16,   26,    5,  8,  2,  0 }, {     16,   27,    5,  8,  2,  0 }, {     16,   28,    6,  8,  2,  0 }, {     16,   29,    6,  8,  2,  0 },
    {     16,   30,    7,  8,  2,  0 }, {     16,   31,    7,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C4E2E, {
    {      0,   16,    0, 16,  0,  4 }, {      1,   16,    0, 16,  0,  4 }, {      2,   16,    0, 16,  0,  4 }, {      3,   16,    0, 16,  0,  4 }, {      4,   16,    0, 16,  0,  4 },
    {      5,   16,    0, 16,  0,  4 }, {      6,   16,    0, 16,  0,  4 }, {      7,   16,    0, 16,  0,  4 }, {      8,   16,    0, 16,  1,  3 }, {      9,   16,    0, 16,  1,  3 },
    {     10,   16,    1, 16,  1,  3 }, {     11,   16,    1, 16,  1,  3 }, {     12,   16,    1, 16,  1,  3 }, {     13,   16,    1, 16,  1,  3 }, {     14,   16,    1, 16,  1,  3 },
    {     15,   16,    1, 16,  1,  3 }, {     16,   16,    2, 16,  1,  3 }, {     17,   16,    2, 16,  1,  3 }, {     18,   16,    2, 16,  1,  3 }, {     19,   16,    2, 16,  1,  3 },
    {     20,   16,    3, 16,  1,  3 }, {     21,   16,    3, 16,  1,  3 }, {     22,   16,    3, 16,  1,  3 }, {     23,   16,    4, 16,  1,  3 }, {     24,   16,    4, 16,  2,  0 },
    {     25,   16,    4, 16,  2,  0 }, {     26,   16,    5, 16,  2,  0 }, {     27,   16,    5, 16,  2,  0 }, {     28,   16,    6, 16,  2,  0 }, {     29,   16,    6, 16,  2,  0 },
    {     30,   16,    7, 16,  2,  0 }, {     31,   16,    7, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C4F50, {
    {     16,   31,    0, 24,  0,  4 }, {     16,   30,    0, 24,  0,  4 }, {     16,   29,    0, 24,  0,  4 }, {     16,   28,    0, 24,  0,  4 }, {     16,   27,    0, 24,  0,  4 },
    {     16,   26,    0, 24,  0,  4 }, {     16,   25,    0, 24,  0,  4 }, {     16,   24,    0, 24,  0,  4 }, {     16,   23,    0, 24,  1,  3 }, {     16,   22,    0, 24,  1,  3 },
    {     16,   21,    1, 24,  1,  3 }, {     16,   20,    1, 24,  1,  3 }, {     16,   19,    1, 24,  1,  3 }, {     16,   18,    1, 24,  1,  3 }, {     16,   17,    1, 24,  1,  3 },
    {     16,   16,    1, 24,  1,  3 }, {     16,   15,    2, 24,  1,  3 }, {     16,   14,    2, 24,  1,  3 }, {     16,   13,    2, 24,  1,  3 }, {     16,   12,    2, 24,  1,  3 },
    {     16,   11,    3, 24,  1,  3 }, {     16,   10,    3, 24,  1,  3 }, {     16,    9,    3, 24,  1,  3 }, {     16,    8,    4, 24,  1,  3 }, {     16,    7,    4, 24,  2,  0 },
    {     16,    6,    4, 24,  2,  0 }, {     16,    5,    5, 24,  2,  0 }, {     16,    4,    5, 24,  2,  0 }, {     16,    3,    6, 24,  2,  0 }, {     16,    2,    6, 24,  2,  0 },
    {     16,    1,    7, 24,  2,  0 }, {     16,    0,    7, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C5072, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    0,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    1,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    2,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    3,  0,  2,  0 }, {     23,   16,    4,  0,  1,  1 }, {     22,   16,    4,  0,  1,  1 },
    {     21,   16,    4,  0,  1,  1 }, {     20,   16,    5,  0,  1,  1 }, {     19,   16,    5,  0,  1,  1 }, {     18,   16,    5,  0,  1,  1 }, {     17,   16,    6,  0,  1,  1 },
    {     16,   16,    6,  0,  1,  1 }, {     15,   16,    6,  0,  1,  1 }, {     14,   16,    6,  0,  1,  1 }, {     13,   16,    7,  0,  1,  1 }, {     12,   16,    7,  0,  1,  1 },
    {     11,   16,    7,  0,  1,  1 }, {     10,   16,    7,  0,  1,  1 }, {      9,   16,    7,  0,  0,  2 }, {      8,   16,    7,  0,  0,  2 }, {      7,   16,    8,  0,  0,  2 },
    {      6,   16,    8,  0,  0,  2 }, {      5,   16,    8,  0,  0,  2 }, {      4,   16,    8,  0,  0,  2 }, {      3,   16,    8,  0,  0,  2 }, {      2,   16,    8,  0,  0,  2 },
    {      1,   16,    8,  0,  0,  2 }, {      0,   16,    8,  0,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C51A6, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    2,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    3,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    4,  8,  1,  1 }, {     16,    9,    4,  8,  1,  1 },
    {     16,   10,    4,  8,  1,  1 }, {     16,   11,    5,  8,  1,  1 }, {     16,   12,    5,  8,  1,  1 }, {     16,   13,    5,  8,  1,  1 }, {     16,   14,    6,  8,  1,  1 },
    {     16,   15,    6,  8,  1,  1 }, {     16,   16,    6,  8,  1,  1 }, {     16,   17,    6,  8,  1,  1 }, {     16,   18,    7,  8,  1,  1 }, {     16,   19,    7,  8,  1,  1 },
    {     16,   20,    7,  8,  1,  1 }, {     16,   21,    7,  8,  1,  1 }, {     16,   22,    7,  8,  0,  2 }, {     16,   23,    7,  8,  0,  2 }, {     16,   24,    8,  8,  0,  2 },
    {     16,   25,    8,  8,  0,  2 }, {     16,   26,    8,  8,  0,  2 }, {     16,   27,    8,  8,  0,  2 }, {     16,   28,    8,  8,  0,  2 }, {     16,   29,    8,  8,  0,  2 },
    {     16,   30,    8,  8,  0,  2 }, {     16,   31,    8,  8,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C52DA, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    2, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    3, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    4, 16,  1,  1 }, {      9,   16,    4, 16,  1,  1 },
    {     10,   16,    4, 16,  1,  1 }, {     11,   16,    5, 16,  1,  1 }, {     12,   16,    5, 16,  1,  1 }, {     13,   16,    5, 16,  1,  1 }, {     14,   16,    6, 16,  1,  1 },
    {     15,   16,    6, 16,  1,  1 }, {     16,   16,    6, 16,  1,  1 }, {     17,   16,    6, 16,  1,  1 }, {     18,   16,    7, 16,  1,  1 }, {     19,   16,    7, 16,  1,  1 },
    {     20,   16,    7, 16,  1,  1 }, {     21,   16,    7, 16,  1,  1 }, {     22,   16,    7, 16,  0,  2 }, {     23,   16,    7, 16,  0,  2 }, {     24,   16,    8, 16,  0,  2 },
    {     25,   16,    8, 16,  0,  2 }, {     26,   16,    8, 16,  0,  2 }, {     27,   16,    8, 16,  0,  2 }, {     28,   16,    8, 16,  0,  2 }, {     29,   16,    8, 16,  0,  2 },
    {     30,   16,    8, 16,  0,  2 }, {     31,   16,    8, 16,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C540E, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    0, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    1, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    2, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    3, 24,  2,  0 }, {     16,   23,    4, 24,  1,  1 }, {     16,   22,    4, 24,  1,  1 },
    {     16,   21,    4, 24,  1,  1 }, {     16,   20,    5, 24,  1,  1 }, {     16,   19,    5, 24,  1,  1 }, {     16,   18,    5, 24,  1,  1 }, {     16,   17,    6, 24,  1,  1 },
    {     16,   16,    6, 24,  1,  1 }, {     16,   15,    6, 24,  1,  1 }, {     16,   14,    6, 24,  1,  1 }, {     16,   13,    7, 24,  1,  1 }, {     16,   12,    7, 24,  1,  1 },
    {     16,   11,    7, 24,  1,  1 }, {     16,   10,    7, 24,  1,  1 }, {     16,    9,    7, 24,  0,  2 }, {     16,    8,    7, 24,  0,  2 }, {     16,    7,    8, 24,  0,  2 },
    {     16,    6,    8, 24,  0,  2 }, {     16,    5,    8, 24,  0,  2 }, {     16,    4,    8, 24,  0,  2 }, {     16,    3,    8, 24,  0,  2 }, {     16,    2,    8, 24,  0,  2 },
    {     16,    1,    8, 24,  0,  2 }, {     16,    0,    8, 24,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C5542, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    0,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    1,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    2,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    3,  0,  2,  0 }, {     23,   16,    4,  0,  1,  3 }, {     22,   16,    4,  0,  1,  3 },
    {     21,   16,    4,  0,  1,  3 }, {     20,   16,    5,  0,  1,  3 }, {     19,   16,    5,  0,  1,  3 }, {     18,   16,    5,  0,  1,  3 }, {     17,   16,    6,  0,  1,  3 },
    {     16,   16,    6,  0,  1,  3 }, {     15,   16,    6,  0,  1,  3 }, {     14,   16,    6,  0,  1,  3 }, {     13,   16,    7,  0,  1,  3 }, {     12,   16,    7,  0,  1,  3 },
    {     11,   16,    7,  0,  1,  3 }, {     10,   16,    7,  0,  1,  3 }, {      9,   16,    7,  0,  0,  4 }, {      8,   16,    7,  0,  0,  4 }, {      7,   16,    8,  0,  0,  4 },
    {      6,   16,    8,  0,  0,  4 }, {      5,   16,    8,  0,  0,  4 }, {      4,   16,    8,  0,  0,  4 }, {      3,   16,    8,  0,  0,  4 }, {      2,   16,    8,  0,  0,  4 },
    {      1,   16,    8,  0,  0,  4 }, {      0,   16,    8,  0,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C5676, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    2,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    3,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    4,  8,  1,  3 }, {     16,    9,    4,  8,  1,  3 },
    {     16,   10,    4,  8,  1,  3 }, {     16,   11,    5,  8,  1,  3 }, {     16,   12,    5,  8,  1,  3 }, {     16,   13,    5,  8,  1,  3 }, {     16,   14,    6,  8,  1,  3 },
    {     16,   15,    6,  8,  1,  3 }, {     16,   16,    6,  8,  1,  3 }, {     16,   17,    6,  8,  1,  3 }, {     16,   18,    7,  8,  1,  3 }, {     16,   19,    7,  8,  1,  3 },
    {     16,   20,    7,  8,  1,  3 }, {     16,   21,    7,  8,  1,  3 }, {     16,   22,    7,  8,  0,  4 }, {     16,   23,    7,  8,  0,  4 }, {     16,   24,    8,  8,  0,  4 },
    {     16,   25,    8,  8,  0,  4 }, {     16,   26,    8,  8,  0,  4 }, {     16,   27,    8,  8,  0,  4 }, {     16,   28,    8,  8,  0,  4 }, {     16,   29,    8,  8,  0,  4 },
    {     16,   30,    8,  8,  0,  4 }, {     16,   31,    8,  8,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C57AA, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    2, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    3, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    4, 16,  1,  3 }, {      9,   16,    4, 16,  1,  3 },
    {     10,   16,    4, 16,  1,  3 }, {     11,   16,    5, 16,  1,  3 }, {     12,   16,    5, 16,  1,  3 }, {     13,   16,    5, 16,  1,  3 }, {     14,   16,    6, 16,  1,  3 },
    {     15,   16,    6, 16,  1,  3 }, {     16,   16,    6, 16,  1,  3 }, {     17,   16,    6, 16,  1,  3 }, {     18,   16,    7, 16,  1,  3 }, {     19,   16,    7, 16,  1,  3 },
    {     20,   16,    7, 16,  1,  3 }, {     21,   16,    7, 16,  1,  3 }, {     22,   16,    7, 16,  0,  4 }, {     23,   16,    7, 16,  0,  4 }, {     24,   16,    8, 16,  0,  4 },
    {     25,   16,    8, 16,  0,  4 }, {     26,   16,    8, 16,  0,  4 }, {     27,   16,    8, 16,  0,  4 }, {     28,   16,    8, 16,  0,  4 }, {     29,   16,    8, 16,  0,  4 },
    {     30,   16,    8, 16,  0,  4 }, {     31,   16,    8, 16,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C58DE, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    0, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    1, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    2, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    3, 24,  2,  0 }, {     16,   23,    4, 24,  1,  3 }, {     16,   22,    4, 24,  1,  3 },
    {     16,   21,    4, 24,  1,  3 }, {     16,   20,    5, 24,  1,  3 }, {     16,   19,    5, 24,  1,  3 }, {     16,   18,    5, 24,  1,  3 }, {     16,   17,    6, 24,  1,  3 },
    {     16,   16,    6, 24,  1,  3 }, {     16,   15,    6, 24,  1,  3 }, {     16,   14,    6, 24,  1,  3 }, {     16,   13,    7, 24,  1,  3 }, {     16,   12,    7, 24,  1,  3 },
    {     16,   11,    7, 24,  1,  3 }, {     16,   10,    7, 24,  1,  3 }, {     16,    9,    7, 24,  0,  4 }, {     16,    8,    7, 24,  0,  4 }, {     16,    7,    8, 24,  0,  4 },
    {     16,    6,    8, 24,  0,  4 }, {     16,    5,    8, 24,  0,  4 }, {     16,    4,    8, 24,  0,  4 }, {     16,    3,    8, 24,  0,  4 }, {     16,    2,    8, 24,  0,  4 },
    {     16,    1,    8, 24,  0,  4 }, {     16,    0,    8, 24,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C6322, {
    {     31,   16,    8,  0,  0,  2 }, {     30,   16,    8,  0,  0,  2 }, {     29,   16,    8,  0,  0,  2 }, {     28,   16,    8,  0,  0,  2 }, {     27,   16,    8,  0,  0,  2 },
    {     26,   16,    8,  0,  0,  2 }, {     25,   16,    8,  0,  0,  2 }, {     24,   16,    8,  0,  0,  2 }, {     23,   16,    7,  0,  5,  1 }, {     22,   16,    7,  0,  5,  1 },
    {     21,   16,    7,  0,  5,  1 }, {     20,   16,    7,  0,  5,  1 }, {     19,   16,    7,  0,  5,  1 }, {     18,   16,    7,  0,  5,  1 }, {     17,   16,    6,  0,  5,  1 },
    {     16,   16,    6,  0,  5,  1 }, {     15,   16,    6,  0,  5,  1 }, {     14,   16,    6,  0,  5,  1 }, {     13,   16,    5,  0,  5,  1 }, {     12,   16,    5,  0,  5,  1 },
    {     11,   16,    5,  0,  5,  1 }, {     10,   16,    4,  0,  5,  1 }, {      9,   16,    4,  0,  5,  1 }, {      8,   16,    4,  0,  5,  1 }, {      7,   16,    3,  0,  6,  0 },
    {      6,   16,    3,  0,  6,  0 }, {      5,   16,    2,  0,  6,  0 }, {      4,   16,    2,  0,  6,  0 }, {      3,   16,    1,  0,  6,  0 }, {      2,   16,    1,  0,  6,  0 },
    {      1,   16,    0,  0,  6,  0 }, {      0,   16,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C6444, {
    {     16,    0,    8,  8,  0,  2 }, {     16,    1,    8,  8,  0,  2 }, {     16,    2,    8,  8,  0,  2 }, {     16,    3,    8,  8,  0,  2 }, {     16,    4,    8,  8,  0,  2 },
    {     16,    5,    8,  8,  0,  2 }, {     16,    6,    8,  8,  0,  2 }, {     16,    7,    8,  8,  0,  2 }, {     16,    8,    7,  8,  5,  1 }, {     16,    9,    7,  8,  5,  1 },
    {     16,   10,    7,  8,  5,  1 }, {     16,   11,    7,  8,  5,  1 }, {     16,   12,    7,  8,  5,  1 }, {     16,   13,    7,  8,  5,  1 }, {     16,   14,    6,  8,  5,  1 },
    {     16,   15,    6,  8,  5,  1 }, {     16,   16,    6,  8,  5,  1 }, {     16,   17,    6,  8,  5,  1 }, {     16,   18,    5,  8,  5,  1 }, {     16,   19,    5,  8,  5,  1 },
    {     16,   20,    5,  8,  5,  1 }, {     16,   21,    4,  8,  5,  1 }, {     16,   22,    4,  8,  5,  1 }, {     16,   23,    4,  8,  5,  1 }, {     16,   24,    3,  8,  6,  0 },
    {     16,   25,    3,  8,  6,  0 }, {     16,   26,    2,  8,  6,  0 }, {     16,   27,    2,  8,  6,  0 }, {     16,   28,    1,  8,  6,  0 }, {     16,   29,    1,  8,  6,  0 },
    {     16,   30,    0,  8,  6,  0 }, {     16,   31,    0,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C6566, {
    {      0,   16,    8, 16,  0,  2 }, {      1,   16,    8, 16,  0,  2 }, {      2,   16,    8, 16,  0,  2 }, {      3,   16,    8, 16,  0,  2 }, {      4,   16,    8, 16,  0,  2 },
    {      5,   16,    8, 16,  0,  2 }, {      6,   16,    8, 16,  0,  2 }, {      7,   16,    8, 16,  0,  2 }, {      8,   16,    7, 16,  5,  1 }, {      9,   16,    7, 16,  5,  1 },
    {     10,   16,    7, 16,  5,  1 }, {     11,   16,    7, 16,  5,  1 }, {     12,   16,    7, 16,  5,  1 }, {     13,   16,    7, 16,  5,  1 }, {     14,   16,    6, 16,  5,  1 },
    {     15,   16,    6, 16,  5,  1 }, {     16,   16,    6, 16,  5,  1 }, {     17,   16,    6, 16,  5,  1 }, {     18,   16,    5, 16,  5,  1 }, {     19,   16,    5, 16,  5,  1 },
    {     20,   16,    5, 16,  5,  1 }, {     21,   16,    4, 16,  5,  1 }, {     22,   16,    4, 16,  5,  1 }, {     23,   16,    4, 16,  5,  1 }, {     24,   16,    3, 16,  6,  0 },
    {     25,   16,    3, 16,  6,  0 }, {     26,   16,    2, 16,  6,  0 }, {     27,   16,    2, 16,  6,  0 }, {     28,   16,    1, 16,  6,  0 }, {     29,   16,    1, 16,  6,  0 },
    {     30,   16,    0, 16,  6,  0 }, {     31,   16,    0, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C6688, {
    {     16,   31,    8, 24,  0,  2 }, {     16,   30,    8, 24,  0,  2 }, {     16,   29,    8, 24,  0,  2 }, {     16,   28,    8, 24,  0,  2 }, {     16,   27,    8, 24,  0,  2 },
    {     16,   26,    8, 24,  0,  2 }, {     16,   25,    8, 24,  0,  2 }, {     16,   24,    8, 24,  0,  2 }, {     16,   23,    7, 24,  5,  1 }, {     16,   22,    7, 24,  5,  1 },
    {     16,   21,    7, 24,  5,  1 }, {     16,   20,    7, 24,  5,  1 }, {     16,   19,    7, 24,  5,  1 }, {     16,   18,    7, 24,  5,  1 }, {     16,   17,    6, 24,  5,  1 },
    {     16,   16,    6, 24,  5,  1 }, {     16,   15,    6, 24,  5,  1 }, {     16,   14,    6, 24,  5,  1 }, {     16,   13,    5, 24,  5,  1 }, {     16,   12,    5, 24,  5,  1 },
    {     16,   11,    5, 24,  5,  1 }, {     16,   10,    4, 24,  5,  1 }, {     16,    9,    4, 24,  5,  1 }, {     16,    8,    4, 24,  5,  1 }, {     16,    7,    3, 24,  6,  0 },
    {     16,    6,    3, 24,  6,  0 }, {     16,    5,    2, 24,  6,  0 }, {     16,    4,    2, 24,  6,  0 }, {     16,    3,    1, 24,  6,  0 }, {     16,    2,    1, 24,  6,  0 },
    {     16,    1,    0, 24,  6,  0 }, {     16,    0,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C67AA, {
    {     31,   16,    8,  0,  0,  4 }, {     30,   16,    8,  0,  0,  4 }, {     29,   16,    8,  0,  0,  4 }, {     28,   16,    8,  0,  0,  4 }, {     27,   16,    8,  0,  0,  4 },
    {     26,   16,    8,  0,  0,  4 }, {     25,   16,    8,  0,  0,  4 }, {     24,   16,    8,  0,  0,  4 }, {     23,   16,    7,  0,  5,  3 }, {     22,   16,    7,  0,  5,  3 },
    {     21,   16,    7,  0,  5,  3 }, {     20,   16,    7,  0,  5,  3 }, {     19,   16,    7,  0,  5,  3 }, {     18,   16,    7,  0,  5,  3 }, {     17,   16,    6,  0,  5,  3 },
    {     16,   16,    6,  0,  5,  3 }, {     15,   16,    6,  0,  5,  3 }, {     14,   16,    6,  0,  5,  3 }, {     13,   16,    5,  0,  5,  3 }, {     12,   16,    5,  0,  5,  3 },
    {     11,   16,    5,  0,  5,  3 }, {     10,   16,    4,  0,  5,  3 }, {      9,   16,    4,  0,  5,  3 }, {      8,   16,    4,  0,  5,  3 }, {      7,   16,    3,  0,  6,  0 },
    {      6,   16,    3,  0,  6,  0 }, {      5,   16,    2,  0,  6,  0 }, {      4,   16,    2,  0,  6,  0 }, {      3,   16,    1,  0,  6,  0 }, {      2,   16,    1,  0,  6,  0 },
    {      1,   16,    0,  0,  6,  0 }, {      0,   16,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C68CC, {
    {     16,    0,    8,  8,  0,  4 }, {     16,    1,    8,  8,  0,  4 }, {     16,    2,    8,  8,  0,  4 }, {     16,    3,    8,  8,  0,  4 }, {     16,    4,    8,  8,  0,  4 },
    {     16,    5,    8,  8,  0,  4 }, {     16,    6,    8,  8,  0,  4 }, {     16,    7,    8,  8,  0,  4 }, {     16,    8,    7,  8,  5,  3 }, {     16,    9,    7,  8,  5,  3 },
    {     16,   10,    7,  8,  5,  3 }, {     16,   11,    7,  8,  5,  3 }, {     16,   12,    7,  8,  5,  3 }, {     16,   13,    7,  8,  5,  3 }, {     16,   14,    6,  8,  5,  3 },
    {     16,   15,    6,  8,  5,  3 }, {     16,   16,    6,  8,  5,  3 }, {     16,   17,    6,  8,  5,  3 }, {     16,   18,    5,  8,  5,  3 }, {     16,   19,    5,  8,  5,  3 },
    {     16,   20,    5,  8,  5,  3 }, {     16,   21,    4,  8,  5,  3 }, {     16,   22,    4,  8,  5,  3 }, {     16,   23,    4,  8,  5,  3 }, {     16,   24,    3,  8,  6,  0 },
    {     16,   25,    3,  8,  6,  0 }, {     16,   26,    2,  8,  6,  0 }, {     16,   27,    2,  8,  6,  0 }, {     16,   28,    1,  8,  6,  0 }, {     16,   29,    1,  8,  6,  0 },
    {     16,   30,    0,  8,  6,  0 }, {     16,   31,    0,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C69EE, {
    {      0,   16,    8, 16,  0,  4 }, {      1,   16,    8, 16,  0,  4 }, {      2,   16,    8, 16,  0,  4 }, {      3,   16,    8, 16,  0,  4 }, {      4,   16,    8, 16,  0,  4 },
    {      5,   16,    8, 16,  0,  4 }, {      6,   16,    8, 16,  0,  4 }, {      7,   16,    8, 16,  0,  4 }, {      8,   16,    7, 16,  5,  3 }, {      9,   16,    7, 16,  5,  3 },
    {     10,   16,    7, 16,  5,  3 }, {     11,   16,    7, 16,  5,  3 }, {     12,   16,    7, 16,  5,  3 }, {     13,   16,    7, 16,  5,  3 }, {     14,   16,    6, 16,  5,  3 },
    {     15,   16,    6, 16,  5,  3 }, {     16,   16,    6, 16,  5,  3 }, {     17,   16,    6, 16,  5,  3 }, {     18,   16,    5, 16,  5,  3 }, {     19,   16,    5, 16,  5,  3 },
    {     20,   16,    5, 16,  5,  3 }, {     21,   16,    4, 16,  5,  3 }, {     22,   16,    4, 16,  5,  3 }, {     23,   16,    4, 16,  5,  3 }, {     24,   16,    3, 16,  6,  0 },
    {     25,   16,    3, 16,  6,  0 }, {     26,   16,    2, 16,  6,  0 }, {     27,   16,    2, 16,  6,  0 }, {     28,   16,    1, 16,  6,  0 }, {     29,   16,    1, 16,  6,  0 },
    {     30,   16,    0, 16,  6,  0 }, {     31,   16,    0, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C6B10, {
    {     16,   31,    8, 24,  0,  4 }, {     16,   30,    8, 24,  0,  4 }, {     16,   29,    8, 24,  0,  4 }, {     16,   28,    8, 24,  0,  4 }, {     16,   27,    8, 24,  0,  4 },
    {     16,   26,    8, 24,  0,  4 }, {     16,   25,    8, 24,  0,  4 }, {     16,   24,    8, 24,  0,  4 }, {     16,   23,    7, 24,  5,  3 }, {     16,   22,    7, 24,  5,  3 },
    {     16,   21,    7, 24,  5,  3 }, {     16,   20,    7, 24,  5,  3 }, {     16,   19,    7, 24,  5,  3 }, {     16,   18,    7, 24,  5,  3 }, {     16,   17,    6, 24,  5,  3 },
    {     16,   16,    6, 24,  5,  3 }, {     16,   15,    6, 24,  5,  3 }, {     16,   14,    6, 24,  5,  3 }, {     16,   13,    5, 24,  5,  3 }, {     16,   12,    5, 24,  5,  3 },
    {     16,   11,    5, 24,  5,  3 }, {     16,   10,    4, 24,  5,  3 }, {     16,    9,    4, 24,  5,  3 }, {     16,    8,    4, 24,  5,  3 }, {     16,    7,    3, 24,  6,  0 },
    {     16,    6,    3, 24,  6,  0 }, {     16,    5,    2, 24,  6,  0 }, {     16,    4,    2, 24,  6,  0 }, {     16,    3,    1, 24,  6,  0 }, {     16,    2,    1, 24,  6,  0 },
    {     16,    1,    0, 24,  6,  0 }, {     16,    0,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C5A12, {
    {     31,   16,    7,  0,  6,  0 }, {     30,   16,    7,  0,  6,  0 }, {     29,   16,    6,  0,  6,  0 }, {     28,   16,    6,  0,  6,  0 }, {     27,   16,    5,  0,  6,  0 },
    {     26,   16,    5,  0,  6,  0 }, {     25,   16,    4,  0,  6,  0 }, {     24,   16,    4,  0,  6,  0 }, {     23,   16,    4,  0,  5,  1 }, {     22,   16,    3,  0,  5,  1 },
    {     21,   16,    3,  0,  5,  1 }, {     20,   16,    3,  0,  5,  1 }, {     19,   16,    2,  0,  5,  1 }, {     18,   16,    2,  0,  5,  1 }, {     17,   16,    2,  0,  5,  1 },
    {     16,   16,    2,  0,  5,  1 }, {     15,   16,    1,  0,  5,  1 }, {     14,   16,    1,  0,  5,  1 }, {     13,   16,    1,  0,  5,  1 }, {     12,   16,    1,  0,  5,  1 },
    {     11,   16,    1,  0,  5,  1 }, {     10,   16,    1,  0,  5,  1 }, {      9,   16,    0,  0,  0,  2 }, {      8,   16,    0,  0,  0,  2 }, {      7,   16,    0,  0,  0,  2 },
    {      6,   16,    0,  0,  0,  2 }, {      5,   16,    0,  0,  0,  2 }, {      4,   16,    0,  0,  0,  2 }, {      3,   16,    0,  0,  0,  2 }, {      2,   16,    0,  0,  0,  2 },
    {      1,   16,    0,  0,  0,  2 }, {      0,   16,    0,  0,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C5B34, {
    {     16,    0,    7,  8,  6,  0 }, {     16,    1,    7,  8,  6,  0 }, {     16,    2,    6,  8,  6,  0 }, {     16,    3,    6,  8,  6,  0 }, {     16,    4,    5,  8,  6,  0 },
    {     16,    5,    5,  8,  6,  0 }, {     16,    6,    4,  8,  6,  0 }, {     16,    7,    4,  8,  6,  0 }, {     16,    8,    4,  8,  5,  1 }, {     16,    9,    3,  8,  5,  1 },
    {     16,   10,    3,  8,  5,  1 }, {     16,   11,    3,  8,  5,  1 }, {     16,   12,    2,  8,  5,  1 }, {     16,   13,    2,  8,  5,  1 }, {     16,   14,    2,  8,  5,  1 },
    {     16,   15,    2,  8,  5,  1 }, {     16,   16,    1,  8,  5,  1 }, {     16,   17,    1,  8,  5,  1 }, {     16,   18,    1,  8,  5,  1 }, {     16,   19,    1,  8,  5,  1 },
    {     16,   20,    1,  8,  5,  1 }, {     16,   21,    1,  8,  5,  1 }, {     16,   22,    0,  8,  0,  2 }, {     16,   23,    0,  8,  0,  2 }, {     16,   24,    0,  8,  0,  2 },
    {     16,   25,    0,  8,  0,  2 }, {     16,   26,    0,  8,  0,  2 }, {     16,   27,    0,  8,  0,  2 }, {     16,   28,    0,  8,  0,  2 }, {     16,   29,    0,  8,  0,  2 },
    {     16,   30,    0,  8,  0,  2 }, {     16,   31,    0,  8,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C5C56, {
    {      0,   16,    7, 16,  6,  0 }, {      1,   16,    7, 16,  6,  0 }, {      2,   16,    6, 16,  6,  0 }, {      3,   16,    6, 16,  6,  0 }, {      4,   16,    5, 16,  6,  0 },
    {      5,   16,    5, 16,  6,  0 }, {      6,   16,    4, 16,  6,  0 }, {      7,   16,    4, 16,  6,  0 }, {      8,   16,    4, 16,  5,  1 }, {      9,   16,    3, 16,  5,  1 },
    {     10,   16,    3, 16,  5,  1 }, {     11,   16,    3, 16,  5,  1 }, {     12,   16,    2, 16,  5,  1 }, {     13,   16,    2, 16,  5,  1 }, {     14,   16,    2, 16,  5,  1 },
    {     15,   16,    2, 16,  5,  1 }, {     16,   16,    1, 16,  5,  1 }, {     17,   16,    1, 16,  5,  1 }, {     18,   16,    1, 16,  5,  1 }, {     19,   16,    1, 16,  5,  1 },
    {     20,   16,    1, 16,  5,  1 }, {     21,   16,    1, 16,  5,  1 }, {     22,   16,    0, 16,  0,  2 }, {     23,   16,    0, 16,  0,  2 }, {     24,   16,    0, 16,  0,  2 },
    {     25,   16,    0, 16,  0,  2 }, {     26,   16,    0, 16,  0,  2 }, {     27,   16,    0, 16,  0,  2 }, {     28,   16,    0, 16,  0,  2 }, {     29,   16,    0, 16,  0,  2 },
    {     30,   16,    0, 16,  0,  2 }, {     31,   16,    0, 16,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C5D78, {
    {     16,   31,    7, 24,  6,  0 }, {     16,   30,    7, 24,  6,  0 }, {     16,   29,    6, 24,  6,  0 }, {     16,   28,    6, 24,  6,  0 }, {     16,   27,    5, 24,  6,  0 },
    {     16,   26,    5, 24,  6,  0 }, {     16,   25,    4, 24,  6,  0 }, {     16,   24,    4, 24,  6,  0 }, {     16,   23,    4, 24,  5,  1 }, {     16,   22,    3, 24,  5,  1 },
    {     16,   21,    3, 24,  5,  1 }, {     16,   20,    3, 24,  5,  1 }, {     16,   19,    2, 24,  5,  1 }, {     16,   18,    2, 24,  5,  1 }, {     16,   17,    2, 24,  5,  1 },
    {     16,   16,    2, 24,  5,  1 }, {     16,   15,    1, 24,  5,  1 }, {     16,   14,    1, 24,  5,  1 }, {     16,   13,    1, 24,  5,  1 }, {     16,   12,    1, 24,  5,  1 },
    {     16,   11,    1, 24,  5,  1 }, {     16,   10,    1, 24,  5,  1 }, {     16,    9,    0, 24,  0,  2 }, {     16,    8,    0, 24,  0,  2 }, {     16,    7,    0, 24,  0,  2 },
    {     16,    6,    0, 24,  0,  2 }, {     16,    5,    0, 24,  0,  2 }, {     16,    4,    0, 24,  0,  2 }, {     16,    3,    0, 24,  0,  2 }, {     16,    2,    0, 24,  0,  2 },
    {     16,    1,    0, 24,  0,  2 }, {     16,    0,    0, 24,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C5E9A, {
    {     31,   16,    7,  0,  6,  0 }, {     30,   16,    7,  0,  6,  0 }, {     29,   16,    6,  0,  6,  0 }, {     28,   16,    6,  0,  6,  0 }, {     27,   16,    5,  0,  6,  0 },
    {     26,   16,    5,  0,  6,  0 }, {     25,   16,    4,  0,  6,  0 }, {     24,   16,    4,  0,  6,  0 }, {     23,   16,    4,  0,  5,  3 }, {     22,   16,    3,  0,  5,  3 },
    {     21,   16,    3,  0,  5,  3 }, {     20,   16,    3,  0,  5,  3 }, {     19,   16,    2,  0,  5,  3 }, {     18,   16,    2,  0,  5,  3 }, {     17,   16,    2,  0,  5,  3 },
    {     16,   16,    2,  0,  5,  3 }, {     15,   16,    1,  0,  5,  3 }, {     14,   16,    1,  0,  5,  3 }, {     13,   16,    1,  0,  5,  3 }, {     12,   16,    1,  0,  5,  3 },
    {     11,   16,    1,  0,  5,  3 }, {     10,   16,    1,  0,  5,  3 }, {      9,   16,    0,  0,  0,  4 }, {      8,   16,    0,  0,  0,  4 }, {      7,   16,    0,  0,  0,  4 },
    {      6,   16,    0,  0,  0,  4 }, {      5,   16,    0,  0,  0,  4 }, {      4,   16,    0,  0,  0,  4 }, {      3,   16,    0,  0,  0,  4 }, {      2,   16,    0,  0,  0,  4 },
    {      1,   16,    0,  0,  0,  4 }, {      0,   16,    0,  0,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C5FBC, {
    {     16,    0,    7,  8,  6,  0 }, {     16,    1,    7,  8,  6,  0 }, {     16,    2,    6,  8,  6,  0 }, {     16,    3,    6,  8,  6,  0 }, {     16,    4,    5,  8,  6,  0 },
    {     16,    5,    5,  8,  6,  0 }, {     16,    6,    4,  8,  6,  0 }, {     16,    7,    4,  8,  6,  0 }, {     16,    8,    4,  8,  5,  3 }, {     16,    9,    3,  8,  5,  3 },
    {     16,   10,    3,  8,  5,  3 }, {     16,   11,    3,  8,  5,  3 }, {     16,   12,    2,  8,  5,  3 }, {     16,   13,    2,  8,  5,  3 }, {     16,   14,    2,  8,  5,  3 },
    {     16,   15,    2,  8,  5,  3 }, {     16,   16,    1,  8,  5,  3 }, {     16,   17,    1,  8,  5,  3 }, {     16,   18,    1,  8,  5,  3 }, {     16,   19,    1,  8,  5,  3 },
    {     16,   20,    1,  8,  5,  3 }, {     16,   21,    1,  8,  5,  3 }, {     16,   22,    0,  8,  0,  4 }, {     16,   23,    0,  8,  0,  4 }, {     16,   24,    0,  8,  0,  4 },
    {     16,   25,    0,  8,  0,  4 }, {     16,   26,    0,  8,  0,  4 }, {     16,   27,    0,  8,  0,  4 }, {     16,   28,    0,  8,  0,  4 }, {     16,   29,    0,  8,  0,  4 },
    {     16,   30,    0,  8,  0,  4 }, {     16,   31,    0,  8,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C60DE, {
    {      0,   16,    7, 16,  6,  0 }, {      1,   16,    7, 16,  6,  0 }, {      2,   16,    6, 16,  6,  0 }, {      3,   16,    6, 16,  6,  0 }, {      4,   16,    5, 16,  6,  0 },
    {      5,   16,    5, 16,  6,  0 }, {      6,   16,    4, 16,  6,  0 }, {      7,   16,    4, 16,  6,  0 }, {      8,   16,    4, 16,  5,  3 }, {      9,   16,    3, 16,  5,  3 },
    {     10,   16,    3, 16,  5,  3 }, {     11,   16,    3, 16,  5,  3 }, {     12,   16,    2, 16,  5,  3 }, {     13,   16,    2, 16,  5,  3 }, {     14,   16,    2, 16,  5,  3 },
    {     15,   16,    2, 16,  5,  3 }, {     16,   16,    1, 16,  5,  3 }, {     17,   16,    1, 16,  5,  3 }, {     18,   16,    1, 16,  5,  3 }, {     19,   16,    1, 16,  5,  3 },
    {     20,   16,    1, 16,  5,  3 }, {     21,   16,    1, 16,  5,  3 }, {     22,   16,    0, 16,  0,  4 }, {     23,   16,    0, 16,  0,  4 }, {     24,   16,    0, 16,  0,  4 },
    {     25,   16,    0, 16,  0,  4 }, {     26,   16,    0, 16,  0,  4 }, {     27,   16,    0, 16,  0,  4 }, {     28,   16,    0, 16,  0,  4 }, {     29,   16,    0, 16,  0,  4 },
    {     30,   16,    0, 16,  0,  4 }, {     31,   16,    0, 16,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C6200, {
    {     16,   31,    7, 24,  6,  0 }, {     16,   30,    7, 24,  6,  0 }, {     16,   29,    6, 24,  6,  0 }, {     16,   28,    6, 24,  6,  0 }, {     16,   27,    5, 24,  6,  0 },
    {     16,   26,    5, 24,  6,  0 }, {     16,   25,    4, 24,  6,  0 }, {     16,   24,    4, 24,  6,  0 }, {     16,   23,    4, 24,  5,  3 }, {     16,   22,    3, 24,  5,  3 },
    {     16,   21,    3, 24,  5,  3 }, {     16,   20,    3, 24,  5,  3 }, {     16,   19,    2, 24,  5,  3 }, {     16,   18,    2, 24,  5,  3 }, {     16,   17,    2, 24,  5,  3 },
    {     16,   16,    2, 24,  5,  3 }, {     16,   15,    1, 24,  5,  3 }, {     16,   14,    1, 24,  5,  3 }, {     16,   13,    1, 24,  5,  3 }, {     16,   12,    1, 24,  5,  3 },
    {     16,   11,    1, 24,  5,  3 }, {     16,   10,    1, 24,  5,  3 }, {     16,    9,    0, 24,  0,  4 }, {     16,    8,    0, 24,  0,  4 }, {     16,    7,    0, 24,  0,  4 },
    {     16,    6,    0, 24,  0,  4 }, {     16,    5,    0, 24,  0,  4 }, {     16,    4,    0, 24,  0,  4 }, {     16,    3,    0, 24,  0,  4 }, {     16,    2,    0, 24,  0,  4 },
    {     16,    1,    0, 24,  0,  4 }, {     16,    0,    0, 24,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BEA02, {
    {     31,   16,    0,  0,  0,  2 }, {     30,   16,    0,  0,  0,  2 }, {     29,   16,    0,  0,  0,  2 }, {     28,   16,    0,  0,  0,  2 }, {     27,   16,    0,  0,  0,  2 },
    {     26,   16,    0,  0,  0,  2 }, {     25,   16,    0,  0,  0,  2 }, {     24,   16,    0,  0,  0,  2 }, {     23,   16,    0,  0,  0,  2 }, {     22,   16,    0,  0,  0,  2 },
    {     21,   16,    0,  0,  0,  2 }, {     20,   16,    0,  0,  0,  2 }, {     19,   16,    0,  0,  0,  2 }, {     18,   16,    0,  0,  0,  2 }, {     17,   16,    0,  0,  0,  2 },
    {     16,   16,    0,  0,  0,  2 }, {     15,   16,    0,  0,  0,  2 }, {     14,   16,    0,  0,  0,  2 }, {     13,   16,    0,  0,  0,  2 }, {     12,   16,    0,  0,  0,  2 },
    {     11,   16,    0,  0,  0,  2 }, {     10,   16,    0,  0,  0,  2 }, {      9,   16,    0,  0,  0,  2 }, {      8,   16,    0,  0,  0,  2 }, {      7,   16,    0,  0,  0,  2 },
    {      6,   16,    0,  0,  0,  2 }, {      5,   16,    0,  0,  0,  2 }, {      4,   16,    0,  0,  0,  2 }, {      3,   16,    0,  0,  0,  2 }, {      2,   16,    0,  0,  0,  2 },
    {      1,   16,    0,  0,  0,  2 }, {      0,   16,    0,  0,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BEB24, {
    {     16,    0,    0,  8,  0,  2 }, {     16,    1,    0,  8,  0,  2 }, {     16,    2,    0,  8,  0,  2 }, {     16,    3,    0,  8,  0,  2 }, {     16,    4,    0,  8,  0,  2 },
    {     16,    5,    0,  8,  0,  2 }, {     16,    6,    0,  8,  0,  2 }, {     16,    7,    0,  8,  0,  2 }, {     16,    8,    0,  8,  0,  2 }, {     16,    9,    0,  8,  0,  2 },
    {     16,   10,    0,  8,  0,  2 }, {     16,   11,    0,  8,  0,  2 }, {     16,   12,    0,  8,  0,  2 }, {     16,   13,    0,  8,  0,  2 }, {     16,   14,    0,  8,  0,  2 },
    {     16,   15,    0,  8,  0,  2 }, {     16,   16,    0,  8,  0,  2 }, {     16,   17,    0,  8,  0,  2 }, {     16,   18,    0,  8,  0,  2 }, {     16,   19,    0,  8,  0,  2 },
    {     16,   20,    0,  8,  0,  2 }, {     16,   21,    0,  8,  0,  2 }, {     16,   22,    0,  8,  0,  2 }, {     16,   23,    0,  8,  0,  2 }, {     16,   24,    0,  8,  0,  2 },
    {     16,   25,    0,  8,  0,  2 }, {     16,   26,    0,  8,  0,  2 }, {     16,   27,    0,  8,  0,  2 }, {     16,   28,    0,  8,  0,  2 }, {     16,   29,    0,  8,  0,  2 },
    {     16,   30,    0,  8,  0,  2 }, {     16,   31,    0,  8,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BEC46, {
    {      0,   16,    0, 16,  0,  2 }, {      1,   16,    0, 16,  0,  2 }, {      2,   16,    0, 16,  0,  2 }, {      3,   16,    0, 16,  0,  2 }, {      4,   16,    0, 16,  0,  2 },
    {      5,   16,    0, 16,  0,  2 }, {      6,   16,    0, 16,  0,  2 }, {      7,   16,    0, 16,  0,  2 }, {      8,   16,    0, 16,  0,  2 }, {      9,   16,    0, 16,  0,  2 },
    {     10,   16,    0, 16,  0,  2 }, {     11,   16,    0, 16,  0,  2 }, {     12,   16,    0, 16,  0,  2 }, {     13,   16,    0, 16,  0,  2 }, {     14,   16,    0, 16,  0,  2 },
    {     15,   16,    0, 16,  0,  2 }, {     16,   16,    0, 16,  0,  2 }, {     17,   16,    0, 16,  0,  2 }, {     18,   16,    0, 16,  0,  2 }, {     19,   16,    0, 16,  0,  2 },
    {     20,   16,    0, 16,  0,  2 }, {     21,   16,    0, 16,  0,  2 }, {     22,   16,    0, 16,  0,  2 }, {     23,   16,    0, 16,  0,  2 }, {     24,   16,    0, 16,  0,  2 },
    {     25,   16,    0, 16,  0,  2 }, {     26,   16,    0, 16,  0,  2 }, {     27,   16,    0, 16,  0,  2 }, {     28,   16,    0, 16,  0,  2 }, {     29,   16,    0, 16,  0,  2 },
    {     30,   16,    0, 16,  0,  2 }, {     31,   16,    0, 16,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BED68, {
    {     16,   31,    0, 24,  0,  2 }, {     16,   30,    0, 24,  0,  2 }, {     16,   29,    0, 24,  0,  2 }, {     16,   28,    0, 24,  0,  2 }, {     16,   27,    0, 24,  0,  2 },
    {     16,   26,    0, 24,  0,  2 }, {     16,   25,    0, 24,  0,  2 }, {     16,   24,    0, 24,  0,  2 }, {     16,   23,    0, 24,  0,  2 }, {     16,   22,    0, 24,  0,  2 },
    {     16,   21,    0, 24,  0,  2 }, {     16,   20,    0, 24,  0,  2 }, {     16,   19,    0, 24,  0,  2 }, {     16,   18,    0, 24,  0,  2 }, {     16,   17,    0, 24,  0,  2 },
    {     16,   16,    0, 24,  0,  2 }, {     16,   15,    0, 24,  0,  2 }, {     16,   14,    0, 24,  0,  2 }, {     16,   13,    0, 24,  0,  2 }, {     16,   12,    0, 24,  0,  2 },
    {     16,   11,    0, 24,  0,  2 }, {     16,   10,    0, 24,  0,  2 }, {     16,    9,    0, 24,  0,  2 }, {     16,    8,    0, 24,  0,  2 }, {     16,    7,    0, 24,  0,  2 },
    {     16,    6,    0, 24,  0,  2 }, {     16,    5,    0, 24,  0,  2 }, {     16,    4,    0, 24,  0,  2 }, {     16,    3,    0, 24,  0,  2 }, {     16,    2,    0, 24,  0,  2 },
    {     16,    1,    0, 24,  0,  2 }, {     16,    0,    0, 24,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BEE8A, {
    {     31,   16,    0,  0,  0,  4 }, {     30,   16,    0,  0,  0,  4 }, {     29,   16,    0,  0,  0,  4 }, {     28,   16,    0,  0,  0,  4 }, {     27,   16,    0,  0,  0,  4 },
    {     26,   16,    0,  0,  0,  4 }, {     25,   16,    0,  0,  0,  4 }, {     24,   16,    0,  0,  0,  4 }, {     23,   16,    0,  0,  0,  4 }, {     22,   16,    0,  0,  0,  4 },
    {     21,   16,    0,  0,  0,  4 }, {     20,   16,    0,  0,  0,  4 }, {     19,   16,    0,  0,  0,  4 }, {     18,   16,    0,  0,  0,  4 }, {     17,   16,    0,  0,  0,  4 },
    {     16,   16,    0,  0,  0,  4 }, {     15,   16,    0,  0,  0,  4 }, {     14,   16,    0,  0,  0,  4 }, {     13,   16,    0,  0,  0,  4 }, {     12,   16,    0,  0,  0,  4 },
    {     11,   16,    0,  0,  0,  4 }, {     10,   16,    0,  0,  0,  4 }, {      9,   16,    0,  0,  0,  4 }, {      8,   16,    0,  0,  0,  4 }, {      7,   16,    0,  0,  0,  4 },
    {      6,   16,    0,  0,  0,  4 }, {      5,   16,    0,  0,  0,  4 }, {      4,   16,    0,  0,  0,  4 }, {      3,   16,    0,  0,  0,  4 }, {      2,   16,    0,  0,  0,  4 },
    {      1,   16,    0,  0,  0,  4 }, {      0,   16,    0,  0,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BEFAC, {
    {     16,    0,    0,  8,  0,  4 }, {     16,    1,    0,  8,  0,  4 }, {     16,    2,    0,  8,  0,  4 }, {     16,    3,    0,  8,  0,  4 }, {     16,    4,    0,  8,  0,  4 },
    {     16,    5,    0,  8,  0,  4 }, {     16,    6,    0,  8,  0,  4 }, {     16,    7,    0,  8,  0,  4 }, {     16,    8,    0,  8,  0,  4 }, {     16,    9,    0,  8,  0,  4 },
    {     16,   10,    0,  8,  0,  4 }, {     16,   11,    0,  8,  0,  4 }, {     16,   12,    0,  8,  0,  4 }, {     16,   13,    0,  8,  0,  4 }, {     16,   14,    0,  8,  0,  4 },
    {     16,   15,    0,  8,  0,  4 }, {     16,   16,    0,  8,  0,  4 }, {     16,   17,    0,  8,  0,  4 }, {     16,   18,    0,  8,  0,  4 }, {     16,   19,    0,  8,  0,  4 },
    {     16,   20,    0,  8,  0,  4 }, {     16,   21,    0,  8,  0,  4 }, {     16,   22,    0,  8,  0,  4 }, {     16,   23,    0,  8,  0,  4 }, {     16,   24,    0,  8,  0,  4 },
    {     16,   25,    0,  8,  0,  4 }, {     16,   26,    0,  8,  0,  4 }, {     16,   27,    0,  8,  0,  4 }, {     16,   28,    0,  8,  0,  4 }, {     16,   29,    0,  8,  0,  4 },
    {     16,   30,    0,  8,  0,  4 }, {     16,   31,    0,  8,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BF0CE, {
    {      0,   16,    0, 16,  0,  4 }, {      1,   16,    0, 16,  0,  4 }, {      2,   16,    0, 16,  0,  4 }, {      3,   16,    0, 16,  0,  4 }, {      4,   16,    0, 16,  0,  4 },
    {      5,   16,    0, 16,  0,  4 }, {      6,   16,    0, 16,  0,  4 }, {      7,   16,    0, 16,  0,  4 }, {      8,   16,    0, 16,  0,  4 }, {      9,   16,    0, 16,  0,  4 },
    {     10,   16,    0, 16,  0,  4 }, {     11,   16,    0, 16,  0,  4 }, {     12,   16,    0, 16,  0,  4 }, {     13,   16,    0, 16,  0,  4 }, {     14,   16,    0, 16,  0,  4 },
    {     15,   16,    0, 16,  0,  4 }, {     16,   16,    0, 16,  0,  4 }, {     17,   16,    0, 16,  0,  4 }, {     18,   16,    0, 16,  0,  4 }, {     19,   16,    0, 16,  0,  4 },
    {     20,   16,    0, 16,  0,  4 }, {     21,   16,    0, 16,  0,  4 }, {     22,   16,    0, 16,  0,  4 }, {     23,   16,    0, 16,  0,  4 }, {     24,   16,    0, 16,  0,  4 },
    {     25,   16,    0, 16,  0,  4 }, {     26,   16,    0, 16,  0,  4 }, {     27,   16,    0, 16,  0,  4 }, {     28,   16,    0, 16,  0,  4 }, {     29,   16,    0, 16,  0,  4 },
    {     30,   16,    0, 16,  0,  4 }, {     31,   16,    0, 16,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8BF1F0, {
    {     16,   31,    0, 24,  0,  4 }, {     16,   30,    0, 24,  0,  4 }, {     16,   29,    0, 24,  0,  4 }, {     16,   28,    0, 24,  0,  4 }, {     16,   27,    0, 24,  0,  4 },
    {     16,   26,    0, 24,  0,  4 }, {     16,   25,    0, 24,  0,  4 }, {     16,   24,    0, 24,  0,  4 }, {     16,   23,    0, 24,  0,  4 }, {     16,   22,    0, 24,  0,  4 },
    {     16,   21,    0, 24,  0,  4 }, {     16,   20,    0, 24,  0,  4 }, {     16,   19,    0, 24,  0,  4 }, {     16,   18,    0, 24,  0,  4 }, {     16,   17,    0, 24,  0,  4 },
    {     16,   16,    0, 24,  0,  4 }, {     16,   15,    0, 24,  0,  4 }, {     16,   14,    0, 24,  0,  4 }, {     16,   13,    0, 24,  0,  4 }, {     16,   12,    0, 24,  0,  4 },
    {     16,   11,    0, 24,  0,  4 }, {     16,   10,    0, 24,  0,  4 }, {     16,    9,    0, 24,  0,  4 }, {     16,    8,    0, 24,  0,  4 }, {     16,    7,    0, 24,  0,  4 },
    {     16,    6,    0, 24,  0,  4 }, {     16,    5,    0, 24,  0,  4 }, {     16,    4,    0, 24,  0,  4 }, {     16,    3,    0, 24,  0,  4 }, {     16,    2,    0, 24,  0,  4 },
    {     16,    1,    0, 24,  0,  4 }, {     16,    0,    0, 24,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D047E, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    0,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    1,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    2,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    3, 31,  2,  0 }, {     23,   15,    4, 31,  2,  0 }, {     22,   15,    4, 31,  2,  0 },
    {     21,   15,    5, 31,  2,  0 }, {     20,   15,    5, 31,  2,  0 }, {     19,   15,    6, 31,  2,  0 }, {     18,   15,    6, 31,  2,  0 }, {     17,   14,    7, 31,  2,  0 },
    {     16,   14,    8, 31,  2,  0 }, {     15,   14,    8, 31,  2,  0 }, {     14,   14,    8, 31,  2,  0 }, {     13,   14,    9, 31,  2,  0 }, {     12,   13,    9, 31,  2,  0 },
    {     11,   13,   10, 31,  2,  0 }, {     10,   13,   11, 30,  2,  0 }, {      9,   13,   11, 30,  2,  0 }, {      8,   12,   12, 30,  2,  0 }, {      7,   12,   12, 30,  2,  0 },
    {      6,   12,   13, 30,  2,  0 }, {      5,   11,   13, 30,  2,  0 }, {      4,   11,   14, 30,  2,  0 }, {      3,   11,   14, 30,  2,  0 }, {      2,   10,   15, 30,  2,  0 },
    {      1,   10,   15, 30,  2,  0 }, {      0,    9,   16, 30,  2,  0 }, {     -1,    9,   17, 30,  2,  0 }, {     -2,    8,   17, 30,  2,  0 }, {     -3,    8,   18, 30,  2,  0 },
    {     -4,    7,   18, 30,  2,  0 }, {     -5,    7,   19, 29,  2,  0 }, {     -6,    6,   19, 29,  2,  0 }, {     -7,    6,   20, 29,  2,  0 }, {     -8,    5,   21, 29,  2,  0 },
    {     -9,    4,   21, 29,  2,  0 }, {    -10,    4,   22, 29,  2,  0 }, {    -11,    3,   22, 29,  2,  0 }, {    -12,    2,   23, 29,  2,  0 }, {    -13,    2,   24, 29,  2,  0 },
    {    -14,    1,   24, 29,  2,  0 }, {    -15,    0,   25, 29,  2,  0 }, {    -16,    0,   26, 29,  2,  0 }, {    -17,   -1,   26, 29,  2,  0 }, {    -18,   -2,   27, 28,  2,  0 },
    {    -19,   -3,   27, 28,  2,  0 }, {    -20,   -3,   28, 28,  2,  0 }, {    -21,   -4,   29, 28,  2,  0 }, {    -22,   -5,   29, 28,  2,  0 }, {    -23,   -6,   30, 28,  2,  0 },
    {    -24,   -7,   31, 28,  2,  0 }, {    -25,   -7,   31, 28,  2,  0 }, {    -26,   -8,   32, 28,  2,  0 }, {    -27,   -9,   32, 28,  2,  0 }, {    -28,  -10,   33, 28,  2,  0 },
    {    -29,  -11,   34, 28,  2,  0 }, {    -29,  -12,   34, 28,  2,  0 }, {    -30,  -13,   35, 27,  2,  0 }, {    -31,  -14,   36, 27,  2,  0 }, {    -32,  -15,   36, 27,  2,  0 },
    {    -32,  -16,   37, 27,  2,  0 }, {    -33,  -17,   37, 27,  2,  0 }, {    -34,  -18,   38, 27,  2,  0 }, {    -34,  -19,   39, 27,  2,  0 }, {    -35,  -20,   39, 27,  2,  0 },
    {    -36,  -21,   40, 27,  2,  0 }, {    -36,  -22,   41, 27,  2,  0 }, {    -37,  -23,   41, 27,  2,  0 }, {    -38,  -24,   42, 27,  2,  0 }, {    -38,  -25,   42, 27,  2,  0 },
    {    -39,  -26,   43, 26,  2,  0 }, {    -39,  -27,   44, 26,  2,  0 }, {    -40,  -28,   44, 26,  2,  0 }, {    -40,  -29,   45, 26,  2,  0 }, {    -41,  -30,   45, 26,  2,  0 },
    {    -41,  -31,   46, 26,  2,  0 }, {    -42,  -32,   46, 26,  2,  0 }, {    -42,  -33,   47, 26,  2,  0 }, {    -43,  -34,   48, 26,  2,  0 }, {    -43,  -35,   48, 26,  2,  0 },
    {    -43,  -36,   49, 26,  2,  0 }, {    -44,  -37,   49, 26,  2,  0 }, {    -44,  -38,   50, 26,  2,  0 }, {    -44,  -39,   50, 26,  2,  0 }, {    -45,  -40,   51, 25,  2,  0 },
    {    -45,  -41,   51, 25,  2,  0 }, {    -45,  -42,   52, 25,  2,  0 }, {    -45,  -43,   52, 25,  2,  0 }, {    -46,  -44,   53, 25,  2,  0 }, {    -46,  -45,   54, 25,  2,  0 },
    {    -46,  -46,   54, 25,  2,  0 }, {    -46,  -47,   55, 25,  2,  0 }, {    -46,  -48,   55, 25,  2,  0 }, {    -47,  -49,   55, 25,  2,  0 }, {    -47,  -50,   56, 25,  2,  0 },
    {    -47,  -51,   57, 25,  2,  0 }, {    -47,  -52,   57, 25,  2,  0 }, {    -47,  -53,   58, 25,  2,  0 }, {    -47,  -54,   58, 25,  2,  0 }, {    -48,  -55,   59, 25,  2,  0 },
    {    -48,  -56,   59, 24,  2,  0 }, {    -48,  -57,   60, 24,  2,  0 }, {    -48,  -58,   60, 24,  2,  0 }, {    -48,  -59,   61, 24,  2,  0 }, {    -48,  -60,   61, 24,  2,  0 },
    {    -48,  -61,   62, 24,  2,  0 }, {    -48,  -62,   62, 24,  2,  0 }, {    -48,  -63,   63, 24,  2,  0 }, {    -48,  -64,   64, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D0882, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    0,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    1,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    2,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    3,  7,  2,  0 }, {     15,    9,    4,  7,  2,  0 },
    {     15,   10,    4,  7,  2,  0 }, {     15,   11,    5,  7,  2,  0 }, {     15,   12,    5,  7,  2,  0 }, {     15,   13,    6,  7,  2,  0 }, {     15,   14,    6,  7,  2,  0 },
    {     14,   15,    7,  7,  2,  0 }, {     14,   16,    8,  7,  2,  0 }, {     14,   17,    8,  7,  2,  0 }, {     14,   18,    8,  7,  2,  0 }, {     14,   19,    9,  7,  2,  0 },
    {     13,   20,    9,  7,  2,  0 }, {     13,   21,   10,  7,  2,  0 }, {     13,   22,   11,  6,  2,  0 }, {     13,   23,   11,  6,  2,  0 }, {     12,   24,   12,  6,  2,  0 },
    {     12,   25,   12,  6,  2,  0 }, {     12,   26,   13,  6,  2,  0 }, {     11,   27,   13,  6,  2,  0 }, {     11,   28,   14,  6,  2,  0 }, {     11,   29,   14,  6,  2,  0 },
    {     10,   30,   15,  6,  2,  0 }, {     10,   31,   15,  6,  2,  0 }, {      9,   32,   16,  6,  2,  0 }, {      9,   33,   17,  6,  2,  0 }, {      8,   34,   17,  6,  2,  0 },
    {      8,   35,   18,  6,  2,  0 }, {      7,   36,   18,  6,  2,  0 }, {      7,   37,   19,  5,  2,  0 }, {      6,   38,   19,  5,  2,  0 }, {      6,   39,   20,  5,  2,  0 },
    {      5,   40,   21,  5,  2,  0 }, {      4,   41,   21,  5,  2,  0 }, {      4,   42,   22,  5,  2,  0 }, {      3,   43,   22,  5,  2,  0 }, {      2,   44,   23,  5,  2,  0 },
    {      2,   45,   24,  5,  2,  0 }, {      1,   46,   24,  5,  2,  0 }, {      0,   47,   25,  5,  2,  0 }, {      0,   48,   26,  5,  2,  0 }, {     -1,   49,   26,  5,  2,  0 },
    {     -2,   50,   27,  4,  2,  0 }, {     -3,   51,   27,  4,  2,  0 }, {     -3,   52,   28,  4,  2,  0 }, {     -4,   53,   29,  4,  2,  0 }, {     -5,   54,   29,  4,  2,  0 },
    {     -6,   55,   30,  4,  2,  0 }, {     -7,   56,   31,  4,  2,  0 }, {     -7,   57,   31,  4,  2,  0 }, {     -8,   58,   32,  4,  2,  0 }, {     -9,   59,   32,  4,  2,  0 },
    {    -10,   60,   33,  4,  2,  0 }, {    -11,   61,   34,  4,  2,  0 }, {    -12,   61,   34,  4,  2,  0 }, {    -13,   62,   35,  3,  2,  0 }, {    -14,   63,   36,  3,  2,  0 },
    {    -15,   64,   36,  3,  2,  0 }, {    -16,   64,   37,  3,  2,  0 }, {    -17,   65,   37,  3,  2,  0 }, {    -18,   66,   38,  3,  2,  0 }, {    -19,   66,   39,  3,  2,  0 },
    {    -20,   67,   39,  3,  2,  0 }, {    -21,   68,   40,  3,  2,  0 }, {    -22,   68,   41,  3,  2,  0 }, {    -23,   69,   41,  3,  2,  0 }, {    -24,   70,   42,  3,  2,  0 },
    {    -25,   70,   42,  3,  2,  0 }, {    -26,   71,   43,  2,  2,  0 }, {    -27,   71,   44,  2,  2,  0 }, {    -28,   72,   44,  2,  2,  0 }, {    -29,   72,   45,  2,  2,  0 },
    {    -30,   73,   45,  2,  2,  0 }, {    -31,   73,   46,  2,  2,  0 }, {    -32,   74,   46,  2,  2,  0 }, {    -33,   74,   47,  2,  2,  0 }, {    -34,   75,   48,  2,  2,  0 },
    {    -35,   75,   48,  2,  2,  0 }, {    -36,   75,   49,  2,  2,  0 }, {    -37,   76,   49,  2,  2,  0 }, {    -38,   76,   50,  2,  2,  0 }, {    -39,   76,   50,  2,  2,  0 },
    {    -40,   77,   51,  1,  2,  0 }, {    -41,   77,   51,  1,  2,  0 }, {    -42,   77,   52,  1,  2,  0 }, {    -43,   77,   52,  1,  2,  0 }, {    -44,   78,   53,  1,  2,  0 },
    {    -45,   78,   54,  1,  2,  0 }, {    -46,   78,   54,  1,  2,  0 }, {    -47,   78,   55,  1,  2,  0 }, {    -48,   78,   55,  1,  2,  0 }, {    -49,   79,   55,  1,  2,  0 },
    {    -50,   79,   56,  1,  2,  0 }, {    -51,   79,   57,  1,  2,  0 }, {    -52,   79,   57,  1,  2,  0 }, {    -53,   79,   58,  1,  2,  0 }, {    -54,   79,   58,  1,  2,  0 },
    {    -55,   80,   59,  1,  2,  0 }, {    -56,   80,   59,  0,  2,  0 }, {    -57,   80,   60,  0,  2,  0 }, {    -58,   80,   60,  0,  2,  0 }, {    -59,   80,   61,  0,  2,  0 },
    {    -60,   80,   61,  0,  2,  0 }, {    -61,   80,   62,  0,  2,  0 }, {    -62,   80,   62,  0,  2,  0 }, {    -63,   80,   63,  0,  2,  0 }, {    -64,   80,   64,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D0C8F, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    0, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    1, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    2, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    3, 15,  2,  0 }, {      9,   17,    4, 15,  2,  0 },
    {     10,   17,    5, 15,  2,  0 }, {     11,   17,    5, 15,  2,  0 }, {     12,   17,    5, 15,  2,  0 }, {     13,   17,    6, 15,  2,  0 }, {     14,   17,    6, 15,  2,  0 },
    {     15,   18,    7, 15,  2,  0 }, {     16,   18,    8, 15,  2,  0 }, {     17,   18,    8, 15,  2,  0 }, {     18,   18,    9, 15,  2,  0 }, {     19,   18,    9, 15,  2,  0 },
    {     20,   19,   10, 15,  2,  0 }, {     21,   19,   10, 15,  2,  0 }, {     22,   19,   11, 14,  2,  0 }, {     23,   19,   11, 14,  2,  0 }, {     24,   20,   12, 14,  2,  0 },
    {     25,   20,   12, 14,  2,  0 }, {     26,   20,   13, 14,  2,  0 }, {     27,   21,   13, 14,  2,  0 }, {     28,   21,   14, 14,  2,  0 }, {     29,   21,   14, 14,  2,  0 },
    {     30,   22,   15, 14,  2,  0 }, {     31,   22,   16, 14,  2,  0 }, {     32,   23,   16, 14,  2,  0 }, {     33,   23,   17, 14,  2,  0 }, {     34,   24,   17, 14,  2,  0 },
    {     35,   24,   18, 14,  2,  0 }, {     36,   25,   18, 14,  2,  0 }, {     37,   25,   19, 13,  2,  0 }, {     38,   26,   20, 13,  2,  0 }, {     39,   26,   20, 13,  2,  0 },
    {     40,   27,   21, 13,  2,  0 }, {     41,   28,   21, 13,  2,  0 }, {     42,   28,   22, 13,  2,  0 }, {     43,   29,   23, 13,  2,  0 }, {     44,   30,   23, 13,  2,  0 },
    {     45,   30,   24, 13,  2,  0 }, {     46,   31,   24, 13,  2,  0 }, {     47,   32,   25, 13,  2,  0 }, {     48,   32,   26, 13,  2,  0 }, {     49,   33,   26, 13,  2,  0 },
    {     50,   34,   27, 12,  2,  0 }, {     51,   35,   28, 12,  2,  0 }, {     52,   35,   28, 12,  2,  0 }, {     53,   36,   29, 12,  2,  0 }, {     54,   37,   29, 12,  2,  0 },
    {     55,   38,   30, 12,  2,  0 }, {     56,   39,   31, 12,  2,  0 }, {     57,   39,   32, 12,  2,  0 }, {     58,   40,   32, 12,  2,  0 }, {     59,   41,   33, 12,  2,  0 },
    {     60,   42,   33, 12,  2,  0 }, {     61,   43,   34, 12,  2,  0 }, {     61,   44,   35, 12,  2,  0 }, {     62,   45,   35, 11,  2,  0 }, {     63,   46,   36, 11,  2,  0 },
    {     64,   47,   37, 11,  2,  0 }, {     64,   48,   37, 11,  2,  0 }, {     65,   49,   38, 11,  2,  0 }, {     66,   50,   38, 11,  2,  0 }, {     66,   51,   39, 11,  2,  0 },
    {     67,   52,   40, 11,  2,  0 }, {     68,   53,   40, 11,  2,  0 }, {     68,   54,   41, 11,  2,  0 }, {     69,   55,   41, 11,  2,  0 }, {     70,   56,   42, 11,  2,  0 },
    {     70,   57,   43, 11,  2,  0 }, {     71,   58,   43, 10,  2,  0 }, {     71,   59,   44, 10,  2,  0 }, {     72,   60,   44, 10,  2,  0 }, {     72,   61,   45, 10,  2,  0 },
    {     73,   62,   46, 10,  2,  0 }, {     73,   63,   46, 10,  2,  0 }, {     74,   64,   47, 10,  2,  0 }, {     74,   65,   47, 10,  2,  0 }, {     75,   66,   48, 10,  2,  0 },
    {     75,   67,   49, 10,  2,  0 }, {     75,   68,   49, 10,  2,  0 }, {     76,   69,   50, 10,  2,  0 }, {     76,   70,   50, 10,  2,  0 }, {     76,   71,   51, 10,  2,  0 },
    {     77,   72,   51,  9,  2,  0 }, {     77,   73,   52,  9,  2,  0 }, {     77,   74,   52,  9,  2,  0 }, {     77,   75,   53,  9,  2,  0 }, {     78,   76,   53,  9,  2,  0 },
    {     78,   77,   54,  9,  2,  0 }, {     78,   78,   54,  9,  2,  0 }, {     78,   79,   55,  9,  2,  0 }, {     78,   80,   55,  9,  2,  0 }, {     79,   81,   56,  9,  2,  0 },
    {     79,   82,   57,  9,  2,  0 }, {     79,   83,   57,  9,  2,  0 }, {     79,   84,   58,  9,  2,  0 }, {     79,   85,   58,  9,  2,  0 }, {     79,   86,   58,  9,  2,  0 },
    {     80,   87,   59,  9,  2,  0 }, {     80,   88,   60,  8,  2,  0 }, {     80,   89,   60,  8,  2,  0 }, {     80,   90,   61,  8,  2,  0 }, {     80,   91,   61,  8,  2,  0 },
    {     80,   92,   62,  8,  2,  0 }, {     80,   93,   62,  8,  2,  0 }, {     80,   94,   63,  8,  2,  0 }, {     80,   95,   63,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D1093, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    0, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    1, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    2, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    3, 23,  2,  0 }, {     17,   23,    4, 23,  2,  0 }, {     17,   22,    5, 23,  2,  0 },
    {     17,   21,    5, 23,  2,  0 }, {     17,   20,    5, 23,  2,  0 }, {     17,   19,    6, 23,  2,  0 }, {     17,   18,    6, 23,  2,  0 }, {     18,   17,    7, 23,  2,  0 },
    {     18,   16,    8, 23,  2,  0 }, {     18,   15,    8, 23,  2,  0 }, {     18,   14,    9, 23,  2,  0 }, {     18,   13,    9, 23,  2,  0 }, {     19,   12,   10, 23,  2,  0 },
    {     19,   11,   10, 23,  2,  0 }, {     19,   10,   11, 22,  2,  0 }, {     19,    9,   11, 22,  2,  0 }, {     20,    8,   12, 22,  2,  0 }, {     20,    7,   12, 22,  2,  0 },
    {     20,    6,   13, 22,  2,  0 }, {     21,    5,   13, 22,  2,  0 }, {     21,    4,   14, 22,  2,  0 }, {     21,    3,   14, 22,  2,  0 }, {     22,    2,   15, 22,  2,  0 },
    {     22,    1,   16, 22,  2,  0 }, {     23,    0,   16, 22,  2,  0 }, {     23,   -1,   17, 22,  2,  0 }, {     24,   -2,   17, 22,  2,  0 }, {     24,   -3,   18, 22,  2,  0 },
    {     25,   -4,   18, 22,  2,  0 }, {     25,   -5,   19, 21,  2,  0 }, {     26,   -6,   20, 21,  2,  0 }, {     26,   -7,   20, 21,  2,  0 }, {     27,   -8,   21, 21,  2,  0 },
    {     28,   -9,   21, 21,  2,  0 }, {     28,  -10,   22, 21,  2,  0 }, {     29,  -11,   23, 21,  2,  0 }, {     30,  -12,   23, 21,  2,  0 }, {     30,  -13,   24, 21,  2,  0 },
    {     31,  -14,   24, 21,  2,  0 }, {     32,  -15,   25, 21,  2,  0 }, {     32,  -16,   26, 21,  2,  0 }, {     33,  -17,   26, 21,  2,  0 }, {     34,  -18,   27, 20,  2,  0 },
    {     35,  -19,   28, 20,  2,  0 }, {     35,  -20,   28, 20,  2,  0 }, {     36,  -21,   29, 20,  2,  0 }, {     37,  -22,   29, 20,  2,  0 }, {     38,  -23,   30, 20,  2,  0 },
    {     39,  -24,   31, 20,  2,  0 }, {     39,  -25,   32, 20,  2,  0 }, {     40,  -26,   32, 20,  2,  0 }, {     41,  -27,   33, 20,  2,  0 }, {     42,  -28,   33, 20,  2,  0 },
    {     43,  -29,   34, 20,  2,  0 }, {     44,  -29,   35, 20,  2,  0 }, {     45,  -30,   35, 19,  2,  0 }, {     46,  -31,   36, 19,  2,  0 }, {     47,  -32,   37, 19,  2,  0 },
    {     48,  -32,   37, 19,  2,  0 }, {     49,  -33,   38, 19,  2,  0 }, {     50,  -34,   38, 19,  2,  0 }, {     51,  -34,   39, 19,  2,  0 }, {     52,  -35,   40, 19,  2,  0 },
    {     53,  -36,   40, 19,  2,  0 }, {     54,  -36,   41, 19,  2,  0 }, {     55,  -37,   41, 19,  2,  0 }, {     56,  -38,   42, 19,  2,  0 }, {     57,  -38,   43, 19,  2,  0 },
    {     58,  -39,   43, 18,  2,  0 }, {     59,  -39,   44, 18,  2,  0 }, {     60,  -40,   44, 18,  2,  0 }, {     61,  -40,   45, 18,  2,  0 }, {     62,  -41,   46, 18,  2,  0 },
    {     63,  -41,   46, 18,  2,  0 }, {     64,  -42,   47, 18,  2,  0 }, {     65,  -42,   47, 18,  2,  0 }, {     66,  -43,   48, 18,  2,  0 }, {     67,  -43,   49, 18,  2,  0 },
    {     68,  -43,   49, 18,  2,  0 }, {     69,  -44,   50, 18,  2,  0 }, {     70,  -44,   50, 18,  2,  0 }, {     71,  -44,   51, 18,  2,  0 }, {     72,  -45,   51, 17,  2,  0 },
    {     73,  -45,   52, 17,  2,  0 }, {     74,  -45,   52, 17,  2,  0 }, {     75,  -45,   53, 17,  2,  0 }, {     76,  -46,   53, 17,  2,  0 }, {     77,  -46,   54, 17,  2,  0 },
    {     78,  -46,   54, 17,  2,  0 }, {     79,  -46,   55, 17,  2,  0 }, {     80,  -46,   55, 17,  2,  0 }, {     81,  -47,   56, 17,  2,  0 }, {     82,  -47,   57, 17,  2,  0 },
    {     83,  -47,   57, 17,  2,  0 }, {     84,  -47,   58, 17,  2,  0 }, {     85,  -47,   58, 17,  2,  0 }, {     86,  -47,   58, 17,  2,  0 }, {     87,  -48,   59, 17,  2,  0 },
    {     88,  -48,   60, 16,  2,  0 }, {     89,  -48,   60, 16,  2,  0 }, {     90,  -48,   61, 16,  2,  0 }, {     91,  -48,   61, 16,  2,  0 }, {     92,  -48,   62, 16,  2,  0 },
    {     93,  -48,   62, 16,  2,  0 }, {     94,  -48,   63, 16,  2,  0 }, {     95,  -48,   63, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D148E, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    0,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    1,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    2,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    3,  1,  2,  0 }, {     23,   17,    4,  1,  2,  0 }, {     22,   17,    5,  1,  2,  0 },
    {     21,   17,    5,  1,  2,  0 }, {     20,   17,    5,  1,  2,  0 }, {     19,   17,    6,  1,  2,  0 }, {     18,   17,    6,  1,  2,  0 }, {     17,   18,    7,  1,  2,  0 },
    {     16,   18,    8,  1,  2,  0 }, {     15,   18,    8,  1,  2,  0 }, {     14,   18,    9,  1,  2,  0 }, {     13,   18,    9,  1,  2,  0 }, {     12,   19,   10,  1,  2,  0 },
    {     11,   19,   10,  1,  2,  0 }, {     10,   19,   11,  2,  2,  0 }, {      9,   19,   11,  2,  2,  0 }, {      8,   20,   12,  2,  2,  0 }, {      7,   20,   12,  2,  2,  0 },
    {      6,   20,   13,  2,  2,  0 }, {      5,   21,   13,  2,  2,  0 }, {      4,   21,   14,  2,  2,  0 }, {      3,   21,   14,  2,  2,  0 }, {      2,   22,   15,  2,  2,  0 },
    {      1,   22,   16,  2,  2,  0 }, {      0,   23,   16,  2,  2,  0 }, {     -1,   23,   17,  2,  2,  0 }, {     -2,   24,   17,  2,  2,  0 }, {     -3,   24,   18,  2,  2,  0 },
    {     -4,   25,   18,  2,  2,  0 }, {     -5,   25,   19,  3,  2,  0 }, {     -6,   26,   20,  3,  2,  0 }, {     -7,   26,   20,  3,  2,  0 }, {     -8,   27,   21,  3,  2,  0 },
    {     -9,   28,   21,  3,  2,  0 }, {    -10,   28,   22,  3,  2,  0 }, {    -11,   29,   23,  3,  2,  0 }, {    -12,   30,   23,  3,  2,  0 }, {    -13,   30,   24,  3,  2,  0 },
    {    -14,   31,   24,  3,  2,  0 }, {    -15,   32,   25,  3,  2,  0 }, {    -16,   32,   26,  3,  2,  0 }, {    -17,   33,   26,  3,  2,  0 }, {    -18,   34,   27,  4,  2,  0 },
    {    -19,   35,   28,  4,  2,  0 }, {    -20,   35,   28,  4,  2,  0 }, {    -21,   36,   29,  4,  2,  0 }, {    -22,   37,   29,  4,  2,  0 }, {    -23,   38,   30,  4,  2,  0 },
    {    -24,   39,   31,  4,  2,  0 }, {    -25,   39,   32,  4,  2,  0 }, {    -26,   40,   32,  4,  2,  0 }, {    -27,   41,   33,  4,  2,  0 }, {    -28,   42,   33,  4,  2,  0 },
    {    -29,   43,   34,  4,  2,  0 }, {    -29,   44,   35,  4,  2,  0 }, {    -30,   45,   35,  5,  2,  0 }, {    -31,   46,   36,  5,  2,  0 }, {    -32,   47,   37,  5,  2,  0 },
    {    -32,   48,   37,  5,  2,  0 }, {    -33,   49,   38,  5,  2,  0 }, {    -34,   50,   38,  5,  2,  0 }, {    -34,   51,   39,  5,  2,  0 }, {    -35,   52,   40,  5,  2,  0 },
    {    -36,   53,   40,  5,  2,  0 }, {    -36,   54,   41,  5,  2,  0 }, {    -37,   55,   41,  5,  2,  0 }, {    -38,   56,   42,  5,  2,  0 }, {    -38,   57,   43,  5,  2,  0 },
    {    -39,   58,   43,  6,  2,  0 }, {    -39,   59,   44,  6,  2,  0 }, {    -40,   60,   44,  6,  2,  0 }, {    -40,   61,   45,  6,  2,  0 }, {    -41,   62,   46,  6,  2,  0 },
    {    -41,   63,   46,  6,  2,  0 }, {    -42,   64,   47,  6,  2,  0 }, {    -42,   65,   47,  6,  2,  0 }, {    -43,   66,   48,  6,  2,  0 }, {    -43,   67,   49,  6,  2,  0 },
    {    -43,   68,   49,  6,  2,  0 }, {    -44,   69,   50,  6,  2,  0 }, {    -44,   70,   50,  6,  2,  0 }, {    -44,   71,   51,  6,  2,  0 }, {    -45,   72,   51,  7,  2,  0 },
    {    -45,   73,   52,  7,  2,  0 }, {    -45,   74,   52,  7,  2,  0 }, {    -45,   75,   53,  7,  2,  0 }, {    -46,   76,   53,  7,  2,  0 }, {    -46,   77,   54,  7,  2,  0 },
    {    -46,   78,   54,  7,  2,  0 }, {    -46,   79,   55,  7,  2,  0 }, {    -46,   80,   55,  7,  2,  0 }, {    -47,   81,   56,  7,  2,  0 }, {    -47,   82,   57,  7,  2,  0 },
    {    -47,   83,   57,  7,  2,  0 }, {    -47,   84,   58,  7,  2,  0 }, {    -47,   85,   58,  7,  2,  0 }, {    -47,   86,   58,  7,  2,  0 }, {    -48,   87,   59,  7,  2,  0 },
    {    -48,   88,   60,  8,  2,  0 }, {    -48,   89,   60,  8,  2,  0 }, {    -48,   90,   61,  8,  2,  0 }, {    -48,   91,   61,  8,  2,  0 }, {    -48,   92,   62,  8,  2,  0 },
    {    -48,   93,   62,  8,  2,  0 }, {    -48,   94,   63,  8,  2,  0 }, {    -48,   95,   63,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D1889, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    0,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    1,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    2,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    3,  9,  2,  0 }, {     17,    9,    4,  9,  2,  0 },
    {     17,   10,    5,  9,  2,  0 }, {     17,   11,    5,  9,  2,  0 }, {     17,   12,    5,  9,  2,  0 }, {     17,   13,    6,  9,  2,  0 }, {     17,   14,    6,  9,  2,  0 },
    {     18,   15,    7,  9,  2,  0 }, {     18,   16,    8,  9,  2,  0 }, {     18,   17,    8,  9,  2,  0 }, {     18,   18,    9,  9,  2,  0 }, {     18,   19,    9,  9,  2,  0 },
    {     19,   20,   10,  9,  2,  0 }, {     19,   21,   10,  9,  2,  0 }, {     19,   22,   11, 10,  2,  0 }, {     19,   23,   11, 10,  2,  0 }, {     20,   24,   12, 10,  2,  0 },
    {     20,   25,   12, 10,  2,  0 }, {     20,   26,   13, 10,  2,  0 }, {     21,   27,   13, 10,  2,  0 }, {     21,   28,   14, 10,  2,  0 }, {     21,   29,   14, 10,  2,  0 },
    {     22,   30,   15, 10,  2,  0 }, {     22,   31,   16, 10,  2,  0 }, {     23,   32,   16, 10,  2,  0 }, {     23,   33,   17, 10,  2,  0 }, {     24,   34,   17, 10,  2,  0 },
    {     24,   35,   18, 10,  2,  0 }, {     25,   36,   18, 10,  2,  0 }, {     25,   37,   19, 11,  2,  0 }, {     26,   38,   20, 11,  2,  0 }, {     26,   39,   20, 11,  2,  0 },
    {     27,   40,   21, 11,  2,  0 }, {     28,   41,   21, 11,  2,  0 }, {     28,   42,   22, 11,  2,  0 }, {     29,   43,   23, 11,  2,  0 }, {     30,   44,   23, 11,  2,  0 },
    {     30,   45,   24, 11,  2,  0 }, {     31,   46,   24, 11,  2,  0 }, {     32,   47,   25, 11,  2,  0 }, {     32,   48,   26, 11,  2,  0 }, {     33,   49,   26, 11,  2,  0 },
    {     34,   50,   27, 12,  2,  0 }, {     35,   51,   28, 12,  2,  0 }, {     35,   52,   28, 12,  2,  0 }, {     36,   53,   29, 12,  2,  0 }, {     37,   54,   29, 12,  2,  0 },
    {     38,   55,   30, 12,  2,  0 }, {     39,   56,   31, 12,  2,  0 }, {     39,   57,   32, 12,  2,  0 }, {     40,   58,   32, 12,  2,  0 }, {     41,   59,   33, 12,  2,  0 },
    {     42,   60,   33, 12,  2,  0 }, {     43,   61,   34, 12,  2,  0 }, {     44,   61,   35, 12,  2,  0 }, {     45,   62,   35, 13,  2,  0 }, {     46,   63,   36, 13,  2,  0 },
    {     47,   64,   37, 13,  2,  0 }, {     48,   64,   37, 13,  2,  0 }, {     49,   65,   38, 13,  2,  0 }, {     50,   66,   38, 13,  2,  0 }, {     51,   66,   39, 13,  2,  0 },
    {     52,   67,   40, 13,  2,  0 }, {     53,   68,   40, 13,  2,  0 }, {     54,   68,   41, 13,  2,  0 }, {     55,   69,   41, 13,  2,  0 }, {     56,   70,   42, 13,  2,  0 },
    {     57,   70,   43, 13,  2,  0 }, {     58,   71,   43, 14,  2,  0 }, {     59,   71,   44, 14,  2,  0 }, {     60,   72,   44, 14,  2,  0 }, {     61,   72,   45, 14,  2,  0 },
    {     62,   73,   46, 14,  2,  0 }, {     63,   73,   46, 14,  2,  0 }, {     64,   74,   47, 14,  2,  0 }, {     65,   74,   47, 14,  2,  0 }, {     66,   75,   48, 14,  2,  0 },
    {     67,   75,   49, 14,  2,  0 }, {     68,   75,   49, 14,  2,  0 }, {     69,   76,   50, 14,  2,  0 }, {     70,   76,   50, 14,  2,  0 }, {     71,   76,   51, 14,  2,  0 },
    {     72,   77,   51, 15,  2,  0 }, {     73,   77,   52, 15,  2,  0 }, {     74,   77,   52, 15,  2,  0 }, {     75,   77,   53, 15,  2,  0 }, {     76,   78,   53, 15,  2,  0 },
    {     77,   78,   54, 15,  2,  0 }, {     78,   78,   54, 15,  2,  0 }, {     79,   78,   55, 15,  2,  0 }, {     80,   78,   55, 15,  2,  0 }, {     81,   79,   56, 15,  2,  0 },
    {     82,   79,   57, 15,  2,  0 }, {     83,   79,   57, 15,  2,  0 }, {     84,   79,   58, 15,  2,  0 }, {     85,   79,   58, 15,  2,  0 }, {     86,   79,   58, 15,  2,  0 },
    {     87,   80,   59, 15,  2,  0 }, {     88,   80,   60, 16,  2,  0 }, {     89,   80,   60, 16,  2,  0 }, {     90,   80,   61, 16,  2,  0 }, {     91,   80,   61, 16,  2,  0 },
    {     92,   80,   62, 16,  2,  0 }, {     93,   80,   62, 16,  2,  0 }, {     94,   80,   63, 16,  2,  0 }, {     95,   80,   63, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D1C8D, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    0, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    1, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    2, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    3, 17,  2,  0 }, {      9,   15,    4, 17,  2,  0 },
    {     10,   15,    4, 17,  2,  0 }, {     11,   15,    5, 17,  2,  0 }, {     12,   15,    5, 17,  2,  0 }, {     13,   15,    6, 17,  2,  0 }, {     14,   15,    6, 17,  2,  0 },
    {     15,   14,    7, 17,  2,  0 }, {     16,   14,    8, 17,  2,  0 }, {     17,   14,    8, 17,  2,  0 }, {     18,   14,    8, 17,  2,  0 }, {     19,   14,    9, 17,  2,  0 },
    {     20,   13,    9, 17,  2,  0 }, {     21,   13,   10, 17,  2,  0 }, {     22,   13,   11, 18,  2,  0 }, {     23,   13,   11, 18,  2,  0 }, {     24,   12,   12, 18,  2,  0 },
    {     25,   12,   12, 18,  2,  0 }, {     26,   12,   13, 18,  2,  0 }, {     27,   11,   13, 18,  2,  0 }, {     28,   11,   14, 18,  2,  0 }, {     29,   11,   14, 18,  2,  0 },
    {     30,   10,   15, 18,  2,  0 }, {     31,   10,   15, 18,  2,  0 }, {     32,    9,   16, 18,  2,  0 }, {     33,    9,   17, 18,  2,  0 }, {     34,    8,   17, 18,  2,  0 },
    {     35,    8,   18, 18,  2,  0 }, {     36,    7,   18, 18,  2,  0 }, {     37,    7,   19, 19,  2,  0 }, {     38,    6,   19, 19,  2,  0 }, {     39,    6,   20, 19,  2,  0 },
    {     40,    5,   21, 19,  2,  0 }, {     41,    4,   21, 19,  2,  0 }, {     42,    4,   22, 19,  2,  0 }, {     43,    3,   22, 19,  2,  0 }, {     44,    2,   23, 19,  2,  0 },
    {     45,    2,   24, 19,  2,  0 }, {     46,    1,   24, 19,  2,  0 }, {     47,    0,   25, 19,  2,  0 }, {     48,    0,   26, 19,  2,  0 }, {     49,   -1,   26, 19,  2,  0 },
    {     50,   -2,   27, 20,  2,  0 }, {     51,   -3,   27, 20,  2,  0 }, {     52,   -3,   28, 20,  2,  0 }, {     53,   -4,   29, 20,  2,  0 }, {     54,   -5,   29, 20,  2,  0 },
    {     55,   -6,   30, 20,  2,  0 }, {     56,   -7,   31, 20,  2,  0 }, {     57,   -7,   31, 20,  2,  0 }, {     58,   -8,   32, 20,  2,  0 }, {     59,   -9,   32, 20,  2,  0 },
    {     60,  -10,   33, 20,  2,  0 }, {     61,  -11,   34, 20,  2,  0 }, {     61,  -12,   34, 20,  2,  0 }, {     62,  -13,   35, 21,  2,  0 }, {     63,  -14,   36, 21,  2,  0 },
    {     64,  -15,   36, 21,  2,  0 }, {     64,  -16,   37, 21,  2,  0 }, {     65,  -17,   37, 21,  2,  0 }, {     66,  -18,   38, 21,  2,  0 }, {     66,  -19,   39, 21,  2,  0 },
    {     67,  -20,   39, 21,  2,  0 }, {     68,  -21,   40, 21,  2,  0 }, {     68,  -22,   41, 21,  2,  0 }, {     69,  -23,   41, 21,  2,  0 }, {     70,  -24,   42, 21,  2,  0 },
    {     70,  -25,   42, 21,  2,  0 }, {     71,  -26,   43, 22,  2,  0 }, {     71,  -27,   44, 22,  2,  0 }, {     72,  -28,   44, 22,  2,  0 }, {     72,  -29,   45, 22,  2,  0 },
    {     73,  -30,   45, 22,  2,  0 }, {     73,  -31,   46, 22,  2,  0 }, {     74,  -32,   46, 22,  2,  0 }, {     74,  -33,   47, 22,  2,  0 }, {     75,  -34,   48, 22,  2,  0 },
    {     75,  -35,   48, 22,  2,  0 }, {     75,  -36,   49, 22,  2,  0 }, {     76,  -37,   49, 22,  2,  0 }, {     76,  -38,   50, 22,  2,  0 }, {     76,  -39,   50, 22,  2,  0 },
    {     77,  -40,   51, 23,  2,  0 }, {     77,  -41,   51, 23,  2,  0 }, {     77,  -42,   52, 23,  2,  0 }, {     77,  -43,   52, 23,  2,  0 }, {     78,  -44,   53, 23,  2,  0 },
    {     78,  -45,   54, 23,  2,  0 }, {     78,  -46,   54, 23,  2,  0 }, {     78,  -47,   55, 23,  2,  0 }, {     78,  -48,   55, 23,  2,  0 }, {     79,  -49,   55, 23,  2,  0 },
    {     79,  -50,   56, 23,  2,  0 }, {     79,  -51,   57, 23,  2,  0 }, {     79,  -52,   57, 23,  2,  0 }, {     79,  -53,   58, 23,  2,  0 }, {     79,  -54,   58, 23,  2,  0 },
    {     80,  -55,   59, 23,  2,  0 }, {     80,  -56,   59, 24,  2,  0 }, {     80,  -57,   60, 24,  2,  0 }, {     80,  -58,   60, 24,  2,  0 }, {     80,  -59,   61, 24,  2,  0 },
    {     80,  -60,   61, 24,  2,  0 }, {     80,  -61,   62, 24,  2,  0 }, {     80,  -62,   62, 24,  2,  0 }, {     80,  -63,   63, 24,  2,  0 }, {     80,  -64,   64, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D209A, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    0, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    1, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    2, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    3, 25,  2,  0 }, {     15,   23,    4, 25,  2,  0 }, {     15,   22,    4, 25,  2,  0 },
    {     15,   21,    5, 25,  2,  0 }, {     15,   20,    5, 25,  2,  0 }, {     15,   19,    6, 25,  2,  0 }, {     15,   18,    6, 25,  2,  0 }, {     14,   17,    7, 25,  2,  0 },
    {     14,   16,    8, 25,  2,  0 }, {     14,   15,    8, 25,  2,  0 }, {     14,   14,    8, 25,  2,  0 }, {     14,   13,    9, 25,  2,  0 }, {     13,   12,    9, 25,  2,  0 },
    {     13,   11,   10, 25,  2,  0 }, {     13,   10,   11, 26,  2,  0 }, {     13,    9,   11, 26,  2,  0 }, {     12,    8,   12, 26,  2,  0 }, {     12,    7,   12, 26,  2,  0 },
    {     12,    6,   13, 26,  2,  0 }, {     11,    5,   13, 26,  2,  0 }, {     11,    4,   14, 26,  2,  0 }, {     11,    3,   14, 26,  2,  0 }, {     10,    2,   15, 26,  2,  0 },
    {     10,    1,   15, 26,  2,  0 }, {      9,    0,   16, 26,  2,  0 }, {      9,   -1,   17, 26,  2,  0 }, {      8,   -2,   17, 26,  2,  0 }, {      8,   -3,   18, 26,  2,  0 },
    {      7,   -4,   18, 26,  2,  0 }, {      7,   -5,   19, 27,  2,  0 }, {      6,   -6,   19, 27,  2,  0 }, {      6,   -7,   20, 27,  2,  0 }, {      5,   -8,   21, 27,  2,  0 },
    {      4,   -9,   21, 27,  2,  0 }, {      4,  -10,   22, 27,  2,  0 }, {      3,  -11,   22, 27,  2,  0 }, {      2,  -12,   23, 27,  2,  0 }, {      2,  -13,   24, 27,  2,  0 },
    {      1,  -14,   24, 27,  2,  0 }, {      0,  -15,   25, 27,  2,  0 }, {      0,  -16,   26, 27,  2,  0 }, {     -1,  -17,   26, 27,  2,  0 }, {     -2,  -18,   27, 28,  2,  0 },
    {     -3,  -19,   27, 28,  2,  0 }, {     -3,  -20,   28, 28,  2,  0 }, {     -4,  -21,   29, 28,  2,  0 }, {     -5,  -22,   29, 28,  2,  0 }, {     -6,  -23,   30, 28,  2,  0 },
    {     -7,  -24,   31, 28,  2,  0 }, {     -7,  -25,   32, 28,  2,  0 }, {     -8,  -26,   32, 28,  2,  0 }, {     -9,  -27,   33, 28,  2,  0 }, {    -10,  -28,   33, 28,  2,  0 },
    {    -11,  -29,   34, 28,  2,  0 }, {    -12,  -29,   35, 28,  2,  0 }, {    -13,  -30,   35, 29,  2,  0 }, {    -14,  -31,   36, 29,  2,  0 }, {    -15,  -32,   37, 29,  2,  0 },
    {    -16,  -32,   37, 29,  2,  0 }, {    -17,  -33,   38, 29,  2,  0 }, {    -18,  -34,   38, 29,  2,  0 }, {    -19,  -34,   39, 29,  2,  0 }, {    -20,  -35,   40, 29,  2,  0 },
    {    -21,  -36,   40, 29,  2,  0 }, {    -22,  -36,   41, 29,  2,  0 }, {    -23,  -37,   41, 29,  2,  0 }, {    -24,  -38,   42, 29,  2,  0 }, {    -25,  -38,   43, 29,  2,  0 },
    {    -26,  -39,   43, 30,  2,  0 }, {    -27,  -39,   44, 30,  2,  0 }, {    -28,  -40,   44, 30,  2,  0 }, {    -29,  -40,   45, 30,  2,  0 }, {    -30,  -41,   45, 30,  2,  0 },
    {    -31,  -41,   46, 30,  2,  0 }, {    -32,  -42,   47, 30,  2,  0 }, {    -33,  -42,   47, 30,  2,  0 }, {    -34,  -43,   48, 30,  2,  0 }, {    -35,  -43,   48, 30,  2,  0 },
    {    -36,  -43,   49, 30,  2,  0 }, {    -37,  -44,   49, 30,  2,  0 }, {    -38,  -44,   50, 30,  2,  0 }, {    -39,  -44,   51, 30,  2,  0 }, {    -40,  -45,   51, 31,  2,  0 },
    {    -41,  -45,   52, 31,  2,  0 }, {    -42,  -45,   52, 31,  2,  0 }, {    -43,  -45,   53, 31,  2,  0 }, {    -44,  -46,   53, 31,  2,  0 }, {    -45,  -46,   54, 31,  2,  0 },
    {    -46,  -46,   54, 31,  2,  0 }, {    -47,  -46,   55, 31,  2,  0 }, {    -48,  -46,   55, 31,  2,  0 }, {    -49,  -47,   56, 31,  2,  0 }, {    -50,  -47,   56, 31,  2,  0 },
    {    -51,  -47,   57, 31,  2,  0 }, {    -52,  -47,   57, 31,  2,  0 }, {    -53,  -47,   58, 31,  2,  0 }, {    -54,  -47,   58, 31,  2,  0 }, {    -55,  -48,   59, 31,  2,  0 },
    {    -56,  -48,   59,  0,  2,  0 }, {    -57,  -48,   60,  0,  2,  0 }, {    -58,  -48,   60,  0,  2,  0 }, {    -59,  -48,   61,  0,  2,  0 }, {    -60,  -48,   61,  0,  2,  0 },
    {    -61,  -48,   62,  0,  2,  0 }, {    -62,  -48,   62,  0,  2,  0 }, {    -63,  -48,   63,  0,  2,  0 }, {    -64,  -48,   64,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D249E, {
    {     31,   16,   15,  0,  6,  0 }, {     30,   16,   15,  0,  6,  0 }, {     29,   16,   14,  0,  6,  0 }, {     28,   16,   14,  0,  6,  0 }, {     27,   16,   13,  0,  6,  0 },
    {     26,   16,   13,  0,  6,  0 }, {     25,   16,   12,  0,  6,  0 }, {     24,   16,   12, 31,  6,  0 }, {     23,   15,   11, 31,  6,  0 }, {     22,   15,   11, 31,  6,  0 },
    {     21,   15,   10, 31,  6,  0 }, {     20,   15,   10, 31,  6,  0 }, {     19,   15,    9, 31,  6,  0 }, {     18,   15,    9, 31,  6,  0 }, {     17,   14,    8, 31,  6,  0 },
    {     16,   14,    7, 31,  6,  0 }, {     15,   14,    7, 31,  6,  0 }, {     14,   14,    7, 31,  6,  0 }, {     13,   14,    6, 31,  6,  0 }, {     12,   13,    6, 31,  6,  0 },
    {     11,   13,    5, 31,  6,  0 }, {     10,   13,    4, 30,  6,  0 }, {      9,   13,    4, 30,  6,  0 }, {      8,   12,    3, 30,  6,  0 }, {      7,   12,    3, 30,  6,  0 },
    {      6,   12,    2, 30,  6,  0 }, {      5,   11,    2, 30,  6,  0 }, {      4,   11,    1, 30,  6,  0 }, {      3,   11,    1, 30,  6,  0 }, {      2,   10,    0, 30,  6,  0 },
    {      1,   10,    0, 30,  6,  0 }, {      0,    9,   -1, 30,  6,  0 }, {     -1,    9,   -2, 30,  6,  0 }, {     -2,    8,   -2, 30,  6,  0 }, {     -3,    8,   -3, 30,  6,  0 },
    {     -4,    7,   -3, 30,  6,  0 }, {     -5,    7,   -4, 29,  6,  0 }, {     -6,    6,   -4, 29,  6,  0 }, {     -7,    6,   -5, 29,  6,  0 }, {     -8,    5,   -6, 29,  6,  0 },
    {     -9,    4,   -6, 29,  6,  0 }, {    -10,    4,   -7, 29,  6,  0 }, {    -11,    3,   -7, 29,  6,  0 }, {    -12,    2,   -8, 29,  6,  0 }, {    -13,    2,   -9, 29,  6,  0 },
    {    -14,    1,   -9, 29,  6,  0 }, {    -15,    0,  -10, 29,  6,  0 }, {    -16,    0,  -11, 29,  6,  0 }, {    -17,   -1,  -11, 29,  6,  0 }, {    -18,   -2,  -12, 28,  6,  0 },
    {    -19,   -3,  -12, 28,  6,  0 }, {    -20,   -3,  -13, 28,  6,  0 }, {    -21,   -4,  -14, 28,  6,  0 }, {    -22,   -5,  -14, 28,  6,  0 }, {    -23,   -6,  -15, 28,  6,  0 },
    {    -24,   -7,  -16, 28,  6,  0 }, {    -25,   -7,  -16, 28,  6,  0 }, {    -26,   -8,  -17, 28,  6,  0 }, {    -27,   -9,  -17, 28,  6,  0 }, {    -28,  -10,  -18, 28,  6,  0 },
    {    -29,  -11,  -19, 28,  6,  0 }, {    -29,  -12,  -19, 28,  6,  0 }, {    -30,  -13,  -20, 27,  6,  0 }, {    -31,  -14,  -21, 27,  6,  0 }, {    -32,  -15,  -21, 27,  6,  0 },
    {    -32,  -16,  -22, 27,  6,  0 }, {    -33,  -17,  -22, 27,  6,  0 }, {    -34,  -18,  -23, 27,  6,  0 }, {    -34,  -19,  -24, 27,  6,  0 }, {    -35,  -20,  -24, 27,  6,  0 },
    {    -36,  -21,  -25, 27,  6,  0 }, {    -36,  -22,  -26, 27,  6,  0 }, {    -37,  -23,  -26, 27,  6,  0 }, {    -38,  -24,  -27, 27,  6,  0 }, {    -38,  -25,  -27, 27,  6,  0 },
    {    -39,  -26,  -28, 26,  6,  0 }, {    -39,  -27,  -29, 26,  6,  0 }, {    -40,  -28,  -29, 26,  6,  0 }, {    -40,  -29,  -30, 26,  6,  0 }, {    -41,  -30,  -30, 26,  6,  0 },
    {    -41,  -31,  -31, 26,  6,  0 }, {    -42,  -32,  -31, 26,  6,  0 }, {    -42,  -33,  -32, 26,  6,  0 }, {    -43,  -34,  -33, 26,  6,  0 }, {    -43,  -35,  -33, 26,  6,  0 },
    {    -43,  -36,  -34, 26,  6,  0 }, {    -44,  -37,  -34, 26,  6,  0 }, {    -44,  -38,  -35, 26,  6,  0 }, {    -44,  -39,  -35, 26,  6,  0 }, {    -45,  -40,  -36, 25,  6,  0 },
    {    -45,  -41,  -36, 25,  6,  0 }, {    -45,  -42,  -37, 25,  6,  0 }, {    -45,  -43,  -37, 25,  6,  0 }, {    -46,  -44,  -38, 25,  6,  0 }, {    -46,  -45,  -39, 25,  6,  0 },
    {    -46,  -46,  -39, 25,  6,  0 }, {    -46,  -47,  -40, 25,  6,  0 }, {    -46,  -48,  -40, 25,  6,  0 }, {    -47,  -49,  -40, 25,  6,  0 }, {    -47,  -50,  -41, 25,  6,  0 },
    {    -47,  -51,  -42, 25,  6,  0 }, {    -47,  -52,  -42, 25,  6,  0 }, {    -47,  -53,  -43, 25,  6,  0 }, {    -47,  -54,  -43, 25,  6,  0 }, {    -48,  -55,  -44, 25,  6,  0 },
    {    -48,  -56,  -44, 24,  6,  0 }, {    -48,  -57,  -45, 24,  6,  0 }, {    -48,  -58,  -45, 24,  6,  0 }, {    -48,  -59,  -46, 24,  6,  0 }, {    -48,  -60,  -46, 24,  6,  0 },
    {    -48,  -61,  -47, 24,  6,  0 }, {    -48,  -62,  -47, 24,  6,  0 }, {    -48,  -63,  -48, 24,  6,  0 }, {    -48,  -64,  -49, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D28A2, {
    {     16,    0,   15,  8,  6,  0 }, {     16,    1,   15,  8,  6,  0 }, {     16,    2,   15,  8,  6,  0 }, {     16,    3,   14,  8,  6,  0 }, {     16,    4,   14,  8,  6,  0 },
    {     16,    5,   13,  8,  6,  0 }, {     16,    6,   13,  8,  6,  0 }, {     16,    7,   12,  8,  6,  0 }, {     16,    8,   12,  7,  6,  0 }, {     15,    9,   11,  7,  6,  0 },
    {     15,   10,   11,  7,  6,  0 }, {     15,   11,   10,  7,  6,  0 }, {     15,   12,   10,  7,  6,  0 }, {     15,   13,    9,  7,  6,  0 }, {     15,   14,    9,  7,  6,  0 },
    {     14,   15,    8,  7,  6,  0 }, {     14,   16,    7,  7,  6,  0 }, {     14,   17,    7,  7,  6,  0 }, {     14,   18,    7,  7,  6,  0 }, {     14,   19,    6,  7,  6,  0 },
    {     13,   20,    6,  7,  6,  0 }, {     13,   21,    5,  7,  6,  0 }, {     13,   22,    4,  6,  6,  0 }, {     13,   23,    4,  6,  6,  0 }, {     12,   24,    3,  6,  6,  0 },
    {     12,   25,    3,  6,  6,  0 }, {     12,   26,    2,  6,  6,  0 }, {     11,   27,    2,  6,  6,  0 }, {     11,   28,    1,  6,  6,  0 }, {     11,   29,    1,  6,  6,  0 },
    {     10,   30,    0,  6,  6,  0 }, {     10,   31,    0,  6,  6,  0 }, {      9,   32,   -1,  6,  6,  0 }, {      9,   33,   -2,  6,  6,  0 }, {      8,   34,   -2,  6,  6,  0 },
    {      8,   35,   -3,  6,  6,  0 }, {      7,   36,   -3,  6,  6,  0 }, {      7,   37,   -4,  5,  6,  0 }, {      6,   38,   -4,  5,  6,  0 }, {      6,   39,   -5,  5,  6,  0 },
    {      5,   40,   -6,  5,  6,  0 }, {      4,   41,   -6,  5,  6,  0 }, {      4,   42,   -7,  5,  6,  0 }, {      3,   43,   -7,  5,  6,  0 }, {      2,   44,   -8,  5,  6,  0 },
    {      2,   45,   -9,  5,  6,  0 }, {      1,   46,   -9,  5,  6,  0 }, {      0,   47,  -10,  5,  6,  0 }, {      0,   48,  -11,  5,  6,  0 }, {     -1,   49,  -11,  5,  6,  0 },
    {     -2,   50,  -12,  4,  6,  0 }, {     -3,   51,  -12,  4,  6,  0 }, {     -3,   52,  -13,  4,  6,  0 }, {     -4,   53,  -14,  4,  6,  0 }, {     -5,   54,  -14,  4,  6,  0 },
    {     -6,   55,  -15,  4,  6,  0 }, {     -7,   56,  -16,  4,  6,  0 }, {     -7,   57,  -16,  4,  6,  0 }, {     -8,   58,  -17,  4,  6,  0 }, {     -9,   59,  -17,  4,  6,  0 },
    {    -10,   60,  -18,  4,  6,  0 }, {    -11,   61,  -19,  4,  6,  0 }, {    -12,   61,  -19,  4,  6,  0 }, {    -13,   62,  -20,  3,  6,  0 }, {    -14,   63,  -21,  3,  6,  0 },
    {    -15,   64,  -21,  3,  6,  0 }, {    -16,   64,  -22,  3,  6,  0 }, {    -17,   65,  -22,  3,  6,  0 }, {    -18,   66,  -23,  3,  6,  0 }, {    -19,   66,  -24,  3,  6,  0 },
    {    -20,   67,  -24,  3,  6,  0 }, {    -21,   68,  -25,  3,  6,  0 }, {    -22,   68,  -26,  3,  6,  0 }, {    -23,   69,  -26,  3,  6,  0 }, {    -24,   70,  -27,  3,  6,  0 },
    {    -25,   70,  -27,  3,  6,  0 }, {    -26,   71,  -28,  2,  6,  0 }, {    -27,   71,  -29,  2,  6,  0 }, {    -28,   72,  -29,  2,  6,  0 }, {    -29,   72,  -30,  2,  6,  0 },
    {    -30,   73,  -30,  2,  6,  0 }, {    -31,   73,  -31,  2,  6,  0 }, {    -32,   74,  -31,  2,  6,  0 }, {    -33,   74,  -32,  2,  6,  0 }, {    -34,   75,  -33,  2,  6,  0 },
    {    -35,   75,  -33,  2,  6,  0 }, {    -36,   75,  -34,  2,  6,  0 }, {    -37,   76,  -34,  2,  6,  0 }, {    -38,   76,  -35,  2,  6,  0 }, {    -39,   76,  -35,  2,  6,  0 },
    {    -40,   77,  -36,  1,  6,  0 }, {    -41,   77,  -36,  1,  6,  0 }, {    -42,   77,  -37,  1,  6,  0 }, {    -43,   77,  -37,  1,  6,  0 }, {    -44,   78,  -38,  1,  6,  0 },
    {    -45,   78,  -39,  1,  6,  0 }, {    -46,   78,  -39,  1,  6,  0 }, {    -47,   78,  -40,  1,  6,  0 }, {    -48,   78,  -40,  1,  6,  0 }, {    -49,   79,  -40,  1,  6,  0 },
    {    -50,   79,  -41,  1,  6,  0 }, {    -51,   79,  -42,  1,  6,  0 }, {    -52,   79,  -42,  1,  6,  0 }, {    -53,   79,  -43,  1,  6,  0 }, {    -54,   79,  -43,  1,  6,  0 },
    {    -55,   80,  -44,  1,  6,  0 }, {    -56,   80,  -44,  0,  6,  0 }, {    -57,   80,  -45,  0,  6,  0 }, {    -58,   80,  -45,  0,  6,  0 }, {    -59,   80,  -46,  0,  6,  0 },
    {    -60,   80,  -46,  0,  6,  0 }, {    -61,   80,  -47,  0,  6,  0 }, {    -62,   80,  -47,  0,  6,  0 }, {    -63,   80,  -48,  0,  6,  0 }, {    -64,   80,  -49,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D2CAF, {
    {      0,   16,   15, 16,  6,  0 }, {      1,   16,   15, 16,  6,  0 }, {      2,   16,   15, 16,  6,  0 }, {      3,   16,   14, 16,  6,  0 }, {      4,   16,   14, 16,  6,  0 },
    {      5,   16,   13, 16,  6,  0 }, {      6,   16,   13, 16,  6,  0 }, {      7,   16,   12, 16,  6,  0 }, {      8,   16,   12, 15,  6,  0 }, {      9,   17,   11, 15,  6,  0 },
    {     10,   17,   10, 15,  6,  0 }, {     11,   17,   10, 15,  6,  0 }, {     12,   17,   10, 15,  6,  0 }, {     13,   17,    9, 15,  6,  0 }, {     14,   17,    9, 15,  6,  0 },
    {     15,   18,    8, 15,  6,  0 }, {     16,   18,    7, 15,  6,  0 }, {     17,   18,    7, 15,  6,  0 }, {     18,   18,    6, 15,  6,  0 }, {     19,   18,    6, 15,  6,  0 },
    {     20,   19,    5, 15,  6,  0 }, {     21,   19,    5, 15,  6,  0 }, {     22,   19,    4, 14,  6,  0 }, {     23,   19,    4, 14,  6,  0 }, {     24,   20,    3, 14,  6,  0 },
    {     25,   20,    3, 14,  6,  0 }, {     26,   20,    2, 14,  6,  0 }, {     27,   21,    2, 14,  6,  0 }, {     28,   21,    1, 14,  6,  0 }, {     29,   21,    1, 14,  6,  0 },
    {     30,   22,    0, 14,  6,  0 }, {     31,   22,   -1, 14,  6,  0 }, {     32,   23,   -1, 14,  6,  0 }, {     33,   23,   -2, 14,  6,  0 }, {     34,   24,   -2, 14,  6,  0 },
    {     35,   24,   -3, 14,  6,  0 }, {     36,   25,   -3, 14,  6,  0 }, {     37,   25,   -4, 13,  6,  0 }, {     38,   26,   -5, 13,  6,  0 }, {     39,   26,   -5, 13,  6,  0 },
    {     40,   27,   -6, 13,  6,  0 }, {     41,   28,   -6, 13,  6,  0 }, {     42,   28,   -7, 13,  6,  0 }, {     43,   29,   -8, 13,  6,  0 }, {     44,   30,   -8, 13,  6,  0 },
    {     45,   30,   -9, 13,  6,  0 }, {     46,   31,   -9, 13,  6,  0 }, {     47,   32,  -10, 13,  6,  0 }, {     48,   32,  -11, 13,  6,  0 }, {     49,   33,  -11, 13,  6,  0 },
    {     50,   34,  -12, 12,  6,  0 }, {     51,   35,  -13, 12,  6,  0 }, {     52,   35,  -13, 12,  6,  0 }, {     53,   36,  -14, 12,  6,  0 }, {     54,   37,  -14, 12,  6,  0 },
    {     55,   38,  -15, 12,  6,  0 }, {     56,   39,  -16, 12,  6,  0 }, {     57,   39,  -17, 12,  6,  0 }, {     58,   40,  -17, 12,  6,  0 }, {     59,   41,  -18, 12,  6,  0 },
    {     60,   42,  -18, 12,  6,  0 }, {     61,   43,  -19, 12,  6,  0 }, {     61,   44,  -20, 12,  6,  0 }, {     62,   45,  -20, 11,  6,  0 }, {     63,   46,  -21, 11,  6,  0 },
    {     64,   47,  -22, 11,  6,  0 }, {     64,   48,  -22, 11,  6,  0 }, {     65,   49,  -23, 11,  6,  0 }, {     66,   50,  -23, 11,  6,  0 }, {     66,   51,  -24, 11,  6,  0 },
    {     67,   52,  -25, 11,  6,  0 }, {     68,   53,  -25, 11,  6,  0 }, {     68,   54,  -26, 11,  6,  0 }, {     69,   55,  -26, 11,  6,  0 }, {     70,   56,  -27, 11,  6,  0 },
    {     70,   57,  -28, 11,  6,  0 }, {     71,   58,  -28, 10,  6,  0 }, {     71,   59,  -29, 10,  6,  0 }, {     72,   60,  -29, 10,  6,  0 }, {     72,   61,  -30, 10,  6,  0 },
    {     73,   62,  -31, 10,  6,  0 }, {     73,   63,  -31, 10,  6,  0 }, {     74,   64,  -32, 10,  6,  0 }, {     74,   65,  -32, 10,  6,  0 }, {     75,   66,  -33, 10,  6,  0 },
    {     75,   67,  -34, 10,  6,  0 }, {     75,   68,  -34, 10,  6,  0 }, {     76,   69,  -35, 10,  6,  0 }, {     76,   70,  -35, 10,  6,  0 }, {     76,   71,  -36, 10,  6,  0 },
    {     77,   72,  -36,  9,  6,  0 }, {     77,   73,  -37,  9,  6,  0 }, {     77,   74,  -37,  9,  6,  0 }, {     77,   75,  -38,  9,  6,  0 }, {     78,   76,  -38,  9,  6,  0 },
    {     78,   77,  -39,  9,  6,  0 }, {     78,   78,  -39,  9,  6,  0 }, {     78,   79,  -40,  9,  6,  0 }, {     78,   80,  -40,  9,  6,  0 }, {     79,   81,  -41,  9,  6,  0 },
    {     79,   82,  -42,  9,  6,  0 }, {     79,   83,  -42,  9,  6,  0 }, {     79,   84,  -43,  9,  6,  0 }, {     79,   85,  -43,  9,  6,  0 }, {     79,   86,  -43,  9,  6,  0 },
    {     80,   87,  -44,  9,  6,  0 }, {     80,   88,  -45,  8,  6,  0 }, {     80,   89,  -45,  8,  6,  0 }, {     80,   90,  -46,  8,  6,  0 }, {     80,   91,  -46,  8,  6,  0 },
    {     80,   92,  -47,  8,  6,  0 }, {     80,   93,  -47,  8,  6,  0 }, {     80,   94,  -48,  8,  6,  0 }, {     80,   95,  -48,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D30B3, {
    {     16,   31,   15, 24,  6,  0 }, {     16,   30,   15, 24,  6,  0 }, {     16,   29,   14, 24,  6,  0 }, {     16,   28,   14, 24,  6,  0 }, {     16,   27,   13, 24,  6,  0 },
    {     16,   26,   13, 24,  6,  0 }, {     16,   25,   12, 24,  6,  0 }, {     16,   24,   12, 23,  6,  0 }, {     17,   23,   11, 23,  6,  0 }, {     17,   22,   10, 23,  6,  0 },
    {     17,   21,   10, 23,  6,  0 }, {     17,   20,   10, 23,  6,  0 }, {     17,   19,    9, 23,  6,  0 }, {     17,   18,    9, 23,  6,  0 }, {     18,   17,    8, 23,  6,  0 },
    {     18,   16,    7, 23,  6,  0 }, {     18,   15,    7, 23,  6,  0 }, {     18,   14,    6, 23,  6,  0 }, {     18,   13,    6, 23,  6,  0 }, {     19,   12,    5, 23,  6,  0 },
    {     19,   11,    5, 23,  6,  0 }, {     19,   10,    4, 22,  6,  0 }, {     19,    9,    4, 22,  6,  0 }, {     20,    8,    3, 22,  6,  0 }, {     20,    7,    3, 22,  6,  0 },
    {     20,    6,    2, 22,  6,  0 }, {     21,    5,    2, 22,  6,  0 }, {     21,    4,    1, 22,  6,  0 }, {     21,    3,    1, 22,  6,  0 }, {     22,    2,    0, 22,  6,  0 },
    {     22,    1,   -1, 22,  6,  0 }, {     23,    0,   -1, 22,  6,  0 }, {     23,   -1,   -2, 22,  6,  0 }, {     24,   -2,   -2, 22,  6,  0 }, {     24,   -3,   -3, 22,  6,  0 },
    {     25,   -4,   -3, 22,  6,  0 }, {     25,   -5,   -4, 21,  6,  0 }, {     26,   -6,   -5, 21,  6,  0 }, {     26,   -7,   -5, 21,  6,  0 }, {     27,   -8,   -6, 21,  6,  0 },
    {     28,   -9,   -6, 21,  6,  0 }, {     28,  -10,   -7, 21,  6,  0 }, {     29,  -11,   -8, 21,  6,  0 }, {     30,  -12,   -8, 21,  6,  0 }, {     30,  -13,   -9, 21,  6,  0 },
    {     31,  -14,   -9, 21,  6,  0 }, {     32,  -15,  -10, 21,  6,  0 }, {     32,  -16,  -11, 21,  6,  0 }, {     33,  -17,  -11, 21,  6,  0 }, {     34,  -18,  -12, 20,  6,  0 },
    {     35,  -19,  -13, 20,  6,  0 }, {     35,  -20,  -13, 20,  6,  0 }, {     36,  -21,  -14, 20,  6,  0 }, {     37,  -22,  -14, 20,  6,  0 }, {     38,  -23,  -15, 20,  6,  0 },
    {     39,  -24,  -16, 20,  6,  0 }, {     39,  -25,  -17, 20,  6,  0 }, {     40,  -26,  -17, 20,  6,  0 }, {     41,  -27,  -18, 20,  6,  0 }, {     42,  -28,  -18, 20,  6,  0 },
    {     43,  -29,  -19, 20,  6,  0 }, {     44,  -29,  -20, 20,  6,  0 }, {     45,  -30,  -20, 19,  6,  0 }, {     46,  -31,  -21, 19,  6,  0 }, {     47,  -32,  -22, 19,  6,  0 },
    {     48,  -32,  -22, 19,  6,  0 }, {     49,  -33,  -23, 19,  6,  0 }, {     50,  -34,  -23, 19,  6,  0 }, {     51,  -34,  -24, 19,  6,  0 }, {     52,  -35,  -25, 19,  6,  0 },
    {     53,  -36,  -25, 19,  6,  0 }, {     54,  -36,  -26, 19,  6,  0 }, {     55,  -37,  -26, 19,  6,  0 }, {     56,  -38,  -27, 19,  6,  0 }, {     57,  -38,  -28, 19,  6,  0 },
    {     58,  -39,  -28, 18,  6,  0 }, {     59,  -39,  -29, 18,  6,  0 }, {     60,  -40,  -29, 18,  6,  0 }, {     61,  -40,  -30, 18,  6,  0 }, {     62,  -41,  -31, 18,  6,  0 },
    {     63,  -41,  -31, 18,  6,  0 }, {     64,  -42,  -32, 18,  6,  0 }, {     65,  -42,  -32, 18,  6,  0 }, {     66,  -43,  -33, 18,  6,  0 }, {     67,  -43,  -34, 18,  6,  0 },
    {     68,  -43,  -34, 18,  6,  0 }, {     69,  -44,  -35, 18,  6,  0 }, {     70,  -44,  -35, 18,  6,  0 }, {     71,  -44,  -36, 18,  6,  0 }, {     72,  -45,  -36, 17,  6,  0 },
    {     73,  -45,  -37, 17,  6,  0 }, {     74,  -45,  -37, 17,  6,  0 }, {     75,  -45,  -38, 17,  6,  0 }, {     76,  -46,  -38, 17,  6,  0 }, {     77,  -46,  -39, 17,  6,  0 },
    {     78,  -46,  -39, 17,  6,  0 }, {     79,  -46,  -40, 17,  6,  0 }, {     80,  -46,  -40, 17,  6,  0 }, {     81,  -47,  -41, 17,  6,  0 }, {     82,  -47,  -42, 17,  6,  0 },
    {     83,  -47,  -42, 17,  6,  0 }, {     84,  -47,  -43, 17,  6,  0 }, {     85,  -47,  -43, 17,  6,  0 }, {     86,  -47,  -43, 17,  6,  0 }, {     87,  -48,  -44, 17,  6,  0 },
    {     88,  -48,  -45, 16,  6,  0 }, {     89,  -48,  -45, 16,  6,  0 }, {     90,  -48,  -46, 16,  6,  0 }, {     91,  -48,  -46, 16,  6,  0 }, {     92,  -48,  -47, 16,  6,  0 },
    {     93,  -48,  -47, 16,  6,  0 }, {     94,  -48,  -48, 16,  6,  0 }, {     95,  -48,  -48, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D34AE, {
    {     31,   16,   15,  0,  6,  0 }, {     30,   16,   15,  0,  6,  0 }, {     29,   16,   14,  0,  6,  0 }, {     28,   16,   14,  0,  6,  0 }, {     27,   16,   13,  0,  6,  0 },
    {     26,   16,   13,  0,  6,  0 }, {     25,   16,   12,  0,  6,  0 }, {     24,   16,   12,  1,  6,  0 }, {     23,   17,   11,  1,  6,  0 }, {     22,   17,   10,  1,  6,  0 },
    {     21,   17,   10,  1,  6,  0 }, {     20,   17,   10,  1,  6,  0 }, {     19,   17,    9,  1,  6,  0 }, {     18,   17,    9,  1,  6,  0 }, {     17,   18,    8,  1,  6,  0 },
    {     16,   18,    7,  1,  6,  0 }, {     15,   18,    7,  1,  6,  0 }, {     14,   18,    6,  1,  6,  0 }, {     13,   18,    6,  1,  6,  0 }, {     12,   19,    5,  1,  6,  0 },
    {     11,   19,    5,  1,  6,  0 }, {     10,   19,    4,  2,  6,  0 }, {      9,   19,    4,  2,  6,  0 }, {      8,   20,    3,  2,  6,  0 }, {      7,   20,    3,  2,  6,  0 },
    {      6,   20,    2,  2,  6,  0 }, {      5,   21,    2,  2,  6,  0 }, {      4,   21,    1,  2,  6,  0 }, {      3,   21,    1,  2,  6,  0 }, {      2,   22,    0,  2,  6,  0 },
    {      1,   22,   -1,  2,  6,  0 }, {      0,   23,   -1,  2,  6,  0 }, {     -1,   23,   -2,  2,  6,  0 }, {     -2,   24,   -2,  2,  6,  0 }, {     -3,   24,   -3,  2,  6,  0 },
    {     -4,   25,   -3,  2,  6,  0 }, {     -5,   25,   -4,  3,  6,  0 }, {     -6,   26,   -5,  3,  6,  0 }, {     -7,   26,   -5,  3,  6,  0 }, {     -8,   27,   -6,  3,  6,  0 },
    {     -9,   28,   -6,  3,  6,  0 }, {    -10,   28,   -7,  3,  6,  0 }, {    -11,   29,   -8,  3,  6,  0 }, {    -12,   30,   -8,  3,  6,  0 }, {    -13,   30,   -9,  3,  6,  0 },
    {    -14,   31,   -9,  3,  6,  0 }, {    -15,   32,  -10,  3,  6,  0 }, {    -16,   32,  -11,  3,  6,  0 }, {    -17,   33,  -11,  3,  6,  0 }, {    -18,   34,  -12,  4,  6,  0 },
    {    -19,   35,  -13,  4,  6,  0 }, {    -20,   35,  -13,  4,  6,  0 }, {    -21,   36,  -14,  4,  6,  0 }, {    -22,   37,  -14,  4,  6,  0 }, {    -23,   38,  -15,  4,  6,  0 },
    {    -24,   39,  -16,  4,  6,  0 }, {    -25,   39,  -17,  4,  6,  0 }, {    -26,   40,  -17,  4,  6,  0 }, {    -27,   41,  -18,  4,  6,  0 }, {    -28,   42,  -18,  4,  6,  0 },
    {    -29,   43,  -19,  4,  6,  0 }, {    -29,   44,  -20,  4,  6,  0 }, {    -30,   45,  -20,  5,  6,  0 }, {    -31,   46,  -21,  5,  6,  0 }, {    -32,   47,  -22,  5,  6,  0 },
    {    -32,   48,  -22,  5,  6,  0 }, {    -33,   49,  -23,  5,  6,  0 }, {    -34,   50,  -23,  5,  6,  0 }, {    -34,   51,  -24,  5,  6,  0 }, {    -35,   52,  -25,  5,  6,  0 },
    {    -36,   53,  -25,  5,  6,  0 }, {    -36,   54,  -26,  5,  6,  0 }, {    -37,   55,  -26,  5,  6,  0 }, {    -38,   56,  -27,  5,  6,  0 }, {    -38,   57,  -28,  5,  6,  0 },
    {    -39,   58,  -28,  6,  6,  0 }, {    -39,   59,  -29,  6,  6,  0 }, {    -40,   60,  -29,  6,  6,  0 }, {    -40,   61,  -30,  6,  6,  0 }, {    -41,   62,  -31,  6,  6,  0 },
    {    -41,   63,  -31,  6,  6,  0 }, {    -42,   64,  -32,  6,  6,  0 }, {    -42,   65,  -32,  6,  6,  0 }, {    -43,   66,  -33,  6,  6,  0 }, {    -43,   67,  -34,  6,  6,  0 },
    {    -43,   68,  -34,  6,  6,  0 }, {    -44,   69,  -35,  6,  6,  0 }, {    -44,   70,  -35,  6,  6,  0 }, {    -44,   71,  -36,  6,  6,  0 }, {    -45,   72,  -36,  7,  6,  0 },
    {    -45,   73,  -37,  7,  6,  0 }, {    -45,   74,  -37,  7,  6,  0 }, {    -45,   75,  -38,  7,  6,  0 }, {    -46,   76,  -38,  7,  6,  0 }, {    -46,   77,  -39,  7,  6,  0 },
    {    -46,   78,  -39,  7,  6,  0 }, {    -46,   79,  -40,  7,  6,  0 }, {    -46,   80,  -40,  7,  6,  0 }, {    -47,   81,  -41,  7,  6,  0 }, {    -47,   82,  -42,  7,  6,  0 },
    {    -47,   83,  -42,  7,  6,  0 }, {    -47,   84,  -43,  7,  6,  0 }, {    -47,   85,  -43,  7,  6,  0 }, {    -47,   86,  -43,  7,  6,  0 }, {    -48,   87,  -44,  7,  6,  0 },
    {    -48,   88,  -45,  8,  6,  0 }, {    -48,   89,  -45,  8,  6,  0 }, {    -48,   90,  -46,  8,  6,  0 }, {    -48,   91,  -46,  8,  6,  0 }, {    -48,   92,  -47,  8,  6,  0 },
    {    -48,   93,  -47,  8,  6,  0 }, {    -48,   94,  -48,  8,  6,  0 }, {    -48,   95,  -48,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D38A9, {
    {     16,    0,   15,  8,  6,  0 }, {     16,    1,   15,  8,  6,  0 }, {     16,    2,   15,  8,  6,  0 }, {     16,    3,   14,  8,  6,  0 }, {     16,    4,   14,  8,  6,  0 },
    {     16,    5,   13,  8,  6,  0 }, {     16,    6,   13,  8,  6,  0 }, {     16,    7,   12,  8,  6,  0 }, {     16,    8,   12,  9,  6,  0 }, {     17,    9,   11,  9,  6,  0 },
    {     17,   10,   10,  9,  6,  0 }, {     17,   11,   10,  9,  6,  0 }, {     17,   12,   10,  9,  6,  0 }, {     17,   13,    9,  9,  6,  0 }, {     17,   14,    9,  9,  6,  0 },
    {     18,   15,    8,  9,  6,  0 }, {     18,   16,    7,  9,  6,  0 }, {     18,   17,    7,  9,  6,  0 }, {     18,   18,    6,  9,  6,  0 }, {     18,   19,    6,  9,  6,  0 },
    {     19,   20,    5,  9,  6,  0 }, {     19,   21,    5,  9,  6,  0 }, {     19,   22,    4, 10,  6,  0 }, {     19,   23,    4, 10,  6,  0 }, {     20,   24,    3, 10,  6,  0 },
    {     20,   25,    3, 10,  6,  0 }, {     20,   26,    2, 10,  6,  0 }, {     21,   27,    2, 10,  6,  0 }, {     21,   28,    1, 10,  6,  0 }, {     21,   29,    1, 10,  6,  0 },
    {     22,   30,    0, 10,  6,  0 }, {     22,   31,   -1, 10,  6,  0 }, {     23,   32,   -1, 10,  6,  0 }, {     23,   33,   -2, 10,  6,  0 }, {     24,   34,   -2, 10,  6,  0 },
    {     24,   35,   -3, 10,  6,  0 }, {     25,   36,   -3, 10,  6,  0 }, {     25,   37,   -4, 11,  6,  0 }, {     26,   38,   -5, 11,  6,  0 }, {     26,   39,   -5, 11,  6,  0 },
    {     27,   40,   -6, 11,  6,  0 }, {     28,   41,   -6, 11,  6,  0 }, {     28,   42,   -7, 11,  6,  0 }, {     29,   43,   -8, 11,  6,  0 }, {     30,   44,   -8, 11,  6,  0 },
    {     30,   45,   -9, 11,  6,  0 }, {     31,   46,   -9, 11,  6,  0 }, {     32,   47,  -10, 11,  6,  0 }, {     32,   48,  -11, 11,  6,  0 }, {     33,   49,  -11, 11,  6,  0 },
    {     34,   50,  -12, 12,  6,  0 }, {     35,   51,  -13, 12,  6,  0 }, {     35,   52,  -13, 12,  6,  0 }, {     36,   53,  -14, 12,  6,  0 }, {     37,   54,  -14, 12,  6,  0 },
    {     38,   55,  -15, 12,  6,  0 }, {     39,   56,  -16, 12,  6,  0 }, {     39,   57,  -17, 12,  6,  0 }, {     40,   58,  -17, 12,  6,  0 }, {     41,   59,  -18, 12,  6,  0 },
    {     42,   60,  -18, 12,  6,  0 }, {     43,   61,  -19, 12,  6,  0 }, {     44,   61,  -20, 12,  6,  0 }, {     45,   62,  -20, 13,  6,  0 }, {     46,   63,  -21, 13,  6,  0 },
    {     47,   64,  -22, 13,  6,  0 }, {     48,   64,  -22, 13,  6,  0 }, {     49,   65,  -23, 13,  6,  0 }, {     50,   66,  -23, 13,  6,  0 }, {     51,   66,  -24, 13,  6,  0 },
    {     52,   67,  -25, 13,  6,  0 }, {     53,   68,  -25, 13,  6,  0 }, {     54,   68,  -26, 13,  6,  0 }, {     55,   69,  -26, 13,  6,  0 }, {     56,   70,  -27, 13,  6,  0 },
    {     57,   70,  -28, 13,  6,  0 }, {     58,   71,  -28, 14,  6,  0 }, {     59,   71,  -29, 14,  6,  0 }, {     60,   72,  -29, 14,  6,  0 }, {     61,   72,  -30, 14,  6,  0 },
    {     62,   73,  -31, 14,  6,  0 }, {     63,   73,  -31, 14,  6,  0 }, {     64,   74,  -32, 14,  6,  0 }, {     65,   74,  -32, 14,  6,  0 }, {     66,   75,  -33, 14,  6,  0 },
    {     67,   75,  -34, 14,  6,  0 }, {     68,   75,  -34, 14,  6,  0 }, {     69,   76,  -35, 14,  6,  0 }, {     70,   76,  -35, 14,  6,  0 }, {     71,   76,  -36, 14,  6,  0 },
    {     72,   77,  -36, 15,  6,  0 }, {     73,   77,  -37, 15,  6,  0 }, {     74,   77,  -37, 15,  6,  0 }, {     75,   77,  -38, 15,  6,  0 }, {     76,   78,  -38, 15,  6,  0 },
    {     77,   78,  -39, 15,  6,  0 }, {     78,   78,  -39, 15,  6,  0 }, {     79,   78,  -40, 15,  6,  0 }, {     80,   78,  -40, 15,  6,  0 }, {     81,   79,  -41, 15,  6,  0 },
    {     82,   79,  -42, 15,  6,  0 }, {     83,   79,  -42, 15,  6,  0 }, {     84,   79,  -43, 15,  6,  0 }, {     85,   79,  -43, 15,  6,  0 }, {     86,   79,  -43, 15,  6,  0 },
    {     87,   80,  -44, 15,  6,  0 }, {     88,   80,  -45, 16,  6,  0 }, {     89,   80,  -45, 16,  6,  0 }, {     90,   80,  -46, 16,  6,  0 }, {     91,   80,  -46, 16,  6,  0 },
    {     92,   80,  -47, 16,  6,  0 }, {     93,   80,  -47, 16,  6,  0 }, {     94,   80,  -48, 16,  6,  0 }, {     95,   80,  -48, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D3CAD, {
    {      0,   16,   15, 16,  6,  0 }, {      1,   16,   15, 16,  6,  0 }, {      2,   16,   15, 16,  6,  0 }, {      3,   16,   14, 16,  6,  0 }, {      4,   16,   14, 16,  6,  0 },
    {      5,   16,   13, 16,  6,  0 }, {      6,   16,   13, 16,  6,  0 }, {      7,   16,   12, 16,  6,  0 }, {      8,   16,   12, 17,  6,  0 }, {      9,   15,   11, 17,  6,  0 },
    {     10,   15,   11, 17,  6,  0 }, {     11,   15,   10, 17,  6,  0 }, {     12,   15,   10, 17,  6,  0 }, {     13,   15,    9, 17,  6,  0 }, {     14,   15,    9, 17,  6,  0 },
    {     15,   14,    8, 17,  6,  0 }, {     16,   14,    7, 17,  6,  0 }, {     17,   14,    7, 17,  6,  0 }, {     18,   14,    7, 17,  6,  0 }, {     19,   14,    6, 17,  6,  0 },
    {     20,   13,    6, 17,  6,  0 }, {     21,   13,    5, 17,  6,  0 }, {     22,   13,    4, 18,  6,  0 }, {     23,   13,    4, 18,  6,  0 }, {     24,   12,    3, 18,  6,  0 },
    {     25,   12,    3, 18,  6,  0 }, {     26,   12,    2, 18,  6,  0 }, {     27,   11,    2, 18,  6,  0 }, {     28,   11,    1, 18,  6,  0 }, {     29,   11,    1, 18,  6,  0 },
    {     30,   10,    0, 18,  6,  0 }, {     31,   10,    0, 18,  6,  0 }, {     32,    9,   -1, 18,  6,  0 }, {     33,    9,   -2, 18,  6,  0 }, {     34,    8,   -2, 18,  6,  0 },
    {     35,    8,   -3, 18,  6,  0 }, {     36,    7,   -3, 18,  6,  0 }, {     37,    7,   -4, 19,  6,  0 }, {     38,    6,   -4, 19,  6,  0 }, {     39,    6,   -5, 19,  6,  0 },
    {     40,    5,   -6, 19,  6,  0 }, {     41,    4,   -6, 19,  6,  0 }, {     42,    4,   -7, 19,  6,  0 }, {     43,    3,   -7, 19,  6,  0 }, {     44,    2,   -8, 19,  6,  0 },
    {     45,    2,   -9, 19,  6,  0 }, {     46,    1,   -9, 19,  6,  0 }, {     47,    0,  -10, 19,  6,  0 }, {     48,    0,  -11, 19,  6,  0 }, {     49,   -1,  -11, 19,  6,  0 },
    {     50,   -2,  -12, 20,  6,  0 }, {     51,   -3,  -12, 20,  6,  0 }, {     52,   -3,  -13, 20,  6,  0 }, {     53,   -4,  -14, 20,  6,  0 }, {     54,   -5,  -14, 20,  6,  0 },
    {     55,   -6,  -15, 20,  6,  0 }, {     56,   -7,  -16, 20,  6,  0 }, {     57,   -7,  -16, 20,  6,  0 }, {     58,   -8,  -17, 20,  6,  0 }, {     59,   -9,  -17, 20,  6,  0 },
    {     60,  -10,  -18, 20,  6,  0 }, {     61,  -11,  -19, 20,  6,  0 }, {     61,  -12,  -19, 20,  6,  0 }, {     62,  -13,  -20, 21,  6,  0 }, {     63,  -14,  -21, 21,  6,  0 },
    {     64,  -15,  -21, 21,  6,  0 }, {     64,  -16,  -22, 21,  6,  0 }, {     65,  -17,  -22, 21,  6,  0 }, {     66,  -18,  -23, 21,  6,  0 }, {     66,  -19,  -24, 21,  6,  0 },
    {     67,  -20,  -24, 21,  6,  0 }, {     68,  -21,  -25, 21,  6,  0 }, {     68,  -22,  -26, 21,  6,  0 }, {     69,  -23,  -26, 21,  6,  0 }, {     70,  -24,  -27, 21,  6,  0 },
    {     70,  -25,  -27, 21,  6,  0 }, {     71,  -26,  -28, 22,  6,  0 }, {     71,  -27,  -29, 22,  6,  0 }, {     72,  -28,  -29, 22,  6,  0 }, {     72,  -29,  -30, 22,  6,  0 },
    {     73,  -30,  -30, 22,  6,  0 }, {     73,  -31,  -31, 22,  6,  0 }, {     74,  -32,  -31, 22,  6,  0 }, {     74,  -33,  -32, 22,  6,  0 }, {     75,  -34,  -33, 22,  6,  0 },
    {     75,  -35,  -33, 22,  6,  0 }, {     75,  -36,  -34, 22,  6,  0 }, {     76,  -37,  -34, 22,  6,  0 }, {     76,  -38,  -35, 22,  6,  0 }, {     76,  -39,  -35, 22,  6,  0 },
    {     77,  -40,  -36, 23,  6,  0 }, {     77,  -41,  -36, 23,  6,  0 }, {     77,  -42,  -37, 23,  6,  0 }, {     77,  -43,  -37, 23,  6,  0 }, {     78,  -44,  -38, 23,  6,  0 },
    {     78,  -45,  -39, 23,  6,  0 }, {     78,  -46,  -39, 23,  6,  0 }, {     78,  -47,  -40, 23,  6,  0 }, {     78,  -48,  -40, 23,  6,  0 }, {     79,  -49,  -40, 23,  6,  0 },
    {     79,  -50,  -41, 23,  6,  0 }, {     79,  -51,  -42, 23,  6,  0 }, {     79,  -52,  -42, 23,  6,  0 }, {     79,  -53,  -43, 23,  6,  0 }, {     79,  -54,  -43, 23,  6,  0 },
    {     80,  -55,  -44, 23,  6,  0 }, {     80,  -56,  -44, 24,  6,  0 }, {     80,  -57,  -45, 24,  6,  0 }, {     80,  -58,  -45, 24,  6,  0 }, {     80,  -59,  -46, 24,  6,  0 },
    {     80,  -60,  -46, 24,  6,  0 }, {     80,  -61,  -47, 24,  6,  0 }, {     80,  -62,  -47, 24,  6,  0 }, {     80,  -63,  -48, 24,  6,  0 }, {     80,  -64,  -49, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D40BA, {
    {     16,   31,   15, 24,  6,  0 }, {     16,   30,   15, 24,  6,  0 }, {     16,   29,   14, 24,  6,  0 }, {     16,   28,   14, 24,  6,  0 }, {     16,   27,   13, 24,  6,  0 },
    {     16,   26,   13, 24,  6,  0 }, {     16,   25,   12, 24,  6,  0 }, {     16,   24,   12, 25,  6,  0 }, {     15,   23,   11, 25,  6,  0 }, {     15,   22,   11, 25,  6,  0 },
    {     15,   21,   10, 25,  6,  0 }, {     15,   20,   10, 25,  6,  0 }, {     15,   19,    9, 25,  6,  0 }, {     15,   18,    9, 25,  6,  0 }, {     14,   17,    8, 25,  6,  0 },
    {     14,   16,    7, 25,  6,  0 }, {     14,   15,    7, 25,  6,  0 }, {     14,   14,    7, 25,  6,  0 }, {     14,   13,    6, 25,  6,  0 }, {     13,   12,    6, 25,  6,  0 },
    {     13,   11,    5, 25,  6,  0 }, {     13,   10,    4, 26,  6,  0 }, {     13,    9,    4, 26,  6,  0 }, {     12,    8,    3, 26,  6,  0 }, {     12,    7,    3, 26,  6,  0 },
    {     12,    6,    2, 26,  6,  0 }, {     11,    5,    2, 26,  6,  0 }, {     11,    4,    1, 26,  6,  0 }, {     11,    3,    1, 26,  6,  0 }, {     10,    2,    0, 26,  6,  0 },
    {     10,    1,    0, 26,  6,  0 }, {      9,    0,   -1, 26,  6,  0 }, {      9,   -1,   -2, 26,  6,  0 }, {      8,   -2,   -2, 26,  6,  0 }, {      8,   -3,   -3, 26,  6,  0 },
    {      7,   -4,   -3, 26,  6,  0 }, {      7,   -5,   -4, 27,  6,  0 }, {      6,   -6,   -4, 27,  6,  0 }, {      6,   -7,   -5, 27,  6,  0 }, {      5,   -8,   -6, 27,  6,  0 },
    {      4,   -9,   -6, 27,  6,  0 }, {      4,  -10,   -7, 27,  6,  0 }, {      3,  -11,   -7, 27,  6,  0 }, {      2,  -12,   -8, 27,  6,  0 }, {      2,  -13,   -9, 27,  6,  0 },
    {      1,  -14,   -9, 27,  6,  0 }, {      0,  -15,  -10, 27,  6,  0 }, {      0,  -16,  -11, 27,  6,  0 }, {     -1,  -17,  -11, 27,  6,  0 }, {     -2,  -18,  -12, 28,  6,  0 },
    {     -3,  -19,  -12, 28,  6,  0 }, {     -3,  -20,  -13, 28,  6,  0 }, {     -4,  -21,  -14, 28,  6,  0 }, {     -5,  -22,  -14, 28,  6,  0 }, {     -6,  -23,  -15, 28,  6,  0 },
    {     -7,  -24,  -16, 28,  6,  0 }, {     -7,  -25,  -16, 28,  6,  0 }, {     -8,  -26,  -17, 28,  6,  0 }, {     -9,  -27,  -17, 28,  6,  0 }, {    -10,  -28,  -18, 28,  6,  0 },
    {    -11,  -29,  -19, 28,  6,  0 }, {    -12,  -29,  -19, 28,  6,  0 }, {    -13,  -30,  -20, 29,  6,  0 }, {    -14,  -31,  -21, 29,  6,  0 }, {    -15,  -32,  -21, 29,  6,  0 },
    {    -16,  -32,  -22, 29,  6,  0 }, {    -17,  -33,  -22, 29,  6,  0 }, {    -18,  -34,  -23, 29,  6,  0 }, {    -19,  -34,  -24, 29,  6,  0 }, {    -20,  -35,  -24, 29,  6,  0 },
    {    -21,  -36,  -25, 29,  6,  0 }, {    -22,  -36,  -26, 29,  6,  0 }, {    -23,  -37,  -26, 29,  6,  0 }, {    -24,  -38,  -27, 29,  6,  0 }, {    -25,  -38,  -27, 29,  6,  0 },
    {    -26,  -39,  -28, 30,  6,  0 }, {    -27,  -39,  -29, 30,  6,  0 }, {    -28,  -40,  -29, 30,  6,  0 }, {    -29,  -40,  -30, 30,  6,  0 }, {    -30,  -41,  -30, 30,  6,  0 },
    {    -31,  -41,  -31, 30,  6,  0 }, {    -32,  -42,  -31, 30,  6,  0 }, {    -33,  -42,  -32, 30,  6,  0 }, {    -34,  -43,  -33, 30,  6,  0 }, {    -35,  -43,  -33, 30,  6,  0 },
    {    -36,  -43,  -34, 30,  6,  0 }, {    -37,  -44,  -34, 30,  6,  0 }, {    -38,  -44,  -35, 30,  6,  0 }, {    -39,  -44,  -35, 30,  6,  0 }, {    -40,  -45,  -36, 31,  6,  0 },
    {    -41,  -45,  -36, 31,  6,  0 }, {    -42,  -45,  -37, 31,  6,  0 }, {    -43,  -45,  -37, 31,  6,  0 }, {    -44,  -46,  -38, 31,  6,  0 }, {    -45,  -46,  -39, 31,  6,  0 },
    {    -46,  -46,  -39, 31,  6,  0 }, {    -47,  -46,  -40, 31,  6,  0 }, {    -48,  -46,  -40, 31,  6,  0 }, {    -49,  -47,  -40, 31,  6,  0 }, {    -50,  -47,  -41, 31,  6,  0 },
    {    -51,  -47,  -42, 31,  6,  0 }, {    -52,  -47,  -42, 31,  6,  0 }, {    -53,  -47,  -43, 31,  6,  0 }, {    -54,  -47,  -43, 31,  6,  0 }, {    -55,  -48,  -44, 31,  6,  0 },
    {    -56,  -48,  -44,  0,  6,  0 }, {    -57,  -48,  -45,  0,  6,  0 }, {    -58,  -48,  -45,  0,  6,  0 }, {    -59,  -48,  -46,  0,  6,  0 }, {    -60,  -48,  -46,  0,  6,  0 },
    {    -61,  -48,  -47,  0,  6,  0 }, {    -62,  -48,  -47,  0,  6,  0 }, {    -63,  -48,  -48,  0,  6,  0 }, {    -64,  -48,  -49,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CC0D2, {
    {     32,   16,    0,  0,  0,  0 }, {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 },
    {     27,   16,    0,  0,  0,  0 }, {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0, 31,  0,  0 }, {     23,   15,    0, 31,  0,  0 },
    {     22,   15,    0, 31,  0,  0 }, {     21,   15,    0, 31,  0,  0 }, {     20,   15,    0, 31,  0,  0 }, {     19,   15,    0, 31,  0,  0 }, {     18,   15,    0, 31,  0,  0 },
    {     17,   14,    0, 31,  0,  0 }, {     16,   14,    0, 31,  0,  0 }, {     15,   14,    0, 31,  0,  0 }, {     14,   14,    0, 31,  0,  0 }, {     13,   14,    0, 31,  0,  0 },
    {     12,   13,    0, 31,  0,  0 }, {     11,   13,    0, 31,  0,  0 }, {     10,   13,    0, 30,  0,  0 }, {      9,   13,    0, 30,  0,  0 }, {      8,   12,    0, 30,  0,  0 },
    {      7,   12,    0, 30,  0,  0 }, {      6,   12,    0, 30,  0,  0 }, {      5,   11,    0, 30,  0,  0 }, {      4,   11,    0, 30,  0,  0 }, {      3,   11,    0, 30,  0,  0 },
    {      2,   10,    0, 30,  0,  0 }, {      1,   10,    0, 30,  0,  0 }, {      0,    9,    0, 30,  0,  0 }, {     -1,    9,    0, 30,  0,  0 }, {     -2,    8,    0, 30,  0,  0 },
    {     -3,    8,    0, 30,  0,  0 }, {     -4,    7,    0, 29,  0,  0 }, {     -5,    7,    0, 29,  0,  0 }, {     -6,    6,    0, 29,  0,  0 }, {     -7,    6,    0, 29,  0,  0 },
    {     -8,    5,    0, 29,  0,  0 }, {     -9,    4,    0, 29,  0,  0 }, {    -10,    4,    0, 29,  0,  0 }, {    -11,    3,    0, 29,  0,  0 }, {    -12,    2,    0, 29,  0,  0 },
    {    -13,    2,    0, 29,  0,  0 }, {    -14,    1,    0, 29,  0,  0 }, {    -15,    0,    0, 29,  0,  0 }, {    -16,    0,    0, 29,  0,  0 }, {    -17,   -1,    0, 29,  0,  0 },
    {    -18,   -2,    0, 29,  0,  0 }, {    -19,   -2,    0, 29,  0,  0 }, {    -20,   -3,    0, 29,  0,  0 }, {    -21,   -4,    0, 29,  0,  0 }, {    -22,   -4,    0, 29,  0,  0 },
    {    -23,   -5,    0, 29,  0,  0 }, {    -24,   -6,    0, 29,  0,  0 }, {    -25,   -6,    0, 29,  0,  0 }, {    -26,   -7,    0, 29,  0,  0 }, {    -27,   -7,    0, 29,  0,  0 },
    {    -28,   -8,    0, 30,  0,  0 }, {    -29,   -8,    0, 30,  0,  0 }, {    -30,   -9,    0, 30,  0,  0 }, {    -31,   -9,    0, 30,  0,  0 }, {    -32,  -10,    0, 30,  0,  0 },
    {    -33,  -10,    0, 30,  0,  0 }, {    -34,  -11,    0, 30,  0,  0 }, {    -35,  -11,    0, 30,  0,  0 }, {    -36,  -11,    0, 30,  0,  0 }, {    -37,  -12,    0, 30,  0,  0 },
    {    -38,  -12,    0, 30,  0,  0 }, {    -39,  -12,    0, 30,  0,  0 }, {    -40,  -13,    0, 30,  0,  0 }, {    -41,  -13,    0, 31,  0,  0 }, {    -42,  -13,    0, 31,  0,  0 },
    {    -43,  -13,    0, 31,  0,  0 }, {    -44,  -14,    0, 31,  0,  0 }, {    -45,  -14,    0, 31,  0,  0 }, {    -46,  -14,    0, 31,  0,  0 }, {    -47,  -14,    0, 31,  0,  0 },
    {    -48,  -14,    0, 31,  0,  0 }, {    -49,  -15,    0, 31,  0,  0 }, {    -50,  -15,    0, 31,  0,  0 }, {    -51,  -15,    0, 31,  0,  0 }, {    -52,  -15,    0, 31,  0,  0 },
    {    -53,  -15,    0, 31,  0,  0 }, {    -54,  -15,    0, 31,  0,  0 }, {    -55,  -16,    0, 31,  0,  0 }, {    -56,  -16,    0,  0,  0,  0 }, {    -57,  -16,    0,  0,  0,  0 },
    {    -58,  -16,    0,  0,  0,  0 }, {    -59,  -16,    0,  0,  0,  0 }, {    -60,  -16,    0,  0,  0,  0 }, {    -61,  -16,    0,  0,  0,  0 }, {    -62,  -16,    0,  0,  0,  0 },
    {    -63,  -16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CC434, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  7,  0,  0 }, {     15,    9,    0,  7,  0,  0 },
    {     15,   10,    0,  7,  0,  0 }, {     15,   11,    0,  7,  0,  0 }, {     15,   12,    0,  7,  0,  0 }, {     15,   13,    0,  7,  0,  0 }, {     15,   14,    0,  7,  0,  0 },
    {     14,   15,    0,  7,  0,  0 }, {     14,   16,    0,  7,  0,  0 }, {     14,   17,    0,  7,  0,  0 }, {     14,   18,    0,  7,  0,  0 }, {     14,   19,    0,  7,  0,  0 },
    {     13,   20,    0,  7,  0,  0 }, {     13,   21,    0,  7,  0,  0 }, {     13,   22,    0,  6,  0,  0 }, {     13,   23,    0,  6,  0,  0 }, {     12,   24,    0,  6,  0,  0 },
    {     12,   25,    0,  6,  0,  0 }, {     12,   26,    0,  6,  0,  0 }, {     11,   27,    0,  6,  0,  0 }, {     11,   28,    0,  6,  0,  0 }, {     11,   29,    0,  6,  0,  0 },
    {     10,   30,    0,  6,  0,  0 }, {     10,   31,    0,  6,  0,  0 }, {      9,   32,    0,  6,  0,  0 }, {      9,   33,    0,  6,  0,  0 }, {      8,   34,    0,  6,  0,  0 },
    {      8,   35,    0,  6,  0,  0 }, {      7,   36,    0,  5,  0,  0 }, {      7,   37,    0,  5,  0,  0 }, {      6,   38,    0,  5,  0,  0 }, {      6,   39,    0,  5,  0,  0 },
    {      5,   40,    0,  5,  0,  0 }, {      4,   41,    0,  5,  0,  0 }, {      4,   42,    0,  5,  0,  0 }, {      3,   43,    0,  5,  0,  0 }, {      2,   44,    0,  5,  0,  0 },
    {      2,   45,    0,  5,  0,  0 }, {      1,   46,    0,  5,  0,  0 }, {      0,   47,    0,  5,  0,  0 }, {      0,   48,    0,  5,  0,  0 }, {     -1,   49,    0,  5,  0,  0 },
    {     -2,   50,    0,  5,  0,  0 }, {     -2,   51,    0,  5,  0,  0 }, {     -3,   52,    0,  5,  0,  0 }, {     -4,   53,    0,  5,  0,  0 }, {     -4,   54,    0,  5,  0,  0 },
    {     -5,   55,    0,  5,  0,  0 }, {     -6,   56,    0,  5,  0,  0 }, {     -6,   57,    0,  5,  0,  0 }, {     -7,   58,    0,  5,  0,  0 }, {     -7,   59,    0,  5,  0,  0 },
    {     -8,   60,    0,  6,  0,  0 }, {     -8,   61,    0,  6,  0,  0 }, {     -9,   62,    0,  6,  0,  0 }, {     -9,   63,    0,  6,  0,  0 }, {    -10,   64,    0,  6,  0,  0 },
    {    -10,   65,    0,  6,  0,  0 }, {    -11,   66,    0,  6,  0,  0 }, {    -11,   67,    0,  6,  0,  0 }, {    -11,   68,    0,  6,  0,  0 }, {    -12,   69,    0,  6,  0,  0 },
    {    -12,   70,    0,  6,  0,  0 }, {    -12,   71,    0,  6,  0,  0 }, {    -13,   72,    0,  6,  0,  0 }, {    -13,   73,    0,  7,  0,  0 }, {    -13,   74,    0,  7,  0,  0 },
    {    -13,   75,    0,  7,  0,  0 }, {    -14,   76,    0,  7,  0,  0 }, {    -14,   77,    0,  7,  0,  0 }, {    -14,   78,    0,  7,  0,  0 }, {    -14,   79,    0,  7,  0,  0 },
    {    -14,   80,    0,  7,  0,  0 }, {    -15,   81,    0,  7,  0,  0 }, {    -15,   82,    0,  7,  0,  0 }, {    -15,   83,    0,  7,  0,  0 }, {    -15,   84,    0,  7,  0,  0 },
    {    -15,   85,    0,  7,  0,  0 }, {    -15,   86,    0,  7,  0,  0 }, {    -16,   87,    0,  7,  0,  0 }, {    -16,   88,    0,  8,  0,  0 }, {    -16,   89,    0,  8,  0,  0 },
    {    -16,   90,    0,  8,  0,  0 }, {    -16,   91,    0,  8,  0,  0 }, {    -16,   92,    0,  8,  0,  0 }, {    -16,   93,    0,  8,  0,  0 }, {    -16,   94,    0,  8,  0,  0 },
    {    -16,   95,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CC796, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 15,  0,  0 }, {      9,   17,    0, 15,  0,  0 },
    {     10,   17,    0, 15,  0,  0 }, {     11,   17,    0, 15,  0,  0 }, {     12,   17,    0, 15,  0,  0 }, {     13,   17,    0, 15,  0,  0 }, {     14,   17,    0, 15,  0,  0 },
    {     15,   18,    0, 15,  0,  0 }, {     16,   18,    0, 15,  0,  0 }, {     17,   18,    0, 15,  0,  0 }, {     18,   18,    0, 15,  0,  0 }, {     19,   18,    0, 15,  0,  0 },
    {     20,   19,    0, 15,  0,  0 }, {     21,   19,    0, 15,  0,  0 }, {     22,   19,    0, 14,  0,  0 }, {     23,   19,    0, 14,  0,  0 }, {     24,   20,    0, 14,  0,  0 },
    {     25,   20,    0, 14,  0,  0 }, {     26,   20,    0, 14,  0,  0 }, {     27,   21,    0, 14,  0,  0 }, {     28,   21,    0, 14,  0,  0 }, {     29,   21,    0, 14,  0,  0 },
    {     30,   22,    0, 14,  0,  0 }, {     31,   22,    0, 14,  0,  0 }, {     32,   23,    0, 14,  0,  0 }, {     33,   23,    0, 14,  0,  0 }, {     34,   24,    0, 14,  0,  0 },
    {     35,   24,    0, 14,  0,  0 }, {     36,   25,    0, 13,  0,  0 }, {     37,   25,    0, 13,  0,  0 }, {     38,   26,    0, 13,  0,  0 }, {     39,   26,    0, 13,  0,  0 },
    {     40,   27,    0, 13,  0,  0 }, {     41,   28,    0, 13,  0,  0 }, {     42,   28,    0, 13,  0,  0 }, {     43,   29,    0, 13,  0,  0 }, {     44,   30,    0, 13,  0,  0 },
    {     45,   30,    0, 13,  0,  0 }, {     46,   31,    0, 13,  0,  0 }, {     47,   32,    0, 13,  0,  0 }, {     48,   32,    0, 13,  0,  0 }, {     49,   33,    0, 13,  0,  0 },
    {     50,   34,    0, 13,  0,  0 }, {     51,   34,    0, 13,  0,  0 }, {     52,   35,    0, 13,  0,  0 }, {     53,   36,    0, 13,  0,  0 }, {     54,   36,    0, 13,  0,  0 },
    {     55,   37,    0, 13,  0,  0 }, {     56,   38,    0, 13,  0,  0 }, {     57,   38,    0, 13,  0,  0 }, {     58,   39,    0, 13,  0,  0 }, {     59,   39,    0, 13,  0,  0 },
    {     60,   40,    0, 14,  0,  0 }, {     61,   40,    0, 14,  0,  0 }, {     62,   41,    0, 14,  0,  0 }, {     63,   41,    0, 14,  0,  0 }, {     64,   42,    0, 14,  0,  0 },
    {     65,   42,    0, 14,  0,  0 }, {     66,   43,    0, 14,  0,  0 }, {     67,   43,    0, 14,  0,  0 }, {     68,   43,    0, 14,  0,  0 }, {     69,   44,    0, 14,  0,  0 },
    {     70,   44,    0, 14,  0,  0 }, {     71,   44,    0, 14,  0,  0 }, {     72,   45,    0, 14,  0,  0 }, {     73,   45,    0, 15,  0,  0 }, {     74,   45,    0, 15,  0,  0 },
    {     75,   45,    0, 15,  0,  0 }, {     76,   46,    0, 15,  0,  0 }, {     77,   46,    0, 15,  0,  0 }, {     78,   46,    0, 15,  0,  0 }, {     79,   46,    0, 15,  0,  0 },
    {     80,   46,    0, 15,  0,  0 }, {     81,   47,    0, 15,  0,  0 }, {     82,   47,    0, 15,  0,  0 }, {     83,   47,    0, 15,  0,  0 }, {     84,   47,    0, 15,  0,  0 },
    {     85,   47,    0, 15,  0,  0 }, {     86,   47,    0, 15,  0,  0 }, {     87,   48,    0, 15,  0,  0 }, {     88,   48,    0, 16,  0,  0 }, {     89,   48,    0, 16,  0,  0 },
    {     90,   48,    0, 16,  0,  0 }, {     91,   48,    0, 16,  0,  0 }, {     92,   48,    0, 16,  0,  0 }, {     93,   48,    0, 16,  0,  0 }, {     94,   48,    0, 16,  0,  0 },
    {     95,   48,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CCAF8, {
    {     16,   32,    0, 24,  0,  0 }, {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 },
    {     16,   27,    0, 24,  0,  0 }, {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 23,  0,  0 }, {     17,   23,    0, 23,  0,  0 },
    {     17,   22,    0, 23,  0,  0 }, {     17,   21,    0, 23,  0,  0 }, {     17,   20,    0, 23,  0,  0 }, {     17,   19,    0, 23,  0,  0 }, {     17,   18,    0, 23,  0,  0 },
    {     18,   17,    0, 23,  0,  0 }, {     18,   16,    0, 23,  0,  0 }, {     18,   15,    0, 23,  0,  0 }, {     18,   14,    0, 23,  0,  0 }, {     18,   13,    0, 23,  0,  0 },
    {     19,   12,    0, 23,  0,  0 }, {     19,   11,    0, 23,  0,  0 }, {     19,   10,    0, 22,  0,  0 }, {     19,    9,    0, 22,  0,  0 }, {     20,    8,    0, 22,  0,  0 },
    {     20,    7,    0, 22,  0,  0 }, {     20,    6,    0, 22,  0,  0 }, {     21,    5,    0, 22,  0,  0 }, {     21,    4,    0, 22,  0,  0 }, {     21,    3,    0, 22,  0,  0 },
    {     22,    2,    0, 22,  0,  0 }, {     22,    1,    0, 22,  0,  0 }, {     23,    0,    0, 22,  0,  0 }, {     23,   -1,    0, 22,  0,  0 }, {     24,   -2,    0, 22,  0,  0 },
    {     24,   -3,    0, 22,  0,  0 }, {     25,   -4,    0, 21,  0,  0 }, {     25,   -5,    0, 21,  0,  0 }, {     26,   -6,    0, 21,  0,  0 }, {     26,   -7,    0, 21,  0,  0 },
    {     27,   -8,    0, 21,  0,  0 }, {     28,   -9,    0, 21,  0,  0 }, {     28,  -10,    0, 21,  0,  0 }, {     29,  -11,    0, 21,  0,  0 }, {     30,  -12,    0, 21,  0,  0 },
    {     30,  -13,    0, 21,  0,  0 }, {     31,  -14,    0, 21,  0,  0 }, {     32,  -15,    0, 21,  0,  0 }, {     32,  -16,    0, 21,  0,  0 }, {     33,  -17,    0, 21,  0,  0 },
    {     34,  -18,    0, 21,  0,  0 }, {     34,  -19,    0, 21,  0,  0 }, {     35,  -20,    0, 21,  0,  0 }, {     36,  -21,    0, 21,  0,  0 }, {     36,  -22,    0, 21,  0,  0 },
    {     37,  -23,    0, 21,  0,  0 }, {     38,  -24,    0, 21,  0,  0 }, {     38,  -25,    0, 21,  0,  0 }, {     39,  -26,    0, 21,  0,  0 }, {     39,  -27,    0, 21,  0,  0 },
    {     40,  -28,    0, 22,  0,  0 }, {     40,  -29,    0, 22,  0,  0 }, {     41,  -30,    0, 22,  0,  0 }, {     41,  -31,    0, 22,  0,  0 }, {     42,  -32,    0, 22,  0,  0 },
    {     42,  -33,    0, 22,  0,  0 }, {     43,  -34,    0, 22,  0,  0 }, {     43,  -35,    0, 22,  0,  0 }, {     43,  -36,    0, 22,  0,  0 }, {     44,  -37,    0, 22,  0,  0 },
    {     44,  -38,    0, 22,  0,  0 }, {     44,  -39,    0, 22,  0,  0 }, {     45,  -40,    0, 22,  0,  0 }, {     45,  -41,    0, 23,  0,  0 }, {     45,  -42,    0, 23,  0,  0 },
    {     45,  -43,    0, 23,  0,  0 }, {     46,  -44,    0, 23,  0,  0 }, {     46,  -45,    0, 23,  0,  0 }, {     46,  -46,    0, 23,  0,  0 }, {     46,  -47,    0, 23,  0,  0 },
    {     46,  -48,    0, 23,  0,  0 }, {     47,  -49,    0, 23,  0,  0 }, {     47,  -50,    0, 23,  0,  0 }, {     47,  -51,    0, 23,  0,  0 }, {     47,  -52,    0, 23,  0,  0 },
    {     47,  -53,    0, 23,  0,  0 }, {     47,  -54,    0, 23,  0,  0 }, {     48,  -55,    0, 23,  0,  0 }, {     48,  -56,    0, 24,  0,  0 }, {     48,  -57,    0, 24,  0,  0 },
    {     48,  -58,    0, 24,  0,  0 }, {     48,  -59,    0, 24,  0,  0 }, {     48,  -60,    0, 24,  0,  0 }, {     48,  -61,    0, 24,  0,  0 }, {     48,  -62,    0, 24,  0,  0 },
    {     48,  -63,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CCE5A, {
    {     32,   16,    0,  0,  0,  0 }, {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 },
    {     27,   16,    0,  0,  0,  0 }, {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  1,  0,  0 }, {     23,   17,    0,  1,  0,  0 },
    {     22,   17,    0,  1,  0,  0 }, {     21,   17,    0,  1,  0,  0 }, {     20,   17,    0,  1,  0,  0 }, {     19,   17,    0,  1,  0,  0 }, {     18,   17,    0,  1,  0,  0 },
    {     17,   18,    0,  1,  0,  0 }, {     16,   18,    0,  1,  0,  0 }, {     15,   18,    0,  1,  0,  0 }, {     14,   18,    0,  1,  0,  0 }, {     13,   18,    0,  1,  0,  0 },
    {     12,   19,    0,  1,  0,  0 }, {     11,   19,    0,  1,  0,  0 }, {     10,   19,    0,  2,  0,  0 }, {      9,   19,    0,  2,  0,  0 }, {      8,   20,    0,  2,  0,  0 },
    {      7,   20,    0,  2,  0,  0 }, {      6,   20,    0,  2,  0,  0 }, {      5,   21,    0,  2,  0,  0 }, {      4,   21,    0,  2,  0,  0 }, {      3,   21,    0,  2,  0,  0 },
    {      2,   22,    0,  2,  0,  0 }, {      1,   22,    0,  2,  0,  0 }, {      0,   23,    0,  2,  0,  0 }, {     -1,   23,    0,  2,  0,  0 }, {     -2,   24,    0,  2,  0,  0 },
    {     -3,   24,    0,  2,  0,  0 }, {     -4,   25,    0,  3,  0,  0 }, {     -5,   25,    0,  3,  0,  0 }, {     -6,   26,    0,  3,  0,  0 }, {     -7,   26,    0,  3,  0,  0 },
    {     -8,   27,    0,  3,  0,  0 }, {     -9,   28,    0,  3,  0,  0 }, {    -10,   28,    0,  3,  0,  0 }, {    -11,   29,    0,  3,  0,  0 }, {    -12,   30,    0,  3,  0,  0 },
    {    -13,   30,    0,  3,  0,  0 }, {    -14,   31,    0,  3,  0,  0 }, {    -15,   32,    0,  3,  0,  0 }, {    -16,   32,    0,  3,  0,  0 }, {    -17,   33,    0,  3,  0,  0 },
    {    -18,   34,    0,  3,  0,  0 }, {    -19,   34,    0,  3,  0,  0 }, {    -20,   35,    0,  3,  0,  0 }, {    -21,   36,    0,  3,  0,  0 }, {    -22,   36,    0,  3,  0,  0 },
    {    -23,   37,    0,  3,  0,  0 }, {    -24,   38,    0,  3,  0,  0 }, {    -25,   38,    0,  3,  0,  0 }, {    -26,   39,    0,  3,  0,  0 }, {    -27,   39,    0,  3,  0,  0 },
    {    -28,   40,    0,  2,  0,  0 }, {    -29,   40,    0,  2,  0,  0 }, {    -30,   41,    0,  2,  0,  0 }, {    -31,   41,    0,  2,  0,  0 }, {    -32,   42,    0,  2,  0,  0 },
    {    -33,   42,    0,  2,  0,  0 }, {    -34,   43,    0,  2,  0,  0 }, {    -35,   43,    0,  2,  0,  0 }, {    -36,   43,    0,  2,  0,  0 }, {    -37,   44,    0,  2,  0,  0 },
    {    -38,   44,    0,  2,  0,  0 }, {    -39,   44,    0,  2,  0,  0 }, {    -40,   45,    0,  2,  0,  0 }, {    -41,   45,    0,  1,  0,  0 }, {    -42,   45,    0,  1,  0,  0 },
    {    -43,   45,    0,  1,  0,  0 }, {    -44,   46,    0,  1,  0,  0 }, {    -45,   46,    0,  1,  0,  0 }, {    -46,   46,    0,  1,  0,  0 }, {    -47,   46,    0,  1,  0,  0 },
    {    -48,   46,    0,  1,  0,  0 }, {    -49,   47,    0,  1,  0,  0 }, {    -50,   47,    0,  1,  0,  0 }, {    -51,   47,    0,  1,  0,  0 }, {    -52,   47,    0,  1,  0,  0 },
    {    -53,   47,    0,  1,  0,  0 }, {    -54,   47,    0,  1,  0,  0 }, {    -55,   48,    0,  1,  0,  0 }, {    -56,   48,    0,  0,  0,  0 }, {    -57,   48,    0,  0,  0,  0 },
    {    -58,   48,    0,  0,  0,  0 }, {    -59,   48,    0,  0,  0,  0 }, {    -60,   48,    0,  0,  0,  0 }, {    -61,   48,    0,  0,  0,  0 }, {    -62,   48,    0,  0,  0,  0 },
    {    -63,   48,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CD1BC, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  9,  0,  0 }, {     17,    9,    0,  9,  0,  0 },
    {     17,   10,    0,  9,  0,  0 }, {     17,   11,    0,  9,  0,  0 }, {     17,   12,    0,  9,  0,  0 }, {     17,   13,    0,  9,  0,  0 }, {     17,   14,    0,  9,  0,  0 },
    {     18,   15,    0,  9,  0,  0 }, {     18,   16,    0,  9,  0,  0 }, {     18,   17,    0,  9,  0,  0 }, {     18,   18,    0,  9,  0,  0 }, {     18,   19,    0,  9,  0,  0 },
    {     19,   20,    0,  9,  0,  0 }, {     19,   21,    0,  9,  0,  0 }, {     19,   22,    0, 10,  0,  0 }, {     19,   23,    0, 10,  0,  0 }, {     20,   24,    0, 10,  0,  0 },
    {     20,   25,    0, 10,  0,  0 }, {     20,   26,    0, 10,  0,  0 }, {     21,   27,    0, 10,  0,  0 }, {     21,   28,    0, 10,  0,  0 }, {     21,   29,    0, 10,  0,  0 },
    {     22,   30,    0, 10,  0,  0 }, {     22,   31,    0, 10,  0,  0 }, {     23,   32,    0, 10,  0,  0 }, {     23,   33,    0, 10,  0,  0 }, {     24,   34,    0, 10,  0,  0 },
    {     24,   35,    0, 10,  0,  0 }, {     25,   36,    0, 11,  0,  0 }, {     25,   37,    0, 11,  0,  0 }, {     26,   38,    0, 11,  0,  0 }, {     26,   39,    0, 11,  0,  0 },
    {     27,   40,    0, 11,  0,  0 }, {     28,   41,    0, 11,  0,  0 }, {     28,   42,    0, 11,  0,  0 }, {     29,   43,    0, 11,  0,  0 }, {     30,   44,    0, 11,  0,  0 },
    {     30,   45,    0, 11,  0,  0 }, {     31,   46,    0, 11,  0,  0 }, {     32,   47,    0, 11,  0,  0 }, {     32,   48,    0, 11,  0,  0 }, {     33,   49,    0, 11,  0,  0 },
    {     34,   50,    0, 11,  0,  0 }, {     34,   51,    0, 11,  0,  0 }, {     35,   52,    0, 11,  0,  0 }, {     36,   53,    0, 11,  0,  0 }, {     36,   54,    0, 11,  0,  0 },
    {     37,   55,    0, 11,  0,  0 }, {     38,   56,    0, 11,  0,  0 }, {     38,   57,    0, 11,  0,  0 }, {     39,   58,    0, 11,  0,  0 }, {     39,   59,    0, 11,  0,  0 },
    {     40,   60,    0, 10,  0,  0 }, {     40,   61,    0, 10,  0,  0 }, {     41,   62,    0, 10,  0,  0 }, {     41,   63,    0, 10,  0,  0 }, {     42,   64,    0, 10,  0,  0 },
    {     42,   65,    0, 10,  0,  0 }, {     43,   66,    0, 10,  0,  0 }, {     43,   67,    0, 10,  0,  0 }, {     43,   68,    0, 10,  0,  0 }, {     44,   69,    0, 10,  0,  0 },
    {     44,   70,    0, 10,  0,  0 }, {     44,   71,    0, 10,  0,  0 }, {     45,   72,    0, 10,  0,  0 }, {     45,   73,    0,  9,  0,  0 }, {     45,   74,    0,  9,  0,  0 },
    {     45,   75,    0,  9,  0,  0 }, {     46,   76,    0,  9,  0,  0 }, {     46,   77,    0,  9,  0,  0 }, {     46,   78,    0,  9,  0,  0 }, {     46,   79,    0,  9,  0,  0 },
    {     46,   80,    0,  9,  0,  0 }, {     47,   81,    0,  9,  0,  0 }, {     47,   82,    0,  9,  0,  0 }, {     47,   83,    0,  9,  0,  0 }, {     47,   84,    0,  9,  0,  0 },
    {     47,   85,    0,  9,  0,  0 }, {     47,   86,    0,  9,  0,  0 }, {     48,   87,    0,  9,  0,  0 }, {     48,   88,    0,  8,  0,  0 }, {     48,   89,    0,  8,  0,  0 },
    {     48,   90,    0,  8,  0,  0 }, {     48,   91,    0,  8,  0,  0 }, {     48,   92,    0,  8,  0,  0 }, {     48,   93,    0,  8,  0,  0 }, {     48,   94,    0,  8,  0,  0 },
    {     48,   95,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CD51E, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 17,  0,  0 }, {      9,   15,    0, 17,  0,  0 },
    {     10,   15,    0, 17,  0,  0 }, {     11,   15,    0, 17,  0,  0 }, {     12,   15,    0, 17,  0,  0 }, {     13,   15,    0, 17,  0,  0 }, {     14,   15,    0, 17,  0,  0 },
    {     15,   14,    0, 17,  0,  0 }, {     16,   14,    0, 17,  0,  0 }, {     17,   14,    0, 17,  0,  0 }, {     18,   14,    0, 17,  0,  0 }, {     19,   14,    0, 17,  0,  0 },
    {     20,   13,    0, 17,  0,  0 }, {     21,   13,    0, 17,  0,  0 }, {     22,   13,    0, 18,  0,  0 }, {     23,   13,    0, 18,  0,  0 }, {     24,   12,    0, 18,  0,  0 },
    {     25,   12,    0, 18,  0,  0 }, {     26,   12,    0, 18,  0,  0 }, {     27,   11,    0, 18,  0,  0 }, {     28,   11,    0, 18,  0,  0 }, {     29,   11,    0, 18,  0,  0 },
    {     30,   10,    0, 18,  0,  0 }, {     31,   10,    0, 18,  0,  0 }, {     32,    9,    0, 18,  0,  0 }, {     33,    9,    0, 18,  0,  0 }, {     34,    8,    0, 18,  0,  0 },
    {     35,    8,    0, 18,  0,  0 }, {     36,    7,    0, 19,  0,  0 }, {     37,    7,    0, 19,  0,  0 }, {     38,    6,    0, 19,  0,  0 }, {     39,    6,    0, 19,  0,  0 },
    {     40,    5,    0, 19,  0,  0 }, {     41,    4,    0, 19,  0,  0 }, {     42,    4,    0, 19,  0,  0 }, {     43,    3,    0, 19,  0,  0 }, {     44,    2,    0, 19,  0,  0 },
    {     45,    2,    0, 19,  0,  0 }, {     46,    1,    0, 19,  0,  0 }, {     47,    0,    0, 19,  0,  0 }, {     48,    0,    0, 19,  0,  0 }, {     49,   -1,    0, 19,  0,  0 },
    {     50,   -2,    0, 19,  0,  0 }, {     51,   -2,    0, 19,  0,  0 }, {     52,   -3,    0, 19,  0,  0 }, {     53,   -4,    0, 19,  0,  0 }, {     54,   -4,    0, 19,  0,  0 },
    {     55,   -5,    0, 19,  0,  0 }, {     56,   -6,    0, 19,  0,  0 }, {     57,   -6,    0, 19,  0,  0 }, {     58,   -7,    0, 19,  0,  0 }, {     59,   -7,    0, 19,  0,  0 },
    {     60,   -8,    0, 18,  0,  0 }, {     61,   -8,    0, 18,  0,  0 }, {     62,   -9,    0, 18,  0,  0 }, {     63,   -9,    0, 18,  0,  0 }, {     64,  -10,    0, 18,  0,  0 },
    {     65,  -10,    0, 18,  0,  0 }, {     66,  -11,    0, 18,  0,  0 }, {     67,  -11,    0, 18,  0,  0 }, {     68,  -11,    0, 18,  0,  0 }, {     69,  -12,    0, 18,  0,  0 },
    {     70,  -12,    0, 18,  0,  0 }, {     71,  -12,    0, 18,  0,  0 }, {     72,  -13,    0, 18,  0,  0 }, {     73,  -13,    0, 17,  0,  0 }, {     74,  -13,    0, 17,  0,  0 },
    {     75,  -13,    0, 17,  0,  0 }, {     76,  -14,    0, 17,  0,  0 }, {     77,  -14,    0, 17,  0,  0 }, {     78,  -14,    0, 17,  0,  0 }, {     79,  -14,    0, 17,  0,  0 },
    {     80,  -14,    0, 17,  0,  0 }, {     81,  -15,    0, 17,  0,  0 }, {     82,  -15,    0, 17,  0,  0 }, {     83,  -15,    0, 17,  0,  0 }, {     84,  -15,    0, 17,  0,  0 },
    {     85,  -15,    0, 17,  0,  0 }, {     86,  -15,    0, 17,  0,  0 }, {     87,  -16,    0, 17,  0,  0 }, {     88,  -16,    0, 16,  0,  0 }, {     89,  -16,    0, 16,  0,  0 },
    {     90,  -16,    0, 16,  0,  0 }, {     91,  -16,    0, 16,  0,  0 }, {     92,  -16,    0, 16,  0,  0 }, {     93,  -16,    0, 16,  0,  0 }, {     94,  -16,    0, 16,  0,  0 },
    {     95,  -16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CD880, {
    {     16,   32,    0, 24,  0,  0 }, {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 },
    {     16,   27,    0, 24,  0,  0 }, {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 25,  0,  0 }, {     15,   23,    0, 25,  0,  0 },
    {     15,   22,    0, 25,  0,  0 }, {     15,   21,    0, 25,  0,  0 }, {     15,   20,    0, 25,  0,  0 }, {     15,   19,    0, 25,  0,  0 }, {     15,   18,    0, 25,  0,  0 },
    {     14,   17,    0, 25,  0,  0 }, {     14,   16,    0, 25,  0,  0 }, {     14,   15,    0, 25,  0,  0 }, {     14,   14,    0, 25,  0,  0 }, {     14,   13,    0, 25,  0,  0 },
    {     13,   12,    0, 25,  0,  0 }, {     13,   11,    0, 25,  0,  0 }, {     13,   10,    0, 26,  0,  0 }, {     13,    9,    0, 26,  0,  0 }, {     12,    8,    0, 26,  0,  0 },
    {     12,    7,    0, 26,  0,  0 }, {     12,    6,    0, 26,  0,  0 }, {     11,    5,    0, 26,  0,  0 }, {     11,    4,    0, 26,  0,  0 }, {     11,    3,    0, 26,  0,  0 },
    {     10,    2,    0, 26,  0,  0 }, {     10,    1,    0, 26,  0,  0 }, {      9,    0,    0, 26,  0,  0 }, {      9,   -1,    0, 26,  0,  0 }, {      8,   -2,    0, 26,  0,  0 },
    {      8,   -3,    0, 26,  0,  0 }, {      7,   -4,    0, 27,  0,  0 }, {      7,   -5,    0, 27,  0,  0 }, {      6,   -6,    0, 27,  0,  0 }, {      6,   -7,    0, 27,  0,  0 },
    {      5,   -8,    0, 27,  0,  0 }, {      4,   -9,    0, 27,  0,  0 }, {      4,  -10,    0, 27,  0,  0 }, {      3,  -11,    0, 27,  0,  0 }, {      2,  -12,    0, 27,  0,  0 },
    {      2,  -13,    0, 27,  0,  0 }, {      1,  -14,    0, 27,  0,  0 }, {      0,  -15,    0, 27,  0,  0 }, {      0,  -16,    0, 27,  0,  0 }, {     -1,  -17,    0, 27,  0,  0 },
    {     -2,  -18,    0, 27,  0,  0 }, {     -2,  -19,    0, 27,  0,  0 }, {     -3,  -20,    0, 27,  0,  0 }, {     -4,  -21,    0, 27,  0,  0 }, {     -4,  -22,    0, 27,  0,  0 },
    {     -5,  -23,    0, 27,  0,  0 }, {     -6,  -24,    0, 27,  0,  0 }, {     -6,  -25,    0, 27,  0,  0 }, {     -7,  -26,    0, 27,  0,  0 }, {     -7,  -27,    0, 27,  0,  0 },
    {     -8,  -28,    0, 26,  0,  0 }, {     -8,  -29,    0, 26,  0,  0 }, {     -9,  -30,    0, 26,  0,  0 }, {     -9,  -31,    0, 26,  0,  0 }, {    -10,  -32,    0, 26,  0,  0 },
    {    -10,  -33,    0, 26,  0,  0 }, {    -11,  -34,    0, 26,  0,  0 }, {    -11,  -35,    0, 26,  0,  0 }, {    -11,  -36,    0, 26,  0,  0 }, {    -12,  -37,    0, 26,  0,  0 },
    {    -12,  -38,    0, 26,  0,  0 }, {    -12,  -39,    0, 26,  0,  0 }, {    -13,  -40,    0, 26,  0,  0 }, {    -13,  -41,    0, 25,  0,  0 }, {    -13,  -42,    0, 25,  0,  0 },
    {    -13,  -43,    0, 25,  0,  0 }, {    -14,  -44,    0, 25,  0,  0 }, {    -14,  -45,    0, 25,  0,  0 }, {    -14,  -46,    0, 25,  0,  0 }, {    -14,  -47,    0, 25,  0,  0 },
    {    -14,  -48,    0, 25,  0,  0 }, {    -15,  -49,    0, 25,  0,  0 }, {    -15,  -50,    0, 25,  0,  0 }, {    -15,  -51,    0, 25,  0,  0 }, {    -15,  -52,    0, 25,  0,  0 },
    {    -15,  -53,    0, 25,  0,  0 }, {    -15,  -54,    0, 25,  0,  0 }, {    -16,  -55,    0, 25,  0,  0 }, {    -16,  -56,    0, 24,  0,  0 }, {    -16,  -57,    0, 24,  0,  0 },
    {    -16,  -58,    0, 24,  0,  0 }, {    -16,  -59,    0, 24,  0,  0 }, {    -16,  -60,    0, 24,  0,  0 }, {    -16,  -61,    0, 24,  0,  0 }, {    -16,  -62,    0, 24,  0,  0 },
    {    -16,  -63,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D44BE, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   15,    0,  0,  2,  0 }, {     29,   15,    1,  0,  2,  0 }, {     28,   15,    1,  0,  2,  0 }, {     27,   15,    2,  0,  2,  0 },
    {     26,   15,    2,  0,  2,  0 }, {     25,   15,    3,  0,  2,  0 }, {     24,   15,    3,  0,  2,  0 }, {     23,   15,    3,  0,  2,  0 }, {     22,   15,    4,  0,  2,  0 },
    {     21,   14,    4,  0,  2,  0 }, {     20,   14,    5,  0,  2,  0 }, {     19,   14,    5,  0,  2,  0 }, {     18,   14,    6,  0,  2,  0 }, {     17,   14,    6,  0,  2,  0 },
    {     16,   14,    7,  0,  2,  0 }, {     15,   14,    7,  0,  2,  0 }, {     14,   14,    8,  0,  2,  0 }, {     13,   14,    8,  0,  2,  0 }, {     12,   14,    9,  0,  3,  0 },
    {     11,   13,    9,  0,  3,  0 }, {     10,   13,   10,  0,  3,  0 }, {      9,   13,   10,  0,  3,  0 }, {      8,   13,   11,  0,  3,  0 }, {      7,   13,   11,  0,  3,  0 },
    {      6,   13,   12,  0,  3,  0 }, {      5,   13,   13,  0,  3,  0 }, {      4,   13,   14,  0,  3,  0 }, {      3,   13,   15,  0,  3,  0 }, {      2,   12,   15,  0,  3,  0 },
    {      1,   12,   16,  0,  3,  0 }, {      0,   12,   17,  0,  3,  0 }, {     -1,   12,   18,  0,  3,  0 }, {     -2,   12,   18,  0,  3,  0 }, {     -3,   12,   19,  0,  3,  0 },
    {     -4,   12,   20,  0,  3,  0 }, {     -5,   12,   21,  0,  3,  0 }, {     -6,   11,   22,  0,  3,  0 }, {     -7,   11,   23,  0,  3,  0 }, {     -8,   11,   24,  0,  3,  0 },
    {     -9,   11,   25,  0,  3,  0 }, {    -10,   11,   26,  0,  3,  0 }, {    -11,   11,   27,  0,  4,  0 }, {    -12,   11,   28,  0,  4,  0 }, {    -13,   11,   29,  0,  4,  0 },
    {    -13,   11,   30,  0,  4,  0 }, {    -14,   10,   31,  0,  4,  0 }, {    -15,   10,   32,  0,  4,  0 }, {    -16,   10,   33,  0,  4,  0 }, {    -16,   10,   34,  0,  4,  0 },
    {    -17,   10,   35,  0,  4,  0 }, {    -18,   10,   36,  0,  4,  0 }, {    -19,   10,   37,  0,  4,  0 }, {    -19,   10,   38,  0,  4,  0 }, {    -20,   10,   39,  0,  4,  0 },
    {    -20,    9,   40,  0,  4,  0 }, {    -21,    9,   41,  0,  4,  0 }, {    -22,    9,   42,  0,  4,  0 }, {    -22,    9,   43,  0,  9,  0 }, {    -23,    9,   44,  0,  9,  0 },
    {    -24,    9,   45,  0,  9,  0 }, {    -24,    9,   46,  0,  9,  0 }, {    -25,    9,   47,  0,  9,  0 }, {    -25,    9,   48,  0,  9,  0 }, {    -25,    8,   49,  0,  9,  0 },
    {    -26,    8,   50,  0,  9,  0 }, {    -26,    8,   51,  0,  9,  0 }, {    -26,    8,   52,  0,  9,  0 }, {    -27,    8,   53,  0,  9,  0 }, {    -27,    8,   54,  0,  9,  0 },
    {    -27,    8,   55,  0,  9,  0 }, {    -28,    8,   56,  0,  9,  0 }, {    -28,    8,   57,  0,  9,  0 }, {    -28,    8,   58,  0,  9,  0 }, {    -29,    7,   59,  0,  9,  0 },
    {    -29,    7,   60,  0,  9,  0 }, {    -29,    7,   61,  0,  9,  0 }, {    -30,    7,   62,  0,  9,  0 }, {    -30,    7,   63,  0,  9,  0 }, {    -30,    7,   64,  0, 10,  0 },
    {    -30,    7,   65,  0, 10,  0 }, {    -31,    7,   66,  0, 10,  0 }, {    -31,    7,   67,  0, 10,  0 }, {    -31,    7,   68,  0, 10,  0 }, {    -31,    6,   69,  0, 10,  0 },
    {    -31,    6,   70,  0, 10,  0 }, {    -32,    6,   71,  0, 10,  0 }, {    -32,    6,   72,  0, 10,  0 }, {    -32,    6,   73,  0, 10,  0 }, {    -32,    6,   74,  0, 10,  0 },
    {    -32,    6,   75,  0, 10,  0 }, {    -32,    6,   76,  0, 10,  0 }, {    -32,    6,   77,  0, 10,  0 }, {    -32,    6,   78,  0, 10,  0 }, {    -32,    6,   79,  0, 10,  0 },
    {    -32,    5,   80,  0, 10,  0 }, {    -32,    5,   81,  0, 10,  0 }, {    -32,    5,   82,  0, 10,  0 }, {    -32,    5,   83,  0, 10,  0 }, {    -32,    5,   84,  0, 10,  0 },
    {    -32,    5,   85,  0, 10,  0 }, {    -32,    5,   86,  0, 10,  0 }, {    -32,    5,   87,  0, 10,  0 }, {    -32,    5,   88,  0, 10,  0 }, {    -32,    5,   89,  0, 10,  0 },
    {    -32,    5,   90,  0, 10,  0 }, {    -32,    5,   91,  0, 11,  0 }, {    -32,    4,   92,  0, 11,  0 }, {    -31,    4,   93,  0, 11,  0 }, {    -31,    4,   94,  0, 11,  0 },
    {    -31,    4,   95,  0, 11,  0 }, {    -31,    4,   96,  0, 11,  0 }, {    -31,    4,   97,  0, 11,  0 }, {    -30,    4,   98,  0, 11,  0 }, {    -30,    4,   99,  0, 11,  0 },
    {    -30,    4,  100,  0, 11,  0 }, {    -30,    4,  101,  0, 11,  0 }, {    -29,    3,  102,  0, 11,  0 }, {    -29,    3,  103,  0, 11,  0 }, {    -29,    3,  104,  0, 11,  0 },
    {    -28,    3,  105,  0, 12,  0 }, {    -28,    3,  106,  0, 12,  0 }, {    -27,    3,  107,  0, 12,  0 }, {    -27,    3,  108,  0, 12,  0 }, {    -26,    3,  109,  0, 12,  0 },
    {    -26,    3,  110,  0, 12,  0 }, {    -26,    3,  111,  0, 12,  0 }, {    -25,    2,  112,  0, 12,  0 }, {    -25,    2,  113,  0, 12,  0 }, {    -24,    2,  114,  0, 13,  0 },
    {    -24,    2,  115,  0, 13,  0 }, {    -23,    2,  116,  0, 13,  0 }, {    -22,    2,  117,  0, 13,  0 }, {    -22,    2,  118,  0, 13,  0 }, {    -21,    2,  119,  0, 13,  0 },
    {    -20,    2,  120,  0, 13,  0 }, {    -19,    1,  121,  0, 13,  0 }, {    -18,    1,  122,  0, 14,  0 }, {    -17,    1,  123,  0, 14,  0 }, {    -16,    1,  124,  0, 14,  0 },
    {    -15,    1,  124,  0, 14,  0 }, {    -14,    1,  125,  0, 14,  0 }, {    -13,    1,  126,  0, 15,  0 }, {    -12,    1,  127,  0, 15,  0 }, {    -11,    0,  128,  0, 15,  0 },
    {    -10,    0,  128,  0, 15,  0 }, {     -9,    0,  129,  0, 15,  0 }, {     -8,    0,  129,  0, 16,  0 }, {     -7,    0,  129,  0, 16,  0 }, {     -6,    0,  130,  0, 16,  0 },
    {     -5,    0,  130,  0, 16,  0 }, {     -4,    0,  130,  0, 16,  0 }, {     -3,    0,  130,  0, 16,  0 }, {     -2,    0,  130,  0, 16,  0 }, {     -1,    0,  130,  0, 16,  0 },
    {      0,    0,  130,  0, 16,  0 }, {      1,    0,  130,  0, 16,  0 }, {      2,    0,  130,  0, 16,  0 }, {      3,    0,  130,  0, 16,  0 }, {      4,    0,  130,  0, 23,  0 },
    {      5,    0,  130,  0, 23,  0 }, {      6,    0,  129,  0, 23,  0 }, {      7,    0,  129,  0, 23,  0 }, {      8,    0,  129,  0, 23,  0 }, {      9,    0,  128,  0, 22,  0 },
    {     10,    0,  128,  0, 22,  0 }, {     11,   -1,  127,  0, 22,  0 }, {     12,   -1,  126,  0, 22,  0 }, {     13,   -1,  125,  0, 22,  0 }, {     14,   -1,  124,  0, 21,  0 },
    {     15,   -1,  124,  0, 21,  0 }, {     16,   -1,  123,  0, 21,  0 }, {     17,   -1,  122,  0, 21,  0 }, {     18,   -1,  121,  0, 21,  0 }, {     19,   -2,  120,  0, 21,  0 },
    {     20,   -2,  119,  0, 21,  0 }, {     21,   -2,  118,  0, 21,  0 }, {     21,   -2,  117,  0, 20,  0 }, {     22,   -2,  116,  0, 20,  0 }, {     23,   -2,  115,  0, 20,  0 },
    {     23,   -2,  114,  0, 20,  0 }, {     24,   -2,  113,  0, 20,  0 }, {     24,   -2,  112,  0, 20,  0 }, {     25,   -3,  111,  0, 20,  0 }, {     25,   -3,  110,  0, 20,  0 },
    {     25,   -3,  109,  0, 20,  0 }, {     26,   -3,  108,  0, 19,  0 }, {     26,   -3,  107,  0, 19,  0 }, {     27,   -3,  106,  0, 19,  0 }, {     27,   -3,  105,  0, 19,  0 },
    {     28,   -3,  104,  0, 19,  0 }, {     28,   -3,  103,  0, 19,  0 }, {     28,   -3,  102,  0, 19,  0 }, {     29,   -4,  101,  0, 19,  0 }, {     29,   -4,  100,  0, 19,  0 },
    {     29,   -4,   99,  0, 19,  0 }, {     29,   -4,   98,  0, 19,  0 }, {     30,   -4,   97,  0, 19,  0 }, {     30,   -4,   96,  0, 19,  0 }, {     30,   -4,   95,  0, 19,  0 },
    {     30,   -4,   94,  0, 18,  0 }, {     30,   -4,   93,  0, 18,  0 }, {     31,   -4,   92,  0, 18,  0 }, {     31,   -5,   91,  0, 18,  0 }, {     31,   -5,   90,  0, 18,  0 },
    {     31,   -5,   89,  0, 18,  0 }, {     31,   -5,   88,  0, 18,  0 }, {     31,   -5,   87,  0, 18,  0 }, {     31,   -5,   86,  0, 18,  0 }, {     31,   -5,   85,  0, 18,  0 },
    {     31,   -5,   84,  0, 18,  0 }, {     31,   -5,   83,  0, 18,  0 }, {     31,   -5,   82,  0, 18,  0 }, {     31,   -5,   81,  0, 18,  0 }, {     31,   -5,   80,  0, 18,  0 },
    {     31,   -6,   79,  0, 18,  0 }, {     31,   -6,   78,  0, 18,  0 }, {     31,   -6,   77,  0, 18,  0 }, {     31,   -6,   76,  0, 18,  0 }, {     31,   -6,   75,  0, 18,  0 },
    {     31,   -6,   74,  0, 18,  0 }, {     31,   -6,   73,  0, 18,  0 }, {     31,   -6,   72,  0, 18,  0 }, {     31,   -6,   71,  0, 18,  0 }, {     30,   -6,   70,  0, 18,  0 },
    {     30,   -6,   69,  0, 18,  0 }, {     30,   -7,   68,  0, 18,  0 }, {     30,   -7,   67,  0, 17,  0 }, {     30,   -7,   66,  0, 17,  0 }, {     29,   -7,   65,  0, 17,  0 },
    {     29,   -7,   64,  0, 17,  0 }, {     29,   -7,   63,  0, 17,  0 }, {     29,   -7,   62,  0, 17,  0 }, {     28,   -7,   61,  0, 17,  0 }, {     28,   -7,   60,  0, 17,  0 },
    {     28,   -7,   59,  0, 17,  0 }, {     27,   -8,   58,  0, 17,  0 }, {     27,   -8,   57,  0, 17,  0 }, {     27,   -8,   56,  0, 17,  0 }, {     26,   -8,   55,  0, 17,  0 },
    {     26,   -8,   54,  0, 17,  0 }, {     26,   -8,   53,  0, 17,  0 }, {     25,   -8,   52,  0, 17,  0 }, {     25,   -8,   51,  0, 17,  0 }, {     25,   -8,   50,  0, 17,  0 },
    {     24,   -8,   49,  0, 17,  0 }, {     24,   -9,   48,  0, 17,  0 }, {     24,   -9,   47,  0, 17,  0 }, {     23,   -9,   46,  0,  8,  0 }, {     23,   -9,   45,  0,  8,  0 },
    {     22,   -9,   44,  0,  8,  0 }, {     21,   -9,   43,  0,  8,  0 }, {     21,   -9,   42,  0,  8,  0 }, {     20,   -9,   41,  0,  8,  0 }, {     19,   -9,   40,  0,  8,  0 },
    {     19,   -9,   39,  0,  8,  0 }, {     18,  -10,   38,  0,  8,  0 }, {     18,  -10,   37,  0,  8,  0 }, {     17,  -10,   36,  0,  8,  0 }, {     16,  -10,   35,  0,  8,  0 },
    {     15,  -10,   34,  0,  8,  0 }, {     15,  -10,   33,  0,  8,  0 }, {     14,  -10,   32,  0,  8,  0 }, {     13,  -10,   31,  0,  8,  0 }, {     12,  -11,   30,  0,  7,  0 },
    {     12,  -11,   29,  0,  7,  0 }, {     11,  -11,   28,  0,  7,  0 }, {     10,  -11,   27,  0,  7,  0 }, {      9,  -11,   26,  0,  7,  0 }, {      8,  -11,   25,  0,  7,  0 },
    {      7,  -11,   24,  0,  7,  0 }, {      6,  -11,   23,  0,  7,  0 }, {      5,  -11,   22,  0,  7,  0 }, {      4,  -12,   21,  0,  7,  0 }, {      3,  -12,   20,  0,  7,  0 },
    {      2,  -12,   19,  0,  7,  0 }, {      1,  -12,   18,  0,  7,  0 }, {      0,  -12,   18,  0,  7,  0 }, {     -1,  -12,   17,  0,  7,  0 }, {     -2,  -12,   16,  0,  7,  0 },
    {     -3,  -12,   15,  0,  7,  0 }, {     -4,  -13,   15,  0,  7,  0 }, {     -5,  -13,   14,  0,  7,  0 }, {     -6,  -13,   13,  0,  7,  0 }, {     -7,  -13,   12,  0,  7,  0 },
    {     -8,  -13,   11,  0,  7,  0 }, {     -9,  -13,   11,  0,  7,  0 }, {    -10,  -13,   10,  0,  6,  0 }, {    -11,  -13,   10,  0,  6,  0 }, {    -12,  -13,    9,  0,  6,  0 },
    {    -13,  -14,    9,  0,  6,  0 }, {    -14,  -14,    8,  0,  6,  0 }, {    -15,  -14,    8,  0,  6,  0 }, {    -16,  -14,    7,  0,  6,  0 }, {    -17,  -14,    7,  0,  6,  0 },
    {    -18,  -14,    6,  0,  6,  0 }, {    -19,  -14,    6,  0,  6,  0 }, {    -20,  -14,    5,  0,  6,  0 }, {    -21,  -14,    5,  0,  6,  0 }, {    -22,  -14,    4,  0,  6,  0 },
    {    -23,  -15,    4,  0,  6,  0 }, {    -24,  -15,    3,  0,  6,  0 }, {    -25,  -15,    3,  0,  6,  0 }, {    -26,  -15,    3,  0,  6,  0 }, {    -27,  -15,    2,  0,  6,  0 },
    {    -28,  -15,    2,  0,  6,  0 }, {    -29,  -15,    1,  0,  6,  0 }, {    -30,  -15,    1,  0,  6,  0 }, {    -31,  -15,    0,  0,  6,  0 }, {    -32,  -16,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D4FA6, {
    {     16,    0,    0,  8,  2,  0 }, {     15,    1,    0,  8,  2,  0 }, {     15,    2,    1,  8,  2,  0 }, {     15,    3,    1,  8,  2,  0 }, {     15,    4,    2,  8,  2,  0 },
    {     15,    5,    2,  8,  2,  0 }, {     15,    6,    3,  8,  2,  0 }, {     15,    7,    3,  8,  2,  0 }, {     15,    8,    3,  8,  2,  0 }, {     15,    9,    4,  8,  2,  0 },
    {     14,   10,    4,  8,  2,  0 }, {     14,   11,    5,  8,  2,  0 }, {     14,   12,    5,  8,  2,  0 }, {     14,   13,    6,  8,  2,  0 }, {     14,   14,    6,  8,  2,  0 },
    {     14,   15,    7,  8,  2,  0 }, {     14,   16,    7,  8,  2,  0 }, {     14,   17,    8,  8,  2,  0 }, {     14,   18,    8,  8,  2,  0 }, {     14,   19,    9,  8,  3,  0 },
    {     13,   20,    9,  8,  3,  0 }, {     13,   21,   10,  8,  3,  0 }, {     13,   22,   10,  8,  3,  0 }, {     13,   23,   11,  8,  3,  0 }, {     13,   24,   11,  8,  3,  0 },
    {     13,   25,   12,  8,  3,  0 }, {     13,   26,   13,  8,  3,  0 }, {     13,   27,   14,  8,  3,  0 }, {     13,   28,   15,  8,  3,  0 }, {     12,   29,   15,  8,  3,  0 },
    {     12,   30,   16,  8,  3,  0 }, {     12,   31,   17,  8,  3,  0 }, {     12,   32,   18,  8,  3,  0 }, {     12,   33,   18,  8,  3,  0 }, {     12,   34,   19,  8,  3,  0 },
    {     12,   35,   20,  8,  3,  0 }, {     12,   36,   21,  8,  3,  0 }, {     11,   37,   22,  8,  3,  0 }, {     11,   38,   23,  8,  3,  0 }, {     11,   39,   24,  8,  3,  0 },
    {     11,   40,   25,  8,  3,  0 }, {     11,   41,   26,  8,  3,  0 }, {     11,   42,   27,  8,  4,  0 }, {     11,   43,   28,  8,  4,  0 }, {     11,   44,   29,  8,  4,  0 },
    {     11,   44,   30,  8,  4,  0 }, {     10,   45,   31,  8,  4,  0 }, {     10,   46,   32,  8,  4,  0 }, {     10,   47,   33,  8,  4,  0 }, {     10,   47,   34,  8,  4,  0 },
    {     10,   48,   35,  8,  4,  0 }, {     10,   49,   36,  8,  4,  0 }, {     10,   50,   37,  8,  4,  0 }, {     10,   50,   38,  8,  4,  0 }, {     10,   51,   39,  8,  4,  0 },
    {      9,   51,   40,  8,  4,  0 }, {      9,   52,   41,  8,  4,  0 }, {      9,   53,   42,  8,  4,  0 }, {      9,   53,   43,  8,  9,  0 }, {      9,   54,   44,  8,  9,  0 },
    {      9,   55,   45,  8,  9,  0 }, {      9,   55,   46,  8,  9,  0 }, {      9,   56,   47,  8,  9,  0 }, {      9,   56,   48,  8,  9,  0 }, {      8,   56,   49,  8,  9,  0 },
    {      8,   57,   50,  8,  9,  0 }, {      8,   57,   51,  8,  9,  0 }, {      8,   57,   52,  8,  9,  0 }, {      8,   58,   53,  8,  9,  0 }, {      8,   58,   54,  8,  9,  0 },
    {      8,   58,   55,  8,  9,  0 }, {      8,   59,   56,  8,  9,  0 }, {      8,   59,   57,  8,  9,  0 }, {      8,   59,   58,  8,  9,  0 }, {      7,   60,   59,  8,  9,  0 },
    {      7,   60,   60,  8,  9,  0 }, {      7,   60,   61,  8,  9,  0 }, {      7,   61,   62,  8,  9,  0 }, {      7,   61,   63,  8,  9,  0 }, {      7,   61,   64,  8, 10,  0 },
    {      7,   61,   65,  8, 10,  0 }, {      7,   62,   66,  8, 10,  0 }, {      7,   62,   67,  8, 10,  0 }, {      7,   62,   68,  8, 10,  0 }, {      6,   62,   69,  8, 10,  0 },
    {      6,   62,   70,  8, 10,  0 }, {      6,   63,   71,  8, 10,  0 }, {      6,   63,   72,  8, 10,  0 }, {      6,   63,   73,  8, 10,  0 }, {      6,   63,   74,  8, 10,  0 },
    {      6,   63,   75,  8, 10,  0 }, {      6,   63,   76,  8, 10,  0 }, {      6,   63,   77,  8, 10,  0 }, {      6,   63,   78,  8, 10,  0 }, {      6,   63,   79,  8, 10,  0 },
    {      5,   63,   80,  8, 10,  0 }, {      5,   63,   81,  8, 10,  0 }, {      5,   63,   82,  8, 10,  0 }, {      5,   63,   83,  8, 10,  0 }, {      5,   63,   84,  8, 10,  0 },
    {      5,   63,   85,  8, 10,  0 }, {      5,   63,   86,  8, 10,  0 }, {      5,   63,   87,  8, 10,  0 }, {      5,   63,   88,  8, 10,  0 }, {      5,   63,   89,  8, 10,  0 },
    {      5,   63,   90,  8, 10,  0 }, {      5,   63,   91,  8, 11,  0 }, {      4,   63,   92,  8, 11,  0 }, {      4,   62,   93,  8, 11,  0 }, {      4,   62,   94,  8, 11,  0 },
    {      4,   62,   95,  8, 11,  0 }, {      4,   62,   96,  8, 11,  0 }, {      4,   62,   97,  8, 11,  0 }, {      4,   61,   98,  8, 11,  0 }, {      4,   61,   99,  8, 11,  0 },
    {      4,   61,  100,  8, 11,  0 }, {      4,   61,  101,  8, 11,  0 }, {      3,   60,  102,  8, 11,  0 }, {      3,   60,  103,  8, 11,  0 }, {      3,   60,  104,  8, 11,  0 },
    {      3,   59,  105,  8, 12,  0 }, {      3,   59,  106,  8, 12,  0 }, {      3,   58,  107,  8, 12,  0 }, {      3,   58,  108,  8, 12,  0 }, {      3,   57,  109,  8, 12,  0 },
    {      3,   57,  110,  8, 12,  0 }, {      3,   57,  111,  8, 12,  0 }, {      2,   56,  112,  8, 12,  0 }, {      2,   56,  113,  8, 12,  0 }, {      2,   55,  114,  8, 13,  0 },
    {      2,   55,  115,  8, 13,  0 }, {      2,   54,  116,  8, 13,  0 }, {      2,   53,  117,  8, 13,  0 }, {      2,   53,  118,  8, 13,  0 }, {      2,   52,  119,  8, 13,  0 },
    {      2,   51,  120,  8, 13,  0 }, {      1,   50,  121,  8, 13,  0 }, {      1,   49,  122,  8, 14,  0 }, {      1,   48,  123,  8, 14,  0 }, {      1,   47,  124,  8, 14,  0 },
    {      1,   46,  124,  8, 14,  0 }, {      1,   45,  125,  8, 14,  0 }, {      1,   44,  126,  8, 15,  0 }, {      1,   43,  127,  8, 15,  0 }, {      0,   42,  128,  8, 15,  0 },
    {      0,   41,  128,  8, 15,  0 }, {      0,   40,  129,  8, 15,  0 }, {      0,   39,  129,  8, 16,  0 }, {      0,   38,  129,  8, 16,  0 }, {      0,   37,  130,  8, 16,  0 },
    {      0,   36,  130,  8, 16,  0 }, {      0,   35,  130,  8, 16,  0 }, {      0,   34,  130,  8, 16,  0 }, {      0,   33,  130,  8, 16,  0 }, {      0,   32,  130,  8, 16,  0 },
    {      0,   31,  130,  8, 16,  0 }, {      0,   30,  130,  8, 16,  0 }, {      0,   29,  130,  8, 16,  0 }, {      0,   28,  130,  8, 16,  0 }, {      0,   27,  130,  8, 23,  0 },
    {      0,   26,  130,  8, 23,  0 }, {      0,   25,  129,  8, 23,  0 }, {      0,   24,  129,  8, 23,  0 }, {      0,   23,  129,  8, 23,  0 }, {      0,   22,  128,  8, 22,  0 },
    {      0,   21,  128,  8, 22,  0 }, {     -1,   20,  127,  8, 22,  0 }, {     -1,   19,  126,  8, 22,  0 }, {     -1,   18,  125,  8, 22,  0 }, {     -1,   17,  124,  8, 21,  0 },
    {     -1,   16,  124,  8, 21,  0 }, {     -1,   15,  123,  8, 21,  0 }, {     -1,   14,  122,  8, 21,  0 }, {     -1,   13,  121,  8, 21,  0 }, {     -2,   12,  120,  8, 21,  0 },
    {     -2,   11,  119,  8, 21,  0 }, {     -2,   10,  118,  8, 21,  0 }, {     -2,   10,  117,  8, 20,  0 }, {     -2,    9,  116,  8, 20,  0 }, {     -2,    8,  115,  8, 20,  0 },
    {     -2,    8,  114,  8, 20,  0 }, {     -2,    7,  113,  8, 20,  0 }, {     -2,    7,  112,  8, 20,  0 }, {     -3,    6,  111,  8, 20,  0 }, {     -3,    6,  110,  8, 20,  0 },
    {     -3,    6,  109,  8, 20,  0 }, {     -3,    5,  108,  8, 19,  0 }, {     -3,    5,  107,  8, 19,  0 }, {     -3,    4,  106,  8, 19,  0 }, {     -3,    4,  105,  8, 19,  0 },
    {     -3,    3,  104,  8, 19,  0 }, {     -3,    3,  103,  8, 19,  0 }, {     -3,    3,  102,  8, 19,  0 }, {     -4,    2,  101,  8, 19,  0 }, {     -4,    2,  100,  8, 19,  0 },
    {     -4,    2,   99,  8, 19,  0 }, {     -4,    2,   98,  8, 19,  0 }, {     -4,    1,   97,  8, 19,  0 }, {     -4,    1,   96,  8, 19,  0 }, {     -4,    1,   95,  8, 19,  0 },
    {     -4,    1,   94,  8, 18,  0 }, {     -4,    1,   93,  8, 18,  0 }, {     -4,    0,   92,  8, 18,  0 }, {     -5,    0,   91,  8, 18,  0 }, {     -5,    0,   90,  8, 18,  0 },
    {     -5,    0,   89,  8, 18,  0 }, {     -5,    0,   88,  8, 18,  0 }, {     -5,    0,   87,  8, 18,  0 }, {     -5,    0,   86,  8, 18,  0 }, {     -5,    0,   85,  8, 18,  0 },
    {     -5,    0,   84,  8, 18,  0 }, {     -5,    0,   83,  8, 18,  0 }, {     -5,    0,   82,  8, 18,  0 }, {     -5,    0,   81,  8, 18,  0 }, {     -5,    0,   80,  8, 18,  0 },
    {     -6,    0,   79,  8, 18,  0 }, {     -6,    0,   78,  8, 18,  0 }, {     -6,    0,   77,  8, 18,  0 }, {     -6,    0,   76,  8, 18,  0 }, {     -6,    0,   75,  8, 18,  0 },
    {     -6,    0,   74,  8, 18,  0 }, {     -6,    0,   73,  8, 18,  0 }, {     -6,    0,   72,  8, 18,  0 }, {     -6,    0,   71,  8, 18,  0 }, {     -6,    1,   70,  8, 18,  0 },
    {     -6,    1,   69,  8, 18,  0 }, {     -7,    1,   68,  8, 18,  0 }, {     -7,    1,   67,  8, 17,  0 }, {     -7,    1,   66,  8, 17,  0 }, {     -7,    2,   65,  8, 17,  0 },
    {     -7,    2,   64,  8, 17,  0 }, {     -7,    2,   63,  8, 17,  0 }, {     -7,    2,   62,  8, 17,  0 }, {     -7,    3,   61,  8, 17,  0 }, {     -7,    3,   60,  8, 17,  0 },
    {     -7,    3,   59,  8, 17,  0 }, {     -8,    4,   58,  8, 17,  0 }, {     -8,    4,   57,  8, 17,  0 }, {     -8,    4,   56,  8, 17,  0 }, {     -8,    5,   55,  8, 17,  0 },
    {     -8,    5,   54,  8, 17,  0 }, {     -8,    5,   53,  8, 17,  0 }, {     -8,    6,   52,  8, 17,  0 }, {     -8,    6,   51,  8, 17,  0 }, {     -8,    6,   50,  8, 17,  0 },
    {     -8,    7,   49,  8, 17,  0 }, {     -9,    7,   48,  8, 17,  0 }, {     -9,    7,   47,  8, 17,  0 }, {     -9,    8,   46,  8,  8,  0 }, {     -9,    8,   45,  8,  8,  0 },
    {     -9,    9,   44,  8,  8,  0 }, {     -9,   10,   43,  8,  8,  0 }, {     -9,   10,   42,  8,  8,  0 }, {     -9,   11,   41,  8,  8,  0 }, {     -9,   12,   40,  8,  8,  0 },
    {     -9,   12,   39,  8,  8,  0 }, {    -10,   13,   38,  8,  8,  0 }, {    -10,   13,   37,  8,  8,  0 }, {    -10,   14,   36,  8,  8,  0 }, {    -10,   15,   35,  8,  8,  0 },
    {    -10,   16,   34,  8,  8,  0 }, {    -10,   16,   33,  8,  8,  0 }, {    -10,   17,   32,  8,  8,  0 }, {    -10,   18,   31,  8,  8,  0 }, {    -11,   19,   30,  8,  7,  0 },
    {    -11,   19,   29,  8,  7,  0 }, {    -11,   20,   28,  8,  7,  0 }, {    -11,   21,   27,  8,  7,  0 }, {    -11,   22,   26,  8,  7,  0 }, {    -11,   23,   25,  8,  7,  0 },
    {    -11,   24,   24,  8,  7,  0 }, {    -11,   25,   23,  8,  7,  0 }, {    -11,   26,   22,  8,  7,  0 }, {    -12,   27,   21,  8,  7,  0 }, {    -12,   28,   20,  8,  7,  0 },
    {    -12,   29,   19,  8,  7,  0 }, {    -12,   30,   18,  8,  7,  0 }, {    -12,   31,   18,  8,  7,  0 }, {    -12,   32,   17,  8,  7,  0 }, {    -12,   33,   16,  8,  7,  0 },
    {    -12,   34,   15,  8,  7,  0 }, {    -13,   35,   15,  8,  7,  0 }, {    -13,   36,   14,  8,  7,  0 }, {    -13,   37,   13,  8,  7,  0 }, {    -13,   38,   12,  8,  7,  0 },
    {    -13,   39,   11,  8,  7,  0 }, {    -13,   40,   11,  8,  7,  0 }, {    -13,   41,   10,  8,  6,  0 }, {    -13,   42,   10,  8,  6,  0 }, {    -13,   43,    9,  8,  6,  0 },
    {    -14,   44,    9,  8,  6,  0 }, {    -14,   45,    8,  8,  6,  0 }, {    -14,   46,    8,  8,  6,  0 }, {    -14,   47,    7,  8,  6,  0 }, {    -14,   48,    7,  8,  6,  0 },
    {    -14,   49,    6,  8,  6,  0 }, {    -14,   50,    6,  8,  6,  0 }, {    -14,   51,    5,  8,  6,  0 }, {    -14,   52,    5,  8,  6,  0 }, {    -14,   53,    4,  8,  6,  0 },
    {    -15,   54,    4,  8,  6,  0 }, {    -15,   55,    3,  8,  6,  0 }, {    -15,   56,    3,  8,  6,  0 }, {    -15,   57,    3,  8,  6,  0 }, {    -15,   58,    2,  8,  6,  0 },
    {    -15,   59,    2,  8,  6,  0 }, {    -15,   60,    1,  8,  6,  0 }, {    -15,   61,    1,  8,  6,  0 }, {    -15,   62,    0,  8,  6,  0 }, {    -16,   63,    0,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D5A8E, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    2, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    3, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    3, 16,  2,  0 }, {      9,   16,    4, 16,  2,  0 },
    {     10,   17,    4, 16,  2,  0 }, {     11,   17,    5, 16,  2,  0 }, {     12,   17,    5, 16,  2,  0 }, {     13,   17,    6, 16,  2,  0 }, {     14,   17,    6, 16,  2,  0 },
    {     15,   17,    7, 16,  2,  0 }, {     16,   17,    7, 16,  2,  0 }, {     17,   17,    8, 16,  2,  0 }, {     18,   17,    8, 16,  2,  0 }, {     19,   17,    9, 16,  3,  0 },
    {     20,   18,    9, 16,  3,  0 }, {     21,   18,   10, 16,  3,  0 }, {     22,   18,   10, 16,  3,  0 }, {     23,   18,   11, 16,  3,  0 }, {     24,   18,   11, 16,  3,  0 },
    {     25,   18,   12, 16,  3,  0 }, {     26,   18,   13, 16,  3,  0 }, {     27,   18,   14, 16,  3,  0 }, {     28,   18,   15, 16,  3,  0 }, {     29,   19,   15, 16,  3,  0 },
    {     30,   19,   16, 16,  3,  0 }, {     31,   19,   17, 16,  3,  0 }, {     32,   19,   18, 16,  3,  0 }, {     33,   19,   18, 16,  3,  0 }, {     34,   19,   19, 16,  3,  0 },
    {     35,   19,   20, 16,  3,  0 }, {     36,   19,   21, 16,  3,  0 }, {     37,   20,   22, 16,  3,  0 }, {     38,   20,   23, 16,  3,  0 }, {     39,   20,   24, 16,  3,  0 },
    {     40,   20,   25, 16,  3,  0 }, {     41,   20,   26, 16,  3,  0 }, {     42,   20,   27, 16,  4,  0 }, {     43,   20,   28, 16,  4,  0 }, {     44,   20,   29, 16,  4,  0 },
    {     44,   20,   30, 16,  4,  0 }, {     45,   21,   31, 16,  4,  0 }, {     46,   21,   32, 16,  4,  0 }, {     47,   21,   33, 16,  4,  0 }, {     47,   21,   34, 16,  4,  0 },
    {     48,   21,   35, 16,  4,  0 }, {     49,   21,   36, 16,  4,  0 }, {     50,   21,   37, 16,  4,  0 }, {     50,   21,   38, 16,  4,  0 }, {     51,   22,   39, 16,  4,  0 },
    {     51,   22,   40, 16,  4,  0 }, {     52,   22,   41, 16,  4,  0 }, {     53,   22,   42, 16,  4,  0 }, {     53,   22,   43, 16,  9,  0 }, {     54,   22,   44, 16,  9,  0 },
    {     55,   22,   45, 16,  9,  0 }, {     55,   22,   46, 16,  9,  0 }, {     56,   22,   47, 16,  9,  0 }, {     56,   22,   48, 16,  9,  0 }, {     56,   23,   49, 16,  9,  0 },
    {     57,   23,   50, 16,  9,  0 }, {     57,   23,   51, 16,  9,  0 }, {     57,   23,   52, 16,  9,  0 }, {     58,   23,   53, 16,  9,  0 }, {     58,   23,   54, 16,  9,  0 },
    {     58,   23,   55, 16,  9,  0 }, {     59,   23,   56, 16,  9,  0 }, {     59,   23,   57, 16,  9,  0 }, {     59,   23,   58, 16,  9,  0 }, {     60,   24,   59, 16,  9,  0 },
    {     60,   24,   60, 16,  9,  0 }, {     60,   24,   61, 16,  9,  0 }, {     61,   24,   62, 16,  9,  0 }, {     61,   24,   63, 16,  9,  0 }, {     61,   24,   64, 16, 10,  0 },
    {     61,   24,   65, 16, 10,  0 }, {     62,   24,   66, 16, 10,  0 }, {     62,   24,   67, 16, 10,  0 }, {     62,   24,   68, 16, 10,  0 }, {     62,   25,   69, 16, 10,  0 },
    {     62,   25,   70, 16, 10,  0 }, {     63,   25,   71, 16, 10,  0 }, {     63,   25,   72, 16, 10,  0 }, {     63,   25,   73, 16, 10,  0 }, {     63,   25,   74, 16, 10,  0 },
    {     63,   25,   75, 16, 10,  0 }, {     63,   25,   76, 16, 10,  0 }, {     63,   25,   77, 16, 10,  0 }, {     63,   25,   78, 16, 10,  0 }, {     63,   25,   79, 16, 10,  0 },
    {     63,   26,   80, 16, 10,  0 }, {     63,   26,   81, 16, 10,  0 }, {     63,   26,   82, 16, 10,  0 }, {     63,   26,   83, 16, 10,  0 }, {     63,   26,   84, 16, 10,  0 },
    {     63,   26,   85, 16, 10,  0 }, {     63,   26,   86, 16, 10,  0 }, {     63,   26,   87, 16, 10,  0 }, {     63,   26,   88, 16, 10,  0 }, {     63,   26,   89, 16, 10,  0 },
    {     63,   26,   90, 16, 10,  0 }, {     63,   26,   91, 16, 11,  0 }, {     63,   27,   92, 16, 11,  0 }, {     62,   27,   93, 16, 11,  0 }, {     62,   27,   94, 16, 11,  0 },
    {     62,   27,   95, 16, 11,  0 }, {     62,   27,   96, 16, 11,  0 }, {     62,   27,   97, 16, 11,  0 }, {     61,   27,   98, 16, 11,  0 }, {     61,   27,   99, 16, 11,  0 },
    {     61,   27,  100, 16, 11,  0 }, {     61,   27,  101, 16, 11,  0 }, {     60,   28,  102, 16, 11,  0 }, {     60,   28,  103, 16, 11,  0 }, {     60,   28,  104, 16, 11,  0 },
    {     59,   28,  105, 16, 12,  0 }, {     59,   28,  106, 16, 12,  0 }, {     58,   28,  107, 16, 12,  0 }, {     58,   28,  108, 16, 12,  0 }, {     57,   28,  109, 16, 12,  0 },
    {     57,   28,  110, 16, 12,  0 }, {     57,   28,  111, 16, 12,  0 }, {     56,   29,  112, 16, 12,  0 }, {     56,   29,  113, 16, 12,  0 }, {     55,   29,  114, 16, 13,  0 },
    {     55,   29,  115, 16, 13,  0 }, {     54,   29,  116, 16, 13,  0 }, {     53,   29,  117, 16, 13,  0 }, {     53,   29,  118, 16, 13,  0 }, {     52,   29,  119, 16, 13,  0 },
    {     51,   29,  120, 16, 13,  0 }, {     50,   30,  121, 16, 13,  0 }, {     49,   30,  122, 16, 14,  0 }, {     48,   30,  123, 16, 14,  0 }, {     47,   30,  124, 16, 14,  0 },
    {     46,   30,  124, 16, 14,  0 }, {     45,   30,  125, 16, 14,  0 }, {     44,   30,  126, 16, 15,  0 }, {     43,   30,  127, 16, 15,  0 }, {     42,   31,  128, 16, 15,  0 },
    {     41,   31,  128, 16, 15,  0 }, {     40,   31,  129, 16, 15,  0 }, {     39,   31,  129, 16, 16,  0 }, {     38,   31,  129, 16, 16,  0 }, {     37,   31,  130, 16, 16,  0 },
    {     36,   31,  130, 16, 16,  0 }, {     35,   31,  130, 16, 16,  0 }, {     34,   31,  130, 16, 16,  0 }, {     33,   31,  130, 16, 16,  0 }, {     32,   31,  130, 16, 16,  0 },
    {     31,   32,  130, 16, 16,  0 }, {     30,   32,  130, 16, 16,  0 }, {     29,   32,  130, 16, 16,  0 }, {     28,   32,  130, 16, 16,  0 }, {     27,   32,  130, 16, 23,  0 },
    {     26,   32,  130, 16, 23,  0 }, {     25,   32,  129, 16, 23,  0 }, {     24,   32,  129, 16, 23,  0 }, {     23,   32,  129, 16, 23,  0 }, {     22,   32,  128, 16, 22,  0 },
    {     21,   32,  128, 16, 22,  0 }, {     20,   33,  127, 16, 22,  0 }, {     19,   33,  126, 16, 22,  0 }, {     18,   33,  125, 16, 22,  0 }, {     17,   33,  124, 16, 21,  0 },
    {     16,   33,  124, 16, 21,  0 }, {     15,   33,  123, 16, 21,  0 }, {     14,   33,  122, 16, 21,  0 }, {     13,   33,  121, 16, 21,  0 }, {     12,   34,  120, 16, 21,  0 },
    {     11,   34,  119, 16, 21,  0 }, {     10,   34,  118, 16, 21,  0 }, {     10,   34,  117, 16, 20,  0 }, {      9,   34,  116, 16, 20,  0 }, {      8,   34,  115, 16, 20,  0 },
    {      8,   34,  114, 16, 20,  0 }, {      7,   34,  113, 16, 20,  0 }, {      7,   34,  112, 16, 20,  0 }, {      6,   35,  111, 16, 20,  0 }, {      6,   35,  110, 16, 20,  0 },
    {      6,   35,  109, 16, 20,  0 }, {      5,   35,  108, 16, 19,  0 }, {      5,   35,  107, 16, 19,  0 }, {      4,   35,  106, 16, 19,  0 }, {      4,   35,  105, 16, 19,  0 },
    {      3,   35,  104, 16, 19,  0 }, {      3,   35,  103, 16, 19,  0 }, {      3,   35,  102, 16, 19,  0 }, {      2,   36,  101, 16, 19,  0 }, {      2,   36,  100, 16, 19,  0 },
    {      2,   36,   99, 16, 19,  0 }, {      2,   36,   98, 16, 19,  0 }, {      1,   36,   97, 16, 19,  0 }, {      1,   36,   96, 16, 19,  0 }, {      1,   36,   95, 16, 19,  0 },
    {      1,   36,   94, 16, 18,  0 }, {      1,   36,   93, 16, 18,  0 }, {      0,   36,   92, 16, 18,  0 }, {      0,   37,   91, 16, 18,  0 }, {      0,   37,   90, 16, 18,  0 },
    {      0,   37,   89, 16, 18,  0 }, {      0,   37,   88, 16, 18,  0 }, {      0,   37,   87, 16, 18,  0 }, {      0,   37,   86, 16, 18,  0 }, {      0,   37,   85, 16, 18,  0 },
    {      0,   37,   84, 16, 18,  0 }, {      0,   37,   83, 16, 18,  0 }, {      0,   37,   82, 16, 18,  0 }, {      0,   37,   81, 16, 18,  0 }, {      0,   37,   80, 16, 18,  0 },
    {      0,   38,   79, 16, 18,  0 }, {      0,   38,   78, 16, 18,  0 }, {      0,   38,   77, 16, 18,  0 }, {      0,   38,   76, 16, 18,  0 }, {      0,   38,   75, 16, 18,  0 },
    {      0,   38,   74, 16, 18,  0 }, {      0,   38,   73, 16, 18,  0 }, {      0,   38,   72, 16, 18,  0 }, {      0,   38,   71, 16, 18,  0 }, {      1,   38,   70, 16, 18,  0 },
    {      1,   38,   69, 16, 18,  0 }, {      1,   39,   68, 16, 18,  0 }, {      1,   39,   67, 16, 17,  0 }, {      1,   39,   66, 16, 17,  0 }, {      2,   39,   65, 16, 17,  0 },
    {      2,   39,   64, 16, 17,  0 }, {      2,   39,   63, 16, 17,  0 }, {      2,   39,   62, 16, 17,  0 }, {      3,   39,   61, 16, 17,  0 }, {      3,   39,   60, 16, 17,  0 },
    {      3,   39,   59, 16, 17,  0 }, {      4,   40,   58, 16, 17,  0 }, {      4,   40,   57, 16, 17,  0 }, {      4,   40,   56, 16, 17,  0 }, {      5,   40,   55, 16, 17,  0 },
    {      5,   40,   54, 16, 17,  0 }, {      5,   40,   53, 16, 17,  0 }, {      6,   40,   52, 16, 17,  0 }, {      6,   40,   51, 16, 17,  0 }, {      6,   40,   50, 16, 17,  0 },
    {      7,   40,   49, 16, 17,  0 }, {      7,   41,   48, 16, 17,  0 }, {      7,   41,   47, 16, 17,  0 }, {      8,   41,   46, 16,  8,  0 }, {      8,   41,   45, 16,  8,  0 },
    {      9,   41,   44, 16,  8,  0 }, {     10,   41,   43, 16,  8,  0 }, {     10,   41,   42, 16,  8,  0 }, {     11,   41,   41, 16,  8,  0 }, {     12,   41,   40, 16,  8,  0 },
    {     12,   41,   39, 16,  8,  0 }, {     13,   42,   38, 16,  8,  0 }, {     13,   42,   37, 16,  8,  0 }, {     14,   42,   36, 16,  8,  0 }, {     15,   42,   35, 16,  8,  0 },
    {     16,   42,   34, 16,  8,  0 }, {     16,   42,   33, 16,  8,  0 }, {     17,   42,   32, 16,  8,  0 }, {     18,   42,   31, 16,  8,  0 }, {     19,   43,   30, 16,  7,  0 },
    {     19,   43,   29, 16,  7,  0 }, {     20,   43,   28, 16,  7,  0 }, {     21,   43,   27, 16,  7,  0 }, {     22,   43,   26, 16,  7,  0 }, {     23,   43,   25, 16,  7,  0 },
    {     24,   43,   24, 16,  7,  0 }, {     25,   43,   23, 16,  7,  0 }, {     26,   43,   22, 16,  7,  0 }, {     27,   44,   21, 16,  7,  0 }, {     28,   44,   20, 16,  7,  0 },
    {     29,   44,   19, 16,  7,  0 }, {     30,   44,   18, 16,  7,  0 }, {     31,   44,   18, 16,  7,  0 }, {     32,   44,   17, 16,  7,  0 }, {     33,   44,   16, 16,  7,  0 },
    {     34,   44,   15, 16,  7,  0 }, {     35,   45,   15, 16,  7,  0 }, {     36,   45,   14, 16,  7,  0 }, {     37,   45,   13, 16,  7,  0 }, {     38,   45,   12, 16,  7,  0 },
    {     39,   45,   11, 16,  7,  0 }, {     40,   45,   11, 16,  7,  0 }, {     41,   45,   10, 16,  6,  0 }, {     42,   45,   10, 16,  6,  0 }, {     43,   45,    9, 16,  6,  0 },
    {     44,   46,    9, 16,  6,  0 }, {     45,   46,    8, 16,  6,  0 }, {     46,   46,    8, 16,  6,  0 }, {     47,   46,    7, 16,  6,  0 }, {     48,   46,    7, 16,  6,  0 },
    {     49,   46,    6, 16,  6,  0 }, {     50,   46,    6, 16,  6,  0 }, {     51,   46,    5, 16,  6,  0 }, {     52,   46,    5, 16,  6,  0 }, {     53,   46,    4, 16,  6,  0 },
    {     54,   47,    4, 16,  6,  0 }, {     55,   47,    3, 16,  6,  0 }, {     56,   47,    3, 16,  6,  0 }, {     57,   47,    3, 16,  6,  0 }, {     58,   47,    2, 16,  6,  0 },
    {     59,   47,    2, 16,  6,  0 }, {     60,   47,    1, 16,  6,  0 }, {     61,   47,    1, 16,  6,  0 }, {     62,   47,    0, 16,  6,  0 }, {     63,   48,    0, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D6576, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    0, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    1, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    2, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    3, 24,  2,  0 }, {     16,   23,    3, 24,  2,  0 }, {     16,   22,    4, 24,  2,  0 },
    {     17,   21,    4, 24,  2,  0 }, {     17,   20,    5, 24,  2,  0 }, {     17,   19,    5, 24,  2,  0 }, {     17,   18,    6, 24,  2,  0 }, {     17,   17,    6, 24,  2,  0 },
    {     17,   16,    7, 24,  2,  0 }, {     17,   15,    7, 24,  2,  0 }, {     17,   14,    8, 24,  2,  0 }, {     17,   13,    8, 24,  2,  0 }, {     17,   12,    9, 24,  3,  0 },
    {     18,   11,    9, 24,  3,  0 }, {     18,   10,   10, 24,  3,  0 }, {     18,    9,   10, 24,  3,  0 }, {     18,    8,   11, 24,  3,  0 }, {     18,    7,   11, 24,  3,  0 },
    {     18,    6,   12, 24,  3,  0 }, {     18,    5,   13, 24,  3,  0 }, {     18,    4,   14, 24,  3,  0 }, {     18,    3,   15, 24,  3,  0 }, {     19,    2,   15, 24,  3,  0 },
    {     19,    1,   16, 24,  3,  0 }, {     19,    0,   17, 24,  3,  0 }, {     19,   -1,   18, 24,  3,  0 }, {     19,   -2,   18, 24,  3,  0 }, {     19,   -3,   19, 24,  3,  0 },
    {     19,   -4,   20, 24,  3,  0 }, {     19,   -5,   21, 24,  3,  0 }, {     20,   -6,   22, 24,  3,  0 }, {     20,   -7,   23, 24,  3,  0 }, {     20,   -8,   24, 24,  3,  0 },
    {     20,   -9,   25, 24,  3,  0 }, {     20,  -10,   26, 24,  3,  0 }, {     20,  -11,   27, 24,  4,  0 }, {     20,  -12,   28, 24,  4,  0 }, {     20,  -13,   29, 24,  4,  0 },
    {     20,  -13,   30, 24,  4,  0 }, {     21,  -14,   31, 24,  4,  0 }, {     21,  -15,   32, 24,  4,  0 }, {     21,  -16,   33, 24,  4,  0 }, {     21,  -16,   34, 24,  4,  0 },
    {     21,  -17,   35, 24,  4,  0 }, {     21,  -18,   36, 24,  4,  0 }, {     21,  -19,   37, 24,  4,  0 }, {     21,  -19,   38, 24,  4,  0 }, {     22,  -20,   39, 24,  4,  0 },
    {     22,  -20,   40, 24,  4,  0 }, {     22,  -21,   41, 24,  4,  0 }, {     22,  -22,   42, 24,  4,  0 }, {     22,  -22,   43, 24,  9,  0 }, {     22,  -23,   44, 24,  9,  0 },
    {     22,  -24,   45, 24,  9,  0 }, {     22,  -24,   46, 24,  9,  0 }, {     22,  -25,   47, 24,  9,  0 }, {     22,  -25,   48, 24,  9,  0 }, {     23,  -25,   49, 24,  9,  0 },
    {     23,  -26,   50, 24,  9,  0 }, {     23,  -26,   51, 24,  9,  0 }, {     23,  -26,   52, 24,  9,  0 }, {     23,  -27,   53, 24,  9,  0 }, {     23,  -27,   54, 24,  9,  0 },
    {     23,  -27,   55, 24,  9,  0 }, {     23,  -28,   56, 24,  9,  0 }, {     23,  -28,   57, 24,  9,  0 }, {     23,  -28,   58, 24,  9,  0 }, {     24,  -29,   59, 24,  9,  0 },
    {     24,  -29,   60, 24,  9,  0 }, {     24,  -29,   61, 24,  9,  0 }, {     24,  -30,   62, 24,  9,  0 }, {     24,  -30,   63, 24,  9,  0 }, {     24,  -30,   64, 24, 10,  0 },
    {     24,  -30,   65, 24, 10,  0 }, {     24,  -31,   66, 24, 10,  0 }, {     24,  -31,   67, 24, 10,  0 }, {     24,  -31,   68, 24, 10,  0 }, {     25,  -31,   69, 24, 10,  0 },
    {     25,  -31,   70, 24, 10,  0 }, {     25,  -32,   71, 24, 10,  0 }, {     25,  -32,   72, 24, 10,  0 }, {     25,  -32,   73, 24, 10,  0 }, {     25,  -32,   74, 24, 10,  0 },
    {     25,  -32,   75, 24, 10,  0 }, {     25,  -32,   76, 24, 10,  0 }, {     25,  -32,   77, 24, 10,  0 }, {     25,  -32,   78, 24, 10,  0 }, {     25,  -32,   79, 24, 10,  0 },
    {     26,  -32,   80, 24, 10,  0 }, {     26,  -32,   81, 24, 10,  0 }, {     26,  -32,   82, 24, 10,  0 }, {     26,  -32,   83, 24, 10,  0 }, {     26,  -32,   84, 24, 10,  0 },
    {     26,  -32,   85, 24, 10,  0 }, {     26,  -32,   86, 24, 10,  0 }, {     26,  -32,   87, 24, 10,  0 }, {     26,  -32,   88, 24, 10,  0 }, {     26,  -32,   89, 24, 10,  0 },
    {     26,  -32,   90, 24, 10,  0 }, {     26,  -32,   91, 24, 11,  0 }, {     27,  -32,   92, 24, 11,  0 }, {     27,  -31,   93, 24, 11,  0 }, {     27,  -31,   94, 24, 11,  0 },
    {     27,  -31,   95, 24, 11,  0 }, {     27,  -31,   96, 24, 11,  0 }, {     27,  -31,   97, 24, 11,  0 }, {     27,  -30,   98, 24, 11,  0 }, {     27,  -30,   99, 24, 11,  0 },
    {     27,  -30,  100, 24, 11,  0 }, {     27,  -30,  101, 24, 11,  0 }, {     28,  -29,  102, 24, 11,  0 }, {     28,  -29,  103, 24, 11,  0 }, {     28,  -29,  104, 24, 11,  0 },
    {     28,  -28,  105, 24, 12,  0 }, {     28,  -28,  106, 24, 12,  0 }, {     28,  -27,  107, 24, 12,  0 }, {     28,  -27,  108, 24, 12,  0 }, {     28,  -26,  109, 24, 12,  0 },
    {     28,  -26,  110, 24, 12,  0 }, {     28,  -26,  111, 24, 12,  0 }, {     29,  -25,  112, 24, 12,  0 }, {     29,  -25,  113, 24, 12,  0 }, {     29,  -24,  114, 24, 13,  0 },
    {     29,  -24,  115, 24, 13,  0 }, {     29,  -23,  116, 24, 13,  0 }, {     29,  -22,  117, 24, 13,  0 }, {     29,  -22,  118, 24, 13,  0 }, {     29,  -21,  119, 24, 13,  0 },
    {     29,  -20,  120, 24, 13,  0 }, {     30,  -19,  121, 24, 13,  0 }, {     30,  -18,  122, 24, 14,  0 }, {     30,  -17,  123, 24, 14,  0 }, {     30,  -16,  124, 24, 14,  0 },
    {     30,  -15,  124, 24, 14,  0 }, {     30,  -14,  125, 24, 14,  0 }, {     30,  -13,  126, 24, 15,  0 }, {     30,  -12,  127, 24, 15,  0 }, {     31,  -11,  128, 24, 15,  0 },
    {     31,  -10,  128, 24, 15,  0 }, {     31,   -9,  129, 24, 15,  0 }, {     31,   -8,  129, 24, 16,  0 }, {     31,   -7,  129, 24, 16,  0 }, {     31,   -6,  130, 24, 16,  0 },
    {     31,   -5,  130, 24, 16,  0 }, {     31,   -4,  130, 24, 16,  0 }, {     31,   -3,  130, 24, 16,  0 }, {     31,   -2,  130, 24, 16,  0 }, {     31,   -1,  130, 24, 16,  0 },
    {     32,    0,  130, 24, 16,  0 }, {     32,    1,  130, 24, 16,  0 }, {     32,    2,  130, 24, 16,  0 }, {     32,    3,  130, 24, 16,  0 }, {     32,    4,  130, 24, 23,  0 },
    {     32,    5,  130, 24, 23,  0 }, {     32,    6,  129, 24, 23,  0 }, {     32,    7,  129, 24, 23,  0 }, {     32,    8,  129, 24, 23,  0 }, {     32,    9,  128, 24, 22,  0 },
    {     32,   10,  128, 24, 22,  0 }, {     33,   11,  127, 24, 22,  0 }, {     33,   12,  126, 24, 22,  0 }, {     33,   13,  125, 24, 22,  0 }, {     33,   14,  124, 24, 21,  0 },
    {     33,   15,  124, 24, 21,  0 }, {     33,   16,  123, 24, 21,  0 }, {     33,   17,  122, 24, 21,  0 }, {     33,   18,  121, 24, 21,  0 }, {     34,   19,  120, 24, 21,  0 },
    {     34,   20,  119, 24, 21,  0 }, {     34,   21,  118, 24, 21,  0 }, {     34,   21,  117, 24, 20,  0 }, {     34,   22,  116, 24, 20,  0 }, {     34,   23,  115, 24, 20,  0 },
    {     34,   23,  114, 24, 20,  0 }, {     34,   24,  113, 24, 20,  0 }, {     34,   24,  112, 24, 20,  0 }, {     35,   25,  111, 24, 20,  0 }, {     35,   25,  110, 24, 20,  0 },
    {     35,   25,  109, 24, 20,  0 }, {     35,   26,  108, 24, 19,  0 }, {     35,   26,  107, 24, 19,  0 }, {     35,   27,  106, 24, 19,  0 }, {     35,   27,  105, 24, 19,  0 },
    {     35,   28,  104, 24, 19,  0 }, {     35,   28,  103, 24, 19,  0 }, {     35,   28,  102, 24, 19,  0 }, {     36,   29,  101, 24, 19,  0 }, {     36,   29,  100, 24, 19,  0 },
    {     36,   29,   99, 24, 19,  0 }, {     36,   29,   98, 24, 19,  0 }, {     36,   30,   97, 24, 19,  0 }, {     36,   30,   96, 24, 19,  0 }, {     36,   30,   95, 24, 19,  0 },
    {     36,   30,   94, 24, 18,  0 }, {     36,   30,   93, 24, 18,  0 }, {     36,   31,   92, 24, 18,  0 }, {     37,   31,   91, 24, 18,  0 }, {     37,   31,   90, 24, 18,  0 },
    {     37,   31,   89, 24, 18,  0 }, {     37,   31,   88, 24, 18,  0 }, {     37,   31,   87, 24, 18,  0 }, {     37,   31,   86, 24, 18,  0 }, {     37,   31,   85, 24, 18,  0 },
    {     37,   31,   84, 24, 18,  0 }, {     37,   31,   83, 24, 18,  0 }, {     37,   31,   82, 24, 18,  0 }, {     37,   31,   81, 24, 18,  0 }, {     37,   31,   80, 24, 18,  0 },
    {     38,   31,   79, 24, 18,  0 }, {     38,   31,   78, 24, 18,  0 }, {     38,   31,   77, 24, 18,  0 }, {     38,   31,   76, 24, 18,  0 }, {     38,   31,   75, 24, 18,  0 },
    {     38,   31,   74, 24, 18,  0 }, {     38,   31,   73, 24, 18,  0 }, {     38,   31,   72, 24, 18,  0 }, {     38,   31,   71, 24, 18,  0 }, {     38,   30,   70, 24, 18,  0 },
    {     38,   30,   69, 24, 18,  0 }, {     39,   30,   68, 24, 18,  0 }, {     39,   30,   67, 24, 17,  0 }, {     39,   30,   66, 24, 17,  0 }, {     39,   29,   65, 24, 17,  0 },
    {     39,   29,   64, 24, 17,  0 }, {     39,   29,   63, 24, 17,  0 }, {     39,   29,   62, 24, 17,  0 }, {     39,   28,   61, 24, 17,  0 }, {     39,   28,   60, 24, 17,  0 },
    {     39,   28,   59, 24, 17,  0 }, {     40,   27,   58, 24, 17,  0 }, {     40,   27,   57, 24, 17,  0 }, {     40,   27,   56, 24, 17,  0 }, {     40,   26,   55, 24, 17,  0 },
    {     40,   26,   54, 24, 17,  0 }, {     40,   26,   53, 24, 17,  0 }, {     40,   25,   52, 24, 17,  0 }, {     40,   25,   51, 24, 17,  0 }, {     40,   25,   50, 24, 17,  0 },
    {     40,   24,   49, 24, 17,  0 }, {     41,   24,   48, 24, 17,  0 }, {     41,   24,   47, 24, 17,  0 }, {     41,   23,   46, 24,  8,  0 }, {     41,   23,   45, 24,  8,  0 },
    {     41,   22,   44, 24,  8,  0 }, {     41,   21,   43, 24,  8,  0 }, {     41,   21,   42, 24,  8,  0 }, {     41,   20,   41, 24,  8,  0 }, {     41,   19,   40, 24,  8,  0 },
    {     41,   19,   39, 24,  8,  0 }, {     42,   18,   38, 24,  8,  0 }, {     42,   18,   37, 24,  8,  0 }, {     42,   17,   36, 24,  8,  0 }, {     42,   16,   35, 24,  8,  0 },
    {     42,   15,   34, 24,  8,  0 }, {     42,   15,   33, 24,  8,  0 }, {     42,   14,   32, 24,  8,  0 }, {     42,   13,   31, 24,  8,  0 }, {     43,   12,   30, 24,  7,  0 },
    {     43,   12,   29, 24,  7,  0 }, {     43,   11,   28, 24,  7,  0 }, {     43,   10,   27, 24,  7,  0 }, {     43,    9,   26, 24,  7,  0 }, {     43,    8,   25, 24,  7,  0 },
    {     43,    7,   24, 24,  7,  0 }, {     43,    6,   23, 24,  7,  0 }, {     43,    5,   22, 24,  7,  0 }, {     44,    4,   21, 24,  7,  0 }, {     44,    3,   20, 24,  7,  0 },
    {     44,    2,   19, 24,  7,  0 }, {     44,    1,   18, 24,  7,  0 }, {     44,    0,   18, 24,  7,  0 }, {     44,   -1,   17, 24,  7,  0 }, {     44,   -2,   16, 24,  7,  0 },
    {     44,   -3,   15, 24,  7,  0 }, {     45,   -4,   15, 24,  7,  0 }, {     45,   -5,   14, 24,  7,  0 }, {     45,   -6,   13, 24,  7,  0 }, {     45,   -7,   12, 24,  7,  0 },
    {     45,   -8,   11, 24,  7,  0 }, {     45,   -9,   11, 24,  7,  0 }, {     45,  -10,   10, 24,  6,  0 }, {     45,  -11,   10, 24,  6,  0 }, {     45,  -12,    9, 24,  6,  0 },
    {     46,  -13,    9, 24,  6,  0 }, {     46,  -14,    8, 24,  6,  0 }, {     46,  -15,    8, 24,  6,  0 }, {     46,  -16,    7, 24,  6,  0 }, {     46,  -17,    7, 24,  6,  0 },
    {     46,  -18,    6, 24,  6,  0 }, {     46,  -19,    6, 24,  6,  0 }, {     46,  -20,    5, 24,  6,  0 }, {     46,  -21,    5, 24,  6,  0 }, {     46,  -22,    4, 24,  6,  0 },
    {     47,  -23,    4, 24,  6,  0 }, {     47,  -24,    3, 24,  6,  0 }, {     47,  -25,    3, 24,  6,  0 }, {     47,  -26,    3, 24,  6,  0 }, {     47,  -27,    2, 24,  6,  0 },
    {     47,  -28,    2, 24,  6,  0 }, {     47,  -29,    1, 24,  6,  0 }, {     47,  -30,    1, 24,  6,  0 }, {     47,  -31,    0, 24,  6,  0 }, {     48,  -32,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D705E, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    0,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    1,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    2,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    3,  0,  2,  0 }, {     23,   16,    3,  0,  2,  0 }, {     22,   16,    4,  0,  2,  0 },
    {     21,   17,    4,  0,  2,  0 }, {     20,   17,    5,  0,  2,  0 }, {     19,   17,    5,  0,  2,  0 }, {     18,   17,    6,  0,  2,  0 }, {     17,   17,    6,  0,  2,  0 },
    {     16,   17,    7,  0,  2,  0 }, {     15,   17,    7,  0,  2,  0 }, {     14,   17,    8,  0,  2,  0 }, {     13,   17,    8,  0,  2,  0 }, {     12,   17,    9,  0,  3,  0 },
    {     11,   18,    9,  0,  3,  0 }, {     10,   18,   10,  0,  3,  0 }, {      9,   18,   10,  0,  3,  0 }, {      8,   18,   11,  0,  3,  0 }, {      7,   18,   11,  0,  3,  0 },
    {      6,   18,   12,  0,  3,  0 }, {      5,   18,   13,  0,  3,  0 }, {      4,   18,   14,  0,  3,  0 }, {      3,   18,   15,  0,  3,  0 }, {      2,   19,   15,  0,  3,  0 },
    {      1,   19,   16,  0,  3,  0 }, {      0,   19,   17,  0,  3,  0 }, {     -1,   19,   18,  0,  3,  0 }, {     -2,   19,   18,  0,  3,  0 }, {     -3,   19,   19,  0,  3,  0 },
    {     -4,   19,   20,  0,  3,  0 }, {     -5,   19,   21,  0,  3,  0 }, {     -6,   20,   22,  0,  3,  0 }, {     -7,   20,   23,  0,  3,  0 }, {     -8,   20,   24,  0,  3,  0 },
    {     -9,   20,   25,  0,  3,  0 }, {    -10,   20,   26,  0,  3,  0 }, {    -11,   20,   27,  0,  4,  0 }, {    -12,   20,   28,  0,  4,  0 }, {    -13,   20,   29,  0,  4,  0 },
    {    -13,   20,   30,  0,  4,  0 }, {    -14,   21,   31,  0,  4,  0 }, {    -15,   21,   32,  0,  4,  0 }, {    -16,   21,   33,  0,  4,  0 }, {    -16,   21,   34,  0,  4,  0 },
    {    -17,   21,   35,  0,  4,  0 }, {    -18,   21,   36,  0,  4,  0 }, {    -19,   21,   37,  0,  4,  0 }, {    -19,   21,   38,  0,  4,  0 }, {    -20,   22,   39,  0,  4,  0 },
    {    -20,   22,   40,  0,  4,  0 }, {    -21,   22,   41,  0,  4,  0 }, {    -22,   22,   42,  0,  4,  0 }, {    -22,   22,   43,  0,  9,  0 }, {    -23,   22,   44,  0,  9,  0 },
    {    -24,   22,   45,  0,  9,  0 }, {    -24,   22,   46,  0,  9,  0 }, {    -25,   22,   47,  0,  9,  0 }, {    -25,   22,   48,  0,  9,  0 }, {    -25,   23,   49,  0,  9,  0 },
    {    -26,   23,   50,  0,  9,  0 }, {    -26,   23,   51,  0,  9,  0 }, {    -26,   23,   52,  0,  9,  0 }, {    -27,   23,   53,  0,  9,  0 }, {    -27,   23,   54,  0,  9,  0 },
    {    -27,   23,   55,  0,  9,  0 }, {    -28,   23,   56,  0,  9,  0 }, {    -28,   23,   57,  0,  9,  0 }, {    -28,   23,   58,  0,  9,  0 }, {    -29,   24,   59,  0,  9,  0 },
    {    -29,   24,   60,  0,  9,  0 }, {    -29,   24,   61,  0,  9,  0 }, {    -30,   24,   62,  0,  9,  0 }, {    -30,   24,   63,  0,  9,  0 }, {    -30,   24,   64,  0, 10,  0 },
    {    -30,   24,   65,  0, 10,  0 }, {    -31,   24,   66,  0, 10,  0 }, {    -31,   24,   67,  0, 10,  0 }, {    -31,   24,   68,  0, 10,  0 }, {    -31,   25,   69,  0, 10,  0 },
    {    -31,   25,   70,  0, 10,  0 }, {    -32,   25,   71,  0, 10,  0 }, {    -32,   25,   72,  0, 10,  0 }, {    -32,   25,   73,  0, 10,  0 }, {    -32,   25,   74,  0, 10,  0 },
    {    -32,   25,   75,  0, 10,  0 }, {    -32,   25,   76,  0, 10,  0 }, {    -32,   25,   77,  0, 10,  0 }, {    -32,   25,   78,  0, 10,  0 }, {    -32,   25,   79,  0, 10,  0 },
    {    -32,   26,   80,  0, 10,  0 }, {    -32,   26,   81,  0, 10,  0 }, {    -32,   26,   82,  0, 10,  0 }, {    -32,   26,   83,  0, 10,  0 }, {    -32,   26,   84,  0, 10,  0 },
    {    -32,   26,   85,  0, 10,  0 }, {    -32,   26,   86,  0, 10,  0 }, {    -32,   26,   87,  0, 10,  0 }, {    -32,   26,   88,  0, 10,  0 }, {    -32,   26,   89,  0, 10,  0 },
    {    -32,   26,   90,  0, 10,  0 }, {    -32,   26,   91,  0, 11,  0 }, {    -32,   27,   92,  0, 11,  0 }, {    -31,   27,   93,  0, 11,  0 }, {    -31,   27,   94,  0, 11,  0 },
    {    -31,   27,   95,  0, 11,  0 }, {    -31,   27,   96,  0, 11,  0 }, {    -31,   27,   97,  0, 11,  0 }, {    -30,   27,   98,  0, 11,  0 }, {    -30,   27,   99,  0, 11,  0 },
    {    -30,   27,  100,  0, 11,  0 }, {    -30,   27,  101,  0, 11,  0 }, {    -29,   28,  102,  0, 11,  0 }, {    -29,   28,  103,  0, 11,  0 }, {    -29,   28,  104,  0, 11,  0 },
    {    -28,   28,  105,  0, 12,  0 }, {    -28,   28,  106,  0, 12,  0 }, {    -27,   28,  107,  0, 12,  0 }, {    -27,   28,  108,  0, 12,  0 }, {    -26,   28,  109,  0, 12,  0 },
    {    -26,   28,  110,  0, 12,  0 }, {    -26,   28,  111,  0, 12,  0 }, {    -25,   29,  112,  0, 12,  0 }, {    -25,   29,  113,  0, 12,  0 }, {    -24,   29,  114,  0, 13,  0 },
    {    -24,   29,  115,  0, 13,  0 }, {    -23,   29,  116,  0, 13,  0 }, {    -22,   29,  117,  0, 13,  0 }, {    -22,   29,  118,  0, 13,  0 }, {    -21,   29,  119,  0, 13,  0 },
    {    -20,   29,  120,  0, 13,  0 }, {    -19,   30,  121,  0, 13,  0 }, {    -18,   30,  122,  0, 14,  0 }, {    -17,   30,  123,  0, 14,  0 }, {    -16,   30,  124,  0, 14,  0 },
    {    -15,   30,  124,  0, 14,  0 }, {    -14,   30,  125,  0, 14,  0 }, {    -13,   30,  126,  0, 15,  0 }, {    -12,   30,  127,  0, 15,  0 }, {    -11,   31,  128,  0, 15,  0 },
    {    -10,   31,  128,  0, 15,  0 }, {     -9,   31,  129,  0, 15,  0 }, {     -8,   31,  129,  0, 16,  0 }, {     -7,   31,  129,  0, 16,  0 }, {     -6,   31,  130,  0, 16,  0 },
    {     -5,   31,  130,  0, 16,  0 }, {     -4,   31,  130,  0, 16,  0 }, {     -3,   31,  130,  0, 16,  0 }, {     -2,   31,  130,  0, 16,  0 }, {     -1,   31,  130,  0, 16,  0 },
    {      0,   32,  130,  0, 16,  0 }, {      1,   32,  130,  0, 16,  0 }, {      2,   32,  130,  0, 16,  0 }, {      3,   32,  130,  0, 16,  0 }, {      4,   32,  130,  0, 23,  0 },
    {      5,   32,  130,  0, 23,  0 }, {      6,   32,  129,  0, 23,  0 }, {      7,   32,  129,  0, 23,  0 }, {      8,   32,  129,  0, 23,  0 }, {      9,   32,  128,  0, 22,  0 },
    {     10,   32,  128,  0, 22,  0 }, {     11,   33,  127,  0, 22,  0 }, {     12,   33,  126,  0, 22,  0 }, {     13,   33,  125,  0, 22,  0 }, {     14,   33,  124,  0, 21,  0 },
    {     15,   33,  124,  0, 21,  0 }, {     16,   33,  123,  0, 21,  0 }, {     17,   33,  122,  0, 21,  0 }, {     18,   33,  121,  0, 21,  0 }, {     19,   34,  120,  0, 21,  0 },
    {     20,   34,  119,  0, 21,  0 }, {     21,   34,  118,  0, 21,  0 }, {     21,   34,  117,  0, 20,  0 }, {     22,   34,  116,  0, 20,  0 }, {     23,   34,  115,  0, 20,  0 },
    {     23,   34,  114,  0, 20,  0 }, {     24,   34,  113,  0, 20,  0 }, {     24,   34,  112,  0, 20,  0 }, {     25,   35,  111,  0, 20,  0 }, {     25,   35,  110,  0, 20,  0 },
    {     25,   35,  109,  0, 20,  0 }, {     26,   35,  108,  0, 19,  0 }, {     26,   35,  107,  0, 19,  0 }, {     27,   35,  106,  0, 19,  0 }, {     27,   35,  105,  0, 19,  0 },
    {     28,   35,  104,  0, 19,  0 }, {     28,   35,  103,  0, 19,  0 }, {     28,   35,  102,  0, 19,  0 }, {     29,   36,  101,  0, 19,  0 }, {     29,   36,  100,  0, 19,  0 },
    {     29,   36,   99,  0, 19,  0 }, {     29,   36,   98,  0, 19,  0 }, {     30,   36,   97,  0, 19,  0 }, {     30,   36,   96,  0, 19,  0 }, {     30,   36,   95,  0, 19,  0 },
    {     30,   36,   94,  0, 18,  0 }, {     30,   36,   93,  0, 18,  0 }, {     31,   36,   92,  0, 18,  0 }, {     31,   37,   91,  0, 18,  0 }, {     31,   37,   90,  0, 18,  0 },
    {     31,   37,   89,  0, 18,  0 }, {     31,   37,   88,  0, 18,  0 }, {     31,   37,   87,  0, 18,  0 }, {     31,   37,   86,  0, 18,  0 }, {     31,   37,   85,  0, 18,  0 },
    {     31,   37,   84,  0, 18,  0 }, {     31,   37,   83,  0, 18,  0 }, {     31,   37,   82,  0, 18,  0 }, {     31,   37,   81,  0, 18,  0 }, {     31,   37,   80,  0, 18,  0 },
    {     31,   38,   79,  0, 18,  0 }, {     31,   38,   78,  0, 18,  0 }, {     31,   38,   77,  0, 18,  0 }, {     31,   38,   76,  0, 18,  0 }, {     31,   38,   75,  0, 18,  0 },
    {     31,   38,   74,  0, 18,  0 }, {     31,   38,   73,  0, 18,  0 }, {     31,   38,   72,  0, 18,  0 }, {     31,   38,   71,  0, 18,  0 }, {     30,   38,   70,  0, 18,  0 },
    {     30,   38,   69,  0, 18,  0 }, {     30,   39,   68,  0, 18,  0 }, {     30,   39,   67,  0, 17,  0 }, {     30,   39,   66,  0, 17,  0 }, {     29,   39,   65,  0, 17,  0 },
    {     29,   39,   64,  0, 17,  0 }, {     29,   39,   63,  0, 17,  0 }, {     29,   39,   62,  0, 17,  0 }, {     28,   39,   61,  0, 17,  0 }, {     28,   39,   60,  0, 17,  0 },
    {     28,   39,   59,  0, 17,  0 }, {     27,   40,   58,  0, 17,  0 }, {     27,   40,   57,  0, 17,  0 }, {     27,   40,   56,  0, 17,  0 }, {     26,   40,   55,  0, 17,  0 },
    {     26,   40,   54,  0, 17,  0 }, {     26,   40,   53,  0, 17,  0 }, {     25,   40,   52,  0, 17,  0 }, {     25,   40,   51,  0, 17,  0 }, {     25,   40,   50,  0, 17,  0 },
    {     24,   40,   49,  0, 17,  0 }, {     24,   41,   48,  0, 17,  0 }, {     24,   41,   47,  0, 17,  0 }, {     23,   41,   46,  0,  8,  0 }, {     23,   41,   45,  0,  8,  0 },
    {     22,   41,   44,  0,  8,  0 }, {     21,   41,   43,  0,  8,  0 }, {     21,   41,   42,  0,  8,  0 }, {     20,   41,   41,  0,  8,  0 }, {     19,   41,   40,  0,  8,  0 },
    {     19,   41,   39,  0,  8,  0 }, {     18,   42,   38,  0,  8,  0 }, {     18,   42,   37,  0,  8,  0 }, {     17,   42,   36,  0,  8,  0 }, {     16,   42,   35,  0,  8,  0 },
    {     15,   42,   34,  0,  8,  0 }, {     15,   42,   33,  0,  8,  0 }, {     14,   42,   32,  0,  8,  0 }, {     13,   42,   31,  0,  8,  0 }, {     12,   43,   30,  0,  7,  0 },
    {     12,   43,   29,  0,  7,  0 }, {     11,   43,   28,  0,  7,  0 }, {     10,   43,   27,  0,  7,  0 }, {      9,   43,   26,  0,  7,  0 }, {      8,   43,   25,  0,  7,  0 },
    {      7,   43,   24,  0,  7,  0 }, {      6,   43,   23,  0,  7,  0 }, {      5,   43,   22,  0,  7,  0 }, {      4,   44,   21,  0,  7,  0 }, {      3,   44,   20,  0,  7,  0 },
    {      2,   44,   19,  0,  7,  0 }, {      1,   44,   18,  0,  7,  0 }, {      0,   44,   18,  0,  7,  0 }, {     -1,   44,   17,  0,  7,  0 }, {     -2,   44,   16,  0,  7,  0 },
    {     -3,   44,   15,  0,  7,  0 }, {     -4,   45,   15,  0,  7,  0 }, {     -5,   45,   14,  0,  7,  0 }, {     -6,   45,   13,  0,  7,  0 }, {     -7,   45,   12,  0,  7,  0 },
    {     -8,   45,   11,  0,  7,  0 }, {     -9,   45,   11,  0,  7,  0 }, {    -10,   45,   10,  0,  6,  0 }, {    -11,   45,   10,  0,  6,  0 }, {    -12,   45,    9,  0,  6,  0 },
    {    -13,   46,    9,  0,  6,  0 }, {    -14,   46,    8,  0,  6,  0 }, {    -15,   46,    8,  0,  6,  0 }, {    -16,   46,    7,  0,  6,  0 }, {    -17,   46,    7,  0,  6,  0 },
    {    -18,   46,    6,  0,  6,  0 }, {    -19,   46,    6,  0,  6,  0 }, {    -20,   46,    5,  0,  6,  0 }, {    -21,   46,    5,  0,  6,  0 }, {    -22,   46,    4,  0,  6,  0 },
    {    -23,   47,    4,  0,  6,  0 }, {    -24,   47,    3,  0,  6,  0 }, {    -25,   47,    3,  0,  6,  0 }, {    -26,   47,    3,  0,  6,  0 }, {    -27,   47,    2,  0,  6,  0 },
    {    -28,   47,    2,  0,  6,  0 }, {    -29,   47,    1,  0,  6,  0 }, {    -30,   47,    1,  0,  6,  0 }, {    -31,   47,    0,  0,  6,  0 }, {    -32,   48,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D7B46, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    2,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    3,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    3,  8,  2,  0 }, {     16,    9,    4,  8,  2,  0 },
    {     17,   10,    4,  8,  2,  0 }, {     17,   11,    5,  8,  2,  0 }, {     17,   12,    5,  8,  2,  0 }, {     17,   13,    6,  8,  2,  0 }, {     17,   14,    6,  8,  2,  0 },
    {     17,   15,    7,  8,  2,  0 }, {     17,   16,    7,  8,  2,  0 }, {     17,   17,    8,  8,  2,  0 }, {     17,   18,    8,  8,  2,  0 }, {     17,   19,    9,  8,  3,  0 },
    {     18,   20,    9,  8,  3,  0 }, {     18,   21,   10,  8,  3,  0 }, {     18,   22,   10,  8,  3,  0 }, {     18,   23,   11,  8,  3,  0 }, {     18,   24,   11,  8,  3,  0 },
    {     18,   25,   12,  8,  3,  0 }, {     18,   26,   13,  8,  3,  0 }, {     18,   27,   14,  8,  3,  0 }, {     18,   28,   15,  8,  3,  0 }, {     19,   29,   15,  8,  3,  0 },
    {     19,   30,   16,  8,  3,  0 }, {     19,   31,   17,  8,  3,  0 }, {     19,   32,   18,  8,  3,  0 }, {     19,   33,   18,  8,  3,  0 }, {     19,   34,   19,  8,  3,  0 },
    {     19,   35,   20,  8,  3,  0 }, {     19,   36,   21,  8,  3,  0 }, {     20,   37,   22,  8,  3,  0 }, {     20,   38,   23,  8,  3,  0 }, {     20,   39,   24,  8,  3,  0 },
    {     20,   40,   25,  8,  3,  0 }, {     20,   41,   26,  8,  3,  0 }, {     20,   42,   27,  8,  4,  0 }, {     20,   43,   28,  8,  4,  0 }, {     20,   44,   29,  8,  4,  0 },
    {     20,   44,   30,  8,  4,  0 }, {     21,   45,   31,  8,  4,  0 }, {     21,   46,   32,  8,  4,  0 }, {     21,   47,   33,  8,  4,  0 }, {     21,   47,   34,  8,  4,  0 },
    {     21,   48,   35,  8,  4,  0 }, {     21,   49,   36,  8,  4,  0 }, {     21,   50,   37,  8,  4,  0 }, {     21,   50,   38,  8,  4,  0 }, {     22,   51,   39,  8,  4,  0 },
    {     22,   51,   40,  8,  4,  0 }, {     22,   52,   41,  8,  4,  0 }, {     22,   53,   42,  8,  4,  0 }, {     22,   53,   43,  8,  9,  0 }, {     22,   54,   44,  8,  9,  0 },
    {     22,   55,   45,  8,  9,  0 }, {     22,   55,   46,  8,  9,  0 }, {     22,   56,   47,  8,  9,  0 }, {     22,   56,   48,  8,  9,  0 }, {     23,   56,   49,  8,  9,  0 },
    {     23,   57,   50,  8,  9,  0 }, {     23,   57,   51,  8,  9,  0 }, {     23,   57,   52,  8,  9,  0 }, {     23,   58,   53,  8,  9,  0 }, {     23,   58,   54,  8,  9,  0 },
    {     23,   58,   55,  8,  9,  0 }, {     23,   59,   56,  8,  9,  0 }, {     23,   59,   57,  8,  9,  0 }, {     23,   59,   58,  8,  9,  0 }, {     24,   60,   59,  8,  9,  0 },
    {     24,   60,   60,  8,  9,  0 }, {     24,   60,   61,  8,  9,  0 }, {     24,   61,   62,  8,  9,  0 }, {     24,   61,   63,  8,  9,  0 }, {     24,   61,   64,  8, 10,  0 },
    {     24,   61,   65,  8, 10,  0 }, {     24,   62,   66,  8, 10,  0 }, {     24,   62,   67,  8, 10,  0 }, {     24,   62,   68,  8, 10,  0 }, {     25,   62,   69,  8, 10,  0 },
    {     25,   62,   70,  8, 10,  0 }, {     25,   63,   71,  8, 10,  0 }, {     25,   63,   72,  8, 10,  0 }, {     25,   63,   73,  8, 10,  0 }, {     25,   63,   74,  8, 10,  0 },
    {     25,   63,   75,  8, 10,  0 }, {     25,   63,   76,  8, 10,  0 }, {     25,   63,   77,  8, 10,  0 }, {     25,   63,   78,  8, 10,  0 }, {     25,   63,   79,  8, 10,  0 },
    {     26,   63,   80,  8, 10,  0 }, {     26,   63,   81,  8, 10,  0 }, {     26,   63,   82,  8, 10,  0 }, {     26,   63,   83,  8, 10,  0 }, {     26,   63,   84,  8, 10,  0 },
    {     26,   63,   85,  8, 10,  0 }, {     26,   63,   86,  8, 10,  0 }, {     26,   63,   87,  8, 10,  0 }, {     26,   63,   88,  8, 10,  0 }, {     26,   63,   89,  8, 10,  0 },
    {     26,   63,   90,  8, 10,  0 }, {     26,   63,   91,  8, 11,  0 }, {     27,   63,   92,  8, 11,  0 }, {     27,   62,   93,  8, 11,  0 }, {     27,   62,   94,  8, 11,  0 },
    {     27,   62,   95,  8, 11,  0 }, {     27,   62,   96,  8, 11,  0 }, {     27,   62,   97,  8, 11,  0 }, {     27,   61,   98,  8, 11,  0 }, {     27,   61,   99,  8, 11,  0 },
    {     27,   61,  100,  8, 11,  0 }, {     27,   61,  101,  8, 11,  0 }, {     28,   60,  102,  8, 11,  0 }, {     28,   60,  103,  8, 11,  0 }, {     28,   60,  104,  8, 11,  0 },
    {     28,   59,  105,  8, 12,  0 }, {     28,   59,  106,  8, 12,  0 }, {     28,   58,  107,  8, 12,  0 }, {     28,   58,  108,  8, 12,  0 }, {     28,   57,  109,  8, 12,  0 },
    {     28,   57,  110,  8, 12,  0 }, {     28,   57,  111,  8, 12,  0 }, {     29,   56,  112,  8, 12,  0 }, {     29,   56,  113,  8, 12,  0 }, {     29,   55,  114,  8, 13,  0 },
    {     29,   55,  115,  8, 13,  0 }, {     29,   54,  116,  8, 13,  0 }, {     29,   53,  117,  8, 13,  0 }, {     29,   53,  118,  8, 13,  0 }, {     29,   52,  119,  8, 13,  0 },
    {     29,   51,  120,  8, 13,  0 }, {     30,   50,  121,  8, 13,  0 }, {     30,   49,  122,  8, 14,  0 }, {     30,   48,  123,  8, 14,  0 }, {     30,   47,  124,  8, 14,  0 },
    {     30,   46,  124,  8, 14,  0 }, {     30,   45,  125,  8, 14,  0 }, {     30,   44,  126,  8, 15,  0 }, {     30,   43,  127,  8, 15,  0 }, {     31,   42,  128,  8, 15,  0 },
    {     31,   41,  128,  8, 15,  0 }, {     31,   40,  129,  8, 15,  0 }, {     31,   39,  129,  8, 16,  0 }, {     31,   38,  129,  8, 16,  0 }, {     31,   37,  130,  8, 16,  0 },
    {     31,   36,  130,  8, 16,  0 }, {     31,   35,  130,  8, 16,  0 }, {     31,   34,  130,  8, 16,  0 }, {     31,   33,  130,  8, 16,  0 }, {     31,   32,  130,  8, 16,  0 },
    {     32,   31,  130,  8, 16,  0 }, {     32,   30,  130,  8, 16,  0 }, {     32,   29,  130,  8, 16,  0 }, {     32,   28,  130,  8, 16,  0 }, {     32,   27,  130,  8, 23,  0 },
    {     32,   26,  130,  8, 23,  0 }, {     32,   25,  129,  8, 23,  0 }, {     32,   24,  129,  8, 23,  0 }, {     32,   23,  129,  8, 23,  0 }, {     32,   22,  128,  8, 22,  0 },
    {     32,   21,  128,  8, 22,  0 }, {     33,   20,  127,  8, 22,  0 }, {     33,   19,  126,  8, 22,  0 }, {     33,   18,  125,  8, 22,  0 }, {     33,   17,  124,  8, 21,  0 },
    {     33,   16,  124,  8, 21,  0 }, {     33,   15,  123,  8, 21,  0 }, {     33,   14,  122,  8, 21,  0 }, {     33,   13,  121,  8, 21,  0 }, {     34,   12,  120,  8, 21,  0 },
    {     34,   11,  119,  8, 21,  0 }, {     34,   10,  118,  8, 21,  0 }, {     34,   10,  117,  8, 20,  0 }, {     34,    9,  116,  8, 20,  0 }, {     34,    8,  115,  8, 20,  0 },
    {     34,    8,  114,  8, 20,  0 }, {     34,    7,  113,  8, 20,  0 }, {     34,    7,  112,  8, 20,  0 }, {     35,    6,  111,  8, 20,  0 }, {     35,    6,  110,  8, 20,  0 },
    {     35,    6,  109,  8, 20,  0 }, {     35,    5,  108,  8, 19,  0 }, {     35,    5,  107,  8, 19,  0 }, {     35,    4,  106,  8, 19,  0 }, {     35,    4,  105,  8, 19,  0 },
    {     35,    3,  104,  8, 19,  0 }, {     35,    3,  103,  8, 19,  0 }, {     35,    3,  102,  8, 19,  0 }, {     36,    2,  101,  8, 19,  0 }, {     36,    2,  100,  8, 19,  0 },
    {     36,    2,   99,  8, 19,  0 }, {     36,    2,   98,  8, 19,  0 }, {     36,    1,   97,  8, 19,  0 }, {     36,    1,   96,  8, 19,  0 }, {     36,    1,   95,  8, 19,  0 },
    {     36,    1,   94,  8, 18,  0 }, {     36,    1,   93,  8, 18,  0 }, {     36,    0,   92,  8, 18,  0 }, {     37,    0,   91,  8, 18,  0 }, {     37,    0,   90,  8, 18,  0 },
    {     37,    0,   89,  8, 18,  0 }, {     37,    0,   88,  8, 18,  0 }, {     37,    0,   87,  8, 18,  0 }, {     37,    0,   86,  8, 18,  0 }, {     37,    0,   85,  8, 18,  0 },
    {     37,    0,   84,  8, 18,  0 }, {     37,    0,   83,  8, 18,  0 }, {     37,    0,   82,  8, 18,  0 }, {     37,    0,   81,  8, 18,  0 }, {     37,    0,   80,  8, 18,  0 },
    {     38,    0,   79,  8, 18,  0 }, {     38,    0,   78,  8, 18,  0 }, {     38,    0,   77,  8, 18,  0 }, {     38,    0,   76,  8, 18,  0 }, {     38,    0,   75,  8, 18,  0 },
    {     38,    0,   74,  8, 18,  0 }, {     38,    0,   73,  8, 18,  0 }, {     38,    0,   72,  8, 18,  0 }, {     38,    0,   71,  8, 18,  0 }, {     38,    1,   70,  8, 18,  0 },
    {     38,    1,   69,  8, 18,  0 }, {     39,    1,   68,  8, 18,  0 }, {     39,    1,   67,  8, 17,  0 }, {     39,    1,   66,  8, 17,  0 }, {     39,    2,   65,  8, 17,  0 },
    {     39,    2,   64,  8, 17,  0 }, {     39,    2,   63,  8, 17,  0 }, {     39,    2,   62,  8, 17,  0 }, {     39,    3,   61,  8, 17,  0 }, {     39,    3,   60,  8, 17,  0 },
    {     39,    3,   59,  8, 17,  0 }, {     40,    4,   58,  8, 17,  0 }, {     40,    4,   57,  8, 17,  0 }, {     40,    4,   56,  8, 17,  0 }, {     40,    5,   55,  8, 17,  0 },
    {     40,    5,   54,  8, 17,  0 }, {     40,    5,   53,  8, 17,  0 }, {     40,    6,   52,  8, 17,  0 }, {     40,    6,   51,  8, 17,  0 }, {     40,    6,   50,  8, 17,  0 },
    {     40,    7,   49,  8, 17,  0 }, {     41,    7,   48,  8, 17,  0 }, {     41,    7,   47,  8, 17,  0 }, {     41,    8,   46,  8,  8,  0 }, {     41,    8,   45,  8,  8,  0 },
    {     41,    9,   44,  8,  8,  0 }, {     41,   10,   43,  8,  8,  0 }, {     41,   10,   42,  8,  8,  0 }, {     41,   11,   41,  8,  8,  0 }, {     41,   12,   40,  8,  8,  0 },
    {     41,   12,   39,  8,  8,  0 }, {     42,   13,   38,  8,  8,  0 }, {     42,   13,   37,  8,  8,  0 }, {     42,   14,   36,  8,  8,  0 }, {     42,   15,   35,  8,  8,  0 },
    {     42,   16,   34,  8,  8,  0 }, {     42,   16,   33,  8,  8,  0 }, {     42,   17,   32,  8,  8,  0 }, {     42,   18,   31,  8,  8,  0 }, {     43,   19,   30,  8,  7,  0 },
    {     43,   19,   29,  8,  7,  0 }, {     43,   20,   28,  8,  7,  0 }, {     43,   21,   27,  8,  7,  0 }, {     43,   22,   26,  8,  7,  0 }, {     43,   23,   25,  8,  7,  0 },
    {     43,   24,   24,  8,  7,  0 }, {     43,   25,   23,  8,  7,  0 }, {     43,   26,   22,  8,  7,  0 }, {     44,   27,   21,  8,  7,  0 }, {     44,   28,   20,  8,  7,  0 },
    {     44,   29,   19,  8,  7,  0 }, {     44,   30,   18,  8,  7,  0 }, {     44,   31,   18,  8,  7,  0 }, {     44,   32,   17,  8,  7,  0 }, {     44,   33,   16,  8,  7,  0 },
    {     44,   34,   15,  8,  7,  0 }, {     45,   35,   15,  8,  7,  0 }, {     45,   36,   14,  8,  7,  0 }, {     45,   37,   13,  8,  7,  0 }, {     45,   38,   12,  8,  7,  0 },
    {     45,   39,   11,  8,  7,  0 }, {     45,   40,   11,  8,  7,  0 }, {     45,   41,   10,  8,  6,  0 }, {     45,   42,   10,  8,  6,  0 }, {     45,   43,    9,  8,  6,  0 },
    {     46,   44,    9,  8,  6,  0 }, {     46,   45,    8,  8,  6,  0 }, {     46,   46,    8,  8,  6,  0 }, {     46,   47,    7,  8,  6,  0 }, {     46,   48,    7,  8,  6,  0 },
    {     46,   49,    6,  8,  6,  0 }, {     46,   50,    6,  8,  6,  0 }, {     46,   51,    5,  8,  6,  0 }, {     46,   52,    5,  8,  6,  0 }, {     46,   53,    4,  8,  6,  0 },
    {     47,   54,    4,  8,  6,  0 }, {     47,   55,    3,  8,  6,  0 }, {     47,   56,    3,  8,  6,  0 }, {     47,   57,    3,  8,  6,  0 }, {     47,   58,    2,  8,  6,  0 },
    {     47,   59,    2,  8,  6,  0 }, {     47,   60,    1,  8,  6,  0 }, {     47,   61,    1,  8,  6,  0 }, {     47,   62,    0,  8,  6,  0 }, {     48,   63,    0,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D862E, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   15,    0, 16,  2,  0 }, {      2,   15,    1, 16,  2,  0 }, {      3,   15,    1, 16,  2,  0 }, {      4,   15,    2, 16,  2,  0 },
    {      5,   15,    2, 16,  2,  0 }, {      6,   15,    3, 16,  2,  0 }, {      7,   15,    3, 16,  2,  0 }, {      8,   15,    3, 16,  2,  0 }, {      9,   15,    4, 16,  2,  0 },
    {     10,   14,    4, 16,  2,  0 }, {     11,   14,    5, 16,  2,  0 }, {     12,   14,    5, 16,  2,  0 }, {     13,   14,    6, 16,  2,  0 }, {     14,   14,    6, 16,  2,  0 },
    {     15,   14,    7, 16,  2,  0 }, {     16,   14,    7, 16,  2,  0 }, {     17,   14,    8, 16,  2,  0 }, {     18,   14,    8, 16,  2,  0 }, {     19,   14,    9, 16,  3,  0 },
    {     20,   13,    9, 16,  3,  0 }, {     21,   13,   10, 16,  3,  0 }, {     22,   13,   10, 16,  3,  0 }, {     23,   13,   11, 16,  3,  0 }, {     24,   13,   11, 16,  3,  0 },
    {     25,   13,   12, 16,  3,  0 }, {     26,   13,   13, 16,  3,  0 }, {     27,   13,   14, 16,  3,  0 }, {     28,   13,   15, 16,  3,  0 }, {     29,   12,   15, 16,  3,  0 },
    {     30,   12,   16, 16,  3,  0 }, {     31,   12,   17, 16,  3,  0 }, {     32,   12,   18, 16,  3,  0 }, {     33,   12,   18, 16,  3,  0 }, {     34,   12,   19, 16,  3,  0 },
    {     35,   12,   20, 16,  3,  0 }, {     36,   12,   21, 16,  3,  0 }, {     37,   11,   22, 16,  3,  0 }, {     38,   11,   23, 16,  3,  0 }, {     39,   11,   24, 16,  3,  0 },
    {     40,   11,   25, 16,  3,  0 }, {     41,   11,   26, 16,  3,  0 }, {     42,   11,   27, 16,  4,  0 }, {     43,   11,   28, 16,  4,  0 }, {     44,   11,   29, 16,  4,  0 },
    {     44,   11,   30, 16,  4,  0 }, {     45,   10,   31, 16,  4,  0 }, {     46,   10,   32, 16,  4,  0 }, {     47,   10,   33, 16,  4,  0 }, {     47,   10,   34, 16,  4,  0 },
    {     48,   10,   35, 16,  4,  0 }, {     49,   10,   36, 16,  4,  0 }, {     50,   10,   37, 16,  4,  0 }, {     50,   10,   38, 16,  4,  0 }, {     51,   10,   39, 16,  4,  0 },
    {     51,    9,   40, 16,  4,  0 }, {     52,    9,   41, 16,  4,  0 }, {     53,    9,   42, 16,  4,  0 }, {     53,    9,   43, 16,  9,  0 }, {     54,    9,   44, 16,  9,  0 },
    {     55,    9,   45, 16,  9,  0 }, {     55,    9,   46, 16,  9,  0 }, {     56,    9,   47, 16,  9,  0 }, {     56,    9,   48, 16,  9,  0 }, {     56,    8,   49, 16,  9,  0 },
    {     57,    8,   50, 16,  9,  0 }, {     57,    8,   51, 16,  9,  0 }, {     57,    8,   52, 16,  9,  0 }, {     58,    8,   53, 16,  9,  0 }, {     58,    8,   54, 16,  9,  0 },
    {     58,    8,   55, 16,  9,  0 }, {     59,    8,   56, 16,  9,  0 }, {     59,    8,   57, 16,  9,  0 }, {     59,    8,   58, 16,  9,  0 }, {     60,    7,   59, 16,  9,  0 },
    {     60,    7,   60, 16,  9,  0 }, {     60,    7,   61, 16,  9,  0 }, {     61,    7,   62, 16,  9,  0 }, {     61,    7,   63, 16,  9,  0 }, {     61,    7,   64, 16, 10,  0 },
    {     61,    7,   65, 16, 10,  0 }, {     62,    7,   66, 16, 10,  0 }, {     62,    7,   67, 16, 10,  0 }, {     62,    7,   68, 16, 10,  0 }, {     62,    6,   69, 16, 10,  0 },
    {     62,    6,   70, 16, 10,  0 }, {     63,    6,   71, 16, 10,  0 }, {     63,    6,   72, 16, 10,  0 }, {     63,    6,   73, 16, 10,  0 }, {     63,    6,   74, 16, 10,  0 },
    {     63,    6,   75, 16, 10,  0 }, {     63,    6,   76, 16, 10,  0 }, {     63,    6,   77, 16, 10,  0 }, {     63,    6,   78, 16, 10,  0 }, {     63,    6,   79, 16, 10,  0 },
    {     63,    5,   80, 16, 10,  0 }, {     63,    5,   81, 16, 10,  0 }, {     63,    5,   82, 16, 10,  0 }, {     63,    5,   83, 16, 10,  0 }, {     63,    5,   84, 16, 10,  0 },
    {     63,    5,   85, 16, 10,  0 }, {     63,    5,   86, 16, 10,  0 }, {     63,    5,   87, 16, 10,  0 }, {     63,    5,   88, 16, 10,  0 }, {     63,    5,   89, 16, 10,  0 },
    {     63,    5,   90, 16, 10,  0 }, {     63,    5,   91, 16, 11,  0 }, {     63,    4,   92, 16, 11,  0 }, {     62,    4,   93, 16, 11,  0 }, {     62,    4,   94, 16, 11,  0 },
    {     62,    4,   95, 16, 11,  0 }, {     62,    4,   96, 16, 11,  0 }, {     62,    4,   97, 16, 11,  0 }, {     61,    4,   98, 16, 11,  0 }, {     61,    4,   99, 16, 11,  0 },
    {     61,    4,  100, 16, 11,  0 }, {     61,    4,  101, 16, 11,  0 }, {     60,    3,  102, 16, 11,  0 }, {     60,    3,  103, 16, 11,  0 }, {     60,    3,  104, 16, 11,  0 },
    {     59,    3,  105, 16, 12,  0 }, {     59,    3,  106, 16, 12,  0 }, {     58,    3,  107, 16, 12,  0 }, {     58,    3,  108, 16, 12,  0 }, {     57,    3,  109, 16, 12,  0 },
    {     57,    3,  110, 16, 12,  0 }, {     57,    3,  111, 16, 12,  0 }, {     56,    2,  112, 16, 12,  0 }, {     56,    2,  113, 16, 12,  0 }, {     55,    2,  114, 16, 13,  0 },
    {     55,    2,  115, 16, 13,  0 }, {     54,    2,  116, 16, 13,  0 }, {     53,    2,  117, 16, 13,  0 }, {     53,    2,  118, 16, 13,  0 }, {     52,    2,  119, 16, 13,  0 },
    {     51,    2,  120, 16, 13,  0 }, {     50,    1,  121, 16, 13,  0 }, {     49,    1,  122, 16, 14,  0 }, {     48,    1,  123, 16, 14,  0 }, {     47,    1,  124, 16, 14,  0 },
    {     46,    1,  124, 16, 14,  0 }, {     45,    1,  125, 16, 14,  0 }, {     44,    1,  126, 16, 15,  0 }, {     43,    1,  127, 16, 15,  0 }, {     42,    0,  128, 16, 15,  0 },
    {     41,    0,  128, 16, 15,  0 }, {     40,    0,  129, 16, 15,  0 }, {     39,    0,  129, 16, 16,  0 }, {     38,    0,  129, 16, 16,  0 }, {     37,    0,  130, 16, 16,  0 },
    {     36,    0,  130, 16, 16,  0 }, {     35,    0,  130, 16, 16,  0 }, {     34,    0,  130, 16, 16,  0 }, {     33,    0,  130, 16, 16,  0 }, {     32,    0,  130, 16, 16,  0 },
    {     31,    0,  130, 16, 16,  0 }, {     30,    0,  130, 16, 16,  0 }, {     29,    0,  130, 16, 16,  0 }, {     28,    0,  130, 16, 16,  0 }, {     27,    0,  130, 16, 23,  0 },
    {     26,    0,  130, 16, 23,  0 }, {     25,    0,  129, 16, 23,  0 }, {     24,    0,  129, 16, 23,  0 }, {     23,    0,  129, 16, 23,  0 }, {     22,    0,  128, 16, 22,  0 },
    {     21,    0,  128, 16, 22,  0 }, {     20,   -1,  127, 16, 22,  0 }, {     19,   -1,  126, 16, 22,  0 }, {     18,   -1,  125, 16, 22,  0 }, {     17,   -1,  124, 16, 21,  0 },
    {     16,   -1,  124, 16, 21,  0 }, {     15,   -1,  123, 16, 21,  0 }, {     14,   -1,  122, 16, 21,  0 }, {     13,   -1,  121, 16, 21,  0 }, {     12,   -2,  120, 16, 21,  0 },
    {     11,   -2,  119, 16, 21,  0 }, {     10,   -2,  118, 16, 21,  0 }, {     10,   -2,  117, 16, 20,  0 }, {      9,   -2,  116, 16, 20,  0 }, {      8,   -2,  115, 16, 20,  0 },
    {      8,   -2,  114, 16, 20,  0 }, {      7,   -2,  113, 16, 20,  0 }, {      7,   -2,  112, 16, 20,  0 }, {      6,   -3,  111, 16, 20,  0 }, {      6,   -3,  110, 16, 20,  0 },
    {      6,   -3,  109, 16, 20,  0 }, {      5,   -3,  108, 16, 19,  0 }, {      5,   -3,  107, 16, 19,  0 }, {      4,   -3,  106, 16, 19,  0 }, {      4,   -3,  105, 16, 19,  0 },
    {      3,   -3,  104, 16, 19,  0 }, {      3,   -3,  103, 16, 19,  0 }, {      3,   -3,  102, 16, 19,  0 }, {      2,   -4,  101, 16, 19,  0 }, {      2,   -4,  100, 16, 19,  0 },
    {      2,   -4,   99, 16, 19,  0 }, {      2,   -4,   98, 16, 19,  0 }, {      1,   -4,   97, 16, 19,  0 }, {      1,   -4,   96, 16, 19,  0 }, {      1,   -4,   95, 16, 19,  0 },
    {      1,   -4,   94, 16, 18,  0 }, {      1,   -4,   93, 16, 18,  0 }, {      0,   -4,   92, 16, 18,  0 }, {      0,   -5,   91, 16, 18,  0 }, {      0,   -5,   90, 16, 18,  0 },
    {      0,   -5,   89, 16, 18,  0 }, {      0,   -5,   88, 16, 18,  0 }, {      0,   -5,   87, 16, 18,  0 }, {      0,   -5,   86, 16, 18,  0 }, {      0,   -5,   85, 16, 18,  0 },
    {      0,   -5,   84, 16, 18,  0 }, {      0,   -5,   83, 16, 18,  0 }, {      0,   -5,   82, 16, 18,  0 }, {      0,   -5,   81, 16, 18,  0 }, {      0,   -5,   80, 16, 18,  0 },
    {      0,   -6,   79, 16, 18,  0 }, {      0,   -6,   78, 16, 18,  0 }, {      0,   -6,   77, 16, 18,  0 }, {      0,   -6,   76, 16, 18,  0 }, {      0,   -6,   75, 16, 18,  0 },
    {      0,   -6,   74, 16, 18,  0 }, {      0,   -6,   73, 16, 18,  0 }, {      0,   -6,   72, 16, 18,  0 }, {      0,   -6,   71, 16, 18,  0 }, {      1,   -6,   70, 16, 18,  0 },
    {      1,   -6,   69, 16, 18,  0 }, {      1,   -7,   68, 16, 18,  0 }, {      1,   -7,   67, 16, 17,  0 }, {      1,   -7,   66, 16, 17,  0 }, {      2,   -7,   65, 16, 17,  0 },
    {      2,   -7,   64, 16, 17,  0 }, {      2,   -7,   63, 16, 17,  0 }, {      2,   -7,   62, 16, 17,  0 }, {      3,   -7,   61, 16, 17,  0 }, {      3,   -7,   60, 16, 17,  0 },
    {      3,   -7,   59, 16, 17,  0 }, {      4,   -8,   58, 16, 17,  0 }, {      4,   -8,   57, 16, 17,  0 }, {      4,   -8,   56, 16, 17,  0 }, {      5,   -8,   55, 16, 17,  0 },
    {      5,   -8,   54, 16, 17,  0 }, {      5,   -8,   53, 16, 17,  0 }, {      6,   -8,   52, 16, 17,  0 }, {      6,   -8,   51, 16, 17,  0 }, {      6,   -8,   50, 16, 17,  0 },
    {      7,   -8,   49, 16, 17,  0 }, {      7,   -9,   48, 16, 17,  0 }, {      7,   -9,   47, 16, 17,  0 }, {      8,   -9,   46, 16,  8,  0 }, {      8,   -9,   45, 16,  8,  0 },
    {      9,   -9,   44, 16,  8,  0 }, {     10,   -9,   43, 16,  8,  0 }, {     10,   -9,   42, 16,  8,  0 }, {     11,   -9,   41, 16,  8,  0 }, {     12,   -9,   40, 16,  8,  0 },
    {     12,   -9,   39, 16,  8,  0 }, {     13,  -10,   38, 16,  8,  0 }, {     13,  -10,   37, 16,  8,  0 }, {     14,  -10,   36, 16,  8,  0 }, {     15,  -10,   35, 16,  8,  0 },
    {     16,  -10,   34, 16,  8,  0 }, {     16,  -10,   33, 16,  8,  0 }, {     17,  -10,   32, 16,  8,  0 }, {     18,  -10,   31, 16,  8,  0 }, {     19,  -11,   30, 16,  7,  0 },
    {     19,  -11,   29, 16,  7,  0 }, {     20,  -11,   28, 16,  7,  0 }, {     21,  -11,   27, 16,  7,  0 }, {     22,  -11,   26, 16,  7,  0 }, {     23,  -11,   25, 16,  7,  0 },
    {     24,  -11,   24, 16,  7,  0 }, {     25,  -11,   23, 16,  7,  0 }, {     26,  -11,   22, 16,  7,  0 }, {     27,  -12,   21, 16,  7,  0 }, {     28,  -12,   20, 16,  7,  0 },
    {     29,  -12,   19, 16,  7,  0 }, {     30,  -12,   18, 16,  7,  0 }, {     31,  -12,   18, 16,  7,  0 }, {     32,  -12,   17, 16,  7,  0 }, {     33,  -12,   16, 16,  7,  0 },
    {     34,  -12,   15, 16,  7,  0 }, {     35,  -13,   15, 16,  7,  0 }, {     36,  -13,   14, 16,  7,  0 }, {     37,  -13,   13, 16,  7,  0 }, {     38,  -13,   12, 16,  7,  0 },
    {     39,  -13,   11, 16,  7,  0 }, {     40,  -13,   11, 16,  7,  0 }, {     41,  -13,   10, 16,  6,  0 }, {     42,  -13,   10, 16,  6,  0 }, {     43,  -13,    9, 16,  6,  0 },
    {     44,  -14,    9, 16,  6,  0 }, {     45,  -14,    8, 16,  6,  0 }, {     46,  -14,    8, 16,  6,  0 }, {     47,  -14,    7, 16,  6,  0 }, {     48,  -14,    7, 16,  6,  0 },
    {     49,  -14,    6, 16,  6,  0 }, {     50,  -14,    6, 16,  6,  0 }, {     51,  -14,    5, 16,  6,  0 }, {     52,  -14,    5, 16,  6,  0 }, {     53,  -14,    4, 16,  6,  0 },
    {     54,  -15,    4, 16,  6,  0 }, {     55,  -15,    3, 16,  6,  0 }, {     56,  -15,    3, 16,  6,  0 }, {     57,  -15,    3, 16,  6,  0 }, {     58,  -15,    2, 16,  6,  0 },
    {     59,  -15,    2, 16,  6,  0 }, {     60,  -15,    1, 16,  6,  0 }, {     61,  -15,    1, 16,  6,  0 }, {     62,  -15,    0, 16,  6,  0 }, {     63,  -16,    0, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D9116, {
    {     16,   31,    0, 24,  2,  0 }, {     15,   30,    0, 24,  2,  0 }, {     15,   29,    1, 24,  2,  0 }, {     15,   28,    1, 24,  2,  0 }, {     15,   27,    2, 24,  2,  0 },
    {     15,   26,    2, 24,  2,  0 }, {     15,   25,    3, 24,  2,  0 }, {     15,   24,    3, 24,  2,  0 }, {     15,   23,    3, 24,  2,  0 }, {     15,   22,    4, 24,  2,  0 },
    {     14,   21,    4, 24,  2,  0 }, {     14,   20,    5, 24,  2,  0 }, {     14,   19,    5, 24,  2,  0 }, {     14,   18,    6, 24,  2,  0 }, {     14,   17,    6, 24,  2,  0 },
    {     14,   16,    7, 24,  2,  0 }, {     14,   15,    7, 24,  2,  0 }, {     14,   14,    8, 24,  2,  0 }, {     14,   13,    8, 24,  2,  0 }, {     14,   12,    9, 24,  3,  0 },
    {     13,   11,    9, 24,  3,  0 }, {     13,   10,   10, 24,  3,  0 }, {     13,    9,   10, 24,  3,  0 }, {     13,    8,   11, 24,  3,  0 }, {     13,    7,   11, 24,  3,  0 },
    {     13,    6,   12, 24,  3,  0 }, {     13,    5,   13, 24,  3,  0 }, {     13,    4,   14, 24,  3,  0 }, {     13,    3,   15, 24,  3,  0 }, {     12,    2,   15, 24,  3,  0 },
    {     12,    1,   16, 24,  3,  0 }, {     12,    0,   17, 24,  3,  0 }, {     12,   -1,   18, 24,  3,  0 }, {     12,   -2,   18, 24,  3,  0 }, {     12,   -3,   19, 24,  3,  0 },
    {     12,   -4,   20, 24,  3,  0 }, {     12,   -5,   21, 24,  3,  0 }, {     11,   -6,   22, 24,  3,  0 }, {     11,   -7,   23, 24,  3,  0 }, {     11,   -8,   24, 24,  3,  0 },
    {     11,   -9,   25, 24,  3,  0 }, {     11,  -10,   26, 24,  3,  0 }, {     11,  -11,   27, 24,  4,  0 }, {     11,  -12,   28, 24,  4,  0 }, {     11,  -13,   29, 24,  4,  0 },
    {     11,  -13,   30, 24,  4,  0 }, {     10,  -14,   31, 24,  4,  0 }, {     10,  -15,   32, 24,  4,  0 }, {     10,  -16,   33, 24,  4,  0 }, {     10,  -16,   34, 24,  4,  0 },
    {     10,  -17,   35, 24,  4,  0 }, {     10,  -18,   36, 24,  4,  0 }, {     10,  -19,   37, 24,  4,  0 }, {     10,  -19,   38, 24,  4,  0 }, {     10,  -20,   39, 24,  4,  0 },
    {      9,  -20,   40, 24,  4,  0 }, {      9,  -21,   41, 24,  4,  0 }, {      9,  -22,   42, 24,  4,  0 }, {      9,  -22,   43, 24,  9,  0 }, {      9,  -23,   44, 24,  9,  0 },
    {      9,  -24,   45, 24,  9,  0 }, {      9,  -24,   46, 24,  9,  0 }, {      9,  -25,   47, 24,  9,  0 }, {      9,  -25,   48, 24,  9,  0 }, {      8,  -25,   49, 24,  9,  0 },
    {      8,  -26,   50, 24,  9,  0 }, {      8,  -26,   51, 24,  9,  0 }, {      8,  -26,   52, 24,  9,  0 }, {      8,  -27,   53, 24,  9,  0 }, {      8,  -27,   54, 24,  9,  0 },
    {      8,  -27,   55, 24,  9,  0 }, {      8,  -28,   56, 24,  9,  0 }, {      8,  -28,   57, 24,  9,  0 }, {      8,  -28,   58, 24,  9,  0 }, {      7,  -29,   59, 24,  9,  0 },
    {      7,  -29,   60, 24,  9,  0 }, {      7,  -29,   61, 24,  9,  0 }, {      7,  -30,   62, 24,  9,  0 }, {      7,  -30,   63, 24,  9,  0 }, {      7,  -30,   64, 24, 10,  0 },
    {      7,  -30,   65, 24, 10,  0 }, {      7,  -31,   66, 24, 10,  0 }, {      7,  -31,   67, 24, 10,  0 }, {      7,  -31,   68, 24, 10,  0 }, {      6,  -31,   69, 24, 10,  0 },
    {      6,  -31,   70, 24, 10,  0 }, {      6,  -32,   71, 24, 10,  0 }, {      6,  -32,   72, 24, 10,  0 }, {      6,  -32,   73, 24, 10,  0 }, {      6,  -32,   74, 24, 10,  0 },
    {      6,  -32,   75, 24, 10,  0 }, {      6,  -32,   76, 24, 10,  0 }, {      6,  -32,   77, 24, 10,  0 }, {      6,  -32,   78, 24, 10,  0 }, {      6,  -32,   79, 24, 10,  0 },
    {      5,  -32,   80, 24, 10,  0 }, {      5,  -32,   81, 24, 10,  0 }, {      5,  -32,   82, 24, 10,  0 }, {      5,  -32,   83, 24, 10,  0 }, {      5,  -32,   84, 24, 10,  0 },
    {      5,  -32,   85, 24, 10,  0 }, {      5,  -32,   86, 24, 10,  0 }, {      5,  -32,   87, 24, 10,  0 }, {      5,  -32,   88, 24, 10,  0 }, {      5,  -32,   89, 24, 10,  0 },
    {      5,  -32,   90, 24, 10,  0 }, {      5,  -32,   91, 24, 11,  0 }, {      4,  -32,   92, 24, 11,  0 }, {      4,  -31,   93, 24, 11,  0 }, {      4,  -31,   94, 24, 11,  0 },
    {      4,  -31,   95, 24, 11,  0 }, {      4,  -31,   96, 24, 11,  0 }, {      4,  -31,   97, 24, 11,  0 }, {      4,  -30,   98, 24, 11,  0 }, {      4,  -30,   99, 24, 11,  0 },
    {      4,  -30,  100, 24, 11,  0 }, {      4,  -30,  101, 24, 11,  0 }, {      3,  -29,  102, 24, 11,  0 }, {      3,  -29,  103, 24, 11,  0 }, {      3,  -29,  104, 24, 11,  0 },
    {      3,  -28,  105, 24, 12,  0 }, {      3,  -28,  106, 24, 12,  0 }, {      3,  -27,  107, 24, 12,  0 }, {      3,  -27,  108, 24, 12,  0 }, {      3,  -26,  109, 24, 12,  0 },
    {      3,  -26,  110, 24, 12,  0 }, {      3,  -26,  111, 24, 12,  0 }, {      2,  -25,  112, 24, 12,  0 }, {      2,  -25,  113, 24, 12,  0 }, {      2,  -24,  114, 24, 13,  0 },
    {      2,  -24,  115, 24, 13,  0 }, {      2,  -23,  116, 24, 13,  0 }, {      2,  -22,  117, 24, 13,  0 }, {      2,  -22,  118, 24, 13,  0 }, {      2,  -21,  119, 24, 13,  0 },
    {      2,  -20,  120, 24, 13,  0 }, {      1,  -19,  121, 24, 13,  0 }, {      1,  -18,  122, 24, 14,  0 }, {      1,  -17,  123, 24, 14,  0 }, {      1,  -16,  124, 24, 14,  0 },
    {      1,  -15,  124, 24, 14,  0 }, {      1,  -14,  125, 24, 14,  0 }, {      1,  -13,  126, 24, 15,  0 }, {      1,  -12,  127, 24, 15,  0 }, {      0,  -11,  128, 24, 15,  0 },
    {      0,  -10,  128, 24, 15,  0 }, {      0,   -9,  129, 24, 15,  0 }, {      0,   -8,  129, 24, 16,  0 }, {      0,   -7,  129, 24, 16,  0 }, {      0,   -6,  130, 24, 16,  0 },
    {      0,   -5,  130, 24, 16,  0 }, {      0,   -4,  130, 24, 16,  0 }, {      0,   -3,  130, 24, 16,  0 }, {      0,   -2,  130, 24, 16,  0 }, {      0,   -1,  130, 24, 16,  0 },
    {      0,    0,  130, 24, 16,  0 }, {      0,    1,  130, 24, 16,  0 }, {      0,    2,  130, 24, 16,  0 }, {      0,    3,  130, 24, 16,  0 }, {      0,    4,  130, 24, 23,  0 },
    {      0,    5,  130, 24, 23,  0 }, {      0,    6,  129, 24, 23,  0 }, {      0,    7,  129, 24, 23,  0 }, {      0,    8,  129, 24, 23,  0 }, {      0,    9,  128, 24, 22,  0 },
    {      0,   10,  128, 24, 22,  0 }, {     -1,   11,  127, 24, 22,  0 }, {     -1,   12,  126, 24, 22,  0 }, {     -1,   13,  125, 24, 22,  0 }, {     -1,   14,  124, 24, 21,  0 },
    {     -1,   15,  124, 24, 21,  0 }, {     -1,   16,  123, 24, 21,  0 }, {     -1,   17,  122, 24, 21,  0 }, {     -1,   18,  121, 24, 21,  0 }, {     -2,   19,  120, 24, 21,  0 },
    {     -2,   20,  119, 24, 21,  0 }, {     -2,   21,  118, 24, 21,  0 }, {     -2,   21,  117, 24, 20,  0 }, {     -2,   22,  116, 24, 20,  0 }, {     -2,   23,  115, 24, 20,  0 },
    {     -2,   23,  114, 24, 20,  0 }, {     -2,   24,  113, 24, 20,  0 }, {     -2,   24,  112, 24, 20,  0 }, {     -3,   25,  111, 24, 20,  0 }, {     -3,   25,  110, 24, 20,  0 },
    {     -3,   25,  109, 24, 20,  0 }, {     -3,   26,  108, 24, 19,  0 }, {     -3,   26,  107, 24, 19,  0 }, {     -3,   27,  106, 24, 19,  0 }, {     -3,   27,  105, 24, 19,  0 },
    {     -3,   28,  104, 24, 19,  0 }, {     -3,   28,  103, 24, 19,  0 }, {     -3,   28,  102, 24, 19,  0 }, {     -4,   29,  101, 24, 19,  0 }, {     -4,   29,  100, 24, 19,  0 },
    {     -4,   29,   99, 24, 19,  0 }, {     -4,   29,   98, 24, 19,  0 }, {     -4,   30,   97, 24, 19,  0 }, {     -4,   30,   96, 24, 19,  0 }, {     -4,   30,   95, 24, 19,  0 },
    {     -4,   30,   94, 24, 18,  0 }, {     -4,   30,   93, 24, 18,  0 }, {     -4,   31,   92, 24, 18,  0 }, {     -5,   31,   91, 24, 18,  0 }, {     -5,   31,   90, 24, 18,  0 },
    {     -5,   31,   89, 24, 18,  0 }, {     -5,   31,   88, 24, 18,  0 }, {     -5,   31,   87, 24, 18,  0 }, {     -5,   31,   86, 24, 18,  0 }, {     -5,   31,   85, 24, 18,  0 },
    {     -5,   31,   84, 24, 18,  0 }, {     -5,   31,   83, 24, 18,  0 }, {     -5,   31,   82, 24, 18,  0 }, {     -5,   31,   81, 24, 18,  0 }, {     -5,   31,   80, 24, 18,  0 },
    {     -6,   31,   79, 24, 18,  0 }, {     -6,   31,   78, 24, 18,  0 }, {     -6,   31,   77, 24, 18,  0 }, {     -6,   31,   76, 24, 18,  0 }, {     -6,   31,   75, 24, 18,  0 },
    {     -6,   31,   74, 24, 18,  0 }, {     -6,   31,   73, 24, 18,  0 }, {     -6,   31,   72, 24, 18,  0 }, {     -6,   31,   71, 24, 18,  0 }, {     -6,   30,   70, 24, 18,  0 },
    {     -6,   30,   69, 24, 18,  0 }, {     -7,   30,   68, 24, 18,  0 }, {     -7,   30,   67, 24, 17,  0 }, {     -7,   30,   66, 24, 17,  0 }, {     -7,   29,   65, 24, 17,  0 },
    {     -7,   29,   64, 24, 17,  0 }, {     -7,   29,   63, 24, 17,  0 }, {     -7,   29,   62, 24, 17,  0 }, {     -7,   28,   61, 24, 17,  0 }, {     -7,   28,   60, 24, 17,  0 },
    {     -7,   28,   59, 24, 17,  0 }, {     -8,   27,   58, 24, 17,  0 }, {     -8,   27,   57, 24, 17,  0 }, {     -8,   27,   56, 24, 17,  0 }, {     -8,   26,   55, 24, 17,  0 },
    {     -8,   26,   54, 24, 17,  0 }, {     -8,   26,   53, 24, 17,  0 }, {     -8,   25,   52, 24, 17,  0 }, {     -8,   25,   51, 24, 17,  0 }, {     -8,   25,   50, 24, 17,  0 },
    {     -8,   24,   49, 24, 17,  0 }, {     -9,   24,   48, 24, 17,  0 }, {     -9,   24,   47, 24, 17,  0 }, {     -9,   23,   46, 24,  8,  0 }, {     -9,   23,   45, 24,  8,  0 },
    {     -9,   22,   44, 24,  8,  0 }, {     -9,   21,   43, 24,  8,  0 }, {     -9,   21,   42, 24,  8,  0 }, {     -9,   20,   41, 24,  8,  0 }, {     -9,   19,   40, 24,  8,  0 },
    {     -9,   19,   39, 24,  8,  0 }, {    -10,   18,   38, 24,  8,  0 }, {    -10,   18,   37, 24,  8,  0 }, {    -10,   17,   36, 24,  8,  0 }, {    -10,   16,   35, 24,  8,  0 },
    {    -10,   15,   34, 24,  8,  0 }, {    -10,   15,   33, 24,  8,  0 }, {    -10,   14,   32, 24,  8,  0 }, {    -10,   13,   31, 24,  8,  0 }, {    -11,   12,   30, 24,  7,  0 },
    {    -11,   12,   29, 24,  7,  0 }, {    -11,   11,   28, 24,  7,  0 }, {    -11,   10,   27, 24,  7,  0 }, {    -11,    9,   26, 24,  7,  0 }, {    -11,    8,   25, 24,  7,  0 },
    {    -11,    7,   24, 24,  7,  0 }, {    -11,    6,   23, 24,  7,  0 }, {    -11,    5,   22, 24,  7,  0 }, {    -12,    4,   21, 24,  7,  0 }, {    -12,    3,   20, 24,  7,  0 },
    {    -12,    2,   19, 24,  7,  0 }, {    -12,    1,   18, 24,  7,  0 }, {    -12,    0,   18, 24,  7,  0 }, {    -12,   -1,   17, 24,  7,  0 }, {    -12,   -2,   16, 24,  7,  0 },
    {    -12,   -3,   15, 24,  7,  0 }, {    -13,   -4,   15, 24,  7,  0 }, {    -13,   -5,   14, 24,  7,  0 }, {    -13,   -6,   13, 24,  7,  0 }, {    -13,   -7,   12, 24,  7,  0 },
    {    -13,   -8,   11, 24,  7,  0 }, {    -13,   -9,   11, 24,  7,  0 }, {    -13,  -10,   10, 24,  6,  0 }, {    -13,  -11,   10, 24,  6,  0 }, {    -13,  -12,    9, 24,  6,  0 },
    {    -14,  -13,    9, 24,  6,  0 }, {    -14,  -14,    8, 24,  6,  0 }, {    -14,  -15,    8, 24,  6,  0 }, {    -14,  -16,    7, 24,  6,  0 }, {    -14,  -17,    7, 24,  6,  0 },
    {    -14,  -18,    6, 24,  6,  0 }, {    -14,  -19,    6, 24,  6,  0 }, {    -14,  -20,    5, 24,  6,  0 }, {    -14,  -21,    5, 24,  6,  0 }, {    -14,  -22,    4, 24,  6,  0 },
    {    -15,  -23,    4, 24,  6,  0 }, {    -15,  -24,    3, 24,  6,  0 }, {    -15,  -25,    3, 24,  6,  0 }, {    -15,  -26,    3, 24,  6,  0 }, {    -15,  -27,    2, 24,  6,  0 },
    {    -15,  -28,    2, 24,  6,  0 }, {    -15,  -29,    1, 24,  6,  0 }, {    -15,  -30,    1, 24,  6,  0 }, {    -15,  -31,    0, 24,  6,  0 }, {    -16,  -32,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DED2E, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0, 31,  0,  0 },
    {     26,   16,    0, 31,  0,  0 }, {     25,   15,    0, 31,  0,  0 }, {     24,   15,    0, 31,  0,  0 }, {     23,   15,    0, 31,  0,  0 }, {     22,   15,    0, 31,  0,  0 },
    {     21,   15,    0, 31,  0,  0 }, {     20,   15,    0, 31,  0,  0 }, {     19,   14,    0, 31,  0,  0 }, {     18,   14,    0, 30,  0,  0 }, {     17,   14,    0, 30,  0,  0 },
    {     16,   13,    0, 30,  0,  0 }, {     15,   13,    0, 30,  0,  0 }, {     14,   13,    0, 30,  0,  0 }, {     13,   12,    0, 30,  0,  0 }, {     12,   12,    0, 30,  0,  0 },
    {     11,   11,    0, 30,  0,  0 }, {     10,   11,    0, 30,  0,  0 }, {      9,   10,    0, 30,  0,  0 }, {      8,   10,    0, 29,  0,  0 }, {      7,    9,    0, 29,  0,  0 },
    {      6,    9,    0, 29,  0,  0 }, {      5,    8,    0, 29,  0,  0 }, {      4,    7,    0, 29,  0,  0 }, {      3,    7,    0, 29,  0,  0 }, {      2,    6,    0, 29,  0,  0 },
    {      1,    5,    0, 29,  0,  0 }, {      0,    4,    0, 29,  0,  0 }, {     -1,    3,    0, 28,  0,  0 }, {     -3,    3,    0, 28,  0,  0 }, {     -4,    2,    0, 28,  0,  0 },
    {     -5,    1,    0, 28,  0,  0 }, {     -6,    0,    0, 28,  0,  0 }, {     -7,   -1,    0, 27,  0,  0 }, {     -7,   -2,    0, 27,  0,  0 }, {     -8,   -3,    0, 27,  0,  0 },
    {     -9,   -4,    0, 27,  0,  0 }, {     -9,   -5,    0, 27,  0,  0 }, {    -10,   -6,    0, 27,  0,  0 }, {    -10,   -7,    0, 27,  0,  0 }, {    -11,   -8,    0, 27,  0,  0 },
    {    -11,   -9,    0, 27,  0,  0 }, {    -12,  -10,    0, 26,  0,  0 }, {    -12,  -11,    0, 26,  0,  0 }, {    -13,  -12,    0, 26,  0,  0 }, {    -13,  -13,    0, 26,  0,  0 },
    {    -13,  -14,    0, 26,  0,  0 }, {    -14,  -15,    0, 26,  0,  0 }, {    -14,  -16,    0, 26,  0,  0 }, {    -14,  -17,    0, 26,  0,  0 }, {    -15,  -18,    0, 26,  0,  0 },
    {    -15,  -19,    0, 26,  0,  0 }, {    -15,  -20,    0, 25,  0,  0 }, {    -15,  -21,    0, 25,  0,  0 }, {    -15,  -22,    0, 25,  0,  0 }, {    -15,  -23,    0, 25,  0,  0 },
    {    -16,  -24,    0, 25,  0,  0 }, {    -16,  -25,    0, 25,  0,  0 }, {    -16,  -26,    0, 25,  0,  0 }, {    -16,  -27,    0, 25,  0,  0 }, {    -16,  -28,    0, 24,  0,  0 },
    {    -16,  -29,    0, 24,  0,  0 }, {    -16,  -30,    0, 24,  0,  0 }, {    -16,  -31,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DEF94, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  7,  0,  0 }, {     16,    6,    0,  7,  0,  0 }, {     15,    7,    0,  7,  0,  0 }, {     15,    8,    0,  7,  0,  0 }, {     15,    9,    0,  7,  0,  0 },
    {     15,   10,    0,  7,  0,  0 }, {     15,   11,    0,  7,  0,  0 }, {     15,   12,    0,  7,  0,  0 }, {     14,   13,    0,  7,  0,  0 }, {     14,   14,    0,  6,  0,  0 },
    {     14,   15,    0,  6,  0,  0 }, {     13,   16,    0,  6,  0,  0 }, {     13,   17,    0,  6,  0,  0 }, {     13,   18,    0,  6,  0,  0 }, {     12,   19,    0,  6,  0,  0 },
    {     12,   20,    0,  6,  0,  0 }, {     11,   21,    0,  6,  0,  0 }, {     11,   22,    0,  6,  0,  0 }, {     10,   23,    0,  6,  0,  0 }, {     10,   24,    0,  5,  0,  0 },
    {      9,   25,    0,  5,  0,  0 }, {      9,   26,    0,  5,  0,  0 }, {      8,   27,    0,  5,  0,  0 }, {      7,   28,    0,  5,  0,  0 }, {      7,   29,    0,  5,  0,  0 },
    {      6,   30,    0,  5,  0,  0 }, {      5,   31,    0,  5,  0,  0 }, {      4,   32,    0,  5,  0,  0 }, {      3,   33,    0,  4,  0,  0 }, {      3,   35,    0,  4,  0,  0 },
    {      2,   36,    0,  4,  0,  0 }, {      1,   37,    0,  4,  0,  0 }, {      0,   38,    0,  4,  0,  0 }, {     -1,   39,    0,  3,  0,  0 }, {     -2,   39,    0,  3,  0,  0 },
    {     -3,   40,    0,  3,  0,  0 }, {     -4,   41,    0,  3,  0,  0 }, {     -5,   41,    0,  3,  0,  0 }, {     -6,   42,    0,  3,  0,  0 }, {     -7,   42,    0,  3,  0,  0 },
    {     -8,   43,    0,  3,  0,  0 }, {     -9,   43,    0,  3,  0,  0 }, {    -10,   44,    0,  2,  0,  0 }, {    -11,   44,    0,  2,  0,  0 }, {    -12,   45,    0,  2,  0,  0 },
    {    -13,   45,    0,  2,  0,  0 }, {    -14,   45,    0,  2,  0,  0 }, {    -15,   46,    0,  2,  0,  0 }, {    -16,   46,    0,  2,  0,  0 }, {    -17,   46,    0,  2,  0,  0 },
    {    -18,   47,    0,  2,  0,  0 }, {    -19,   47,    0,  2,  0,  0 }, {    -20,   47,    0,  1,  0,  0 }, {    -21,   47,    0,  1,  0,  0 }, {    -22,   47,    0,  1,  0,  0 },
    {    -23,   47,    0,  1,  0,  0 }, {    -24,   48,    0,  1,  0,  0 }, {    -25,   48,    0,  1,  0,  0 }, {    -26,   48,    0,  1,  0,  0 }, {    -27,   48,    0,  1,  0,  0 },
    {    -28,   48,    0,  0,  0,  0 }, {    -29,   48,    0,  0,  0,  0 }, {    -30,   48,    0,  0,  0,  0 }, {    -31,   48,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DF203, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 15,  0,  0 }, {      6,   16,    0, 15,  0,  0 }, {      7,   17,    0, 15,  0,  0 }, {      8,   17,    0, 15,  0,  0 }, {      9,   17,    0, 15,  0,  0 },
    {     10,   17,    0, 15,  0,  0 }, {     11,   17,    0, 15,  0,  0 }, {     12,   17,    0, 15,  0,  0 }, {     13,   18,    0, 15,  0,  0 }, {     14,   18,    0, 14,  0,  0 },
    {     15,   18,    0, 14,  0,  0 }, {     16,   19,    0, 14,  0,  0 }, {     17,   19,    0, 14,  0,  0 }, {     18,   19,    0, 14,  0,  0 }, {     19,   20,    0, 14,  0,  0 },
    {     20,   20,    0, 14,  0,  0 }, {     21,   21,    0, 14,  0,  0 }, {     22,   21,    0, 14,  0,  0 }, {     23,   22,    0, 14,  0,  0 }, {     24,   22,    0, 13,  0,  0 },
    {     25,   23,    0, 13,  0,  0 }, {     26,   23,    0, 13,  0,  0 }, {     27,   24,    0, 13,  0,  0 }, {     28,   25,    0, 13,  0,  0 }, {     29,   25,    0, 13,  0,  0 },
    {     30,   26,    0, 13,  0,  0 }, {     31,   27,    0, 13,  0,  0 }, {     32,   28,    0, 13,  0,  0 }, {     33,   29,    0, 12,  0,  0 }, {     35,   29,    0, 12,  0,  0 },
    {     36,   30,    0, 12,  0,  0 }, {     37,   31,    0, 12,  0,  0 }, {     38,   32,    0, 12,  0,  0 }, {     39,   33,    0, 11,  0,  0 }, {     39,   34,    0, 11,  0,  0 },
    {     40,   35,    0, 11,  0,  0 }, {     41,   36,    0, 11,  0,  0 }, {     41,   37,    0, 11,  0,  0 }, {     42,   38,    0, 11,  0,  0 }, {     42,   39,    0, 11,  0,  0 },
    {     43,   40,    0, 11,  0,  0 }, {     43,   41,    0, 11,  0,  0 }, {     44,   42,    0, 10,  0,  0 }, {     44,   43,    0, 10,  0,  0 }, {     45,   44,    0, 10,  0,  0 },
    {     45,   45,    0, 10,  0,  0 }, {     45,   46,    0, 10,  0,  0 }, {     46,   47,    0, 10,  0,  0 }, {     46,   48,    0, 10,  0,  0 }, {     46,   49,    0, 10,  0,  0 },
    {     47,   50,    0, 10,  0,  0 }, {     47,   51,    0, 10,  0,  0 }, {     47,   52,    0,  9,  0,  0 }, {     47,   53,    0,  9,  0,  0 }, {     47,   54,    0,  9,  0,  0 },
    {     47,   55,    0,  9,  0,  0 }, {     48,   56,    0,  9,  0,  0 }, {     48,   57,    0,  9,  0,  0 }, {     48,   58,    0,  9,  0,  0 }, {     48,   59,    0,  9,  0,  0 },
    {     48,   60,    0,  8,  0,  0 }, {     48,   61,    0,  8,  0,  0 }, {     48,   62,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DF469, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 23,  0,  0 },
    {     16,   26,    0, 23,  0,  0 }, {     17,   25,    0, 23,  0,  0 }, {     17,   24,    0, 23,  0,  0 }, {     17,   23,    0, 23,  0,  0 }, {     17,   22,    0, 23,  0,  0 },
    {     17,   21,    0, 23,  0,  0 }, {     17,   20,    0, 23,  0,  0 }, {     18,   19,    0, 23,  0,  0 }, {     18,   18,    0, 22,  0,  0 }, {     18,   17,    0, 22,  0,  0 },
    {     19,   16,    0, 22,  0,  0 }, {     19,   15,    0, 22,  0,  0 }, {     19,   14,    0, 22,  0,  0 }, {     20,   13,    0, 22,  0,  0 }, {     20,   12,    0, 22,  0,  0 },
    {     21,   11,    0, 22,  0,  0 }, {     21,   10,    0, 22,  0,  0 }, {     22,    9,    0, 22,  0,  0 }, {     22,    8,    0, 21,  0,  0 }, {     23,    7,    0, 21,  0,  0 },
    {     23,    6,    0, 21,  0,  0 }, {     24,    5,    0, 21,  0,  0 }, {     25,    4,    0, 21,  0,  0 }, {     25,    3,    0, 21,  0,  0 }, {     26,    2,    0, 21,  0,  0 },
    {     27,    1,    0, 21,  0,  0 }, {     28,    0,    0, 21,  0,  0 }, {     29,   -1,    0, 20,  0,  0 }, {     29,   -3,    0, 20,  0,  0 }, {     30,   -4,    0, 20,  0,  0 },
    {     31,   -5,    0, 20,  0,  0 }, {     32,   -6,    0, 20,  0,  0 }, {     33,   -7,    0, 19,  0,  0 }, {     34,   -7,    0, 19,  0,  0 }, {     35,   -8,    0, 19,  0,  0 },
    {     36,   -9,    0, 19,  0,  0 }, {     37,   -9,    0, 19,  0,  0 }, {     38,  -10,    0, 19,  0,  0 }, {     39,  -10,    0, 19,  0,  0 }, {     40,  -11,    0, 19,  0,  0 },
    {     41,  -11,    0, 19,  0,  0 }, {     42,  -12,    0, 18,  0,  0 }, {     43,  -12,    0, 18,  0,  0 }, {     44,  -13,    0, 18,  0,  0 }, {     45,  -13,    0, 18,  0,  0 },
    {     46,  -13,    0, 18,  0,  0 }, {     47,  -14,    0, 18,  0,  0 }, {     48,  -14,    0, 18,  0,  0 }, {     49,  -14,    0, 18,  0,  0 }, {     50,  -15,    0, 18,  0,  0 },
    {     51,  -15,    0, 18,  0,  0 }, {     52,  -15,    0, 17,  0,  0 }, {     53,  -15,    0, 17,  0,  0 }, {     54,  -15,    0, 17,  0,  0 }, {     55,  -15,    0, 17,  0,  0 },
    {     56,  -16,    0, 17,  0,  0 }, {     57,  -16,    0, 17,  0,  0 }, {     58,  -16,    0, 17,  0,  0 }, {     59,  -16,    0, 17,  0,  0 }, {     60,  -16,    0, 16,  0,  0 },
    {     61,  -16,    0, 16,  0,  0 }, {     62,  -16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DF6C6, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  1,  0,  0 },
    {     26,   16,    0,  1,  0,  0 }, {     25,   17,    0,  1,  0,  0 }, {     24,   17,    0,  1,  0,  0 }, {     23,   17,    0,  1,  0,  0 }, {     22,   17,    0,  1,  0,  0 },
    {     21,   17,    0,  1,  0,  0 }, {     20,   17,    0,  1,  0,  0 }, {     19,   18,    0,  1,  0,  0 }, {     18,   18,    0,  2,  0,  0 }, {     17,   18,    0,  2,  0,  0 },
    {     16,   19,    0,  2,  0,  0 }, {     15,   19,    0,  2,  0,  0 }, {     14,   19,    0,  2,  0,  0 }, {     13,   20,    0,  2,  0,  0 }, {     12,   20,    0,  2,  0,  0 },
    {     11,   21,    0,  2,  0,  0 }, {     10,   21,    0,  2,  0,  0 }, {      9,   22,    0,  2,  0,  0 }, {      8,   22,    0,  3,  0,  0 }, {      7,   23,    0,  3,  0,  0 },
    {      6,   23,    0,  3,  0,  0 }, {      5,   24,    0,  3,  0,  0 }, {      4,   25,    0,  3,  0,  0 }, {      3,   25,    0,  3,  0,  0 }, {      2,   26,    0,  3,  0,  0 },
    {      1,   27,    0,  3,  0,  0 }, {      0,   28,    0,  3,  0,  0 }, {     -1,   29,    0,  4,  0,  0 }, {     -3,   29,    0,  4,  0,  0 }, {     -4,   30,    0,  4,  0,  0 },
    {     -5,   31,    0,  4,  0,  0 }, {     -6,   32,    0,  4,  0,  0 }, {     -7,   33,    0,  5,  0,  0 }, {     -7,   34,    0,  5,  0,  0 }, {     -8,   35,    0,  5,  0,  0 },
    {     -9,   36,    0,  5,  0,  0 }, {     -9,   37,    0,  5,  0,  0 }, {    -10,   38,    0,  5,  0,  0 }, {    -10,   39,    0,  5,  0,  0 }, {    -11,   40,    0,  5,  0,  0 },
    {    -11,   41,    0,  5,  0,  0 }, {    -12,   42,    0,  6,  0,  0 }, {    -12,   43,    0,  6,  0,  0 }, {    -13,   44,    0,  6,  0,  0 }, {    -13,   45,    0,  6,  0,  0 },
    {    -13,   46,    0,  6,  0,  0 }, {    -14,   47,    0,  6,  0,  0 }, {    -14,   48,    0,  6,  0,  0 }, {    -14,   49,    0,  6,  0,  0 }, {    -15,   50,    0,  6,  0,  0 },
    {    -15,   51,    0,  6,  0,  0 }, {    -15,   52,    0,  7,  0,  0 }, {    -15,   53,    0,  7,  0,  0 }, {    -15,   54,    0,  7,  0,  0 }, {    -15,   55,    0,  7,  0,  0 },
    {    -16,   56,    0,  7,  0,  0 }, {    -16,   57,    0,  7,  0,  0 }, {    -16,   58,    0,  7,  0,  0 }, {    -16,   59,    0,  7,  0,  0 }, {    -16,   60,    0,  8,  0,  0 },
    {    -16,   61,    0,  8,  0,  0 }, {    -16,   62,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DF923, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  9,  0,  0 }, {     16,    6,    0,  9,  0,  0 }, {     17,    7,    0,  9,  0,  0 }, {     17,    8,    0,  9,  0,  0 }, {     17,    9,    0,  9,  0,  0 },
    {     17,   10,    0,  9,  0,  0 }, {     17,   11,    0,  9,  0,  0 }, {     17,   12,    0,  9,  0,  0 }, {     18,   13,    0,  9,  0,  0 }, {     18,   14,    0, 10,  0,  0 },
    {     18,   15,    0, 10,  0,  0 }, {     19,   16,    0, 10,  0,  0 }, {     19,   17,    0, 10,  0,  0 }, {     19,   18,    0, 10,  0,  0 }, {     20,   19,    0, 10,  0,  0 },
    {     20,   20,    0, 10,  0,  0 }, {     21,   21,    0, 10,  0,  0 }, {     21,   22,    0, 10,  0,  0 }, {     22,   23,    0, 10,  0,  0 }, {     22,   24,    0, 11,  0,  0 },
    {     23,   25,    0, 11,  0,  0 }, {     23,   26,    0, 11,  0,  0 }, {     24,   27,    0, 11,  0,  0 }, {     25,   28,    0, 11,  0,  0 }, {     25,   29,    0, 11,  0,  0 },
    {     26,   30,    0, 11,  0,  0 }, {     27,   31,    0, 11,  0,  0 }, {     28,   32,    0, 11,  0,  0 }, {     29,   33,    0, 12,  0,  0 }, {     29,   35,    0, 12,  0,  0 },
    {     30,   36,    0, 12,  0,  0 }, {     31,   37,    0, 12,  0,  0 }, {     32,   38,    0, 12,  0,  0 }, {     33,   39,    0, 13,  0,  0 }, {     34,   39,    0, 13,  0,  0 },
    {     35,   40,    0, 13,  0,  0 }, {     36,   41,    0, 13,  0,  0 }, {     37,   41,    0, 13,  0,  0 }, {     38,   42,    0, 13,  0,  0 }, {     39,   42,    0, 13,  0,  0 },
    {     40,   43,    0, 13,  0,  0 }, {     41,   43,    0, 13,  0,  0 }, {     42,   44,    0, 14,  0,  0 }, {     43,   44,    0, 14,  0,  0 }, {     44,   45,    0, 14,  0,  0 },
    {     45,   45,    0, 14,  0,  0 }, {     46,   45,    0, 14,  0,  0 }, {     47,   46,    0, 14,  0,  0 }, {     48,   46,    0, 14,  0,  0 }, {     49,   46,    0, 14,  0,  0 },
    {     50,   47,    0, 14,  0,  0 }, {     51,   47,    0, 14,  0,  0 }, {     52,   47,    0, 15,  0,  0 }, {     53,   47,    0, 15,  0,  0 }, {     54,   47,    0, 15,  0,  0 },
    {     55,   47,    0, 15,  0,  0 }, {     56,   48,    0, 15,  0,  0 }, {     57,   48,    0, 15,  0,  0 }, {     58,   48,    0, 15,  0,  0 }, {     59,   48,    0, 15,  0,  0 },
    {     60,   48,    0, 16,  0,  0 }, {     61,   48,    0, 16,  0,  0 }, {     62,   48,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DFB89, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 17,  0,  0 }, {      6,   16,    0, 17,  0,  0 }, {      7,   15,    0, 17,  0,  0 }, {      8,   15,    0, 17,  0,  0 }, {      9,   15,    0, 17,  0,  0 },
    {     10,   15,    0, 17,  0,  0 }, {     11,   15,    0, 17,  0,  0 }, {     12,   15,    0, 17,  0,  0 }, {     13,   14,    0, 17,  0,  0 }, {     14,   14,    0, 18,  0,  0 },
    {     15,   14,    0, 18,  0,  0 }, {     16,   13,    0, 18,  0,  0 }, {     17,   13,    0, 18,  0,  0 }, {     18,   13,    0, 18,  0,  0 }, {     19,   12,    0, 18,  0,  0 },
    {     20,   12,    0, 18,  0,  0 }, {     21,   11,    0, 18,  0,  0 }, {     22,   11,    0, 18,  0,  0 }, {     23,   10,    0, 18,  0,  0 }, {     24,   10,    0, 19,  0,  0 },
    {     25,    9,    0, 19,  0,  0 }, {     26,    9,    0, 19,  0,  0 }, {     27,    8,    0, 19,  0,  0 }, {     28,    7,    0, 19,  0,  0 }, {     29,    7,    0, 19,  0,  0 },
    {     30,    6,    0, 19,  0,  0 }, {     31,    5,    0, 19,  0,  0 }, {     32,    4,    0, 19,  0,  0 }, {     33,    3,    0, 20,  0,  0 }, {     35,    3,    0, 20,  0,  0 },
    {     36,    2,    0, 20,  0,  0 }, {     37,    1,    0, 20,  0,  0 }, {     38,    0,    0, 20,  0,  0 }, {     39,   -1,    0, 21,  0,  0 }, {     39,   -2,    0, 21,  0,  0 },
    {     40,   -3,    0, 21,  0,  0 }, {     41,   -4,    0, 21,  0,  0 }, {     41,   -5,    0, 21,  0,  0 }, {     42,   -6,    0, 21,  0,  0 }, {     42,   -7,    0, 21,  0,  0 },
    {     43,   -8,    0, 21,  0,  0 }, {     43,   -9,    0, 21,  0,  0 }, {     44,  -10,    0, 22,  0,  0 }, {     44,  -11,    0, 22,  0,  0 }, {     45,  -12,    0, 22,  0,  0 },
    {     45,  -13,    0, 22,  0,  0 }, {     45,  -14,    0, 22,  0,  0 }, {     46,  -15,    0, 22,  0,  0 }, {     46,  -16,    0, 22,  0,  0 }, {     46,  -17,    0, 22,  0,  0 },
    {     47,  -18,    0, 22,  0,  0 }, {     47,  -19,    0, 22,  0,  0 }, {     47,  -20,    0, 23,  0,  0 }, {     47,  -21,    0, 23,  0,  0 }, {     47,  -22,    0, 23,  0,  0 },
    {     47,  -23,    0, 23,  0,  0 }, {     48,  -24,    0, 23,  0,  0 }, {     48,  -25,    0, 23,  0,  0 }, {     48,  -26,    0, 23,  0,  0 }, {     48,  -27,    0, 23,  0,  0 },
    {     48,  -28,    0, 24,  0,  0 }, {     48,  -29,    0, 24,  0,  0 }, {     48,  -30,    0, 24,  0,  0 }, {     48,  -31,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DFDF8, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 25,  0,  0 },
    {     16,   26,    0, 25,  0,  0 }, {     15,   25,    0, 25,  0,  0 }, {     15,   24,    0, 25,  0,  0 }, {     15,   23,    0, 25,  0,  0 }, {     15,   22,    0, 25,  0,  0 },
    {     15,   21,    0, 25,  0,  0 }, {     15,   20,    0, 25,  0,  0 }, {     14,   19,    0, 25,  0,  0 }, {     14,   18,    0, 26,  0,  0 }, {     14,   17,    0, 26,  0,  0 },
    {     13,   16,    0, 26,  0,  0 }, {     13,   15,    0, 26,  0,  0 }, {     13,   14,    0, 26,  0,  0 }, {     12,   13,    0, 26,  0,  0 }, {     12,   12,    0, 26,  0,  0 },
    {     11,   11,    0, 26,  0,  0 }, {     11,   10,    0, 26,  0,  0 }, {     10,    9,    0, 26,  0,  0 }, {     10,    8,    0, 27,  0,  0 }, {      9,    7,    0, 27,  0,  0 },
    {      9,    6,    0, 27,  0,  0 }, {      8,    5,    0, 27,  0,  0 }, {      7,    4,    0, 27,  0,  0 }, {      7,    3,    0, 27,  0,  0 }, {      6,    2,    0, 27,  0,  0 },
    {      5,    1,    0, 27,  0,  0 }, {      4,    0,    0, 27,  0,  0 }, {      3,   -1,    0, 28,  0,  0 }, {      3,   -3,    0, 28,  0,  0 }, {      2,   -4,    0, 28,  0,  0 },
    {      1,   -5,    0, 28,  0,  0 }, {      0,   -6,    0, 28,  0,  0 }, {     -1,   -7,    0, 29,  0,  0 }, {     -2,   -7,    0, 29,  0,  0 }, {     -3,   -8,    0, 29,  0,  0 },
    {     -4,   -9,    0, 29,  0,  0 }, {     -5,   -9,    0, 29,  0,  0 }, {     -6,  -10,    0, 29,  0,  0 }, {     -7,  -10,    0, 29,  0,  0 }, {     -8,  -11,    0, 29,  0,  0 },
    {     -9,  -11,    0, 29,  0,  0 }, {    -10,  -12,    0, 30,  0,  0 }, {    -11,  -12,    0, 30,  0,  0 }, {    -12,  -13,    0, 30,  0,  0 }, {    -13,  -13,    0, 30,  0,  0 },
    {    -14,  -13,    0, 30,  0,  0 }, {    -15,  -14,    0, 30,  0,  0 }, {    -16,  -14,    0, 30,  0,  0 }, {    -17,  -14,    0, 30,  0,  0 }, {    -18,  -15,    0, 30,  0,  0 },
    {    -19,  -15,    0, 30,  0,  0 }, {    -20,  -15,    0, 31,  0,  0 }, {    -21,  -15,    0, 31,  0,  0 }, {    -22,  -15,    0, 31,  0,  0 }, {    -23,  -15,    0, 31,  0,  0 },
    {    -24,  -16,    0, 31,  0,  0 }, {    -25,  -16,    0, 31,  0,  0 }, {    -26,  -16,    0, 31,  0,  0 }, {    -27,  -16,    0, 31,  0,  0 }, {    -28,  -16,    0,  0,  0,  0 },
    {    -29,  -16,    0,  0,  0,  0 }, {    -30,  -16,    0,  0,  0,  0 }, {    -31,  -16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E005E, {
    {     31,   16,    0,  0,  0,  2 }, {     30,   16,    0,  0,  0,  2 }, {     29,   16,    0,  0,  0,  2 }, {     28,   16,    0,  0,  0,  2 }, {     27,   16,    0, 31,  0,  2 },
    {     26,   16,    0, 31,  0,  2 }, {     25,   15,    0, 31,  0,  2 }, {     24,   15,    0, 31,  0,  2 }, {     23,   15,    0, 31,  0,  2 }, {     22,   15,    0, 31,  0,  2 },
    {     21,   15,    0, 31,  0,  2 }, {     20,   15,    0, 31,  0,  2 }, {     19,   14,    0, 31,  0,  2 }, {     18,   14,    0, 30,  0,  2 }, {     17,   14,    0, 30,  0,  2 },
    {     16,   13,    0, 30,  0,  2 }, {     15,   13,    0, 30,  0,  2 }, {     14,   13,    0, 30,  0,  2 }, {     13,   12,    0, 30,  0,  2 }, {     12,   12,    0, 30,  0,  2 },
    {     11,   11,    0, 30,  0,  2 }, {     10,   11,    0, 30,  0,  2 }, {      9,   10,    0, 30,  0,  2 }, {      8,   10,    0, 29,  0,  2 }, {      7,    9,    0, 29,  0,  2 },
    {      6,    9,    0, 29,  0,  2 }, {      5,    8,    0, 29,  0,  2 }, {      4,    7,    0, 29,  0,  2 }, {      3,    7,    0, 29,  0,  2 }, {      2,    6,    0, 29,  0,  2 },
    {      1,    5,    0, 29,  0,  2 }, {      0,    4,    0, 29,  0,  2 }, {     -1,    3,    0, 28,  0,  2 }, {     -3,    3,    0, 28,  0,  2 }, {     -4,    2,    0, 28,  0,  2 },
    {     -5,    1,    0, 28,  0,  2 }, {     -6,    0,    0, 28,  0,  2 }, {     -7,   -1,    0, 27,  0,  2 }, {     -7,   -2,    0, 27,  0,  2 }, {     -8,   -3,    0, 27,  0,  2 },
    {     -9,   -4,    0, 27,  0,  2 }, {     -9,   -5,    0, 27,  0,  2 }, {    -10,   -6,    0, 27,  0,  2 }, {    -10,   -7,    0, 27,  0,  2 }, {    -11,   -8,    0, 27,  0,  2 },
    {    -11,   -9,    0, 27,  0,  2 }, {    -12,  -10,    0, 26,  0,  2 }, {    -12,  -11,    0, 26,  0,  2 }, {    -13,  -12,    0, 26,  0,  2 }, {    -13,  -13,    0, 26,  0,  2 },
    {    -13,  -14,    0, 26,  0,  2 }, {    -14,  -15,    0, 26,  0,  2 }, {    -14,  -16,    0, 26,  0,  2 }, {    -14,  -17,    0, 26,  0,  2 }, {    -15,  -18,    0, 26,  0,  2 },
    {    -15,  -19,    0, 26,  0,  2 }, {    -15,  -20,    0, 25,  0,  2 }, {    -15,  -21,    0, 25,  0,  2 }, {    -15,  -22,    0, 25,  0,  2 }, {    -15,  -23,    0, 25,  0,  2 },
    {    -16,  -24,    0, 25,  0,  2 }, {    -16,  -25,    0, 25,  0,  2 }, {    -16,  -26,    0, 25,  0,  2 }, {    -16,  -27,    0, 25,  0,  2 }, {    -16,  -28,    0, 24,  0,  2 },
    {    -16,  -29,    0, 24,  0,  2 }, {    -16,  -30,    0, 24,  0,  2 }, {    -16,  -31,    0, 24,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E02C4, {
    {     16,    0,    0,  8,  0,  2 }, {     16,    1,    0,  8,  0,  2 }, {     16,    2,    0,  8,  0,  2 }, {     16,    3,    0,  8,  0,  2 }, {     16,    4,    0,  8,  0,  2 },
    {     16,    5,    0,  7,  0,  2 }, {     16,    6,    0,  7,  0,  2 }, {     15,    7,    0,  7,  0,  2 }, {     15,    8,    0,  7,  0,  2 }, {     15,    9,    0,  7,  0,  2 },
    {     15,   10,    0,  7,  0,  2 }, {     15,   11,    0,  7,  0,  2 }, {     15,   12,    0,  7,  0,  2 }, {     14,   13,    0,  7,  0,  2 }, {     14,   14,    0,  6,  0,  2 },
    {     14,   15,    0,  6,  0,  2 }, {     13,   16,    0,  6,  0,  2 }, {     13,   17,    0,  6,  0,  2 }, {     13,   18,    0,  6,  0,  2 }, {     12,   19,    0,  6,  0,  2 },
    {     12,   20,    0,  6,  0,  2 }, {     11,   21,    0,  6,  0,  2 }, {     11,   22,    0,  6,  0,  2 }, {     10,   23,    0,  6,  0,  2 }, {     10,   24,    0,  5,  0,  2 },
    {      9,   25,    0,  5,  0,  2 }, {      9,   26,    0,  5,  0,  2 }, {      8,   27,    0,  5,  0,  2 }, {      7,   28,    0,  5,  0,  2 }, {      7,   29,    0,  5,  0,  2 },
    {      6,   30,    0,  5,  0,  2 }, {      5,   31,    0,  5,  0,  2 }, {      4,   32,    0,  5,  0,  2 }, {      3,   33,    0,  4,  0,  2 }, {      3,   35,    0,  4,  0,  2 },
    {      2,   36,    0,  4,  0,  2 }, {      1,   37,    0,  4,  0,  2 }, {      0,   38,    0,  4,  0,  2 }, {     -1,   39,    0,  3,  0,  2 }, {     -2,   39,    0,  3,  0,  2 },
    {     -3,   40,    0,  3,  0,  2 }, {     -4,   41,    0,  3,  0,  2 }, {     -5,   41,    0,  3,  0,  2 }, {     -6,   42,    0,  3,  0,  2 }, {     -7,   42,    0,  3,  0,  2 },
    {     -8,   43,    0,  3,  0,  2 }, {     -9,   43,    0,  3,  0,  2 }, {    -10,   44,    0,  2,  0,  2 }, {    -11,   44,    0,  2,  0,  2 }, {    -12,   45,    0,  2,  0,  2 },
    {    -13,   45,    0,  2,  0,  2 }, {    -14,   45,    0,  2,  0,  2 }, {    -15,   46,    0,  2,  0,  2 }, {    -16,   46,    0,  2,  0,  2 }, {    -17,   46,    0,  2,  0,  2 },
    {    -18,   47,    0,  2,  0,  2 }, {    -19,   47,    0,  2,  0,  2 }, {    -20,   47,    0,  1,  0,  2 }, {    -21,   47,    0,  1,  0,  2 }, {    -22,   47,    0,  1,  0,  2 },
    {    -23,   47,    0,  1,  0,  2 }, {    -24,   48,    0,  1,  0,  2 }, {    -25,   48,    0,  1,  0,  2 }, {    -26,   48,    0,  1,  0,  2 }, {    -27,   48,    0,  1,  0,  2 },
    {    -28,   48,    0,  0,  0,  2 }, {    -29,   48,    0,  0,  0,  2 }, {    -30,   48,    0,  0,  0,  2 }, {    -31,   48,    0,  0,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E0533, {
    {      0,   16,    0, 16,  0,  2 }, {      1,   16,    0, 16,  0,  2 }, {      2,   16,    0, 16,  0,  2 }, {      3,   16,    0, 16,  0,  2 }, {      4,   16,    0, 16,  0,  2 },
    {      5,   16,    0, 15,  0,  2 }, {      6,   16,    0, 15,  0,  2 }, {      7,   17,    0, 15,  0,  2 }, {      8,   17,    0, 15,  0,  2 }, {      9,   17,    0, 15,  0,  2 },
    {     10,   17,    0, 15,  0,  2 }, {     11,   17,    0, 15,  0,  2 }, {     12,   17,    0, 15,  0,  2 }, {     13,   18,    0, 15,  0,  2 }, {     14,   18,    0, 14,  0,  2 },
    {     15,   18,    0, 14,  0,  2 }, {     16,   19,    0, 14,  0,  2 }, {     17,   19,    0, 14,  0,  2 }, {     18,   19,    0, 14,  0,  2 }, {     19,   20,    0, 14,  0,  2 },
    {     20,   20,    0, 14,  0,  2 }, {     21,   21,    0, 14,  0,  2 }, {     22,   21,    0, 14,  0,  2 }, {     23,   22,    0, 14,  0,  2 }, {     24,   22,    0, 13,  0,  2 },
    {     25,   23,    0, 13,  0,  2 }, {     26,   23,    0, 13,  0,  2 }, {     27,   24,    0, 13,  0,  2 }, {     28,   25,    0, 13,  0,  2 }, {     29,   25,    0, 13,  0,  2 },
    {     30,   26,    0, 13,  0,  2 }, {     31,   27,    0, 13,  0,  2 }, {     32,   28,    0, 13,  0,  2 }, {     33,   29,    0, 12,  0,  2 }, {     35,   29,    0, 12,  0,  2 },
    {     36,   30,    0, 12,  0,  2 }, {     37,   31,    0, 12,  0,  2 }, {     38,   32,    0, 12,  0,  2 }, {     39,   33,    0, 11,  0,  2 }, {     39,   34,    0, 11,  0,  2 },
    {     40,   35,    0, 11,  0,  2 }, {     41,   36,    0, 11,  0,  2 }, {     41,   37,    0, 11,  0,  2 }, {     42,   38,    0, 11,  0,  2 }, {     42,   39,    0, 11,  0,  2 },
    {     43,   40,    0, 11,  0,  2 }, {     43,   41,    0, 11,  0,  2 }, {     44,   42,    0, 10,  0,  2 }, {     44,   43,    0, 10,  0,  2 }, {     45,   44,    0, 10,  0,  2 },
    {     45,   45,    0, 10,  0,  2 }, {     45,   46,    0, 10,  0,  2 }, {     46,   47,    0, 10,  0,  2 }, {     46,   48,    0, 10,  0,  2 }, {     46,   49,    0, 10,  0,  2 },
    {     47,   50,    0, 10,  0,  2 }, {     47,   51,    0, 10,  0,  2 }, {     47,   52,    0,  9,  0,  2 }, {     47,   53,    0,  9,  0,  2 }, {     47,   54,    0,  9,  0,  2 },
    {     47,   55,    0,  9,  0,  2 }, {     48,   56,    0,  9,  0,  2 }, {     48,   57,    0,  9,  0,  2 }, {     48,   58,    0,  9,  0,  2 }, {     48,   59,    0,  9,  0,  2 },
    {     48,   60,    0,  8,  0,  2 }, {     48,   61,    0,  8,  0,  2 }, {     48,   62,    0,  8,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E0799, {
    {     16,   31,    0, 24,  0,  2 }, {     16,   30,    0, 24,  0,  2 }, {     16,   29,    0, 24,  0,  2 }, {     16,   28,    0, 24,  0,  2 }, {     16,   27,    0, 23,  0,  2 },
    {     16,   26,    0, 23,  0,  2 }, {     17,   25,    0, 23,  0,  2 }, {     17,   24,    0, 23,  0,  2 }, {     17,   23,    0, 23,  0,  2 }, {     17,   22,    0, 23,  0,  2 },
    {     17,   21,    0, 23,  0,  2 }, {     17,   20,    0, 23,  0,  2 }, {     18,   19,    0, 23,  0,  2 }, {     18,   18,    0, 22,  0,  2 }, {     18,   17,    0, 22,  0,  2 },
    {     19,   16,    0, 22,  0,  2 }, {     19,   15,    0, 22,  0,  2 }, {     19,   14,    0, 22,  0,  2 }, {     20,   13,    0, 22,  0,  2 }, {     20,   12,    0, 22,  0,  2 },
    {     21,   11,    0, 22,  0,  2 }, {     21,   10,    0, 22,  0,  2 }, {     22,    9,    0, 22,  0,  2 }, {     22,    8,    0, 21,  0,  2 }, {     23,    7,    0, 21,  0,  2 },
    {     23,    6,    0, 21,  0,  2 }, {     24,    5,    0, 21,  0,  2 }, {     25,    4,    0, 21,  0,  2 }, {     25,    3,    0, 21,  0,  2 }, {     26,    2,    0, 21,  0,  2 },
    {     27,    1,    0, 21,  0,  2 }, {     28,    0,    0, 21,  0,  2 }, {     29,   -1,    0, 20,  0,  2 }, {     29,   -3,    0, 20,  0,  2 }, {     30,   -4,    0, 20,  0,  2 },
    {     31,   -5,    0, 20,  0,  2 }, {     32,   -6,    0, 20,  0,  2 }, {     33,   -7,    0, 19,  0,  2 }, {     34,   -7,    0, 19,  0,  2 }, {     35,   -8,    0, 19,  0,  2 },
    {     36,   -9,    0, 19,  0,  2 }, {     37,   -9,    0, 19,  0,  2 }, {     38,  -10,    0, 19,  0,  2 }, {     39,  -10,    0, 19,  0,  2 }, {     40,  -11,    0, 19,  0,  2 },
    {     41,  -11,    0, 19,  0,  2 }, {     42,  -12,    0, 18,  0,  2 }, {     43,  -12,    0, 18,  0,  2 }, {     44,  -13,    0, 18,  0,  2 }, {     45,  -13,    0, 18,  0,  2 },
    {     46,  -13,    0, 18,  0,  2 }, {     47,  -14,    0, 18,  0,  2 }, {     48,  -14,    0, 18,  0,  2 }, {     49,  -14,    0, 18,  0,  2 }, {     50,  -15,    0, 18,  0,  2 },
    {     51,  -15,    0, 18,  0,  2 }, {     52,  -15,    0, 17,  0,  2 }, {     53,  -15,    0, 17,  0,  2 }, {     54,  -15,    0, 17,  0,  2 }, {     55,  -15,    0, 17,  0,  2 },
    {     56,  -16,    0, 17,  0,  2 }, {     57,  -16,    0, 17,  0,  2 }, {     58,  -16,    0, 17,  0,  2 }, {     59,  -16,    0, 17,  0,  2 }, {     60,  -16,    0, 16,  0,  2 },
    {     61,  -16,    0, 16,  0,  2 }, {     62,  -16,    0, 16,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E09F6, {
    {     31,   16,    0,  0,  0,  4 }, {     30,   16,    0,  0,  0,  4 }, {     29,   16,    0,  0,  0,  4 }, {     28,   16,    0,  0,  0,  4 }, {     27,   16,    0,  1,  0,  4 },
    {     26,   16,    0,  1,  0,  4 }, {     25,   17,    0,  1,  0,  4 }, {     24,   17,    0,  1,  0,  4 }, {     23,   17,    0,  1,  0,  4 }, {     22,   17,    0,  1,  0,  4 },
    {     21,   17,    0,  1,  0,  4 }, {     20,   17,    0,  1,  0,  4 }, {     19,   18,    0,  1,  0,  4 }, {     18,   18,    0,  2,  0,  4 }, {     17,   18,    0,  2,  0,  4 },
    {     16,   19,    0,  2,  0,  4 }, {     15,   19,    0,  2,  0,  4 }, {     14,   19,    0,  2,  0,  4 }, {     13,   20,    0,  2,  0,  4 }, {     12,   20,    0,  2,  0,  4 },
    {     11,   21,    0,  2,  0,  4 }, {     10,   21,    0,  2,  0,  4 }, {      9,   22,    0,  2,  0,  4 }, {      8,   22,    0,  3,  0,  4 }, {      7,   23,    0,  3,  0,  4 },
    {      6,   23,    0,  3,  0,  4 }, {      5,   24,    0,  3,  0,  4 }, {      4,   25,    0,  3,  0,  4 }, {      3,   25,    0,  3,  0,  4 }, {      2,   26,    0,  3,  0,  4 },
    {      1,   27,    0,  3,  0,  4 }, {      0,   28,    0,  3,  0,  4 }, {     -1,   29,    0,  4,  0,  4 }, {     -3,   29,    0,  4,  0,  4 }, {     -4,   30,    0,  4,  0,  4 },
    {     -5,   31,    0,  4,  0,  4 }, {     -6,   32,    0,  4,  0,  4 }, {     -7,   33,    0,  5,  0,  4 }, {     -7,   34,    0,  5,  0,  4 }, {     -8,   35,    0,  5,  0,  4 },
    {     -9,   36,    0,  5,  0,  4 }, {     -9,   37,    0,  5,  0,  4 }, {    -10,   38,    0,  5,  0,  4 }, {    -10,   39,    0,  5,  0,  4 }, {    -11,   40,    0,  5,  0,  4 },
    {    -11,   41,    0,  5,  0,  4 }, {    -12,   42,    0,  6,  0,  4 }, {    -12,   43,    0,  6,  0,  4 }, {    -13,   44,    0,  6,  0,  4 }, {    -13,   45,    0,  6,  0,  4 },
    {    -13,   46,    0,  6,  0,  4 }, {    -14,   47,    0,  6,  0,  4 }, {    -14,   48,    0,  6,  0,  4 }, {    -14,   49,    0,  6,  0,  4 }, {    -15,   50,    0,  6,  0,  4 },
    {    -15,   51,    0,  6,  0,  4 }, {    -15,   52,    0,  7,  0,  4 }, {    -15,   53,    0,  7,  0,  4 }, {    -15,   54,    0,  7,  0,  4 }, {    -15,   55,    0,  7,  0,  4 },
    {    -16,   56,    0,  7,  0,  4 }, {    -16,   57,    0,  7,  0,  4 }, {    -16,   58,    0,  7,  0,  4 }, {    -16,   59,    0,  7,  0,  4 }, {    -16,   60,    0,  8,  0,  4 },
    {    -16,   61,    0,  8,  0,  4 }, {    -16,   62,    0,  8,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E0C53, {
    {     16,    0,    0,  8,  0,  4 }, {     16,    1,    0,  8,  0,  4 }, {     16,    2,    0,  8,  0,  4 }, {     16,    3,    0,  8,  0,  4 }, {     16,    4,    0,  8,  0,  4 },
    {     16,    5,    0,  9,  0,  4 }, {     16,    6,    0,  9,  0,  4 }, {     17,    7,    0,  9,  0,  4 }, {     17,    8,    0,  9,  0,  4 }, {     17,    9,    0,  9,  0,  4 },
    {     17,   10,    0,  9,  0,  4 }, {     17,   11,    0,  9,  0,  4 }, {     17,   12,    0,  9,  0,  4 }, {     18,   13,    0,  9,  0,  4 }, {     18,   14,    0, 10,  0,  4 },
    {     18,   15,    0, 10,  0,  4 }, {     19,   16,    0, 10,  0,  4 }, {     19,   17,    0, 10,  0,  4 }, {     19,   18,    0, 10,  0,  4 }, {     20,   19,    0, 10,  0,  4 },
    {     20,   20,    0, 10,  0,  4 }, {     21,   21,    0, 10,  0,  4 }, {     21,   22,    0, 10,  0,  4 }, {     22,   23,    0, 10,  0,  4 }, {     22,   24,    0, 11,  0,  4 },
    {     23,   25,    0, 11,  0,  4 }, {     23,   26,    0, 11,  0,  4 }, {     24,   27,    0, 11,  0,  4 }, {     25,   28,    0, 11,  0,  4 }, {     25,   29,    0, 11,  0,  4 },
    {     26,   30,    0, 11,  0,  4 }, {     27,   31,    0, 11,  0,  4 }, {     28,   32,    0, 11,  0,  4 }, {     29,   33,    0, 12,  0,  4 }, {     29,   35,    0, 12,  0,  4 },
    {     30,   36,    0, 12,  0,  4 }, {     31,   37,    0, 12,  0,  4 }, {     32,   38,    0, 12,  0,  4 }, {     33,   39,    0, 13,  0,  4 }, {     34,   39,    0, 13,  0,  4 },
    {     35,   40,    0, 13,  0,  4 }, {     36,   41,    0, 13,  0,  4 }, {     37,   41,    0, 13,  0,  4 }, {     38,   42,    0, 13,  0,  4 }, {     39,   42,    0, 13,  0,  4 },
    {     40,   43,    0, 13,  0,  4 }, {     41,   43,    0, 13,  0,  4 }, {     42,   44,    0, 14,  0,  4 }, {     43,   44,    0, 14,  0,  4 }, {     44,   45,    0, 14,  0,  4 },
    {     45,   45,    0, 14,  0,  4 }, {     46,   45,    0, 14,  0,  4 }, {     47,   46,    0, 14,  0,  4 }, {     48,   46,    0, 14,  0,  4 }, {     49,   46,    0, 14,  0,  4 },
    {     50,   47,    0, 14,  0,  4 }, {     51,   47,    0, 14,  0,  4 }, {     52,   47,    0, 15,  0,  4 }, {     53,   47,    0, 15,  0,  4 }, {     54,   47,    0, 15,  0,  4 },
    {     55,   47,    0, 15,  0,  4 }, {     56,   48,    0, 15,  0,  4 }, {     57,   48,    0, 15,  0,  4 }, {     58,   48,    0, 15,  0,  4 }, {     59,   48,    0, 15,  0,  4 },
    {     60,   48,    0, 16,  0,  4 }, {     61,   48,    0, 16,  0,  4 }, {     62,   48,    0, 16,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E0EB9, {
    {      0,   16,    0, 16,  0,  4 }, {      1,   16,    0, 16,  0,  4 }, {      2,   16,    0, 16,  0,  4 }, {      3,   16,    0, 16,  0,  4 }, {      4,   16,    0, 16,  0,  4 },
    {      5,   16,    0, 17,  0,  4 }, {      6,   16,    0, 17,  0,  4 }, {      7,   15,    0, 17,  0,  4 }, {      8,   15,    0, 17,  0,  4 }, {      9,   15,    0, 17,  0,  4 },
    {     10,   15,    0, 17,  0,  4 }, {     11,   15,    0, 17,  0,  4 }, {     12,   15,    0, 17,  0,  4 }, {     13,   14,    0, 17,  0,  4 }, {     14,   14,    0, 18,  0,  4 },
    {     15,   14,    0, 18,  0,  4 }, {     16,   13,    0, 18,  0,  4 }, {     17,   13,    0, 18,  0,  4 }, {     18,   13,    0, 18,  0,  4 }, {     19,   12,    0, 18,  0,  4 },
    {     20,   12,    0, 18,  0,  4 }, {     21,   11,    0, 18,  0,  4 }, {     22,   11,    0, 18,  0,  4 }, {     23,   10,    0, 18,  0,  4 }, {     24,   10,    0, 19,  0,  4 },
    {     25,    9,    0, 19,  0,  4 }, {     26,    9,    0, 19,  0,  4 }, {     27,    8,    0, 19,  0,  4 }, {     28,    7,    0, 19,  0,  4 }, {     29,    7,    0, 19,  0,  4 },
    {     30,    6,    0, 19,  0,  4 }, {     31,    5,    0, 19,  0,  4 }, {     32,    4,    0, 19,  0,  4 }, {     33,    3,    0, 20,  0,  4 }, {     35,    3,    0, 20,  0,  4 },
    {     36,    2,    0, 20,  0,  4 }, {     37,    1,    0, 20,  0,  4 }, {     38,    0,    0, 20,  0,  4 }, {     39,   -1,    0, 21,  0,  4 }, {     39,   -2,    0, 21,  0,  4 },
    {     40,   -3,    0, 21,  0,  4 }, {     41,   -4,    0, 21,  0,  4 }, {     41,   -5,    0, 21,  0,  4 }, {     42,   -6,    0, 21,  0,  4 }, {     42,   -7,    0, 21,  0,  4 },
    {     43,   -8,    0, 21,  0,  4 }, {     43,   -9,    0, 21,  0,  4 }, {     44,  -10,    0, 22,  0,  4 }, {     44,  -11,    0, 22,  0,  4 }, {     45,  -12,    0, 22,  0,  4 },
    {     45,  -13,    0, 22,  0,  4 }, {     45,  -14,    0, 22,  0,  4 }, {     46,  -15,    0, 22,  0,  4 }, {     46,  -16,    0, 22,  0,  4 }, {     46,  -17,    0, 22,  0,  4 },
    {     47,  -18,    0, 22,  0,  4 }, {     47,  -19,    0, 22,  0,  4 }, {     47,  -20,    0, 23,  0,  4 }, {     47,  -21,    0, 23,  0,  4 }, {     47,  -22,    0, 23,  0,  4 },
    {     47,  -23,    0, 23,  0,  4 }, {     48,  -24,    0, 23,  0,  4 }, {     48,  -25,    0, 23,  0,  4 }, {     48,  -26,    0, 23,  0,  4 }, {     48,  -27,    0, 23,  0,  4 },
    {     48,  -28,    0, 24,  0,  4 }, {     48,  -29,    0, 24,  0,  4 }, {     48,  -30,    0, 24,  0,  4 }, {     48,  -31,    0, 24,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E1128, {
    {     16,   31,    0, 24,  0,  4 }, {     16,   30,    0, 24,  0,  4 }, {     16,   29,    0, 24,  0,  4 }, {     16,   28,    0, 24,  0,  4 }, {     16,   27,    0, 25,  0,  4 },
    {     16,   26,    0, 25,  0,  4 }, {     15,   25,    0, 25,  0,  4 }, {     15,   24,    0, 25,  0,  4 }, {     15,   23,    0, 25,  0,  4 }, {     15,   22,    0, 25,  0,  4 },
    {     15,   21,    0, 25,  0,  4 }, {     15,   20,    0, 25,  0,  4 }, {     14,   19,    0, 25,  0,  4 }, {     14,   18,    0, 26,  0,  4 }, {     14,   17,    0, 26,  0,  4 },
    {     13,   16,    0, 26,  0,  4 }, {     13,   15,    0, 26,  0,  4 }, {     13,   14,    0, 26,  0,  4 }, {     12,   13,    0, 26,  0,  4 }, {     12,   12,    0, 26,  0,  4 },
    {     11,   11,    0, 26,  0,  4 }, {     11,   10,    0, 26,  0,  4 }, {     10,    9,    0, 26,  0,  4 }, {     10,    8,    0, 27,  0,  4 }, {      9,    7,    0, 27,  0,  4 },
    {      9,    6,    0, 27,  0,  4 }, {      8,    5,    0, 27,  0,  4 }, {      7,    4,    0, 27,  0,  4 }, {      7,    3,    0, 27,  0,  4 }, {      6,    2,    0, 27,  0,  4 },
    {      5,    1,    0, 27,  0,  4 }, {      4,    0,    0, 27,  0,  4 }, {      3,   -1,    0, 28,  0,  4 }, {      3,   -3,    0, 28,  0,  4 }, {      2,   -4,    0, 28,  0,  4 },
    {      1,   -5,    0, 28,  0,  4 }, {      0,   -6,    0, 28,  0,  4 }, {     -1,   -7,    0, 29,  0,  4 }, {     -2,   -7,    0, 29,  0,  4 }, {     -3,   -8,    0, 29,  0,  4 },
    {     -4,   -9,    0, 29,  0,  4 }, {     -5,   -9,    0, 29,  0,  4 }, {     -6,  -10,    0, 29,  0,  4 }, {     -7,  -10,    0, 29,  0,  4 }, {     -8,  -11,    0, 29,  0,  4 },
    {     -9,  -11,    0, 29,  0,  4 }, {    -10,  -12,    0, 30,  0,  4 }, {    -11,  -12,    0, 30,  0,  4 }, {    -12,  -13,    0, 30,  0,  4 }, {    -13,  -13,    0, 30,  0,  4 },
    {    -14,  -13,    0, 30,  0,  4 }, {    -15,  -14,    0, 30,  0,  4 }, {    -16,  -14,    0, 30,  0,  4 }, {    -17,  -14,    0, 30,  0,  4 }, {    -18,  -15,    0, 30,  0,  4 },
    {    -19,  -15,    0, 30,  0,  4 }, {    -20,  -15,    0, 31,  0,  4 }, {    -21,  -15,    0, 31,  0,  4 }, {    -22,  -15,    0, 31,  0,  4 }, {    -23,  -15,    0, 31,  0,  4 },
    {    -24,  -16,    0, 31,  0,  4 }, {    -25,  -16,    0, 31,  0,  4 }, {    -26,  -16,    0, 31,  0,  4 }, {    -27,  -16,    0, 31,  0,  4 }, {    -28,  -16,    0,  0,  0,  4 },
    {    -29,  -16,    0,  0,  0,  4 }, {    -30,  -16,    0,  0,  0,  4 }, {    -31,  -16,    0,  0,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E26BE, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    0,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    1,  0,  2,  0 }, {     27,   16,    2, 31,  2,  0 },
    {     26,   16,    2, 31,  2,  0 }, {     25,   15,    2, 31,  2,  0 }, {     24,   15,    3, 31,  2,  0 }, {     23,   15,    3, 31,  2,  0 }, {     22,   15,    4, 31,  2,  0 },
    {     21,   15,    4, 31,  2,  0 }, {     20,   15,    4, 31,  2,  0 }, {     19,   14,    5, 31,  2,  0 }, {     18,   14,    5, 30,  2,  0 }, {     17,   14,    6, 30,  2,  0 },
    {     16,   13,    6, 30,  2,  0 }, {     15,   13,    7, 30,  2,  0 }, {     14,   13,    7, 30,  2,  0 }, {     13,   12,    8, 30,  2,  0 }, {     12,   12,    8, 30,  2,  0 },
    {     11,   11,    9, 30,  2,  0 }, {     10,   11,    9, 30,  2,  0 }, {      9,   10,   10, 30,  2,  0 }, {      8,   10,   10, 29,  2,  0 }, {      7,    9,   11, 29,  2,  0 },
    {      6,    9,   11, 29,  2,  0 }, {      5,    8,   11, 29,  2,  0 }, {      4,    7,   12, 29,  2,  0 }, {      3,    7,   13, 29,  2,  0 }, {      2,    6,   13, 29,  2,  0 },
    {      1,    5,   14, 29,  2,  0 }, {      0,    4,   14, 29,  2,  0 }, {     -1,    3,   15, 28,  2,  0 }, {     -3,    3,   15, 28,  2,  0 }, {     -4,    2,   16, 28,  2,  0 },
    {     -5,    1,   16, 28,  2,  0 }, {     -6,    0,   17, 28,  2,  0 }, {     -7,   -1,   17, 27,  2,  0 }, {     -7,   -2,   18, 27,  2,  0 }, {     -8,   -3,   18, 27,  2,  0 },
    {     -9,   -4,   19, 27,  2,  0 }, {     -9,   -5,   19, 27,  2,  0 }, {    -10,   -6,   20, 27,  2,  0 }, {    -10,   -7,   20, 27,  2,  0 }, {    -11,   -8,   21, 27,  2,  0 },
    {    -11,   -9,   21, 27,  2,  0 }, {    -12,  -10,   22, 26,  2,  0 }, {    -12,  -11,   22, 26,  2,  0 }, {    -13,  -12,   23, 26,  2,  0 }, {    -13,  -13,   23, 26,  2,  0 },
    {    -13,  -14,   24, 26,  2,  0 }, {    -14,  -15,   24, 26,  2,  0 }, {    -14,  -16,   25, 26,  2,  0 }, {    -14,  -17,   25, 26,  2,  0 }, {    -15,  -18,   25, 26,  2,  0 },
    {    -15,  -19,   26, 26,  2,  0 }, {    -15,  -20,   26, 25,  2,  0 }, {    -15,  -21,   27, 25,  2,  0 }, {    -15,  -22,   27, 25,  2,  0 }, {    -15,  -23,   28, 25,  2,  0 },
    {    -16,  -24,   28, 25,  2,  0 }, {    -16,  -25,   29, 25,  2,  0 }, {    -16,  -26,   29, 25,  2,  0 }, {    -16,  -27,   29, 25,  2,  0 }, {    -16,  -28,   30, 24,  2,  0 },
    {    -16,  -29,   30, 24,  2,  0 }, {    -16,  -30,   31, 24,  2,  0 }, {    -16,  -31,   31, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E2924, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    0,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    1,  8,  2,  0 },
    {     16,    5,    2,  7,  2,  0 }, {     16,    6,    2,  7,  2,  0 }, {     15,    7,    2,  7,  2,  0 }, {     15,    8,    3,  7,  2,  0 }, {     15,    9,    3,  7,  2,  0 },
    {     15,   10,    4,  7,  2,  0 }, {     15,   11,    4,  7,  2,  0 }, {     15,   12,    4,  7,  2,  0 }, {     14,   13,    5,  7,  2,  0 }, {     14,   14,    5,  6,  2,  0 },
    {     14,   15,    6,  6,  2,  0 }, {     13,   16,    6,  6,  2,  0 }, {     13,   17,    7,  6,  2,  0 }, {     13,   18,    7,  6,  2,  0 }, {     12,   19,    8,  6,  2,  0 },
    {     12,   20,    8,  6,  2,  0 }, {     11,   21,    9,  6,  2,  0 }, {     11,   22,    9,  6,  2,  0 }, {     10,   23,   10,  6,  2,  0 }, {     10,   24,   10,  5,  2,  0 },
    {      9,   25,   11,  5,  2,  0 }, {      9,   26,   11,  5,  2,  0 }, {      8,   27,   11,  5,  2,  0 }, {      7,   28,   12,  5,  2,  0 }, {      7,   29,   13,  5,  2,  0 },
    {      6,   30,   13,  5,  2,  0 }, {      5,   31,   14,  5,  2,  0 }, {      4,   32,   14,  5,  2,  0 }, {      3,   33,   15,  4,  2,  0 }, {      3,   35,   15,  4,  2,  0 },
    {      2,   36,   16,  4,  2,  0 }, {      1,   37,   16,  4,  2,  0 }, {      0,   38,   17,  4,  2,  0 }, {     -1,   39,   17,  3,  2,  0 }, {     -2,   39,   18,  3,  2,  0 },
    {     -3,   40,   18,  3,  2,  0 }, {     -4,   41,   19,  3,  2,  0 }, {     -5,   41,   19,  3,  2,  0 }, {     -6,   42,   20,  3,  2,  0 }, {     -7,   42,   20,  3,  2,  0 },
    {     -8,   43,   21,  3,  2,  0 }, {     -9,   43,   21,  3,  2,  0 }, {    -10,   44,   22,  2,  2,  0 }, {    -11,   44,   22,  2,  2,  0 }, {    -12,   45,   23,  2,  2,  0 },
    {    -13,   45,   23,  2,  2,  0 }, {    -14,   45,   24,  2,  2,  0 }, {    -15,   46,   24,  2,  2,  0 }, {    -16,   46,   25,  2,  2,  0 }, {    -17,   46,   25,  2,  2,  0 },
    {    -18,   47,   25,  2,  2,  0 }, {    -19,   47,   26,  2,  2,  0 }, {    -20,   47,   26,  1,  2,  0 }, {    -21,   47,   27,  1,  2,  0 }, {    -22,   47,   27,  1,  2,  0 },
    {    -23,   47,   28,  1,  2,  0 }, {    -24,   48,   28,  1,  2,  0 }, {    -25,   48,   29,  1,  2,  0 }, {    -26,   48,   29,  1,  2,  0 }, {    -27,   48,   29,  1,  2,  0 },
    {    -28,   48,   30,  0,  2,  0 }, {    -29,   48,   30,  0,  2,  0 }, {    -30,   48,   31,  0,  2,  0 }, {    -31,   48,   31,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E2B93, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    0, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    1, 16,  2,  0 },
    {      5,   16,    2, 15,  2,  0 }, {      6,   16,    2, 15,  2,  0 }, {      7,   17,    2, 15,  2,  0 }, {      8,   17,    3, 15,  2,  0 }, {      9,   17,    3, 15,  2,  0 },
    {     10,   17,    4, 15,  2,  0 }, {     11,   17,    4, 15,  2,  0 }, {     12,   17,    5, 15,  2,  0 }, {     13,   18,    5, 15,  2,  0 }, {     14,   18,    6, 14,  2,  0 },
    {     15,   18,    6, 14,  2,  0 }, {     16,   19,    6, 14,  2,  0 }, {     17,   19,    7, 14,  2,  0 }, {     18,   19,    7, 14,  2,  0 }, {     19,   20,    8, 14,  2,  0 },
    {     20,   20,    8, 14,  2,  0 }, {     21,   21,    9, 14,  2,  0 }, {     22,   21,    9, 14,  2,  0 }, {     23,   22,   10, 14,  2,  0 }, {     24,   22,   10, 13,  2,  0 },
    {     25,   23,   11, 13,  2,  0 }, {     26,   23,   11, 13,  2,  0 }, {     27,   24,   12, 13,  2,  0 }, {     28,   25,   12, 13,  2,  0 }, {     29,   25,   13, 13,  2,  0 },
    {     30,   26,   13, 13,  2,  0 }, {     31,   27,   14, 13,  2,  0 }, {     32,   28,   14, 13,  2,  0 }, {     33,   29,   15, 12,  2,  0 }, {     35,   29,   15, 12,  2,  0 },
    {     36,   30,   16, 12,  2,  0 }, {     37,   31,   16, 12,  2,  0 }, {     38,   32,   17, 12,  2,  0 }, {     39,   33,   18, 11,  2,  0 }, {     39,   34,   18, 11,  2,  0 },
    {     40,   35,   19, 11,  2,  0 }, {     41,   36,   19, 11,  2,  0 }, {     41,   37,   20, 11,  2,  0 }, {     42,   38,   20, 11,  2,  0 }, {     42,   39,   21, 11,  2,  0 },
    {     43,   40,   21, 11,  2,  0 }, {     43,   41,   22, 11,  2,  0 }, {     44,   42,   22, 10,  2,  0 }, {     44,   43,   23, 10,  2,  0 }, {     45,   44,   23, 10,  2,  0 },
    {     45,   45,   24, 10,  2,  0 }, {     45,   46,   24, 10,  2,  0 }, {     46,   47,   24, 10,  2,  0 }, {     46,   48,   25, 10,  2,  0 }, {     46,   49,   25, 10,  2,  0 },
    {     47,   50,   26, 10,  2,  0 }, {     47,   51,   26, 10,  2,  0 }, {     47,   52,   27,  9,  2,  0 }, {     47,   53,   27,  9,  2,  0 }, {     47,   54,   28,  9,  2,  0 },
    {     47,   55,   28,  9,  2,  0 }, {     48,   56,   28,  9,  2,  0 }, {     48,   57,   29,  9,  2,  0 }, {     48,   58,   29,  9,  2,  0 }, {     48,   59,   30,  9,  2,  0 },
    {     48,   60,   30,  8,  2,  0 }, {     48,   61,   31,  8,  2,  0 }, {     48,   62,   31,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E2DF9, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    0, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    1, 24,  2,  0 }, {     16,   27,    2, 23,  2,  0 },
    {     16,   26,    2, 23,  2,  0 }, {     17,   25,    2, 23,  2,  0 }, {     17,   24,    3, 23,  2,  0 }, {     17,   23,    3, 23,  2,  0 }, {     17,   22,    4, 23,  2,  0 },
    {     17,   21,    4, 23,  2,  0 }, {     17,   20,    5, 23,  2,  0 }, {     18,   19,    5, 23,  2,  0 }, {     18,   18,    6, 22,  2,  0 }, {     18,   17,    6, 22,  2,  0 },
    {     19,   16,    6, 22,  2,  0 }, {     19,   15,    7, 22,  2,  0 }, {     19,   14,    7, 22,  2,  0 }, {     20,   13,    8, 22,  2,  0 }, {     20,   12,    8, 22,  2,  0 },
    {     21,   11,    9, 22,  2,  0 }, {     21,   10,    9, 22,  2,  0 }, {     22,    9,   10, 22,  2,  0 }, {     22,    8,   10, 21,  2,  0 }, {     23,    7,   11, 21,  2,  0 },
    {     23,    6,   11, 21,  2,  0 }, {     24,    5,   12, 21,  2,  0 }, {     25,    4,   12, 21,  2,  0 }, {     25,    3,   13, 21,  2,  0 }, {     26,    2,   13, 21,  2,  0 },
    {     27,    1,   14, 21,  2,  0 }, {     28,    0,   14, 21,  2,  0 }, {     29,   -1,   15, 20,  2,  0 }, {     29,   -3,   15, 20,  2,  0 }, {     30,   -4,   16, 20,  2,  0 },
    {     31,   -5,   16, 20,  2,  0 }, {     32,   -6,   17, 20,  2,  0 }, {     33,   -7,   18, 19,  2,  0 }, {     34,   -7,   18, 19,  2,  0 }, {     35,   -8,   19, 19,  2,  0 },
    {     36,   -9,   19, 19,  2,  0 }, {     37,   -9,   20, 19,  2,  0 }, {     38,  -10,   20, 19,  2,  0 }, {     39,  -10,   21, 19,  2,  0 }, {     40,  -11,   21, 19,  2,  0 },
    {     41,  -11,   22, 19,  2,  0 }, {     42,  -12,   22, 18,  2,  0 }, {     43,  -12,   23, 18,  2,  0 }, {     44,  -13,   23, 18,  2,  0 }, {     45,  -13,   24, 18,  2,  0 },
    {     46,  -13,   24, 18,  2,  0 }, {     47,  -14,   24, 18,  2,  0 }, {     48,  -14,   25, 18,  2,  0 }, {     49,  -14,   25, 18,  2,  0 }, {     50,  -15,   26, 18,  2,  0 },
    {     51,  -15,   26, 18,  2,  0 }, {     52,  -15,   27, 17,  2,  0 }, {     53,  -15,   27, 17,  2,  0 }, {     54,  -15,   28, 17,  2,  0 }, {     55,  -15,   28, 17,  2,  0 },
    {     56,  -16,   28, 17,  2,  0 }, {     57,  -16,   29, 17,  2,  0 }, {     58,  -16,   29, 17,  2,  0 }, {     59,  -16,   30, 17,  2,  0 }, {     60,  -16,   30, 16,  2,  0 },
    {     61,  -16,   31, 16,  2,  0 }, {     62,  -16,   31, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E3056, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    0,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    1,  0,  2,  0 }, {     27,   16,    2,  1,  2,  0 },
    {     26,   16,    2,  1,  2,  0 }, {     25,   17,    2,  1,  2,  0 }, {     24,   17,    3,  1,  2,  0 }, {     23,   17,    3,  1,  2,  0 }, {     22,   17,    4,  1,  2,  0 },
    {     21,   17,    4,  1,  2,  0 }, {     20,   17,    5,  1,  2,  0 }, {     19,   18,    5,  1,  2,  0 }, {     18,   18,    6,  2,  2,  0 }, {     17,   18,    6,  2,  2,  0 },
    {     16,   19,    6,  2,  2,  0 }, {     15,   19,    7,  2,  2,  0 }, {     14,   19,    7,  2,  2,  0 }, {     13,   20,    8,  2,  2,  0 }, {     12,   20,    8,  2,  2,  0 },
    {     11,   21,    9,  2,  2,  0 }, {     10,   21,    9,  2,  2,  0 }, {      9,   22,   10,  2,  2,  0 }, {      8,   22,   10,  3,  2,  0 }, {      7,   23,   11,  3,  2,  0 },
    {      6,   23,   11,  3,  2,  0 }, {      5,   24,   12,  3,  2,  0 }, {      4,   25,   12,  3,  2,  0 }, {      3,   25,   13,  3,  2,  0 }, {      2,   26,   13,  3,  2,  0 },
    {      1,   27,   14,  3,  2,  0 }, {      0,   28,   14,  3,  2,  0 }, {     -1,   29,   15,  4,  2,  0 }, {     -3,   29,   15,  4,  2,  0 }, {     -4,   30,   16,  4,  2,  0 },
    {     -5,   31,   16,  4,  2,  0 }, {     -6,   32,   17,  4,  2,  0 }, {     -7,   33,   18,  5,  2,  0 }, {     -7,   34,   18,  5,  2,  0 }, {     -8,   35,   19,  5,  2,  0 },
    {     -9,   36,   19,  5,  2,  0 }, {     -9,   37,   20,  5,  2,  0 }, {    -10,   38,   20,  5,  2,  0 }, {    -10,   39,   21,  5,  2,  0 }, {    -11,   40,   21,  5,  2,  0 },
    {    -11,   41,   22,  5,  2,  0 }, {    -12,   42,   22,  6,  2,  0 }, {    -12,   43,   23,  6,  2,  0 }, {    -13,   44,   23,  6,  2,  0 }, {    -13,   45,   24,  6,  2,  0 },
    {    -13,   46,   24,  6,  2,  0 }, {    -14,   47,   24,  6,  2,  0 }, {    -14,   48,   25,  6,  2,  0 }, {    -14,   49,   25,  6,  2,  0 }, {    -15,   50,   26,  6,  2,  0 },
    {    -15,   51,   26,  6,  2,  0 }, {    -15,   52,   27,  7,  2,  0 }, {    -15,   53,   27,  7,  2,  0 }, {    -15,   54,   28,  7,  2,  0 }, {    -15,   55,   28,  7,  2,  0 },
    {    -16,   56,   28,  7,  2,  0 }, {    -16,   57,   29,  7,  2,  0 }, {    -16,   58,   29,  7,  2,  0 }, {    -16,   59,   30,  7,  2,  0 }, {    -16,   60,   30,  8,  2,  0 },
    {    -16,   61,   31,  8,  2,  0 }, {    -16,   62,   31,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E32B3, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    0,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    1,  8,  2,  0 },
    {     16,    5,    2,  9,  2,  0 }, {     16,    6,    2,  9,  2,  0 }, {     17,    7,    2,  9,  2,  0 }, {     17,    8,    3,  9,  2,  0 }, {     17,    9,    3,  9,  2,  0 },
    {     17,   10,    4,  9,  2,  0 }, {     17,   11,    4,  9,  2,  0 }, {     17,   12,    5,  9,  2,  0 }, {     18,   13,    5,  9,  2,  0 }, {     18,   14,    6, 10,  2,  0 },
    {     18,   15,    6, 10,  2,  0 }, {     19,   16,    6, 10,  2,  0 }, {     19,   17,    7, 10,  2,  0 }, {     19,   18,    7, 10,  2,  0 }, {     20,   19,    8, 10,  2,  0 },
    {     20,   20,    8, 10,  2,  0 }, {     21,   21,    9, 10,  2,  0 }, {     21,   22,    9, 10,  2,  0 }, {     22,   23,   10, 10,  2,  0 }, {     22,   24,   10, 11,  2,  0 },
    {     23,   25,   11, 11,  2,  0 }, {     23,   26,   11, 11,  2,  0 }, {     24,   27,   12, 11,  2,  0 }, {     25,   28,   12, 11,  2,  0 }, {     25,   29,   13, 11,  2,  0 },
    {     26,   30,   13, 11,  2,  0 }, {     27,   31,   14, 11,  2,  0 }, {     28,   32,   14, 11,  2,  0 }, {     29,   33,   15, 12,  2,  0 }, {     29,   35,   15, 12,  2,  0 },
    {     30,   36,   16, 12,  2,  0 }, {     31,   37,   16, 12,  2,  0 }, {     32,   38,   17, 12,  2,  0 }, {     33,   39,   18, 13,  2,  0 }, {     34,   39,   18, 13,  2,  0 },
    {     35,   40,   19, 13,  2,  0 }, {     36,   41,   19, 13,  2,  0 }, {     37,   41,   20, 13,  2,  0 }, {     38,   42,   20, 13,  2,  0 }, {     39,   42,   21, 13,  2,  0 },
    {     40,   43,   21, 13,  2,  0 }, {     41,   43,   22, 13,  2,  0 }, {     42,   44,   22, 14,  2,  0 }, {     43,   44,   23, 14,  2,  0 }, {     44,   45,   23, 14,  2,  0 },
    {     45,   45,   24, 14,  2,  0 }, {     46,   45,   24, 14,  2,  0 }, {     47,   46,   24, 14,  2,  0 }, {     48,   46,   25, 14,  2,  0 }, {     49,   46,   25, 14,  2,  0 },
    {     50,   47,   26, 14,  2,  0 }, {     51,   47,   26, 14,  2,  0 }, {     52,   47,   27, 15,  2,  0 }, {     53,   47,   27, 15,  2,  0 }, {     54,   47,   28, 15,  2,  0 },
    {     55,   47,   28, 15,  2,  0 }, {     56,   48,   28, 15,  2,  0 }, {     57,   48,   29, 15,  2,  0 }, {     58,   48,   29, 15,  2,  0 }, {     59,   48,   30, 15,  2,  0 },
    {     60,   48,   30, 16,  2,  0 }, {     61,   48,   31, 16,  2,  0 }, {     62,   48,   31, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E3519, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    0, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    1, 16,  2,  0 },
    {      5,   16,    2, 17,  2,  0 }, {      6,   16,    2, 17,  2,  0 }, {      7,   15,    2, 17,  2,  0 }, {      8,   15,    3, 17,  2,  0 }, {      9,   15,    3, 17,  2,  0 },
    {     10,   15,    4, 17,  2,  0 }, {     11,   15,    4, 17,  2,  0 }, {     12,   15,    4, 17,  2,  0 }, {     13,   14,    5, 17,  2,  0 }, {     14,   14,    5, 18,  2,  0 },
    {     15,   14,    6, 18,  2,  0 }, {     16,   13,    6, 18,  2,  0 }, {     17,   13,    7, 18,  2,  0 }, {     18,   13,    7, 18,  2,  0 }, {     19,   12,    8, 18,  2,  0 },
    {     20,   12,    8, 18,  2,  0 }, {     21,   11,    9, 18,  2,  0 }, {     22,   11,    9, 18,  2,  0 }, {     23,   10,   10, 18,  2,  0 }, {     24,   10,   10, 19,  2,  0 },
    {     25,    9,   11, 19,  2,  0 }, {     26,    9,   11, 19,  2,  0 }, {     27,    8,   11, 19,  2,  0 }, {     28,    7,   12, 19,  2,  0 }, {     29,    7,   13, 19,  2,  0 },
    {     30,    6,   13, 19,  2,  0 }, {     31,    5,   14, 19,  2,  0 }, {     32,    4,   14, 19,  2,  0 }, {     33,    3,   15, 20,  2,  0 }, {     35,    3,   15, 20,  2,  0 },
    {     36,    2,   16, 20,  2,  0 }, {     37,    1,   16, 20,  2,  0 }, {     38,    0,   17, 20,  2,  0 }, {     39,   -1,   17, 21,  2,  0 }, {     39,   -2,   18, 21,  2,  0 },
    {     40,   -3,   18, 21,  2,  0 }, {     41,   -4,   19, 21,  2,  0 }, {     41,   -5,   19, 21,  2,  0 }, {     42,   -6,   20, 21,  2,  0 }, {     42,   -7,   20, 21,  2,  0 },
    {     43,   -8,   21, 21,  2,  0 }, {     43,   -9,   21, 21,  2,  0 }, {     44,  -10,   22, 22,  2,  0 }, {     44,  -11,   22, 22,  2,  0 }, {     45,  -12,   23, 22,  2,  0 },
    {     45,  -13,   23, 22,  2,  0 }, {     45,  -14,   24, 22,  2,  0 }, {     46,  -15,   24, 22,  2,  0 }, {     46,  -16,   25, 22,  2,  0 }, {     46,  -17,   25, 22,  2,  0 },
    {     47,  -18,   25, 22,  2,  0 }, {     47,  -19,   26, 22,  2,  0 }, {     47,  -20,   26, 23,  2,  0 }, {     47,  -21,   27, 23,  2,  0 }, {     47,  -22,   27, 23,  2,  0 },
    {     47,  -23,   28, 23,  2,  0 }, {     48,  -24,   28, 23,  2,  0 }, {     48,  -25,   29, 23,  2,  0 }, {     48,  -26,   29, 23,  2,  0 }, {     48,  -27,   29, 23,  2,  0 },
    {     48,  -28,   30, 24,  2,  0 }, {     48,  -29,   30, 24,  2,  0 }, {     48,  -30,   31, 24,  2,  0 }, {     48,  -31,   31, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E3788, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    0, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    1, 24,  2,  0 }, {     16,   27,    2, 25,  2,  0 },
    {     16,   26,    2, 25,  2,  0 }, {     15,   25,    2, 25,  2,  0 }, {     15,   24,    3, 25,  2,  0 }, {     15,   23,    3, 25,  2,  0 }, {     15,   22,    4, 25,  2,  0 },
    {     15,   21,    4, 25,  2,  0 }, {     15,   20,    4, 25,  2,  0 }, {     14,   19,    5, 25,  2,  0 }, {     14,   18,    5, 26,  2,  0 }, {     14,   17,    6, 26,  2,  0 },
    {     13,   16,    6, 26,  2,  0 }, {     13,   15,    7, 26,  2,  0 }, {     13,   14,    7, 26,  2,  0 }, {     12,   13,    8, 26,  2,  0 }, {     12,   12,    8, 26,  2,  0 },
    {     11,   11,    9, 26,  2,  0 }, {     11,   10,    9, 26,  2,  0 }, {     10,    9,   10, 26,  2,  0 }, {     10,    8,   10, 27,  2,  0 }, {      9,    7,   11, 27,  2,  0 },
    {      9,    6,   11, 27,  2,  0 }, {      8,    5,   11, 27,  2,  0 }, {      7,    4,   12, 27,  2,  0 }, {      7,    3,   13, 27,  2,  0 }, {      6,    2,   13, 27,  2,  0 },
    {      5,    1,   14, 27,  2,  0 }, {      4,    0,   14, 27,  2,  0 }, {      3,   -1,   15, 28,  2,  0 }, {      3,   -3,   15, 28,  2,  0 }, {      2,   -4,   16, 28,  2,  0 },
    {      1,   -5,   16, 28,  2,  0 }, {      0,   -6,   17, 28,  2,  0 }, {     -1,   -7,   17, 29,  2,  0 }, {     -2,   -7,   18, 29,  2,  0 }, {     -3,   -8,   18, 29,  2,  0 },
    {     -4,   -9,   19, 29,  2,  0 }, {     -5,   -9,   19, 29,  2,  0 }, {     -6,  -10,   20, 29,  2,  0 }, {     -7,  -10,   20, 29,  2,  0 }, {     -8,  -11,   21, 29,  2,  0 },
    {     -9,  -11,   21, 29,  2,  0 }, {    -10,  -12,   22, 30,  2,  0 }, {    -11,  -12,   22, 30,  2,  0 }, {    -12,  -13,   23, 30,  2,  0 }, {    -13,  -13,   23, 30,  2,  0 },
    {    -14,  -13,   24, 30,  2,  0 }, {    -15,  -14,   24, 30,  2,  0 }, {    -16,  -14,   25, 30,  2,  0 }, {    -17,  -14,   25, 30,  2,  0 }, {    -18,  -15,   25, 30,  2,  0 },
    {    -19,  -15,   26, 30,  2,  0 }, {    -20,  -15,   26, 31,  2,  0 }, {    -21,  -15,   27, 31,  2,  0 }, {    -22,  -15,   27, 31,  2,  0 }, {    -23,  -15,   28, 31,  2,  0 },
    {    -24,  -16,   28, 31,  2,  0 }, {    -25,  -16,   29, 31,  2,  0 }, {    -26,  -16,   29, 31,  2,  0 }, {    -27,  -16,   29, 31,  2,  0 }, {    -28,  -16,   30,  0,  2,  0 },
    {    -29,  -16,   30,  0,  2,  0 }, {    -30,  -16,   31,  0,  2,  0 }, {    -31,  -16,   31,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E138E, {
    {     31,   16,   15,  0,  6,  0 }, {     30,   16,   15,  0,  6,  0 }, {     29,   16,   14,  0,  6,  0 }, {     28,   16,   14,  0,  6,  0 }, {     27,   16,   13, 31,  6,  0 },
    {     26,   16,   13, 31,  6,  0 }, {     25,   15,   13, 31,  6,  0 }, {     24,   15,   12, 31,  6,  0 }, {     23,   15,   12, 31,  6,  0 }, {     22,   15,   11, 31,  6,  0 },
    {     21,   15,   11, 31,  6,  0 }, {     20,   15,   11, 31,  6,  0 }, {     19,   14,   10, 31,  6,  0 }, {     18,   14,   10, 30,  6,  0 }, {     17,   14,    9, 30,  6,  0 },
    {     16,   13,    9, 30,  6,  0 }, {     15,   13,    8, 30,  6,  0 }, {     14,   13,    8, 30,  6,  0 }, {     13,   12,    7, 30,  6,  0 }, {     12,   12,    7, 30,  6,  0 },
    {     11,   11,    6, 30,  6,  0 }, {     10,   11,    6, 30,  6,  0 }, {      9,   10,    5, 30,  6,  0 }, {      8,   10,    5, 29,  6,  0 }, {      7,    9,    4, 29,  6,  0 },
    {      6,    9,    4, 29,  6,  0 }, {      5,    8,    4, 29,  6,  0 }, {      4,    7,    3, 29,  6,  0 }, {      3,    7,    2, 29,  6,  0 }, {      2,    6,    2, 29,  6,  0 },
    {      1,    5,    1, 29,  6,  0 }, {      0,    4,    1, 29,  6,  0 }, {     -1,    3,    0, 28,  6,  0 }, {     -3,    3,    0, 28,  6,  0 }, {     -4,    2,   -1, 28,  6,  0 },
    {     -5,    1,   -1, 28,  6,  0 }, {     -6,    0,   -2, 28,  6,  0 }, {     -7,   -1,   -2, 27,  6,  0 }, {     -7,   -2,   -3, 27,  6,  0 }, {     -8,   -3,   -3, 27,  6,  0 },
    {     -9,   -4,   -4, 27,  6,  0 }, {     -9,   -5,   -5, 27,  6,  0 }, {    -10,   -6,   -5, 27,  6,  0 }, {    -10,   -7,   -5, 27,  6,  0 }, {    -11,   -8,   -6, 27,  6,  0 },
    {    -11,   -9,   -6, 27,  6,  0 }, {    -12,  -10,   -7, 26,  6,  0 }, {    -12,  -11,   -7, 26,  6,  0 }, {    -13,  -12,   -8, 26,  6,  0 }, {    -13,  -13,   -8, 26,  6,  0 },
    {    -13,  -14,   -9, 26,  6,  0 }, {    -14,  -15,   -9, 26,  6,  0 }, {    -14,  -16,  -10, 26,  6,  0 }, {    -14,  -17,  -10, 26,  6,  0 }, {    -15,  -18,  -11, 26,  6,  0 },
    {    -15,  -19,  -11, 26,  6,  0 }, {    -15,  -20,  -12, 25,  6,  0 }, {    -15,  -21,  -12, 25,  6,  0 }, {    -15,  -22,  -12, 25,  6,  0 }, {    -15,  -23,  -13, 25,  6,  0 },
    {    -16,  -24,  -13, 25,  6,  0 }, {    -16,  -25,  -14, 25,  6,  0 }, {    -16,  -26,  -14, 25,  6,  0 }, {    -16,  -27,  -14, 25,  6,  0 }, {    -16,  -28,  -15, 24,  6,  0 },
    {    -16,  -29,  -15, 24,  6,  0 }, {    -16,  -30,  -16, 24,  6,  0 }, {    -16,  -31,  -17, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E15F4, {
    {     16,    0,   15,  8,  6,  0 }, {     16,    1,   15,  8,  6,  0 }, {     16,    2,   15,  8,  6,  0 }, {     16,    3,   14,  8,  6,  0 }, {     16,    4,   14,  8,  6,  0 },
    {     16,    5,   13,  7,  6,  0 }, {     16,    6,   13,  7,  6,  0 }, {     15,    7,   13,  7,  6,  0 }, {     15,    8,   12,  7,  6,  0 }, {     15,    9,   12,  7,  6,  0 },
    {     15,   10,   11,  7,  6,  0 }, {     15,   11,   11,  7,  6,  0 }, {     15,   12,   11,  7,  6,  0 }, {     14,   13,   10,  7,  6,  0 }, {     14,   14,   10,  6,  6,  0 },
    {     14,   15,    9,  6,  6,  0 }, {     13,   16,    9,  6,  6,  0 }, {     13,   17,    8,  6,  6,  0 }, {     13,   18,    8,  6,  6,  0 }, {     12,   19,    7,  6,  6,  0 },
    {     12,   20,    7,  6,  6,  0 }, {     11,   21,    6,  6,  6,  0 }, {     11,   22,    6,  6,  6,  0 }, {     10,   23,    5,  6,  6,  0 }, {     10,   24,    5,  5,  6,  0 },
    {      9,   25,    4,  5,  6,  0 }, {      9,   26,    4,  5,  6,  0 }, {      8,   27,    4,  5,  6,  0 }, {      7,   28,    3,  5,  6,  0 }, {      7,   29,    2,  5,  6,  0 },
    {      6,   30,    2,  5,  6,  0 }, {      5,   31,    1,  5,  6,  0 }, {      4,   32,    1,  5,  6,  0 }, {      3,   33,    0,  4,  6,  0 }, {      3,   35,    0,  4,  6,  0 },
    {      2,   36,   -1,  4,  6,  0 }, {      1,   37,   -1,  4,  6,  0 }, {      0,   38,   -2,  4,  6,  0 }, {     -1,   39,   -2,  3,  6,  0 }, {     -2,   39,   -3,  3,  6,  0 },
    {     -3,   40,   -3,  3,  6,  0 }, {     -4,   41,   -4,  3,  6,  0 }, {     -5,   41,   -5,  3,  6,  0 }, {     -6,   42,   -5,  3,  6,  0 }, {     -7,   42,   -5,  3,  6,  0 },
    {     -8,   43,   -6,  3,  6,  0 }, {     -9,   43,   -6,  3,  6,  0 }, {    -10,   44,   -7,  2,  6,  0 }, {    -11,   44,   -7,  2,  6,  0 }, {    -12,   45,   -8,  2,  6,  0 },
    {    -13,   45,   -8,  2,  6,  0 }, {    -14,   45,   -9,  2,  6,  0 }, {    -15,   46,   -9,  2,  6,  0 }, {    -16,   46,  -10,  2,  6,  0 }, {    -17,   46,  -10,  2,  6,  0 },
    {    -18,   47,  -11,  2,  6,  0 }, {    -19,   47,  -11,  2,  6,  0 }, {    -20,   47,  -12,  1,  6,  0 }, {    -21,   47,  -12,  1,  6,  0 }, {    -22,   47,  -12,  1,  6,  0 },
    {    -23,   47,  -13,  1,  6,  0 }, {    -24,   48,  -13,  1,  6,  0 }, {    -25,   48,  -14,  1,  6,  0 }, {    -26,   48,  -14,  1,  6,  0 }, {    -27,   48,  -14,  1,  6,  0 },
    {    -28,   48,  -15,  0,  6,  0 }, {    -29,   48,  -15,  0,  6,  0 }, {    -30,   48,  -16,  0,  6,  0 }, {    -31,   48,  -17,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E1863, {
    {      0,   16,   15, 16,  6,  0 }, {      1,   16,   15, 16,  6,  0 }, {      2,   16,   15, 16,  6,  0 }, {      3,   16,   14, 16,  6,  0 }, {      4,   16,   14, 16,  6,  0 },
    {      5,   16,   13, 15,  6,  0 }, {      6,   16,   13, 15,  6,  0 }, {      7,   17,   13, 15,  6,  0 }, {      8,   17,   12, 15,  6,  0 }, {      9,   17,   12, 15,  6,  0 },
    {     10,   17,   11, 15,  6,  0 }, {     11,   17,   11, 15,  6,  0 }, {     12,   17,   10, 15,  6,  0 }, {     13,   18,   10, 15,  6,  0 }, {     14,   18,    9, 14,  6,  0 },
    {     15,   18,    9, 14,  6,  0 }, {     16,   19,    9, 14,  6,  0 }, {     17,   19,    8, 14,  6,  0 }, {     18,   19,    8, 14,  6,  0 }, {     19,   20,    7, 14,  6,  0 },
    {     20,   20,    7, 14,  6,  0 }, {     21,   21,    6, 14,  6,  0 }, {     22,   21,    6, 14,  6,  0 }, {     23,   22,    5, 14,  6,  0 }, {     24,   22,    5, 13,  6,  0 },
    {     25,   23,    4, 13,  6,  0 }, {     26,   23,    4, 13,  6,  0 }, {     27,   24,    3, 13,  6,  0 }, {     28,   25,    3, 13,  6,  0 }, {     29,   25,    2, 13,  6,  0 },
    {     30,   26,    2, 13,  6,  0 }, {     31,   27,    1, 13,  6,  0 }, {     32,   28,    1, 13,  6,  0 }, {     33,   29,    0, 12,  6,  0 }, {     35,   29,   -1, 12,  6,  0 },
    {     36,   30,   -1, 12,  6,  0 }, {     37,   31,   -1, 12,  6,  0 }, {     38,   32,   -2, 12,  6,  0 }, {     39,   33,   -3, 11,  6,  0 }, {     39,   34,   -3, 11,  6,  0 },
    {     40,   35,   -4, 11,  6,  0 }, {     41,   36,   -4, 11,  6,  0 }, {     41,   37,   -5, 11,  6,  0 }, {     42,   38,   -5, 11,  6,  0 }, {     42,   39,   -6, 11,  6,  0 },
    {     43,   40,   -6, 11,  6,  0 }, {     43,   41,   -7, 11,  6,  0 }, {     44,   42,   -7, 10,  6,  0 }, {     44,   43,   -8, 10,  6,  0 }, {     45,   44,   -8, 10,  6,  0 },
    {     45,   45,   -9, 10,  6,  0 }, {     45,   46,   -9, 10,  6,  0 }, {     46,   47,   -9, 10,  6,  0 }, {     46,   48,  -10, 10,  6,  0 }, {     46,   49,  -10, 10,  6,  0 },
    {     47,   50,  -11, 10,  6,  0 }, {     47,   51,  -11, 10,  6,  0 }, {     47,   52,  -12,  9,  6,  0 }, {     47,   53,  -12,  9,  6,  0 }, {     47,   54,  -13,  9,  6,  0 },
    {     47,   55,  -13,  9,  6,  0 }, {     48,   56,  -13,  9,  6,  0 }, {     48,   57,  -14,  9,  6,  0 }, {     48,   58,  -14,  9,  6,  0 }, {     48,   59,  -15,  9,  6,  0 },
    {     48,   60,  -15,  8,  6,  0 }, {     48,   61,  -16,  8,  6,  0 }, {     48,   62,  -16,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E1AC9, {
    {     16,   31,   15, 24,  6,  0 }, {     16,   30,   15, 24,  6,  0 }, {     16,   29,   14, 24,  6,  0 }, {     16,   28,   14, 24,  6,  0 }, {     16,   27,   13, 23,  6,  0 },
    {     16,   26,   13, 23,  6,  0 }, {     17,   25,   13, 23,  6,  0 }, {     17,   24,   12, 23,  6,  0 }, {     17,   23,   12, 23,  6,  0 }, {     17,   22,   11, 23,  6,  0 },
    {     17,   21,   11, 23,  6,  0 }, {     17,   20,   10, 23,  6,  0 }, {     18,   19,   10, 23,  6,  0 }, {     18,   18,    9, 22,  6,  0 }, {     18,   17,    9, 22,  6,  0 },
    {     19,   16,    9, 22,  6,  0 }, {     19,   15,    8, 22,  6,  0 }, {     19,   14,    8, 22,  6,  0 }, {     20,   13,    7, 22,  6,  0 }, {     20,   12,    7, 22,  6,  0 },
    {     21,   11,    6, 22,  6,  0 }, {     21,   10,    6, 22,  6,  0 }, {     22,    9,    5, 22,  6,  0 }, {     22,    8,    5, 21,  6,  0 }, {     23,    7,    4, 21,  6,  0 },
    {     23,    6,    4, 21,  6,  0 }, {     24,    5,    3, 21,  6,  0 }, {     25,    4,    3, 21,  6,  0 }, {     25,    3,    2, 21,  6,  0 }, {     26,    2,    2, 21,  6,  0 },
    {     27,    1,    1, 21,  6,  0 }, {     28,    0,    1, 21,  6,  0 }, {     29,   -1,    0, 20,  6,  0 }, {     29,   -3,   -1, 20,  6,  0 }, {     30,   -4,   -1, 20,  6,  0 },
    {     31,   -5,   -1, 20,  6,  0 }, {     32,   -6,   -2, 20,  6,  0 }, {     33,   -7,   -3, 19,  6,  0 }, {     34,   -7,   -3, 19,  6,  0 }, {     35,   -8,   -4, 19,  6,  0 },
    {     36,   -9,   -4, 19,  6,  0 }, {     37,   -9,   -5, 19,  6,  0 }, {     38,  -10,   -5, 19,  6,  0 }, {     39,  -10,   -6, 19,  6,  0 }, {     40,  -11,   -6, 19,  6,  0 },
    {     41,  -11,   -7, 19,  6,  0 }, {     42,  -12,   -7, 18,  6,  0 }, {     43,  -12,   -8, 18,  6,  0 }, {     44,  -13,   -8, 18,  6,  0 }, {     45,  -13,   -9, 18,  6,  0 },
    {     46,  -13,   -9, 18,  6,  0 }, {     47,  -14,   -9, 18,  6,  0 }, {     48,  -14,  -10, 18,  6,  0 }, {     49,  -14,  -10, 18,  6,  0 }, {     50,  -15,  -11, 18,  6,  0 },
    {     51,  -15,  -11, 18,  6,  0 }, {     52,  -15,  -12, 17,  6,  0 }, {     53,  -15,  -12, 17,  6,  0 }, {     54,  -15,  -13, 17,  6,  0 }, {     55,  -15,  -13, 17,  6,  0 },
    {     56,  -16,  -13, 17,  6,  0 }, {     57,  -16,  -14, 17,  6,  0 }, {     58,  -16,  -14, 17,  6,  0 }, {     59,  -16,  -15, 17,  6,  0 }, {     60,  -16,  -15, 16,  6,  0 },
    {     61,  -16,  -16, 16,  6,  0 }, {     62,  -16,  -16, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E1D26, {
    {     31,   16,   15,  0,  6,  0 }, {     30,   16,   15,  0,  6,  0 }, {     29,   16,   14,  0,  6,  0 }, {     28,   16,   14,  0,  6,  0 }, {     27,   16,   13,  1,  6,  0 },
    {     26,   16,   13,  1,  6,  0 }, {     25,   17,   13,  1,  6,  0 }, {     24,   17,   12,  1,  6,  0 }, {     23,   17,   12,  1,  6,  0 }, {     22,   17,   11,  1,  6,  0 },
    {     21,   17,   11,  1,  6,  0 }, {     20,   17,   10,  1,  6,  0 }, {     19,   18,   10,  1,  6,  0 }, {     18,   18,    9,  2,  6,  0 }, {     17,   18,    9,  2,  6,  0 },
    {     16,   19,    9,  2,  6,  0 }, {     15,   19,    8,  2,  6,  0 }, {     14,   19,    8,  2,  6,  0 }, {     13,   20,    7,  2,  6,  0 }, {     12,   20,    7,  2,  6,  0 },
    {     11,   21,    6,  2,  6,  0 }, {     10,   21,    6,  2,  6,  0 }, {      9,   22,    5,  2,  6,  0 }, {      8,   22,    5,  3,  6,  0 }, {      7,   23,    4,  3,  6,  0 },
    {      6,   23,    4,  3,  6,  0 }, {      5,   24,    3,  3,  6,  0 }, {      4,   25,    3,  3,  6,  0 }, {      3,   25,    2,  3,  6,  0 }, {      2,   26,    2,  3,  6,  0 },
    {      1,   27,    1,  3,  6,  0 }, {      0,   28,    1,  3,  6,  0 }, {     -1,   29,    0,  4,  6,  0 }, {     -3,   29,   -1,  4,  6,  0 }, {     -4,   30,   -1,  4,  6,  0 },
    {     -5,   31,   -1,  4,  6,  0 }, {     -6,   32,   -2,  4,  6,  0 }, {     -7,   33,   -3,  5,  6,  0 }, {     -7,   34,   -3,  5,  6,  0 }, {     -8,   35,   -4,  5,  6,  0 },
    {     -9,   36,   -4,  5,  6,  0 }, {     -9,   37,   -5,  5,  6,  0 }, {    -10,   38,   -5,  5,  6,  0 }, {    -10,   39,   -6,  5,  6,  0 }, {    -11,   40,   -6,  5,  6,  0 },
    {    -11,   41,   -7,  5,  6,  0 }, {    -12,   42,   -7,  6,  6,  0 }, {    -12,   43,   -8,  6,  6,  0 }, {    -13,   44,   -8,  6,  6,  0 }, {    -13,   45,   -9,  6,  6,  0 },
    {    -13,   46,   -9,  6,  6,  0 }, {    -14,   47,   -9,  6,  6,  0 }, {    -14,   48,  -10,  6,  6,  0 }, {    -14,   49,  -10,  6,  6,  0 }, {    -15,   50,  -11,  6,  6,  0 },
    {    -15,   51,  -11,  6,  6,  0 }, {    -15,   52,  -12,  7,  6,  0 }, {    -15,   53,  -12,  7,  6,  0 }, {    -15,   54,  -13,  7,  6,  0 }, {    -15,   55,  -13,  7,  6,  0 },
    {    -16,   56,  -13,  7,  6,  0 }, {    -16,   57,  -14,  7,  6,  0 }, {    -16,   58,  -14,  7,  6,  0 }, {    -16,   59,  -15,  7,  6,  0 }, {    -16,   60,  -15,  8,  6,  0 },
    {    -16,   61,  -16,  8,  6,  0 }, {    -16,   62,  -16,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E1F83, {
    {     16,    0,   15,  8,  6,  0 }, {     16,    1,   15,  8,  6,  0 }, {     16,    2,   15,  8,  6,  0 }, {     16,    3,   14,  8,  6,  0 }, {     16,    4,   14,  8,  6,  0 },
    {     16,    5,   13,  9,  6,  0 }, {     16,    6,   13,  9,  6,  0 }, {     17,    7,   13,  9,  6,  0 }, {     17,    8,   12,  9,  6,  0 }, {     17,    9,   12,  9,  6,  0 },
    {     17,   10,   11,  9,  6,  0 }, {     17,   11,   11,  9,  6,  0 }, {     17,   12,   10,  9,  6,  0 }, {     18,   13,   10,  9,  6,  0 }, {     18,   14,    9, 10,  6,  0 },
    {     18,   15,    9, 10,  6,  0 }, {     19,   16,    9, 10,  6,  0 }, {     19,   17,    8, 10,  6,  0 }, {     19,   18,    8, 10,  6,  0 }, {     20,   19,    7, 10,  6,  0 },
    {     20,   20,    7, 10,  6,  0 }, {     21,   21,    6, 10,  6,  0 }, {     21,   22,    6, 10,  6,  0 }, {     22,   23,    5, 10,  6,  0 }, {     22,   24,    5, 11,  6,  0 },
    {     23,   25,    4, 11,  6,  0 }, {     23,   26,    4, 11,  6,  0 }, {     24,   27,    3, 11,  6,  0 }, {     25,   28,    3, 11,  6,  0 }, {     25,   29,    2, 11,  6,  0 },
    {     26,   30,    2, 11,  6,  0 }, {     27,   31,    1, 11,  6,  0 }, {     28,   32,    1, 11,  6,  0 }, {     29,   33,    0, 12,  6,  0 }, {     29,   35,   -1, 12,  6,  0 },
    {     30,   36,   -1, 12,  6,  0 }, {     31,   37,   -1, 12,  6,  0 }, {     32,   38,   -2, 12,  6,  0 }, {     33,   39,   -3, 13,  6,  0 }, {     34,   39,   -3, 13,  6,  0 },
    {     35,   40,   -4, 13,  6,  0 }, {     36,   41,   -4, 13,  6,  0 }, {     37,   41,   -5, 13,  6,  0 }, {     38,   42,   -5, 13,  6,  0 }, {     39,   42,   -6, 13,  6,  0 },
    {     40,   43,   -6, 13,  6,  0 }, {     41,   43,   -7, 13,  6,  0 }, {     42,   44,   -7, 14,  6,  0 }, {     43,   44,   -8, 14,  6,  0 }, {     44,   45,   -8, 14,  6,  0 },
    {     45,   45,   -9, 14,  6,  0 }, {     46,   45,   -9, 14,  6,  0 }, {     47,   46,   -9, 14,  6,  0 }, {     48,   46,  -10, 14,  6,  0 }, {     49,   46,  -10, 14,  6,  0 },
    {     50,   47,  -11, 14,  6,  0 }, {     51,   47,  -11, 14,  6,  0 }, {     52,   47,  -12, 15,  6,  0 }, {     53,   47,  -12, 15,  6,  0 }, {     54,   47,  -13, 15,  6,  0 },
    {     55,   47,  -13, 15,  6,  0 }, {     56,   48,  -13, 15,  6,  0 }, {     57,   48,  -14, 15,  6,  0 }, {     58,   48,  -14, 15,  6,  0 }, {     59,   48,  -15, 15,  6,  0 },
    {     60,   48,  -15, 16,  6,  0 }, {     61,   48,  -16, 16,  6,  0 }, {     62,   48,  -16, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E21E9, {
    {      0,   16,   15, 16,  6,  0 }, {      1,   16,   15, 16,  6,  0 }, {      2,   16,   15, 16,  6,  0 }, {      3,   16,   14, 16,  6,  0 }, {      4,   16,   14, 16,  6,  0 },
    {      5,   16,   13, 17,  6,  0 }, {      6,   16,   13, 17,  6,  0 }, {      7,   15,   13, 17,  6,  0 }, {      8,   15,   12, 17,  6,  0 }, {      9,   15,   12, 17,  6,  0 },
    {     10,   15,   11, 17,  6,  0 }, {     11,   15,   11, 17,  6,  0 }, {     12,   15,   11, 17,  6,  0 }, {     13,   14,   10, 17,  6,  0 }, {     14,   14,   10, 18,  6,  0 },
    {     15,   14,    9, 18,  6,  0 }, {     16,   13,    9, 18,  6,  0 }, {     17,   13,    8, 18,  6,  0 }, {     18,   13,    8, 18,  6,  0 }, {     19,   12,    7, 18,  6,  0 },
    {     20,   12,    7, 18,  6,  0 }, {     21,   11,    6, 18,  6,  0 }, {     22,   11,    6, 18,  6,  0 }, {     23,   10,    5, 18,  6,  0 }, {     24,   10,    5, 19,  6,  0 },
    {     25,    9,    4, 19,  6,  0 }, {     26,    9,    4, 19,  6,  0 }, {     27,    8,    4, 19,  6,  0 }, {     28,    7,    3, 19,  6,  0 }, {     29,    7,    2, 19,  6,  0 },
    {     30,    6,    2, 19,  6,  0 }, {     31,    5,    1, 19,  6,  0 }, {     32,    4,    1, 19,  6,  0 }, {     33,    3,    0, 20,  6,  0 }, {     35,    3,    0, 20,  6,  0 },
    {     36,    2,   -1, 20,  6,  0 }, {     37,    1,   -1, 20,  6,  0 }, {     38,    0,   -2, 20,  6,  0 }, {     39,   -1,   -2, 21,  6,  0 }, {     39,   -2,   -3, 21,  6,  0 },
    {     40,   -3,   -3, 21,  6,  0 }, {     41,   -4,   -4, 21,  6,  0 }, {     41,   -5,   -4, 21,  6,  0 }, {     42,   -6,   -5, 21,  6,  0 }, {     42,   -7,   -5, 21,  6,  0 },
    {     43,   -8,   -6, 21,  6,  0 }, {     43,   -9,   -6, 21,  6,  0 }, {     44,  -10,   -7, 22,  6,  0 }, {     44,  -11,   -7, 22,  6,  0 }, {     45,  -12,   -8, 22,  6,  0 },
    {     45,  -13,   -8, 22,  6,  0 }, {     45,  -14,   -9, 22,  6,  0 }, {     46,  -15,   -9, 22,  6,  0 }, {     46,  -16,  -10, 22,  6,  0 }, {     46,  -17,  -10, 22,  6,  0 },
    {     47,  -18,  -10, 22,  6,  0 }, {     47,  -19,  -11, 22,  6,  0 }, {     47,  -20,  -11, 23,  6,  0 }, {     47,  -21,  -12, 23,  6,  0 }, {     47,  -22,  -12, 23,  6,  0 },
    {     47,  -23,  -13, 23,  6,  0 }, {     48,  -24,  -13, 23,  6,  0 }, {     48,  -25,  -14, 23,  6,  0 }, {     48,  -26,  -14, 23,  6,  0 }, {     48,  -27,  -14, 23,  6,  0 },
    {     48,  -28,  -15, 24,  6,  0 }, {     48,  -29,  -15, 24,  6,  0 }, {     48,  -30,  -16, 24,  6,  0 }, {     48,  -31,  -16, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E2458, {
    {     16,   31,   15, 24,  6,  0 }, {     16,   30,   15, 24,  6,  0 }, {     16,   29,   14, 24,  6,  0 }, {     16,   28,   14, 24,  6,  0 }, {     16,   27,   13, 25,  6,  0 },
    {     16,   26,   13, 25,  6,  0 }, {     15,   25,   13, 25,  6,  0 }, {     15,   24,   12, 25,  6,  0 }, {     15,   23,   12, 25,  6,  0 }, {     15,   22,   11, 25,  6,  0 },
    {     15,   21,   11, 25,  6,  0 }, {     15,   20,   11, 25,  6,  0 }, {     14,   19,   10, 25,  6,  0 }, {     14,   18,   10, 26,  6,  0 }, {     14,   17,    9, 26,  6,  0 },
    {     13,   16,    9, 26,  6,  0 }, {     13,   15,    8, 26,  6,  0 }, {     13,   14,    8, 26,  6,  0 }, {     12,   13,    7, 26,  6,  0 }, {     12,   12,    7, 26,  6,  0 },
    {     11,   11,    6, 26,  6,  0 }, {     11,   10,    6, 26,  6,  0 }, {     10,    9,    5, 26,  6,  0 }, {     10,    8,    5, 27,  6,  0 }, {      9,    7,    4, 27,  6,  0 },
    {      9,    6,    4, 27,  6,  0 }, {      8,    5,    4, 27,  6,  0 }, {      7,    4,    3, 27,  6,  0 }, {      7,    3,    2, 27,  6,  0 }, {      6,    2,    2, 27,  6,  0 },
    {      5,    1,    1, 27,  6,  0 }, {      4,    0,    1, 27,  6,  0 }, {      3,   -1,    0, 28,  6,  0 }, {      3,   -3,    0, 28,  6,  0 }, {      2,   -4,   -1, 28,  6,  0 },
    {      1,   -5,   -1, 28,  6,  0 }, {      0,   -6,   -2, 28,  6,  0 }, {     -1,   -7,   -2, 29,  6,  0 }, {     -2,   -7,   -3, 29,  6,  0 }, {     -3,   -8,   -3, 29,  6,  0 },
    {     -4,   -9,   -4, 29,  6,  0 }, {     -5,   -9,   -4, 29,  6,  0 }, {     -6,  -10,   -5, 29,  6,  0 }, {     -7,  -10,   -5, 29,  6,  0 }, {     -8,  -11,   -6, 29,  6,  0 },
    {     -9,  -11,   -6, 29,  6,  0 }, {    -10,  -12,   -7, 30,  6,  0 }, {    -11,  -12,   -7, 30,  6,  0 }, {    -12,  -13,   -8, 30,  6,  0 }, {    -13,  -13,   -8, 30,  6,  0 },
    {    -14,  -13,   -9, 30,  6,  0 }, {    -15,  -14,   -9, 30,  6,  0 }, {    -16,  -14,  -10, 30,  6,  0 }, {    -17,  -14,  -10, 30,  6,  0 }, {    -18,  -15,  -10, 30,  6,  0 },
    {    -19,  -15,  -11, 30,  6,  0 }, {    -20,  -15,  -11, 31,  6,  0 }, {    -21,  -15,  -12, 31,  6,  0 }, {    -22,  -15,  -12, 31,  6,  0 }, {    -23,  -15,  -13, 31,  6,  0 },
    {    -24,  -16,  -13, 31,  6,  0 }, {    -25,  -16,  -14, 31,  6,  0 }, {    -26,  -16,  -14, 31,  6,  0 }, {    -27,  -16,  -14, 31,  6,  0 }, {    -28,  -16,  -15,  0,  6,  0 },
    {    -29,  -16,  -15,  0,  6,  0 }, {    -30,  -16,  -16,  0,  6,  0 }, {    -31,  -16,  -16,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E39EE, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0, 31,  0,  0 }, {     28,   15,    0, 31,  0,  0 }, {     27,   15,    0, 30,  0,  0 },
    {     26,   15,    0, 30,  0,  0 }, {     25,   14,    0, 30,  0,  0 }, {     24,   14,    0, 29,  0,  0 }, {     23,   13,    0, 29,  0,  0 }, {     22,   12,    0, 28,  0,  0 },
    {     21,   11,    0, 28,  0,  0 }, {     20,   10,    0, 28,  0,  0 }, {     19,    9,    0, 27,  0,  0 }, {     18,    8,    0, 27,  0,  0 }, {     18,    7,    0, 26,  0,  0 },
    {     17,    6,    0, 26,  0,  0 }, {     17,    5,    0, 26,  0,  0 }, {     17,    4,    0, 25,  0,  0 }, {     16,    3,    0, 25,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E3AB6, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  7,  0,  0 }, {     15,    4,    0,  7,  0,  0 },
    {     15,    5,    0,  6,  0,  0 }, {     15,    6,    0,  6,  0,  0 }, {     14,    7,    0,  6,  0,  0 }, {     14,    8,    0,  5,  0,  0 }, {     13,    9,    0,  5,  0,  0 },
    {     12,   10,    0,  4,  0,  0 }, {     11,   11,    0,  4,  0,  0 }, {     10,   12,    0,  4,  0,  0 }, {      9,   13,    0,  3,  0,  0 }, {      8,   14,    0,  3,  0,  0 },
    {      7,   14,    0,  2,  0,  0 }, {      6,   15,    0,  2,  0,  0 }, {      5,   15,    0,  2,  0,  0 }, {      4,   15,    0,  1,  0,  0 }, {      3,   16,    0,  1,  0,  0 },
    {      2,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E3B87, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 15,  0,  0 }, {      4,   17,    0, 15,  0,  0 },
    {      5,   17,    0, 14,  0,  0 }, {      6,   17,    0, 14,  0,  0 }, {      7,   18,    0, 14,  0,  0 }, {      8,   18,    0, 13,  0,  0 }, {      9,   19,    0, 13,  0,  0 },
    {     10,   20,    0, 12,  0,  0 }, {     11,   21,    0, 12,  0,  0 }, {     12,   22,    0, 12,  0,  0 }, {     13,   23,    0, 11,  0,  0 }, {     14,   24,    0, 11,  0,  0 },
    {     14,   25,    0, 10,  0,  0 }, {     15,   26,    0, 10,  0,  0 }, {     15,   27,    0, 10,  0,  0 }, {     15,   28,    0,  9,  0,  0 }, {     16,   29,    0,  9,  0,  0 },
    {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E3C4F, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 23,  0,  0 }, {     17,   28,    0, 23,  0,  0 }, {     17,   27,    0, 22,  0,  0 },
    {     17,   26,    0, 22,  0,  0 }, {     18,   25,    0, 22,  0,  0 }, {     18,   24,    0, 21,  0,  0 }, {     19,   23,    0, 21,  0,  0 }, {     20,   22,    0, 20,  0,  0 },
    {     21,   21,    0, 20,  0,  0 }, {     22,   20,    0, 20,  0,  0 }, {     23,   19,    0, 19,  0,  0 }, {     24,   18,    0, 19,  0,  0 }, {     25,   18,    0, 18,  0,  0 },
    {     26,   17,    0, 18,  0,  0 }, {     27,   17,    0, 18,  0,  0 }, {     28,   17,    0, 17,  0,  0 }, {     29,   16,    0, 17,  0,  0 }, {     30,   16,    0, 16,  0,  0 },
    {     31,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E3D0E, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  1,  0,  0 }, {     28,   17,    0,  1,  0,  0 }, {     27,   17,    0,  2,  0,  0 },
    {     26,   17,    0,  2,  0,  0 }, {     25,   18,    0,  2,  0,  0 }, {     24,   18,    0,  3,  0,  0 }, {     23,   19,    0,  3,  0,  0 }, {     22,   20,    0,  4,  0,  0 },
    {     21,   21,    0,  4,  0,  0 }, {     20,   22,    0,  4,  0,  0 }, {     19,   23,    0,  5,  0,  0 }, {     18,   24,    0,  5,  0,  0 }, {     18,   25,    0,  6,  0,  0 },
    {     17,   26,    0,  6,  0,  0 }, {     17,   27,    0,  6,  0,  0 }, {     17,   28,    0,  7,  0,  0 }, {     16,   29,    0,  7,  0,  0 }, {     16,   30,    0,  8,  0,  0 },
    {     16,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E3DCD, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  9,  0,  0 }, {     17,    4,    0,  9,  0,  0 },
    {     17,    5,    0, 10,  0,  0 }, {     17,    6,    0, 10,  0,  0 }, {     18,    7,    0, 10,  0,  0 }, {     18,    8,    0, 11,  0,  0 }, {     19,    9,    0, 11,  0,  0 },
    {     20,   10,    0, 12,  0,  0 }, {     21,   11,    0, 12,  0,  0 }, {     22,   12,    0, 12,  0,  0 }, {     23,   13,    0, 13,  0,  0 }, {     24,   14,    0, 13,  0,  0 },
    {     25,   14,    0, 14,  0,  0 }, {     26,   15,    0, 14,  0,  0 }, {     27,   15,    0, 14,  0,  0 }, {     28,   15,    0, 15,  0,  0 }, {     29,   16,    0, 15,  0,  0 },
    {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E3E95, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 17,  0,  0 }, {      4,   15,    0, 17,  0,  0 },
    {      5,   15,    0, 18,  0,  0 }, {      6,   15,    0, 18,  0,  0 }, {      7,   14,    0, 18,  0,  0 }, {      8,   14,    0, 19,  0,  0 }, {      9,   13,    0, 19,  0,  0 },
    {     10,   12,    0, 20,  0,  0 }, {     11,   11,    0, 20,  0,  0 }, {     12,   10,    0, 20,  0,  0 }, {     13,    9,    0, 21,  0,  0 }, {     14,    8,    0, 21,  0,  0 },
    {     14,    7,    0, 22,  0,  0 }, {     15,    6,    0, 22,  0,  0 }, {     15,    5,    0, 22,  0,  0 }, {     15,    4,    0, 23,  0,  0 }, {     16,    3,    0, 23,  0,  0 },
    {     16,    2,    0, 24,  0,  0 }, {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E3F66, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 25,  0,  0 }, {     15,   28,    0, 25,  0,  0 }, {     15,   27,    0, 26,  0,  0 },
    {     15,   26,    0, 26,  0,  0 }, {     14,   25,    0, 26,  0,  0 }, {     14,   24,    0, 27,  0,  0 }, {     13,   23,    0, 27,  0,  0 }, {     12,   22,    0, 28,  0,  0 },
    {     11,   21,    0, 28,  0,  0 }, {     10,   20,    0, 28,  0,  0 }, {      9,   19,    0, 29,  0,  0 }, {      8,   18,    0, 29,  0,  0 }, {      7,   18,    0, 30,  0,  0 },
    {      6,   17,    0, 30,  0,  0 }, {      5,   17,    0, 30,  0,  0 }, {      4,   17,    0, 31,  0,  0 }, {      3,   16,    0, 31,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D9BFE, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  1 }, {     25,   16,    0,  0,  0,  1 }, {     24,   16,    0,  0,  0,  1 }, {     23,   16,    0,  0,  0,  1 }, {     22,   16,    0,  0,  0,  1 },
    {     21,   16,    0,  0,  0,  1 }, {     20,   16,    0,  0,  0,  1 }, {     19,   16,    0,  0,  0,  1 }, {     18,   16,    0,  0,  0,  1 }, {     17,   16,    0,  0,  0,  1 },
    {     16,   16,    0,  0,  0,  1 }, {     15,   16,    0,  0,  0,  1 }, {     14,   16,    0,  0,  0,  1 }, {     13,   16,    0,  0,  0,  2 }, {     12,   16,    0,  0,  0,  2 },
    {     11,   16,    0,  0,  0,  2 }, {     10,   16,    0,  0,  0,  2 }, {      9,   16,    0,  0,  0,  2 }, {      8,   16,    0,  0,  0,  2 }, {      7,   16,    0,  0,  0,  2 },
    {      6,   16,    0,  0,  0,  2 }, {      5,   16,    0,  0,  0,  2 }, {      4,   16,    0,  0,  0,  2 }, {      3,   16,    0,  0,  0,  2 }, {      2,   16,    0,  0,  0,  5 },
    {      1,   16,    0,  0,  0,  5 }, {      0,   16,    0,  0,  0,  5 }, {     -1,   16,    0,  0,  0,  5 }, {     -2,   16,    0,  0,  0,  5 }, {     -3,   16,    0,  0,  0,  5 },
    {     -4,   16,    0,  0,  0,  5 }, {     -5,   16,    0,  0,  0,  5 }, {     -6,   16,    0,  0,  0,  5 }, {     -7,   16,    0,  0,  0,  5 }, {     -8,   16,    0,  0,  0,  5 },
    {     -9,   16,    0,  0,  0,  5 }, {    -10,   16,    0,  0,  0,  5 }, {    -11,   16,    0,  0,  0,  6 }, {    -12,   16,    0,  0,  0,  6 }, {    -13,   16,    0,  0,  0,  6 },
    {    -14,   16,    0,  0,  0,  6 }, {    -15,   16,    0,  0,  0,  6 }, {    -16,   16,    0,  0,  0,  6 }, {    -17,   16,    0,  0,  0,  6 }, {    -18,   16,    0,  0,  0,  6 },
    {    -19,   16,    0,  0,  0,  6 }, {    -20,   16,    0,  0,  0,  6 }, {    -21,   16,    0,  0,  0,  6 }, {    -22,   16,    0,  0,  0,  7 }, {    -23,   16,    0,  0,  0,  7 },
    {    -24,   16,    0,  0,  0,  7 }, {    -25,   16,    0,  0,  0,  7 }, {    -26,   16,    0,  0,  0,  7 }, {    -27,   16,    0,  0,  0,  7 }, {    -28,   16,    0,  0,  0,  7 },
    {    -29,   16,    0,  0,  0,  7 }, {    -30,   16,    0,  0,  0,  7 }, {    -31,   16,    0,  0,  0,  7 }, {    -32,   16,    0,  0,  0,  7 }, {    -33,   16,    0,  0,  0,  7 },
    {    -34,   16,    0,  0,  0,  7 }, {    -35,   16,    0,  0,  0,  8 }, {    -36,   16,    0,  0,  0,  8 }, {    -37,   16,    0,  0,  0,  8 }, {    -38,   16,    0,  0,  0,  8 },
    {    -39,   16,    0,  0,  0,  8 }, {    -40,   16,    0,  0,  0,  8 }, {    -41,   16,    0,  0,  0,  8 }, {    -42,   16,    0,  0,  0,  8 }, {    -43,   16,    0,  0,  0,  8 },
    {    -44,   16,    0,  0,  0,  8 }, {    -45,   16,    0,  0,  0,  8 }, {    -46,   16,    0,  0,  0,  9 }, {    -47,   16,    0,  0,  0,  9 }, {    -48,   16,    0,  0,  0,  9 },
    {    -49,   16,    0,  0,  0,  9 }, {    -50,   16,    0,  0,  0,  9 }, {    -51,   16,    0,  0,  0,  9 }, {    -52,   16,    0,  0,  0,  9 }, {    -53,   16,    0,  0,  0,  9 },
    {    -54,   16,    0,  0,  0,  9 }, {    -55,   16,    0,  0,  0,  9 }, {    -56,   16,    0,  0,  0,  9 }, {    -57,   16,    0,  0,  0,  9 }, {    -58,   16,    0,  0,  0,  9 },
    {    -59,   16,    0, 16, 16,  0 }, {    -60,   16,    0, 16, 16,  0 }, {    -61,   16,    0, 16, 16,  0 }, {    -62,   16,    0, 16, 16,  0 }, {    -63,   16,    0, 16, 16,  0 },
    {    -64,   16,    0, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D9F60, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  1 }, {     16,    6,    0,  8,  0,  1 }, {     16,    7,    0,  8,  0,  1 }, {     16,    8,    0,  8,  0,  1 }, {     16,    9,    0,  8,  0,  1 },
    {     16,   10,    0,  8,  0,  1 }, {     16,   11,    0,  8,  0,  1 }, {     16,   12,    0,  8,  0,  1 }, {     16,   13,    0,  8,  0,  1 }, {     16,   14,    0,  8,  0,  1 },
    {     16,   15,    0,  8,  0,  1 }, {     16,   16,    0,  8,  0,  1 }, {     16,   17,    0,  8,  0,  1 }, {     16,   18,    0,  8,  0,  2 }, {     16,   19,    0,  8,  0,  2 },
    {     16,   20,    0,  8,  0,  2 }, {     16,   21,    0,  8,  0,  2 }, {     16,   22,    0,  8,  0,  2 }, {     16,   23,    0,  8,  0,  2 }, {     16,   24,    0,  8,  0,  2 },
    {     16,   25,    0,  8,  0,  2 }, {     16,   26,    0,  8,  0,  2 }, {     16,   27,    0,  8,  0,  2 }, {     16,   28,    0,  8,  0,  2 }, {     16,   29,    0,  8,  0,  5 },
    {     16,   30,    0,  8,  0,  5 }, {     16,   31,    0,  8,  0,  5 }, {     16,   32,    0,  8,  0,  5 }, {     16,   33,    0,  8,  0,  5 }, {     16,   34,    0,  8,  0,  5 },
    {     16,   35,    0,  8,  0,  5 }, {     16,   36,    0,  8,  0,  5 }, {     16,   37,    0,  8,  0,  5 }, {     16,   38,    0,  8,  0,  5 }, {     16,   39,    0,  8,  0,  5 },
    {     16,   40,    0,  8,  0,  5 }, {     16,   41,    0,  8,  0,  5 }, {     16,   42,    0,  8,  0,  6 }, {     16,   43,    0,  8,  0,  6 }, {     16,   44,    0,  8,  0,  6 },
    {     16,   45,    0,  8,  0,  6 }, {     16,   46,    0,  8,  0,  6 }, {     16,   47,    0,  8,  0,  6 }, {     16,   48,    0,  8,  0,  6 }, {     16,   49,    0,  8,  0,  6 },
    {     16,   50,    0,  8,  0,  6 }, {     16,   51,    0,  8,  0,  6 }, {     16,   52,    0,  8,  0,  6 }, {     16,   53,    0,  8,  0,  7 }, {     16,   54,    0,  8,  0,  7 },
    {     16,   55,    0,  8,  0,  7 }, {     16,   56,    0,  8,  0,  7 }, {     16,   57,    0,  8,  0,  7 }, {     16,   58,    0,  8,  0,  7 }, {     16,   59,    0,  8,  0,  7 },
    {     16,   60,    0,  8,  0,  7 }, {     16,   61,    0,  8,  0,  7 }, {     16,   62,    0,  8,  0,  7 }, {     16,   63,    0,  8,  0,  7 }, {     16,   64,    0,  8,  0,  7 },
    {     16,   65,    0,  8,  0,  7 }, {     16,   66,    0,  8,  0,  8 }, {     16,   67,    0,  8,  0,  8 }, {     16,   68,    0,  8,  0,  8 }, {     16,   69,    0,  8,  0,  8 },
    {     16,   70,    0,  8,  0,  8 }, {     16,   71,    0,  8,  0,  8 }, {     16,   72,    0,  8,  0,  8 }, {     16,   73,    0,  8,  0,  8 }, {     16,   74,    0,  8,  0,  8 },
    {     16,   75,    0,  8,  0,  8 }, {     16,   76,    0,  8,  0,  8 }, {     16,   77,    0,  8,  0,  9 }, {     16,   78,    0,  8,  0,  9 }, {     16,   79,    0,  8,  0,  9 },
    {     16,   80,    0,  8,  0,  9 }, {     16,   81,    0,  8,  0,  9 }, {     16,   82,    0,  8,  0,  9 }, {     16,   83,    0,  8,  0,  9 }, {     16,   84,    0,  8,  0,  9 },
    {     16,   85,    0,  8,  0,  9 }, {     16,   86,    0,  8,  0,  9 }, {     16,   87,    0,  8,  0,  9 }, {     16,   88,    0,  8,  0,  9 }, {     16,   89,    0,  8,  0,  9 },
    {     16,   90,    0, 24, 16,  0 }, {     16,   91,    0, 24, 16,  0 }, {     16,   92,    0, 24, 16,  0 }, {     16,   93,    0, 24, 16,  0 }, {     16,   94,    0, 24, 16,  0 },
    {     16,   95,    0, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DA2C2, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  1 }, {      6,   16,    0, 16,  0,  1 }, {      7,   16,    0, 16,  0,  1 }, {      8,   16,    0, 16,  0,  1 }, {      9,   16,    0, 16,  0,  1 },
    {     10,   16,    0, 16,  0,  1 }, {     11,   16,    0, 16,  0,  1 }, {     12,   16,    0, 16,  0,  1 }, {     13,   16,    0, 16,  0,  1 }, {     14,   16,    0, 16,  0,  1 },
    {     15,   16,    0, 16,  0,  1 }, {     16,   16,    0, 16,  0,  1 }, {     17,   16,    0, 16,  0,  1 }, {     18,   16,    0, 16,  0,  2 }, {     19,   16,    0, 16,  0,  2 },
    {     20,   16,    0, 16,  0,  2 }, {     21,   16,    0, 16,  0,  2 }, {     22,   16,    0, 16,  0,  2 }, {     23,   16,    0, 16,  0,  2 }, {     24,   16,    0, 16,  0,  2 },
    {     25,   16,    0, 16,  0,  2 }, {     26,   16,    0, 16,  0,  2 }, {     27,   16,    0, 16,  0,  2 }, {     28,   16,    0, 16,  0,  2 }, {     29,   16,    0, 16,  0,  5 },
    {     30,   16,    0, 16,  0,  5 }, {     31,   16,    0, 16,  0,  5 }, {     32,   16,    0, 16,  0,  5 }, {     33,   16,    0, 16,  0,  5 }, {     34,   16,    0, 16,  0,  5 },
    {     35,   16,    0, 16,  0,  5 }, {     36,   16,    0, 16,  0,  5 }, {     37,   16,    0, 16,  0,  5 }, {     38,   16,    0, 16,  0,  5 }, {     39,   16,    0, 16,  0,  5 },
    {     40,   16,    0, 16,  0,  5 }, {     41,   16,    0, 16,  0,  5 }, {     42,   16,    0, 16,  0,  6 }, {     43,   16,    0, 16,  0,  6 }, {     44,   16,    0, 16,  0,  6 },
    {     45,   16,    0, 16,  0,  6 }, {     46,   16,    0, 16,  0,  6 }, {     47,   16,    0, 16,  0,  6 }, {     48,   16,    0, 16,  0,  6 }, {     49,   16,    0, 16,  0,  6 },
    {     50,   16,    0, 16,  0,  6 }, {     51,   16,    0, 16,  0,  6 }, {     52,   16,    0, 16,  0,  6 }, {     53,   16,    0, 16,  0,  7 }, {     54,   16,    0, 16,  0,  7 },
    {     55,   16,    0, 16,  0,  7 }, {     56,   16,    0, 16,  0,  7 }, {     57,   16,    0, 16,  0,  7 }, {     58,   16,    0, 16,  0,  7 }, {     59,   16,    0, 16,  0,  7 },
    {     60,   16,    0, 16,  0,  7 }, {     61,   16,    0, 16,  0,  7 }, {     62,   16,    0, 16,  0,  7 }, {     63,   16,    0, 16,  0,  7 }, {     64,   16,    0, 16,  0,  7 },
    {     65,   16,    0, 16,  0,  7 }, {     66,   16,    0, 16,  0,  8 }, {     67,   16,    0, 16,  0,  8 }, {     68,   16,    0, 16,  0,  8 }, {     69,   16,    0, 16,  0,  8 },
    {     70,   16,    0, 16,  0,  8 }, {     71,   16,    0, 16,  0,  8 }, {     72,   16,    0, 16,  0,  8 }, {     73,   16,    0, 16,  0,  8 }, {     74,   16,    0, 16,  0,  8 },
    {     75,   16,    0, 16,  0,  8 }, {     76,   16,    0, 16,  0,  8 }, {     77,   16,    0, 16,  0,  9 }, {     78,   16,    0, 16,  0,  9 }, {     79,   16,    0, 16,  0,  9 },
    {     80,   16,    0, 16,  0,  9 }, {     81,   16,    0, 16,  0,  9 }, {     82,   16,    0, 16,  0,  9 }, {     83,   16,    0, 16,  0,  9 }, {     84,   16,    0, 16,  0,  9 },
    {     85,   16,    0, 16,  0,  9 }, {     86,   16,    0, 16,  0,  9 }, {     87,   16,    0, 16,  0,  9 }, {     88,   16,    0, 16,  0,  9 }, {     89,   16,    0, 16,  0,  9 },
    {     90,   16,    0,  0, 16,  0 }, {     91,   16,    0,  0, 16,  0 }, {     92,   16,    0,  0, 16,  0 }, {     93,   16,    0,  0, 16,  0 }, {     94,   16,    0,  0, 16,  0 },
    {     95,   16,    0,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DA624, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  1 }, {     16,   25,    0, 24,  0,  1 }, {     16,   24,    0, 24,  0,  1 }, {     16,   23,    0, 24,  0,  1 }, {     16,   22,    0, 24,  0,  1 },
    {     16,   21,    0, 24,  0,  1 }, {     16,   20,    0, 24,  0,  1 }, {     16,   19,    0, 24,  0,  1 }, {     16,   18,    0, 24,  0,  1 }, {     16,   17,    0, 24,  0,  1 },
    {     16,   16,    0, 24,  0,  1 }, {     16,   15,    0, 24,  0,  1 }, {     16,   14,    0, 24,  0,  1 }, {     16,   13,    0, 24,  0,  2 }, {     16,   12,    0, 24,  0,  2 },
    {     16,   11,    0, 24,  0,  2 }, {     16,   10,    0, 24,  0,  2 }, {     16,    9,    0, 24,  0,  2 }, {     16,    8,    0, 24,  0,  2 }, {     16,    7,    0, 24,  0,  2 },
    {     16,    6,    0, 24,  0,  2 }, {     16,    5,    0, 24,  0,  2 }, {     16,    4,    0, 24,  0,  2 }, {     16,    3,    0, 24,  0,  2 }, {     16,    2,    0, 24,  0,  5 },
    {     16,    1,    0, 24,  0,  5 }, {     16,    0,    0, 24,  0,  5 }, {     16,   -1,    0, 24,  0,  5 }, {     16,   -2,    0, 24,  0,  5 }, {     16,   -3,    0, 24,  0,  5 },
    {     16,   -4,    0, 24,  0,  5 }, {     16,   -5,    0, 24,  0,  5 }, {     16,   -6,    0, 24,  0,  5 }, {     16,   -7,    0, 24,  0,  5 }, {     16,   -8,    0, 24,  0,  5 },
    {     16,   -9,    0, 24,  0,  5 }, {     16,  -10,    0, 24,  0,  5 }, {     16,  -11,    0, 24,  0,  6 }, {     16,  -12,    0, 24,  0,  6 }, {     16,  -13,    0, 24,  0,  6 },
    {     16,  -14,    0, 24,  0,  6 }, {     16,  -15,    0, 24,  0,  6 }, {     16,  -16,    0, 24,  0,  6 }, {     16,  -17,    0, 24,  0,  6 }, {     16,  -18,    0, 24,  0,  6 },
    {     16,  -19,    0, 24,  0,  6 }, {     16,  -20,    0, 24,  0,  6 }, {     16,  -21,    0, 24,  0,  6 }, {     16,  -22,    0, 24,  0,  7 }, {     16,  -23,    0, 24,  0,  7 },
    {     16,  -24,    0, 24,  0,  7 }, {     16,  -25,    0, 24,  0,  7 }, {     16,  -26,    0, 24,  0,  7 }, {     16,  -27,    0, 24,  0,  7 }, {     16,  -28,    0, 24,  0,  7 },
    {     16,  -29,    0, 24,  0,  7 }, {     16,  -30,    0, 24,  0,  7 }, {     16,  -31,    0, 24,  0,  7 }, {     16,  -32,    0, 24,  0,  7 }, {     16,  -33,    0, 24,  0,  7 },
    {     16,  -34,    0, 24,  0,  7 }, {     16,  -35,    0, 24,  0,  8 }, {     16,  -36,    0, 24,  0,  8 }, {     16,  -37,    0, 24,  0,  8 }, {     16,  -38,    0, 24,  0,  8 },
    {     16,  -39,    0, 24,  0,  8 }, {     16,  -40,    0, 24,  0,  8 }, {     16,  -41,    0, 24,  0,  8 }, {     16,  -42,    0, 24,  0,  8 }, {     16,  -43,    0, 24,  0,  8 },
    {     16,  -44,    0, 24,  0,  8 }, {     16,  -45,    0, 24,  0,  8 }, {     16,  -46,    0, 24,  0,  9 }, {     16,  -47,    0, 24,  0,  9 }, {     16,  -48,    0, 24,  0,  9 },
    {     16,  -49,    0, 24,  0,  9 }, {     16,  -50,    0, 24,  0,  9 }, {     16,  -51,    0, 24,  0,  9 }, {     16,  -52,    0, 24,  0,  9 }, {     16,  -53,    0, 24,  0,  9 },
    {     16,  -54,    0, 24,  0,  9 }, {     16,  -55,    0, 24,  0,  9 }, {     16,  -56,    0, 24,  0,  9 }, {     16,  -57,    0, 24,  0,  9 }, {     16,  -58,    0, 24,  0,  9 },
    {     16,  -59,    0,  8, 16,  0 }, {     16,  -60,    0,  8, 16,  0 }, {     16,  -61,    0,  8, 16,  0 }, {     16,  -62,    0,  8, 16,  0 }, {     16,  -63,    0,  8, 16,  0 },
    {     16,  -64,    0,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DA986, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  3 }, {     25,   16,    0,  0,  0,  3 }, {     24,   16,    0,  0,  0,  3 }, {     23,   16,    0,  0,  0,  3 }, {     22,   16,    0,  0,  0,  3 },
    {     21,   16,    0,  0,  0,  3 }, {     20,   16,    0,  0,  0,  3 }, {     19,   16,    0,  0,  0,  3 }, {     18,   16,    0,  0,  0,  3 }, {     17,   16,    0,  0,  0,  3 },
    {     16,   16,    0,  0,  0,  3 }, {     15,   16,    0,  0,  0,  3 }, {     14,   16,    0,  0,  0,  3 }, {     13,   16,    0,  0,  0,  4 }, {     12,   16,    0,  0,  0,  4 },
    {     11,   16,    0,  0,  0,  4 }, {     10,   16,    0,  0,  0,  4 }, {      9,   16,    0,  0,  0,  4 }, {      8,   16,    0,  0,  0,  4 }, {      7,   16,    0,  0,  0,  4 },
    {      6,   16,    0,  0,  0,  4 }, {      5,   16,    0,  0,  0,  4 }, {      4,   16,    0,  0,  0,  4 }, {      3,   16,    0,  0,  0,  4 }, {      2,   16,    0,  0,  0, 10 },
    {      1,   16,    0,  0,  0, 10 }, {      0,   16,    0,  0,  0, 10 }, {     -1,   16,    0,  0,  0, 10 }, {     -2,   16,    0,  0,  0, 10 }, {     -3,   16,    0,  0,  0, 10 },
    {     -4,   16,    0,  0,  0, 10 }, {     -5,   16,    0,  0,  0, 10 }, {     -6,   16,    0,  0,  0, 10 }, {     -7,   16,    0,  0,  0, 10 }, {     -8,   16,    0,  0,  0, 10 },
    {     -9,   16,    0,  0,  0, 10 }, {    -10,   16,    0,  0,  0, 10 }, {    -11,   16,    0,  0,  0, 11 }, {    -12,   16,    0,  0,  0, 11 }, {    -13,   16,    0,  0,  0, 11 },
    {    -14,   16,    0,  0,  0, 11 }, {    -15,   16,    0,  0,  0, 11 }, {    -16,   16,    0,  0,  0, 11 }, {    -17,   16,    0,  0,  0, 11 }, {    -18,   16,    0,  0,  0, 11 },
    {    -19,   16,    0,  0,  0, 11 }, {    -20,   16,    0,  0,  0, 11 }, {    -21,   16,    0,  0,  0, 11 }, {    -22,   16,    0,  0,  0, 12 }, {    -23,   16,    0,  0,  0, 12 },
    {    -24,   16,    0,  0,  0, 12 }, {    -25,   16,    0,  0,  0, 12 }, {    -26,   16,    0,  0,  0, 12 }, {    -27,   16,    0,  0,  0, 12 }, {    -28,   16,    0,  0,  0, 12 },
    {    -29,   16,    0,  0,  0, 12 }, {    -30,   16,    0,  0,  0, 12 }, {    -31,   16,    0,  0,  0, 12 }, {    -32,   16,    0,  0,  0, 12 }, {    -33,   16,    0,  0,  0, 12 },
    {    -34,   16,    0,  0,  0, 12 }, {    -35,   16,    0,  0,  0, 13 }, {    -36,   16,    0,  0,  0, 13 }, {    -37,   16,    0,  0,  0, 13 }, {    -38,   16,    0,  0,  0, 13 },
    {    -39,   16,    0,  0,  0, 13 }, {    -40,   16,    0,  0,  0, 13 }, {    -41,   16,    0,  0,  0, 13 }, {    -42,   16,    0,  0,  0, 13 }, {    -43,   16,    0,  0,  0, 13 },
    {    -44,   16,    0,  0,  0, 13 }, {    -45,   16,    0,  0,  0, 13 }, {    -46,   16,    0,  0,  0, 14 }, {    -47,   16,    0,  0,  0, 14 }, {    -48,   16,    0,  0,  0, 14 },
    {    -49,   16,    0,  0,  0, 14 }, {    -50,   16,    0,  0,  0, 14 }, {    -51,   16,    0,  0,  0, 14 }, {    -52,   16,    0,  0,  0, 14 }, {    -53,   16,    0,  0,  0, 14 },
    {    -54,   16,    0,  0,  0, 14 }, {    -55,   16,    0,  0,  0, 14 }, {    -56,   16,    0,  0,  0, 14 }, {    -57,   16,    0,  0,  0, 14 }, {    -58,   16,    0,  0,  0, 14 },
    {    -59,   16,    0, 16, 16,  0 }, {    -60,   16,    0, 16, 16,  0 }, {    -61,   16,    0, 16, 16,  0 }, {    -62,   16,    0, 16, 16,  0 }, {    -63,   16,    0, 16, 16,  0 },
    {    -64,   16,    0, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DACE8, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  3 }, {     16,    6,    0,  8,  0,  3 }, {     16,    7,    0,  8,  0,  3 }, {     16,    8,    0,  8,  0,  3 }, {     16,    9,    0,  8,  0,  3 },
    {     16,   10,    0,  8,  0,  3 }, {     16,   11,    0,  8,  0,  3 }, {     16,   12,    0,  8,  0,  3 }, {     16,   13,    0,  8,  0,  3 }, {     16,   14,    0,  8,  0,  3 },
    {     16,   15,    0,  8,  0,  3 }, {     16,   16,    0,  8,  0,  3 }, {     16,   17,    0,  8,  0,  3 }, {     16,   18,    0,  8,  0,  4 }, {     16,   19,    0,  8,  0,  4 },
    {     16,   20,    0,  8,  0,  4 }, {     16,   21,    0,  8,  0,  4 }, {     16,   22,    0,  8,  0,  4 }, {     16,   23,    0,  8,  0,  4 }, {     16,   24,    0,  8,  0,  4 },
    {     16,   25,    0,  8,  0,  4 }, {     16,   26,    0,  8,  0,  4 }, {     16,   27,    0,  8,  0,  4 }, {     16,   28,    0,  8,  0,  4 }, {     16,   29,    0,  8,  0, 10 },
    {     16,   30,    0,  8,  0, 10 }, {     16,   31,    0,  8,  0, 10 }, {     16,   32,    0,  8,  0, 10 }, {     16,   33,    0,  8,  0, 10 }, {     16,   34,    0,  8,  0, 10 },
    {     16,   35,    0,  8,  0, 10 }, {     16,   36,    0,  8,  0, 10 }, {     16,   37,    0,  8,  0, 10 }, {     16,   38,    0,  8,  0, 10 }, {     16,   39,    0,  8,  0, 10 },
    {     16,   40,    0,  8,  0, 10 }, {     16,   41,    0,  8,  0, 10 }, {     16,   42,    0,  8,  0, 11 }, {     16,   43,    0,  8,  0, 11 }, {     16,   44,    0,  8,  0, 11 },
    {     16,   45,    0,  8,  0, 11 }, {     16,   46,    0,  8,  0, 11 }, {     16,   47,    0,  8,  0, 11 }, {     16,   48,    0,  8,  0, 11 }, {     16,   49,    0,  8,  0, 11 },
    {     16,   50,    0,  8,  0, 11 }, {     16,   51,    0,  8,  0, 11 }, {     16,   52,    0,  8,  0, 11 }, {     16,   53,    0,  8,  0, 12 }, {     16,   54,    0,  8,  0, 12 },
    {     16,   55,    0,  8,  0, 12 }, {     16,   56,    0,  8,  0, 12 }, {     16,   57,    0,  8,  0, 12 }, {     16,   58,    0,  8,  0, 12 }, {     16,   59,    0,  8,  0, 12 },
    {     16,   60,    0,  8,  0, 12 }, {     16,   61,    0,  8,  0, 12 }, {     16,   62,    0,  8,  0, 12 }, {     16,   63,    0,  8,  0, 12 }, {     16,   64,    0,  8,  0, 12 },
    {     16,   65,    0,  8,  0, 12 }, {     16,   66,    0,  8,  0, 13 }, {     16,   67,    0,  8,  0, 13 }, {     16,   68,    0,  8,  0, 13 }, {     16,   69,    0,  8,  0, 13 },
    {     16,   70,    0,  8,  0, 13 }, {     16,   71,    0,  8,  0, 13 }, {     16,   72,    0,  8,  0, 13 }, {     16,   73,    0,  8,  0, 13 }, {     16,   74,    0,  8,  0, 13 },
    {     16,   75,    0,  8,  0, 13 }, {     16,   76,    0,  8,  0, 13 }, {     16,   77,    0,  8,  0, 14 }, {     16,   78,    0,  8,  0, 14 }, {     16,   79,    0,  8,  0, 14 },
    {     16,   80,    0,  8,  0, 14 }, {     16,   81,    0,  8,  0, 14 }, {     16,   82,    0,  8,  0, 14 }, {     16,   83,    0,  8,  0, 14 }, {     16,   84,    0,  8,  0, 14 },
    {     16,   85,    0,  8,  0, 14 }, {     16,   86,    0,  8,  0, 14 }, {     16,   87,    0,  8,  0, 14 }, {     16,   88,    0,  8,  0, 14 }, {     16,   89,    0,  8,  0, 14 },
    {     16,   90,    0, 24, 16,  0 }, {     16,   91,    0, 24, 16,  0 }, {     16,   92,    0, 24, 16,  0 }, {     16,   93,    0, 24, 16,  0 }, {     16,   94,    0, 24, 16,  0 },
    {     16,   95,    0, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DB04A, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  3 }, {      6,   16,    0, 16,  0,  3 }, {      7,   16,    0, 16,  0,  3 }, {      8,   16,    0, 16,  0,  3 }, {      9,   16,    0, 16,  0,  3 },
    {     10,   16,    0, 16,  0,  3 }, {     11,   16,    0, 16,  0,  3 }, {     12,   16,    0, 16,  0,  3 }, {     13,   16,    0, 16,  0,  3 }, {     14,   16,    0, 16,  0,  3 },
    {     15,   16,    0, 16,  0,  3 }, {     16,   16,    0, 16,  0,  3 }, {     17,   16,    0, 16,  0,  3 }, {     18,   16,    0, 16,  0,  4 }, {     19,   16,    0, 16,  0,  4 },
    {     20,   16,    0, 16,  0,  4 }, {     21,   16,    0, 16,  0,  4 }, {     22,   16,    0, 16,  0,  4 }, {     23,   16,    0, 16,  0,  4 }, {     24,   16,    0, 16,  0,  4 },
    {     25,   16,    0, 16,  0,  4 }, {     26,   16,    0, 16,  0,  4 }, {     27,   16,    0, 16,  0,  4 }, {     28,   16,    0, 16,  0,  4 }, {     29,   16,    0, 16,  0, 10 },
    {     30,   16,    0, 16,  0, 10 }, {     31,   16,    0, 16,  0, 10 }, {     32,   16,    0, 16,  0, 10 }, {     33,   16,    0, 16,  0, 10 }, {     34,   16,    0, 16,  0, 10 },
    {     35,   16,    0, 16,  0, 10 }, {     36,   16,    0, 16,  0, 10 }, {     37,   16,    0, 16,  0, 10 }, {     38,   16,    0, 16,  0, 10 }, {     39,   16,    0, 16,  0, 10 },
    {     40,   16,    0, 16,  0, 10 }, {     41,   16,    0, 16,  0, 10 }, {     42,   16,    0, 16,  0, 11 }, {     43,   16,    0, 16,  0, 11 }, {     44,   16,    0, 16,  0, 11 },
    {     45,   16,    0, 16,  0, 11 }, {     46,   16,    0, 16,  0, 11 }, {     47,   16,    0, 16,  0, 11 }, {     48,   16,    0, 16,  0, 11 }, {     49,   16,    0, 16,  0, 11 },
    {     50,   16,    0, 16,  0, 11 }, {     51,   16,    0, 16,  0, 11 }, {     52,   16,    0, 16,  0, 11 }, {     53,   16,    0, 16,  0, 12 }, {     54,   16,    0, 16,  0, 12 },
    {     55,   16,    0, 16,  0, 12 }, {     56,   16,    0, 16,  0, 12 }, {     57,   16,    0, 16,  0, 12 }, {     58,   16,    0, 16,  0, 12 }, {     59,   16,    0, 16,  0, 12 },
    {     60,   16,    0, 16,  0, 12 }, {     61,   16,    0, 16,  0, 12 }, {     62,   16,    0, 16,  0, 12 }, {     63,   16,    0, 16,  0, 12 }, {     64,   16,    0, 16,  0, 12 },
    {     65,   16,    0, 16,  0, 12 }, {     66,   16,    0, 16,  0, 13 }, {     67,   16,    0, 16,  0, 13 }, {     68,   16,    0, 16,  0, 13 }, {     69,   16,    0, 16,  0, 13 },
    {     70,   16,    0, 16,  0, 13 }, {     71,   16,    0, 16,  0, 13 }, {     72,   16,    0, 16,  0, 13 }, {     73,   16,    0, 16,  0, 13 }, {     74,   16,    0, 16,  0, 13 },
    {     75,   16,    0, 16,  0, 13 }, {     76,   16,    0, 16,  0, 13 }, {     77,   16,    0, 16,  0, 14 }, {     78,   16,    0, 16,  0, 14 }, {     79,   16,    0, 16,  0, 14 },
    {     80,   16,    0, 16,  0, 14 }, {     81,   16,    0, 16,  0, 14 }, {     82,   16,    0, 16,  0, 14 }, {     83,   16,    0, 16,  0, 14 }, {     84,   16,    0, 16,  0, 14 },
    {     85,   16,    0, 16,  0, 14 }, {     86,   16,    0, 16,  0, 14 }, {     87,   16,    0, 16,  0, 14 }, {     88,   16,    0, 16,  0, 14 }, {     89,   16,    0, 16,  0, 14 },
    {     90,   16,    0,  0, 16,  0 }, {     91,   16,    0,  0, 16,  0 }, {     92,   16,    0,  0, 16,  0 }, {     93,   16,    0,  0, 16,  0 }, {     94,   16,    0,  0, 16,  0 },
    {     95,   16,    0,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DB3AC, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  3 }, {     16,   25,    0, 24,  0,  3 }, {     16,   24,    0, 24,  0,  3 }, {     16,   23,    0, 24,  0,  3 }, {     16,   22,    0, 24,  0,  3 },
    {     16,   21,    0, 24,  0,  3 }, {     16,   20,    0, 24,  0,  3 }, {     16,   19,    0, 24,  0,  3 }, {     16,   18,    0, 24,  0,  3 }, {     16,   17,    0, 24,  0,  3 },
    {     16,   16,    0, 24,  0,  3 }, {     16,   15,    0, 24,  0,  3 }, {     16,   14,    0, 24,  0,  3 }, {     16,   13,    0, 24,  0,  4 }, {     16,   12,    0, 24,  0,  4 },
    {     16,   11,    0, 24,  0,  4 }, {     16,   10,    0, 24,  0,  4 }, {     16,    9,    0, 24,  0,  4 }, {     16,    8,    0, 24,  0,  4 }, {     16,    7,    0, 24,  0,  4 },
    {     16,    6,    0, 24,  0,  4 }, {     16,    5,    0, 24,  0,  4 }, {     16,    4,    0, 24,  0,  4 }, {     16,    3,    0, 24,  0,  4 }, {     16,    2,    0, 24,  0, 10 },
    {     16,    1,    0, 24,  0, 10 }, {     16,    0,    0, 24,  0, 10 }, {     16,   -1,    0, 24,  0, 10 }, {     16,   -2,    0, 24,  0, 10 }, {     16,   -3,    0, 24,  0, 10 },
    {     16,   -4,    0, 24,  0, 10 }, {     16,   -5,    0, 24,  0, 10 }, {     16,   -6,    0, 24,  0, 10 }, {     16,   -7,    0, 24,  0, 10 }, {     16,   -8,    0, 24,  0, 10 },
    {     16,   -9,    0, 24,  0, 10 }, {     16,  -10,    0, 24,  0, 10 }, {     16,  -11,    0, 24,  0, 11 }, {     16,  -12,    0, 24,  0, 11 }, {     16,  -13,    0, 24,  0, 11 },
    {     16,  -14,    0, 24,  0, 11 }, {     16,  -15,    0, 24,  0, 11 }, {     16,  -16,    0, 24,  0, 11 }, {     16,  -17,    0, 24,  0, 11 }, {     16,  -18,    0, 24,  0, 11 },
    {     16,  -19,    0, 24,  0, 11 }, {     16,  -20,    0, 24,  0, 11 }, {     16,  -21,    0, 24,  0, 11 }, {     16,  -22,    0, 24,  0, 12 }, {     16,  -23,    0, 24,  0, 12 },
    {     16,  -24,    0, 24,  0, 12 }, {     16,  -25,    0, 24,  0, 12 }, {     16,  -26,    0, 24,  0, 12 }, {     16,  -27,    0, 24,  0, 12 }, {     16,  -28,    0, 24,  0, 12 },
    {     16,  -29,    0, 24,  0, 12 }, {     16,  -30,    0, 24,  0, 12 }, {     16,  -31,    0, 24,  0, 12 }, {     16,  -32,    0, 24,  0, 12 }, {     16,  -33,    0, 24,  0, 12 },
    {     16,  -34,    0, 24,  0, 12 }, {     16,  -35,    0, 24,  0, 13 }, {     16,  -36,    0, 24,  0, 13 }, {     16,  -37,    0, 24,  0, 13 }, {     16,  -38,    0, 24,  0, 13 },
    {     16,  -39,    0, 24,  0, 13 }, {     16,  -40,    0, 24,  0, 13 }, {     16,  -41,    0, 24,  0, 13 }, {     16,  -42,    0, 24,  0, 13 }, {     16,  -43,    0, 24,  0, 13 },
    {     16,  -44,    0, 24,  0, 13 }, {     16,  -45,    0, 24,  0, 13 }, {     16,  -46,    0, 24,  0, 14 }, {     16,  -47,    0, 24,  0, 14 }, {     16,  -48,    0, 24,  0, 14 },
    {     16,  -49,    0, 24,  0, 14 }, {     16,  -50,    0, 24,  0, 14 }, {     16,  -51,    0, 24,  0, 14 }, {     16,  -52,    0, 24,  0, 14 }, {     16,  -53,    0, 24,  0, 14 },
    {     16,  -54,    0, 24,  0, 14 }, {     16,  -55,    0, 24,  0, 14 }, {     16,  -56,    0, 24,  0, 14 }, {     16,  -57,    0, 24,  0, 14 }, {     16,  -58,    0, 24,  0, 14 },
    {     16,  -59,    0,  8, 16,  0 }, {     16,  -60,    0,  8, 16,  0 }, {     16,  -61,    0,  8, 16,  0 }, {     16,  -62,    0,  8, 16,  0 }, {     16,  -63,    0,  8, 16,  0 },
    {     16,  -64,    0,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DB70E, {
    {     31,   16,  -16, 16, 16,  0 }, {     30,   16,  -16, 16, 16,  0 }, {     29,   16,  -16, 16, 16,  0 }, {     28,   16,  -16, 16, 16,  0 }, {     27,   16,  -16, 16, 16,  0 },
    {     26,   16,  -16,  0,  0, 14 }, {     25,   16,  -16,  0,  0, 14 }, {     24,   16,  -16,  0,  0, 14 }, {     23,   16,  -16,  0,  0, 14 }, {     22,   16,  -16,  0,  0, 14 },
    {     21,   16,  -16,  0,  0, 14 }, {     20,   16,  -16,  0,  0, 14 }, {     19,   16,  -16,  0,  0, 14 }, {     18,   16,  -16,  0,  0, 14 }, {     17,   16,  -16,  0,  0, 14 },
    {     16,   16,  -16,  0,  0, 14 }, {     15,   16,  -16,  0,  0, 14 }, {     14,   16,  -16,  0,  0, 14 }, {     13,   16,  -16,  0,  0, 13 }, {     12,   16,  -16,  0,  0, 13 },
    {     11,   16,  -16,  0,  0, 13 }, {     10,   16,  -16,  0,  0, 13 }, {      9,   16,  -16,  0,  0, 13 }, {      8,   16,  -16,  0,  0, 13 }, {      7,   16,  -16,  0,  0, 13 },
    {      6,   16,  -16,  0,  0, 13 }, {      5,   16,  -16,  0,  0, 13 }, {      4,   16,  -16,  0,  0, 13 }, {      3,   16,  -16,  0,  0, 13 }, {      2,   16,  -16,  0,  0, 12 },
    {      1,   16,  -16,  0,  0, 12 }, {      0,   16,  -16,  0,  0, 12 }, {     -1,   16,  -16,  0,  0, 12 }, {     -2,   16,  -16,  0,  0, 12 }, {     -3,   16,  -16,  0,  0, 12 },
    {     -4,   16,  -16,  0,  0, 12 }, {     -5,   16,  -16,  0,  0, 12 }, {     -6,   16,  -16,  0,  0, 12 }, {     -7,   16,  -16,  0,  0, 12 }, {     -8,   16,  -16,  0,  0, 12 },
    {     -9,   16,  -16,  0,  0, 12 }, {    -10,   16,  -16,  0,  0, 12 }, {    -11,   16,  -16,  0,  0, 11 }, {    -12,   16,  -16,  0,  0, 11 }, {    -13,   16,  -16,  0,  0, 11 },
    {    -14,   16,  -16,  0,  0, 11 }, {    -15,   16,  -16,  0,  0, 11 }, {    -16,   16,  -16,  0,  0, 11 }, {    -17,   16,  -16,  0,  0, 11 }, {    -18,   16,  -16,  0,  0, 11 },
    {    -19,   16,  -16,  0,  0, 11 }, {    -20,   16,  -16,  0,  0, 11 }, {    -21,   16,  -16,  0,  0, 11 }, {    -22,   16,  -16,  0,  0, 10 }, {    -23,   16,  -16,  0,  0, 10 },
    {    -24,   16,  -16,  0,  0, 10 }, {    -25,   16,  -16,  0,  0, 10 }, {    -26,   16,  -16,  0,  0, 10 }, {    -27,   16,  -16,  0,  0, 10 }, {    -28,   16,  -16,  0,  0, 10 },
    {    -29,   16,  -16,  0,  0, 10 }, {    -30,   16,  -16,  0,  0, 10 }, {    -31,   16,  -16,  0,  0, 10 }, {    -32,   16,  -16,  0,  0, 10 }, {    -33,   16,  -16,  0,  0, 10 },
    {    -34,   16,  -16,  0,  0, 10 }, {    -35,   16,  -16,  0,  0,  4 }, {    -36,   16,  -16,  0,  0,  4 }, {    -37,   16,  -16,  0,  0,  4 }, {    -38,   16,  -16,  0,  0,  4 },
    {    -39,   16,  -16,  0,  0,  4 }, {    -40,   16,  -16,  0,  0,  4 }, {    -41,   16,  -16,  0,  0,  4 }, {    -42,   16,  -16,  0,  0,  4 }, {    -43,   16,  -16,  0,  0,  4 },
    {    -44,   16,  -16,  0,  0,  4 }, {    -45,   16,  -16,  0,  0,  4 }, {    -46,   16,  -16,  0,  0,  3 }, {    -47,   16,  -16,  0,  0,  3 }, {    -48,   16,  -16,  0,  0,  3 },
    {    -49,   16,  -16,  0,  0,  3 }, {    -50,   16,  -16,  0,  0,  3 }, {    -51,   16,  -16,  0,  0,  3 }, {    -52,   16,  -16,  0,  0,  3 }, {    -53,   16,  -16,  0,  0,  3 },
    {    -54,   16,  -16,  0,  0,  3 }, {    -55,   16,  -16,  0,  0,  3 }, {    -56,   16,  -16,  0,  0,  3 }, {    -57,   16,  -16,  0,  0,  3 }, {    -58,   16,  -16,  0,  0,  3 },
    {    -59,   16,  -16,  0,  0,  0 }, {    -60,   16,  -16,  0,  0,  0 }, {    -61,   16,  -16,  0,  0,  0 }, {    -62,   16,  -16,  0,  0,  0 }, {    -63,   16,  -16,  0,  0,  0 },
    {    -64,   16,  -16,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DBA70, {
    {     16,    0,  -16, 24, 16,  0 }, {     16,    1,  -16, 24, 16,  0 }, {     16,    2,  -16, 24, 16,  0 }, {     16,    3,  -16, 24, 16,  0 }, {     16,    4,  -16, 24, 16,  0 },
    {     16,    5,  -16,  8,  0, 14 }, {     16,    6,  -16,  8,  0, 14 }, {     16,    7,  -16,  8,  0, 14 }, {     16,    8,  -16,  8,  0, 14 }, {     16,    9,  -16,  8,  0, 14 },
    {     16,   10,  -16,  8,  0, 14 }, {     16,   11,  -16,  8,  0, 14 }, {     16,   12,  -16,  8,  0, 14 }, {     16,   13,  -16,  8,  0, 14 }, {     16,   14,  -16,  8,  0, 14 },
    {     16,   15,  -16,  8,  0, 14 }, {     16,   16,  -16,  8,  0, 14 }, {     16,   17,  -16,  8,  0, 14 }, {     16,   18,  -16,  8,  0, 13 }, {     16,   19,  -16,  8,  0, 13 },
    {     16,   20,  -16,  8,  0, 13 }, {     16,   21,  -16,  8,  0, 13 }, {     16,   22,  -16,  8,  0, 13 }, {     16,   23,  -16,  8,  0, 13 }, {     16,   24,  -16,  8,  0, 13 },
    {     16,   25,  -16,  8,  0, 13 }, {     16,   26,  -16,  8,  0, 13 }, {     16,   27,  -16,  8,  0, 13 }, {     16,   28,  -16,  8,  0, 13 }, {     16,   29,  -16,  8,  0, 12 },
    {     16,   30,  -16,  8,  0, 12 }, {     16,   31,  -16,  8,  0, 12 }, {     16,   32,  -16,  8,  0, 12 }, {     16,   33,  -16,  8,  0, 12 }, {     16,   34,  -16,  8,  0, 12 },
    {     16,   35,  -16,  8,  0, 12 }, {     16,   36,  -16,  8,  0, 12 }, {     16,   37,  -16,  8,  0, 12 }, {     16,   38,  -16,  8,  0, 12 }, {     16,   39,  -16,  8,  0, 12 },
    {     16,   40,  -16,  8,  0, 12 }, {     16,   41,  -16,  8,  0, 12 }, {     16,   42,  -16,  8,  0, 11 }, {     16,   43,  -16,  8,  0, 11 }, {     16,   44,  -16,  8,  0, 11 },
    {     16,   45,  -16,  8,  0, 11 }, {     16,   46,  -16,  8,  0, 11 }, {     16,   47,  -16,  8,  0, 11 }, {     16,   48,  -16,  8,  0, 11 }, {     16,   49,  -16,  8,  0, 11 },
    {     16,   50,  -16,  8,  0, 11 }, {     16,   51,  -16,  8,  0, 11 }, {     16,   52,  -16,  8,  0, 11 }, {     16,   53,  -16,  8,  0, 10 }, {     16,   54,  -16,  8,  0, 10 },
    {     16,   55,  -16,  8,  0, 10 }, {     16,   56,  -16,  8,  0, 10 }, {     16,   57,  -16,  8,  0, 10 }, {     16,   58,  -16,  8,  0, 10 }, {     16,   59,  -16,  8,  0, 10 },
    {     16,   60,  -16,  8,  0, 10 }, {     16,   61,  -16,  8,  0, 10 }, {     16,   62,  -16,  8,  0, 10 }, {     16,   63,  -16,  8,  0, 10 }, {     16,   64,  -16,  8,  0, 10 },
    {     16,   65,  -16,  8,  0, 10 }, {     16,   66,  -16,  8,  0,  4 }, {     16,   67,  -16,  8,  0,  4 }, {     16,   68,  -16,  8,  0,  4 }, {     16,   69,  -16,  8,  0,  4 },
    {     16,   70,  -16,  8,  0,  4 }, {     16,   71,  -16,  8,  0,  4 }, {     16,   72,  -16,  8,  0,  4 }, {     16,   73,  -16,  8,  0,  4 }, {     16,   74,  -16,  8,  0,  4 },
    {     16,   75,  -16,  8,  0,  4 }, {     16,   76,  -16,  8,  0,  4 }, {     16,   77,  -16,  8,  0,  3 }, {     16,   78,  -16,  8,  0,  3 }, {     16,   79,  -16,  8,  0,  3 },
    {     16,   80,  -16,  8,  0,  3 }, {     16,   81,  -16,  8,  0,  3 }, {     16,   82,  -16,  8,  0,  3 }, {     16,   83,  -16,  8,  0,  3 }, {     16,   84,  -16,  8,  0,  3 },
    {     16,   85,  -16,  8,  0,  3 }, {     16,   86,  -16,  8,  0,  3 }, {     16,   87,  -16,  8,  0,  3 }, {     16,   88,  -16,  8,  0,  3 }, {     16,   89,  -16,  8,  0,  3 },
    {     16,   90,  -16,  8,  0,  0 }, {     16,   91,  -16,  8,  0,  0 }, {     16,   92,  -16,  8,  0,  0 }, {     16,   93,  -16,  8,  0,  0 }, {     16,   94,  -16,  8,  0,  0 },
    {     16,   95,  -16,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DBDD2, {
    {      0,   16,  -16,  0, 16,  0 }, {      1,   16,  -16,  0, 16,  0 }, {      2,   16,  -16,  0, 16,  0 }, {      3,   16,  -16,  0, 16,  0 }, {      4,   16,  -16,  0, 16,  0 },
    {      5,   16,  -16, 16,  0, 14 }, {      6,   16,  -16, 16,  0, 14 }, {      7,   16,  -16, 16,  0, 14 }, {      8,   16,  -16, 16,  0, 14 }, {      9,   16,  -16, 16,  0, 14 },
    {     10,   16,  -16, 16,  0, 14 }, {     11,   16,  -16, 16,  0, 14 }, {     12,   16,  -16, 16,  0, 14 }, {     13,   16,  -16, 16,  0, 14 }, {     14,   16,  -16, 16,  0, 14 },
    {     15,   16,  -16, 16,  0, 14 }, {     16,   16,  -16, 16,  0, 14 }, {     17,   16,  -16, 16,  0, 14 }, {     18,   16,  -16, 16,  0, 13 }, {     19,   16,  -16, 16,  0, 13 },
    {     20,   16,  -16, 16,  0, 13 }, {     21,   16,  -16, 16,  0, 13 }, {     22,   16,  -16, 16,  0, 13 }, {     23,   16,  -16, 16,  0, 13 }, {     24,   16,  -16, 16,  0, 13 },
    {     25,   16,  -16, 16,  0, 13 }, {     26,   16,  -16, 16,  0, 13 }, {     27,   16,  -16, 16,  0, 13 }, {     28,   16,  -16, 16,  0, 13 }, {     29,   16,  -16, 16,  0, 12 },
    {     30,   16,  -16, 16,  0, 12 }, {     31,   16,  -16, 16,  0, 12 }, {     32,   16,  -16, 16,  0, 12 }, {     33,   16,  -16, 16,  0, 12 }, {     34,   16,  -16, 16,  0, 12 },
    {     35,   16,  -16, 16,  0, 12 }, {     36,   16,  -16, 16,  0, 12 }, {     37,   16,  -16, 16,  0, 12 }, {     38,   16,  -16, 16,  0, 12 }, {     39,   16,  -16, 16,  0, 12 },
    {     40,   16,  -16, 16,  0, 12 }, {     41,   16,  -16, 16,  0, 12 }, {     42,   16,  -16, 16,  0, 11 }, {     43,   16,  -16, 16,  0, 11 }, {     44,   16,  -16, 16,  0, 11 },
    {     45,   16,  -16, 16,  0, 11 }, {     46,   16,  -16, 16,  0, 11 }, {     47,   16,  -16, 16,  0, 11 }, {     48,   16,  -16, 16,  0, 11 }, {     49,   16,  -16, 16,  0, 11 },
    {     50,   16,  -16, 16,  0, 11 }, {     51,   16,  -16, 16,  0, 11 }, {     52,   16,  -16, 16,  0, 11 }, {     53,   16,  -16, 16,  0, 10 }, {     54,   16,  -16, 16,  0, 10 },
    {     55,   16,  -16, 16,  0, 10 }, {     56,   16,  -16, 16,  0, 10 }, {     57,   16,  -16, 16,  0, 10 }, {     58,   16,  -16, 16,  0, 10 }, {     59,   16,  -16, 16,  0, 10 },
    {     60,   16,  -16, 16,  0, 10 }, {     61,   16,  -16, 16,  0, 10 }, {     62,   16,  -16, 16,  0, 10 }, {     63,   16,  -16, 16,  0, 10 }, {     64,   16,  -16, 16,  0, 10 },
    {     65,   16,  -16, 16,  0, 10 }, {     66,   16,  -16, 16,  0,  4 }, {     67,   16,  -16, 16,  0,  4 }, {     68,   16,  -16, 16,  0,  4 }, {     69,   16,  -16, 16,  0,  4 },
    {     70,   16,  -16, 16,  0,  4 }, {     71,   16,  -16, 16,  0,  4 }, {     72,   16,  -16, 16,  0,  4 }, {     73,   16,  -16, 16,  0,  4 }, {     74,   16,  -16, 16,  0,  4 },
    {     75,   16,  -16, 16,  0,  4 }, {     76,   16,  -16, 16,  0,  4 }, {     77,   16,  -16, 16,  0,  3 }, {     78,   16,  -16, 16,  0,  3 }, {     79,   16,  -16, 16,  0,  3 },
    {     80,   16,  -16, 16,  0,  3 }, {     81,   16,  -16, 16,  0,  3 }, {     82,   16,  -16, 16,  0,  3 }, {     83,   16,  -16, 16,  0,  3 }, {     84,   16,  -16, 16,  0,  3 },
    {     85,   16,  -16, 16,  0,  3 }, {     86,   16,  -16, 16,  0,  3 }, {     87,   16,  -16, 16,  0,  3 }, {     88,   16,  -16, 16,  0,  3 }, {     89,   16,  -16, 16,  0,  3 },
    {     90,   16,  -16, 16,  0,  0 }, {     91,   16,  -16, 16,  0,  0 }, {     92,   16,  -16, 16,  0,  0 }, {     93,   16,  -16, 16,  0,  0 }, {     94,   16,  -16, 16,  0,  0 },
    {     95,   16,  -16, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DC134, {
    {     16,   31,  -16,  8, 16,  0 }, {     16,   30,  -16,  8, 16,  0 }, {     16,   29,  -16,  8, 16,  0 }, {     16,   28,  -16,  8, 16,  0 }, {     16,   27,  -16,  8, 16,  0 },
    {     16,   26,  -16, 24,  0, 14 }, {     16,   25,  -16, 24,  0, 14 }, {     16,   24,  -16, 24,  0, 14 }, {     16,   23,  -16, 24,  0, 14 }, {     16,   22,  -16, 24,  0, 14 },
    {     16,   21,  -16, 24,  0, 14 }, {     16,   20,  -16, 24,  0, 14 }, {     16,   19,  -16, 24,  0, 14 }, {     16,   18,  -16, 24,  0, 14 }, {     16,   17,  -16, 24,  0, 14 },
    {     16,   16,  -16, 24,  0, 14 }, {     16,   15,  -16, 24,  0, 14 }, {     16,   14,  -16, 24,  0, 14 }, {     16,   13,  -16, 24,  0, 13 }, {     16,   12,  -16, 24,  0, 13 },
    {     16,   11,  -16, 24,  0, 13 }, {     16,   10,  -16, 24,  0, 13 }, {     16,    9,  -16, 24,  0, 13 }, {     16,    8,  -16, 24,  0, 13 }, {     16,    7,  -16, 24,  0, 13 },
    {     16,    6,  -16, 24,  0, 13 }, {     16,    5,  -16, 24,  0, 13 }, {     16,    4,  -16, 24,  0, 13 }, {     16,    3,  -16, 24,  0, 13 }, {     16,    2,  -16, 24,  0, 12 },
    {     16,    1,  -16, 24,  0, 12 }, {     16,    0,  -16, 24,  0, 12 }, {     16,   -1,  -16, 24,  0, 12 }, {     16,   -2,  -16, 24,  0, 12 }, {     16,   -3,  -16, 24,  0, 12 },
    {     16,   -4,  -16, 24,  0, 12 }, {     16,   -5,  -16, 24,  0, 12 }, {     16,   -6,  -16, 24,  0, 12 }, {     16,   -7,  -16, 24,  0, 12 }, {     16,   -8,  -16, 24,  0, 12 },
    {     16,   -9,  -16, 24,  0, 12 }, {     16,  -10,  -16, 24,  0, 12 }, {     16,  -11,  -16, 24,  0, 11 }, {     16,  -12,  -16, 24,  0, 11 }, {     16,  -13,  -16, 24,  0, 11 },
    {     16,  -14,  -16, 24,  0, 11 }, {     16,  -15,  -16, 24,  0, 11 }, {     16,  -16,  -16, 24,  0, 11 }, {     16,  -17,  -16, 24,  0, 11 }, {     16,  -18,  -16, 24,  0, 11 },
    {     16,  -19,  -16, 24,  0, 11 }, {     16,  -20,  -16, 24,  0, 11 }, {     16,  -21,  -16, 24,  0, 11 }, {     16,  -22,  -16, 24,  0, 10 }, {     16,  -23,  -16, 24,  0, 10 },
    {     16,  -24,  -16, 24,  0, 10 }, {     16,  -25,  -16, 24,  0, 10 }, {     16,  -26,  -16, 24,  0, 10 }, {     16,  -27,  -16, 24,  0, 10 }, {     16,  -28,  -16, 24,  0, 10 },
    {     16,  -29,  -16, 24,  0, 10 }, {     16,  -30,  -16, 24,  0, 10 }, {     16,  -31,  -16, 24,  0, 10 }, {     16,  -32,  -16, 24,  0, 10 }, {     16,  -33,  -16, 24,  0, 10 },
    {     16,  -34,  -16, 24,  0, 10 }, {     16,  -35,  -16, 24,  0,  4 }, {     16,  -36,  -16, 24,  0,  4 }, {     16,  -37,  -16, 24,  0,  4 }, {     16,  -38,  -16, 24,  0,  4 },
    {     16,  -39,  -16, 24,  0,  4 }, {     16,  -40,  -16, 24,  0,  4 }, {     16,  -41,  -16, 24,  0,  4 }, {     16,  -42,  -16, 24,  0,  4 }, {     16,  -43,  -16, 24,  0,  4 },
    {     16,  -44,  -16, 24,  0,  4 }, {     16,  -45,  -16, 24,  0,  4 }, {     16,  -46,  -16, 24,  0,  3 }, {     16,  -47,  -16, 24,  0,  3 }, {     16,  -48,  -16, 24,  0,  3 },
    {     16,  -49,  -16, 24,  0,  3 }, {     16,  -50,  -16, 24,  0,  3 }, {     16,  -51,  -16, 24,  0,  3 }, {     16,  -52,  -16, 24,  0,  3 }, {     16,  -53,  -16, 24,  0,  3 },
    {     16,  -54,  -16, 24,  0,  3 }, {     16,  -55,  -16, 24,  0,  3 }, {     16,  -56,  -16, 24,  0,  3 }, {     16,  -57,  -16, 24,  0,  3 }, {     16,  -58,  -16, 24,  0,  3 },
    {     16,  -59,  -16, 24,  0,  0 }, {     16,  -60,  -16, 24,  0,  0 }, {     16,  -61,  -16, 24,  0,  0 }, {     16,  -62,  -16, 24,  0,  0 }, {     16,  -63,  -16, 24,  0,  0 },
    {     16,  -64,  -16, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DC496, {
    {     31,   16,  -16, 16, 16,  0 }, {     30,   16,  -16, 16, 16,  0 }, {     29,   16,  -16, 16, 16,  0 }, {     28,   16,  -16, 16, 16,  0 }, {     27,   16,  -16, 16, 16,  0 },
    {     26,   16,  -16,  0,  0,  9 }, {     25,   16,  -16,  0,  0,  9 }, {     24,   16,  -16,  0,  0,  9 }, {     23,   16,  -16,  0,  0,  9 }, {     22,   16,  -16,  0,  0,  9 },
    {     21,   16,  -16,  0,  0,  9 }, {     20,   16,  -16,  0,  0,  9 }, {     19,   16,  -16,  0,  0,  9 }, {     18,   16,  -16,  0,  0,  9 }, {     17,   16,  -16,  0,  0,  9 },
    {     16,   16,  -16,  0,  0,  9 }, {     15,   16,  -16,  0,  0,  9 }, {     14,   16,  -16,  0,  0,  9 }, {     13,   16,  -16,  0,  0,  8 }, {     12,   16,  -16,  0,  0,  8 },
    {     11,   16,  -16,  0,  0,  8 }, {     10,   16,  -16,  0,  0,  8 }, {      9,   16,  -16,  0,  0,  8 }, {      8,   16,  -16,  0,  0,  8 }, {      7,   16,  -16,  0,  0,  8 },
    {      6,   16,  -16,  0,  0,  8 }, {      5,   16,  -16,  0,  0,  8 }, {      4,   16,  -16,  0,  0,  8 }, {      3,   16,  -16,  0,  0,  8 }, {      2,   16,  -16,  0,  0,  7 },
    {      1,   16,  -16,  0,  0,  7 }, {      0,   16,  -16,  0,  0,  7 }, {     -1,   16,  -16,  0,  0,  7 }, {     -2,   16,  -16,  0,  0,  7 }, {     -3,   16,  -16,  0,  0,  7 },
    {     -4,   16,  -16,  0,  0,  7 }, {     -5,   16,  -16,  0,  0,  7 }, {     -6,   16,  -16,  0,  0,  7 }, {     -7,   16,  -16,  0,  0,  7 }, {     -8,   16,  -16,  0,  0,  7 },
    {     -9,   16,  -16,  0,  0,  7 }, {    -10,   16,  -16,  0,  0,  7 }, {    -11,   16,  -16,  0,  0,  6 }, {    -12,   16,  -16,  0,  0,  6 }, {    -13,   16,  -16,  0,  0,  6 },
    {    -14,   16,  -16,  0,  0,  6 }, {    -15,   16,  -16,  0,  0,  6 }, {    -16,   16,  -16,  0,  0,  6 }, {    -17,   16,  -16,  0,  0,  6 }, {    -18,   16,  -16,  0,  0,  6 },
    {    -19,   16,  -16,  0,  0,  6 }, {    -20,   16,  -16,  0,  0,  6 }, {    -21,   16,  -16,  0,  0,  6 }, {    -22,   16,  -16,  0,  0,  5 }, {    -23,   16,  -16,  0,  0,  5 },
    {    -24,   16,  -16,  0,  0,  5 }, {    -25,   16,  -16,  0,  0,  5 }, {    -26,   16,  -16,  0,  0,  5 }, {    -27,   16,  -16,  0,  0,  5 }, {    -28,   16,  -16,  0,  0,  5 },
    {    -29,   16,  -16,  0,  0,  5 }, {    -30,   16,  -16,  0,  0,  5 }, {    -31,   16,  -16,  0,  0,  5 }, {    -32,   16,  -16,  0,  0,  5 }, {    -33,   16,  -16,  0,  0,  5 },
    {    -34,   16,  -16,  0,  0,  5 }, {    -35,   16,  -16,  0,  0,  2 }, {    -36,   16,  -16,  0,  0,  2 }, {    -37,   16,  -16,  0,  0,  2 }, {    -38,   16,  -16,  0,  0,  2 },
    {    -39,   16,  -16,  0,  0,  2 }, {    -40,   16,  -16,  0,  0,  2 }, {    -41,   16,  -16,  0,  0,  2 }, {    -42,   16,  -16,  0,  0,  2 }, {    -43,   16,  -16,  0,  0,  2 },
    {    -44,   16,  -16,  0,  0,  2 }, {    -45,   16,  -16,  0,  0,  2 }, {    -46,   16,  -16,  0,  0,  1 }, {    -47,   16,  -16,  0,  0,  1 }, {    -48,   16,  -16,  0,  0,  1 },
    {    -49,   16,  -16,  0,  0,  1 }, {    -50,   16,  -16,  0,  0,  1 }, {    -51,   16,  -16,  0,  0,  1 }, {    -52,   16,  -16,  0,  0,  1 }, {    -53,   16,  -16,  0,  0,  1 },
    {    -54,   16,  -16,  0,  0,  1 }, {    -55,   16,  -16,  0,  0,  1 }, {    -56,   16,  -16,  0,  0,  1 }, {    -57,   16,  -16,  0,  0,  1 }, {    -58,   16,  -16,  0,  0,  1 },
    {    -59,   16,  -16,  0,  0,  0 }, {    -60,   16,  -16,  0,  0,  0 }, {    -61,   16,  -16,  0,  0,  0 }, {    -62,   16,  -16,  0,  0,  0 }, {    -63,   16,  -16,  0,  0,  0 },
    {    -64,   16,  -16,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DC7F8, {
    {     16,    0,  -16, 24, 16,  0 }, {     16,    1,  -16, 24, 16,  0 }, {     16,    2,  -16, 24, 16,  0 }, {     16,    3,  -16, 24, 16,  0 }, {     16,    4,  -16, 24, 16,  0 },
    {     16,    5,  -16,  8,  0,  9 }, {     16,    6,  -16,  8,  0,  9 }, {     16,    7,  -16,  8,  0,  9 }, {     16,    8,  -16,  8,  0,  9 }, {     16,    9,  -16,  8,  0,  9 },
    {     16,   10,  -16,  8,  0,  9 }, {     16,   11,  -16,  8,  0,  9 }, {     16,   12,  -16,  8,  0,  9 }, {     16,   13,  -16,  8,  0,  9 }, {     16,   14,  -16,  8,  0,  9 },
    {     16,   15,  -16,  8,  0,  9 }, {     16,   16,  -16,  8,  0,  9 }, {     16,   17,  -16,  8,  0,  9 }, {     16,   18,  -16,  8,  0,  8 }, {     16,   19,  -16,  8,  0,  8 },
    {     16,   20,  -16,  8,  0,  8 }, {     16,   21,  -16,  8,  0,  8 }, {     16,   22,  -16,  8,  0,  8 }, {     16,   23,  -16,  8,  0,  8 }, {     16,   24,  -16,  8,  0,  8 },
    {     16,   25,  -16,  8,  0,  8 }, {     16,   26,  -16,  8,  0,  8 }, {     16,   27,  -16,  8,  0,  8 }, {     16,   28,  -16,  8,  0,  8 }, {     16,   29,  -16,  8,  0,  7 },
    {     16,   30,  -16,  8,  0,  7 }, {     16,   31,  -16,  8,  0,  7 }, {     16,   32,  -16,  8,  0,  7 }, {     16,   33,  -16,  8,  0,  7 }, {     16,   34,  -16,  8,  0,  7 },
    {     16,   35,  -16,  8,  0,  7 }, {     16,   36,  -16,  8,  0,  7 }, {     16,   37,  -16,  8,  0,  7 }, {     16,   38,  -16,  8,  0,  7 }, {     16,   39,  -16,  8,  0,  7 },
    {     16,   40,  -16,  8,  0,  7 }, {     16,   41,  -16,  8,  0,  7 }, {     16,   42,  -16,  8,  0,  6 }, {     16,   43,  -16,  8,  0,  6 }, {     16,   44,  -16,  8,  0,  6 },
    {     16,   45,  -16,  8,  0,  6 }, {     16,   46,  -16,  8,  0,  6 }, {     16,   47,  -16,  8,  0,  6 }, {     16,   48,  -16,  8,  0,  6 }, {     16,   49,  -16,  8,  0,  6 },
    {     16,   50,  -16,  8,  0,  6 }, {     16,   51,  -16,  8,  0,  6 }, {     16,   52,  -16,  8,  0,  6 }, {     16,   53,  -16,  8,  0,  5 }, {     16,   54,  -16,  8,  0,  5 },
    {     16,   55,  -16,  8,  0,  5 }, {     16,   56,  -16,  8,  0,  5 }, {     16,   57,  -16,  8,  0,  5 }, {     16,   58,  -16,  8,  0,  5 }, {     16,   59,  -16,  8,  0,  5 },
    {     16,   60,  -16,  8,  0,  5 }, {     16,   61,  -16,  8,  0,  5 }, {     16,   62,  -16,  8,  0,  5 }, {     16,   63,  -16,  8,  0,  5 }, {     16,   64,  -16,  8,  0,  5 },
    {     16,   65,  -16,  8,  0,  5 }, {     16,   66,  -16,  8,  0,  2 }, {     16,   67,  -16,  8,  0,  2 }, {     16,   68,  -16,  8,  0,  2 }, {     16,   69,  -16,  8,  0,  2 },
    {     16,   70,  -16,  8,  0,  2 }, {     16,   71,  -16,  8,  0,  2 }, {     16,   72,  -16,  8,  0,  2 }, {     16,   73,  -16,  8,  0,  2 }, {     16,   74,  -16,  8,  0,  2 },
    {     16,   75,  -16,  8,  0,  2 }, {     16,   76,  -16,  8,  0,  2 }, {     16,   77,  -16,  8,  0,  1 }, {     16,   78,  -16,  8,  0,  1 }, {     16,   79,  -16,  8,  0,  1 },
    {     16,   80,  -16,  8,  0,  1 }, {     16,   81,  -16,  8,  0,  1 }, {     16,   82,  -16,  8,  0,  1 }, {     16,   83,  -16,  8,  0,  1 }, {     16,   84,  -16,  8,  0,  1 },
    {     16,   85,  -16,  8,  0,  1 }, {     16,   86,  -16,  8,  0,  1 }, {     16,   87,  -16,  8,  0,  1 }, {     16,   88,  -16,  8,  0,  1 }, {     16,   89,  -16,  8,  0,  1 },
    {     16,   90,  -16,  8,  0,  0 }, {     16,   91,  -16,  8,  0,  0 }, {     16,   92,  -16,  8,  0,  0 }, {     16,   93,  -16,  8,  0,  0 }, {     16,   94,  -16,  8,  0,  0 },
    {     16,   95,  -16,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DCB5A, {
    {      0,   16,  -16,  0, 16,  0 }, {      1,   16,  -16,  0, 16,  0 }, {      2,   16,  -16,  0, 16,  0 }, {      3,   16,  -16,  0, 16,  0 }, {      4,   16,  -16,  0, 16,  0 },
    {      5,   16,  -16, 16,  0,  9 }, {      6,   16,  -16, 16,  0,  9 }, {      7,   16,  -16, 16,  0,  9 }, {      8,   16,  -16, 16,  0,  9 }, {      9,   16,  -16, 16,  0,  9 },
    {     10,   16,  -16, 16,  0,  9 }, {     11,   16,  -16, 16,  0,  9 }, {     12,   16,  -16, 16,  0,  9 }, {     13,   16,  -16, 16,  0,  9 }, {     14,   16,  -16, 16,  0,  9 },
    {     15,   16,  -16, 16,  0,  9 }, {     16,   16,  -16, 16,  0,  9 }, {     17,   16,  -16, 16,  0,  9 }, {     18,   16,  -16, 16,  0,  8 }, {     19,   16,  -16, 16,  0,  8 },
    {     20,   16,  -16, 16,  0,  8 }, {     21,   16,  -16, 16,  0,  8 }, {     22,   16,  -16, 16,  0,  8 }, {     23,   16,  -16, 16,  0,  8 }, {     24,   16,  -16, 16,  0,  8 },
    {     25,   16,  -16, 16,  0,  8 }, {     26,   16,  -16, 16,  0,  8 }, {     27,   16,  -16, 16,  0,  8 }, {     28,   16,  -16, 16,  0,  8 }, {     29,   16,  -16, 16,  0,  7 },
    {     30,   16,  -16, 16,  0,  7 }, {     31,   16,  -16, 16,  0,  7 }, {     32,   16,  -16, 16,  0,  7 }, {     33,   16,  -16, 16,  0,  7 }, {     34,   16,  -16, 16,  0,  7 },
    {     35,   16,  -16, 16,  0,  7 }, {     36,   16,  -16, 16,  0,  7 }, {     37,   16,  -16, 16,  0,  7 }, {     38,   16,  -16, 16,  0,  7 }, {     39,   16,  -16, 16,  0,  7 },
    {     40,   16,  -16, 16,  0,  7 }, {     41,   16,  -16, 16,  0,  7 }, {     42,   16,  -16, 16,  0,  6 }, {     43,   16,  -16, 16,  0,  6 }, {     44,   16,  -16, 16,  0,  6 },
    {     45,   16,  -16, 16,  0,  6 }, {     46,   16,  -16, 16,  0,  6 }, {     47,   16,  -16, 16,  0,  6 }, {     48,   16,  -16, 16,  0,  6 }, {     49,   16,  -16, 16,  0,  6 },
    {     50,   16,  -16, 16,  0,  6 }, {     51,   16,  -16, 16,  0,  6 }, {     52,   16,  -16, 16,  0,  6 }, {     53,   16,  -16, 16,  0,  5 }, {     54,   16,  -16, 16,  0,  5 },
    {     55,   16,  -16, 16,  0,  5 }, {     56,   16,  -16, 16,  0,  5 }, {     57,   16,  -16, 16,  0,  5 }, {     58,   16,  -16, 16,  0,  5 }, {     59,   16,  -16, 16,  0,  5 },
    {     60,   16,  -16, 16,  0,  5 }, {     61,   16,  -16, 16,  0,  5 }, {     62,   16,  -16, 16,  0,  5 }, {     63,   16,  -16, 16,  0,  5 }, {     64,   16,  -16, 16,  0,  5 },
    {     65,   16,  -16, 16,  0,  5 }, {     66,   16,  -16, 16,  0,  2 }, {     67,   16,  -16, 16,  0,  2 }, {     68,   16,  -16, 16,  0,  2 }, {     69,   16,  -16, 16,  0,  2 },
    {     70,   16,  -16, 16,  0,  2 }, {     71,   16,  -16, 16,  0,  2 }, {     72,   16,  -16, 16,  0,  2 }, {     73,   16,  -16, 16,  0,  2 }, {     74,   16,  -16, 16,  0,  2 },
    {     75,   16,  -16, 16,  0,  2 }, {     76,   16,  -16, 16,  0,  2 }, {     77,   16,  -16, 16,  0,  1 }, {     78,   16,  -16, 16,  0,  1 }, {     79,   16,  -16, 16,  0,  1 },
    {     80,   16,  -16, 16,  0,  1 }, {     81,   16,  -16, 16,  0,  1 }, {     82,   16,  -16, 16,  0,  1 }, {     83,   16,  -16, 16,  0,  1 }, {     84,   16,  -16, 16,  0,  1 },
    {     85,   16,  -16, 16,  0,  1 }, {     86,   16,  -16, 16,  0,  1 }, {     87,   16,  -16, 16,  0,  1 }, {     88,   16,  -16, 16,  0,  1 }, {     89,   16,  -16, 16,  0,  1 },
    {     90,   16,  -16, 16,  0,  0 }, {     91,   16,  -16, 16,  0,  0 }, {     92,   16,  -16, 16,  0,  0 }, {     93,   16,  -16, 16,  0,  0 }, {     94,   16,  -16, 16,  0,  0 },
    {     95,   16,  -16, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DCEBC, {
    {     16,   31,  -16,  8, 16,  0 }, {     16,   30,  -16,  8, 16,  0 }, {     16,   29,  -16,  8, 16,  0 }, {     16,   28,  -16,  8, 16,  0 }, {     16,   27,  -16,  8, 16,  0 },
    {     16,   26,  -16, 24,  0,  9 }, {     16,   25,  -16, 24,  0,  9 }, {     16,   24,  -16, 24,  0,  9 }, {     16,   23,  -16, 24,  0,  9 }, {     16,   22,  -16, 24,  0,  9 },
    {     16,   21,  -16, 24,  0,  9 }, {     16,   20,  -16, 24,  0,  9 }, {     16,   19,  -16, 24,  0,  9 }, {     16,   18,  -16, 24,  0,  9 }, {     16,   17,  -16, 24,  0,  9 },
    {     16,   16,  -16, 24,  0,  9 }, {     16,   15,  -16, 24,  0,  9 }, {     16,   14,  -16, 24,  0,  9 }, {     16,   13,  -16, 24,  0,  8 }, {     16,   12,  -16, 24,  0,  8 },
    {     16,   11,  -16, 24,  0,  8 }, {     16,   10,  -16, 24,  0,  8 }, {     16,    9,  -16, 24,  0,  8 }, {     16,    8,  -16, 24,  0,  8 }, {     16,    7,  -16, 24,  0,  8 },
    {     16,    6,  -16, 24,  0,  8 }, {     16,    5,  -16, 24,  0,  8 }, {     16,    4,  -16, 24,  0,  8 }, {     16,    3,  -16, 24,  0,  8 }, {     16,    2,  -16, 24,  0,  7 },
    {     16,    1,  -16, 24,  0,  7 }, {     16,    0,  -16, 24,  0,  7 }, {     16,   -1,  -16, 24,  0,  7 }, {     16,   -2,  -16, 24,  0,  7 }, {     16,   -3,  -16, 24,  0,  7 },
    {     16,   -4,  -16, 24,  0,  7 }, {     16,   -5,  -16, 24,  0,  7 }, {     16,   -6,  -16, 24,  0,  7 }, {     16,   -7,  -16, 24,  0,  7 }, {     16,   -8,  -16, 24,  0,  7 },
    {     16,   -9,  -16, 24,  0,  7 }, {     16,  -10,  -16, 24,  0,  7 }, {     16,  -11,  -16, 24,  0,  6 }, {     16,  -12,  -16, 24,  0,  6 }, {     16,  -13,  -16, 24,  0,  6 },
    {     16,  -14,  -16, 24,  0,  6 }, {     16,  -15,  -16, 24,  0,  6 }, {     16,  -16,  -16, 24,  0,  6 }, {     16,  -17,  -16, 24,  0,  6 }, {     16,  -18,  -16, 24,  0,  6 },
    {     16,  -19,  -16, 24,  0,  6 }, {     16,  -20,  -16, 24,  0,  6 }, {     16,  -21,  -16, 24,  0,  6 }, {     16,  -22,  -16, 24,  0,  5 }, {     16,  -23,  -16, 24,  0,  5 },
    {     16,  -24,  -16, 24,  0,  5 }, {     16,  -25,  -16, 24,  0,  5 }, {     16,  -26,  -16, 24,  0,  5 }, {     16,  -27,  -16, 24,  0,  5 }, {     16,  -28,  -16, 24,  0,  5 },
    {     16,  -29,  -16, 24,  0,  5 }, {     16,  -30,  -16, 24,  0,  5 }, {     16,  -31,  -16, 24,  0,  5 }, {     16,  -32,  -16, 24,  0,  5 }, {     16,  -33,  -16, 24,  0,  5 },
    {     16,  -34,  -16, 24,  0,  5 }, {     16,  -35,  -16, 24,  0,  2 }, {     16,  -36,  -16, 24,  0,  2 }, {     16,  -37,  -16, 24,  0,  2 }, {     16,  -38,  -16, 24,  0,  2 },
    {     16,  -39,  -16, 24,  0,  2 }, {     16,  -40,  -16, 24,  0,  2 }, {     16,  -41,  -16, 24,  0,  2 }, {     16,  -42,  -16, 24,  0,  2 }, {     16,  -43,  -16, 24,  0,  2 },
    {     16,  -44,  -16, 24,  0,  2 }, {     16,  -45,  -16, 24,  0,  2 }, {     16,  -46,  -16, 24,  0,  1 }, {     16,  -47,  -16, 24,  0,  1 }, {     16,  -48,  -16, 24,  0,  1 },
    {     16,  -49,  -16, 24,  0,  1 }, {     16,  -50,  -16, 24,  0,  1 }, {     16,  -51,  -16, 24,  0,  1 }, {     16,  -52,  -16, 24,  0,  1 }, {     16,  -53,  -16, 24,  0,  1 },
    {     16,  -54,  -16, 24,  0,  1 }, {     16,  -55,  -16, 24,  0,  1 }, {     16,  -56,  -16, 24,  0,  1 }, {     16,  -57,  -16, 24,  0,  1 }, {     16,  -58,  -16, 24,  0,  1 },
    {     16,  -59,  -16, 24,  0,  0 }, {     16,  -60,  -16, 24,  0,  0 }, {     16,  -61,  -16, 24,  0,  0 }, {     16,  -62,  -16, 24,  0,  0 }, {     16,  -63,  -16, 24,  0,  0 },
    {     16,  -64,  -16, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E644E, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    0,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    1,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    2,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    3,  0,  2,  0 }, {     23,   16,    3,  0,  2,  0 }, {     22,   16,    4,  0,  2,  0 },
    {     21,   16,    4,  0,  2,  0 }, {     20,   16,    5,  0,  2,  0 }, {     19,   16,    5,  0,  2,  0 }, {     18,   16,    6,  0,  2,  0 }, {     17,   16,    6,  0,  2,  0 },
    {     16,   16,    7,  0,  2,  0 }, {     15,   16,    7,  0,  2,  0 }, {     14,   16,    8,  0,  2,  0 }, {     13,   16,    8,  0,  2,  0 }, {     12,   16,    9,  0,  3,  0 },
    {     11,   16,    9,  0,  3,  0 }, {     10,   16,   10,  0,  3,  0 }, {      9,   16,   10,  0,  3,  0 }, {      8,   16,   11,  0,  3,  0 }, {      7,   16,   11,  0,  3,  0 },
    {      6,   16,   12,  0,  3,  0 }, {      5,   16,   13,  0,  3,  0 }, {      4,   16,   14,  0,  3,  0 }, {      3,   16,   15,  0,  3,  0 }, {      2,   16,   15,  0,  3,  0 },
    {      1,   16,   16,  0,  3,  0 }, {      0,   16,   17,  0,  3,  0 }, {     -1,   16,   18,  0,  3,  0 }, {     -2,   16,   18,  0,  3,  0 }, {     -3,   16,   19,  0,  3,  0 },
    {     -4,   16,   20,  0,  3,  0 }, {     -5,   16,   21,  0,  3,  0 }, {     -6,   16,   22,  0,  3,  0 }, {     -7,   16,   23,  0,  3,  0 }, {     -8,   16,   24,  0,  3,  0 },
    {     -9,   16,   25,  0,  3,  0 }, {    -10,   16,   26,  0,  3,  0 }, {    -11,   16,   27,  0,  4,  0 }, {    -12,   16,   28,  0,  4,  0 }, {    -13,   16,   29,  0,  4,  0 },
    {    -13,   16,   30,  0,  4,  0 }, {    -14,   16,   31,  0,  4,  0 }, {    -15,   16,   32,  0,  4,  0 }, {    -16,   16,   33,  0,  4,  0 }, {    -16,   16,   34,  0,  4,  0 },
    {    -17,   16,   35,  0,  4,  0 }, {    -18,   16,   36,  0,  4,  0 }, {    -19,   16,   37,  0,  4,  0 }, {    -19,   16,   38,  0,  4,  0 }, {    -20,   16,   39,  0,  4,  0 },
    {    -20,   16,   40,  0,  4,  0 }, {    -21,   16,   41,  0,  4,  0 }, {    -22,   16,   42,  0,  4,  0 }, {    -22,   16,   43,  0,  9,  0 }, {    -23,   16,   44,  0,  9,  0 },
    {    -24,   16,   45,  0,  9,  0 }, {    -24,   16,   46,  0,  9,  0 }, {    -25,   16,   47,  0,  9,  0 }, {    -25,   16,   48,  0,  9,  0 }, {    -25,   16,   49,  0,  9,  0 },
    {    -26,   16,   50,  0,  9,  0 }, {    -26,   16,   51,  0,  9,  0 }, {    -26,   16,   52,  0,  9,  0 }, {    -27,   16,   53,  0,  9,  0 }, {    -27,   16,   54,  0,  9,  0 },
    {    -27,   16,   55,  0,  9,  0 }, {    -28,   16,   56,  0,  9,  0 }, {    -28,   16,   57,  0,  9,  0 }, {    -28,   16,   58,  0,  9,  0 }, {    -29,   16,   59,  0,  9,  0 },
    {    -29,   16,   60,  0,  9,  0 }, {    -29,   16,   61,  0,  9,  0 }, {    -30,   16,   62,  0,  9,  0 }, {    -30,   16,   63,  0,  9,  0 }, {    -30,   16,   64,  0, 10,  0 },
    {    -30,   16,   65,  0, 10,  0 }, {    -31,   16,   66,  0, 10,  0 }, {    -31,   16,   67,  0, 10,  0 }, {    -31,   16,   68,  0, 10,  0 }, {    -31,   16,   69,  0, 10,  0 },
    {    -31,   16,   70,  0, 10,  0 }, {    -32,   16,   71,  0, 10,  0 }, {    -32,   16,   72,  0, 10,  0 }, {    -32,   16,   73,  0, 10,  0 }, {    -32,   16,   74,  0, 10,  0 },
    {    -32,   16,   75,  0, 10,  0 }, {    -32,   16,   76,  0, 10,  0 }, {    -32,   16,   77,  0, 10,  0 }, {    -32,   16,   78,  0, 10,  0 }, {    -32,   16,   79,  0, 10,  0 },
    {    -32,   16,   80,  0, 10,  0 }, {    -32,   16,   81,  0, 10,  0 }, {    -32,   16,   82,  0, 10,  0 }, {    -32,   16,   83,  0, 10,  0 }, {    -32,   16,   84,  0, 10,  0 },
    {    -32,   16,   85,  0, 10,  0 }, {    -32,   16,   86,  0, 10,  0 }, {    -32,   16,   87,  0, 10,  0 }, {    -32,   16,   88,  0, 10,  0 }, {    -32,   16,   89,  0, 10,  0 },
    {    -32,   16,   90,  0, 10,  0 }, {    -32,   16,   91,  0, 10,  0 }, {    -32,   16,   92,  0, 10,  0 }, {    -32,   16,   93,  0, 10,  0 }, {    -32,   16,   94,  0, 10,  0 },
    {    -32,   16,   95,  0, 10,  0 }, {    -32,   16,   96,  0, 10,  0 }, {    -32,   16,   97,  0, 11,  0 }, {    -32,   16,   98,  0, 11,  0 }, {    -31,   16,   99,  0, 11,  0 },
    {    -31,   16,  100,  0, 11,  0 }, {    -31,   16,  101,  0, 11,  0 }, {    -31,   16,  102,  0, 11,  0 }, {    -31,   16,  103,  0, 11,  0 }, {    -30,   16,  104,  0, 11,  0 },
    {    -30,   16,  105,  0, 11,  0 }, {    -30,   16,  106,  0, 11,  0 }, {    -30,   16,  107,  0, 11,  0 }, {    -29,   16,  108,  0, 11,  0 }, {    -29,   16,  109,  0, 11,  0 },
    {    -29,   16,  110,  0, 11,  0 }, {    -28,   16,  111,  0, 12,  0 }, {    -28,   16,  112,  0, 12,  0 }, {    -27,   16,  113,  0, 12,  0 }, {    -27,   16,  114,  0, 12,  0 },
    {    -26,   16,  115,  0, 12,  0 }, {    -26,   16,  116,  0, 12,  0 }, {    -26,   16,  117,  0, 12,  0 }, {    -25,   16,  118,  0, 12,  0 }, {    -25,   16,  119,  0, 12,  0 },
    {    -24,   16,  120,  0, 13,  0 }, {    -24,   16,  121,  0, 13,  0 }, {    -23,   16,  122,  0, 13,  0 }, {    -22,   16,  123,  0, 13,  0 }, {    -22,   16,  124,  0, 13,  0 },
    {    -21,   16,  125,  0, 13,  0 }, {    -20,   16,  126,  0, 13,  0 }, {    -19,   16,  127,  0, 13,  0 }, {    -18,   16,  128,  0, 14,  0 }, {    -17,   16,  129,  0, 14,  0 },
    {    -16,   16,  130,  0, 14,  0 }, {    -15,   16,  130,  0, 14,  0 }, {    -14,   16,  131,  0, 14,  0 }, {    -13,   16,  132,  0, 15,  0 }, {    -12,   16,  133,  0, 15,  0 },
    {    -11,   16,  134,  0, 15,  0 }, {    -10,   16,  134,  0, 15,  0 }, {     -9,   16,  135,  0, 15,  0 }, {     -8,   16,  135,  0, 16,  0 }, {     -7,   16,  135,  0, 16,  0 },
    {     -6,   16,  136,  0, 16,  0 }, {     -5,   16,  136,  0, 16,  0 }, {     -4,   16,  136,  0, 16,  0 }, {     -3,   16,  136,  0, 16,  0 }, {     -2,   16,  136,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E69F9, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    2,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    3,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    3,  8,  2,  0 }, {     16,    9,    4,  8,  2,  0 },
    {     16,   10,    4,  8,  2,  0 }, {     16,   11,    5,  8,  2,  0 }, {     16,   12,    5,  8,  2,  0 }, {     16,   13,    6,  8,  2,  0 }, {     16,   14,    6,  8,  2,  0 },
    {     16,   15,    7,  8,  2,  0 }, {     16,   16,    7,  8,  2,  0 }, {     16,   17,    8,  8,  2,  0 }, {     16,   18,    8,  8,  2,  0 }, {     16,   19,    9,  8,  3,  0 },
    {     16,   20,    9,  8,  3,  0 }, {     16,   21,   10,  8,  3,  0 }, {     16,   22,   10,  8,  3,  0 }, {     16,   23,   11,  8,  3,  0 }, {     16,   24,   11,  8,  3,  0 },
    {     16,   25,   12,  8,  3,  0 }, {     16,   26,   13,  8,  3,  0 }, {     16,   27,   14,  8,  3,  0 }, {     16,   28,   15,  8,  3,  0 }, {     16,   29,   15,  8,  3,  0 },
    {     16,   30,   16,  8,  3,  0 }, {     16,   31,   17,  8,  3,  0 }, {     16,   32,   18,  8,  3,  0 }, {     16,   33,   18,  8,  3,  0 }, {     16,   34,   19,  8,  3,  0 },
    {     16,   35,   20,  8,  3,  0 }, {     16,   36,   21,  8,  3,  0 }, {     16,   37,   22,  8,  3,  0 }, {     16,   38,   23,  8,  3,  0 }, {     16,   39,   24,  8,  3,  0 },
    {     16,   40,   25,  8,  3,  0 }, {     16,   41,   26,  8,  3,  0 }, {     16,   42,   27,  8,  4,  0 }, {     16,   43,   28,  8,  4,  0 }, {     16,   44,   29,  8,  4,  0 },
    {     16,   44,   30,  8,  4,  0 }, {     16,   45,   31,  8,  4,  0 }, {     16,   46,   32,  8,  4,  0 }, {     16,   47,   33,  8,  4,  0 }, {     16,   47,   34,  8,  4,  0 },
    {     16,   48,   35,  8,  4,  0 }, {     16,   49,   36,  8,  4,  0 }, {     16,   50,   37,  8,  4,  0 }, {     16,   50,   38,  8,  4,  0 }, {     16,   51,   39,  8,  4,  0 },
    {     16,   51,   40,  8,  4,  0 }, {     16,   52,   41,  8,  4,  0 }, {     16,   53,   42,  8,  4,  0 }, {     16,   53,   43,  8,  9,  0 }, {     16,   54,   44,  8,  9,  0 },
    {     16,   55,   45,  8,  9,  0 }, {     16,   55,   46,  8,  9,  0 }, {     16,   56,   47,  8,  9,  0 }, {     16,   56,   48,  8,  9,  0 }, {     16,   56,   49,  8,  9,  0 },
    {     16,   57,   50,  8,  9,  0 }, {     16,   57,   51,  8,  9,  0 }, {     16,   57,   52,  8,  9,  0 }, {     16,   58,   53,  8,  9,  0 }, {     16,   58,   54,  8,  9,  0 },
    {     16,   58,   55,  8,  9,  0 }, {     16,   59,   56,  8,  9,  0 }, {     16,   59,   57,  8,  9,  0 }, {     16,   59,   58,  8,  9,  0 }, {     16,   60,   59,  8,  9,  0 },
    {     16,   60,   60,  8,  9,  0 }, {     16,   60,   61,  8,  9,  0 }, {     16,   61,   62,  8,  9,  0 }, {     16,   61,   63,  8,  9,  0 }, {     16,   61,   64,  8, 10,  0 },
    {     16,   61,   65,  8, 10,  0 }, {     16,   62,   66,  8, 10,  0 }, {     16,   62,   67,  8, 10,  0 }, {     16,   62,   68,  8, 10,  0 }, {     16,   62,   69,  8, 10,  0 },
    {     16,   62,   70,  8, 10,  0 }, {     16,   63,   71,  8, 10,  0 }, {     16,   63,   72,  8, 10,  0 }, {     16,   63,   73,  8, 10,  0 }, {     16,   63,   74,  8, 10,  0 },
    {     16,   63,   75,  8, 10,  0 }, {     16,   63,   76,  8, 10,  0 }, {     16,   63,   77,  8, 10,  0 }, {     16,   63,   78,  8, 10,  0 }, {     16,   63,   79,  8, 10,  0 },
    {     16,   63,   80,  8, 10,  0 }, {     16,   63,   81,  8, 10,  0 }, {     16,   63,   82,  8, 10,  0 }, {     16,   63,   83,  8, 10,  0 }, {     16,   63,   84,  8, 10,  0 },
    {     16,   63,   85,  8, 10,  0 }, {     16,   63,   86,  8, 10,  0 }, {     16,   63,   87,  8, 10,  0 }, {     16,   63,   88,  8, 10,  0 }, {     16,   63,   89,  8, 10,  0 },
    {     16,   63,   90,  8, 10,  0 }, {     16,   63,   91,  8, 10,  0 }, {     16,   63,   92,  8, 10,  0 }, {     16,   63,   93,  8, 10,  0 }, {     16,   63,   94,  8, 10,  0 },
    {     16,   63,   95,  8, 10,  0 }, {     16,   63,   96,  8, 10,  0 }, {     16,   63,   97,  8, 11,  0 }, {     16,   63,   98,  8, 11,  0 }, {     16,   62,   99,  8, 11,  0 },
    {     16,   62,  100,  8, 11,  0 }, {     16,   62,  101,  8, 11,  0 }, {     16,   62,  102,  8, 11,  0 }, {     16,   62,  103,  8, 11,  0 }, {     16,   61,  104,  8, 11,  0 },
    {     16,   61,  105,  8, 11,  0 }, {     16,   61,  106,  8, 11,  0 }, {     16,   61,  107,  8, 11,  0 }, {     16,   60,  108,  8, 11,  0 }, {     16,   60,  109,  8, 11,  0 },
    {     16,   60,  110,  8, 11,  0 }, {     16,   59,  111,  8, 12,  0 }, {     16,   59,  112,  8, 12,  0 }, {     16,   58,  113,  8, 12,  0 }, {     16,   58,  114,  8, 12,  0 },
    {     16,   57,  115,  8, 12,  0 }, {     16,   57,  116,  8, 12,  0 }, {     16,   57,  117,  8, 12,  0 }, {     16,   56,  118,  8, 12,  0 }, {     16,   56,  119,  8, 12,  0 },
    {     16,   55,  120,  8, 13,  0 }, {     16,   55,  121,  8, 13,  0 }, {     16,   54,  122,  8, 13,  0 }, {     16,   53,  123,  8, 13,  0 }, {     16,   53,  124,  8, 13,  0 },
    {     16,   52,  125,  8, 13,  0 }, {     16,   51,  126,  8, 13,  0 }, {     16,   50,  127,  8, 13,  0 }, {     16,   49,  128,  8, 14,  0 }, {     16,   48,  129,  8, 14,  0 },
    {     16,   47,  130,  8, 14,  0 }, {     16,   46,  130,  8, 14,  0 }, {     16,   45,  131,  8, 14,  0 }, {     16,   44,  132,  8, 15,  0 }, {     16,   43,  133,  8, 15,  0 },
    {     16,   42,  134,  8, 15,  0 }, {     16,   41,  134,  8, 15,  0 }, {     16,   40,  135,  8, 15,  0 }, {     16,   39,  135,  8, 16,  0 }, {     16,   38,  135,  8, 16,  0 },
    {     16,   37,  136,  8, 16,  0 }, {     16,   36,  136,  8, 16,  0 }, {     16,   35,  136,  8, 16,  0 }, {     16,   34,  136,  8, 16,  0 }, {     16,   33,  136,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E6FA4, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    2, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    3, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    3, 16,  2,  0 }, {      9,   16,    4, 16,  2,  0 },
    {     10,   16,    4, 16,  2,  0 }, {     11,   16,    5, 16,  2,  0 }, {     12,   16,    5, 16,  2,  0 }, {     13,   16,    6, 16,  2,  0 }, {     14,   16,    6, 16,  2,  0 },
    {     15,   16,    7, 16,  2,  0 }, {     16,   16,    7, 16,  2,  0 }, {     17,   16,    8, 16,  2,  0 }, {     18,   16,    8, 16,  2,  0 }, {     19,   16,    9, 16,  3,  0 },
    {     20,   16,    9, 16,  3,  0 }, {     21,   16,   10, 16,  3,  0 }, {     22,   16,   10, 16,  3,  0 }, {     23,   16,   11, 16,  3,  0 }, {     24,   16,   11, 16,  3,  0 },
    {     25,   16,   12, 16,  3,  0 }, {     26,   16,   13, 16,  3,  0 }, {     27,   16,   14, 16,  3,  0 }, {     28,   16,   15, 16,  3,  0 }, {     29,   16,   15, 16,  3,  0 },
    {     30,   16,   16, 16,  3,  0 }, {     31,   16,   17, 16,  3,  0 }, {     32,   16,   18, 16,  3,  0 }, {     33,   16,   18, 16,  3,  0 }, {     34,   16,   19, 16,  3,  0 },
    {     35,   16,   20, 16,  3,  0 }, {     36,   16,   21, 16,  3,  0 }, {     37,   16,   22, 16,  3,  0 }, {     38,   16,   23, 16,  3,  0 }, {     39,   16,   24, 16,  3,  0 },
    {     40,   16,   25, 16,  3,  0 }, {     41,   16,   26, 16,  3,  0 }, {     42,   16,   27, 16,  4,  0 }, {     43,   16,   28, 16,  4,  0 }, {     44,   16,   29, 16,  4,  0 },
    {     44,   16,   30, 16,  4,  0 }, {     45,   16,   31, 16,  4,  0 }, {     46,   16,   32, 16,  4,  0 }, {     47,   16,   33, 16,  4,  0 }, {     47,   16,   34, 16,  4,  0 },
    {     48,   16,   35, 16,  4,  0 }, {     49,   16,   36, 16,  4,  0 }, {     50,   16,   37, 16,  4,  0 }, {     50,   16,   38, 16,  4,  0 }, {     51,   16,   39, 16,  4,  0 },
    {     51,   16,   40, 16,  4,  0 }, {     52,   16,   41, 16,  4,  0 }, {     53,   16,   42, 16,  4,  0 }, {     53,   16,   43, 16,  9,  0 }, {     54,   16,   44, 16,  9,  0 },
    {     55,   16,   45, 16,  9,  0 }, {     55,   16,   46, 16,  9,  0 }, {     56,   16,   47, 16,  9,  0 }, {     56,   16,   48, 16,  9,  0 }, {     56,   16,   49, 16,  9,  0 },
    {     57,   16,   50, 16,  9,  0 }, {     57,   16,   51, 16,  9,  0 }, {     57,   16,   52, 16,  9,  0 }, {     58,   16,   53, 16,  9,  0 }, {     58,   16,   54, 16,  9,  0 },
    {     58,   16,   55, 16,  9,  0 }, {     59,   16,   56, 16,  9,  0 }, {     59,   16,   57, 16,  9,  0 }, {     59,   16,   58, 16,  9,  0 }, {     60,   16,   59, 16,  9,  0 },
    {     60,   16,   60, 16,  9,  0 }, {     60,   16,   61, 16,  9,  0 }, {     61,   16,   62, 16,  9,  0 }, {     61,   16,   63, 16,  9,  0 }, {     61,   16,   64, 16, 10,  0 },
    {     61,   16,   65, 16, 10,  0 }, {     62,   16,   66, 16, 10,  0 }, {     62,   16,   67, 16, 10,  0 }, {     62,   16,   68, 16, 10,  0 }, {     62,   16,   69, 16, 10,  0 },
    {     62,   16,   70, 16, 10,  0 }, {     63,   16,   71, 16, 10,  0 }, {     63,   16,   72, 16, 10,  0 }, {     63,   16,   73, 16, 10,  0 }, {     63,   16,   74, 16, 10,  0 },
    {     63,   16,   75, 16, 10,  0 }, {     63,   16,   76, 16, 10,  0 }, {     63,   16,   77, 16, 10,  0 }, {     63,   16,   78, 16, 10,  0 }, {     63,   16,   79, 16, 10,  0 },
    {     63,   16,   80, 16, 10,  0 }, {     63,   16,   81, 16, 10,  0 }, {     63,   16,   82, 16, 10,  0 }, {     63,   16,   83, 16, 10,  0 }, {     63,   16,   84, 16, 10,  0 },
    {     63,   16,   85, 16, 10,  0 }, {     63,   16,   86, 16, 10,  0 }, {     63,   16,   87, 16, 10,  0 }, {     63,   16,   88, 16, 10,  0 }, {     63,   16,   89, 16, 10,  0 },
    {     63,   16,   90, 16, 10,  0 }, {     63,   16,   91, 16, 10,  0 }, {     63,   16,   92, 16, 10,  0 }, {     63,   16,   93, 16, 10,  0 }, {     63,   16,   94, 16, 10,  0 },
    {     63,   16,   95, 16, 10,  0 }, {     63,   16,   96, 16, 10,  0 }, {     63,   16,   97, 16, 11,  0 }, {     63,   16,   98, 16, 11,  0 }, {     62,   16,   99, 16, 11,  0 },
    {     62,   16,  100, 16, 11,  0 }, {     62,   16,  101, 16, 11,  0 }, {     62,   16,  102, 16, 11,  0 }, {     62,   16,  103, 16, 11,  0 }, {     61,   16,  104, 16, 11,  0 },
    {     61,   16,  105, 16, 11,  0 }, {     61,   16,  106, 16, 11,  0 }, {     61,   16,  107, 16, 11,  0 }, {     60,   16,  108, 16, 11,  0 }, {     60,   16,  109, 16, 11,  0 },
    {     60,   16,  110, 16, 11,  0 }, {     59,   16,  111, 16, 12,  0 }, {     59,   16,  112, 16, 12,  0 }, {     58,   16,  113, 16, 12,  0 }, {     58,   16,  114, 16, 12,  0 },
    {     57,   16,  115, 16, 12,  0 }, {     57,   16,  116, 16, 12,  0 }, {     57,   16,  117, 16, 12,  0 }, {     56,   16,  118, 16, 12,  0 }, {     56,   16,  119, 16, 12,  0 },
    {     55,   16,  120, 16, 13,  0 }, {     55,   16,  121, 16, 13,  0 }, {     54,   16,  122, 16, 13,  0 }, {     53,   16,  123, 16, 13,  0 }, {     53,   16,  124, 16, 13,  0 },
    {     52,   16,  125, 16, 13,  0 }, {     51,   16,  126, 16, 13,  0 }, {     50,   16,  127, 16, 13,  0 }, {     49,   16,  128, 16, 14,  0 }, {     48,   16,  129, 16, 14,  0 },
    {     47,   16,  130, 16, 14,  0 }, {     46,   16,  130, 16, 14,  0 }, {     45,   16,  131, 16, 14,  0 }, {     44,   16,  132, 16, 15,  0 }, {     43,   16,  133, 16, 15,  0 },
    {     42,   16,  134, 16, 15,  0 }, {     41,   16,  134, 16, 15,  0 }, {     40,   16,  135, 16, 15,  0 }, {     39,   16,  135, 16, 16,  0 }, {     38,   16,  135, 16, 16,  0 },
    {     37,   16,  136, 16, 16,  0 }, {     36,   16,  136, 16, 16,  0 }, {     35,   16,  136, 16, 16,  0 }, {     34,   16,  136, 16, 16,  0 }, {     33,   16,  136, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E754F, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    0, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    1, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    2, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    3, 24,  2,  0 }, {     16,   23,    3, 24,  2,  0 }, {     16,   22,    4, 24,  2,  0 },
    {     16,   21,    4, 24,  2,  0 }, {     16,   20,    5, 24,  2,  0 }, {     16,   19,    5, 24,  2,  0 }, {     16,   18,    6, 24,  2,  0 }, {     16,   17,    6, 24,  2,  0 },
    {     16,   16,    7, 24,  2,  0 }, {     16,   15,    7, 24,  2,  0 }, {     16,   14,    8, 24,  2,  0 }, {     16,   13,    8, 24,  2,  0 }, {     16,   12,    9, 24,  3,  0 },
    {     16,   11,    9, 24,  3,  0 }, {     16,   10,   10, 24,  3,  0 }, {     16,    9,   10, 24,  3,  0 }, {     16,    8,   11, 24,  3,  0 }, {     16,    7,   11, 24,  3,  0 },
    {     16,    6,   12, 24,  3,  0 }, {     16,    5,   13, 24,  3,  0 }, {     16,    4,   14, 24,  3,  0 }, {     16,    3,   15, 24,  3,  0 }, {     16,    2,   15, 24,  3,  0 },
    {     16,    1,   16, 24,  3,  0 }, {     16,    0,   17, 24,  3,  0 }, {     16,   -1,   18, 24,  3,  0 }, {     16,   -2,   18, 24,  3,  0 }, {     16,   -3,   19, 24,  3,  0 },
    {     16,   -4,   20, 24,  3,  0 }, {     16,   -5,   21, 24,  3,  0 }, {     16,   -6,   22, 24,  3,  0 }, {     16,   -7,   23, 24,  3,  0 }, {     16,   -8,   24, 24,  3,  0 },
    {     16,   -9,   25, 24,  3,  0 }, {     16,  -10,   26, 24,  3,  0 }, {     16,  -11,   27, 24,  4,  0 }, {     16,  -12,   28, 24,  4,  0 }, {     16,  -13,   29, 24,  4,  0 },
    {     16,  -13,   30, 24,  4,  0 }, {     16,  -14,   31, 24,  4,  0 }, {     16,  -15,   32, 24,  4,  0 }, {     16,  -16,   33, 24,  4,  0 }, {     16,  -16,   34, 24,  4,  0 },
    {     16,  -17,   35, 24,  4,  0 }, {     16,  -18,   36, 24,  4,  0 }, {     16,  -19,   37, 24,  4,  0 }, {     16,  -19,   38, 24,  4,  0 }, {     16,  -20,   39, 24,  4,  0 },
    {     16,  -20,   40, 24,  4,  0 }, {     16,  -21,   41, 24,  4,  0 }, {     16,  -22,   42, 24,  4,  0 }, {     16,  -22,   43, 24,  9,  0 }, {     16,  -23,   44, 24,  9,  0 },
    {     16,  -24,   45, 24,  9,  0 }, {     16,  -24,   46, 24,  9,  0 }, {     16,  -25,   47, 24,  9,  0 }, {     16,  -25,   48, 24,  9,  0 }, {     16,  -25,   49, 24,  9,  0 },
    {     16,  -26,   50, 24,  9,  0 }, {     16,  -26,   51, 24,  9,  0 }, {     16,  -26,   52, 24,  9,  0 }, {     16,  -27,   53, 24,  9,  0 }, {     16,  -27,   54, 24,  9,  0 },
    {     16,  -27,   55, 24,  9,  0 }, {     16,  -28,   56, 24,  9,  0 }, {     16,  -28,   57, 24,  9,  0 }, {     16,  -28,   58, 24,  9,  0 }, {     16,  -29,   59, 24,  9,  0 },
    {     16,  -29,   60, 24,  9,  0 }, {     16,  -29,   61, 24,  9,  0 }, {     16,  -30,   62, 24,  9,  0 }, {     16,  -30,   63, 24,  9,  0 }, {     16,  -30,   64, 24, 10,  0 },
    {     16,  -30,   65, 24, 10,  0 }, {     16,  -31,   66, 24, 10,  0 }, {     16,  -31,   67, 24, 10,  0 }, {     16,  -31,   68, 24, 10,  0 }, {     16,  -31,   69, 24, 10,  0 },
    {     16,  -31,   70, 24, 10,  0 }, {     16,  -32,   71, 24, 10,  0 }, {     16,  -32,   72, 24, 10,  0 }, {     16,  -32,   73, 24, 10,  0 }, {     16,  -32,   74, 24, 10,  0 },
    {     16,  -32,   75, 24, 10,  0 }, {     16,  -32,   76, 24, 10,  0 }, {     16,  -32,   77, 24, 10,  0 }, {     16,  -32,   78, 24, 10,  0 }, {     16,  -32,   79, 24, 10,  0 },
    {     16,  -32,   80, 24, 10,  0 }, {     16,  -32,   81, 24, 10,  0 }, {     16,  -32,   82, 24, 10,  0 }, {     16,  -32,   83, 24, 10,  0 }, {     16,  -32,   84, 24, 10,  0 },
    {     16,  -32,   85, 24, 10,  0 }, {     16,  -32,   86, 24, 10,  0 }, {     16,  -32,   87, 24, 10,  0 }, {     16,  -32,   88, 24, 10,  0 }, {     16,  -32,   89, 24, 10,  0 },
    {     16,  -32,   90, 24, 10,  0 }, {     16,  -32,   91, 24, 10,  0 }, {     16,  -32,   92, 24, 10,  0 }, {     16,  -32,   93, 24, 10,  0 }, {     16,  -32,   94, 24, 10,  0 },
    {     16,  -32,   95, 24, 10,  0 }, {     16,  -32,   96, 24, 10,  0 }, {     16,  -32,   97, 24, 11,  0 }, {     16,  -32,   98, 24, 11,  0 }, {     16,  -31,   99, 24, 11,  0 },
    {     16,  -31,  100, 24, 11,  0 }, {     16,  -31,  101, 24, 11,  0 }, {     16,  -31,  102, 24, 11,  0 }, {     16,  -31,  103, 24, 11,  0 }, {     16,  -30,  104, 24, 11,  0 },
    {     16,  -30,  105, 24, 11,  0 }, {     16,  -30,  106, 24, 11,  0 }, {     16,  -30,  107, 24, 11,  0 }, {     16,  -29,  108, 24, 11,  0 }, {     16,  -29,  109, 24, 11,  0 },
    {     16,  -29,  110, 24, 11,  0 }, {     16,  -28,  111, 24, 12,  0 }, {     16,  -28,  112, 24, 12,  0 }, {     16,  -27,  113, 24, 12,  0 }, {     16,  -27,  114, 24, 12,  0 },
    {     16,  -26,  115, 24, 12,  0 }, {     16,  -26,  116, 24, 12,  0 }, {     16,  -26,  117, 24, 12,  0 }, {     16,  -25,  118, 24, 12,  0 }, {     16,  -25,  119, 24, 12,  0 },
    {     16,  -24,  120, 24, 13,  0 }, {     16,  -24,  121, 24, 13,  0 }, {     16,  -23,  122, 24, 13,  0 }, {     16,  -22,  123, 24, 13,  0 }, {     16,  -22,  124, 24, 13,  0 },
    {     16,  -21,  125, 24, 13,  0 }, {     16,  -20,  126, 24, 13,  0 }, {     16,  -19,  127, 24, 13,  0 }, {     16,  -18,  128, 24, 14,  0 }, {     16,  -17,  129, 24, 14,  0 },
    {     16,  -16,  130, 24, 14,  0 }, {     16,  -15,  130, 24, 14,  0 }, {     16,  -14,  131, 24, 14,  0 }, {     16,  -13,  132, 24, 15,  0 }, {     16,  -12,  133, 24, 15,  0 },
    {     16,  -11,  134, 24, 15,  0 }, {     16,  -10,  134, 24, 15,  0 }, {     16,   -9,  135, 24, 15,  0 }, {     16,   -8,  135, 24, 16,  0 }, {     16,   -7,  135, 24, 16,  0 },
    {     16,   -6,  136, 24, 16,  0 }, {     16,   -5,  136, 24, 16,  0 }, {     16,   -4,  136, 24, 16,  0 }, {     16,   -3,  136, 24, 16,  0 }, {     16,   -2,  136, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E7AFA, {
    {     31,   16,   16, 16, 16,  0 }, {     30,   16,   16, 16, 16,  0 }, {     29,   16,   16, 16, 16,  0 }, {     28,   16,   16, 16, 16,  0 }, {     27,   16,   16, 16, 16,  0 },
    {     26,   16,   16, 16, 23,  0 }, {     25,   16,   15, 16, 23,  0 }, {     24,   16,   15, 16, 23,  0 }, {     23,   16,   15, 16, 23,  0 }, {     22,   16,   14, 16, 23,  0 },
    {     21,   16,   14, 16, 22,  0 }, {     20,   16,   13, 16, 22,  0 }, {     19,   16,   12, 16, 22,  0 }, {     18,   16,   11, 16, 22,  0 }, {     17,   16,   10, 16, 22,  0 },
    {     16,   16,   10, 16, 21,  0 }, {     15,   16,    9, 16, 21,  0 }, {     14,   16,    8, 16, 21,  0 }, {     13,   16,    7, 16, 21,  0 }, {     12,   16,    6, 16, 21,  0 },
    {     11,   16,    5, 16, 21,  0 }, {     10,   16,    4, 16, 21,  0 }, {     10,   16,    3, 16, 21,  0 }, {      9,   16,    2, 16, 20,  0 }, {      8,   16,    1, 16, 20,  0 },
    {      8,   16,    0, 16, 20,  0 }, {      7,   16,   -1, 16, 20,  0 }, {      7,   16,   -2, 16, 20,  0 }, {      6,   16,   -3, 16, 20,  0 }, {      6,   16,   -4, 16, 20,  0 },
    {      6,   16,   -5, 16, 20,  0 }, {      5,   16,   -6, 16, 20,  0 }, {      5,   16,   -7, 16, 19,  0 }, {      4,   16,   -8, 16, 19,  0 }, {      4,   16,   -9, 16, 19,  0 },
    {      3,   16,  -10, 16, 19,  0 }, {      3,   16,  -11, 16, 19,  0 }, {      3,   16,  -12, 16, 19,  0 }, {      2,   16,  -13, 16, 19,  0 }, {      2,   16,  -14, 16, 19,  0 },
    {      2,   16,  -15, 16, 19,  0 }, {      2,   16,  -16, 16, 19,  0 }, {      1,   16,  -17, 16, 19,  0 }, {      1,   16,  -18, 16, 19,  0 }, {      1,   16,  -19, 16, 19,  0 },
    {      1,   16,  -20, 16, 19,  0 }, {      1,   16,  -21, 16, 18,  0 }, {      0,   16,  -22, 16, 18,  0 }, {      0,   16,  -23, 16, 18,  0 }, {      0,   16,  -24, 16, 18,  0 },
    {      0,   16,  -25, 16, 18,  0 }, {      0,   16,  -26, 16, 18,  0 }, {      0,   16,  -27, 16, 18,  0 }, {      0,   16,  -28, 16, 18,  0 }, {      0,   16,  -29, 16, 18,  0 },
    {      0,   16,  -30, 16, 18,  0 }, {      0,   16,  -31, 16, 18,  0 }, {      0,   16,  -32, 16, 18,  0 }, {      0,   16,  -33, 16, 18,  0 }, {      0,   16,  -34, 16, 18,  0 },
    {      0,   16,  -35, 16, 18,  0 }, {      0,   16,  -36, 16, 18,  0 }, {      0,   16,  -37, 16, 18,  0 }, {      0,   16,  -38, 16, 18,  0 }, {      0,   16,  -39, 16, 18,  0 },
    {      0,   16,  -40, 16, 18,  0 }, {      0,   16,  -41, 16, 18,  0 }, {      0,   16,  -42, 16, 18,  0 }, {      0,   16,  -43, 16, 18,  0 }, {      0,   16,  -44, 16, 18,  0 },
    {      0,   16,  -45, 16, 18,  0 }, {      0,   16,  -46, 16, 18,  0 }, {      0,   16,  -47, 16, 18,  0 }, {      0,   16,  -48, 16, 18,  0 }, {      0,   16,  -49, 16, 18,  0 },
    {      1,   16,  -50, 16, 18,  0 }, {      1,   16,  -51, 16, 18,  0 }, {      1,   16,  -52, 16, 18,  0 }, {      1,   16,  -53, 16, 18,  0 }, {      1,   16,  -54, 16, 17,  0 },
    {      2,   16,  -55, 16, 17,  0 }, {      2,   16,  -56, 16, 17,  0 }, {      2,   16,  -57, 16, 17,  0 }, {      2,   16,  -58, 16, 17,  0 }, {      3,   16,  -59, 16, 17,  0 },
    {      3,   16,  -60, 16, 17,  0 }, {      3,   16,  -61, 16, 17,  0 }, {      4,   16,  -62, 16, 17,  0 }, {      4,   16,  -63, 16, 17,  0 }, {      4,   16,  -64, 16, 17,  0 },
    {      5,   16,  -65, 16, 17,  0 }, {      5,   16,  -66, 16, 17,  0 }, {      5,   16,  -67, 16, 17,  0 }, {      6,   16,  -68, 16, 17,  0 }, {      6,   16,  -69, 16, 17,  0 },
    {      6,   16,  -70, 16, 17,  0 }, {      7,   16,  -71, 16, 17,  0 }, {      7,   16,  -72, 16, 17,  0 }, {      7,   16,  -73, 16, 17,  0 }, {      8,   16,  -74, 16, 17,  0 },
    {      8,   16,  -75, 16,  8,  0 }, {      9,   16,  -76, 16,  8,  0 }, {     10,   16,  -77, 16,  8,  0 }, {     10,   16,  -78, 16,  8,  0 }, {     11,   16,  -79, 16,  8,  0 },
    {     12,   16,  -80, 16,  8,  0 }, {     12,   16,  -81, 16,  8,  0 }, {     13,   16,  -82, 16,  8,  0 }, {     13,   16,  -83, 16,  8,  0 }, {     14,   16,  -84, 16,  8,  0 },
    {     15,   16,  -85, 16,  8,  0 }, {     16,   16,  -86, 16,  8,  0 }, {     16,   16,  -87, 16,  8,  0 }, {     17,   16,  -88, 16,  8,  0 }, {     18,   16,  -89, 16,  8,  0 },
    {     19,   16,  -90, 16,  8,  0 }, {     19,   16,  -91, 16,  7,  0 }, {     20,   16,  -92, 16,  7,  0 }, {     21,   16,  -93, 16,  7,  0 }, {     22,   16,  -94, 16,  7,  0 },
    {     23,   16,  -95, 16,  7,  0 }, {     24,   16,  -96, 16,  7,  0 }, {     25,   16,  -97, 16,  7,  0 }, {     26,   16,  -98, 16,  7,  0 }, {     27,   16,  -99, 16,  7,  0 },
    {     28,   16, -100, 16,  7,  0 }, {     29,   16, -101, 16,  7,  0 }, {     30,   16, -102, 16,  7,  0 }, {     31,   16, -102, 16,  7,  0 }, {     32,   16, -103, 16,  7,  0 },
    {     33,   16, -104, 16,  7,  0 }, {     34,   16, -105, 16,  7,  0 }, {     35,   16, -105, 16,  7,  0 }, {     36,   16, -106, 16,  7,  0 }, {     37,   16, -107, 16,  7,  0 },
    {     38,   16, -108, 16,  7,  0 }, {     39,   16, -109, 16,  7,  0 }, {     40,   16, -109, 16,  7,  0 }, {     41,   16, -110, 16,  7,  0 }, {     42,   16, -110, 16,  6,  0 },
    {     43,   16, -111, 16,  6,  0 }, {     44,   16, -111, 16,  6,  0 }, {     45,   16, -112, 16,  6,  0 }, {     46,   16, -112, 16,  6,  0 }, {     47,   16, -113, 16,  6,  0 },
    {     48,   16, -113, 16,  6,  0 }, {     49,   16, -114, 16,  6,  0 }, {     50,   16, -114, 16,  6,  0 }, {     51,   16, -115, 16,  6,  0 }, {     52,   16, -115, 16,  6,  0 },
    {     53,   16, -116, 16,  6,  0 }, {     54,   16, -116, 16,  6,  0 }, {     55,   16, -117, 16,  6,  0 }, {     56,   16, -117, 16,  6,  0 }, {     57,   16, -117, 16,  6,  0 },
    {     58,   16, -118, 16,  6,  0 }, {     59,   16, -118, 16,  6,  0 }, {     60,   16, -119, 16,  6,  0 }, {     61,   16, -119, 16,  6,  0 }, {     62,   16, -120, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E80A5, {
    {     16,    0,   16, 24, 16,  0 }, {     16,    1,   16, 24, 16,  0 }, {     16,    2,   16, 24, 16,  0 }, {     16,    3,   16, 24, 16,  0 }, {     16,    4,   16, 24, 16,  0 },
    {     16,    5,   16, 24, 23,  0 }, {     16,    6,   15, 24, 23,  0 }, {     16,    7,   15, 24, 23,  0 }, {     16,    8,   15, 24, 23,  0 }, {     16,    9,   14, 24, 23,  0 },
    {     16,   10,   14, 24, 22,  0 }, {     16,   11,   13, 24, 22,  0 }, {     16,   12,   12, 24, 22,  0 }, {     16,   13,   11, 24, 22,  0 }, {     16,   14,   10, 24, 22,  0 },
    {     16,   15,   10, 24, 21,  0 }, {     16,   16,    9, 24, 21,  0 }, {     16,   17,    8, 24, 21,  0 }, {     16,   18,    7, 24, 21,  0 }, {     16,   19,    6, 24, 21,  0 },
    {     16,   20,    5, 24, 21,  0 }, {     16,   21,    4, 24, 21,  0 }, {     16,   21,    3, 24, 21,  0 }, {     16,   22,    2, 24, 20,  0 }, {     16,   23,    1, 24, 20,  0 },
    {     16,   23,    0, 24, 20,  0 }, {     16,   24,   -1, 24, 20,  0 }, {     16,   24,   -2, 24, 20,  0 }, {     16,   25,   -3, 24, 20,  0 }, {     16,   25,   -4, 24, 20,  0 },
    {     16,   25,   -5, 24, 20,  0 }, {     16,   26,   -6, 24, 20,  0 }, {     16,   26,   -7, 24, 19,  0 }, {     16,   27,   -8, 24, 19,  0 }, {     16,   27,   -9, 24, 19,  0 },
    {     16,   28,  -10, 24, 19,  0 }, {     16,   28,  -11, 24, 19,  0 }, {     16,   28,  -12, 24, 19,  0 }, {     16,   29,  -13, 24, 19,  0 }, {     16,   29,  -14, 24, 19,  0 },
    {     16,   29,  -15, 24, 19,  0 }, {     16,   29,  -16, 24, 19,  0 }, {     16,   30,  -17, 24, 19,  0 }, {     16,   30,  -18, 24, 19,  0 }, {     16,   30,  -19, 24, 19,  0 },
    {     16,   30,  -20, 24, 19,  0 }, {     16,   30,  -21, 24, 18,  0 }, {     16,   31,  -22, 24, 18,  0 }, {     16,   31,  -23, 24, 18,  0 }, {     16,   31,  -24, 24, 18,  0 },
    {     16,   31,  -25, 24, 18,  0 }, {     16,   31,  -26, 24, 18,  0 }, {     16,   31,  -27, 24, 18,  0 }, {     16,   31,  -28, 24, 18,  0 }, {     16,   31,  -29, 24, 18,  0 },
    {     16,   31,  -30, 24, 18,  0 }, {     16,   31,  -31, 24, 18,  0 }, {     16,   31,  -32, 24, 18,  0 }, {     16,   31,  -33, 24, 18,  0 }, {     16,   31,  -34, 24, 18,  0 },
    {     16,   31,  -35, 24, 18,  0 }, {     16,   31,  -36, 24, 18,  0 }, {     16,   31,  -37, 24, 18,  0 }, {     16,   31,  -38, 24, 18,  0 }, {     16,   31,  -39, 24, 18,  0 },
    {     16,   31,  -40, 24, 18,  0 }, {     16,   31,  -41, 24, 18,  0 }, {     16,   31,  -42, 24, 18,  0 }, {     16,   31,  -43, 24, 18,  0 }, {     16,   31,  -44, 24, 18,  0 },
    {     16,   31,  -45, 24, 18,  0 }, {     16,   31,  -46, 24, 18,  0 }, {     16,   31,  -47, 24, 18,  0 }, {     16,   31,  -48, 24, 18,  0 }, {     16,   31,  -49, 24, 18,  0 },
    {     16,   30,  -50, 24, 18,  0 }, {     16,   30,  -51, 24, 18,  0 }, {     16,   30,  -52, 24, 18,  0 }, {     16,   30,  -53, 24, 18,  0 }, {     16,   30,  -54, 24, 17,  0 },
    {     16,   29,  -55, 24, 17,  0 }, {     16,   29,  -56, 24, 17,  0 }, {     16,   29,  -57, 24, 17,  0 }, {     16,   29,  -58, 24, 17,  0 }, {     16,   28,  -59, 24, 17,  0 },
    {     16,   28,  -60, 24, 17,  0 }, {     16,   28,  -61, 24, 17,  0 }, {     16,   27,  -62, 24, 17,  0 }, {     16,   27,  -63, 24, 17,  0 }, {     16,   27,  -64, 24, 17,  0 },
    {     16,   26,  -65, 24, 17,  0 }, {     16,   26,  -66, 24, 17,  0 }, {     16,   26,  -67, 24, 17,  0 }, {     16,   25,  -68, 24, 17,  0 }, {     16,   25,  -69, 24, 17,  0 },
    {     16,   25,  -70, 24, 17,  0 }, {     16,   24,  -71, 24, 17,  0 }, {     16,   24,  -72, 24, 17,  0 }, {     16,   24,  -73, 24, 17,  0 }, {     16,   23,  -74, 24, 17,  0 },
    {     16,   23,  -75, 24,  8,  0 }, {     16,   22,  -76, 24,  8,  0 }, {     16,   21,  -77, 24,  8,  0 }, {     16,   21,  -78, 24,  8,  0 }, {     16,   20,  -79, 24,  8,  0 },
    {     16,   19,  -80, 24,  8,  0 }, {     16,   19,  -81, 24,  8,  0 }, {     16,   18,  -82, 24,  8,  0 }, {     16,   18,  -83, 24,  8,  0 }, {     16,   17,  -84, 24,  8,  0 },
    {     16,   16,  -85, 24,  8,  0 }, {     16,   15,  -86, 24,  8,  0 }, {     16,   15,  -87, 24,  8,  0 }, {     16,   14,  -88, 24,  8,  0 }, {     16,   13,  -89, 24,  8,  0 },
    {     16,   12,  -90, 24,  8,  0 }, {     16,   12,  -91, 24,  7,  0 }, {     16,   11,  -92, 24,  7,  0 }, {     16,   10,  -93, 24,  7,  0 }, {     16,    9,  -94, 24,  7,  0 },
    {     16,    8,  -95, 24,  7,  0 }, {     16,    7,  -96, 24,  7,  0 }, {     16,    6,  -97, 24,  7,  0 }, {     16,    5,  -98, 24,  7,  0 }, {     16,    4,  -99, 24,  7,  0 },
    {     16,    3, -100, 24,  7,  0 }, {     16,    2, -101, 24,  7,  0 }, {     16,    1, -102, 24,  7,  0 }, {     16,    0, -102, 24,  7,  0 }, {     16,   -1, -103, 24,  7,  0 },
    {     16,   -2, -104, 24,  7,  0 }, {     16,   -3, -105, 24,  7,  0 }, {     16,   -4, -105, 24,  7,  0 }, {     16,   -5, -106, 24,  7,  0 }, {     16,   -6, -107, 24,  7,  0 },
    {     16,   -7, -108, 24,  7,  0 }, {     16,   -8, -109, 24,  7,  0 }, {     16,   -9, -109, 24,  7,  0 }, {     16,  -10, -110, 24,  7,  0 }, {     16,  -11, -110, 24,  6,  0 },
    {     16,  -12, -111, 24,  6,  0 }, {     16,  -13, -111, 24,  6,  0 }, {     16,  -14, -112, 24,  6,  0 }, {     16,  -15, -112, 24,  6,  0 }, {     16,  -16, -113, 24,  6,  0 },
    {     16,  -17, -113, 24,  6,  0 }, {     16,  -18, -114, 24,  6,  0 }, {     16,  -19, -114, 24,  6,  0 }, {     16,  -20, -115, 24,  6,  0 }, {     16,  -21, -115, 24,  6,  0 },
    {     16,  -22, -116, 24,  6,  0 }, {     16,  -23, -116, 24,  6,  0 }, {     16,  -24, -117, 24,  6,  0 }, {     16,  -25, -117, 24,  6,  0 }, {     16,  -26, -117, 24,  6,  0 },
    {     16,  -27, -118, 24,  6,  0 }, {     16,  -28, -118, 24,  6,  0 }, {     16,  -29, -119, 24,  6,  0 }, {     16,  -30, -119, 24,  6,  0 }, {     16,  -31, -120, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E8650, {
    {      0,   16,   16,  0, 16,  0 }, {      1,   16,   16,  0, 16,  0 }, {      2,   16,   16,  0, 16,  0 }, {      3,   16,   16,  0, 16,  0 }, {      4,   16,   16,  0, 16,  0 },
    {      5,   16,   16,  0, 23,  0 }, {      6,   16,   15,  0, 23,  0 }, {      7,   16,   15,  0, 23,  0 }, {      8,   16,   15,  0, 23,  0 }, {      9,   16,   14,  0, 23,  0 },
    {     10,   16,   14,  0, 22,  0 }, {     11,   16,   13,  0, 22,  0 }, {     12,   16,   12,  0, 22,  0 }, {     13,   16,   11,  0, 22,  0 }, {     14,   16,   10,  0, 22,  0 },
    {     15,   16,   10,  0, 21,  0 }, {     16,   16,    9,  0, 21,  0 }, {     17,   16,    8,  0, 21,  0 }, {     18,   16,    7,  0, 21,  0 }, {     19,   16,    6,  0, 21,  0 },
    {     20,   16,    5,  0, 21,  0 }, {     21,   16,    4,  0, 21,  0 }, {     21,   16,    3,  0, 21,  0 }, {     22,   16,    2,  0, 20,  0 }, {     23,   16,    1,  0, 20,  0 },
    {     23,   16,    0,  0, 20,  0 }, {     24,   16,   -1,  0, 20,  0 }, {     24,   16,   -2,  0, 20,  0 }, {     25,   16,   -3,  0, 20,  0 }, {     25,   16,   -4,  0, 20,  0 },
    {     25,   16,   -5,  0, 20,  0 }, {     26,   16,   -6,  0, 20,  0 }, {     26,   16,   -7,  0, 19,  0 }, {     27,   16,   -8,  0, 19,  0 }, {     27,   16,   -9,  0, 19,  0 },
    {     28,   16,  -10,  0, 19,  0 }, {     28,   16,  -11,  0, 19,  0 }, {     28,   16,  -12,  0, 19,  0 }, {     29,   16,  -13,  0, 19,  0 }, {     29,   16,  -14,  0, 19,  0 },
    {     29,   16,  -15,  0, 19,  0 }, {     29,   16,  -16,  0, 19,  0 }, {     30,   16,  -17,  0, 19,  0 }, {     30,   16,  -18,  0, 19,  0 }, {     30,   16,  -19,  0, 19,  0 },
    {     30,   16,  -20,  0, 19,  0 }, {     30,   16,  -21,  0, 18,  0 }, {     31,   16,  -22,  0, 18,  0 }, {     31,   16,  -23,  0, 18,  0 }, {     31,   16,  -24,  0, 18,  0 },
    {     31,   16,  -25,  0, 18,  0 }, {     31,   16,  -26,  0, 18,  0 }, {     31,   16,  -27,  0, 18,  0 }, {     31,   16,  -28,  0, 18,  0 }, {     31,   16,  -29,  0, 18,  0 },
    {     31,   16,  -30,  0, 18,  0 }, {     31,   16,  -31,  0, 18,  0 }, {     31,   16,  -32,  0, 18,  0 }, {     31,   16,  -33,  0, 18,  0 }, {     31,   16,  -34,  0, 18,  0 },
    {     31,   16,  -35,  0, 18,  0 }, {     31,   16,  -36,  0, 18,  0 }, {     31,   16,  -37,  0, 18,  0 }, {     31,   16,  -38,  0, 18,  0 }, {     31,   16,  -39,  0, 18,  0 },
    {     31,   16,  -40,  0, 18,  0 }, {     31,   16,  -41,  0, 18,  0 }, {     31,   16,  -42,  0, 18,  0 }, {     31,   16,  -43,  0, 18,  0 }, {     31,   16,  -44,  0, 18,  0 },
    {     31,   16,  -45,  0, 18,  0 }, {     31,   16,  -46,  0, 18,  0 }, {     31,   16,  -47,  0, 18,  0 }, {     31,   16,  -48,  0, 18,  0 }, {     31,   16,  -49,  0, 18,  0 },
    {     30,   16,  -50,  0, 18,  0 }, {     30,   16,  -51,  0, 18,  0 }, {     30,   16,  -52,  0, 18,  0 }, {     30,   16,  -53,  0, 18,  0 }, {     30,   16,  -54,  0, 17,  0 },
    {     29,   16,  -55,  0, 17,  0 }, {     29,   16,  -56,  0, 17,  0 }, {     29,   16,  -57,  0, 17,  0 }, {     29,   16,  -58,  0, 17,  0 }, {     28,   16,  -59,  0, 17,  0 },
    {     28,   16,  -60,  0, 17,  0 }, {     28,   16,  -61,  0, 17,  0 }, {     27,   16,  -62,  0, 17,  0 }, {     27,   16,  -63,  0, 17,  0 }, {     27,   16,  -64,  0, 17,  0 },
    {     26,   16,  -65,  0, 17,  0 }, {     26,   16,  -66,  0, 17,  0 }, {     26,   16,  -67,  0, 17,  0 }, {     25,   16,  -68,  0, 17,  0 }, {     25,   16,  -69,  0, 17,  0 },
    {     25,   16,  -70,  0, 17,  0 }, {     24,   16,  -71,  0, 17,  0 }, {     24,   16,  -72,  0, 17,  0 }, {     24,   16,  -73,  0, 17,  0 }, {     23,   16,  -74,  0, 17,  0 },
    {     23,   16,  -75,  0,  8,  0 }, {     22,   16,  -76,  0,  8,  0 }, {     21,   16,  -77,  0,  8,  0 }, {     21,   16,  -78,  0,  8,  0 }, {     20,   16,  -79,  0,  8,  0 },
    {     19,   16,  -80,  0,  8,  0 }, {     19,   16,  -81,  0,  8,  0 }, {     18,   16,  -82,  0,  8,  0 }, {     18,   16,  -83,  0,  8,  0 }, {     17,   16,  -84,  0,  8,  0 },
    {     16,   16,  -85,  0,  8,  0 }, {     15,   16,  -86,  0,  8,  0 }, {     15,   16,  -87,  0,  8,  0 }, {     14,   16,  -88,  0,  8,  0 }, {     13,   16,  -89,  0,  8,  0 },
    {     12,   16,  -90,  0,  8,  0 }, {     12,   16,  -91,  0,  7,  0 }, {     11,   16,  -92,  0,  7,  0 }, {     10,   16,  -93,  0,  7,  0 }, {      9,   16,  -94,  0,  7,  0 },
    {      8,   16,  -95,  0,  7,  0 }, {      7,   16,  -96,  0,  7,  0 }, {      6,   16,  -97,  0,  7,  0 }, {      5,   16,  -98,  0,  7,  0 }, {      4,   16,  -99,  0,  7,  0 },
    {      3,   16, -100,  0,  7,  0 }, {      2,   16, -101,  0,  7,  0 }, {      1,   16, -102,  0,  7,  0 }, {      0,   16, -102,  0,  7,  0 }, {     -1,   16, -103,  0,  7,  0 },
    {     -2,   16, -104,  0,  7,  0 }, {     -3,   16, -105,  0,  7,  0 }, {     -4,   16, -105,  0,  7,  0 }, {     -5,   16, -106,  0,  7,  0 }, {     -6,   16, -107,  0,  7,  0 },
    {     -7,   16, -108,  0,  7,  0 }, {     -8,   16, -109,  0,  7,  0 }, {     -9,   16, -109,  0,  7,  0 }, {    -10,   16, -110,  0,  7,  0 }, {    -11,   16, -110,  0,  6,  0 },
    {    -12,   16, -111,  0,  6,  0 }, {    -13,   16, -111,  0,  6,  0 }, {    -14,   16, -112,  0,  6,  0 }, {    -15,   16, -112,  0,  6,  0 }, {    -16,   16, -113,  0,  6,  0 },
    {    -17,   16, -113,  0,  6,  0 }, {    -18,   16, -114,  0,  6,  0 }, {    -19,   16, -114,  0,  6,  0 }, {    -20,   16, -115,  0,  6,  0 }, {    -21,   16, -115,  0,  6,  0 },
    {    -22,   16, -116,  0,  6,  0 }, {    -23,   16, -116,  0,  6,  0 }, {    -24,   16, -117,  0,  6,  0 }, {    -25,   16, -117,  0,  6,  0 }, {    -26,   16, -117,  0,  6,  0 },
    {    -27,   16, -118,  0,  6,  0 }, {    -28,   16, -118,  0,  6,  0 }, {    -29,   16, -119,  0,  6,  0 }, {    -30,   16, -119,  0,  6,  0 }, {    -31,   16, -120,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E8BFB, {
    {     16,   31,   16,  8, 16,  0 }, {     16,   30,   16,  8, 16,  0 }, {     16,   29,   16,  8, 16,  0 }, {     16,   28,   16,  8, 16,  0 }, {     16,   27,   16,  8, 16,  0 },
    {     16,   26,   16,  8, 23,  0 }, {     16,   25,   15,  8, 23,  0 }, {     16,   24,   15,  8, 23,  0 }, {     16,   23,   15,  8, 23,  0 }, {     16,   22,   14,  8, 23,  0 },
    {     16,   21,   14,  8, 22,  0 }, {     16,   20,   13,  8, 22,  0 }, {     16,   19,   12,  8, 22,  0 }, {     16,   18,   11,  8, 22,  0 }, {     16,   17,   10,  8, 22,  0 },
    {     16,   16,   10,  8, 21,  0 }, {     16,   15,    9,  8, 21,  0 }, {     16,   14,    8,  8, 21,  0 }, {     16,   13,    7,  8, 21,  0 }, {     16,   12,    6,  8, 21,  0 },
    {     16,   11,    5,  8, 21,  0 }, {     16,   10,    4,  8, 21,  0 }, {     16,   10,    3,  8, 21,  0 }, {     16,    9,    2,  8, 20,  0 }, {     16,    8,    1,  8, 20,  0 },
    {     16,    8,    0,  8, 20,  0 }, {     16,    7,   -1,  8, 20,  0 }, {     16,    7,   -2,  8, 20,  0 }, {     16,    6,   -3,  8, 20,  0 }, {     16,    6,   -4,  8, 20,  0 },
    {     16,    6,   -5,  8, 20,  0 }, {     16,    5,   -6,  8, 20,  0 }, {     16,    5,   -7,  8, 19,  0 }, {     16,    4,   -8,  8, 19,  0 }, {     16,    4,   -9,  8, 19,  0 },
    {     16,    3,  -10,  8, 19,  0 }, {     16,    3,  -11,  8, 19,  0 }, {     16,    3,  -12,  8, 19,  0 }, {     16,    2,  -13,  8, 19,  0 }, {     16,    2,  -14,  8, 19,  0 },
    {     16,    2,  -15,  8, 19,  0 }, {     16,    2,  -16,  8, 19,  0 }, {     16,    1,  -17,  8, 19,  0 }, {     16,    1,  -18,  8, 19,  0 }, {     16,    1,  -19,  8, 19,  0 },
    {     16,    1,  -20,  8, 19,  0 }, {     16,    1,  -21,  8, 18,  0 }, {     16,    0,  -22,  8, 18,  0 }, {     16,    0,  -23,  8, 18,  0 }, {     16,    0,  -24,  8, 18,  0 },
    {     16,    0,  -25,  8, 18,  0 }, {     16,    0,  -26,  8, 18,  0 }, {     16,    0,  -27,  8, 18,  0 }, {     16,    0,  -28,  8, 18,  0 }, {     16,    0,  -29,  8, 18,  0 },
    {     16,    0,  -30,  8, 18,  0 }, {     16,    0,  -31,  8, 18,  0 }, {     16,    0,  -32,  8, 18,  0 }, {     16,    0,  -33,  8, 18,  0 }, {     16,    0,  -34,  8, 18,  0 },
    {     16,    0,  -35,  8, 18,  0 }, {     16,    0,  -36,  8, 18,  0 }, {     16,    0,  -37,  8, 18,  0 }, {     16,    0,  -38,  8, 18,  0 }, {     16,    0,  -39,  8, 18,  0 },
    {     16,    0,  -40,  8, 18,  0 }, {     16,    0,  -41,  8, 18,  0 }, {     16,    0,  -42,  8, 18,  0 }, {     16,    0,  -43,  8, 18,  0 }, {     16,    0,  -44,  8, 18,  0 },
    {     16,    0,  -45,  8, 18,  0 }, {     16,    0,  -46,  8, 18,  0 }, {     16,    0,  -47,  8, 18,  0 }, {     16,    0,  -48,  8, 18,  0 }, {     16,    0,  -49,  8, 18,  0 },
    {     16,    1,  -50,  8, 18,  0 }, {     16,    1,  -51,  8, 18,  0 }, {     16,    1,  -52,  8, 18,  0 }, {     16,    1,  -53,  8, 18,  0 }, {     16,    1,  -54,  8, 17,  0 },
    {     16,    2,  -55,  8, 17,  0 }, {     16,    2,  -56,  8, 17,  0 }, {     16,    2,  -57,  8, 17,  0 }, {     16,    2,  -58,  8, 17,  0 }, {     16,    3,  -59,  8, 17,  0 },
    {     16,    3,  -60,  8, 17,  0 }, {     16,    3,  -61,  8, 17,  0 }, {     16,    4,  -62,  8, 17,  0 }, {     16,    4,  -63,  8, 17,  0 }, {     16,    4,  -64,  8, 17,  0 },
    {     16,    5,  -65,  8, 17,  0 }, {     16,    5,  -66,  8, 17,  0 }, {     16,    5,  -67,  8, 17,  0 }, {     16,    6,  -68,  8, 17,  0 }, {     16,    6,  -69,  8, 17,  0 },
    {     16,    6,  -70,  8, 17,  0 }, {     16,    7,  -71,  8, 17,  0 }, {     16,    7,  -72,  8, 17,  0 }, {     16,    7,  -73,  8, 17,  0 }, {     16,    8,  -74,  8, 17,  0 },
    {     16,    8,  -75,  8,  8,  0 }, {     16,    9,  -76,  8,  8,  0 }, {     16,   10,  -77,  8,  8,  0 }, {     16,   10,  -78,  8,  8,  0 }, {     16,   11,  -79,  8,  8,  0 },
    {     16,   12,  -80,  8,  8,  0 }, {     16,   12,  -81,  8,  8,  0 }, {     16,   13,  -82,  8,  8,  0 }, {     16,   13,  -83,  8,  8,  0 }, {     16,   14,  -84,  8,  8,  0 },
    {     16,   15,  -85,  8,  8,  0 }, {     16,   16,  -86,  8,  8,  0 }, {     16,   16,  -87,  8,  8,  0 }, {     16,   17,  -88,  8,  8,  0 }, {     16,   18,  -89,  8,  8,  0 },
    {     16,   19,  -90,  8,  8,  0 }, {     16,   19,  -91,  8,  7,  0 }, {     16,   20,  -92,  8,  7,  0 }, {     16,   21,  -93,  8,  7,  0 }, {     16,   22,  -94,  8,  7,  0 },
    {     16,   23,  -95,  8,  7,  0 }, {     16,   24,  -96,  8,  7,  0 }, {     16,   25,  -97,  8,  7,  0 }, {     16,   26,  -98,  8,  7,  0 }, {     16,   27,  -99,  8,  7,  0 },
    {     16,   28, -100,  8,  7,  0 }, {     16,   29, -101,  8,  7,  0 }, {     16,   30, -102,  8,  7,  0 }, {     16,   31, -102,  8,  7,  0 }, {     16,   32, -103,  8,  7,  0 },
    {     16,   33, -104,  8,  7,  0 }, {     16,   34, -105,  8,  7,  0 }, {     16,   35, -105,  8,  7,  0 }, {     16,   36, -106,  8,  7,  0 }, {     16,   37, -107,  8,  7,  0 },
    {     16,   38, -108,  8,  7,  0 }, {     16,   39, -109,  8,  7,  0 }, {     16,   40, -109,  8,  7,  0 }, {     16,   41, -110,  8,  7,  0 }, {     16,   42, -110,  8,  6,  0 },
    {     16,   43, -111,  8,  6,  0 }, {     16,   44, -111,  8,  6,  0 }, {     16,   45, -112,  8,  6,  0 }, {     16,   46, -112,  8,  6,  0 }, {     16,   47, -113,  8,  6,  0 },
    {     16,   48, -113,  8,  6,  0 }, {     16,   49, -114,  8,  6,  0 }, {     16,   50, -114,  8,  6,  0 }, {     16,   51, -115,  8,  6,  0 }, {     16,   52, -115,  8,  6,  0 },
    {     16,   53, -116,  8,  6,  0 }, {     16,   54, -116,  8,  6,  0 }, {     16,   55, -117,  8,  6,  0 }, {     16,   56, -117,  8,  6,  0 }, {     16,   57, -117,  8,  6,  0 },
    {     16,   58, -118,  8,  6,  0 }, {     16,   59, -118,  8,  6,  0 }, {     16,   60, -119,  8,  6,  0 }, {     16,   61, -119,  8,  6,  0 }, {     16,   62, -120,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EA852, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    1,  0,  0,  0 }, {     24,   16,    1,  0,  0,  0 }, {     23,   16,    1,  0, 34,  0 }, {     22,   16,    1,  0, 34,  0 },
    {     21,   16,    1,  0, 34,  0 }, {     20,   16,    2,  0, 34,  0 }, {     19,   16,    2,  0, 34,  0 }, {     18,   16,    2,  0, 34,  0 }, {     17,   16,    3,  0, 34,  0 },
    {     16,   16,    3,  0, 34,  0 }, {     15,   16,    4,  0, 34,  0 }, {     14,   16,    4,  0, 34,  0 }, {     13,   16,    5,  0, 34,  0 }, {     12,   16,    5,  0, 34,  0 },
    {     11,   16,    6,  0, 34,  0 }, {     10,   16,    6,  0, 34,  0 }, {      9,   16,    7,  0, 34,  0 }, {      8,   16,    8,  0, 34,  0 }, {      7,   16,    9,  0, 35,  0 },
    {      6,   16,    9,  0, 35,  0 }, {      5,   15,   10,  0, 35,  0 }, {      4,   15,   11,  0, 35,  0 }, {      3,   15,   12,  0, 35,  0 }, {      2,   15,   13,  0, 35,  0 },
    {      1,   15,   14,  0, 35,  0 }, {      0,   15,   15,  0, 35,  0 }, {     -1,   14,   16,  0, 35,  0 }, {     -2,   14,   17,  0, 35,  0 }, {     -2,   14,   18,  0, 35,  0 },
    {     -3,   14,   19,  0, 35,  0 }, {     -4,   14,   20,  0, 35,  0 }, {     -5,   13,   21,  0, 35,  0 }, {     -5,   13,   22,  0, 35,  0 }, {     -6,   13,   23,  0, 35,  0 },
    {     -6,   12,   24,  0, 36,  0 }, {     -7,   12,   25,  0, 36,  0 }, {     -8,   12,   26,  0, 36,  0 }, {     -8,   12,   27,  0, 36,  0 }, {     -9,   11,   28,  0, 36,  0 },
    {     -9,   11,   29,  0, 36,  0 }, {    -10,   10,   30,  0, 36,  0 }, {    -10,   10,   31,  0, 36,  0 }, {    -11,   10,   32,  0, 36,  0 }, {    -11,    9,   33,  0, 36,  0 },
    {    -11,    9,   34,  0, 36,  0 }, {    -12,    8,   35,  0, 36,  0 }, {    -12,    8,   36,  0, 36,  0 }, {    -13,    7,   37,  0, 36,  0 }, {    -13,    7,   38,  0, 36,  0 },
    {    -13,    6,   39,  0, 36,  0 }, {    -13,    5,   40,  0, 36,  0 }, {    -14,    5,   41,  0, 37,  0 }, {    -14,    4,   42,  0, 37,  0 }, {    -14,    4,   43,  0, 37,  0 },
    {    -15,    3,   44,  0, 37,  0 }, {    -15,    2,   45,  0, 37,  0 }, {    -15,    1,   46,  0, 37,  0 }, {    -15,    1,   47,  0, 37,  0 }, {    -15,    0,   48,  0, 37,  0 },
    {    -16,   -1,   49,  0, 37,  0 }, {    -16,   -2,   50,  0, 37,  0 }, {    -16,   -3,   51,  0, 37,  0 }, {    -16,   -4,   52,  0, 37,  0 }, {    -16,   -5,   53,  0, 37,  0 },
    {    -16,   -6,   54,  0, 37,  0 }, {    -17,   -7,   55,  0, 37,  0 }, {    -17,   -8,   55,  0, 37,  0 }, {    -17,   -9,   56,  0, 38,  0 }, {    -17,  -10,   57,  0, 38,  0 },
    {    -17,  -11,   58,  0, 38,  0 }, {    -17,  -12,   58,  0, 38,  0 }, {    -17,  -13,   59,  0, 38,  0 }, {    -17,  -14,   59,  0, 38,  0 }, {    -17,  -15,   60,  0, 38,  0 },
    {    -17,  -16,   60,  0, 38,  0 }, {    -17,  -17,   61,  0, 38,  0 }, {    -17,  -18,   61,  0, 38,  0 }, {    -17,  -19,   62,  0, 38,  0 }, {    -17,  -20,   62,  0, 38,  0 },
    {    -17,  -21,   62,  0, 38,  0 }, {    -17,  -22,   63,  0, 38,  0 }, {    -17,  -23,   63,  0, 38,  0 }, {    -17,  -24,   63,  0, 38,  0 }, {    -17,  -25,   63,  0, 38,  0 },
    {    -17,  -26,   63,  8, 16,  0 }, {    -17,  -27,   64,  8, 16,  0 }, {    -17,  -28,   64,  8, 16,  0 }, {    -17,  -29,   64,  8, 16,  0 }, {    -17,  -30,   64,  8, 16,  0 },
    {    -17,  -31,   64,  8, 16,  0 }, {    -17,  -32,   64,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EABBD, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    1,  8,  0,  0 }, {     16,    7,    1,  8,  0,  0 }, {     16,    8,    1,  8, 34,  0 }, {     16,    9,    1,  8, 34,  0 },
    {     16,   10,    1,  8, 34,  0 }, {     16,   11,    2,  8, 34,  0 }, {     16,   12,    2,  8, 34,  0 }, {     16,   13,    2,  8, 34,  0 }, {     16,   14,    3,  8, 34,  0 },
    {     16,   15,    3,  8, 34,  0 }, {     16,   16,    4,  8, 34,  0 }, {     16,   17,    4,  8, 34,  0 }, {     16,   18,    5,  8, 34,  0 }, {     16,   19,    5,  8, 34,  0 },
    {     16,   20,    6,  8, 34,  0 }, {     16,   21,    6,  8, 34,  0 }, {     16,   22,    7,  8, 34,  0 }, {     16,   23,    8,  8, 34,  0 }, {     16,   24,    9,  8, 35,  0 },
    {     16,   25,    9,  8, 35,  0 }, {     15,   26,   10,  8, 35,  0 }, {     15,   27,   11,  8, 35,  0 }, {     15,   28,   12,  8, 35,  0 }, {     15,   29,   13,  8, 35,  0 },
    {     15,   30,   14,  8, 35,  0 }, {     15,   31,   15,  8, 35,  0 }, {     14,   32,   16,  8, 35,  0 }, {     14,   33,   17,  8, 35,  0 }, {     14,   33,   18,  8, 35,  0 },
    {     14,   34,   19,  8, 35,  0 }, {     14,   35,   20,  8, 35,  0 }, {     13,   36,   21,  8, 35,  0 }, {     13,   36,   22,  8, 35,  0 }, {     13,   37,   23,  8, 35,  0 },
    {     12,   37,   24,  8, 36,  0 }, {     12,   38,   25,  8, 36,  0 }, {     12,   39,   26,  8, 36,  0 }, {     12,   39,   27,  8, 36,  0 }, {     11,   40,   28,  8, 36,  0 },
    {     11,   40,   29,  8, 36,  0 }, {     10,   41,   30,  8, 36,  0 }, {     10,   41,   31,  8, 36,  0 }, {     10,   42,   32,  8, 36,  0 }, {      9,   42,   33,  8, 36,  0 },
    {      9,   42,   34,  8, 36,  0 }, {      8,   43,   35,  8, 36,  0 }, {      8,   43,   36,  8, 36,  0 }, {      7,   44,   37,  8, 36,  0 }, {      7,   44,   38,  8, 36,  0 },
    {      6,   44,   39,  8, 36,  0 }, {      5,   44,   40,  8, 36,  0 }, {      5,   45,   41,  8, 37,  0 }, {      4,   45,   42,  8, 37,  0 }, {      4,   45,   43,  8, 37,  0 },
    {      3,   46,   44,  8, 37,  0 }, {      2,   46,   45,  8, 37,  0 }, {      1,   46,   46,  8, 37,  0 }, {      1,   46,   47,  8, 37,  0 }, {      0,   46,   48,  8, 37,  0 },
    {     -1,   47,   49,  8, 37,  0 }, {     -2,   47,   50,  8, 37,  0 }, {     -3,   47,   51,  8, 37,  0 }, {     -4,   47,   52,  8, 37,  0 }, {     -5,   47,   53,  8, 37,  0 },
    {     -6,   47,   54,  8, 37,  0 }, {     -7,   48,   55,  8, 37,  0 }, {     -8,   48,   55,  8, 37,  0 }, {     -9,   48,   56,  8, 38,  0 }, {    -10,   48,   57,  8, 38,  0 },
    {    -11,   48,   58,  8, 38,  0 }, {    -12,   48,   58,  8, 38,  0 }, {    -13,   48,   59,  8, 38,  0 }, {    -14,   48,   59,  8, 38,  0 }, {    -15,   48,   60,  8, 38,  0 },
    {    -16,   48,   60,  8, 38,  0 }, {    -17,   48,   61,  8, 38,  0 }, {    -18,   48,   61,  8, 38,  0 }, {    -19,   48,   62,  8, 38,  0 }, {    -20,   48,   62,  8, 38,  0 },
    {    -21,   48,   62,  8, 38,  0 }, {    -22,   48,   63,  8, 38,  0 }, {    -23,   48,   63,  8, 38,  0 }, {    -24,   48,   63,  8, 38,  0 }, {    -25,   48,   63,  8, 38,  0 },
    {    -26,   48,   63, 16, 16,  0 }, {    -27,   48,   64, 16, 16,  0 }, {    -28,   48,   64, 16, 16,  0 }, {    -29,   48,   64, 16, 16,  0 }, {    -30,   48,   64, 16, 16,  0 },
    {    -31,   48,   64, 16, 16,  0 }, {    -32,   48,   64, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EAF28, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    1, 16,  0,  0 }, {      7,   16,    1, 16,  0,  0 }, {      8,   16,    1, 16, 34,  0 }, {      9,   16,    1, 16, 34,  0 },
    {     10,   16,    1, 16, 34,  0 }, {     11,   16,    2, 16, 34,  0 }, {     12,   16,    2, 16, 34,  0 }, {     13,   16,    2, 16, 34,  0 }, {     14,   16,    3, 16, 34,  0 },
    {     15,   16,    3, 16, 34,  0 }, {     16,   16,    4, 16, 34,  0 }, {     17,   16,    4, 16, 34,  0 }, {     18,   16,    5, 16, 34,  0 }, {     19,   16,    5, 16, 34,  0 },
    {     20,   16,    6, 16, 34,  0 }, {     21,   16,    6, 16, 34,  0 }, {     22,   16,    7, 16, 34,  0 }, {     23,   16,    8, 16, 34,  0 }, {     24,   16,    9, 16, 35,  0 },
    {     25,   16,    9, 16, 35,  0 }, {     26,   17,   10, 16, 35,  0 }, {     27,   17,   11, 16, 35,  0 }, {     28,   17,   12, 16, 35,  0 }, {     29,   17,   13, 16, 35,  0 },
    {     30,   17,   14, 16, 35,  0 }, {     31,   17,   15, 16, 35,  0 }, {     32,   18,   16, 16, 35,  0 }, {     33,   18,   17, 16, 35,  0 }, {     33,   18,   18, 16, 35,  0 },
    {     34,   18,   19, 16, 35,  0 }, {     35,   18,   20, 16, 35,  0 }, {     36,   19,   21, 16, 35,  0 }, {     36,   19,   22, 16, 35,  0 }, {     37,   19,   23, 16, 35,  0 },
    {     37,   20,   24, 16, 36,  0 }, {     38,   20,   25, 16, 36,  0 }, {     39,   20,   26, 16, 36,  0 }, {     39,   20,   27, 16, 36,  0 }, {     40,   21,   28, 16, 36,  0 },
    {     40,   21,   29, 16, 36,  0 }, {     41,   22,   30, 16, 36,  0 }, {     41,   22,   31, 16, 36,  0 }, {     42,   22,   32, 16, 36,  0 }, {     42,   23,   33, 16, 36,  0 },
    {     42,   23,   34, 16, 36,  0 }, {     43,   24,   35, 16, 36,  0 }, {     43,   24,   36, 16, 36,  0 }, {     44,   25,   37, 16, 36,  0 }, {     44,   25,   38, 16, 36,  0 },
    {     44,   26,   39, 16, 36,  0 }, {     44,   27,   40, 16, 36,  0 }, {     45,   27,   41, 16, 37,  0 }, {     45,   28,   42, 16, 37,  0 }, {     45,   28,   43, 16, 37,  0 },
    {     46,   29,   44, 16, 37,  0 }, {     46,   30,   45, 16, 37,  0 }, {     46,   31,   46, 16, 37,  0 }, {     46,   31,   47, 16, 37,  0 }, {     46,   32,   48, 16, 37,  0 },
    {     47,   33,   49, 16, 37,  0 }, {     47,   34,   50, 16, 37,  0 }, {     47,   35,   51, 16, 37,  0 }, {     47,   36,   52, 16, 37,  0 }, {     47,   37,   53, 16, 37,  0 },
    {     47,   38,   54, 16, 37,  0 }, {     48,   39,   55, 16, 37,  0 }, {     48,   40,   55, 16, 37,  0 }, {     48,   41,   56, 16, 38,  0 }, {     48,   42,   57, 16, 38,  0 },
    {     48,   43,   58, 16, 38,  0 }, {     48,   44,   58, 16, 38,  0 }, {     48,   45,   59, 16, 38,  0 }, {     48,   46,   59, 16, 38,  0 }, {     48,   47,   60, 16, 38,  0 },
    {     48,   48,   60, 16, 38,  0 }, {     48,   49,   61, 16, 38,  0 }, {     48,   50,   61, 16, 38,  0 }, {     48,   51,   62, 16, 38,  0 }, {     48,   52,   62, 16, 38,  0 },
    {     48,   53,   62, 16, 38,  0 }, {     48,   54,   63, 16, 38,  0 }, {     48,   55,   63, 16, 38,  0 }, {     48,   56,   63, 16, 38,  0 }, {     48,   57,   63, 16, 38,  0 },
    {     48,   58,   63, 24, 16,  0 }, {     48,   59,   64, 24, 16,  0 }, {     48,   60,   64, 24, 16,  0 }, {     48,   61,   64, 24, 16,  0 }, {     48,   62,   64, 24, 16,  0 },
    {     48,   63,   64, 24, 16,  0 }, {     48,   64,   64, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EB293, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    1, 24,  0,  0 }, {     16,   24,    1, 24,  0,  0 }, {     16,   23,    1, 24, 34,  0 }, {     16,   22,    1, 24, 34,  0 },
    {     16,   21,    1, 24, 34,  0 }, {     16,   20,    2, 24, 34,  0 }, {     16,   19,    2, 24, 34,  0 }, {     16,   18,    2, 24, 34,  0 }, {     16,   17,    3, 24, 34,  0 },
    {     16,   16,    3, 24, 34,  0 }, {     16,   15,    4, 24, 34,  0 }, {     16,   14,    4, 24, 34,  0 }, {     16,   13,    5, 24, 34,  0 }, {     16,   12,    5, 24, 34,  0 },
    {     16,   11,    6, 24, 34,  0 }, {     16,   10,    6, 24, 34,  0 }, {     16,    9,    7, 24, 34,  0 }, {     16,    8,    8, 24, 34,  0 }, {     16,    7,    9, 24, 35,  0 },
    {     16,    6,    9, 24, 35,  0 }, {     17,    5,   10, 24, 35,  0 }, {     17,    4,   11, 24, 35,  0 }, {     17,    3,   12, 24, 35,  0 }, {     17,    2,   13, 24, 35,  0 },
    {     17,    1,   14, 24, 35,  0 }, {     17,    0,   15, 24, 35,  0 }, {     18,   -1,   16, 24, 35,  0 }, {     18,   -2,   17, 24, 35,  0 }, {     18,   -2,   18, 24, 35,  0 },
    {     18,   -3,   19, 24, 35,  0 }, {     18,   -4,   20, 24, 35,  0 }, {     19,   -5,   21, 24, 35,  0 }, {     19,   -5,   22, 24, 35,  0 }, {     19,   -6,   23, 24, 35,  0 },
    {     20,   -6,   24, 24, 36,  0 }, {     20,   -7,   25, 24, 36,  0 }, {     20,   -8,   26, 24, 36,  0 }, {     20,   -8,   27, 24, 36,  0 }, {     21,   -9,   28, 24, 36,  0 },
    {     21,   -9,   29, 24, 36,  0 }, {     22,  -10,   30, 24, 36,  0 }, {     22,  -10,   31, 24, 36,  0 }, {     22,  -11,   32, 24, 36,  0 }, {     23,  -11,   33, 24, 36,  0 },
    {     23,  -11,   34, 24, 36,  0 }, {     24,  -12,   35, 24, 36,  0 }, {     24,  -12,   36, 24, 36,  0 }, {     25,  -13,   37, 24, 36,  0 }, {     25,  -13,   38, 24, 36,  0 },
    {     26,  -13,   39, 24, 36,  0 }, {     27,  -13,   40, 24, 36,  0 }, {     27,  -14,   41, 24, 37,  0 }, {     28,  -14,   42, 24, 37,  0 }, {     28,  -14,   43, 24, 37,  0 },
    {     29,  -15,   44, 24, 37,  0 }, {     30,  -15,   45, 24, 37,  0 }, {     31,  -15,   46, 24, 37,  0 }, {     31,  -15,   47, 24, 37,  0 }, {     32,  -15,   48, 24, 37,  0 },
    {     33,  -16,   49, 24, 37,  0 }, {     34,  -16,   50, 24, 37,  0 }, {     35,  -16,   51, 24, 37,  0 }, {     36,  -16,   52, 24, 37,  0 }, {     37,  -16,   53, 24, 37,  0 },
    {     38,  -16,   54, 24, 37,  0 }, {     39,  -17,   55, 24, 37,  0 }, {     40,  -17,   55, 24, 37,  0 }, {     41,  -17,   56, 24, 38,  0 }, {     42,  -17,   57, 24, 38,  0 },
    {     43,  -17,   58, 24, 38,  0 }, {     44,  -17,   58, 24, 38,  0 }, {     45,  -17,   59, 24, 38,  0 }, {     46,  -17,   59, 24, 38,  0 }, {     47,  -17,   60, 24, 38,  0 },
    {     48,  -17,   60, 24, 38,  0 }, {     49,  -17,   61, 24, 38,  0 }, {     50,  -17,   61, 24, 38,  0 }, {     51,  -17,   62, 24, 38,  0 }, {     52,  -17,   62, 24, 38,  0 },
    {     53,  -17,   62, 24, 38,  0 }, {     54,  -17,   63, 24, 38,  0 }, {     55,  -17,   63, 24, 38,  0 }, {     56,  -17,   63, 24, 38,  0 }, {     57,  -17,   63, 24, 38,  0 },
    {     58,  -17,   63,  0, 16,  0 }, {     59,  -17,   64,  0, 16,  0 }, {     60,  -17,   64,  0, 16,  0 }, {     61,  -17,   64,  0, 16,  0 }, {     62,  -17,   64,  0, 16,  0 },
    {     63,  -17,   64,  0, 16,  0 }, {     64,  -17,   64,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EB5FE, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    1,  0,  0,  0 }, {     24,   16,    1,  0,  0,  0 }, {     23,   16,    1,  0, 24,  0 }, {     22,   16,    1,  0, 24,  0 },
    {     21,   16,    1,  0, 24,  0 }, {     20,   16,    2,  0, 24,  0 }, {     19,   16,    2,  0, 24,  0 }, {     18,   16,    2,  0, 24,  0 }, {     17,   16,    3,  0, 24,  0 },
    {     16,   16,    3,  0, 24,  0 }, {     15,   16,    4,  0, 24,  0 }, {     14,   16,    4,  0, 24,  0 }, {     13,   16,    5,  0, 24,  0 }, {     12,   16,    5,  0, 24,  0 },
    {     11,   16,    6,  0, 24,  0 }, {     10,   16,    6,  0, 24,  0 }, {      9,   16,    7,  0, 24,  0 }, {      8,   16,    8,  0, 24,  0 }, {      7,   16,    9,  0, 25,  0 },
    {      6,   16,    9,  0, 25,  0 }, {      5,   17,   10,  0, 25,  0 }, {      4,   17,   11,  0, 25,  0 }, {      3,   17,   12,  0, 25,  0 }, {      2,   17,   13,  0, 25,  0 },
    {      1,   17,   14,  0, 25,  0 }, {      0,   17,   15,  0, 25,  0 }, {     -1,   18,   16,  0, 25,  0 }, {     -2,   18,   17,  0, 25,  0 }, {     -2,   18,   18,  0, 25,  0 },
    {     -3,   18,   19,  0, 25,  0 }, {     -4,   18,   20,  0, 25,  0 }, {     -5,   19,   21,  0, 25,  0 }, {     -5,   19,   22,  0, 25,  0 }, {     -6,   19,   23,  0, 25,  0 },
    {     -6,   20,   24,  0, 26,  0 }, {     -7,   20,   25,  0, 26,  0 }, {     -8,   20,   26,  0, 26,  0 }, {     -8,   20,   27,  0, 26,  0 }, {     -9,   21,   28,  0, 26,  0 },
    {     -9,   21,   29,  0, 26,  0 }, {    -10,   22,   30,  0, 26,  0 }, {    -10,   22,   31,  0, 26,  0 }, {    -11,   22,   32,  0, 26,  0 }, {    -11,   23,   33,  0, 26,  0 },
    {    -11,   23,   34,  0, 26,  0 }, {    -12,   24,   35,  0, 26,  0 }, {    -12,   24,   36,  0, 26,  0 }, {    -13,   25,   37,  0, 26,  0 }, {    -13,   25,   38,  0, 26,  0 },
    {    -13,   26,   39,  0, 26,  0 }, {    -13,   27,   40,  0, 26,  0 }, {    -14,   27,   41,  0, 27,  0 }, {    -14,   28,   42,  0, 27,  0 }, {    -14,   28,   43,  0, 27,  0 },
    {    -15,   29,   44,  0, 27,  0 }, {    -15,   30,   45,  0, 27,  0 }, {    -15,   31,   46,  0, 27,  0 }, {    -15,   31,   47,  0, 27,  0 }, {    -15,   32,   48,  0, 27,  0 },
    {    -16,   33,   49,  0, 27,  0 }, {    -16,   34,   50,  0, 27,  0 }, {    -16,   35,   51,  0, 27,  0 }, {    -16,   36,   52,  0, 27,  0 }, {    -16,   37,   53,  0, 27,  0 },
    {    -16,   38,   54,  0, 27,  0 }, {    -17,   39,   55,  0, 27,  0 }, {    -17,   40,   55,  0, 27,  0 }, {    -17,   41,   56,  0, 28,  0 }, {    -17,   42,   57,  0, 28,  0 },
    {    -17,   43,   58,  0, 28,  0 }, {    -17,   44,   58,  0, 28,  0 }, {    -17,   45,   59,  0, 28,  0 }, {    -17,   46,   59,  0, 28,  0 }, {    -17,   47,   60,  0, 28,  0 },
    {    -17,   48,   60,  0, 28,  0 }, {    -17,   49,   61,  0, 28,  0 }, {    -17,   50,   61,  0, 28,  0 }, {    -17,   51,   62,  0, 28,  0 }, {    -17,   52,   62,  0, 28,  0 },
    {    -17,   53,   62,  0, 28,  0 }, {    -17,   54,   63,  0, 28,  0 }, {    -17,   55,   63,  0, 28,  0 }, {    -17,   56,   63,  0, 28,  0 }, {    -17,   57,   63,  0, 28,  0 },
    {    -17,   58,   63, 24, 16,  0 }, {    -17,   59,   64, 24, 16,  0 }, {    -17,   60,   64, 24, 16,  0 }, {    -17,   61,   64, 24, 16,  0 }, {    -17,   62,   64, 24, 16,  0 },
    {    -17,   63,   64, 24, 16,  0 }, {    -17,   64,   64, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EB969, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    1,  8,  0,  0 }, {     16,    7,    1,  8,  0,  0 }, {     16,    8,    1,  8, 24,  0 }, {     16,    9,    1,  8, 24,  0 },
    {     16,   10,    1,  8, 24,  0 }, {     16,   11,    2,  8, 24,  0 }, {     16,   12,    2,  8, 24,  0 }, {     16,   13,    2,  8, 24,  0 }, {     16,   14,    3,  8, 24,  0 },
    {     16,   15,    3,  8, 24,  0 }, {     16,   16,    4,  8, 24,  0 }, {     16,   17,    4,  8, 24,  0 }, {     16,   18,    5,  8, 24,  0 }, {     16,   19,    5,  8, 24,  0 },
    {     16,   20,    6,  8, 24,  0 }, {     16,   21,    6,  8, 24,  0 }, {     16,   22,    7,  8, 24,  0 }, {     16,   23,    8,  8, 24,  0 }, {     16,   24,    9,  8, 25,  0 },
    {     16,   25,    9,  8, 25,  0 }, {     17,   26,   10,  8, 25,  0 }, {     17,   27,   11,  8, 25,  0 }, {     17,   28,   12,  8, 25,  0 }, {     17,   29,   13,  8, 25,  0 },
    {     17,   30,   14,  8, 25,  0 }, {     17,   31,   15,  8, 25,  0 }, {     18,   32,   16,  8, 25,  0 }, {     18,   33,   17,  8, 25,  0 }, {     18,   33,   18,  8, 25,  0 },
    {     18,   34,   19,  8, 25,  0 }, {     18,   35,   20,  8, 25,  0 }, {     19,   36,   21,  8, 25,  0 }, {     19,   36,   22,  8, 25,  0 }, {     19,   37,   23,  8, 25,  0 },
    {     20,   37,   24,  8, 26,  0 }, {     20,   38,   25,  8, 26,  0 }, {     20,   39,   26,  8, 26,  0 }, {     20,   39,   27,  8, 26,  0 }, {     21,   40,   28,  8, 26,  0 },
    {     21,   40,   29,  8, 26,  0 }, {     22,   41,   30,  8, 26,  0 }, {     22,   41,   31,  8, 26,  0 }, {     22,   42,   32,  8, 26,  0 }, {     23,   42,   33,  8, 26,  0 },
    {     23,   42,   34,  8, 26,  0 }, {     24,   43,   35,  8, 26,  0 }, {     24,   43,   36,  8, 26,  0 }, {     25,   44,   37,  8, 26,  0 }, {     25,   44,   38,  8, 26,  0 },
    {     26,   44,   39,  8, 26,  0 }, {     27,   44,   40,  8, 26,  0 }, {     27,   45,   41,  8, 27,  0 }, {     28,   45,   42,  8, 27,  0 }, {     28,   45,   43,  8, 27,  0 },
    {     29,   46,   44,  8, 27,  0 }, {     30,   46,   45,  8, 27,  0 }, {     31,   46,   46,  8, 27,  0 }, {     31,   46,   47,  8, 27,  0 }, {     32,   46,   48,  8, 27,  0 },
    {     33,   47,   49,  8, 27,  0 }, {     34,   47,   50,  8, 27,  0 }, {     35,   47,   51,  8, 27,  0 }, {     36,   47,   52,  8, 27,  0 }, {     37,   47,   53,  8, 27,  0 },
    {     38,   47,   54,  8, 27,  0 }, {     39,   48,   55,  8, 27,  0 }, {     40,   48,   55,  8, 27,  0 }, {     41,   48,   56,  8, 28,  0 }, {     42,   48,   57,  8, 28,  0 },
    {     43,   48,   58,  8, 28,  0 }, {     44,   48,   58,  8, 28,  0 }, {     45,   48,   59,  8, 28,  0 }, {     46,   48,   59,  8, 28,  0 }, {     47,   48,   60,  8, 28,  0 },
    {     48,   48,   60,  8, 28,  0 }, {     49,   48,   61,  8, 28,  0 }, {     50,   48,   61,  8, 28,  0 }, {     51,   48,   62,  8, 28,  0 }, {     52,   48,   62,  8, 28,  0 },
    {     53,   48,   62,  8, 28,  0 }, {     54,   48,   63,  8, 28,  0 }, {     55,   48,   63,  8, 28,  0 }, {     56,   48,   63,  8, 28,  0 }, {     57,   48,   63,  8, 28,  0 },
    {     58,   48,   63,  0, 16,  0 }, {     59,   48,   64,  0, 16,  0 }, {     60,   48,   64,  0, 16,  0 }, {     61,   48,   64,  0, 16,  0 }, {     62,   48,   64,  0, 16,  0 },
    {     63,   48,   64,  0, 16,  0 }, {     64,   48,   64,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EBCD4, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    1, 16,  0,  0 }, {      7,   16,    1, 16,  0,  0 }, {      8,   16,    1, 16, 24,  0 }, {      9,   16,    1, 16, 24,  0 },
    {     10,   16,    1, 16, 24,  0 }, {     11,   16,    2, 16, 24,  0 }, {     12,   16,    2, 16, 24,  0 }, {     13,   16,    2, 16, 24,  0 }, {     14,   16,    3, 16, 24,  0 },
    {     15,   16,    3, 16, 24,  0 }, {     16,   16,    4, 16, 24,  0 }, {     17,   16,    4, 16, 24,  0 }, {     18,   16,    5, 16, 24,  0 }, {     19,   16,    5, 16, 24,  0 },
    {     20,   16,    6, 16, 24,  0 }, {     21,   16,    6, 16, 24,  0 }, {     22,   16,    7, 16, 24,  0 }, {     23,   16,    8, 16, 24,  0 }, {     24,   16,    9, 16, 25,  0 },
    {     25,   16,    9, 16, 25,  0 }, {     26,   15,   10, 16, 25,  0 }, {     27,   15,   11, 16, 25,  0 }, {     28,   15,   12, 16, 25,  0 }, {     29,   15,   13, 16, 25,  0 },
    {     30,   15,   14, 16, 25,  0 }, {     31,   15,   15, 16, 25,  0 }, {     32,   14,   16, 16, 25,  0 }, {     33,   14,   17, 16, 25,  0 }, {     33,   14,   18, 16, 25,  0 },
    {     34,   14,   19, 16, 25,  0 }, {     35,   14,   20, 16, 25,  0 }, {     36,   13,   21, 16, 25,  0 }, {     36,   13,   22, 16, 25,  0 }, {     37,   13,   23, 16, 25,  0 },
    {     37,   12,   24, 16, 26,  0 }, {     38,   12,   25, 16, 26,  0 }, {     39,   12,   26, 16, 26,  0 }, {     39,   12,   27, 16, 26,  0 }, {     40,   11,   28, 16, 26,  0 },
    {     40,   11,   29, 16, 26,  0 }, {     41,   10,   30, 16, 26,  0 }, {     41,   10,   31, 16, 26,  0 }, {     42,   10,   32, 16, 26,  0 }, {     42,    9,   33, 16, 26,  0 },
    {     42,    9,   34, 16, 26,  0 }, {     43,    8,   35, 16, 26,  0 }, {     43,    8,   36, 16, 26,  0 }, {     44,    7,   37, 16, 26,  0 }, {     44,    7,   38, 16, 26,  0 },
    {     44,    6,   39, 16, 26,  0 }, {     44,    5,   40, 16, 26,  0 }, {     45,    5,   41, 16, 27,  0 }, {     45,    4,   42, 16, 27,  0 }, {     45,    4,   43, 16, 27,  0 },
    {     46,    3,   44, 16, 27,  0 }, {     46,    2,   45, 16, 27,  0 }, {     46,    1,   46, 16, 27,  0 }, {     46,    1,   47, 16, 27,  0 }, {     46,    0,   48, 16, 27,  0 },
    {     47,   -1,   49, 16, 27,  0 }, {     47,   -2,   50, 16, 27,  0 }, {     47,   -3,   51, 16, 27,  0 }, {     47,   -4,   52, 16, 27,  0 }, {     47,   -5,   53, 16, 27,  0 },
    {     47,   -6,   54, 16, 27,  0 }, {     48,   -7,   55, 16, 27,  0 }, {     48,   -8,   55, 16, 27,  0 }, {     48,   -9,   56, 16, 28,  0 }, {     48,  -10,   57, 16, 28,  0 },
    {     48,  -11,   58, 16, 28,  0 }, {     48,  -12,   58, 16, 28,  0 }, {     48,  -13,   59, 16, 28,  0 }, {     48,  -14,   59, 16, 28,  0 }, {     48,  -15,   60, 16, 28,  0 },
    {     48,  -16,   60, 16, 28,  0 }, {     48,  -17,   61, 16, 28,  0 }, {     48,  -18,   61, 16, 28,  0 }, {     48,  -19,   62, 16, 28,  0 }, {     48,  -20,   62, 16, 28,  0 },
    {     48,  -21,   62, 16, 28,  0 }, {     48,  -22,   63, 16, 28,  0 }, {     48,  -23,   63, 16, 28,  0 }, {     48,  -24,   63, 16, 28,  0 }, {     48,  -25,   63, 16, 28,  0 },
    {     48,  -26,   63,  8, 16,  0 }, {     48,  -27,   64,  8, 16,  0 }, {     48,  -28,   64,  8, 16,  0 }, {     48,  -29,   64,  8, 16,  0 }, {     48,  -30,   64,  8, 16,  0 },
    {     48,  -31,   64,  8, 16,  0 }, {     48,  -32,   64,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EC03F, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    1, 24,  0,  0 }, {     16,   24,    1, 24,  0,  0 }, {     16,   23,    1, 24, 24,  0 }, {     16,   22,    1, 24, 24,  0 },
    {     16,   21,    1, 24, 24,  0 }, {     16,   20,    2, 24, 24,  0 }, {     16,   19,    2, 24, 24,  0 }, {     16,   18,    2, 24, 24,  0 }, {     16,   17,    3, 24, 24,  0 },
    {     16,   16,    3, 24, 24,  0 }, {     16,   15,    4, 24, 24,  0 }, {     16,   14,    4, 24, 24,  0 }, {     16,   13,    5, 24, 24,  0 }, {     16,   12,    5, 24, 24,  0 },
    {     16,   11,    6, 24, 24,  0 }, {     16,   10,    6, 24, 24,  0 }, {     16,    9,    7, 24, 24,  0 }, {     16,    8,    8, 24, 24,  0 }, {     16,    7,    9, 24, 25,  0 },
    {     16,    6,    9, 24, 25,  0 }, {     15,    5,   10, 24, 25,  0 }, {     15,    4,   11, 24, 25,  0 }, {     15,    3,   12, 24, 25,  0 }, {     15,    2,   13, 24, 25,  0 },
    {     15,    1,   14, 24, 25,  0 }, {     15,    0,   15, 24, 25,  0 }, {     14,   -1,   16, 24, 25,  0 }, {     14,   -2,   17, 24, 25,  0 }, {     14,   -2,   18, 24, 25,  0 },
    {     14,   -3,   19, 24, 25,  0 }, {     14,   -4,   20, 24, 25,  0 }, {     13,   -5,   21, 24, 25,  0 }, {     13,   -5,   22, 24, 25,  0 }, {     13,   -6,   23, 24, 25,  0 },
    {     12,   -6,   24, 24, 26,  0 }, {     12,   -7,   25, 24, 26,  0 }, {     12,   -8,   26, 24, 26,  0 }, {     12,   -8,   27, 24, 26,  0 }, {     11,   -9,   28, 24, 26,  0 },
    {     11,   -9,   29, 24, 26,  0 }, {     10,  -10,   30, 24, 26,  0 }, {     10,  -10,   31, 24, 26,  0 }, {     10,  -11,   32, 24, 26,  0 }, {      9,  -11,   33, 24, 26,  0 },
    {      9,  -11,   34, 24, 26,  0 }, {      8,  -12,   35, 24, 26,  0 }, {      8,  -12,   36, 24, 26,  0 }, {      7,  -13,   37, 24, 26,  0 }, {      7,  -13,   38, 24, 26,  0 },
    {      6,  -13,   39, 24, 26,  0 }, {      5,  -13,   40, 24, 26,  0 }, {      5,  -14,   41, 24, 27,  0 }, {      4,  -14,   42, 24, 27,  0 }, {      4,  -14,   43, 24, 27,  0 },
    {      3,  -15,   44, 24, 27,  0 }, {      2,  -15,   45, 24, 27,  0 }, {      1,  -15,   46, 24, 27,  0 }, {      1,  -15,   47, 24, 27,  0 }, {      0,  -15,   48, 24, 27,  0 },
    {     -1,  -16,   49, 24, 27,  0 }, {     -2,  -16,   50, 24, 27,  0 }, {     -3,  -16,   51, 24, 27,  0 }, {     -4,  -16,   52, 24, 27,  0 }, {     -5,  -16,   53, 24, 27,  0 },
    {     -6,  -16,   54, 24, 27,  0 }, {     -7,  -17,   55, 24, 27,  0 }, {     -8,  -17,   55, 24, 27,  0 }, {     -9,  -17,   56, 24, 28,  0 }, {    -10,  -17,   57, 24, 28,  0 },
    {    -11,  -17,   58, 24, 28,  0 }, {    -12,  -17,   58, 24, 28,  0 }, {    -13,  -17,   59, 24, 28,  0 }, {    -14,  -17,   59, 24, 28,  0 }, {    -15,  -17,   60, 24, 28,  0 },
    {    -16,  -17,   60, 24, 28,  0 }, {    -17,  -17,   61, 24, 28,  0 }, {    -18,  -17,   61, 24, 28,  0 }, {    -19,  -17,   62, 24, 28,  0 }, {    -20,  -17,   62, 24, 28,  0 },
    {    -21,  -17,   62, 24, 28,  0 }, {    -22,  -17,   63, 24, 28,  0 }, {    -23,  -17,   63, 24, 28,  0 }, {    -24,  -17,   63, 24, 28,  0 }, {    -25,  -17,   63, 24, 28,  0 },
    {    -26,  -17,   63, 16, 16,  0 }, {    -27,  -17,   64, 16, 16,  0 }, {    -28,  -17,   64, 16, 16,  0 }, {    -29,  -17,   64, 16, 16,  0 }, {    -30,  -17,   64, 16, 16,  0 },
    {    -31,  -17,   64, 16, 16,  0 }, {    -32,  -17,   64, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EC3AA, {
    {     31,   16,   16, 16, 16,  0 }, {     30,   16,   16, 16, 16,  0 }, {     29,   16,   16, 16, 16,  0 }, {     28,   16,   16, 16, 16,  0 }, {     27,   16,   16, 16, 16,  0 },
    {     26,   16,   16, 16, 16,  0 }, {     25,   16,   15, 16, 16,  0 }, {     24,   16,   15, 16, 16,  0 }, {     23,   16,   15, 24, 33,  0 }, {     22,   16,   15, 24, 33,  0 },
    {     21,   16,   15, 24, 33,  0 }, {     20,   16,   14, 24, 33,  0 }, {     19,   16,   14, 24, 33,  0 }, {     18,   16,   14, 24, 33,  0 }, {     17,   16,   13, 24, 33,  0 },
    {     16,   16,   13, 24, 33,  0 }, {     15,   16,   12, 24, 33,  0 }, {     14,   16,   12, 24, 33,  0 }, {     13,   16,   11, 24, 33,  0 }, {     12,   16,   11, 24, 33,  0 },
    {     11,   16,   10, 24, 33,  0 }, {     10,   16,   10, 24, 33,  0 }, {      9,   16,    9, 24, 33,  0 }, {      8,   16,    8, 24, 33,  0 }, {      7,   16,    7, 24, 32,  0 },
    {      6,   16,    7, 24, 32,  0 }, {      5,   15,    6, 24, 32,  0 }, {      4,   15,    5, 24, 32,  0 }, {      3,   15,    4, 24, 32,  0 }, {      2,   15,    3, 24, 32,  0 },
    {      1,   15,    2, 24, 32,  0 }, {      0,   15,    1, 24, 32,  0 }, {     -1,   14,    0, 24, 32,  0 }, {     -2,   14,   -1, 24, 32,  0 }, {     -2,   14,   -2, 24, 32,  0 },
    {     -3,   14,   -3, 24, 32,  0 }, {     -4,   14,   -4, 24, 32,  0 }, {     -5,   13,   -5, 24, 32,  0 }, {     -5,   13,   -6, 24, 32,  0 }, {     -6,   13,   -7, 24, 32,  0 },
    {     -6,   12,   -8, 24, 31,  0 }, {     -7,   12,   -9, 24, 31,  0 }, {     -8,   12,  -10, 24, 31,  0 }, {     -8,   12,  -11, 24, 31,  0 }, {     -9,   11,  -12, 24, 31,  0 },
    {     -9,   11,  -13, 24, 31,  0 }, {    -10,   10,  -14, 24, 31,  0 }, {    -10,   10,  -15, 24, 31,  0 }, {    -11,   10,  -16, 24, 31,  0 }, {    -11,    9,  -17, 24, 31,  0 },
    {    -11,    9,  -18, 24, 31,  0 }, {    -12,    8,  -19, 24, 31,  0 }, {    -12,    8,  -20, 24, 31,  0 }, {    -13,    7,  -21, 24, 31,  0 }, {    -13,    7,  -22, 24, 31,  0 },
    {    -13,    6,  -23, 24, 31,  0 }, {    -13,    5,  -24, 24, 31,  0 }, {    -14,    5,  -25, 24, 30,  0 }, {    -14,    4,  -26, 24, 30,  0 }, {    -14,    4,  -27, 24, 30,  0 },
    {    -15,    3,  -28, 24, 30,  0 }, {    -15,    2,  -29, 24, 30,  0 }, {    -15,    1,  -30, 24, 30,  0 }, {    -15,    1,  -31, 24, 30,  0 }, {    -15,    0,  -32, 24, 30,  0 },
    {    -16,   -1,  -33, 24, 30,  0 }, {    -16,   -2,  -34, 24, 30,  0 }, {    -16,   -3,  -35, 24, 30,  0 }, {    -16,   -4,  -36, 24, 30,  0 }, {    -16,   -5,  -37, 24, 30,  0 },
    {    -16,   -6,  -38, 24, 30,  0 }, {    -17,   -7,  -39, 24, 30,  0 }, {    -17,   -8,  -39, 24, 30,  0 }, {    -17,   -9,  -40, 24, 29,  0 }, {    -17,  -10,  -41, 24, 29,  0 },
    {    -17,  -11,  -42, 24, 29,  0 }, {    -17,  -12,  -42, 24, 29,  0 }, {    -17,  -13,  -43, 24, 29,  0 }, {    -17,  -14,  -43, 24, 29,  0 }, {    -17,  -15,  -44, 24, 29,  0 },
    {    -17,  -16,  -44, 24, 29,  0 }, {    -17,  -17,  -45, 24, 29,  0 }, {    -17,  -18,  -45, 24, 29,  0 }, {    -17,  -19,  -46, 24, 29,  0 }, {    -17,  -20,  -46, 24, 29,  0 },
    {    -17,  -21,  -46, 24, 29,  0 }, {    -17,  -22,  -47, 24, 29,  0 }, {    -17,  -23,  -47, 24, 29,  0 }, {    -17,  -24,  -47, 24, 29,  0 }, {    -17,  -25,  -47, 24, 29,  0 },
    {    -17,  -26,  -47, 24,  0,  0 }, {    -17,  -27,  -48, 24,  0,  0 }, {    -17,  -28,  -48, 24,  0,  0 }, {    -17,  -29,  -48, 24,  0,  0 }, {    -17,  -30,  -48, 24,  0,  0 },
    {    -17,  -31,  -48, 24,  0,  0 }, {    -17,  -32,  -48, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EC715, {
    {     16,    0,   16, 24, 16,  0 }, {     16,    1,   16, 24, 16,  0 }, {     16,    2,   16, 24, 16,  0 }, {     16,    3,   16, 24, 16,  0 }, {     16,    4,   16, 24, 16,  0 },
    {     16,    5,   16, 24, 16,  0 }, {     16,    6,   15, 24, 16,  0 }, {     16,    7,   15, 24, 16,  0 }, {     16,    8,   15,  0, 33,  0 }, {     16,    9,   15,  0, 33,  0 },
    {     16,   10,   15,  0, 33,  0 }, {     16,   11,   14,  0, 33,  0 }, {     16,   12,   14,  0, 33,  0 }, {     16,   13,   14,  0, 33,  0 }, {     16,   14,   13,  0, 33,  0 },
    {     16,   15,   13,  0, 33,  0 }, {     16,   16,   12,  0, 33,  0 }, {     16,   17,   12,  0, 33,  0 }, {     16,   18,   11,  0, 33,  0 }, {     16,   19,   11,  0, 33,  0 },
    {     16,   20,   10,  0, 33,  0 }, {     16,   21,   10,  0, 33,  0 }, {     16,   22,    9,  0, 33,  0 }, {     16,   23,    8,  0, 33,  0 }, {     16,   24,    7,  0, 32,  0 },
    {     16,   25,    7,  0, 32,  0 }, {     15,   26,    6,  0, 32,  0 }, {     15,   27,    5,  0, 32,  0 }, {     15,   28,    4,  0, 32,  0 }, {     15,   29,    3,  0, 32,  0 },
    {     15,   30,    2,  0, 32,  0 }, {     15,   31,    1,  0, 32,  0 }, {     14,   32,    0,  0, 32,  0 }, {     14,   33,   -1,  0, 32,  0 }, {     14,   33,   -2,  0, 32,  0 },
    {     14,   34,   -3,  0, 32,  0 }, {     14,   35,   -4,  0, 32,  0 }, {     13,   36,   -5,  0, 32,  0 }, {     13,   36,   -6,  0, 32,  0 }, {     13,   37,   -7,  0, 32,  0 },
    {     12,   37,   -8,  0, 31,  0 }, {     12,   38,   -9,  0, 31,  0 }, {     12,   39,  -10,  0, 31,  0 }, {     12,   39,  -11,  0, 31,  0 }, {     11,   40,  -12,  0, 31,  0 },
    {     11,   40,  -13,  0, 31,  0 }, {     10,   41,  -14,  0, 31,  0 }, {     10,   41,  -15,  0, 31,  0 }, {     10,   42,  -16,  0, 31,  0 }, {      9,   42,  -17,  0, 31,  0 },
    {      9,   42,  -18,  0, 31,  0 }, {      8,   43,  -19,  0, 31,  0 }, {      8,   43,  -20,  0, 31,  0 }, {      7,   44,  -21,  0, 31,  0 }, {      7,   44,  -22,  0, 31,  0 },
    {      6,   44,  -23,  0, 31,  0 }, {      5,   44,  -24,  0, 31,  0 }, {      5,   45,  -25,  0, 30,  0 }, {      4,   45,  -26,  0, 30,  0 }, {      4,   45,  -27,  0, 30,  0 },
    {      3,   46,  -28,  0, 30,  0 }, {      2,   46,  -29,  0, 30,  0 }, {      1,   46,  -30,  0, 30,  0 }, {      1,   46,  -31,  0, 30,  0 }, {      0,   46,  -32,  0, 30,  0 },
    {     -1,   47,  -33,  0, 30,  0 }, {     -2,   47,  -34,  0, 30,  0 }, {     -3,   47,  -35,  0, 30,  0 }, {     -4,   47,  -36,  0, 30,  0 }, {     -5,   47,  -37,  0, 30,  0 },
    {     -6,   47,  -38,  0, 30,  0 }, {     -7,   48,  -39,  0, 30,  0 }, {     -8,   48,  -39,  0, 30,  0 }, {     -9,   48,  -40,  0, 29,  0 }, {    -10,   48,  -41,  0, 29,  0 },
    {    -11,   48,  -42,  0, 29,  0 }, {    -12,   48,  -42,  0, 29,  0 }, {    -13,   48,  -43,  0, 29,  0 }, {    -14,   48,  -43,  0, 29,  0 }, {    -15,   48,  -44,  0, 29,  0 },
    {    -16,   48,  -44,  0, 29,  0 }, {    -17,   48,  -45,  0, 29,  0 }, {    -18,   48,  -45,  0, 29,  0 }, {    -19,   48,  -46,  0, 29,  0 }, {    -20,   48,  -46,  0, 29,  0 },
    {    -21,   48,  -46,  0, 29,  0 }, {    -22,   48,  -47,  0, 29,  0 }, {    -23,   48,  -47,  0, 29,  0 }, {    -24,   48,  -47,  0, 29,  0 }, {    -25,   48,  -47,  0, 29,  0 },
    {    -26,   48,  -47,  0,  0,  0 }, {    -27,   48,  -48,  0,  0,  0 }, {    -28,   48,  -48,  0,  0,  0 }, {    -29,   48,  -48,  0,  0,  0 }, {    -30,   48,  -48,  0,  0,  0 },
    {    -31,   48,  -48,  0,  0,  0 }, {    -32,   48,  -48,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8ECA80, {
    {      0,   16,   16,  0, 16,  0 }, {      1,   16,   16,  0, 16,  0 }, {      2,   16,   16,  0, 16,  0 }, {      3,   16,   16,  0, 16,  0 }, {      4,   16,   16,  0, 16,  0 },
    {      5,   16,   16,  0, 16,  0 }, {      6,   16,   15,  0, 16,  0 }, {      7,   16,   15,  0, 16,  0 }, {      8,   16,   15,  8, 33,  0 }, {      9,   16,   15,  8, 33,  0 },
    {     10,   16,   15,  8, 33,  0 }, {     11,   16,   14,  8, 33,  0 }, {     12,   16,   14,  8, 33,  0 }, {     13,   16,   14,  8, 33,  0 }, {     14,   16,   13,  8, 33,  0 },
    {     15,   16,   13,  8, 33,  0 }, {     16,   16,   12,  8, 33,  0 }, {     17,   16,   12,  8, 33,  0 }, {     18,   16,   11,  8, 33,  0 }, {     19,   16,   11,  8, 33,  0 },
    {     20,   16,   10,  8, 33,  0 }, {     21,   16,   10,  8, 33,  0 }, {     22,   16,    9,  8, 33,  0 }, {     23,   16,    8,  8, 33,  0 }, {     24,   16,    7,  8, 32,  0 },
    {     25,   16,    7,  8, 32,  0 }, {     26,   17,    6,  8, 32,  0 }, {     27,   17,    5,  8, 32,  0 }, {     28,   17,    4,  8, 32,  0 }, {     29,   17,    3,  8, 32,  0 },
    {     30,   17,    2,  8, 32,  0 }, {     31,   17,    1,  8, 32,  0 }, {     32,   18,    0,  8, 32,  0 }, {     33,   18,   -1,  8, 32,  0 }, {     33,   18,   -2,  8, 32,  0 },
    {     34,   18,   -3,  8, 32,  0 }, {     35,   18,   -4,  8, 32,  0 }, {     36,   19,   -5,  8, 32,  0 }, {     36,   19,   -6,  8, 32,  0 }, {     37,   19,   -7,  8, 32,  0 },
    {     37,   20,   -8,  8, 31,  0 }, {     38,   20,   -9,  8, 31,  0 }, {     39,   20,  -10,  8, 31,  0 }, {     39,   20,  -11,  8, 31,  0 }, {     40,   21,  -12,  8, 31,  0 },
    {     40,   21,  -13,  8, 31,  0 }, {     41,   22,  -14,  8, 31,  0 }, {     41,   22,  -15,  8, 31,  0 }, {     42,   22,  -16,  8, 31,  0 }, {     42,   23,  -17,  8, 31,  0 },
    {     42,   23,  -18,  8, 31,  0 }, {     43,   24,  -19,  8, 31,  0 }, {     43,   24,  -20,  8, 31,  0 }, {     44,   25,  -21,  8, 31,  0 }, {     44,   25,  -22,  8, 31,  0 },
    {     44,   26,  -23,  8, 31,  0 }, {     44,   27,  -24,  8, 31,  0 }, {     45,   27,  -25,  8, 30,  0 }, {     45,   28,  -26,  8, 30,  0 }, {     45,   28,  -27,  8, 30,  0 },
    {     46,   29,  -28,  8, 30,  0 }, {     46,   30,  -29,  8, 30,  0 }, {     46,   31,  -30,  8, 30,  0 }, {     46,   31,  -31,  8, 30,  0 }, {     46,   32,  -32,  8, 30,  0 },
    {     47,   33,  -33,  8, 30,  0 }, {     47,   34,  -34,  8, 30,  0 }, {     47,   35,  -35,  8, 30,  0 }, {     47,   36,  -36,  8, 30,  0 }, {     47,   37,  -37,  8, 30,  0 },
    {     47,   38,  -38,  8, 30,  0 }, {     48,   39,  -39,  8, 30,  0 }, {     48,   40,  -39,  8, 30,  0 }, {     48,   41,  -40,  8, 29,  0 }, {     48,   42,  -41,  8, 29,  0 },
    {     48,   43,  -42,  8, 29,  0 }, {     48,   44,  -42,  8, 29,  0 }, {     48,   45,  -43,  8, 29,  0 }, {     48,   46,  -43,  8, 29,  0 }, {     48,   47,  -44,  8, 29,  0 },
    {     48,   48,  -44,  8, 29,  0 }, {     48,   49,  -45,  8, 29,  0 }, {     48,   50,  -45,  8, 29,  0 }, {     48,   51,  -46,  8, 29,  0 }, {     48,   52,  -46,  8, 29,  0 },
    {     48,   53,  -46,  8, 29,  0 }, {     48,   54,  -47,  8, 29,  0 }, {     48,   55,  -47,  8, 29,  0 }, {     48,   56,  -47,  8, 29,  0 }, {     48,   57,  -47,  8, 29,  0 },
    {     48,   58,  -47,  8,  0,  0 }, {     48,   59,  -48,  8,  0,  0 }, {     48,   60,  -48,  8,  0,  0 }, {     48,   61,  -48,  8,  0,  0 }, {     48,   62,  -48,  8,  0,  0 },
    {     48,   63,  -48,  8,  0,  0 }, {     48,   64,  -48,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8ECDEB, {
    {     16,   31,   16,  8, 16,  0 }, {     16,   30,   16,  8, 16,  0 }, {     16,   29,   16,  8, 16,  0 }, {     16,   28,   16,  8, 16,  0 }, {     16,   27,   16,  8, 16,  0 },
    {     16,   26,   16,  8, 16,  0 }, {     16,   25,   15,  8, 16,  0 }, {     16,   24,   15,  8, 16,  0 }, {     16,   23,   15, 16, 33,  0 }, {     16,   22,   15, 16, 33,  0 },
    {     16,   21,   15, 16, 33,  0 }, {     16,   20,   14, 16, 33,  0 }, {     16,   19,   14, 16, 33,  0 }, {     16,   18,   14, 16, 33,  0 }, {     16,   17,   13, 16, 33,  0 },
    {     16,   16,   13, 16, 33,  0 }, {     16,   15,   12, 16, 33,  0 }, {     16,   14,   12, 16, 33,  0 }, {     16,   13,   11, 16, 33,  0 }, {     16,   12,   11, 16, 33,  0 },
    {     16,   11,   10, 16, 33,  0 }, {     16,   10,   10, 16, 33,  0 }, {     16,    9,    9, 16, 33,  0 }, {     16,    8,    8, 16, 33,  0 }, {     16,    7,    7, 16, 32,  0 },
    {     16,    6,    7, 16, 32,  0 }, {     17,    5,    6, 16, 32,  0 }, {     17,    4,    5, 16, 32,  0 }, {     17,    3,    4, 16, 32,  0 }, {     17,    2,    3, 16, 32,  0 },
    {     17,    1,    2, 16, 32,  0 }, {     17,    0,    1, 16, 32,  0 }, {     18,   -1,    0, 16, 32,  0 }, {     18,   -2,   -1, 16, 32,  0 }, {     18,   -2,   -2, 16, 32,  0 },
    {     18,   -3,   -3, 16, 32,  0 }, {     18,   -4,   -4, 16, 32,  0 }, {     19,   -5,   -5, 16, 32,  0 }, {     19,   -5,   -6, 16, 32,  0 }, {     19,   -6,   -7, 16, 32,  0 },
    {     20,   -6,   -8, 16, 31,  0 }, {     20,   -7,   -9, 16, 31,  0 }, {     20,   -8,  -10, 16, 31,  0 }, {     20,   -8,  -11, 16, 31,  0 }, {     21,   -9,  -12, 16, 31,  0 },
    {     21,   -9,  -13, 16, 31,  0 }, {     22,  -10,  -14, 16, 31,  0 }, {     22,  -10,  -15, 16, 31,  0 }, {     22,  -11,  -16, 16, 31,  0 }, {     23,  -11,  -17, 16, 31,  0 },
    {     23,  -11,  -18, 16, 31,  0 }, {     24,  -12,  -19, 16, 31,  0 }, {     24,  -12,  -20, 16, 31,  0 }, {     25,  -13,  -21, 16, 31,  0 }, {     25,  -13,  -22, 16, 31,  0 },
    {     26,  -13,  -23, 16, 31,  0 }, {     27,  -13,  -24, 16, 31,  0 }, {     27,  -14,  -25, 16, 30,  0 }, {     28,  -14,  -26, 16, 30,  0 }, {     28,  -14,  -27, 16, 30,  0 },
    {     29,  -15,  -28, 16, 30,  0 }, {     30,  -15,  -29, 16, 30,  0 }, {     31,  -15,  -30, 16, 30,  0 }, {     31,  -15,  -31, 16, 30,  0 }, {     32,  -15,  -32, 16, 30,  0 },
    {     33,  -16,  -33, 16, 30,  0 }, {     34,  -16,  -34, 16, 30,  0 }, {     35,  -16,  -35, 16, 30,  0 }, {     36,  -16,  -36, 16, 30,  0 }, {     37,  -16,  -37, 16, 30,  0 },
    {     38,  -16,  -38, 16, 30,  0 }, {     39,  -17,  -39, 16, 30,  0 }, {     40,  -17,  -39, 16, 30,  0 }, {     41,  -17,  -40, 16, 29,  0 }, {     42,  -17,  -41, 16, 29,  0 },
    {     43,  -17,  -42, 16, 29,  0 }, {     44,  -17,  -42, 16, 29,  0 }, {     45,  -17,  -43, 16, 29,  0 }, {     46,  -17,  -43, 16, 29,  0 }, {     47,  -17,  -44, 16, 29,  0 },
    {     48,  -17,  -44, 16, 29,  0 }, {     49,  -17,  -45, 16, 29,  0 }, {     50,  -17,  -45, 16, 29,  0 }, {     51,  -17,  -46, 16, 29,  0 }, {     52,  -17,  -46, 16, 29,  0 },
    {     53,  -17,  -46, 16, 29,  0 }, {     54,  -17,  -47, 16, 29,  0 }, {     55,  -17,  -47, 16, 29,  0 }, {     56,  -17,  -47, 16, 29,  0 }, {     57,  -17,  -47, 16, 29,  0 },
    {     58,  -17,  -47, 16,  0,  0 }, {     59,  -17,  -48, 16,  0,  0 }, {     60,  -17,  -48, 16,  0,  0 }, {     61,  -17,  -48, 16,  0,  0 }, {     62,  -17,  -48, 16,  0,  0 },
    {     63,  -17,  -48, 16,  0,  0 }, {     64,  -17,  -48, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8ED156, {
    {     31,   16,   16, 16, 16,  0 }, {     30,   16,   16, 16, 16,  0 }, {     29,   16,   16, 16, 16,  0 }, {     28,   16,   16, 16, 16,  0 }, {     27,   16,   16, 16, 16,  0 },
    {     26,   16,   16, 16, 16,  0 }, {     25,   16,   15, 16, 16,  0 }, {     24,   16,   15, 16, 16,  0 }, {     23,   16,   15,  8, 43,  0 }, {     22,   16,   15,  8, 43,  0 },
    {     21,   16,   15,  8, 43,  0 }, {     20,   16,   14,  8, 43,  0 }, {     19,   16,   14,  8, 43,  0 }, {     18,   16,   14,  8, 43,  0 }, {     17,   16,   13,  8, 43,  0 },
    {     16,   16,   13,  8, 43,  0 }, {     15,   16,   12,  8, 43,  0 }, {     14,   16,   12,  8, 43,  0 }, {     13,   16,   11,  8, 43,  0 }, {     12,   16,   11,  8, 43,  0 },
    {     11,   16,   10,  8, 43,  0 }, {     10,   16,   10,  8, 43,  0 }, {      9,   16,    9,  8, 43,  0 }, {      8,   16,    8,  8, 43,  0 }, {      7,   16,    7,  8, 42,  0 },
    {      6,   16,    7,  8, 42,  0 }, {      5,   17,    6,  8, 42,  0 }, {      4,   17,    5,  8, 42,  0 }, {      3,   17,    4,  8, 42,  0 }, {      2,   17,    3,  8, 42,  0 },
    {      1,   17,    2,  8, 42,  0 }, {      0,   17,    1,  8, 42,  0 }, {     -1,   18,    0,  8, 42,  0 }, {     -2,   18,   -1,  8, 42,  0 }, {     -2,   18,   -2,  8, 42,  0 },
    {     -3,   18,   -3,  8, 42,  0 }, {     -4,   18,   -4,  8, 42,  0 }, {     -5,   19,   -5,  8, 42,  0 }, {     -5,   19,   -6,  8, 42,  0 }, {     -6,   19,   -7,  8, 42,  0 },
    {     -6,   20,   -8,  8, 41,  0 }, {     -7,   20,   -9,  8, 41,  0 }, {     -8,   20,  -10,  8, 41,  0 }, {     -8,   20,  -11,  8, 41,  0 }, {     -9,   21,  -12,  8, 41,  0 },
    {     -9,   21,  -13,  8, 41,  0 }, {    -10,   22,  -14,  8, 41,  0 }, {    -10,   22,  -15,  8, 41,  0 }, {    -11,   22,  -16,  8, 41,  0 }, {    -11,   23,  -17,  8, 41,  0 },
    {    -11,   23,  -18,  8, 41,  0 }, {    -12,   24,  -19,  8, 41,  0 }, {    -12,   24,  -20,  8, 41,  0 }, {    -13,   25,  -21,  8, 41,  0 }, {    -13,   25,  -22,  8, 41,  0 },
    {    -13,   26,  -23,  8, 41,  0 }, {    -13,   27,  -24,  8, 41,  0 }, {    -14,   27,  -25,  8, 40,  0 }, {    -14,   28,  -26,  8, 40,  0 }, {    -14,   28,  -27,  8, 40,  0 },
    {    -15,   29,  -28,  8, 40,  0 }, {    -15,   30,  -29,  8, 40,  0 }, {    -15,   31,  -30,  8, 40,  0 }, {    -15,   31,  -31,  8, 40,  0 }, {    -15,   32,  -32,  8, 40,  0 },
    {    -16,   33,  -33,  8, 40,  0 }, {    -16,   34,  -34,  8, 40,  0 }, {    -16,   35,  -35,  8, 40,  0 }, {    -16,   36,  -36,  8, 40,  0 }, {    -16,   37,  -37,  8, 40,  0 },
    {    -16,   38,  -38,  8, 40,  0 }, {    -17,   39,  -39,  8, 40,  0 }, {    -17,   40,  -39,  8, 40,  0 }, {    -17,   41,  -40,  8, 39,  0 }, {    -17,   42,  -41,  8, 39,  0 },
    {    -17,   43,  -42,  8, 39,  0 }, {    -17,   44,  -42,  8, 39,  0 }, {    -17,   45,  -43,  8, 39,  0 }, {    -17,   46,  -43,  8, 39,  0 }, {    -17,   47,  -44,  8, 39,  0 },
    {    -17,   48,  -44,  8, 39,  0 }, {    -17,   49,  -45,  8, 39,  0 }, {    -17,   50,  -45,  8, 39,  0 }, {    -17,   51,  -46,  8, 39,  0 }, {    -17,   52,  -46,  8, 39,  0 },
    {    -17,   53,  -46,  8, 39,  0 }, {    -17,   54,  -47,  8, 39,  0 }, {    -17,   55,  -47,  8, 39,  0 }, {    -17,   56,  -47,  8, 39,  0 }, {    -17,   57,  -47,  8, 39,  0 },
    {    -17,   58,  -47,  8,  0,  0 }, {    -17,   59,  -48,  8,  0,  0 }, {    -17,   60,  -48,  8,  0,  0 }, {    -17,   61,  -48,  8,  0,  0 }, {    -17,   62,  -48,  8,  0,  0 },
    {    -17,   63,  -48,  8,  0,  0 }, {    -17,   64,  -48,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8ED4C1, {
    {     16,    0,   16, 24, 16,  0 }, {     16,    1,   16, 24, 16,  0 }, {     16,    2,   16, 24, 16,  0 }, {     16,    3,   16, 24, 16,  0 }, {     16,    4,   16, 24, 16,  0 },
    {     16,    5,   16, 24, 16,  0 }, {     16,    6,   15, 24, 16,  0 }, {     16,    7,   15, 24, 16,  0 }, {     16,    8,   15, 16, 43,  0 }, {     16,    9,   15, 16, 43,  0 },
    {     16,   10,   15, 16, 43,  0 }, {     16,   11,   14, 16, 43,  0 }, {     16,   12,   14, 16, 43,  0 }, {     16,   13,   14, 16, 43,  0 }, {     16,   14,   13, 16, 43,  0 },
    {     16,   15,   13, 16, 43,  0 }, {     16,   16,   12, 16, 43,  0 }, {     16,   17,   12, 16, 43,  0 }, {     16,   18,   11, 16, 43,  0 }, {     16,   19,   11, 16, 43,  0 },
    {     16,   20,   10, 16, 43,  0 }, {     16,   21,   10, 16, 43,  0 }, {     16,   22,    9, 16, 43,  0 }, {     16,   23,    8, 16, 43,  0 }, {     16,   24,    7, 16, 42,  0 },
    {     16,   25,    7, 16, 42,  0 }, {     17,   26,    6, 16, 42,  0 }, {     17,   27,    5, 16, 42,  0 }, {     17,   28,    4, 16, 42,  0 }, {     17,   29,    3, 16, 42,  0 },
    {     17,   30,    2, 16, 42,  0 }, {     17,   31,    1, 16, 42,  0 }, {     18,   32,    0, 16, 42,  0 }, {     18,   33,   -1, 16, 42,  0 }, {     18,   33,   -2, 16, 42,  0 },
    {     18,   34,   -3, 16, 42,  0 }, {     18,   35,   -4, 16, 42,  0 }, {     19,   36,   -5, 16, 42,  0 }, {     19,   36,   -6, 16, 42,  0 }, {     19,   37,   -7, 16, 42,  0 },
    {     20,   37,   -8, 16, 41,  0 }, {     20,   38,   -9, 16, 41,  0 }, {     20,   39,  -10, 16, 41,  0 }, {     20,   39,  -11, 16, 41,  0 }, {     21,   40,  -12, 16, 41,  0 },
    {     21,   40,  -13, 16, 41,  0 }, {     22,   41,  -14, 16, 41,  0 }, {     22,   41,  -15, 16, 41,  0 }, {     22,   42,  -16, 16, 41,  0 }, {     23,   42,  -17, 16, 41,  0 },
    {     23,   42,  -18, 16, 41,  0 }, {     24,   43,  -19, 16, 41,  0 }, {     24,   43,  -20, 16, 41,  0 }, {     25,   44,  -21, 16, 41,  0 }, {     25,   44,  -22, 16, 41,  0 },
    {     26,   44,  -23, 16, 41,  0 }, {     27,   44,  -24, 16, 41,  0 }, {     27,   45,  -25, 16, 40,  0 }, {     28,   45,  -26, 16, 40,  0 }, {     28,   45,  -27, 16, 40,  0 },
    {     29,   46,  -28, 16, 40,  0 }, {     30,   46,  -29, 16, 40,  0 }, {     31,   46,  -30, 16, 40,  0 }, {     31,   46,  -31, 16, 40,  0 }, {     32,   46,  -32, 16, 40,  0 },
    {     33,   47,  -33, 16, 40,  0 }, {     34,   47,  -34, 16, 40,  0 }, {     35,   47,  -35, 16, 40,  0 }, {     36,   47,  -36, 16, 40,  0 }, {     37,   47,  -37, 16, 40,  0 },
    {     38,   47,  -38, 16, 40,  0 }, {     39,   48,  -39, 16, 40,  0 }, {     40,   48,  -39, 16, 40,  0 }, {     41,   48,  -40, 16, 39,  0 }, {     42,   48,  -41, 16, 39,  0 },
    {     43,   48,  -42, 16, 39,  0 }, {     44,   48,  -42, 16, 39,  0 }, {     45,   48,  -43, 16, 39,  0 }, {     46,   48,  -43, 16, 39,  0 }, {     47,   48,  -44, 16, 39,  0 },
    {     48,   48,  -44, 16, 39,  0 }, {     49,   48,  -45, 16, 39,  0 }, {     50,   48,  -45, 16, 39,  0 }, {     51,   48,  -46, 16, 39,  0 }, {     52,   48,  -46, 16, 39,  0 },
    {     53,   48,  -46, 16, 39,  0 }, {     54,   48,  -47, 16, 39,  0 }, {     55,   48,  -47, 16, 39,  0 }, {     56,   48,  -47, 16, 39,  0 }, {     57,   48,  -47, 16, 39,  0 },
    {     58,   48,  -47, 16,  0,  0 }, {     59,   48,  -48, 16,  0,  0 }, {     60,   48,  -48, 16,  0,  0 }, {     61,   48,  -48, 16,  0,  0 }, {     62,   48,  -48, 16,  0,  0 },
    {     63,   48,  -48, 16,  0,  0 }, {     64,   48,  -48, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8ED82C, {
    {      0,   16,   16,  0, 16,  0 }, {      1,   16,   16,  0, 16,  0 }, {      2,   16,   16,  0, 16,  0 }, {      3,   16,   16,  0, 16,  0 }, {      4,   16,   16,  0, 16,  0 },
    {      5,   16,   16,  0, 16,  0 }, {      6,   16,   15,  0, 16,  0 }, {      7,   16,   15,  0, 16,  0 }, {      8,   16,   15, 24, 43,  0 }, {      9,   16,   15, 24, 43,  0 },
    {     10,   16,   15, 24, 43,  0 }, {     11,   16,   14, 24, 43,  0 }, {     12,   16,   14, 24, 43,  0 }, {     13,   16,   14, 24, 43,  0 }, {     14,   16,   13, 24, 43,  0 },
    {     15,   16,   13, 24, 43,  0 }, {     16,   16,   12, 24, 43,  0 }, {     17,   16,   12, 24, 43,  0 }, {     18,   16,   11, 24, 43,  0 }, {     19,   16,   11, 24, 43,  0 },
    {     20,   16,   10, 24, 43,  0 }, {     21,   16,   10, 24, 43,  0 }, {     22,   16,    9, 24, 43,  0 }, {     23,   16,    8, 24, 43,  0 }, {     24,   16,    7, 24, 42,  0 },
    {     25,   16,    7, 24, 42,  0 }, {     26,   15,    6, 24, 42,  0 }, {     27,   15,    5, 24, 42,  0 }, {     28,   15,    4, 24, 42,  0 }, {     29,   15,    3, 24, 42,  0 },
    {     30,   15,    2, 24, 42,  0 }, {     31,   15,    1, 24, 42,  0 }, {     32,   14,    0, 24, 42,  0 }, {     33,   14,   -1, 24, 42,  0 }, {     33,   14,   -2, 24, 42,  0 },
    {     34,   14,   -3, 24, 42,  0 }, {     35,   14,   -4, 24, 42,  0 }, {     36,   13,   -5, 24, 42,  0 }, {     36,   13,   -6, 24, 42,  0 }, {     37,   13,   -7, 24, 42,  0 },
    {     37,   12,   -8, 24, 41,  0 }, {     38,   12,   -9, 24, 41,  0 }, {     39,   12,  -10, 24, 41,  0 }, {     39,   12,  -11, 24, 41,  0 }, {     40,   11,  -12, 24, 41,  0 },
    {     40,   11,  -13, 24, 41,  0 }, {     41,   10,  -14, 24, 41,  0 }, {     41,   10,  -15, 24, 41,  0 }, {     42,   10,  -16, 24, 41,  0 }, {     42,    9,  -17, 24, 41,  0 },
    {     42,    9,  -18, 24, 41,  0 }, {     43,    8,  -19, 24, 41,  0 }, {     43,    8,  -20, 24, 41,  0 }, {     44,    7,  -21, 24, 41,  0 }, {     44,    7,  -22, 24, 41,  0 },
    {     44,    6,  -23, 24, 41,  0 }, {     44,    5,  -24, 24, 41,  0 }, {     45,    5,  -25, 24, 40,  0 }, {     45,    4,  -26, 24, 40,  0 }, {     45,    4,  -27, 24, 40,  0 },
    {     46,    3,  -28, 24, 40,  0 }, {     46,    2,  -29, 24, 40,  0 }, {     46,    1,  -30, 24, 40,  0 }, {     46,    1,  -31, 24, 40,  0 }, {     46,    0,  -32, 24, 40,  0 },
    {     47,   -1,  -33, 24, 40,  0 }, {     47,   -2,  -34, 24, 40,  0 }, {     47,   -3,  -35, 24, 40,  0 }, {     47,   -4,  -36, 24, 40,  0 }, {     47,   -5,  -37, 24, 40,  0 },
    {     47,   -6,  -38, 24, 40,  0 }, {     48,   -7,  -39, 24, 40,  0 }, {     48,   -8,  -39, 24, 40,  0 }, {     48,   -9,  -40, 24, 39,  0 }, {     48,  -10,  -41, 24, 39,  0 },
    {     48,  -11,  -42, 24, 39,  0 }, {     48,  -12,  -42, 24, 39,  0 }, {     48,  -13,  -43, 24, 39,  0 }, {     48,  -14,  -43, 24, 39,  0 }, {     48,  -15,  -44, 24, 39,  0 },
    {     48,  -16,  -44, 24, 39,  0 }, {     48,  -17,  -45, 24, 39,  0 }, {     48,  -18,  -45, 24, 39,  0 }, {     48,  -19,  -46, 24, 39,  0 }, {     48,  -20,  -46, 24, 39,  0 },
    {     48,  -21,  -46, 24, 39,  0 }, {     48,  -22,  -47, 24, 39,  0 }, {     48,  -23,  -47, 24, 39,  0 }, {     48,  -24,  -47, 24, 39,  0 }, {     48,  -25,  -47, 24, 39,  0 },
    {     48,  -26,  -47, 24,  0,  0 }, {     48,  -27,  -48, 24,  0,  0 }, {     48,  -28,  -48, 24,  0,  0 }, {     48,  -29,  -48, 24,  0,  0 }, {     48,  -30,  -48, 24,  0,  0 },
    {     48,  -31,  -48, 24,  0,  0 }, {     48,  -32,  -48, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EDB97, {
    {     16,   31,   16,  8, 16,  0 }, {     16,   30,   16,  8, 16,  0 }, {     16,   29,   16,  8, 16,  0 }, {     16,   28,   16,  8, 16,  0 }, {     16,   27,   16,  8, 16,  0 },
    {     16,   26,   16,  8, 16,  0 }, {     16,   25,   15,  8, 16,  0 }, {     16,   24,   15,  8, 16,  0 }, {     16,   23,   15,  0, 43,  0 }, {     16,   22,   15,  0, 43,  0 },
    {     16,   21,   15,  0, 43,  0 }, {     16,   20,   14,  0, 43,  0 }, {     16,   19,   14,  0, 43,  0 }, {     16,   18,   14,  0, 43,  0 }, {     16,   17,   13,  0, 43,  0 },
    {     16,   16,   13,  0, 43,  0 }, {     16,   15,   12,  0, 43,  0 }, {     16,   14,   12,  0, 43,  0 }, {     16,   13,   11,  0, 43,  0 }, {     16,   12,   11,  0, 43,  0 },
    {     16,   11,   10,  0, 43,  0 }, {     16,   10,   10,  0, 43,  0 }, {     16,    9,    9,  0, 43,  0 }, {     16,    8,    8,  0, 43,  0 }, {     16,    7,    7,  0, 42,  0 },
    {     16,    6,    7,  0, 42,  0 }, {     15,    5,    6,  0, 42,  0 }, {     15,    4,    5,  0, 42,  0 }, {     15,    3,    4,  0, 42,  0 }, {     15,    2,    3,  0, 42,  0 },
    {     15,    1,    2,  0, 42,  0 }, {     15,    0,    1,  0, 42,  0 }, {     14,   -1,    0,  0, 42,  0 }, {     14,   -2,   -1,  0, 42,  0 }, {     14,   -2,   -2,  0, 42,  0 },
    {     14,   -3,   -3,  0, 42,  0 }, {     14,   -4,   -4,  0, 42,  0 }, {     13,   -5,   -5,  0, 42,  0 }, {     13,   -5,   -6,  0, 42,  0 }, {     13,   -6,   -7,  0, 42,  0 },
    {     12,   -6,   -8,  0, 41,  0 }, {     12,   -7,   -9,  0, 41,  0 }, {     12,   -8,  -10,  0, 41,  0 }, {     12,   -8,  -11,  0, 41,  0 }, {     11,   -9,  -12,  0, 41,  0 },
    {     11,   -9,  -13,  0, 41,  0 }, {     10,  -10,  -14,  0, 41,  0 }, {     10,  -10,  -15,  0, 41,  0 }, {     10,  -11,  -16,  0, 41,  0 }, {      9,  -11,  -17,  0, 41,  0 },
    {      9,  -11,  -18,  0, 41,  0 }, {      8,  -12,  -19,  0, 41,  0 }, {      8,  -12,  -20,  0, 41,  0 }, {      7,  -13,  -21,  0, 41,  0 }, {      7,  -13,  -22,  0, 41,  0 },
    {      6,  -13,  -23,  0, 41,  0 }, {      5,  -13,  -24,  0, 41,  0 }, {      5,  -14,  -25,  0, 40,  0 }, {      4,  -14,  -26,  0, 40,  0 }, {      4,  -14,  -27,  0, 40,  0 },
    {      3,  -15,  -28,  0, 40,  0 }, {      2,  -15,  -29,  0, 40,  0 }, {      1,  -15,  -30,  0, 40,  0 }, {      1,  -15,  -31,  0, 40,  0 }, {      0,  -15,  -32,  0, 40,  0 },
    {     -1,  -16,  -33,  0, 40,  0 }, {     -2,  -16,  -34,  0, 40,  0 }, {     -3,  -16,  -35,  0, 40,  0 }, {     -4,  -16,  -36,  0, 40,  0 }, {     -5,  -16,  -37,  0, 40,  0 },
    {     -6,  -16,  -38,  0, 40,  0 }, {     -7,  -17,  -39,  0, 40,  0 }, {     -8,  -17,  -39,  0, 40,  0 }, {     -9,  -17,  -40,  0, 39,  0 }, {    -10,  -17,  -41,  0, 39,  0 },
    {    -11,  -17,  -42,  0, 39,  0 }, {    -12,  -17,  -42,  0, 39,  0 }, {    -13,  -17,  -43,  0, 39,  0 }, {    -14,  -17,  -43,  0, 39,  0 }, {    -15,  -17,  -44,  0, 39,  0 },
    {    -16,  -17,  -44,  0, 39,  0 }, {    -17,  -17,  -45,  0, 39,  0 }, {    -18,  -17,  -45,  0, 39,  0 }, {    -19,  -17,  -46,  0, 39,  0 }, {    -20,  -17,  -46,  0, 39,  0 },
    {    -21,  -17,  -46,  0, 39,  0 }, {    -22,  -17,  -47,  0, 39,  0 }, {    -23,  -17,  -47,  0, 39,  0 }, {    -24,  -17,  -47,  0, 39,  0 }, {    -25,  -17,  -47,  0, 39,  0 },
    {    -26,  -17,  -47,  0,  0,  0 }, {    -27,  -17,  -48,  0,  0,  0 }, {    -28,  -17,  -48,  0,  0,  0 }, {    -29,  -17,  -48,  0,  0,  0 }, {    -30,  -17,  -48,  0,  0,  0 },
    {    -31,  -17,  -48,  0,  0,  0 }, {    -32,  -17,  -48,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C6C32, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    1,  0,  0,  0 },
    {     26,   16,    1,  0,  1,  0 }, {     25,   16,    1,  0,  1,  0 }, {     24,   16,    2,  0,  1,  0 }, {     23,   16,    2,  0,  1,  0 }, {     22,   16,    2,  0,  1,  0 },
    {     21,   16,    3,  0,  1,  0 }, {     20,   16,    3,  0,  1,  0 }, {     19,   16,    4,  0,  1,  0 }, {     18,   16,    4,  0,  2,  0 }, {     17,   16,    5,  0,  2,  0 },
    {     16,   16,    5,  0,  2,  0 }, {     15,   16,    6,  0,  2,  0 }, {     14,   16,    6,  0,  2,  0 }, {     13,   16,    7,  0,  2,  0 }, {     12,   16,    8,  0,  2,  0 },
    {     11,   16,    8,  0,  2,  0 }, {     10,   16,    9,  0,  2,  0 }, {      9,   16,   10,  0,  3,  0 }, {      8,   16,   11,  0,  3,  0 }, {      7,   16,   12,  0,  3,  0 },
    {      6,   16,   13,  0,  3,  0 }, {      5,   16,   14,  0,  3,  0 }, {      4,   16,   15,  0,  3,  0 }, {      4,   16,   16,  0,  3,  0 }, {      3,   16,   17,  0,  4,  0 },
    {      2,   16,   18,  0,  4,  0 }, {      2,   16,   19,  0,  4,  0 }, {      1,   16,   20,  0,  4,  0 }, {      1,   16,   21,  0,  4,  0 }, {      0,   16,   22,  0,  4,  0 },
    {      0,   16,   23,  0,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C6D78, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    1,  8,  0,  0 },
    {     16,    5,    1,  8,  1,  0 }, {     16,    6,    1,  8,  1,  0 }, {     16,    7,    2,  8,  1,  0 }, {     16,    8,    2,  8,  1,  0 }, {     16,    9,    2,  8,  1,  0 },
    {     16,   10,    3,  8,  1,  0 }, {     16,   11,    3,  8,  1,  0 }, {     16,   12,    4,  8,  1,  0 }, {     16,   13,    4,  8,  2,  0 }, {     16,   14,    5,  8,  2,  0 },
    {     16,   15,    5,  8,  2,  0 }, {     16,   16,    6,  8,  2,  0 }, {     16,   17,    6,  8,  2,  0 }, {     16,   18,    7,  8,  2,  0 }, {     16,   19,    8,  8,  2,  0 },
    {     16,   20,    8,  8,  2,  0 }, {     16,   21,    9,  8,  2,  0 }, {     16,   22,   10,  8,  3,  0 }, {     16,   23,   11,  8,  3,  0 }, {     16,   24,   12,  8,  3,  0 },
    {     16,   25,   13,  8,  3,  0 }, {     16,   26,   14,  8,  3,  0 }, {     16,   27,   15,  8,  3,  0 }, {     16,   27,   16,  8,  3,  0 }, {     16,   28,   17,  8,  4,  0 },
    {     16,   29,   18,  8,  4,  0 }, {     16,   29,   19,  8,  4,  0 }, {     16,   30,   20,  8,  4,  0 }, {     16,   30,   21,  8,  4,  0 }, {     16,   31,   22,  8,  4,  0 },
    {     16,   31,   23,  8,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C6EBE, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    1, 16,  0,  0 },
    {      5,   16,    1, 16,  1,  0 }, {      6,   16,    1, 16,  1,  0 }, {      7,   16,    2, 16,  1,  0 }, {      8,   16,    2, 16,  1,  0 }, {      9,   16,    2, 16,  1,  0 },
    {     10,   16,    3, 16,  1,  0 }, {     11,   16,    3, 16,  1,  0 }, {     12,   16,    4, 16,  1,  0 }, {     13,   16,    4, 16,  2,  0 }, {     14,   16,    5, 16,  2,  0 },
    {     15,   16,    5, 16,  2,  0 }, {     16,   16,    6, 16,  2,  0 }, {     17,   16,    6, 16,  2,  0 }, {     18,   16,    7, 16,  2,  0 }, {     19,   16,    8, 16,  2,  0 },
    {     20,   16,    8, 16,  2,  0 }, {     21,   16,    9, 16,  2,  0 }, {     22,   16,   10, 16,  3,  0 }, {     23,   16,   11, 16,  3,  0 }, {     24,   16,   12, 16,  3,  0 },
    {     25,   16,   13, 16,  3,  0 }, {     26,   16,   14, 16,  3,  0 }, {     27,   16,   15, 16,  3,  0 }, {     27,   16,   16, 16,  3,  0 }, {     28,   16,   17, 16,  4,  0 },
    {     29,   16,   18, 16,  4,  0 }, {     29,   16,   19, 16,  4,  0 }, {     30,   16,   20, 16,  4,  0 }, {     30,   16,   21, 16,  4,  0 }, {     31,   16,   22, 16,  4,  0 },
    {     31,   16,   23, 16,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C7004, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    1, 24,  0,  0 },
    {     16,   26,    1, 24,  1,  0 }, {     16,   25,    1, 24,  1,  0 }, {     16,   24,    2, 24,  1,  0 }, {     16,   23,    2, 24,  1,  0 }, {     16,   22,    2, 24,  1,  0 },
    {     16,   21,    3, 24,  1,  0 }, {     16,   20,    3, 24,  1,  0 }, {     16,   19,    4, 24,  1,  0 }, {     16,   18,    4, 24,  2,  0 }, {     16,   17,    5, 24,  2,  0 },
    {     16,   16,    5, 24,  2,  0 }, {     16,   15,    6, 24,  2,  0 }, {     16,   14,    6, 24,  2,  0 }, {     16,   13,    7, 24,  2,  0 }, {     16,   12,    8, 24,  2,  0 },
    {     16,   11,    8, 24,  2,  0 }, {     16,   10,    9, 24,  2,  0 }, {     16,    9,   10, 24,  3,  0 }, {     16,    8,   11, 24,  3,  0 }, {     16,    7,   12, 24,  3,  0 },
    {     16,    6,   13, 24,  3,  0 }, {     16,    5,   14, 24,  3,  0 }, {     16,    4,   15, 24,  3,  0 }, {     16,    4,   16, 24,  3,  0 }, {     16,    3,   17, 24,  4,  0 },
    {     16,    2,   18, 24,  4,  0 }, {     16,    2,   19, 24,  4,  0 }, {     16,    1,   20, 24,  4,  0 }, {     16,    1,   21, 24,  4,  0 }, {     16,    0,   22, 24,  4,  0 },
    {     16,    0,   23, 24,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C714A, {
    {     31,   16,    0,  0,  4,  0 }, {     31,   16,    1,  0,  4,  0 }, {     30,   16,    2,  0,  4,  0 }, {     30,   16,    3,  0,  4,  0 }, {     29,   16,    4,  0,  4,  0 },
    {     29,   16,    5,  0,  4,  0 }, {     28,   16,    6,  0,  4,  0 }, {     27,   16,    7,  0,  3,  0 }, {     27,   16,    8,  0,  3,  0 }, {     26,   16,    9,  0,  3,  0 },
    {     25,   16,   10,  0,  3,  0 }, {     24,   16,   11,  0,  3,  0 }, {     23,   16,   12,  0,  3,  0 }, {     22,   16,   13,  0,  3,  0 }, {     21,   16,   14,  0,  2,  0 },
    {     20,   16,   15,  0,  2,  0 }, {     19,   16,   15,  0,  2,  0 }, {     18,   16,   16,  0,  2,  0 }, {     17,   16,   17,  0,  2,  0 }, {     16,   16,   17,  0,  2,  0 },
    {     15,   16,   18,  0,  2,  0 }, {     14,   16,   18,  0,  2,  0 }, {     13,   16,   19,  0,  2,  0 }, {     12,   16,   19,  0,  1,  0 }, {     11,   16,   20,  0,  1,  0 },
    {     10,   16,   20,  0,  1,  0 }, {      9,   16,   21,  0,  1,  0 }, {      8,   16,   21,  0,  1,  0 }, {      7,   16,   21,  0,  1,  0 }, {      6,   16,   22,  0,  1,  0 },
    {      5,   16,   22,  0,  1,  0 }, {      4,   16,   22,  0,  0,  0 }, {      3,   16,   23,  0,  0,  0 }, {      2,   16,   23,  0,  0,  0 }, {      1,   16,   23,  0,  0,  0 },
    {      0,   16,   23,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C7290, {
    {     16,    0,    0,  8,  4,  0 }, {     16,    0,    1,  8,  4,  0 }, {     16,    1,    2,  8,  4,  0 }, {     16,    1,    3,  8,  4,  0 }, {     16,    2,    4,  8,  4,  0 },
    {     16,    2,    5,  8,  4,  0 }, {     16,    3,    6,  8,  4,  0 }, {     16,    4,    7,  8,  3,  0 }, {     16,    4,    8,  8,  3,  0 }, {     16,    5,    9,  8,  3,  0 },
    {     16,    6,   10,  8,  3,  0 }, {     16,    7,   11,  8,  3,  0 }, {     16,    8,   12,  8,  3,  0 }, {     16,    9,   13,  8,  3,  0 }, {     16,   10,   14,  8,  2,  0 },
    {     16,   11,   15,  8,  2,  0 }, {     16,   12,   15,  8,  2,  0 }, {     16,   13,   16,  8,  2,  0 }, {     16,   14,   17,  8,  2,  0 }, {     16,   15,   17,  8,  2,  0 },
    {     16,   16,   18,  8,  2,  0 }, {     16,   17,   18,  8,  2,  0 }, {     16,   18,   19,  8,  2,  0 }, {     16,   19,   19,  8,  1,  0 }, {     16,   20,   20,  8,  1,  0 },
    {     16,   21,   20,  8,  1,  0 }, {     16,   22,   21,  8,  1,  0 }, {     16,   23,   21,  8,  1,  0 }, {     16,   24,   21,  8,  1,  0 }, {     16,   25,   22,  8,  1,  0 },
    {     16,   26,   22,  8,  1,  0 }, {     16,   27,   22,  8,  0,  0 }, {     16,   28,   23,  8,  0,  0 }, {     16,   29,   23,  8,  0,  0 }, {     16,   30,   23,  8,  0,  0 },
    {     16,   31,   23,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C73D6, {
    {      0,   16,    0, 16,  4,  0 }, {      0,   16,    1, 16,  4,  0 }, {      1,   16,    2, 16,  4,  0 }, {      1,   16,    3, 16,  4,  0 }, {      2,   16,    4, 16,  4,  0 },
    {      2,   16,    5, 16,  4,  0 }, {      3,   16,    6, 16,  4,  0 }, {      4,   16,    7, 16,  3,  0 }, {      4,   16,    8, 16,  3,  0 }, {      5,   16,    9, 16,  3,  0 },
    {      6,   16,   10, 16,  3,  0 }, {      7,   16,   11, 16,  3,  0 }, {      8,   16,   12, 16,  3,  0 }, {      9,   16,   13, 16,  3,  0 }, {     10,   16,   14, 16,  2,  0 },
    {     11,   16,   15, 16,  2,  0 }, {     12,   16,   15, 16,  2,  0 }, {     13,   16,   16, 16,  2,  0 }, {     14,   16,   17, 16,  2,  0 }, {     15,   16,   17, 16,  2,  0 },
    {     16,   16,   18, 16,  2,  0 }, {     17,   16,   18, 16,  2,  0 }, {     18,   16,   19, 16,  2,  0 }, {     19,   16,   19, 16,  1,  0 }, {     20,   16,   20, 16,  1,  0 },
    {     21,   16,   20, 16,  1,  0 }, {     22,   16,   21, 16,  1,  0 }, {     23,   16,   21, 16,  1,  0 }, {     24,   16,   21, 16,  1,  0 }, {     25,   16,   22, 16,  1,  0 },
    {     26,   16,   22, 16,  1,  0 }, {     27,   16,   22, 16,  0,  0 }, {     28,   16,   23, 16,  0,  0 }, {     29,   16,   23, 16,  0,  0 }, {     30,   16,   23, 16,  0,  0 },
    {     31,   16,   23, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C751C, {
    {     16,   31,    0, 24,  4,  0 }, {     16,   31,    1, 24,  4,  0 }, {     16,   30,    2, 24,  4,  0 }, {     16,   30,    3, 24,  4,  0 }, {     16,   29,    4, 24,  4,  0 },
    {     16,   29,    5, 24,  4,  0 }, {     16,   28,    6, 24,  4,  0 }, {     16,   27,    7, 24,  3,  0 }, {     16,   27,    8, 24,  3,  0 }, {     16,   26,    9, 24,  3,  0 },
    {     16,   25,   10, 24,  3,  0 }, {     16,   24,   11, 24,  3,  0 }, {     16,   23,   12, 24,  3,  0 }, {     16,   22,   13, 24,  3,  0 }, {     16,   21,   14, 24,  2,  0 },
    {     16,   20,   15, 24,  2,  0 }, {     16,   19,   15, 24,  2,  0 }, {     16,   18,   16, 24,  2,  0 }, {     16,   17,   17, 24,  2,  0 }, {     16,   16,   17, 24,  2,  0 },
    {     16,   15,   18, 24,  2,  0 }, {     16,   14,   18, 24,  2,  0 }, {     16,   13,   19, 24,  2,  0 }, {     16,   12,   19, 24,  1,  0 }, {     16,   11,   20, 24,  1,  0 },
    {     16,   10,   20, 24,  1,  0 }, {     16,    9,   21, 24,  1,  0 }, {     16,    8,   21, 24,  1,  0 }, {     16,    7,   21, 24,  1,  0 }, {     16,    6,   22, 24,  1,  0 },
    {     16,    5,   22, 24,  1,  0 }, {     16,    4,   22, 24,  0,  0 }, {     16,    3,   23, 24,  0,  0 }, {     16,    2,   23, 24,  0,  0 }, {     16,    1,   23, 24,  0,  0 },
    {     16,    0,   23, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C7662, {
    {     31,   16,   23,  0,  0,  0 }, {     30,   16,   23,  0,  0,  0 }, {     29,   16,   23,  0,  0,  0 }, {     28,   16,   23,  0,  0,  0 }, {     27,   16,   22,  0,  0,  0 },
    {     26,   16,   22,  0,  5,  0 }, {     25,   16,   22,  0,  5,  0 }, {     24,   16,   21,  0,  5,  0 }, {     23,   16,   21,  0,  5,  0 }, {     22,   16,   21,  0,  5,  0 },
    {     21,   16,   20,  0,  5,  0 }, {     20,   16,   20,  0,  5,  0 }, {     19,   16,   19,  0,  5,  0 }, {     18,   16,   19,  0,  6,  0 }, {     17,   16,   18,  0,  6,  0 },
    {     16,   16,   18,  0,  6,  0 }, {     15,   16,   17,  0,  6,  0 }, {     14,   16,   17,  0,  6,  0 }, {     13,   16,   16,  0,  6,  0 }, {     12,   16,   15,  0,  6,  0 },
    {     11,   16,   15,  0,  6,  0 }, {     10,   16,   14,  0,  6,  0 }, {      9,   16,   13,  0,  7,  0 }, {      8,   16,   12,  0,  7,  0 }, {      7,   16,   11,  0,  7,  0 },
    {      6,   16,   10,  0,  7,  0 }, {      5,   16,    9,  0,  7,  0 }, {      4,   16,    8,  0,  7,  0 }, {      4,   16,    7,  0,  7,  0 }, {      3,   16,    6,  0,  8,  0 },
    {      2,   16,    5,  0,  8,  0 }, {      2,   16,    4,  0,  8,  0 }, {      1,   16,    3,  0,  8,  0 }, {      1,   16,    2,  0,  8,  0 }, {      0,   16,    1,  0,  8,  0 },
    {      0,   16,    0,  0,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C77A8, {
    {     16,    0,   23,  8,  0,  0 }, {     16,    1,   23,  8,  0,  0 }, {     16,    2,   23,  8,  0,  0 }, {     16,    3,   23,  8,  0,  0 }, {     16,    4,   22,  8,  0,  0 },
    {     16,    5,   22,  8,  5,  0 }, {     16,    6,   22,  8,  5,  0 }, {     16,    7,   21,  8,  5,  0 }, {     16,    8,   21,  8,  5,  0 }, {     16,    9,   21,  8,  5,  0 },
    {     16,   10,   20,  8,  5,  0 }, {     16,   11,   20,  8,  5,  0 }, {     16,   12,   19,  8,  5,  0 }, {     16,   13,   19,  8,  6,  0 }, {     16,   14,   18,  8,  6,  0 },
    {     16,   15,   18,  8,  6,  0 }, {     16,   16,   17,  8,  6,  0 }, {     16,   17,   17,  8,  6,  0 }, {     16,   18,   16,  8,  6,  0 }, {     16,   19,   15,  8,  6,  0 },
    {     16,   20,   15,  8,  6,  0 }, {     16,   21,   14,  8,  6,  0 }, {     16,   22,   13,  8,  7,  0 }, {     16,   23,   12,  8,  7,  0 }, {     16,   24,   11,  8,  7,  0 },
    {     16,   25,   10,  8,  7,  0 }, {     16,   26,    9,  8,  7,  0 }, {     16,   27,    8,  8,  7,  0 }, {     16,   27,    7,  8,  7,  0 }, {     16,   28,    6,  8,  8,  0 },
    {     16,   29,    5,  8,  8,  0 }, {     16,   29,    4,  8,  8,  0 }, {     16,   30,    3,  8,  8,  0 }, {     16,   30,    2,  8,  8,  0 }, {     16,   31,    1,  8,  8,  0 },
    {     16,   31,    0,  8,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C78EE, {
    {      0,   16,   23, 16,  0,  0 }, {      1,   16,   23, 16,  0,  0 }, {      2,   16,   23, 16,  0,  0 }, {      3,   16,   23, 16,  0,  0 }, {      4,   16,   22, 16,  0,  0 },
    {      5,   16,   22, 16,  5,  0 }, {      6,   16,   22, 16,  5,  0 }, {      7,   16,   21, 16,  5,  0 }, {      8,   16,   21, 16,  5,  0 }, {      9,   16,   21, 16,  5,  0 },
    {     10,   16,   20, 16,  5,  0 }, {     11,   16,   20, 16,  5,  0 }, {     12,   16,   19, 16,  5,  0 }, {     13,   16,   19, 16,  6,  0 }, {     14,   16,   18, 16,  6,  0 },
    {     15,   16,   18, 16,  6,  0 }, {     16,   16,   17, 16,  6,  0 }, {     17,   16,   17, 16,  6,  0 }, {     18,   16,   16, 16,  6,  0 }, {     19,   16,   15, 16,  6,  0 },
    {     20,   16,   15, 16,  6,  0 }, {     21,   16,   14, 16,  6,  0 }, {     22,   16,   13, 16,  7,  0 }, {     23,   16,   12, 16,  7,  0 }, {     24,   16,   11, 16,  7,  0 },
    {     25,   16,   10, 16,  7,  0 }, {     26,   16,    9, 16,  7,  0 }, {     27,   16,    8, 16,  7,  0 }, {     27,   16,    7, 16,  7,  0 }, {     28,   16,    6, 16,  8,  0 },
    {     29,   16,    5, 16,  8,  0 }, {     29,   16,    4, 16,  8,  0 }, {     30,   16,    3, 16,  8,  0 }, {     30,   16,    2, 16,  8,  0 }, {     31,   16,    1, 16,  8,  0 },
    {     31,   16,    0, 16,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C7A34, {
    {     16,   31,   23, 24,  0,  0 }, {     16,   30,   23, 24,  0,  0 }, {     16,   29,   23, 24,  0,  0 }, {     16,   28,   23, 24,  0,  0 }, {     16,   27,   22, 24,  0,  0 },
    {     16,   26,   22, 24,  5,  0 }, {     16,   25,   22, 24,  5,  0 }, {     16,   24,   21, 24,  5,  0 }, {     16,   23,   21, 24,  5,  0 }, {     16,   22,   21, 24,  5,  0 },
    {     16,   21,   20, 24,  5,  0 }, {     16,   20,   20, 24,  5,  0 }, {     16,   19,   19, 24,  5,  0 }, {     16,   18,   19, 24,  6,  0 }, {     16,   17,   18, 24,  6,  0 },
    {     16,   16,   18, 24,  6,  0 }, {     16,   15,   17, 24,  6,  0 }, {     16,   14,   17, 24,  6,  0 }, {     16,   13,   16, 24,  6,  0 }, {     16,   12,   15, 24,  6,  0 },
    {     16,   11,   15, 24,  6,  0 }, {     16,   10,   14, 24,  6,  0 }, {     16,    9,   13, 24,  7,  0 }, {     16,    8,   12, 24,  7,  0 }, {     16,    7,   11, 24,  7,  0 },
    {     16,    6,   10, 24,  7,  0 }, {     16,    5,    9, 24,  7,  0 }, {     16,    4,    8, 24,  7,  0 }, {     16,    4,    7, 24,  7,  0 }, {     16,    3,    6, 24,  8,  0 },
    {     16,    2,    5, 24,  8,  0 }, {     16,    2,    4, 24,  8,  0 }, {     16,    1,    3, 24,  8,  0 }, {     16,    1,    2, 24,  8,  0 }, {     16,    0,    1, 24,  8,  0 },
    {     16,    0,    0, 24,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C7B7A, {
    {     31,   16,   23,  0,  8,  0 }, {     31,   16,   22,  0,  8,  0 }, {     30,   16,   21,  0,  8,  0 }, {     30,   16,   20,  0,  8,  0 }, {     29,   16,   19,  0,  8,  0 },
    {     29,   16,   18,  0,  8,  0 }, {     28,   16,   17,  0,  8,  0 }, {     27,   16,   16,  0,  7,  0 }, {     27,   16,   15,  0,  7,  0 }, {     26,   16,   14,  0,  7,  0 },
    {     25,   16,   13,  0,  7,  0 }, {     24,   16,   12,  0,  7,  0 }, {     23,   16,   11,  0,  7,  0 }, {     22,   16,   10,  0,  7,  0 }, {     21,   16,    9,  0,  6,  0 },
    {     20,   16,    8,  0,  6,  0 }, {     19,   16,    8,  0,  6,  0 }, {     18,   16,    7,  0,  6,  0 }, {     17,   16,    6,  0,  6,  0 }, {     16,   16,    6,  0,  6,  0 },
    {     15,   16,    5,  0,  6,  0 }, {     14,   16,    5,  0,  6,  0 }, {     13,   16,    4,  0,  6,  0 }, {     12,   16,    4,  0,  5,  0 }, {     11,   16,    3,  0,  5,  0 },
    {     10,   16,    3,  0,  5,  0 }, {      9,   16,    2,  0,  5,  0 }, {      8,   16,    2,  0,  5,  0 }, {      7,   16,    2,  0,  5,  0 }, {      6,   16,    1,  0,  5,  0 },
    {      5,   16,    1,  0,  5,  0 }, {      4,   16,    1,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 },
    {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C7CC0, {
    {     16,    0,   23,  8,  8,  0 }, {     16,    0,   22,  8,  8,  0 }, {     16,    1,   21,  8,  8,  0 }, {     16,    1,   20,  8,  8,  0 }, {     16,    2,   19,  8,  8,  0 },
    {     16,    2,   18,  8,  8,  0 }, {     16,    3,   17,  8,  8,  0 }, {     16,    4,   16,  8,  7,  0 }, {     16,    4,   15,  8,  7,  0 }, {     16,    5,   14,  8,  7,  0 },
    {     16,    6,   13,  8,  7,  0 }, {     16,    7,   12,  8,  7,  0 }, {     16,    8,   11,  8,  7,  0 }, {     16,    9,   10,  8,  7,  0 }, {     16,   10,    9,  8,  6,  0 },
    {     16,   11,    8,  8,  6,  0 }, {     16,   12,    8,  8,  6,  0 }, {     16,   13,    7,  8,  6,  0 }, {     16,   14,    6,  8,  6,  0 }, {     16,   15,    6,  8,  6,  0 },
    {     16,   16,    5,  8,  6,  0 }, {     16,   17,    5,  8,  6,  0 }, {     16,   18,    4,  8,  6,  0 }, {     16,   19,    4,  8,  5,  0 }, {     16,   20,    3,  8,  5,  0 },
    {     16,   21,    3,  8,  5,  0 }, {     16,   22,    2,  8,  5,  0 }, {     16,   23,    2,  8,  5,  0 }, {     16,   24,    2,  8,  5,  0 }, {     16,   25,    1,  8,  5,  0 },
    {     16,   26,    1,  8,  5,  0 }, {     16,   27,    1,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   29,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 },
    {     16,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C7E06, {
    {      0,   16,   23, 16,  8,  0 }, {      0,   16,   22, 16,  8,  0 }, {      1,   16,   21, 16,  8,  0 }, {      1,   16,   20, 16,  8,  0 }, {      2,   16,   19, 16,  8,  0 },
    {      2,   16,   18, 16,  8,  0 }, {      3,   16,   17, 16,  8,  0 }, {      4,   16,   16, 16,  7,  0 }, {      4,   16,   15, 16,  7,  0 }, {      5,   16,   14, 16,  7,  0 },
    {      6,   16,   13, 16,  7,  0 }, {      7,   16,   12, 16,  7,  0 }, {      8,   16,   11, 16,  7,  0 }, {      9,   16,   10, 16,  7,  0 }, {     10,   16,    9, 16,  6,  0 },
    {     11,   16,    8, 16,  6,  0 }, {     12,   16,    8, 16,  6,  0 }, {     13,   16,    7, 16,  6,  0 }, {     14,   16,    6, 16,  6,  0 }, {     15,   16,    6, 16,  6,  0 },
    {     16,   16,    5, 16,  6,  0 }, {     17,   16,    5, 16,  6,  0 }, {     18,   16,    4, 16,  6,  0 }, {     19,   16,    4, 16,  5,  0 }, {     20,   16,    3, 16,  5,  0 },
    {     21,   16,    3, 16,  5,  0 }, {     22,   16,    2, 16,  5,  0 }, {     23,   16,    2, 16,  5,  0 }, {     24,   16,    2, 16,  5,  0 }, {     25,   16,    1, 16,  5,  0 },
    {     26,   16,    1, 16,  5,  0 }, {     27,   16,    1, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 }, {     29,   16,    0, 16,  0,  0 }, {     30,   16,    0, 16,  0,  0 },
    {     31,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8C7F4C, {
    {     16,   31,   23, 24,  8,  0 }, {     16,   31,   22, 24,  8,  0 }, {     16,   30,   21, 24,  8,  0 }, {     16,   30,   20, 24,  8,  0 }, {     16,   29,   19, 24,  8,  0 },
    {     16,   29,   18, 24,  8,  0 }, {     16,   28,   17, 24,  8,  0 }, {     16,   27,   16, 24,  7,  0 }, {     16,   27,   15, 24,  7,  0 }, {     16,   26,   14, 24,  7,  0 },
    {     16,   25,   13, 24,  7,  0 }, {     16,   24,   12, 24,  7,  0 }, {     16,   23,   11, 24,  7,  0 }, {     16,   22,   10, 24,  7,  0 }, {     16,   21,    9, 24,  6,  0 },
    {     16,   20,    8, 24,  6,  0 }, {     16,   19,    8, 24,  6,  0 }, {     16,   18,    7, 24,  6,  0 }, {     16,   17,    6, 24,  6,  0 }, {     16,   16,    6, 24,  6,  0 },
    {     16,   15,    5, 24,  6,  0 }, {     16,   14,    5, 24,  6,  0 }, {     16,   13,    4, 24,  6,  0 }, {     16,   12,    4, 24,  5,  0 }, {     16,   11,    3, 24,  5,  0 },
    {     16,   10,    3, 24,  5,  0 }, {     16,    9,    2, 24,  5,  0 }, {     16,    8,    2, 24,  5,  0 }, {     16,    7,    2, 24,  5,  0 }, {     16,    6,    1, 24,  5,  0 },
    {     16,    5,    1, 24,  5,  0 }, {     16,    4,    1, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 }, {     16,    1,    0, 24,  0,  0 },
    {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EFA5A, {
    {     16,   16,    2,  0, 10,  0 }, {     16,   16,    3,  0, 10,  0 }, {     16,   16,    4,  0, 10,  0 }, {     16,   16,    5,  0, 10,  0 }, {     16,   16,    6,  0, 10,  0 },
    {     16,   16,    7,  0, 10,  0 }, {     16,   16,    8,  0, 10,  0 }, {     16,   16,    9,  0, 10,  0 }, {     16,   16,   10,  0, 10,  0 }, {     16,   16,   11,  0, 10,  0 },
    {     16,   16,   12,  0, 10,  0 }, {     16,   16,   13,  0, 10,  0 }, {     16,   16,   14,  0, 10,  0 }, {     16,   16,   15,  0, 10,  0 }, {     16,   16,   16,  0, 10,  0 },
    {     16,   16,   17,  0, 10,  0 }, {     16,   16,   18,  0, 10,  0 }, {     16,   16,   19,  0, 10,  0 }, {     16,   16,   20,  0, 10,  0 }, {     16,   16,   21,  0, 10,  0 },
    {     16,   16,   22,  0, 10,  0 }, {     16,   16,   23,  0, 10,  0 }, {     16,   16,   24,  0, 10,  0 }, {     16,   16,   25,  0, 10,  0 }, {     16,   16,   26,  0, 10,  0 },
    {     16,   16,   27,  0, 10,  0 }, {     16,   16,   28,  0, 10,  0 }, {     16,   16,   29,  0, 10,  0 }, {     16,   16,   30,  0, 10,  0 }, {     16,   16,   31,  0, 10,  0 },
    {     16,   16,   32,  0, 10,  0 }, {     16,   16,   33,  0, 10,  0 }, {     16,   16,   34,  0, 10,  0 }, {     16,   16,   35,  0, 10,  0 }, {     16,   16,   36,  0, 10,  0 },
    {     16,   16,   37,  0, 10,  0 }, {     16,   16,   38,  0, 10,  0 }, {     16,   16,   39,  0, 10,  0 }, {     16,   16,   40,  0, 10,  0 }, {     16,   16,   41,  0, 10,  0 },
    {     16,   16,   42,  0, 10,  0 }, {     16,   16,   43,  0, 10,  0 }, {     16,   16,   44,  0, 10,  0 }, {     16,   16,   45,  0, 10,  0 }, {     16,   16,   46,  0, 10,  0 },
    {     16,   16,   47,  0, 10,  0 }, {     16,   16,   48,  0, 10,  0 }, {     16,   16,   49,  0, 10,  0 }, {     16,   16,   50,  0, 10,  0 }, {     16,   16,   51,  0, 10,  0 },
    {     16,   16,   52,  0, 10,  0 }, {     16,   16,   53,  0, 10,  0 }, {     16,   16,   54,  0, 10,  0 }, {     16,   16,   55,  0, 10,  0 }, {     16,   16,   56,  0, 10,  0 },
    {     16,   16,   57,  0, 10,  0 }, {     16,   16,   58,  0, 10,  0 }, {     16,   16,   59,  0, 10,  0 }, {     16,   16,   60,  0, 10,  0 }, {     16,   16,   61,  0, 10,  0 },
    {     16,   16,   62,  0, 10,  0 }, {     16,   16,   63,  0, 10,  0 }, {     16,   16,   64,  0, 10,  0 }, {     16,   16,   65,  0, 10,  0 }, {     16,   16,   66,  0, 10,  0 },
    {     16,   16,   67,  0, 10,  0 }, {     16,   16,   68,  0, 10,  0 }, {     16,   16,   69,  0, 10,  0 }, {     16,   16,   70,  0, 10,  0 }, {     16,   16,   71,  0, 10,  0 },
    {     16,   16,   72,  0, 10,  0 }, {     16,   16,   73,  0, 10,  0 }, {     16,   16,   74,  0, 10,  0 }, {     16,   16,   75,  0, 10,  0 }, {     16,   16,   76,  0, 10,  0 },
    {     16,   16,   77,  0, 10,  0 }, {     16,   16,   78,  0, 10,  0 }, {     16,   16,   79,  0, 10,  0 }, {     16,   16,   80,  0, 10,  0 }, {     16,   16,   81,  0, 10,  0 },
    {     16,   16,   82,  0, 10,  0 }, {     16,   16,   83,  0, 10,  0 }, {     16,   16,   84,  0, 10,  0 }, {     16,   16,   85,  0, 10,  0 }, {     16,   16,   86,  0, 10,  0 },
    {     16,   16,   87,  0, 10,  0 }, {     16,   16,   88,  0, 10,  0 }, {     16,   16,   89,  0, 10,  0 }, {     16,   16,   90,  0, 10,  0 }, {     16,   16,   91,  0, 10,  0 },
    {     16,   16,   92,  0, 10,  0 }, {     16,   16,   93,  0, 10,  0 }, {     16,   16,   94,  0, 10,  0 }, {     16,   16,   95,  0, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EFDAA, {
    {     16,   16,    2,  8, 10,  0 }, {     16,   16,    3,  8, 10,  0 }, {     16,   16,    4,  8, 10,  0 }, {     16,   16,    5,  8, 10,  0 }, {     16,   16,    6,  8, 10,  0 },
    {     16,   16,    7,  8, 10,  0 }, {     16,   16,    8,  8, 10,  0 }, {     16,   16,    9,  8, 10,  0 }, {     16,   16,   10,  8, 10,  0 }, {     16,   16,   11,  8, 10,  0 },
    {     16,   16,   12,  8, 10,  0 }, {     16,   16,   13,  8, 10,  0 }, {     16,   16,   14,  8, 10,  0 }, {     16,   16,   15,  8, 10,  0 }, {     16,   16,   16,  8, 10,  0 },
    {     16,   16,   17,  8, 10,  0 }, {     16,   16,   18,  8, 10,  0 }, {     16,   16,   19,  8, 10,  0 }, {     16,   16,   20,  8, 10,  0 }, {     16,   16,   21,  8, 10,  0 },
    {     16,   16,   22,  8, 10,  0 }, {     16,   16,   23,  8, 10,  0 }, {     16,   16,   24,  8, 10,  0 }, {     16,   16,   25,  8, 10,  0 }, {     16,   16,   26,  8, 10,  0 },
    {     16,   16,   27,  8, 10,  0 }, {     16,   16,   28,  8, 10,  0 }, {     16,   16,   29,  8, 10,  0 }, {     16,   16,   30,  8, 10,  0 }, {     16,   16,   31,  8, 10,  0 },
    {     16,   16,   32,  8, 10,  0 }, {     16,   16,   33,  8, 10,  0 }, {     16,   16,   34,  8, 10,  0 }, {     16,   16,   35,  8, 10,  0 }, {     16,   16,   36,  8, 10,  0 },
    {     16,   16,   37,  8, 10,  0 }, {     16,   16,   38,  8, 10,  0 }, {     16,   16,   39,  8, 10,  0 }, {     16,   16,   40,  8, 10,  0 }, {     16,   16,   41,  8, 10,  0 },
    {     16,   16,   42,  8, 10,  0 }, {     16,   16,   43,  8, 10,  0 }, {     16,   16,   44,  8, 10,  0 }, {     16,   16,   45,  8, 10,  0 }, {     16,   16,   46,  8, 10,  0 },
    {     16,   16,   47,  8, 10,  0 }, {     16,   16,   48,  8, 10,  0 }, {     16,   16,   49,  8, 10,  0 }, {     16,   16,   50,  8, 10,  0 }, {     16,   16,   51,  8, 10,  0 },
    {     16,   16,   52,  8, 10,  0 }, {     16,   16,   53,  8, 10,  0 }, {     16,   16,   54,  8, 10,  0 }, {     16,   16,   55,  8, 10,  0 }, {     16,   16,   56,  8, 10,  0 },
    {     16,   16,   57,  8, 10,  0 }, {     16,   16,   58,  8, 10,  0 }, {     16,   16,   59,  8, 10,  0 }, {     16,   16,   60,  8, 10,  0 }, {     16,   16,   61,  8, 10,  0 },
    {     16,   16,   62,  8, 10,  0 }, {     16,   16,   63,  8, 10,  0 }, {     16,   16,   64,  8, 10,  0 }, {     16,   16,   65,  8, 10,  0 }, {     16,   16,   66,  8, 10,  0 },
    {     16,   16,   67,  8, 10,  0 }, {     16,   16,   68,  8, 10,  0 }, {     16,   16,   69,  8, 10,  0 }, {     16,   16,   70,  8, 10,  0 }, {     16,   16,   71,  8, 10,  0 },
    {     16,   16,   72,  8, 10,  0 }, {     16,   16,   73,  8, 10,  0 }, {     16,   16,   74,  8, 10,  0 }, {     16,   16,   75,  8, 10,  0 }, {     16,   16,   76,  8, 10,  0 },
    {     16,   16,   77,  8, 10,  0 }, {     16,   16,   78,  8, 10,  0 }, {     16,   16,   79,  8, 10,  0 }, {     16,   16,   80,  8, 10,  0 }, {     16,   16,   81,  8, 10,  0 },
    {     16,   16,   82,  8, 10,  0 }, {     16,   16,   83,  8, 10,  0 }, {     16,   16,   84,  8, 10,  0 }, {     16,   16,   85,  8, 10,  0 }, {     16,   16,   86,  8, 10,  0 },
    {     16,   16,   87,  8, 10,  0 }, {     16,   16,   88,  8, 10,  0 }, {     16,   16,   89,  8, 10,  0 }, {     16,   16,   90,  8, 10,  0 }, {     16,   16,   91,  8, 10,  0 },
    {     16,   16,   92,  8, 10,  0 }, {     16,   16,   93,  8, 10,  0 }, {     16,   16,   94,  8, 10,  0 }, {     16,   16,   95,  8, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F00FA, {
    {     16,   16,    2, 16, 10,  0 }, {     16,   16,    3, 16, 10,  0 }, {     16,   16,    4, 16, 10,  0 }, {     16,   16,    5, 16, 10,  0 }, {     16,   16,    6, 16, 10,  0 },
    {     16,   16,    7, 16, 10,  0 }, {     16,   16,    8, 16, 10,  0 }, {     16,   16,    9, 16, 10,  0 }, {     16,   16,   10, 16, 10,  0 }, {     16,   16,   11, 16, 10,  0 },
    {     16,   16,   12, 16, 10,  0 }, {     16,   16,   13, 16, 10,  0 }, {     16,   16,   14, 16, 10,  0 }, {     16,   16,   15, 16, 10,  0 }, {     16,   16,   16, 16, 10,  0 },
    {     16,   16,   17, 16, 10,  0 }, {     16,   16,   18, 16, 10,  0 }, {     16,   16,   19, 16, 10,  0 }, {     16,   16,   20, 16, 10,  0 }, {     16,   16,   21, 16, 10,  0 },
    {     16,   16,   22, 16, 10,  0 }, {     16,   16,   23, 16, 10,  0 }, {     16,   16,   24, 16, 10,  0 }, {     16,   16,   25, 16, 10,  0 }, {     16,   16,   26, 16, 10,  0 },
    {     16,   16,   27, 16, 10,  0 }, {     16,   16,   28, 16, 10,  0 }, {     16,   16,   29, 16, 10,  0 }, {     16,   16,   30, 16, 10,  0 }, {     16,   16,   31, 16, 10,  0 },
    {     16,   16,   32, 16, 10,  0 }, {     16,   16,   33, 16, 10,  0 }, {     16,   16,   34, 16, 10,  0 }, {     16,   16,   35, 16, 10,  0 }, {     16,   16,   36, 16, 10,  0 },
    {     16,   16,   37, 16, 10,  0 }, {     16,   16,   38, 16, 10,  0 }, {     16,   16,   39, 16, 10,  0 }, {     16,   16,   40, 16, 10,  0 }, {     16,   16,   41, 16, 10,  0 },
    {     16,   16,   42, 16, 10,  0 }, {     16,   16,   43, 16, 10,  0 }, {     16,   16,   44, 16, 10,  0 }, {     16,   16,   45, 16, 10,  0 }, {     16,   16,   46, 16, 10,  0 },
    {     16,   16,   47, 16, 10,  0 }, {     16,   16,   48, 16, 10,  0 }, {     16,   16,   49, 16, 10,  0 }, {     16,   16,   50, 16, 10,  0 }, {     16,   16,   51, 16, 10,  0 },
    {     16,   16,   52, 16, 10,  0 }, {     16,   16,   53, 16, 10,  0 }, {     16,   16,   54, 16, 10,  0 }, {     16,   16,   55, 16, 10,  0 }, {     16,   16,   56, 16, 10,  0 },
    {     16,   16,   57, 16, 10,  0 }, {     16,   16,   58, 16, 10,  0 }, {     16,   16,   59, 16, 10,  0 }, {     16,   16,   60, 16, 10,  0 }, {     16,   16,   61, 16, 10,  0 },
    {     16,   16,   62, 16, 10,  0 }, {     16,   16,   63, 16, 10,  0 }, {     16,   16,   64, 16, 10,  0 }, {     16,   16,   65, 16, 10,  0 }, {     16,   16,   66, 16, 10,  0 },
    {     16,   16,   67, 16, 10,  0 }, {     16,   16,   68, 16, 10,  0 }, {     16,   16,   69, 16, 10,  0 }, {     16,   16,   70, 16, 10,  0 }, {     16,   16,   71, 16, 10,  0 },
    {     16,   16,   72, 16, 10,  0 }, {     16,   16,   73, 16, 10,  0 }, {     16,   16,   74, 16, 10,  0 }, {     16,   16,   75, 16, 10,  0 }, {     16,   16,   76, 16, 10,  0 },
    {     16,   16,   77, 16, 10,  0 }, {     16,   16,   78, 16, 10,  0 }, {     16,   16,   79, 16, 10,  0 }, {     16,   16,   80, 16, 10,  0 }, {     16,   16,   81, 16, 10,  0 },
    {     16,   16,   82, 16, 10,  0 }, {     16,   16,   83, 16, 10,  0 }, {     16,   16,   84, 16, 10,  0 }, {     16,   16,   85, 16, 10,  0 }, {     16,   16,   86, 16, 10,  0 },
    {     16,   16,   87, 16, 10,  0 }, {     16,   16,   88, 16, 10,  0 }, {     16,   16,   89, 16, 10,  0 }, {     16,   16,   90, 16, 10,  0 }, {     16,   16,   91, 16, 10,  0 },
    {     16,   16,   92, 16, 10,  0 }, {     16,   16,   93, 16, 10,  0 }, {     16,   16,   94, 16, 10,  0 }, {     16,   16,   95, 16, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F044A, {
    {     16,   16,    2, 24, 10,  0 }, {     16,   16,    3, 24, 10,  0 }, {     16,   16,    4, 24, 10,  0 }, {     16,   16,    5, 24, 10,  0 }, {     16,   16,    6, 24, 10,  0 },
    {     16,   16,    7, 24, 10,  0 }, {     16,   16,    8, 24, 10,  0 }, {     16,   16,    9, 24, 10,  0 }, {     16,   16,   10, 24, 10,  0 }, {     16,   16,   11, 24, 10,  0 },
    {     16,   16,   12, 24, 10,  0 }, {     16,   16,   13, 24, 10,  0 }, {     16,   16,   14, 24, 10,  0 }, {     16,   16,   15, 24, 10,  0 }, {     16,   16,   16, 24, 10,  0 },
    {     16,   16,   17, 24, 10,  0 }, {     16,   16,   18, 24, 10,  0 }, {     16,   16,   19, 24, 10,  0 }, {     16,   16,   20, 24, 10,  0 }, {     16,   16,   21, 24, 10,  0 },
    {     16,   16,   22, 24, 10,  0 }, {     16,   16,   23, 24, 10,  0 }, {     16,   16,   24, 24, 10,  0 }, {     16,   16,   25, 24, 10,  0 }, {     16,   16,   26, 24, 10,  0 },
    {     16,   16,   27, 24, 10,  0 }, {     16,   16,   28, 24, 10,  0 }, {     16,   16,   29, 24, 10,  0 }, {     16,   16,   30, 24, 10,  0 }, {     16,   16,   31, 24, 10,  0 },
    {     16,   16,   32, 24, 10,  0 }, {     16,   16,   33, 24, 10,  0 }, {     16,   16,   34, 24, 10,  0 }, {     16,   16,   35, 24, 10,  0 }, {     16,   16,   36, 24, 10,  0 },
    {     16,   16,   37, 24, 10,  0 }, {     16,   16,   38, 24, 10,  0 }, {     16,   16,   39, 24, 10,  0 }, {     16,   16,   40, 24, 10,  0 }, {     16,   16,   41, 24, 10,  0 },
    {     16,   16,   42, 24, 10,  0 }, {     16,   16,   43, 24, 10,  0 }, {     16,   16,   44, 24, 10,  0 }, {     16,   16,   45, 24, 10,  0 }, {     16,   16,   46, 24, 10,  0 },
    {     16,   16,   47, 24, 10,  0 }, {     16,   16,   48, 24, 10,  0 }, {     16,   16,   49, 24, 10,  0 }, {     16,   16,   50, 24, 10,  0 }, {     16,   16,   51, 24, 10,  0 },
    {     16,   16,   52, 24, 10,  0 }, {     16,   16,   53, 24, 10,  0 }, {     16,   16,   54, 24, 10,  0 }, {     16,   16,   55, 24, 10,  0 }, {     16,   16,   56, 24, 10,  0 },
    {     16,   16,   57, 24, 10,  0 }, {     16,   16,   58, 24, 10,  0 }, {     16,   16,   59, 24, 10,  0 }, {     16,   16,   60, 24, 10,  0 }, {     16,   16,   61, 24, 10,  0 },
    {     16,   16,   62, 24, 10,  0 }, {     16,   16,   63, 24, 10,  0 }, {     16,   16,   64, 24, 10,  0 }, {     16,   16,   65, 24, 10,  0 }, {     16,   16,   66, 24, 10,  0 },
    {     16,   16,   67, 24, 10,  0 }, {     16,   16,   68, 24, 10,  0 }, {     16,   16,   69, 24, 10,  0 }, {     16,   16,   70, 24, 10,  0 }, {     16,   16,   71, 24, 10,  0 },
    {     16,   16,   72, 24, 10,  0 }, {     16,   16,   73, 24, 10,  0 }, {     16,   16,   74, 24, 10,  0 }, {     16,   16,   75, 24, 10,  0 }, {     16,   16,   76, 24, 10,  0 },
    {     16,   16,   77, 24, 10,  0 }, {     16,   16,   78, 24, 10,  0 }, {     16,   16,   79, 24, 10,  0 }, {     16,   16,   80, 24, 10,  0 }, {     16,   16,   81, 24, 10,  0 },
    {     16,   16,   82, 24, 10,  0 }, {     16,   16,   83, 24, 10,  0 }, {     16,   16,   84, 24, 10,  0 }, {     16,   16,   85, 24, 10,  0 }, {     16,   16,   86, 24, 10,  0 },
    {     16,   16,   87, 24, 10,  0 }, {     16,   16,   88, 24, 10,  0 }, {     16,   16,   89, 24, 10,  0 }, {     16,   16,   90, 24, 10,  0 }, {     16,   16,   91, 24, 10,  0 },
    {     16,   16,   92, 24, 10,  0 }, {     16,   16,   93, 24, 10,  0 }, {     16,   16,   94, 24, 10,  0 }, {     16,   16,   95, 24, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F079A, {
    {     16,   16,    0,  0, 10,  0 }, {     16,   16,    1,  0, 10,  0 }, {     16,   16,    2,  0, 10,  0 }, {     16,   16,    3,  0, 10,  0 }, {     16,   16,    4,  0, 10,  0 },
    {     16,   16,    5,  0, 10,  0 }, {     16,   16,    6,  0, 10,  0 }, {     16,   16,    7,  0, 10,  0 }, {     16,   16,    8,  0, 10,  0 }, {     16,   16,    9,  0, 10,  0 },
    {     16,   16,   10,  0, 10,  0 }, {     16,   16,   11,  0, 10,  0 }, {     16,   16,   12,  0, 10,  0 }, {     16,   16,   13,  0, 10,  0 }, {     16,   16,   14,  0, 10,  0 },
    {     16,   16,   15,  0, 10,  0 }, {     16,   16,   16,  0, 10,  0 }, {     16,   16,   17,  0, 10,  0 }, {     16,   16,   18,  0, 10,  0 }, {     16,   16,   19,  0, 10,  0 },
    {     16,   16,   20,  0, 10,  0 }, {     16,   16,   21,  0, 10,  0 }, {     16,   16,   22,  0, 10,  0 }, {     16,   16,   23,  0, 10,  0 }, {     16,   16,   24,  0, 10,  0 },
    {     16,   16,   25,  0, 10,  0 }, {     16,   16,   26,  0, 10,  0 }, {     16,   16,   27,  0, 10,  0 }, {     16,   16,   28,  0, 10,  0 }, {     16,   16,   29,  0, 10,  0 },
    {     16,   16,   30,  0, 10,  0 }, {     16,   16,   31,  0, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F08BC, {
    {     16,   16,    0,  8, 10,  0 }, {     16,   16,    1,  8, 10,  0 }, {     16,   16,    2,  8, 10,  0 }, {     16,   16,    3,  8, 10,  0 }, {     16,   16,    4,  8, 10,  0 },
    {     16,   16,    5,  8, 10,  0 }, {     16,   16,    6,  8, 10,  0 }, {     16,   16,    7,  8, 10,  0 }, {     16,   16,    8,  8, 10,  0 }, {     16,   16,    9,  8, 10,  0 },
    {     16,   16,   10,  8, 10,  0 }, {     16,   16,   11,  8, 10,  0 }, {     16,   16,   12,  8, 10,  0 }, {     16,   16,   13,  8, 10,  0 }, {     16,   16,   14,  8, 10,  0 },
    {     16,   16,   15,  8, 10,  0 }, {     16,   16,   16,  8, 10,  0 }, {     16,   16,   17,  8, 10,  0 }, {     16,   16,   18,  8, 10,  0 }, {     16,   16,   19,  8, 10,  0 },
    {     16,   16,   20,  8, 10,  0 }, {     16,   16,   21,  8, 10,  0 }, {     16,   16,   22,  8, 10,  0 }, {     16,   16,   23,  8, 10,  0 }, {     16,   16,   24,  8, 10,  0 },
    {     16,   16,   25,  8, 10,  0 }, {     16,   16,   26,  8, 10,  0 }, {     16,   16,   27,  8, 10,  0 }, {     16,   16,   28,  8, 10,  0 }, {     16,   16,   29,  8, 10,  0 },
    {     16,   16,   30,  8, 10,  0 }, {     16,   16,   31,  8, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F09DE, {
    {     16,   16,    0, 16, 10,  0 }, {     16,   16,    1, 16, 10,  0 }, {     16,   16,    2, 16, 10,  0 }, {     16,   16,    3, 16, 10,  0 }, {     16,   16,    4, 16, 10,  0 },
    {     16,   16,    5, 16, 10,  0 }, {     16,   16,    6, 16, 10,  0 }, {     16,   16,    7, 16, 10,  0 }, {     16,   16,    8, 16, 10,  0 }, {     16,   16,    9, 16, 10,  0 },
    {     16,   16,   10, 16, 10,  0 }, {     16,   16,   11, 16, 10,  0 }, {     16,   16,   12, 16, 10,  0 }, {     16,   16,   13, 16, 10,  0 }, {     16,   16,   14, 16, 10,  0 },
    {     16,   16,   15, 16, 10,  0 }, {     16,   16,   16, 16, 10,  0 }, {     16,   16,   17, 16, 10,  0 }, {     16,   16,   18, 16, 10,  0 }, {     16,   16,   19, 16, 10,  0 },
    {     16,   16,   20, 16, 10,  0 }, {     16,   16,   21, 16, 10,  0 }, {     16,   16,   22, 16, 10,  0 }, {     16,   16,   23, 16, 10,  0 }, {     16,   16,   24, 16, 10,  0 },
    {     16,   16,   25, 16, 10,  0 }, {     16,   16,   26, 16, 10,  0 }, {     16,   16,   27, 16, 10,  0 }, {     16,   16,   28, 16, 10,  0 }, {     16,   16,   29, 16, 10,  0 },
    {     16,   16,   30, 16, 10,  0 }, {     16,   16,   31, 16, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F0B00, {
    {     16,   16,    0, 24, 10,  0 }, {     16,   16,    1, 24, 10,  0 }, {     16,   16,    2, 24, 10,  0 }, {     16,   16,    3, 24, 10,  0 }, {     16,   16,    4, 24, 10,  0 },
    {     16,   16,    5, 24, 10,  0 }, {     16,   16,    6, 24, 10,  0 }, {     16,   16,    7, 24, 10,  0 }, {     16,   16,    8, 24, 10,  0 }, {     16,   16,    9, 24, 10,  0 },
    {     16,   16,   10, 24, 10,  0 }, {     16,   16,   11, 24, 10,  0 }, {     16,   16,   12, 24, 10,  0 }, {     16,   16,   13, 24, 10,  0 }, {     16,   16,   14, 24, 10,  0 },
    {     16,   16,   15, 24, 10,  0 }, {     16,   16,   16, 24, 10,  0 }, {     16,   16,   17, 24, 10,  0 }, {     16,   16,   18, 24, 10,  0 }, {     16,   16,   19, 24, 10,  0 },
    {     16,   16,   20, 24, 10,  0 }, {     16,   16,   21, 24, 10,  0 }, {     16,   16,   22, 24, 10,  0 }, {     16,   16,   23, 24, 10,  0 }, {     16,   16,   24, 24, 10,  0 },
    {     16,   16,   25, 24, 10,  0 }, {     16,   16,   26, 24, 10,  0 }, {     16,   16,   27, 24, 10,  0 }, {     16,   16,   28, 24, 10,  0 }, {     16,   16,   29, 24, 10,  0 },
    {     16,   16,   30, 24, 10,  0 }, {     16,   16,   31, 24, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F8C82, {
    {     31,   16,    0,  0, 45,  2 }, {     30,   16,    0,  0, 45,  2 }, {     29,   16,    0,  0, 45,  2 }, {     28,   16,    0,  0, 45,  2 }, {     27,   16,    0, 31, 45,  2 },
    {     26,   16,    0, 31, 45,  2 }, {     25,   15,    0, 31, 45,  2 }, {     24,   15,    0, 31, 45,  2 }, {     23,   15,    1, 31, 45,  2 }, {     22,   15,    1, 31, 45,  2 },
    {     21,   15,    1, 31, 45,  2 }, {     20,   15,    1, 31, 45,  2 }, {     19,   14,    1, 31, 45,  2 }, {     18,   14,    1, 30, 45,  2 }, {     17,   14,    1, 30, 45,  2 },
    {     16,   13,    1, 30, 45,  2 }, {     15,   13,    2, 30, 45,  2 }, {     14,   13,    2, 30, 45,  2 }, {     13,   12,    2, 30, 45,  2 }, {     12,   12,    2, 30, 45,  2 },
    {     11,   11,    2, 30, 45,  2 }, {     10,   11,    2, 30, 45,  2 }, {      9,   10,    2, 30, 45,  2 }, {      8,   10,    2, 29, 45,  2 }, {      7,    9,    2, 29, 45,  2 },
    {      6,    9,    3, 29, 45,  2 }, {      5,    8,    3, 29, 45,  2 }, {      4,    7,    3, 29, 45,  2 }, {      3,    7,    3, 29, 45,  2 }, {      2,    6,    3, 29, 45,  2 },
    {      1,    5,    3, 29, 45,  2 }, {      0,    4,    3, 29, 45,  2 }, {     -1,    3,    3, 28, 45,  2 }, {     -3,    3,    4, 28, 45,  2 }, {     -4,    2,    4, 28, 45,  2 },
    {     -5,    1,    4, 28, 45,  2 }, {     -6,    0,    4, 28, 45,  2 }, {     -7,   -1,    4, 27, 45,  2 }, {     -7,   -2,    4, 27, 45,  2 }, {     -8,   -3,    4, 27, 45,  2 },
    {     -9,   -4,    4, 27, 45,  2 }, {     -9,   -5,    4, 27, 45,  2 }, {    -10,   -6,    5, 27, 45,  2 }, {    -10,   -7,    5, 27, 45,  2 }, {    -11,   -8,    5, 27, 45,  2 },
    {    -11,   -9,    5, 27, 45,  2 }, {    -12,  -10,    5, 26, 45,  2 }, {    -12,  -11,    5, 26, 45,  2 }, {    -13,  -12,    5, 26, 45,  2 }, {    -13,  -13,    5, 26, 45,  2 },
    {    -13,  -14,    6, 26, 45,  2 }, {    -14,  -15,    6, 26, 45,  2 }, {    -14,  -16,    6, 26, 45,  2 }, {    -14,  -17,    6, 26, 45,  2 }, {    -15,  -18,    6, 26, 45,  2 },
    {    -15,  -19,    6, 26, 45,  2 }, {    -15,  -20,    6, 25, 45,  2 }, {    -15,  -21,    6, 25, 45,  2 }, {    -15,  -22,    6, 25, 45,  2 }, {    -15,  -23,    7, 25, 45,  2 },
    {    -16,  -24,    7, 25, 45,  2 }, {    -16,  -25,    7, 25, 45,  2 }, {    -16,  -26,    7, 25, 45,  2 }, {    -16,  -27,    7, 25, 45,  2 }, {    -16,  -28,    7, 24, 45,  2 },
    {    -16,  -29,    7, 24, 45,  2 }, {    -16,  -30,    7, 24, 45,  2 }, {    -16,  -31,    8, 24, 45,  2 }, {    -16,  -33,    8, 24, 45,  2 }, {    -16,  -34,    8, 24, 45,  2 },
    {    -16,  -35,    8, 24, 45,  2 }, {    -16,  -36,    8, 24, 45,  2 }, {    -16,  -37,    8, 23, 45,  2 }, {    -16,  -38,    8, 23, 45,  2 }, {    -15,  -39,    8, 23, 45,  2 },
    {    -15,  -40,    8, 23, 45,  2 }, {    -15,  -41,    9, 23, 45,  2 }, {    -15,  -42,    9, 23, 45,  2 }, {    -15,  -43,    9, 23, 45,  2 }, {    -15,  -44,    9, 23, 45,  2 },
    {    -14,  -45,    9, 23, 45,  2 }, {    -14,  -46,    9, 22, 45,  2 }, {    -14,  -47,    9, 22, 45,  2 }, {    -13,  -48,    9, 22, 45,  2 }, {    -13,  -49,   10, 22, 45,  2 },
    {    -13,  -50,   10, 22, 45,  2 }, {    -12,  -51,   10, 22, 45,  2 }, {    -12,  -52,   10, 22, 45,  2 }, {    -11,  -53,   10, 22, 45,  2 }, {    -11,  -54,   10, 22, 45,  2 },
    {    -10,  -55,   10, 22, 45,  2 }, {    -10,  -56,   10, 21, 45,  2 }, {     -9,  -57,   10, 21, 45,  2 }, {     -9,  -58,   11, 21, 45,  2 }, {     -8,  -59,   11, 21, 45,  2 },
    {     -7,  -60,   11, 21, 45,  2 }, {     -7,  -61,   11, 21, 45,  2 }, {     -6,  -62,   11, 21, 45,  2 }, {     -5,  -63,   11, 21, 45,  2 }, {     -4,  -64,   11, 21, 45,  2 },
    {     -3,  -65,   11, 20, 45,  2 }, {     -3,  -67,   12, 20, 45,  2 }, {     -2,  -68,   12, 20, 45,  2 }, {     -1,  -69,   12, 20, 45,  2 }, {      0,  -70,   12, 20, 45,  2 },
    {      1,  -71,   12, 19, 45,  2 }, {      2,  -71,   12, 19, 45,  2 }, {      3,  -72,   12, 19, 45,  2 }, {      4,  -73,   12, 19, 45,  2 }, {      5,  -73,   13, 19, 45,  2 },
    {      6,  -74,   13, 19, 45,  2 }, {      7,  -74,   13, 19, 45,  2 }, {      8,  -75,   13, 19, 45,  2 }, {      9,  -75,   13, 19, 45,  2 }, {     10,  -76,   13, 18, 45,  2 },
    {     11,  -76,   13, 18, 45,  2 }, {     12,  -77,   13, 18, 45,  2 }, {     13,  -77,   13, 18, 45,  2 }, {     14,  -77,   14, 18, 45,  2 }, {     15,  -78,   14, 18, 45,  2 },
    {     16,  -78,   14, 18, 45,  2 }, {     17,  -78,   14, 18, 45,  2 }, {     18,  -79,   14, 18, 45,  2 }, {     19,  -79,   14, 18, 45,  2 }, {     20,  -79,   14, 17, 45,  2 },
    {     21,  -79,   14, 17, 45,  2 }, {     22,  -79,   15, 17, 45,  2 }, {     23,  -79,   15, 17, 45,  2 }, {     24,  -80,   15, 17, 45,  2 }, {     25,  -80,   15, 17, 45,  2 },
    {     26,  -80,   15, 17, 45,  2 }, {     27,  -80,   15, 17, 45,  2 }, {     28,  -80,   15, 16, 45,  2 }, {     29,  -80,   15, 16, 45,  2 }, {     30,  -80,   16, 16, 45,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F9143, {
    {     16,    0,    0,  8, 45,  2 }, {     16,    1,    0,  8, 45,  2 }, {     16,    2,    0,  8, 45,  2 }, {     16,    3,    0,  8, 45,  2 }, {     16,    4,    0,  8, 45,  2 },
    {     16,    5,    0,  7, 45,  2 }, {     16,    6,    0,  7, 45,  2 }, {     15,    7,    0,  7, 45,  2 }, {     15,    8,    0,  7, 45,  2 }, {     15,    9,    1,  7, 45,  2 },
    {     15,   10,    1,  7, 45,  2 }, {     15,   11,    1,  7, 45,  2 }, {     15,   12,    1,  7, 45,  2 }, {     14,   13,    1,  7, 45,  2 }, {     14,   14,    1,  6, 45,  2 },
    {     14,   15,    1,  6, 45,  2 }, {     13,   16,    1,  6, 45,  2 }, {     13,   17,    1,  6, 45,  2 }, {     13,   18,    2,  6, 45,  2 }, {     12,   19,    2,  6, 45,  2 },
    {     12,   20,    2,  6, 45,  2 }, {     11,   21,    2,  6, 45,  2 }, {     11,   22,    2,  6, 45,  2 }, {     10,   23,    2,  6, 45,  2 }, {     10,   24,    2,  5, 45,  2 },
    {      9,   25,    2,  5, 45,  2 }, {      9,   26,    3,  5, 45,  2 }, {      8,   27,    3,  5, 45,  2 }, {      7,   28,    3,  5, 45,  2 }, {      7,   29,    3,  5, 45,  2 },
    {      6,   30,    3,  5, 45,  2 }, {      5,   31,    3,  5, 45,  2 }, {      4,   32,    3,  5, 45,  2 }, {      3,   33,    3,  4, 45,  2 }, {      3,   35,    3,  4, 45,  2 },
    {      2,   36,    4,  4, 45,  2 }, {      1,   37,    4,  4, 45,  2 }, {      0,   38,    4,  4, 45,  2 }, {     -1,   39,    4,  3, 45,  2 }, {     -2,   39,    4,  3, 45,  2 },
    {     -3,   40,    4,  3, 45,  2 }, {     -4,   41,    4,  3, 45,  2 }, {     -5,   41,    4,  3, 45,  2 }, {     -6,   42,    4,  3, 45,  2 }, {     -7,   42,    5,  3, 45,  2 },
    {     -8,   43,    5,  3, 45,  2 }, {     -9,   43,    5,  3, 45,  2 }, {    -10,   44,    5,  2, 45,  2 }, {    -11,   44,    5,  2, 45,  2 }, {    -12,   45,    5,  2, 45,  2 },
    {    -13,   45,    5,  2, 45,  2 }, {    -14,   45,    5,  2, 45,  2 }, {    -15,   46,    6,  2, 45,  2 }, {    -16,   46,    6,  2, 45,  2 }, {    -17,   46,    6,  2, 45,  2 },
    {    -18,   47,    6,  2, 45,  2 }, {    -19,   47,    6,  2, 45,  2 }, {    -20,   47,    6,  1, 45,  2 }, {    -21,   47,    6,  1, 45,  2 }, {    -22,   47,    6,  1, 45,  2 },
    {    -23,   47,    6,  1, 45,  2 }, {    -24,   48,    7,  1, 45,  2 }, {    -25,   48,    7,  1, 45,  2 }, {    -26,   48,    7,  1, 45,  2 }, {    -27,   48,    7,  1, 45,  2 },
    {    -28,   48,    7,  0, 45,  2 }, {    -29,   48,    7,  0, 45,  2 }, {    -30,   48,    7,  0, 45,  2 }, {    -31,   48,    7,  0, 45,  2 }, {    -33,   48,    8,  0, 45,  2 },
    {    -34,   48,    8,  0, 45,  2 }, {    -35,   48,    8,  0, 45,  2 }, {    -36,   48,    8,  0, 45,  2 }, {    -37,   48,    8, 31, 45,  2 }, {    -38,   48,    8, 31, 45,  2 },
    {    -39,   47,    8, 31, 45,  2 }, {    -40,   47,    8, 31, 45,  2 }, {    -41,   47,    9, 31, 45,  2 }, {    -42,   47,    9, 31, 45,  2 }, {    -43,   47,    9, 31, 45,  2 },
    {    -44,   47,    9, 31, 45,  2 }, {    -45,   46,    9, 31, 45,  2 }, {    -46,   46,    9, 30, 45,  2 }, {    -47,   46,    9, 30, 45,  2 }, {    -48,   45,    9, 30, 45,  2 },
    {    -49,   45,   10, 30, 45,  2 }, {    -50,   45,   10, 30, 45,  2 }, {    -51,   44,   10, 30, 45,  2 }, {    -52,   44,   10, 30, 45,  2 }, {    -53,   43,   10, 30, 45,  2 },
    {    -54,   43,   10, 30, 45,  2 }, {    -55,   42,   10, 30, 45,  2 }, {    -56,   42,   10, 29, 45,  2 }, {    -57,   41,   10, 29, 45,  2 }, {    -58,   41,   11, 29, 45,  2 },
    {    -59,   40,   11, 29, 45,  2 }, {    -60,   39,   11, 29, 45,  2 }, {    -61,   39,   11, 29, 45,  2 }, {    -62,   38,   11, 29, 45,  2 }, {    -63,   37,   11, 29, 45,  2 },
    {    -64,   36,   11, 29, 45,  2 }, {    -65,   35,   11, 28, 45,  2 }, {    -67,   35,   12, 28, 45,  2 }, {    -68,   34,   12, 28, 45,  2 }, {    -69,   33,   12, 28, 45,  2 },
    {    -70,   32,   12, 28, 45,  2 }, {    -71,   31,   12, 27, 45,  2 }, {    -71,   30,   12, 27, 45,  2 }, {    -72,   29,   12, 27, 45,  2 }, {    -73,   28,   12, 27, 45,  2 },
    {    -73,   27,   12, 27, 45,  2 }, {    -74,   26,   13, 27, 45,  2 }, {    -74,   25,   13, 27, 45,  2 }, {    -75,   24,   13, 27, 45,  2 }, {    -75,   23,   13, 27, 45,  2 },
    {    -76,   22,   13, 26, 45,  2 }, {    -76,   21,   13, 26, 45,  2 }, {    -77,   20,   13, 26, 45,  2 }, {    -77,   19,   13, 26, 45,  2 }, {    -77,   18,   14, 26, 45,  2 },
    {    -78,   17,   14, 26, 45,  2 }, {    -78,   16,   14, 26, 45,  2 }, {    -78,   15,   14, 26, 45,  2 }, {    -79,   14,   14, 26, 45,  2 }, {    -79,   13,   14, 26, 45,  2 },
    {    -79,   12,   14, 25, 45,  2 }, {    -79,   11,   14, 25, 45,  2 }, {    -79,   10,   14, 25, 45,  2 }, {    -79,    9,   15, 25, 45,  2 }, {    -80,    8,   15, 25, 45,  2 },
    {    -80,    7,   15, 25, 45,  2 }, {    -80,    6,   15, 25, 45,  2 }, {    -80,    5,   15, 25, 45,  2 }, {    -80,    4,   15, 24, 45,  2 }, {    -80,    3,   15, 24, 45,  2 },
    {    -80,    2,   15, 24, 45,  2 }, {    -80,    1,   16, 24, 45,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F9616, {
    {      0,   16,    0, 16, 45,  2 }, {      1,   16,    0, 16, 45,  2 }, {      2,   16,    0, 16, 45,  2 }, {      3,   16,    0, 16, 45,  2 }, {      4,   16,    0, 16, 45,  2 },
    {      5,   16,    0, 15, 45,  2 }, {      6,   16,    0, 15, 45,  2 }, {      7,   17,    0, 15, 45,  2 }, {      8,   17,    0, 15, 45,  2 }, {      9,   17,    1, 15, 45,  2 },
    {     10,   17,    1, 15, 45,  2 }, {     11,   17,    1, 15, 45,  2 }, {     12,   17,    1, 15, 45,  2 }, {     13,   18,    1, 15, 45,  2 }, {     14,   18,    1, 14, 45,  2 },
    {     15,   18,    1, 14, 45,  2 }, {     16,   19,    1, 14, 45,  2 }, {     17,   19,    2, 14, 45,  2 }, {     18,   19,    2, 14, 45,  2 }, {     19,   20,    2, 14, 45,  2 },
    {     20,   20,    2, 14, 45,  2 }, {     21,   21,    2, 14, 45,  2 }, {     22,   21,    2, 14, 45,  2 }, {     23,   22,    2, 14, 45,  2 }, {     24,   22,    2, 13, 45,  2 },
    {     25,   23,    2, 13, 45,  2 }, {     26,   23,    3, 13, 45,  2 }, {     27,   24,    3, 13, 45,  2 }, {     28,   25,    3, 13, 45,  2 }, {     29,   25,    3, 13, 45,  2 },
    {     30,   26,    3, 13, 45,  2 }, {     31,   27,    3, 13, 45,  2 }, {     32,   28,    3, 13, 45,  2 }, {     33,   29,    3, 12, 45,  2 }, {     35,   29,    4, 12, 45,  2 },
    {     36,   30,    4, 12, 45,  2 }, {     37,   31,    4, 12, 45,  2 }, {     38,   32,    4, 12, 45,  2 }, {     39,   33,    4, 11, 45,  2 }, {     39,   34,    4, 11, 45,  2 },
    {     40,   35,    4, 11, 45,  2 }, {     41,   36,    4, 11, 45,  2 }, {     41,   37,    4, 11, 45,  2 }, {     42,   38,    5, 11, 45,  2 }, {     42,   39,    5, 11, 45,  2 },
    {     43,   40,    5, 11, 45,  2 }, {     43,   41,    5, 11, 45,  2 }, {     44,   42,    5, 10, 45,  2 }, {     44,   43,    5, 10, 45,  2 }, {     45,   44,    5, 10, 45,  2 },
    {     45,   45,    5, 10, 45,  2 }, {     45,   46,    6, 10, 45,  2 }, {     46,   47,    6, 10, 45,  2 }, {     46,   48,    6, 10, 45,  2 }, {     46,   49,    6, 10, 45,  2 },
    {     47,   50,    6, 10, 45,  2 }, {     47,   51,    6, 10, 45,  2 }, {     47,   52,    6,  9, 45,  2 }, {     47,   53,    6,  9, 45,  2 }, {     47,   54,    6,  9, 45,  2 },
    {     47,   55,    7,  9, 45,  2 }, {     48,   56,    7,  9, 45,  2 }, {     48,   57,    7,  9, 45,  2 }, {     48,   58,    7,  9, 45,  2 }, {     48,   59,    7,  9, 45,  2 },
    {     48,   60,    7,  8, 45,  2 }, {     48,   61,    7,  8, 45,  2 }, {     48,   62,    7,  8, 45,  2 }, {     48,   64,    8,  8, 45,  2 }, {     48,   65,    8,  8, 45,  2 },
    {     48,   66,    8,  8, 45,  2 }, {     48,   67,    8,  8, 45,  2 }, {     48,   68,    8,  8, 45,  2 }, {     48,   69,    8,  7, 45,  2 }, {     48,   70,    8,  7, 45,  2 },
    {     47,   71,    8,  7, 45,  2 }, {     47,   72,    8,  7, 45,  2 }, {     47,   73,    9,  7, 45,  2 }, {     47,   74,    9,  7, 45,  2 }, {     47,   75,    9,  7, 45,  2 },
    {     47,   76,    9,  7, 45,  2 }, {     46,   77,    9,  7, 45,  2 }, {     46,   78,    9,  6, 45,  2 }, {     46,   79,    9,  6, 45,  2 }, {     45,   80,    9,  6, 45,  2 },
    {     45,   81,    9,  6, 45,  2 }, {     45,   82,   10,  6, 45,  2 }, {     44,   83,   10,  6, 45,  2 }, {     44,   84,   10,  6, 45,  2 }, {     43,   85,   10,  6, 45,  2 },
    {     43,   86,   10,  6, 45,  2 }, {     42,   87,   10,  6, 45,  2 }, {     42,   88,   10,  5, 45,  2 }, {     41,   89,   10,  5, 45,  2 }, {     41,   90,   11,  5, 45,  2 },
    {     40,   91,   11,  5, 45,  2 }, {     39,   92,   11,  5, 45,  2 }, {     39,   93,   11,  5, 45,  2 }, {     38,   94,   11,  5, 45,  2 }, {     37,   95,   11,  5, 45,  2 },
    {     36,   96,   11,  5, 45,  2 }, {     35,   97,   11,  4, 45,  2 }, {     35,   99,   11,  4, 45,  2 }, {     34,  100,   12,  4, 45,  2 }, {     33,  101,   12,  4, 45,  2 },
    {     32,  102,   12,  4, 45,  2 }, {     31,  103,   12,  3, 45,  2 }, {     30,  103,   12,  3, 45,  2 }, {     29,  104,   12,  3, 45,  2 }, {     28,  105,   12,  3, 45,  2 },
    {     27,  105,   12,  3, 45,  2 }, {     26,  106,   12,  3, 45,  2 }, {     25,  106,   13,  3, 45,  2 }, {     24,  107,   13,  3, 45,  2 }, {     23,  107,   13,  3, 45,  2 },
    {     22,  108,   13,  2, 45,  2 }, {     21,  108,   13,  2, 45,  2 }, {     20,  109,   13,  2, 45,  2 }, {     19,  109,   13,  2, 45,  2 }, {     18,  109,   13,  2, 45,  2 },
    {     17,  110,   14,  2, 45,  2 }, {     16,  110,   14,  2, 45,  2 }, {     15,  110,   14,  2, 45,  2 }, {     14,  111,   14,  2, 45,  2 }, {     13,  111,   14,  2, 45,  2 },
    {     12,  111,   14,  1, 45,  2 }, {     11,  111,   14,  1, 45,  2 }, {     10,  111,   14,  1, 45,  2 }, {      9,  111,   14,  1, 45,  2 }, {      8,  112,   15,  1, 45,  2 },
    {      7,  112,   15,  1, 45,  2 }, {      6,  112,   15,  1, 45,  2 }, {      5,  112,   15,  1, 45,  2 }, {      4,  112,   15,  0, 45,  2 }, {      3,  112,   15,  0, 45,  2 },
    {      2,  112,   15,  0, 45,  2 }, {      1,  112,   15,  0, 45,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F9AE9, {
    {     16,   31,    0, 24, 45,  2 }, {     16,   30,    0, 24, 45,  2 }, {     16,   29,    0, 24, 45,  2 }, {     16,   28,    0, 24, 45,  2 }, {     16,   27,    0, 23, 45,  2 },
    {     16,   26,    0, 23, 45,  2 }, {     17,   25,    0, 23, 45,  2 }, {     17,   24,    0, 23, 45,  2 }, {     17,   23,    1, 23, 45,  2 }, {     17,   22,    1, 23, 45,  2 },
    {     17,   21,    1, 23, 45,  2 }, {     17,   20,    1, 23, 45,  2 }, {     18,   19,    1, 23, 45,  2 }, {     18,   18,    1, 22, 45,  2 }, {     18,   17,    1, 22, 45,  2 },
    {     19,   16,    1, 22, 45,  2 }, {     19,   15,    2, 22, 45,  2 }, {     19,   14,    2, 22, 45,  2 }, {     20,   13,    2, 22, 45,  2 }, {     20,   12,    2, 22, 45,  2 },
    {     21,   11,    2, 22, 45,  2 }, {     21,   10,    2, 22, 45,  2 }, {     22,    9,    2, 22, 45,  2 }, {     22,    8,    2, 21, 45,  2 }, {     23,    7,    2, 21, 45,  2 },
    {     23,    6,    3, 21, 45,  2 }, {     24,    5,    3, 21, 45,  2 }, {     25,    4,    3, 21, 45,  2 }, {     25,    3,    3, 21, 45,  2 }, {     26,    2,    3, 21, 45,  2 },
    {     27,    1,    3, 21, 45,  2 }, {     28,    0,    3, 21, 45,  2 }, {     29,   -1,    3, 20, 45,  2 }, {     29,   -3,    4, 20, 45,  2 }, {     30,   -4,    4, 20, 45,  2 },
    {     31,   -5,    4, 20, 45,  2 }, {     32,   -6,    4, 20, 45,  2 }, {     33,   -7,    4, 19, 45,  2 }, {     34,   -7,    4, 19, 45,  2 }, {     35,   -8,    4, 19, 45,  2 },
    {     36,   -9,    4, 19, 45,  2 }, {     37,   -9,    5, 19, 45,  2 }, {     38,  -10,    5, 19, 45,  2 }, {     39,  -10,    5, 19, 45,  2 }, {     40,  -11,    5, 19, 45,  2 },
    {     41,  -11,    5, 19, 45,  2 }, {     42,  -12,    5, 18, 45,  2 }, {     43,  -12,    5, 18, 45,  2 }, {     44,  -13,    5, 18, 45,  2 }, {     45,  -13,    5, 18, 45,  2 },
    {     46,  -13,    6, 18, 45,  2 }, {     47,  -14,    6, 18, 45,  2 }, {     48,  -14,    6, 18, 45,  2 }, {     49,  -14,    6, 18, 45,  2 }, {     50,  -15,    6, 18, 45,  2 },
    {     51,  -15,    6, 18, 45,  2 }, {     52,  -15,    6, 17, 45,  2 }, {     53,  -15,    6, 17, 45,  2 }, {     54,  -15,    7, 17, 45,  2 }, {     55,  -15,    7, 17, 45,  2 },
    {     56,  -16,    7, 17, 45,  2 }, {     57,  -16,    7, 17, 45,  2 }, {     58,  -16,    7, 17, 45,  2 }, {     59,  -16,    7, 17, 45,  2 }, {     60,  -16,    7, 16, 45,  2 },
    {     61,  -16,    7, 16, 45,  2 }, {     62,  -16,    8, 16, 45,  2 }, {     64,  -16,    8, 16, 45,  2 }, {     65,  -16,    8, 16, 45,  2 }, {     66,  -16,    8, 16, 45,  2 },
    {     67,  -16,    8, 16, 45,  2 }, {     68,  -16,    8, 16, 45,  2 }, {     69,  -16,    8, 15, 45,  2 }, {     70,  -16,    8, 15, 45,  2 }, {     71,  -15,    8, 15, 45,  2 },
    {     72,  -15,    8, 15, 45,  2 }, {     73,  -15,    9, 15, 45,  2 }, {     74,  -15,    9, 15, 45,  2 }, {     75,  -15,    9, 15, 45,  2 }, {     76,  -15,    9, 15, 45,  2 },
    {     77,  -14,    9, 15, 45,  2 }, {     78,  -14,    9, 14, 45,  2 }, {     79,  -14,    9, 14, 45,  2 }, {     80,  -13,    9, 14, 45,  2 }, {     81,  -13,   10, 14, 45,  2 },
    {     82,  -13,   10, 14, 45,  2 }, {     83,  -12,   10, 14, 45,  2 }, {     84,  -12,   10, 14, 45,  2 }, {     85,  -11,   10, 14, 45,  2 }, {     86,  -11,   10, 14, 45,  2 },
    {     87,  -10,   10, 14, 45,  2 }, {     88,  -10,   10, 13, 45,  2 }, {     89,   -9,   10, 13, 45,  2 }, {     90,   -9,   11, 13, 45,  2 }, {     91,   -8,   11, 13, 45,  2 },
    {     92,   -7,   11, 13, 45,  2 }, {     93,   -7,   11, 13, 45,  2 }, {     94,   -6,   11, 13, 45,  2 }, {     95,   -5,   11, 13, 45,  2 }, {     96,   -4,   11, 13, 45,  2 },
    {     97,   -3,   11, 12, 45,  2 }, {     99,   -3,   12, 12, 45,  2 }, {    100,   -2,   12, 12, 45,  2 }, {    101,   -1,   12, 12, 45,  2 }, {    102,    0,   12, 12, 45,  2 },
    {    103,    1,   12, 11, 45,  2 }, {    103,    2,   12, 11, 45,  2 }, {    104,    3,   12, 11, 45,  2 }, {    105,    4,   12, 11, 45,  2 }, {    105,    5,   12, 11, 45,  2 },
    {    106,    6,   13, 11, 45,  2 }, {    106,    7,   13, 11, 45,  2 }, {    107,    8,   13, 11, 45,  2 }, {    107,    9,   13, 11, 45,  2 }, {    108,   10,   13, 10, 45,  2 },
    {    108,   11,   13, 10, 45,  2 }, {    109,   12,   13, 10, 45,  2 }, {    109,   13,   13, 10, 45,  2 }, {    109,   14,   14, 10, 45,  2 }, {    110,   15,   14, 10, 45,  2 },
    {    110,   16,   14, 10, 45,  2 }, {    110,   17,   14, 10, 45,  2 }, {    111,   18,   14, 10, 45,  2 }, {    111,   19,   14, 10, 45,  2 }, {    111,   20,   14,  9, 45,  2 },
    {    111,   21,   14,  9, 45,  2 }, {    111,   22,   14,  9, 45,  2 }, {    111,   23,   15,  9, 45,  2 }, {    112,   24,   15,  9, 45,  2 }, {    112,   25,   15,  9, 45,  2 },
    {    112,   26,   15,  9, 45,  2 }, {    112,   27,   15,  9, 45,  2 }, {    112,   28,   15,  8, 45,  2 }, {    112,   29,   15,  8, 45,  2 }, {    112,   30,   15,  8, 45,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F9FAA, {
    {     31,   16,    0,  0, 45,  4 }, {     30,   16,    0,  0, 45,  4 }, {     29,   16,    0,  0, 45,  4 }, {     28,   16,    0,  0, 45,  4 }, {     27,   16,    0,  1, 45,  4 },
    {     26,   16,    0,  1, 45,  4 }, {     25,   17,    0,  1, 45,  4 }, {     24,   17,    0,  1, 45,  4 }, {     23,   17,    1,  1, 45,  4 }, {     22,   17,    1,  1, 45,  4 },
    {     21,   17,    1,  1, 45,  4 }, {     20,   17,    1,  1, 45,  4 }, {     19,   18,    1,  1, 45,  4 }, {     18,   18,    1,  2, 45,  4 }, {     17,   18,    1,  2, 45,  4 },
    {     16,   19,    1,  2, 45,  4 }, {     15,   19,    2,  2, 45,  4 }, {     14,   19,    2,  2, 45,  4 }, {     13,   20,    2,  2, 45,  4 }, {     12,   20,    2,  2, 45,  4 },
    {     11,   21,    2,  2, 45,  4 }, {     10,   21,    2,  2, 45,  4 }, {      9,   22,    2,  2, 45,  4 }, {      8,   22,    2,  3, 45,  4 }, {      7,   23,    2,  3, 45,  4 },
    {      6,   23,    3,  3, 45,  4 }, {      5,   24,    3,  3, 45,  4 }, {      4,   25,    3,  3, 45,  4 }, {      3,   25,    3,  3, 45,  4 }, {      2,   26,    3,  3, 45,  4 },
    {      1,   27,    3,  3, 45,  4 }, {      0,   28,    3,  3, 45,  4 }, {     -1,   29,    3,  4, 45,  4 }, {     -3,   29,    4,  4, 45,  4 }, {     -4,   30,    4,  4, 45,  4 },
    {     -5,   31,    4,  4, 45,  4 }, {     -6,   32,    4,  4, 45,  4 }, {     -7,   33,    4,  5, 45,  4 }, {     -7,   34,    4,  5, 45,  4 }, {     -8,   35,    4,  5, 45,  4 },
    {     -9,   36,    4,  5, 45,  4 }, {     -9,   37,    5,  5, 45,  4 }, {    -10,   38,    5,  5, 45,  4 }, {    -10,   39,    5,  5, 45,  4 }, {    -11,   40,    5,  5, 45,  4 },
    {    -11,   41,    5,  5, 45,  4 }, {    -12,   42,    5,  6, 45,  4 }, {    -12,   43,    5,  6, 45,  4 }, {    -13,   44,    5,  6, 45,  4 }, {    -13,   45,    5,  6, 45,  4 },
    {    -13,   46,    6,  6, 45,  4 }, {    -14,   47,    6,  6, 45,  4 }, {    -14,   48,    6,  6, 45,  4 }, {    -14,   49,    6,  6, 45,  4 }, {    -15,   50,    6,  6, 45,  4 },
    {    -15,   51,    6,  6, 45,  4 }, {    -15,   52,    6,  7, 45,  4 }, {    -15,   53,    6,  7, 45,  4 }, {    -15,   54,    7,  7, 45,  4 }, {    -15,   55,    7,  7, 45,  4 },
    {    -16,   56,    7,  7, 45,  4 }, {    -16,   57,    7,  7, 45,  4 }, {    -16,   58,    7,  7, 45,  4 }, {    -16,   59,    7,  7, 45,  4 }, {    -16,   60,    7,  8, 45,  4 },
    {    -16,   61,    7,  8, 45,  4 }, {    -16,   62,    8,  8, 45,  4 }, {    -16,   64,    8,  8, 45,  4 }, {    -16,   65,    8,  8, 45,  4 }, {    -16,   66,    8,  8, 45,  4 },
    {    -16,   67,    8,  8, 45,  4 }, {    -16,   68,    8,  8, 45,  4 }, {    -16,   69,    8,  9, 45,  4 }, {    -16,   70,    8,  9, 45,  4 }, {    -15,   71,    8,  9, 45,  4 },
    {    -15,   72,    8,  9, 45,  4 }, {    -15,   73,    9,  9, 45,  4 }, {    -15,   74,    9,  9, 45,  4 }, {    -15,   75,    9,  9, 45,  4 }, {    -15,   76,    9,  9, 45,  4 },
    {    -14,   77,    9,  9, 45,  4 }, {    -14,   78,    9, 10, 45,  4 }, {    -14,   79,    9, 10, 45,  4 }, {    -13,   80,    9, 10, 45,  4 }, {    -13,   81,   10, 10, 45,  4 },
    {    -13,   82,   10, 10, 45,  4 }, {    -12,   83,   10, 10, 45,  4 }, {    -12,   84,   10, 10, 45,  4 }, {    -11,   85,   10, 10, 45,  4 }, {    -11,   86,   10, 10, 45,  4 },
    {    -10,   87,   10, 10, 45,  4 }, {    -10,   88,   10, 11, 45,  4 }, {     -9,   89,   10, 11, 45,  4 }, {     -9,   90,   11, 11, 45,  4 }, {     -8,   91,   11, 11, 45,  4 },
    {     -7,   92,   11, 11, 45,  4 }, {     -7,   93,   11, 11, 45,  4 }, {     -6,   94,   11, 11, 45,  4 }, {     -5,   95,   11, 11, 45,  4 }, {     -4,   96,   11, 11, 45,  4 },
    {     -3,   97,   11, 12, 45,  4 }, {     -3,   99,   12, 12, 45,  4 }, {     -2,  100,   12, 12, 45,  4 }, {     -1,  101,   12, 12, 45,  4 }, {      0,  102,   12, 12, 45,  4 },
    {      1,  103,   12, 13, 45,  4 }, {      2,  103,   12, 13, 45,  4 }, {      3,  104,   12, 13, 45,  4 }, {      4,  105,   12, 13, 45,  4 }, {      5,  105,   12, 13, 45,  4 },
    {      6,  106,   13, 13, 45,  4 }, {      7,  106,   13, 13, 45,  4 }, {      8,  107,   13, 13, 45,  4 }, {      9,  107,   13, 13, 45,  4 }, {     10,  108,   13, 14, 45,  4 },
    {     11,  108,   13, 14, 45,  4 }, {     12,  109,   13, 14, 45,  4 }, {     13,  109,   13, 14, 45,  4 }, {     14,  109,   14, 14, 45,  4 }, {     15,  110,   14, 14, 45,  4 },
    {     16,  110,   14, 14, 45,  4 }, {     17,  110,   14, 14, 45,  4 }, {     18,  111,   14, 14, 45,  4 }, {     19,  111,   14, 14, 45,  4 }, {     20,  111,   14, 15, 45,  4 },
    {     21,  111,   14, 15, 45,  4 }, {     22,  111,   14, 15, 45,  4 }, {     23,  111,   15, 15, 45,  4 }, {     24,  112,   15, 15, 45,  4 }, {     25,  112,   15, 15, 45,  4 },
    {     26,  112,   15, 15, 45,  4 }, {     27,  112,   15, 15, 45,  4 }, {     28,  112,   15, 16, 45,  4 }, {     29,  112,   15, 16, 45,  4 }, {     30,  112,   15, 16, 45,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FA46B, {
    {     16,    0,    0,  8, 45,  4 }, {     16,    1,    0,  8, 45,  4 }, {     16,    2,    0,  8, 45,  4 }, {     16,    3,    0,  8, 45,  4 }, {     16,    4,    0,  8, 45,  4 },
    {     16,    5,    0,  9, 45,  4 }, {     16,    6,    0,  9, 45,  4 }, {     17,    7,    0,  9, 45,  4 }, {     17,    8,    0,  9, 45,  4 }, {     17,    9,    1,  9, 45,  4 },
    {     17,   10,    1,  9, 45,  4 }, {     17,   11,    1,  9, 45,  4 }, {     17,   12,    1,  9, 45,  4 }, {     18,   13,    1,  9, 45,  4 }, {     18,   14,    1, 10, 45,  4 },
    {     18,   15,    1, 10, 45,  4 }, {     19,   16,    1, 10, 45,  4 }, {     19,   17,    2, 10, 45,  4 }, {     19,   18,    2, 10, 45,  4 }, {     20,   19,    2, 10, 45,  4 },
    {     20,   20,    2, 10, 45,  4 }, {     21,   21,    2, 10, 45,  4 }, {     21,   22,    2, 10, 45,  4 }, {     22,   23,    2, 10, 45,  4 }, {     22,   24,    2, 11, 45,  4 },
    {     23,   25,    2, 11, 45,  4 }, {     23,   26,    3, 11, 45,  4 }, {     24,   27,    3, 11, 45,  4 }, {     25,   28,    3, 11, 45,  4 }, {     25,   29,    3, 11, 45,  4 },
    {     26,   30,    3, 11, 45,  4 }, {     27,   31,    3, 11, 45,  4 }, {     28,   32,    3, 11, 45,  4 }, {     29,   33,    3, 12, 45,  4 }, {     29,   35,    4, 12, 45,  4 },
    {     30,   36,    4, 12, 45,  4 }, {     31,   37,    4, 12, 45,  4 }, {     32,   38,    4, 12, 45,  4 }, {     33,   39,    4, 13, 45,  4 }, {     34,   39,    4, 13, 45,  4 },
    {     35,   40,    4, 13, 45,  4 }, {     36,   41,    4, 13, 45,  4 }, {     37,   41,    4, 13, 45,  4 }, {     38,   42,    5, 13, 45,  4 }, {     39,   42,    5, 13, 45,  4 },
    {     40,   43,    5, 13, 45,  4 }, {     41,   43,    5, 13, 45,  4 }, {     42,   44,    5, 14, 45,  4 }, {     43,   44,    5, 14, 45,  4 }, {     44,   45,    5, 14, 45,  4 },
    {     45,   45,    5, 14, 45,  4 }, {     46,   45,    6, 14, 45,  4 }, {     47,   46,    6, 14, 45,  4 }, {     48,   46,    6, 14, 45,  4 }, {     49,   46,    6, 14, 45,  4 },
    {     50,   47,    6, 14, 45,  4 }, {     51,   47,    6, 14, 45,  4 }, {     52,   47,    6, 15, 45,  4 }, {     53,   47,    6, 15, 45,  4 }, {     54,   47,    6, 15, 45,  4 },
    {     55,   47,    7, 15, 45,  4 }, {     56,   48,    7, 15, 45,  4 }, {     57,   48,    7, 15, 45,  4 }, {     58,   48,    7, 15, 45,  4 }, {     59,   48,    7, 15, 45,  4 },
    {     60,   48,    7, 16, 45,  4 }, {     61,   48,    7, 16, 45,  4 }, {     62,   48,    7, 16, 45,  4 }, {     64,   48,    8, 16, 45,  4 }, {     65,   48,    8, 16, 45,  4 },
    {     66,   48,    8, 16, 45,  4 }, {     67,   48,    8, 16, 45,  4 }, {     68,   48,    8, 16, 45,  4 }, {     69,   48,    8, 17, 45,  4 }, {     70,   48,    8, 17, 45,  4 },
    {     71,   47,    8, 17, 45,  4 }, {     72,   47,    8, 17, 45,  4 }, {     73,   47,    9, 17, 45,  4 }, {     74,   47,    9, 17, 45,  4 }, {     75,   47,    9, 17, 45,  4 },
    {     76,   47,    9, 17, 45,  4 }, {     77,   46,    9, 17, 45,  4 }, {     78,   46,    9, 18, 45,  4 }, {     79,   46,    9, 18, 45,  4 }, {     80,   45,    9, 18, 45,  4 },
    {     81,   45,    9, 18, 45,  4 }, {     82,   45,   10, 18, 45,  4 }, {     83,   44,   10, 18, 45,  4 }, {     84,   44,   10, 18, 45,  4 }, {     85,   43,   10, 18, 45,  4 },
    {     86,   43,   10, 18, 45,  4 }, {     87,   42,   10, 18, 45,  4 }, {     88,   42,   10, 19, 45,  4 }, {     89,   41,   10, 19, 45,  4 }, {     90,   41,   11, 19, 45,  4 },
    {     91,   40,   11, 19, 45,  4 }, {     92,   39,   11, 19, 45,  4 }, {     93,   39,   11, 19, 45,  4 }, {     94,   38,   11, 19, 45,  4 }, {     95,   37,   11, 19, 45,  4 },
    {     96,   36,   11, 19, 45,  4 }, {     97,   35,   11, 20, 45,  4 }, {     99,   35,   11, 20, 45,  4 }, {    100,   34,   12, 20, 45,  4 }, {    101,   33,   12, 20, 45,  4 },
    {    102,   32,   12, 20, 45,  4 }, {    103,   31,   12, 21, 45,  4 }, {    103,   30,   12, 21, 45,  4 }, {    104,   29,   12, 21, 45,  4 }, {    105,   28,   12, 21, 45,  4 },
    {    105,   27,   12, 21, 45,  4 }, {    106,   26,   12, 21, 45,  4 }, {    106,   25,   13, 21, 45,  4 }, {    107,   24,   13, 21, 45,  4 }, {    107,   23,   13, 21, 45,  4 },
    {    108,   22,   13, 22, 45,  4 }, {    108,   21,   13, 22, 45,  4 }, {    109,   20,   13, 22, 45,  4 }, {    109,   19,   13, 22, 45,  4 }, {    109,   18,   13, 22, 45,  4 },
    {    110,   17,   14, 22, 45,  4 }, {    110,   16,   14, 22, 45,  4 }, {    110,   15,   14, 22, 45,  4 }, {    111,   14,   14, 22, 45,  4 }, {    111,   13,   14, 22, 45,  4 },
    {    111,   12,   14, 23, 45,  4 }, {    111,   11,   14, 23, 45,  4 }, {    111,   10,   14, 23, 45,  4 }, {    111,    9,   14, 23, 45,  4 }, {    112,    8,   15, 23, 45,  4 },
    {    112,    7,   15, 23, 45,  4 }, {    112,    6,   15, 23, 45,  4 }, {    112,    5,   15, 23, 45,  4 }, {    112,    4,   15, 24, 45,  4 }, {    112,    3,   15, 24, 45,  4 },
    {    112,    2,   15, 24, 45,  4 }, {    112,    1,   15, 24, 45,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FA93E, {
    {      0,   16,    0, 16, 45,  4 }, {      1,   16,    0, 16, 45,  4 }, {      2,   16,    0, 16, 45,  4 }, {      3,   16,    0, 16, 45,  4 }, {      4,   16,    0, 16, 45,  4 },
    {      5,   16,    0, 17, 45,  4 }, {      6,   16,    0, 17, 45,  4 }, {      7,   15,    0, 17, 45,  4 }, {      8,   15,    0, 17, 45,  4 }, {      9,   15,    1, 17, 45,  4 },
    {     10,   15,    1, 17, 45,  4 }, {     11,   15,    1, 17, 45,  4 }, {     12,   15,    1, 17, 45,  4 }, {     13,   14,    1, 17, 45,  4 }, {     14,   14,    1, 18, 45,  4 },
    {     15,   14,    1, 18, 45,  4 }, {     16,   13,    1, 18, 45,  4 }, {     17,   13,    1, 18, 45,  4 }, {     18,   13,    2, 18, 45,  4 }, {     19,   12,    2, 18, 45,  4 },
    {     20,   12,    2, 18, 45,  4 }, {     21,   11,    2, 18, 45,  4 }, {     22,   11,    2, 18, 45,  4 }, {     23,   10,    2, 18, 45,  4 }, {     24,   10,    2, 19, 45,  4 },
    {     25,    9,    2, 19, 45,  4 }, {     26,    9,    3, 19, 45,  4 }, {     27,    8,    3, 19, 45,  4 }, {     28,    7,    3, 19, 45,  4 }, {     29,    7,    3, 19, 45,  4 },
    {     30,    6,    3, 19, 45,  4 }, {     31,    5,    3, 19, 45,  4 }, {     32,    4,    3, 19, 45,  4 }, {     33,    3,    3, 20, 45,  4 }, {     35,    3,    3, 20, 45,  4 },
    {     36,    2,    4, 20, 45,  4 }, {     37,    1,    4, 20, 45,  4 }, {     38,    0,    4, 20, 45,  4 }, {     39,   -1,    4, 21, 45,  4 }, {     39,   -2,    4, 21, 45,  4 },
    {     40,   -3,    4, 21, 45,  4 }, {     41,   -4,    4, 21, 45,  4 }, {     41,   -5,    4, 21, 45,  4 }, {     42,   -6,    4, 21, 45,  4 }, {     42,   -7,    5, 21, 45,  4 },
    {     43,   -8,    5, 21, 45,  4 }, {     43,   -9,    5, 21, 45,  4 }, {     44,  -10,    5, 22, 45,  4 }, {     44,  -11,    5, 22, 45,  4 }, {     45,  -12,    5, 22, 45,  4 },
    {     45,  -13,    5, 22, 45,  4 }, {     45,  -14,    5, 22, 45,  4 }, {     46,  -15,    6, 22, 45,  4 }, {     46,  -16,    6, 22, 45,  4 }, {     46,  -17,    6, 22, 45,  4 },
    {     47,  -18,    6, 22, 45,  4 }, {     47,  -19,    6, 22, 45,  4 }, {     47,  -20,    6, 23, 45,  4 }, {     47,  -21,    6, 23, 45,  4 }, {     47,  -22,    6, 23, 45,  4 },
    {     47,  -23,    6, 23, 45,  4 }, {     48,  -24,    7, 23, 45,  4 }, {     48,  -25,    7, 23, 45,  4 }, {     48,  -26,    7, 23, 45,  4 }, {     48,  -27,    7, 23, 45,  4 },
    {     48,  -28,    7, 24, 45,  4 }, {     48,  -29,    7, 24, 45,  4 }, {     48,  -30,    7, 24, 45,  4 }, {     48,  -31,    7, 24, 45,  4 }, {     48,  -33,    8, 24, 45,  4 },
    {     48,  -34,    8, 24, 45,  4 }, {     48,  -35,    8, 24, 45,  4 }, {     48,  -36,    8, 24, 45,  4 }, {     48,  -37,    8, 25, 45,  4 }, {     48,  -38,    8, 25, 45,  4 },
    {     47,  -39,    8, 25, 45,  4 }, {     47,  -40,    8, 25, 45,  4 }, {     47,  -41,    9, 25, 45,  4 }, {     47,  -42,    9, 25, 45,  4 }, {     47,  -43,    9, 25, 45,  4 },
    {     47,  -44,    9, 25, 45,  4 }, {     46,  -45,    9, 25, 45,  4 }, {     46,  -46,    9, 26, 45,  4 }, {     46,  -47,    9, 26, 45,  4 }, {     45,  -48,    9, 26, 45,  4 },
    {     45,  -49,   10, 26, 45,  4 }, {     45,  -50,   10, 26, 45,  4 }, {     44,  -51,   10, 26, 45,  4 }, {     44,  -52,   10, 26, 45,  4 }, {     43,  -53,   10, 26, 45,  4 },
    {     43,  -54,   10, 26, 45,  4 }, {     42,  -55,   10, 26, 45,  4 }, {     42,  -56,   10, 27, 45,  4 }, {     41,  -57,   10, 27, 45,  4 }, {     41,  -58,   11, 27, 45,  4 },
    {     40,  -59,   11, 27, 45,  4 }, {     39,  -60,   11, 27, 45,  4 }, {     39,  -61,   11, 27, 45,  4 }, {     38,  -62,   11, 27, 45,  4 }, {     37,  -63,   11, 27, 45,  4 },
    {     36,  -64,   11, 27, 45,  4 }, {     35,  -65,   11, 28, 45,  4 }, {     35,  -67,   12, 28, 45,  4 }, {     34,  -68,   12, 28, 45,  4 }, {     33,  -69,   12, 28, 45,  4 },
    {     32,  -70,   12, 28, 45,  4 }, {     31,  -71,   12, 29, 45,  4 }, {     30,  -71,   12, 29, 45,  4 }, {     29,  -72,   12, 29, 45,  4 }, {     28,  -73,   12, 29, 45,  4 },
    {     27,  -73,   12, 29, 45,  4 }, {     26,  -74,   13, 29, 45,  4 }, {     25,  -74,   13, 29, 45,  4 }, {     24,  -75,   13, 29, 45,  4 }, {     23,  -75,   13, 29, 45,  4 },
    {     22,  -76,   13, 30, 45,  4 }, {     21,  -76,   13, 30, 45,  4 }, {     20,  -77,   13, 30, 45,  4 }, {     19,  -77,   13, 30, 45,  4 }, {     18,  -77,   14, 30, 45,  4 },
    {     17,  -78,   14, 30, 45,  4 }, {     16,  -78,   14, 30, 45,  4 }, {     15,  -78,   14, 30, 45,  4 }, {     14,  -79,   14, 30, 45,  4 }, {     13,  -79,   14, 30, 45,  4 },
    {     12,  -79,   14, 31, 45,  4 }, {     11,  -79,   14, 31, 45,  4 }, {     10,  -79,   14, 31, 45,  4 }, {      9,  -79,   15, 31, 45,  4 }, {      8,  -80,   15, 31, 45,  4 },
    {      7,  -80,   15, 31, 45,  4 }, {      6,  -80,   15, 31, 45,  4 }, {      5,  -80,   15, 31, 45,  4 }, {      4,  -80,   15,  0, 45,  4 }, {      3,  -80,   15,  0, 45,  4 },
    {      2,  -80,   15,  0, 45,  4 }, {      1,  -80,   16,  0, 45,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FAE11, {
    {     16,   31,    0, 24, 45,  4 }, {     16,   30,    0, 24, 45,  4 }, {     16,   29,    0, 24, 45,  4 }, {     16,   28,    0, 24, 45,  4 }, {     16,   27,    0, 25, 45,  4 },
    {     16,   26,    0, 25, 45,  4 }, {     15,   25,    0, 25, 45,  4 }, {     15,   24,    0, 25, 45,  4 }, {     15,   23,    1, 25, 45,  4 }, {     15,   22,    1, 25, 45,  4 },
    {     15,   21,    1, 25, 45,  4 }, {     15,   20,    1, 25, 45,  4 }, {     14,   19,    1, 25, 45,  4 }, {     14,   18,    1, 26, 45,  4 }, {     14,   17,    1, 26, 45,  4 },
    {     13,   16,    1, 26, 45,  4 }, {     13,   15,    2, 26, 45,  4 }, {     13,   14,    2, 26, 45,  4 }, {     12,   13,    2, 26, 45,  4 }, {     12,   12,    2, 26, 45,  4 },
    {     11,   11,    2, 26, 45,  4 }, {     11,   10,    2, 26, 45,  4 }, {     10,    9,    2, 26, 45,  4 }, {     10,    8,    2, 27, 45,  4 }, {      9,    7,    2, 27, 45,  4 },
    {      9,    6,    3, 27, 45,  4 }, {      8,    5,    3, 27, 45,  4 }, {      7,    4,    3, 27, 45,  4 }, {      7,    3,    3, 27, 45,  4 }, {      6,    2,    3, 27, 45,  4 },
    {      5,    1,    3, 27, 45,  4 }, {      4,    0,    3, 27, 45,  4 }, {      3,   -1,    3, 28, 45,  4 }, {      3,   -3,    4, 28, 45,  4 }, {      2,   -4,    4, 28, 45,  4 },
    {      1,   -5,    4, 28, 45,  4 }, {      0,   -6,    4, 28, 45,  4 }, {     -1,   -7,    4, 29, 45,  4 }, {     -2,   -7,    4, 29, 45,  4 }, {     -3,   -8,    4, 29, 45,  4 },
    {     -4,   -9,    4, 29, 45,  4 }, {     -5,   -9,    4, 29, 45,  4 }, {     -6,  -10,    5, 29, 45,  4 }, {     -7,  -10,    5, 29, 45,  4 }, {     -8,  -11,    5, 29, 45,  4 },
    {     -9,  -11,    5, 29, 45,  4 }, {    -10,  -12,    5, 30, 45,  4 }, {    -11,  -12,    5, 30, 45,  4 }, {    -12,  -13,    5, 30, 45,  4 }, {    -13,  -13,    5, 30, 45,  4 },
    {    -14,  -13,    6, 30, 45,  4 }, {    -15,  -14,    6, 30, 45,  4 }, {    -16,  -14,    6, 30, 45,  4 }, {    -17,  -14,    6, 30, 45,  4 }, {    -18,  -15,    6, 30, 45,  4 },
    {    -19,  -15,    6, 30, 45,  4 }, {    -20,  -15,    6, 31, 45,  4 }, {    -21,  -15,    6, 31, 45,  4 }, {    -22,  -15,    6, 31, 45,  4 }, {    -23,  -15,    7, 31, 45,  4 },
    {    -24,  -16,    7, 31, 45,  4 }, {    -25,  -16,    7, 31, 45,  4 }, {    -26,  -16,    7, 31, 45,  4 }, {    -27,  -16,    7, 31, 45,  4 }, {    -28,  -16,    7,  0, 45,  4 },
    {    -29,  -16,    7,  0, 45,  4 }, {    -30,  -16,    7,  0, 45,  4 }, {    -31,  -16,    8,  0, 45,  4 }, {    -33,  -16,    8,  0, 45,  4 }, {    -34,  -16,    8,  0, 45,  4 },
    {    -35,  -16,    8,  0, 45,  4 }, {    -36,  -16,    8,  0, 45,  4 }, {    -37,  -16,    8,  1, 45,  4 }, {    -38,  -16,    8,  1, 45,  4 }, {    -39,  -15,    8,  1, 45,  4 },
    {    -40,  -15,    8,  1, 45,  4 }, {    -41,  -15,    9,  1, 45,  4 }, {    -42,  -15,    9,  1, 45,  4 }, {    -43,  -15,    9,  1, 45,  4 }, {    -44,  -15,    9,  1, 45,  4 },
    {    -45,  -14,    9,  1, 45,  4 }, {    -46,  -14,    9,  2, 45,  4 }, {    -47,  -14,    9,  2, 45,  4 }, {    -48,  -13,    9,  2, 45,  4 }, {    -49,  -13,   10,  2, 45,  4 },
    {    -50,  -13,   10,  2, 45,  4 }, {    -51,  -12,   10,  2, 45,  4 }, {    -52,  -12,   10,  2, 45,  4 }, {    -53,  -11,   10,  2, 45,  4 }, {    -54,  -11,   10,  2, 45,  4 },
    {    -55,  -10,   10,  2, 45,  4 }, {    -56,  -10,   10,  3, 45,  4 }, {    -57,   -9,   10,  3, 45,  4 }, {    -58,   -9,   11,  3, 45,  4 }, {    -59,   -8,   11,  3, 45,  4 },
    {    -60,   -7,   11,  3, 45,  4 }, {    -61,   -7,   11,  3, 45,  4 }, {    -62,   -6,   11,  3, 45,  4 }, {    -63,   -5,   11,  3, 45,  4 }, {    -64,   -4,   11,  3, 45,  4 },
    {    -65,   -3,   11,  4, 45,  4 }, {    -67,   -3,   12,  4, 45,  4 }, {    -68,   -2,   12,  4, 45,  4 }, {    -69,   -1,   12,  4, 45,  4 }, {    -70,    0,   12,  4, 45,  4 },
    {    -71,    1,   12,  5, 45,  4 }, {    -71,    2,   12,  5, 45,  4 }, {    -72,    3,   12,  5, 45,  4 }, {    -73,    4,   12,  5, 45,  4 }, {    -73,    5,   13,  5, 45,  4 },
    {    -74,    6,   13,  5, 45,  4 }, {    -74,    7,   13,  5, 45,  4 }, {    -75,    8,   13,  5, 45,  4 }, {    -75,    9,   13,  5, 45,  4 }, {    -76,   10,   13,  6, 45,  4 },
    {    -76,   11,   13,  6, 45,  4 }, {    -77,   12,   13,  6, 45,  4 }, {    -77,   13,   13,  6, 45,  4 }, {    -77,   14,   14,  6, 45,  4 }, {    -78,   15,   14,  6, 45,  4 },
    {    -78,   16,   14,  6, 45,  4 }, {    -78,   17,   14,  6, 45,  4 }, {    -79,   18,   14,  6, 45,  4 }, {    -79,   19,   14,  6, 45,  4 }, {    -79,   20,   14,  7, 45,  4 },
    {    -79,   21,   14,  7, 45,  4 }, {    -79,   22,   15,  7, 45,  4 }, {    -79,   23,   15,  7, 45,  4 }, {    -80,   24,   15,  7, 45,  4 }, {    -80,   25,   15,  7, 45,  4 },
    {    -80,   26,   15,  7, 45,  4 }, {    -80,   27,   15,  7, 45,  4 }, {    -80,   28,   15,  8, 45,  4 }, {    -80,   29,   15,  8, 45,  4 }, {    -80,   30,   16,  8, 45,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FB2D2, {
    {     31,   16,    8,  0, 47,  2 }, {     30,   16,    8,  0, 47,  2 }, {     29,   16,    8,  0, 47,  2 }, {     28,   16,    8,  0, 47,  2 }, {     27,   16,    8, 31, 47,  2 },
    {     26,   16,    8, 31, 47,  2 }, {     25,   15,    8, 31, 47,  2 }, {     24,   15,    8, 31, 47,  2 }, {     23,   15,    7, 31, 47,  2 }, {     22,   15,    7, 31, 47,  2 },
    {     21,   15,    7, 31, 47,  2 }, {     20,   15,    7, 31, 47,  2 }, {     19,   14,    7, 31, 47,  2 }, {     18,   14,    7, 30, 47,  2 }, {     17,   14,    7, 30, 47,  2 },
    {     16,   13,    7, 30, 47,  2 }, {     15,   13,    6, 30, 47,  2 }, {     14,   13,    6, 30, 47,  2 }, {     13,   12,    6, 30, 47,  2 }, {     12,   12,    6, 30, 47,  2 },
    {     11,   11,    6, 30, 47,  2 }, {     10,   11,    6, 30, 47,  2 }, {      9,   10,    6, 30, 47,  2 }, {      8,   10,    6, 29, 47,  2 }, {      7,    9,    6, 29, 47,  2 },
    {      6,    9,    5, 29, 47,  2 }, {      5,    8,    5, 29, 47,  2 }, {      4,    7,    5, 29, 47,  2 }, {      3,    7,    5, 29, 47,  2 }, {      2,    6,    5, 29, 47,  2 },
    {      1,    5,    5, 29, 47,  2 }, {      0,    4,    5, 29, 47,  2 }, {     -1,    3,    5, 28, 47,  2 }, {     -3,    3,    4, 28, 47,  2 }, {     -4,    2,    4, 28, 47,  2 },
    {     -5,    1,    4, 28, 47,  2 }, {     -6,    0,    4, 28, 47,  2 }, {     -7,   -1,    4, 27, 47,  2 }, {     -7,   -2,    4, 27, 47,  2 }, {     -8,   -3,    4, 27, 47,  2 },
    {     -9,   -4,    4, 27, 47,  2 }, {     -9,   -5,    4, 27, 47,  2 }, {    -10,   -6,    3, 27, 47,  2 }, {    -10,   -7,    3, 27, 47,  2 }, {    -11,   -8,    3, 27, 47,  2 },
    {    -11,   -9,    3, 27, 47,  2 }, {    -12,  -10,    3, 26, 47,  2 }, {    -12,  -11,    3, 26, 47,  2 }, {    -13,  -12,    3, 26, 47,  2 }, {    -13,  -13,    3, 26, 47,  2 },
    {    -13,  -14,    2, 26, 47,  2 }, {    -14,  -15,    2, 26, 47,  2 }, {    -14,  -16,    2, 26, 47,  2 }, {    -14,  -17,    2, 26, 47,  2 }, {    -15,  -18,    2, 26, 47,  2 },
    {    -15,  -19,    2, 26, 47,  2 }, {    -15,  -20,    2, 25, 47,  2 }, {    -15,  -21,    2, 25, 47,  2 }, {    -15,  -22,    2, 25, 47,  2 }, {    -15,  -23,    1, 25, 47,  2 },
    {    -16,  -24,    1, 25, 47,  2 }, {    -16,  -25,    1, 25, 47,  2 }, {    -16,  -26,    1, 25, 47,  2 }, {    -16,  -27,    1, 25, 47,  2 }, {    -16,  -28,    1, 24, 47,  2 },
    {    -16,  -29,    1, 24, 47,  2 }, {    -16,  -30,    1, 24, 47,  2 }, {    -16,  -31,    0, 24, 47,  2 }, {    -16,  -33,    0, 24, 47,  2 }, {    -16,  -34,    0, 24, 47,  2 },
    {    -16,  -35,    0, 24, 47,  2 }, {    -16,  -36,    0, 24, 47,  2 }, {    -16,  -37,    0, 23, 47,  2 }, {    -16,  -38,    0, 23, 47,  2 }, {    -15,  -39,    0, 23, 47,  2 },
    {    -15,  -40,    0, 23, 47,  2 }, {    -15,  -41,   -1, 23, 47,  2 }, {    -15,  -42,   -1, 23, 47,  2 }, {    -15,  -43,   -1, 23, 47,  2 }, {    -15,  -44,   -1, 23, 47,  2 },
    {    -14,  -45,   -1, 23, 47,  2 }, {    -14,  -46,   -1, 22, 47,  2 }, {    -14,  -47,   -1, 22, 47,  2 }, {    -13,  -48,   -1, 22, 47,  2 }, {    -13,  -49,   -2, 22, 47,  2 },
    {    -13,  -50,   -2, 22, 47,  2 }, {    -12,  -51,   -2, 22, 47,  2 }, {    -12,  -52,   -2, 22, 47,  2 }, {    -11,  -53,   -2, 22, 47,  2 }, {    -11,  -54,   -2, 22, 47,  2 },
    {    -10,  -55,   -2, 22, 47,  2 }, {    -10,  -56,   -2, 21, 47,  2 }, {     -9,  -57,   -2, 21, 47,  2 }, {     -9,  -58,   -3, 21, 47,  2 }, {     -8,  -59,   -3, 21, 47,  2 },
    {     -7,  -60,   -3, 21, 47,  2 }, {     -7,  -61,   -3, 21, 47,  2 }, {     -6,  -62,   -3, 21, 47,  2 }, {     -5,  -63,   -3, 21, 47,  2 }, {     -4,  -64,   -3, 21, 47,  2 },
    {     -3,  -65,   -3, 20, 47,  2 }, {     -3,  -67,   -4, 20, 47,  2 }, {     -2,  -68,   -4, 20, 47,  2 }, {     -1,  -69,   -4, 20, 47,  2 }, {      0,  -70,   -4, 20, 47,  2 },
    {      1,  -71,   -4, 19, 47,  2 }, {      2,  -71,   -4, 19, 47,  2 }, {      3,  -72,   -4, 19, 47,  2 }, {      4,  -73,   -4, 19, 47,  2 }, {      5,  -73,   -5, 19, 47,  2 },
    {      6,  -74,   -5, 19, 47,  2 }, {      7,  -74,   -5, 19, 47,  2 }, {      8,  -75,   -5, 19, 47,  2 }, {      9,  -75,   -5, 19, 47,  2 }, {     10,  -76,   -5, 18, 47,  2 },
    {     11,  -76,   -5, 18, 47,  2 }, {     12,  -77,   -5, 18, 47,  2 }, {     13,  -77,   -5, 18, 47,  2 }, {     14,  -77,   -6, 18, 47,  2 }, {     15,  -78,   -6, 18, 47,  2 },
    {     16,  -78,   -6, 18, 47,  2 }, {     17,  -78,   -6, 18, 47,  2 }, {     18,  -79,   -6, 18, 47,  2 }, {     19,  -79,   -6, 18, 47,  2 }, {     20,  -79,   -6, 17, 47,  2 },
    {     21,  -79,   -6, 17, 47,  2 }, {     22,  -79,   -7, 17, 47,  2 }, {     23,  -79,   -7, 17, 47,  2 }, {     24,  -80,   -7, 17, 47,  2 }, {     25,  -80,   -7, 17, 47,  2 },
    {     26,  -80,   -7, 17, 47,  2 }, {     27,  -80,   -7, 17, 47,  2 }, {     28,  -80,   -7, 16, 47,  2 }, {     29,  -80,   -7, 16, 47,  2 }, {     30,  -80,   -8, 16, 47,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FB793, {
    {     16,    0,    8,  8, 47,  2 }, {     16,    1,    8,  8, 47,  2 }, {     16,    2,    8,  8, 47,  2 }, {     16,    3,    8,  8, 47,  2 }, {     16,    4,    8,  8, 47,  2 },
    {     16,    5,    8,  7, 47,  2 }, {     16,    6,    8,  7, 47,  2 }, {     15,    7,    8,  7, 47,  2 }, {     15,    8,    8,  7, 47,  2 }, {     15,    9,    7,  7, 47,  2 },
    {     15,   10,    7,  7, 47,  2 }, {     15,   11,    7,  7, 47,  2 }, {     15,   12,    7,  7, 47,  2 }, {     14,   13,    7,  7, 47,  2 }, {     14,   14,    7,  6, 47,  2 },
    {     14,   15,    7,  6, 47,  2 }, {     13,   16,    7,  6, 47,  2 }, {     13,   17,    7,  6, 47,  2 }, {     13,   18,    6,  6, 47,  2 }, {     12,   19,    6,  6, 47,  2 },
    {     12,   20,    6,  6, 47,  2 }, {     11,   21,    6,  6, 47,  2 }, {     11,   22,    6,  6, 47,  2 }, {     10,   23,    6,  6, 47,  2 }, {     10,   24,    6,  5, 47,  2 },
    {      9,   25,    6,  5, 47,  2 }, {      9,   26,    5,  5, 47,  2 }, {      8,   27,    5,  5, 47,  2 }, {      7,   28,    5,  5, 47,  2 }, {      7,   29,    5,  5, 47,  2 },
    {      6,   30,    5,  5, 47,  2 }, {      5,   31,    5,  5, 47,  2 }, {      4,   32,    5,  5, 47,  2 }, {      3,   33,    5,  4, 47,  2 }, {      3,   35,    5,  4, 47,  2 },
    {      2,   36,    4,  4, 47,  2 }, {      1,   37,    4,  4, 47,  2 }, {      0,   38,    4,  4, 47,  2 }, {     -1,   39,    4,  3, 47,  2 }, {     -2,   39,    4,  3, 47,  2 },
    {     -3,   40,    4,  3, 47,  2 }, {     -4,   41,    4,  3, 47,  2 }, {     -5,   41,    4,  3, 47,  2 }, {     -6,   42,    4,  3, 47,  2 }, {     -7,   42,    3,  3, 47,  2 },
    {     -8,   43,    3,  3, 47,  2 }, {     -9,   43,    3,  3, 47,  2 }, {    -10,   44,    3,  2, 47,  2 }, {    -11,   44,    3,  2, 47,  2 }, {    -12,   45,    3,  2, 47,  2 },
    {    -13,   45,    3,  2, 47,  2 }, {    -14,   45,    3,  2, 47,  2 }, {    -15,   46,    2,  2, 47,  2 }, {    -16,   46,    2,  2, 47,  2 }, {    -17,   46,    2,  2, 47,  2 },
    {    -18,   47,    2,  2, 47,  2 }, {    -19,   47,    2,  2, 47,  2 }, {    -20,   47,    2,  1, 47,  2 }, {    -21,   47,    2,  1, 47,  2 }, {    -22,   47,    2,  1, 47,  2 },
    {    -23,   47,    2,  1, 47,  2 }, {    -24,   48,    1,  1, 47,  2 }, {    -25,   48,    1,  1, 47,  2 }, {    -26,   48,    1,  1, 47,  2 }, {    -27,   48,    1,  1, 47,  2 },
    {    -28,   48,    1,  0, 47,  2 }, {    -29,   48,    1,  0, 47,  2 }, {    -30,   48,    1,  0, 47,  2 }, {    -31,   48,    1,  0, 47,  2 }, {    -33,   48,    0,  0, 47,  2 },
    {    -34,   48,    0,  0, 47,  2 }, {    -35,   48,    0,  0, 47,  2 }, {    -36,   48,    0,  0, 47,  2 }, {    -37,   48,    0, 31, 47,  2 }, {    -38,   48,    0, 31, 47,  2 },
    {    -39,   47,    0, 31, 47,  2 }, {    -40,   47,    0, 31, 47,  2 }, {    -41,   47,   -1, 31, 47,  2 }, {    -42,   47,   -1, 31, 47,  2 }, {    -43,   47,   -1, 31, 47,  2 },
    {    -44,   47,   -1, 31, 47,  2 }, {    -45,   46,   -1, 31, 47,  2 }, {    -46,   46,   -1, 30, 47,  2 }, {    -47,   46,   -1, 30, 47,  2 }, {    -48,   45,   -1, 30, 47,  2 },
    {    -49,   45,   -2, 30, 47,  2 }, {    -50,   45,   -2, 30, 47,  2 }, {    -51,   44,   -2, 30, 47,  2 }, {    -52,   44,   -2, 30, 47,  2 }, {    -53,   43,   -2, 30, 47,  2 },
    {    -54,   43,   -2, 30, 47,  2 }, {    -55,   42,   -2, 30, 47,  2 }, {    -56,   42,   -2, 29, 47,  2 }, {    -57,   41,   -2, 29, 47,  2 }, {    -58,   41,   -3, 29, 47,  2 },
    {    -59,   40,   -3, 29, 47,  2 }, {    -60,   39,   -3, 29, 47,  2 }, {    -61,   39,   -3, 29, 47,  2 }, {    -62,   38,   -3, 29, 47,  2 }, {    -63,   37,   -3, 29, 47,  2 },
    {    -64,   36,   -3, 29, 47,  2 }, {    -65,   35,   -3, 28, 47,  2 }, {    -67,   35,   -4, 28, 47,  2 }, {    -68,   34,   -4, 28, 47,  2 }, {    -69,   33,   -4, 28, 47,  2 },
    {    -70,   32,   -4, 28, 47,  2 }, {    -71,   31,   -4, 27, 47,  2 }, {    -71,   30,   -4, 27, 47,  2 }, {    -72,   29,   -4, 27, 47,  2 }, {    -73,   28,   -4, 27, 47,  2 },
    {    -73,   27,   -4, 27, 47,  2 }, {    -74,   26,   -5, 27, 47,  2 }, {    -74,   25,   -5, 27, 47,  2 }, {    -75,   24,   -5, 27, 47,  2 }, {    -75,   23,   -5, 27, 47,  2 },
    {    -76,   22,   -5, 26, 47,  2 }, {    -76,   21,   -5, 26, 47,  2 }, {    -77,   20,   -5, 26, 47,  2 }, {    -77,   19,   -5, 26, 47,  2 }, {    -77,   18,   -6, 26, 47,  2 },
    {    -78,   17,   -6, 26, 47,  2 }, {    -78,   16,   -6, 26, 47,  2 }, {    -78,   15,   -6, 26, 47,  2 }, {    -79,   14,   -6, 26, 47,  2 }, {    -79,   13,   -6, 26, 47,  2 },
    {    -79,   12,   -6, 25, 47,  2 }, {    -79,   11,   -6, 25, 47,  2 }, {    -79,   10,   -6, 25, 47,  2 }, {    -79,    9,   -7, 25, 47,  2 }, {    -80,    8,   -7, 25, 47,  2 },
    {    -80,    7,   -7, 25, 47,  2 }, {    -80,    6,   -7, 25, 47,  2 }, {    -80,    5,   -7, 25, 47,  2 }, {    -80,    4,   -7, 24, 47,  2 }, {    -80,    3,   -7, 24, 47,  2 },
    {    -80,    2,   -7, 24, 47,  2 }, {    -80,    1,   -8, 24, 47,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FBC66, {
    {      0,   16,    8, 16, 47,  2 }, {      1,   16,    8, 16, 47,  2 }, {      2,   16,    8, 16, 47,  2 }, {      3,   16,    8, 16, 47,  2 }, {      4,   16,    8, 16, 47,  2 },
    {      5,   16,    8, 15, 47,  2 }, {      6,   16,    8, 15, 47,  2 }, {      7,   17,    8, 15, 47,  2 }, {      8,   17,    8, 15, 47,  2 }, {      9,   17,    7, 15, 47,  2 },
    {     10,   17,    7, 15, 47,  2 }, {     11,   17,    7, 15, 47,  2 }, {     12,   17,    7, 15, 47,  2 }, {     13,   18,    7, 15, 47,  2 }, {     14,   18,    7, 14, 47,  2 },
    {     15,   18,    7, 14, 47,  2 }, {     16,   19,    7, 14, 47,  2 }, {     17,   19,    6, 14, 47,  2 }, {     18,   19,    6, 14, 47,  2 }, {     19,   20,    6, 14, 47,  2 },
    {     20,   20,    6, 14, 47,  2 }, {     21,   21,    6, 14, 47,  2 }, {     22,   21,    6, 14, 47,  2 }, {     23,   22,    6, 14, 47,  2 }, {     24,   22,    6, 13, 47,  2 },
    {     25,   23,    6, 13, 47,  2 }, {     26,   23,    5, 13, 47,  2 }, {     27,   24,    5, 13, 47,  2 }, {     28,   25,    5, 13, 47,  2 }, {     29,   25,    5, 13, 47,  2 },
    {     30,   26,    5, 13, 47,  2 }, {     31,   27,    5, 13, 47,  2 }, {     32,   28,    5, 13, 47,  2 }, {     33,   29,    5, 12, 47,  2 }, {     35,   29,    4, 12, 47,  2 },
    {     36,   30,    4, 12, 47,  2 }, {     37,   31,    4, 12, 47,  2 }, {     38,   32,    4, 12, 47,  2 }, {     39,   33,    4, 11, 47,  2 }, {     39,   34,    4, 11, 47,  2 },
    {     40,   35,    4, 11, 47,  2 }, {     41,   36,    4, 11, 47,  2 }, {     41,   37,    4, 11, 47,  2 }, {     42,   38,    3, 11, 47,  2 }, {     42,   39,    3, 11, 47,  2 },
    {     43,   40,    3, 11, 47,  2 }, {     43,   41,    3, 11, 47,  2 }, {     44,   42,    3, 10, 47,  2 }, {     44,   43,    3, 10, 47,  2 }, {     45,   44,    3, 10, 47,  2 },
    {     45,   45,    3, 10, 47,  2 }, {     45,   46,    2, 10, 47,  2 }, {     46,   47,    2, 10, 47,  2 }, {     46,   48,    2, 10, 47,  2 }, {     46,   49,    2, 10, 47,  2 },
    {     47,   50,    2, 10, 47,  2 }, {     47,   51,    2, 10, 47,  2 }, {     47,   52,    2,  9, 47,  2 }, {     47,   53,    2,  9, 47,  2 }, {     47,   54,    2,  9, 47,  2 },
    {     47,   55,    1,  9, 47,  2 }, {     48,   56,    1,  9, 47,  2 }, {     48,   57,    1,  9, 47,  2 }, {     48,   58,    1,  9, 47,  2 }, {     48,   59,    1,  9, 47,  2 },
    {     48,   60,    1,  8, 47,  2 }, {     48,   61,    1,  8, 47,  2 }, {     48,   62,    1,  8, 47,  2 }, {     48,   64,    0,  8, 47,  2 }, {     48,   65,    0,  8, 47,  2 },
    {     48,   66,    0,  8, 47,  2 }, {     48,   67,    0,  8, 47,  2 }, {     48,   68,    0,  8, 47,  2 }, {     48,   69,    0,  7, 47,  2 }, {     48,   70,    0,  7, 47,  2 },
    {     47,   71,    0,  7, 47,  2 }, {     47,   72,    0,  7, 47,  2 }, {     47,   73,   -1,  7, 47,  2 }, {     47,   74,   -1,  7, 47,  2 }, {     47,   75,   -1,  7, 47,  2 },
    {     47,   76,   -1,  7, 47,  2 }, {     46,   77,   -1,  7, 47,  2 }, {     46,   78,   -1,  6, 47,  2 }, {     46,   79,   -1,  6, 47,  2 }, {     45,   80,   -1,  6, 47,  2 },
    {     45,   81,   -1,  6, 47,  2 }, {     45,   82,   -2,  6, 47,  2 }, {     44,   83,   -2,  6, 47,  2 }, {     44,   84,   -2,  6, 47,  2 }, {     43,   85,   -2,  6, 47,  2 },
    {     43,   86,   -2,  6, 47,  2 }, {     42,   87,   -2,  6, 47,  2 }, {     42,   88,   -2,  5, 47,  2 }, {     41,   89,   -2,  5, 47,  2 }, {     41,   90,   -3,  5, 47,  2 },
    {     40,   91,   -3,  5, 47,  2 }, {     39,   92,   -3,  5, 47,  2 }, {     39,   93,   -3,  5, 47,  2 }, {     38,   94,   -3,  5, 47,  2 }, {     37,   95,   -3,  5, 47,  2 },
    {     36,   96,   -3,  5, 47,  2 }, {     35,   97,   -3,  4, 47,  2 }, {     35,   99,   -3,  4, 47,  2 }, {     34,  100,   -4,  4, 47,  2 }, {     33,  101,   -4,  4, 47,  2 },
    {     32,  102,   -4,  4, 47,  2 }, {     31,  103,   -4,  3, 47,  2 }, {     30,  103,   -4,  3, 47,  2 }, {     29,  104,   -4,  3, 47,  2 }, {     28,  105,   -4,  3, 47,  2 },
    {     27,  105,   -4,  3, 47,  2 }, {     26,  106,   -4,  3, 47,  2 }, {     25,  106,   -5,  3, 47,  2 }, {     24,  107,   -5,  3, 47,  2 }, {     23,  107,   -5,  3, 47,  2 },
    {     22,  108,   -5,  2, 47,  2 }, {     21,  108,   -5,  2, 47,  2 }, {     20,  109,   -5,  2, 47,  2 }, {     19,  109,   -5,  2, 47,  2 }, {     18,  109,   -5,  2, 47,  2 },
    {     17,  110,   -6,  2, 47,  2 }, {     16,  110,   -6,  2, 47,  2 }, {     15,  110,   -6,  2, 47,  2 }, {     14,  111,   -6,  2, 47,  2 }, {     13,  111,   -6,  2, 47,  2 },
    {     12,  111,   -6,  1, 47,  2 }, {     11,  111,   -6,  1, 47,  2 }, {     10,  111,   -6,  1, 47,  2 }, {      9,  111,   -6,  1, 47,  2 }, {      8,  112,   -7,  1, 47,  2 },
    {      7,  112,   -7,  1, 47,  2 }, {      6,  112,   -7,  1, 47,  2 }, {      5,  112,   -7,  1, 47,  2 }, {      4,  112,   -7,  0, 47,  2 }, {      3,  112,   -7,  0, 47,  2 },
    {      2,  112,   -7,  0, 47,  2 }, {      1,  112,   -7,  0, 47,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FC139, {
    {     16,   31,    8, 24, 47,  2 }, {     16,   30,    8, 24, 47,  2 }, {     16,   29,    8, 24, 47,  2 }, {     16,   28,    8, 24, 47,  2 }, {     16,   27,    8, 23, 47,  2 },
    {     16,   26,    8, 23, 47,  2 }, {     17,   25,    8, 23, 47,  2 }, {     17,   24,    8, 23, 47,  2 }, {     17,   23,    7, 23, 47,  2 }, {     17,   22,    7, 23, 47,  2 },
    {     17,   21,    7, 23, 47,  2 }, {     17,   20,    7, 23, 47,  2 }, {     18,   19,    7, 23, 47,  2 }, {     18,   18,    7, 22, 47,  2 }, {     18,   17,    7, 22, 47,  2 },
    {     19,   16,    7, 22, 47,  2 }, {     19,   15,    6, 22, 47,  2 }, {     19,   14,    6, 22, 47,  2 }, {     20,   13,    6, 22, 47,  2 }, {     20,   12,    6, 22, 47,  2 },
    {     21,   11,    6, 22, 47,  2 }, {     21,   10,    6, 22, 47,  2 }, {     22,    9,    6, 22, 47,  2 }, {     22,    8,    6, 21, 47,  2 }, {     23,    7,    6, 21, 47,  2 },
    {     23,    6,    5, 21, 47,  2 }, {     24,    5,    5, 21, 47,  2 }, {     25,    4,    5, 21, 47,  2 }, {     25,    3,    5, 21, 47,  2 }, {     26,    2,    5, 21, 47,  2 },
    {     27,    1,    5, 21, 47,  2 }, {     28,    0,    5, 21, 47,  2 }, {     29,   -1,    5, 20, 47,  2 }, {     29,   -3,    4, 20, 47,  2 }, {     30,   -4,    4, 20, 47,  2 },
    {     31,   -5,    4, 20, 47,  2 }, {     32,   -6,    4, 20, 47,  2 }, {     33,   -7,    4, 19, 47,  2 }, {     34,   -7,    4, 19, 47,  2 }, {     35,   -8,    4, 19, 47,  2 },
    {     36,   -9,    4, 19, 47,  2 }, {     37,   -9,    3, 19, 47,  2 }, {     38,  -10,    3, 19, 47,  2 }, {     39,  -10,    3, 19, 47,  2 }, {     40,  -11,    3, 19, 47,  2 },
    {     41,  -11,    3, 19, 47,  2 }, {     42,  -12,    3, 18, 47,  2 }, {     43,  -12,    3, 18, 47,  2 }, {     44,  -13,    3, 18, 47,  2 }, {     45,  -13,    3, 18, 47,  2 },
    {     46,  -13,    2, 18, 47,  2 }, {     47,  -14,    2, 18, 47,  2 }, {     48,  -14,    2, 18, 47,  2 }, {     49,  -14,    2, 18, 47,  2 }, {     50,  -15,    2, 18, 47,  2 },
    {     51,  -15,    2, 18, 47,  2 }, {     52,  -15,    2, 17, 47,  2 }, {     53,  -15,    2, 17, 47,  2 }, {     54,  -15,    1, 17, 47,  2 }, {     55,  -15,    1, 17, 47,  2 },
    {     56,  -16,    1, 17, 47,  2 }, {     57,  -16,    1, 17, 47,  2 }, {     58,  -16,    1, 17, 47,  2 }, {     59,  -16,    1, 17, 47,  2 }, {     60,  -16,    1, 16, 47,  2 },
    {     61,  -16,    1, 16, 47,  2 }, {     62,  -16,    0, 16, 47,  2 }, {     64,  -16,    0, 16, 47,  2 }, {     65,  -16,    0, 16, 47,  2 }, {     66,  -16,    0, 16, 47,  2 },
    {     67,  -16,    0, 16, 47,  2 }, {     68,  -16,    0, 16, 47,  2 }, {     69,  -16,    0, 15, 47,  2 }, {     70,  -16,    0, 15, 47,  2 }, {     71,  -15,    0, 15, 47,  2 },
    {     72,  -15,    0, 15, 47,  2 }, {     73,  -15,   -1, 15, 47,  2 }, {     74,  -15,   -1, 15, 47,  2 }, {     75,  -15,   -1, 15, 47,  2 }, {     76,  -15,   -1, 15, 47,  2 },
    {     77,  -14,   -1, 15, 47,  2 }, {     78,  -14,   -1, 14, 47,  2 }, {     79,  -14,   -1, 14, 47,  2 }, {     80,  -13,   -1, 14, 47,  2 }, {     81,  -13,   -2, 14, 47,  2 },
    {     82,  -13,   -2, 14, 47,  2 }, {     83,  -12,   -2, 14, 47,  2 }, {     84,  -12,   -2, 14, 47,  2 }, {     85,  -11,   -2, 14, 47,  2 }, {     86,  -11,   -2, 14, 47,  2 },
    {     87,  -10,   -2, 14, 47,  2 }, {     88,  -10,   -2, 13, 47,  2 }, {     89,   -9,   -2, 13, 47,  2 }, {     90,   -9,   -3, 13, 47,  2 }, {     91,   -8,   -3, 13, 47,  2 },
    {     92,   -7,   -3, 13, 47,  2 }, {     93,   -7,   -3, 13, 47,  2 }, {     94,   -6,   -3, 13, 47,  2 }, {     95,   -5,   -3, 13, 47,  2 }, {     96,   -4,   -3, 13, 47,  2 },
    {     97,   -3,   -3, 12, 47,  2 }, {     99,   -3,   -4, 12, 47,  2 }, {    100,   -2,   -4, 12, 47,  2 }, {    101,   -1,   -4, 12, 47,  2 }, {    102,    0,   -4, 12, 47,  2 },
    {    103,    1,   -4, 11, 47,  2 }, {    103,    2,   -4, 11, 47,  2 }, {    104,    3,   -4, 11, 47,  2 }, {    105,    4,   -4, 11, 47,  2 }, {    105,    5,   -4, 11, 47,  2 },
    {    106,    6,   -5, 11, 47,  2 }, {    106,    7,   -5, 11, 47,  2 }, {    107,    8,   -5, 11, 47,  2 }, {    107,    9,   -5, 11, 47,  2 }, {    108,   10,   -5, 10, 47,  2 },
    {    108,   11,   -5, 10, 47,  2 }, {    109,   12,   -5, 10, 47,  2 }, {    109,   13,   -5, 10, 47,  2 }, {    109,   14,   -6, 10, 47,  2 }, {    110,   15,   -6, 10, 47,  2 },
    {    110,   16,   -6, 10, 47,  2 }, {    110,   17,   -6, 10, 47,  2 }, {    111,   18,   -6, 10, 47,  2 }, {    111,   19,   -6, 10, 47,  2 }, {    111,   20,   -6,  9, 47,  2 },
    {    111,   21,   -6,  9, 47,  2 }, {    111,   22,   -6,  9, 47,  2 }, {    111,   23,   -7,  9, 47,  2 }, {    112,   24,   -7,  9, 47,  2 }, {    112,   25,   -7,  9, 47,  2 },
    {    112,   26,   -7,  9, 47,  2 }, {    112,   27,   -7,  9, 47,  2 }, {    112,   28,   -7,  8, 47,  2 }, {    112,   29,   -7,  8, 47,  2 }, {    112,   30,   -7,  8, 47,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FC5FA, {
    {     31,   16,    8,  0, 47,  4 }, {     30,   16,    8,  0, 47,  4 }, {     29,   16,    8,  0, 47,  4 }, {     28,   16,    8,  0, 47,  4 }, {     27,   16,    8,  1, 47,  4 },
    {     26,   16,    8,  1, 47,  4 }, {     25,   17,    8,  1, 47,  4 }, {     24,   17,    8,  1, 47,  4 }, {     23,   17,    7,  1, 47,  4 }, {     22,   17,    7,  1, 47,  4 },
    {     21,   17,    7,  1, 47,  4 }, {     20,   17,    7,  1, 47,  4 }, {     19,   18,    7,  1, 47,  4 }, {     18,   18,    7,  2, 47,  4 }, {     17,   18,    7,  2, 47,  4 },
    {     16,   19,    7,  2, 47,  4 }, {     15,   19,    6,  2, 47,  4 }, {     14,   19,    6,  2, 47,  4 }, {     13,   20,    6,  2, 47,  4 }, {     12,   20,    6,  2, 47,  4 },
    {     11,   21,    6,  2, 47,  4 }, {     10,   21,    6,  2, 47,  4 }, {      9,   22,    6,  2, 47,  4 }, {      8,   22,    6,  3, 47,  4 }, {      7,   23,    6,  3, 47,  4 },
    {      6,   23,    5,  3, 47,  4 }, {      5,   24,    5,  3, 47,  4 }, {      4,   25,    5,  3, 47,  4 }, {      3,   25,    5,  3, 47,  4 }, {      2,   26,    5,  3, 47,  4 },
    {      1,   27,    5,  3, 47,  4 }, {      0,   28,    5,  3, 47,  4 }, {     -1,   29,    5,  4, 47,  4 }, {     -3,   29,    4,  4, 47,  4 }, {     -4,   30,    4,  4, 47,  4 },
    {     -5,   31,    4,  4, 47,  4 }, {     -6,   32,    4,  4, 47,  4 }, {     -7,   33,    4,  5, 47,  4 }, {     -7,   34,    4,  5, 47,  4 }, {     -8,   35,    4,  5, 47,  4 },
    {     -9,   36,    4,  5, 47,  4 }, {     -9,   37,    3,  5, 47,  4 }, {    -10,   38,    3,  5, 47,  4 }, {    -10,   39,    3,  5, 47,  4 }, {    -11,   40,    3,  5, 47,  4 },
    {    -11,   41,    3,  5, 47,  4 }, {    -12,   42,    3,  6, 47,  4 }, {    -12,   43,    3,  6, 47,  4 }, {    -13,   44,    3,  6, 47,  4 }, {    -13,   45,    3,  6, 47,  4 },
    {    -13,   46,    2,  6, 47,  4 }, {    -14,   47,    2,  6, 47,  4 }, {    -14,   48,    2,  6, 47,  4 }, {    -14,   49,    2,  6, 47,  4 }, {    -15,   50,    2,  6, 47,  4 },
    {    -15,   51,    2,  6, 47,  4 }, {    -15,   52,    2,  7, 47,  4 }, {    -15,   53,    2,  7, 47,  4 }, {    -15,   54,    1,  7, 47,  4 }, {    -15,   55,    1,  7, 47,  4 },
    {    -16,   56,    1,  7, 47,  4 }, {    -16,   57,    1,  7, 47,  4 }, {    -16,   58,    1,  7, 47,  4 }, {    -16,   59,    1,  7, 47,  4 }, {    -16,   60,    1,  8, 47,  4 },
    {    -16,   61,    1,  8, 47,  4 }, {    -16,   62,    0,  8, 47,  4 }, {    -16,   64,    0,  8, 47,  4 }, {    -16,   65,    0,  8, 47,  4 }, {    -16,   66,    0,  8, 47,  4 },
    {    -16,   67,    0,  8, 47,  4 }, {    -16,   68,    0,  8, 47,  4 }, {    -16,   69,    0,  9, 47,  4 }, {    -16,   70,    0,  9, 47,  4 }, {    -15,   71,    0,  9, 47,  4 },
    {    -15,   72,    0,  9, 47,  4 }, {    -15,   73,   -1,  9, 47,  4 }, {    -15,   74,   -1,  9, 47,  4 }, {    -15,   75,   -1,  9, 47,  4 }, {    -15,   76,   -1,  9, 47,  4 },
    {    -14,   77,   -1,  9, 47,  4 }, {    -14,   78,   -1, 10, 47,  4 }, {    -14,   79,   -1, 10, 47,  4 }, {    -13,   80,   -1, 10, 47,  4 }, {    -13,   81,   -2, 10, 47,  4 },
    {    -13,   82,   -2, 10, 47,  4 }, {    -12,   83,   -2, 10, 47,  4 }, {    -12,   84,   -2, 10, 47,  4 }, {    -11,   85,   -2, 10, 47,  4 }, {    -11,   86,   -2, 10, 47,  4 },
    {    -10,   87,   -2, 10, 47,  4 }, {    -10,   88,   -2, 11, 47,  4 }, {     -9,   89,   -2, 11, 47,  4 }, {     -9,   90,   -3, 11, 47,  4 }, {     -8,   91,   -3, 11, 47,  4 },
    {     -7,   92,   -3, 11, 47,  4 }, {     -7,   93,   -3, 11, 47,  4 }, {     -6,   94,   -3, 11, 47,  4 }, {     -5,   95,   -3, 11, 47,  4 }, {     -4,   96,   -3, 11, 47,  4 },
    {     -3,   97,   -3, 12, 47,  4 }, {     -3,   99,   -4, 12, 47,  4 }, {     -2,  100,   -4, 12, 47,  4 }, {     -1,  101,   -4, 12, 47,  4 }, {      0,  102,   -4, 12, 47,  4 },
    {      1,  103,   -4, 13, 47,  4 }, {      2,  103,   -4, 13, 47,  4 }, {      3,  104,   -4, 13, 47,  4 }, {      4,  105,   -4, 13, 47,  4 }, {      5,  105,   -4, 13, 47,  4 },
    {      6,  106,   -5, 13, 47,  4 }, {      7,  106,   -5, 13, 47,  4 }, {      8,  107,   -5, 13, 47,  4 }, {      9,  107,   -5, 13, 47,  4 }, {     10,  108,   -5, 14, 47,  4 },
    {     11,  108,   -5, 14, 47,  4 }, {     12,  109,   -5, 14, 47,  4 }, {     13,  109,   -5, 14, 47,  4 }, {     14,  109,   -6, 14, 47,  4 }, {     15,  110,   -6, 14, 47,  4 },
    {     16,  110,   -6, 14, 47,  4 }, {     17,  110,   -6, 14, 47,  4 }, {     18,  111,   -6, 14, 47,  4 }, {     19,  111,   -6, 14, 47,  4 }, {     20,  111,   -6, 15, 47,  4 },
    {     21,  111,   -6, 15, 47,  4 }, {     22,  111,   -6, 15, 47,  4 }, {     23,  111,   -7, 15, 47,  4 }, {     24,  112,   -7, 15, 47,  4 }, {     25,  112,   -7, 15, 47,  4 },
    {     26,  112,   -7, 15, 47,  4 }, {     27,  112,   -7, 15, 47,  4 }, {     28,  112,   -7, 16, 47,  4 }, {     29,  112,   -7, 16, 47,  4 }, {     30,  112,   -7, 16, 47,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FCABB, {
    {     16,    0,    8,  8, 47,  4 }, {     16,    1,    8,  8, 47,  4 }, {     16,    2,    8,  8, 47,  4 }, {     16,    3,    8,  8, 47,  4 }, {     16,    4,    8,  8, 47,  4 },
    {     16,    5,    8,  9, 47,  4 }, {     16,    6,    8,  9, 47,  4 }, {     17,    7,    8,  9, 47,  4 }, {     17,    8,    8,  9, 47,  4 }, {     17,    9,    7,  9, 47,  4 },
    {     17,   10,    7,  9, 47,  4 }, {     17,   11,    7,  9, 47,  4 }, {     17,   12,    7,  9, 47,  4 }, {     18,   13,    7,  9, 47,  4 }, {     18,   14,    7, 10, 47,  4 },
    {     18,   15,    7, 10, 47,  4 }, {     19,   16,    7, 10, 47,  4 }, {     19,   17,    6, 10, 47,  4 }, {     19,   18,    6, 10, 47,  4 }, {     20,   19,    6, 10, 47,  4 },
    {     20,   20,    6, 10, 47,  4 }, {     21,   21,    6, 10, 47,  4 }, {     21,   22,    6, 10, 47,  4 }, {     22,   23,    6, 10, 47,  4 }, {     22,   24,    6, 11, 47,  4 },
    {     23,   25,    6, 11, 47,  4 }, {     23,   26,    5, 11, 47,  4 }, {     24,   27,    5, 11, 47,  4 }, {     25,   28,    5, 11, 47,  4 }, {     25,   29,    5, 11, 47,  4 },
    {     26,   30,    5, 11, 47,  4 }, {     27,   31,    5, 11, 47,  4 }, {     28,   32,    5, 11, 47,  4 }, {     29,   33,    5, 12, 47,  4 }, {     29,   35,    4, 12, 47,  4 },
    {     30,   36,    4, 12, 47,  4 }, {     31,   37,    4, 12, 47,  4 }, {     32,   38,    4, 12, 47,  4 }, {     33,   39,    4, 13, 47,  4 }, {     34,   39,    4, 13, 47,  4 },
    {     35,   40,    4, 13, 47,  4 }, {     36,   41,    4, 13, 47,  4 }, {     37,   41,    4, 13, 47,  4 }, {     38,   42,    3, 13, 47,  4 }, {     39,   42,    3, 13, 47,  4 },
    {     40,   43,    3, 13, 47,  4 }, {     41,   43,    3, 13, 47,  4 }, {     42,   44,    3, 14, 47,  4 }, {     43,   44,    3, 14, 47,  4 }, {     44,   45,    3, 14, 47,  4 },
    {     45,   45,    3, 14, 47,  4 }, {     46,   45,    2, 14, 47,  4 }, {     47,   46,    2, 14, 47,  4 }, {     48,   46,    2, 14, 47,  4 }, {     49,   46,    2, 14, 47,  4 },
    {     50,   47,    2, 14, 47,  4 }, {     51,   47,    2, 14, 47,  4 }, {     52,   47,    2, 15, 47,  4 }, {     53,   47,    2, 15, 47,  4 }, {     54,   47,    2, 15, 47,  4 },
    {     55,   47,    1, 15, 47,  4 }, {     56,   48,    1, 15, 47,  4 }, {     57,   48,    1, 15, 47,  4 }, {     58,   48,    1, 15, 47,  4 }, {     59,   48,    1, 15, 47,  4 },
    {     60,   48,    1, 16, 47,  4 }, {     61,   48,    1, 16, 47,  4 }, {     62,   48,    1, 16, 47,  4 }, {     64,   48,    0, 16, 47,  4 }, {     65,   48,    0, 16, 47,  4 },
    {     66,   48,    0, 16, 47,  4 }, {     67,   48,    0, 16, 47,  4 }, {     68,   48,    0, 16, 47,  4 }, {     69,   48,    0, 17, 47,  4 }, {     70,   48,    0, 17, 47,  4 },
    {     71,   47,    0, 17, 47,  4 }, {     72,   47,    0, 17, 47,  4 }, {     73,   47,   -1, 17, 47,  4 }, {     74,   47,   -1, 17, 47,  4 }, {     75,   47,   -1, 17, 47,  4 },
    {     76,   47,   -1, 17, 47,  4 }, {     77,   46,   -1, 17, 47,  4 }, {     78,   46,   -1, 18, 47,  4 }, {     79,   46,   -1, 18, 47,  4 }, {     80,   45,   -1, 18, 47,  4 },
    {     81,   45,   -1, 18, 47,  4 }, {     82,   45,   -2, 18, 47,  4 }, {     83,   44,   -2, 18, 47,  4 }, {     84,   44,   -2, 18, 47,  4 }, {     85,   43,   -2, 18, 47,  4 },
    {     86,   43,   -2, 18, 47,  4 }, {     87,   42,   -2, 18, 47,  4 }, {     88,   42,   -2, 19, 47,  4 }, {     89,   41,   -2, 19, 47,  4 }, {     90,   41,   -3, 19, 47,  4 },
    {     91,   40,   -3, 19, 47,  4 }, {     92,   39,   -3, 19, 47,  4 }, {     93,   39,   -3, 19, 47,  4 }, {     94,   38,   -3, 19, 47,  4 }, {     95,   37,   -3, 19, 47,  4 },
    {     96,   36,   -3, 19, 47,  4 }, {     97,   35,   -3, 20, 47,  4 }, {     99,   35,   -3, 20, 47,  4 }, {    100,   34,   -4, 20, 47,  4 }, {    101,   33,   -4, 20, 47,  4 },
    {    102,   32,   -4, 20, 47,  4 }, {    103,   31,   -4, 21, 47,  4 }, {    103,   30,   -4, 21, 47,  4 }, {    104,   29,   -4, 21, 47,  4 }, {    105,   28,   -4, 21, 47,  4 },
    {    105,   27,   -4, 21, 47,  4 }, {    106,   26,   -4, 21, 47,  4 }, {    106,   25,   -5, 21, 47,  4 }, {    107,   24,   -5, 21, 47,  4 }, {    107,   23,   -5, 21, 47,  4 },
    {    108,   22,   -5, 22, 47,  4 }, {    108,   21,   -5, 22, 47,  4 }, {    109,   20,   -5, 22, 47,  4 }, {    109,   19,   -5, 22, 47,  4 }, {    109,   18,   -5, 22, 47,  4 },
    {    110,   17,   -6, 22, 47,  4 }, {    110,   16,   -6, 22, 47,  4 }, {    110,   15,   -6, 22, 47,  4 }, {    111,   14,   -6, 22, 47,  4 }, {    111,   13,   -6, 22, 47,  4 },
    {    111,   12,   -6, 23, 47,  4 }, {    111,   11,   -6, 23, 47,  4 }, {    111,   10,   -6, 23, 47,  4 }, {    111,    9,   -6, 23, 47,  4 }, {    112,    8,   -7, 23, 47,  4 },
    {    112,    7,   -7, 23, 47,  4 }, {    112,    6,   -7, 23, 47,  4 }, {    112,    5,   -7, 23, 47,  4 }, {    112,    4,   -7, 24, 47,  4 }, {    112,    3,   -7, 24, 47,  4 },
    {    112,    2,   -7, 24, 47,  4 }, {    112,    1,   -7, 24, 47,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FCF8E, {
    {      0,   16,    8, 16, 47,  4 }, {      1,   16,    8, 16, 47,  4 }, {      2,   16,    8, 16, 47,  4 }, {      3,   16,    8, 16, 47,  4 }, {      4,   16,    8, 16, 47,  4 },
    {      5,   16,    8, 17, 47,  4 }, {      6,   16,    8, 17, 47,  4 }, {      7,   15,    8, 17, 47,  4 }, {      8,   15,    8, 17, 47,  4 }, {      9,   15,    7, 17, 47,  4 },
    {     10,   15,    7, 17, 47,  4 }, {     11,   15,    7, 17, 47,  4 }, {     12,   15,    7, 17, 47,  4 }, {     13,   14,    7, 17, 47,  4 }, {     14,   14,    7, 18, 47,  4 },
    {     15,   14,    7, 18, 47,  4 }, {     16,   13,    7, 18, 47,  4 }, {     17,   13,    7, 18, 47,  4 }, {     18,   13,    6, 18, 47,  4 }, {     19,   12,    6, 18, 47,  4 },
    {     20,   12,    6, 18, 47,  4 }, {     21,   11,    6, 18, 47,  4 }, {     22,   11,    6, 18, 47,  4 }, {     23,   10,    6, 18, 47,  4 }, {     24,   10,    6, 19, 47,  4 },
    {     25,    9,    6, 19, 47,  4 }, {     26,    9,    5, 19, 47,  4 }, {     27,    8,    5, 19, 47,  4 }, {     28,    7,    5, 19, 47,  4 }, {     29,    7,    5, 19, 47,  4 },
    {     30,    6,    5, 19, 47,  4 }, {     31,    5,    5, 19, 47,  4 }, {     32,    4,    5, 19, 47,  4 }, {     33,    3,    5, 20, 47,  4 }, {     35,    3,    5, 20, 47,  4 },
    {     36,    2,    4, 20, 47,  4 }, {     37,    1,    4, 20, 47,  4 }, {     38,    0,    4, 20, 47,  4 }, {     39,   -1,    4, 21, 47,  4 }, {     39,   -2,    4, 21, 47,  4 },
    {     40,   -3,    4, 21, 47,  4 }, {     41,   -4,    4, 21, 47,  4 }, {     41,   -5,    4, 21, 47,  4 }, {     42,   -6,    4, 21, 47,  4 }, {     42,   -7,    3, 21, 47,  4 },
    {     43,   -8,    3, 21, 47,  4 }, {     43,   -9,    3, 21, 47,  4 }, {     44,  -10,    3, 22, 47,  4 }, {     44,  -11,    3, 22, 47,  4 }, {     45,  -12,    3, 22, 47,  4 },
    {     45,  -13,    3, 22, 47,  4 }, {     45,  -14,    3, 22, 47,  4 }, {     46,  -15,    2, 22, 47,  4 }, {     46,  -16,    2, 22, 47,  4 }, {     46,  -17,    2, 22, 47,  4 },
    {     47,  -18,    2, 22, 47,  4 }, {     47,  -19,    2, 22, 47,  4 }, {     47,  -20,    2, 23, 47,  4 }, {     47,  -21,    2, 23, 47,  4 }, {     47,  -22,    2, 23, 47,  4 },
    {     47,  -23,    2, 23, 47,  4 }, {     48,  -24,    1, 23, 47,  4 }, {     48,  -25,    1, 23, 47,  4 }, {     48,  -26,    1, 23, 47,  4 }, {     48,  -27,    1, 23, 47,  4 },
    {     48,  -28,    1, 24, 47,  4 }, {     48,  -29,    1, 24, 47,  4 }, {     48,  -30,    1, 24, 47,  4 }, {     48,  -31,    1, 24, 47,  4 }, {     48,  -33,    0, 24, 47,  4 },
    {     48,  -34,    0, 24, 47,  4 }, {     48,  -35,    0, 24, 47,  4 }, {     48,  -36,    0, 24, 47,  4 }, {     48,  -37,    0, 25, 47,  4 }, {     48,  -38,    0, 25, 47,  4 },
    {     47,  -39,    0, 25, 47,  4 }, {     47,  -40,    0, 25, 47,  4 }, {     47,  -41,   -1, 25, 47,  4 }, {     47,  -42,   -1, 25, 47,  4 }, {     47,  -43,   -1, 25, 47,  4 },
    {     47,  -44,   -1, 25, 47,  4 }, {     46,  -45,   -1, 25, 47,  4 }, {     46,  -46,   -1, 26, 47,  4 }, {     46,  -47,   -1, 26, 47,  4 }, {     45,  -48,   -1, 26, 47,  4 },
    {     45,  -49,   -2, 26, 47,  4 }, {     45,  -50,   -2, 26, 47,  4 }, {     44,  -51,   -2, 26, 47,  4 }, {     44,  -52,   -2, 26, 47,  4 }, {     43,  -53,   -2, 26, 47,  4 },
    {     43,  -54,   -2, 26, 47,  4 }, {     42,  -55,   -2, 26, 47,  4 }, {     42,  -56,   -2, 27, 47,  4 }, {     41,  -57,   -2, 27, 47,  4 }, {     41,  -58,   -3, 27, 47,  4 },
    {     40,  -59,   -3, 27, 47,  4 }, {     39,  -60,   -3, 27, 47,  4 }, {     39,  -61,   -3, 27, 47,  4 }, {     38,  -62,   -3, 27, 47,  4 }, {     37,  -63,   -3, 27, 47,  4 },
    {     36,  -64,   -3, 27, 47,  4 }, {     35,  -65,   -3, 28, 47,  4 }, {     35,  -67,   -4, 28, 47,  4 }, {     34,  -68,   -4, 28, 47,  4 }, {     33,  -69,   -4, 28, 47,  4 },
    {     32,  -70,   -4, 28, 47,  4 }, {     31,  -71,   -4, 29, 47,  4 }, {     30,  -71,   -4, 29, 47,  4 }, {     29,  -72,   -4, 29, 47,  4 }, {     28,  -73,   -4, 29, 47,  4 },
    {     27,  -73,   -4, 29, 47,  4 }, {     26,  -74,   -5, 29, 47,  4 }, {     25,  -74,   -5, 29, 47,  4 }, {     24,  -75,   -5, 29, 47,  4 }, {     23,  -75,   -5, 29, 47,  4 },
    {     22,  -76,   -5, 30, 47,  4 }, {     21,  -76,   -5, 30, 47,  4 }, {     20,  -77,   -5, 30, 47,  4 }, {     19,  -77,   -5, 30, 47,  4 }, {     18,  -77,   -6, 30, 47,  4 },
    {     17,  -78,   -6, 30, 47,  4 }, {     16,  -78,   -6, 30, 47,  4 }, {     15,  -78,   -6, 30, 47,  4 }, {     14,  -79,   -6, 30, 47,  4 }, {     13,  -79,   -6, 30, 47,  4 },
    {     12,  -79,   -6, 31, 47,  4 }, {     11,  -79,   -6, 31, 47,  4 }, {     10,  -79,   -6, 31, 47,  4 }, {      9,  -79,   -7, 31, 47,  4 }, {      8,  -80,   -7, 31, 47,  4 },
    {      7,  -80,   -7, 31, 47,  4 }, {      6,  -80,   -7, 31, 47,  4 }, {      5,  -80,   -7, 31, 47,  4 }, {      4,  -80,   -7,  0, 47,  4 }, {      3,  -80,   -7,  0, 47,  4 },
    {      2,  -80,   -7,  0, 47,  4 }, {      1,  -80,   -8,  0, 47,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FD461, {
    {     16,   31,    8, 24, 47,  4 }, {     16,   30,    8, 24, 47,  4 }, {     16,   29,    8, 24, 47,  4 }, {     16,   28,    8, 24, 47,  4 }, {     16,   27,    8, 25, 47,  4 },
    {     16,   26,    8, 25, 47,  4 }, {     15,   25,    8, 25, 47,  4 }, {     15,   24,    8, 25, 47,  4 }, {     15,   23,    7, 25, 47,  4 }, {     15,   22,    7, 25, 47,  4 },
    {     15,   21,    7, 25, 47,  4 }, {     15,   20,    7, 25, 47,  4 }, {     14,   19,    7, 25, 47,  4 }, {     14,   18,    7, 26, 47,  4 }, {     14,   17,    7, 26, 47,  4 },
    {     13,   16,    7, 26, 47,  4 }, {     13,   15,    6, 26, 47,  4 }, {     13,   14,    6, 26, 47,  4 }, {     12,   13,    6, 26, 47,  4 }, {     12,   12,    6, 26, 47,  4 },
    {     11,   11,    6, 26, 47,  4 }, {     11,   10,    6, 26, 47,  4 }, {     10,    9,    6, 26, 47,  4 }, {     10,    8,    6, 27, 47,  4 }, {      9,    7,    6, 27, 47,  4 },
    {      9,    6,    5, 27, 47,  4 }, {      8,    5,    5, 27, 47,  4 }, {      7,    4,    5, 27, 47,  4 }, {      7,    3,    5, 27, 47,  4 }, {      6,    2,    5, 27, 47,  4 },
    {      5,    1,    5, 27, 47,  4 }, {      4,    0,    5, 27, 47,  4 }, {      3,   -1,    5, 28, 47,  4 }, {      3,   -3,    4, 28, 47,  4 }, {      2,   -4,    4, 28, 47,  4 },
    {      1,   -5,    4, 28, 47,  4 }, {      0,   -6,    4, 28, 47,  4 }, {     -1,   -7,    4, 29, 47,  4 }, {     -2,   -7,    4, 29, 47,  4 }, {     -3,   -8,    4, 29, 47,  4 },
    {     -4,   -9,    4, 29, 47,  4 }, {     -5,   -9,    4, 29, 47,  4 }, {     -6,  -10,    3, 29, 47,  4 }, {     -7,  -10,    3, 29, 47,  4 }, {     -8,  -11,    3, 29, 47,  4 },
    {     -9,  -11,    3, 29, 47,  4 }, {    -10,  -12,    3, 30, 47,  4 }, {    -11,  -12,    3, 30, 47,  4 }, {    -12,  -13,    3, 30, 47,  4 }, {    -13,  -13,    3, 30, 47,  4 },
    {    -14,  -13,    2, 30, 47,  4 }, {    -15,  -14,    2, 30, 47,  4 }, {    -16,  -14,    2, 30, 47,  4 }, {    -17,  -14,    2, 30, 47,  4 }, {    -18,  -15,    2, 30, 47,  4 },
    {    -19,  -15,    2, 30, 47,  4 }, {    -20,  -15,    2, 31, 47,  4 }, {    -21,  -15,    2, 31, 47,  4 }, {    -22,  -15,    2, 31, 47,  4 }, {    -23,  -15,    1, 31, 47,  4 },
    {    -24,  -16,    1, 31, 47,  4 }, {    -25,  -16,    1, 31, 47,  4 }, {    -26,  -16,    1, 31, 47,  4 }, {    -27,  -16,    1, 31, 47,  4 }, {    -28,  -16,    1,  0, 47,  4 },
    {    -29,  -16,    1,  0, 47,  4 }, {    -30,  -16,    1,  0, 47,  4 }, {    -31,  -16,    0,  0, 47,  4 }, {    -33,  -16,    0,  0, 47,  4 }, {    -34,  -16,    0,  0, 47,  4 },
    {    -35,  -16,    0,  0, 47,  4 }, {    -36,  -16,    0,  0, 47,  4 }, {    -37,  -16,    0,  1, 47,  4 }, {    -38,  -16,    0,  1, 47,  4 }, {    -39,  -15,    0,  1, 47,  4 },
    {    -40,  -15,    0,  1, 47,  4 }, {    -41,  -15,   -1,  1, 47,  4 }, {    -42,  -15,   -1,  1, 47,  4 }, {    -43,  -15,   -1,  1, 47,  4 }, {    -44,  -15,   -1,  1, 47,  4 },
    {    -45,  -14,   -1,  1, 47,  4 }, {    -46,  -14,   -1,  2, 47,  4 }, {    -47,  -14,   -1,  2, 47,  4 }, {    -48,  -13,   -1,  2, 47,  4 }, {    -49,  -13,   -2,  2, 47,  4 },
    {    -50,  -13,   -2,  2, 47,  4 }, {    -51,  -12,   -2,  2, 47,  4 }, {    -52,  -12,   -2,  2, 47,  4 }, {    -53,  -11,   -2,  2, 47,  4 }, {    -54,  -11,   -2,  2, 47,  4 },
    {    -55,  -10,   -2,  2, 47,  4 }, {    -56,  -10,   -2,  3, 47,  4 }, {    -57,   -9,   -2,  3, 47,  4 }, {    -58,   -9,   -3,  3, 47,  4 }, {    -59,   -8,   -3,  3, 47,  4 },
    {    -60,   -7,   -3,  3, 47,  4 }, {    -61,   -7,   -3,  3, 47,  4 }, {    -62,   -6,   -3,  3, 47,  4 }, {    -63,   -5,   -3,  3, 47,  4 }, {    -64,   -4,   -3,  3, 47,  4 },
    {    -65,   -3,   -3,  4, 47,  4 }, {    -67,   -3,   -4,  4, 47,  4 }, {    -68,   -2,   -4,  4, 47,  4 }, {    -69,   -1,   -4,  4, 47,  4 }, {    -70,    0,   -4,  4, 47,  4 },
    {    -71,    1,   -4,  5, 47,  4 }, {    -71,    2,   -4,  5, 47,  4 }, {    -72,    3,   -4,  5, 47,  4 }, {    -73,    4,   -4,  5, 47,  4 }, {    -73,    5,   -5,  5, 47,  4 },
    {    -74,    6,   -5,  5, 47,  4 }, {    -74,    7,   -5,  5, 47,  4 }, {    -75,    8,   -5,  5, 47,  4 }, {    -75,    9,   -5,  5, 47,  4 }, {    -76,   10,   -5,  6, 47,  4 },
    {    -76,   11,   -5,  6, 47,  4 }, {    -77,   12,   -5,  6, 47,  4 }, {    -77,   13,   -5,  6, 47,  4 }, {    -77,   14,   -6,  6, 47,  4 }, {    -78,   15,   -6,  6, 47,  4 },
    {    -78,   16,   -6,  6, 47,  4 }, {    -78,   17,   -6,  6, 47,  4 }, {    -79,   18,   -6,  6, 47,  4 }, {    -79,   19,   -6,  6, 47,  4 }, {    -79,   20,   -6,  7, 47,  4 },
    {    -79,   21,   -6,  7, 47,  4 }, {    -79,   22,   -7,  7, 47,  4 }, {    -79,   23,   -7,  7, 47,  4 }, {    -80,   24,   -7,  7, 47,  4 }, {    -80,   25,   -7,  7, 47,  4 },
    {    -80,   26,   -7,  7, 47,  4 }, {    -80,   27,   -7,  7, 47,  4 }, {    -80,   28,   -7,  8, 47,  4 }, {    -80,   29,   -7,  8, 47,  4 }, {    -80,   30,   -8,  8, 47,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F0C22, {
    {     31,   16,    0,  0, 44,  2 }, {     30,   16,    0,  0, 44,  2 }, {     29,   16,    0,  0, 44,  2 }, {     28,   16,    0,  0, 44,  2 }, {     27,   16,    0,  0, 44,  2 },
    {     26,   16,    0,  0, 44,  2 }, {     25,   16,    0,  0, 44,  2 }, {     24,   16,    0, 31, 44,  2 }, {     23,   15,    0, 31, 44,  2 }, {     22,   15,    0, 31, 44,  2 },
    {     21,   15,    0, 31, 44,  2 }, {     20,   15,    0, 31, 44,  2 }, {     19,   15,    0, 31, 44,  2 }, {     18,   15,    0, 31, 44,  2 }, {     17,   14,    1, 31, 44,  2 },
    {     16,   14,    1, 31, 44,  2 }, {     15,   14,    1, 31, 44,  2 }, {     14,   14,    1, 31, 44,  2 }, {     13,   14,    1, 31, 44,  2 }, {     12,   13,    1, 31, 44,  2 },
    {     11,   13,    1, 31, 44,  2 }, {     10,   13,    1, 30, 44,  2 }, {      9,   13,    1, 30, 44,  2 }, {      8,   12,    1, 30, 44,  2 }, {      7,   12,    1, 30, 44,  2 },
    {      6,   12,    1, 30, 44,  2 }, {      5,   11,    1, 30, 44,  2 }, {      4,   11,    1, 30, 44,  2 }, {      3,   11,    2, 30, 44,  2 }, {      2,   10,    2, 30, 44,  2 },
    {      1,   10,    2, 30, 44,  2 }, {      0,    9,    2, 30, 44,  2 }, {     -1,    9,    2, 30, 44,  2 }, {     -2,    8,    2, 30, 44,  2 }, {     -3,    8,    2, 30, 44,  2 },
    {     -4,    7,    2, 30, 44,  2 }, {     -5,    7,    2, 29, 44,  2 }, {     -6,    6,    2, 29, 44,  2 }, {     -7,    6,    2, 29, 44,  2 }, {     -8,    5,    2, 29, 44,  2 },
    {     -9,    4,    2, 29, 44,  2 }, {    -10,    4,    2, 29, 44,  2 }, {    -11,    3,    3, 29, 44,  2 }, {    -12,    2,    3, 29, 44,  2 }, {    -13,    2,    3, 29, 44,  2 },
    {    -14,    1,    3, 29, 44,  2 }, {    -15,    0,    3, 29, 44,  2 }, {    -16,    0,    3, 29, 44,  2 }, {    -17,   -1,    3, 29, 44,  2 }, {    -18,   -2,    3, 28, 44,  2 },
    {    -19,   -3,    3, 28, 44,  2 }, {    -20,   -3,    3, 28, 44,  2 }, {    -21,   -4,    3, 28, 44,  2 }, {    -22,   -5,    3, 28, 44,  2 }, {    -23,   -6,    3, 28, 44,  2 },
    {    -24,   -7,    3, 28, 44,  2 }, {    -25,   -7,    4, 28, 44,  2 }, {    -26,   -8,    4, 28, 44,  2 }, {    -27,   -9,    4, 28, 44,  2 }, {    -28,  -10,    4, 28, 44,  2 },
    {    -29,  -11,    4, 28, 44,  2 }, {    -29,  -12,    4, 28, 44,  2 }, {    -30,  -13,    4, 27, 44,  2 }, {    -31,  -14,    4, 27, 44,  2 }, {    -32,  -15,    4, 27, 44,  2 },
    {    -32,  -16,    4, 27, 44,  2 }, {    -33,  -17,    4, 27, 44,  2 }, {    -34,  -18,    4, 27, 44,  2 }, {    -34,  -19,    4, 27, 44,  2 }, {    -35,  -20,    4, 27, 44,  2 },
    {    -36,  -21,    4, 27, 44,  2 }, {    -36,  -22,    5, 27, 44,  2 }, {    -37,  -23,    5, 27, 44,  2 }, {    -38,  -24,    5, 27, 44,  2 }, {    -38,  -25,    5, 27, 44,  2 },
    {    -39,  -26,    5, 26, 44,  2 }, {    -39,  -27,    5, 26, 44,  2 }, {    -40,  -28,    5, 26, 44,  2 }, {    -40,  -29,    5, 26, 44,  2 }, {    -41,  -30,    5, 26, 44,  2 },
    {    -41,  -31,    5, 26, 44,  2 }, {    -42,  -32,    5, 26, 44,  2 }, {    -42,  -33,    5, 26, 44,  2 }, {    -43,  -34,    5, 26, 44,  2 }, {    -43,  -35,    5, 26, 44,  2 },
    {    -43,  -36,    6, 26, 44,  2 }, {    -44,  -37,    6, 26, 44,  2 }, {    -44,  -38,    6, 26, 44,  2 }, {    -44,  -39,    6, 26, 44,  2 }, {    -45,  -40,    6, 25, 44,  2 },
    {    -45,  -41,    6, 25, 44,  2 }, {    -45,  -42,    6, 25, 44,  2 }, {    -45,  -43,    6, 25, 44,  2 }, {    -46,  -44,    6, 25, 44,  2 }, {    -46,  -45,    6, 25, 44,  2 },
    {    -46,  -46,    6, 25, 44,  2 }, {    -46,  -47,    6, 25, 44,  2 }, {    -46,  -48,    6, 25, 44,  2 }, {    -47,  -49,    6, 25, 44,  2 }, {    -47,  -50,    7, 25, 44,  2 },
    {    -47,  -51,    7, 25, 44,  2 }, {    -47,  -52,    7, 25, 44,  2 }, {    -47,  -53,    7, 25, 44,  2 }, {    -47,  -54,    7, 25, 44,  2 }, {    -48,  -55,    7, 25, 44,  2 },
    {    -48,  -56,    7, 24, 44,  2 }, {    -48,  -57,    7, 24, 44,  2 }, {    -48,  -58,    7, 24, 44,  2 }, {    -48,  -59,    7, 24, 44,  2 }, {    -48,  -60,    7, 24, 44,  2 },
    {    -48,  -61,    7, 24, 44,  2 }, {    -48,  -62,    7, 24, 44,  2 }, {    -48,  -63,    7, 24, 44,  2 }, {    -48,  -64,    8, 24, 44,  2 }, {    -48,  -65,    8, 24, 44,  2 },
    {    -48,  -66,    8, 24, 44,  2 }, {    -48,  -67,    8, 24, 44,  2 }, {    -48,  -68,    8, 24, 44,  2 }, {    -48,  -69,    8, 24, 44,  2 }, {    -48,  -70,    8, 24, 44,  2 },
    {    -48,  -71,    8, 24, 44,  2 }, {    -48,  -72,    8, 23, 44,  2 }, {    -47,  -73,    8, 23, 44,  2 }, {    -47,  -74,    8, 23, 44,  2 }, {    -47,  -75,    8, 23, 44,  2 },
    {    -47,  -76,    8, 23, 44,  2 }, {    -47,  -77,    8, 23, 44,  2 }, {    -47,  -78,    8, 23, 44,  2 }, {    -46,  -79,    9, 23, 44,  2 }, {    -46,  -80,    9, 23, 44,  2 },
    {    -46,  -81,    9, 23, 44,  2 }, {    -46,  -82,    9, 23, 44,  2 }, {    -46,  -83,    9, 23, 44,  2 }, {    -45,  -84,    9, 23, 44,  2 }, {    -45,  -85,    9, 23, 44,  2 },
    {    -45,  -86,    9, 22, 44,  2 }, {    -45,  -87,    9, 22, 44,  2 }, {    -44,  -88,    9, 22, 44,  2 }, {    -44,  -89,    9, 22, 44,  2 }, {    -44,  -90,    9, 22, 44,  2 },
    {    -43,  -91,    9, 22, 44,  2 }, {    -43,  -92,    9, 22, 44,  2 }, {    -43,  -93,   10, 22, 44,  2 }, {    -42,  -94,   10, 22, 44,  2 }, {    -42,  -95,   10, 22, 44,  2 },
    {    -41,  -96,   10, 22, 44,  2 }, {    -41,  -97,   10, 22, 44,  2 }, {    -40,  -98,   10, 22, 44,  2 }, {    -40,  -99,   10, 22, 44,  2 }, {    -39, -100,   10, 22, 44,  2 },
    {    -39, -101,   10, 21, 44,  2 }, {    -38, -102,   10, 21, 44,  2 }, {    -38, -103,   10, 21, 44,  2 }, {    -37, -104,   10, 21, 44,  2 }, {    -36, -105,   10, 21, 44,  2 },
    {    -36, -106,   10, 21, 44,  2 }, {    -35, -107,   11, 21, 44,  2 }, {    -34, -108,   11, 21, 44,  2 }, {    -34, -109,   11, 21, 44,  2 }, {    -33, -110,   11, 21, 44,  2 },
    {    -32, -111,   11, 21, 44,  2 }, {    -32, -112,   11, 21, 44,  2 }, {    -31, -113,   11, 21, 44,  2 }, {    -30, -114,   11, 20, 44,  2 }, {    -29, -115,   11, 20, 44,  2 },
    {    -29, -116,   11, 20, 44,  2 }, {    -28, -117,   11, 20, 44,  2 }, {    -27, -118,   11, 20, 44,  2 }, {    -26, -119,   11, 20, 44,  2 }, {    -25, -120,   11, 20, 44,  2 },
    {    -25, -121,   12, 20, 44,  2 }, {    -24, -122,   12, 20, 44,  2 }, {    -23, -123,   12, 20, 44,  2 }, {    -22, -124,   12, 20, 44,  2 }, {    -21, -125,   12, 20, 44,  2 },
    {    -20, -125,   12, 20, 44,  2 }, {    -19, -126,   12, 19, 44,  2 }, {    -18, -127,   12, 19, 44,  2 }, {    -17, -128,   12, 19, 44,  2 }, {    -16, -128,   12, 19, 44,  2 },
    {    -15, -129,   12, 19, 44,  2 }, {    -14, -130,   12, 19, 44,  2 }, {    -13, -130,   12, 19, 44,  2 }, {    -12, -131,   12, 19, 44,  2 }, {    -11, -132,   13, 19, 44,  2 },
    {    -10, -132,   13, 19, 44,  2 }, {     -9, -133,   13, 19, 44,  2 }, {     -8, -134,   13, 19, 44,  2 }, {     -7, -134,   13, 19, 44,  2 }, {     -6, -135,   13, 18, 44,  2 },
    {     -5, -135,   13, 18, 44,  2 }, {     -4, -136,   13, 18, 44,  2 }, {     -3, -136,   13, 18, 44,  2 }, {     -2, -137,   13, 18, 44,  2 }, {     -1, -137,   13, 18, 44,  2 },
    {      0, -138,   13, 18, 44,  2 }, {      1, -138,   13, 18, 44,  2 }, {      2, -139,   13, 18, 44,  2 }, {      3, -139,   14, 18, 44,  2 }, {      4, -139,   14, 18, 44,  2 },
    {      5, -140,   14, 18, 44,  2 }, {      6, -140,   14, 18, 44,  2 }, {      7, -140,   14, 18, 44,  2 }, {      8, -141,   14, 17, 44,  2 }, {      9, -141,   14, 17, 44,  2 },
    {     10, -141,   14, 17, 44,  2 }, {     11, -141,   14, 17, 44,  2 }, {     12, -142,   14, 17, 44,  2 }, {     13, -142,   14, 17, 44,  2 }, {     14, -142,   14, 17, 44,  2 },
    {     15, -142,   14, 17, 44,  2 }, {     16, -142,   14, 17, 44,  2 }, {     17, -143,   15, 17, 44,  2 }, {     18, -143,   15, 17, 44,  2 }, {     19, -143,   15, 17, 44,  2 },
    {     20, -143,   15, 17, 44,  2 }, {     21, -143,   15, 17, 44,  2 }, {     22, -143,   15, 17, 44,  2 }, {     23, -144,   15, 17, 44,  2 }, {     24, -144,   15, 16, 44,  2 },
    {     25, -144,   15, 16, 44,  2 }, {     26, -144,   15, 16, 44,  2 }, {     27, -144,   15, 16, 44,  2 }, {     28, -144,   15, 16, 44,  2 }, {     29, -144,   15, 16, 44,  2 },
    {     30, -144,   15, 16, 44,  2 }, {     31, -144,   16, 16, 44,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F141F, {
    {     16,    0,    0,  8, 44,  2 }, {     16,    1,    0,  8, 44,  2 }, {     16,    2,    0,  8, 44,  2 }, {     16,    3,    0,  8, 44,  2 }, {     16,    4,    0,  8, 44,  2 },
    {     16,    5,    0,  8, 44,  2 }, {     16,    6,    0,  8, 44,  2 }, {     16,    7,    0,  8, 44,  2 }, {     16,    8,    0,  7, 44,  2 }, {     15,    9,    0,  7, 44,  2 },
    {     15,   10,    0,  7, 44,  2 }, {     15,   11,    0,  7, 44,  2 }, {     15,   12,    0,  7, 44,  2 }, {     15,   13,    0,  7, 44,  2 }, {     15,   14,    0,  7, 44,  2 },
    {     14,   15,    1,  7, 44,  2 }, {     14,   16,    1,  7, 44,  2 }, {     14,   17,    1,  7, 44,  2 }, {     14,   18,    1,  7, 44,  2 }, {     14,   19,    1,  7, 44,  2 },
    {     13,   20,    1,  7, 44,  2 }, {     13,   21,    1,  7, 44,  2 }, {     13,   22,    1,  6, 44,  2 }, {     13,   23,    1,  6, 44,  2 }, {     12,   24,    1,  6, 44,  2 },
    {     12,   25,    1,  6, 44,  2 }, {     12,   26,    1,  6, 44,  2 }, {     11,   27,    1,  6, 44,  2 }, {     11,   28,    1,  6, 44,  2 }, {     11,   29,    2,  6, 44,  2 },
    {     10,   30,    2,  6, 44,  2 }, {     10,   31,    2,  6, 44,  2 }, {      9,   32,    2,  6, 44,  2 }, {      9,   33,    2,  6, 44,  2 }, {      8,   34,    2,  6, 44,  2 },
    {      8,   35,    2,  6, 44,  2 }, {      7,   36,    2,  6, 44,  2 }, {      7,   37,    2,  5, 44,  2 }, {      6,   38,    2,  5, 44,  2 }, {      6,   39,    2,  5, 44,  2 },
    {      5,   40,    2,  5, 44,  2 }, {      4,   41,    2,  5, 44,  2 }, {      4,   42,    2,  5, 44,  2 }, {      3,   43,    2,  5, 44,  2 }, {      2,   44,    3,  5, 44,  2 },
    {      2,   45,    3,  5, 44,  2 }, {      1,   46,    3,  5, 44,  2 }, {      0,   47,    3,  5, 44,  2 }, {      0,   48,    3,  5, 44,  2 }, {     -1,   49,    3,  5, 44,  2 },
    {     -2,   50,    3,  4, 44,  2 }, {     -3,   51,    3,  4, 44,  2 }, {     -3,   52,    3,  4, 44,  2 }, {     -4,   53,    3,  4, 44,  2 }, {     -5,   54,    3,  4, 44,  2 },
    {     -6,   55,    3,  4, 44,  2 }, {     -7,   56,    3,  4, 44,  2 }, {     -7,   57,    3,  4, 44,  2 }, {     -8,   58,    4,  4, 44,  2 }, {     -9,   59,    4,  4, 44,  2 },
    {    -10,   60,    4,  4, 44,  2 }, {    -11,   61,    4,  4, 44,  2 }, {    -12,   61,    4,  4, 44,  2 }, {    -13,   62,    4,  3, 44,  2 }, {    -14,   63,    4,  3, 44,  2 },
    {    -15,   64,    4,  3, 44,  2 }, {    -16,   64,    4,  3, 44,  2 }, {    -17,   65,    4,  3, 44,  2 }, {    -18,   66,    4,  3, 44,  2 }, {    -19,   66,    4,  3, 44,  2 },
    {    -20,   67,    4,  3, 44,  2 }, {    -21,   68,    4,  3, 44,  2 }, {    -22,   68,    5,  3, 44,  2 }, {    -23,   69,    5,  3, 44,  2 }, {    -24,   70,    5,  3, 44,  2 },
    {    -25,   70,    5,  3, 44,  2 }, {    -26,   71,    5,  2, 44,  2 }, {    -27,   71,    5,  2, 44,  2 }, {    -28,   72,    5,  2, 44,  2 }, {    -29,   72,    5,  2, 44,  2 },
    {    -30,   73,    5,  2, 44,  2 }, {    -31,   73,    5,  2, 44,  2 }, {    -32,   74,    5,  2, 44,  2 }, {    -33,   74,    5,  2, 44,  2 }, {    -34,   75,    5,  2, 44,  2 },
    {    -35,   75,    5,  2, 44,  2 }, {    -36,   75,    5,  2, 44,  2 }, {    -37,   76,    6,  2, 44,  2 }, {    -38,   76,    6,  2, 44,  2 }, {    -39,   76,    6,  2, 44,  2 },
    {    -40,   77,    6,  1, 44,  2 }, {    -41,   77,    6,  1, 44,  2 }, {    -42,   77,    6,  1, 44,  2 }, {    -43,   77,    6,  1, 44,  2 }, {    -44,   78,    6,  1, 44,  2 },
    {    -45,   78,    6,  1, 44,  2 }, {    -46,   78,    6,  1, 44,  2 }, {    -47,   78,    6,  1, 44,  2 }, {    -48,   78,    6,  1, 44,  2 }, {    -49,   79,    6,  1, 44,  2 },
    {    -50,   79,    6,  1, 44,  2 }, {    -51,   79,    7,  1, 44,  2 }, {    -52,   79,    7,  1, 44,  2 }, {    -53,   79,    7,  1, 44,  2 }, {    -54,   79,    7,  1, 44,  2 },
    {    -55,   80,    7,  1, 44,  2 }, {    -56,   80,    7,  0, 44,  2 }, {    -57,   80,    7,  0, 44,  2 }, {    -58,   80,    7,  0, 44,  2 }, {    -59,   80,    7,  0, 44,  2 },
    {    -60,   80,    7,  0, 44,  2 }, {    -61,   80,    7,  0, 44,  2 }, {    -62,   80,    7,  0, 44,  2 }, {    -63,   80,    7,  0, 44,  2 }, {    -64,   80,    7,  0, 44,  2 },
    {    -65,   80,    8,  0, 44,  2 }, {    -66,   80,    8,  0, 44,  2 }, {    -67,   80,    8,  0, 44,  2 }, {    -68,   80,    8,  0, 44,  2 }, {    -69,   80,    8,  0, 44,  2 },
    {    -70,   80,    8,  0, 44,  2 }, {    -71,   80,    8,  0, 44,  2 }, {    -72,   80,    8, 31, 44,  2 }, {    -73,   79,    8, 31, 44,  2 }, {    -74,   79,    8, 31, 44,  2 },
    {    -75,   79,    8, 31, 44,  2 }, {    -76,   79,    8, 31, 44,  2 }, {    -77,   79,    8, 31, 44,  2 }, {    -78,   79,    8, 31, 44,  2 }, {    -79,   78,    9, 31, 44,  2 },
    {    -80,   78,    9, 31, 44,  2 }, {    -81,   78,    9, 31, 44,  2 }, {    -82,   78,    9, 31, 44,  2 }, {    -83,   78,    9, 31, 44,  2 }, {    -84,   77,    9, 31, 44,  2 },
    {    -85,   77,    9, 31, 44,  2 }, {    -86,   77,    9, 30, 44,  2 }, {    -87,   77,    9, 30, 44,  2 }, {    -88,   76,    9, 30, 44,  2 }, {    -89,   76,    9, 30, 44,  2 },
    {    -90,   76,    9, 30, 44,  2 }, {    -91,   75,    9, 30, 44,  2 }, {    -92,   75,    9, 30, 44,  2 }, {    -93,   75,   10, 30, 44,  2 }, {    -94,   74,   10, 30, 44,  2 },
    {    -95,   74,   10, 30, 44,  2 }, {    -96,   73,   10, 30, 44,  2 }, {    -97,   73,   10, 30, 44,  2 }, {    -98,   72,   10, 30, 44,  2 }, {    -99,   72,   10, 30, 44,  2 },
    {   -100,   71,   10, 30, 44,  2 }, {   -101,   71,   10, 29, 44,  2 }, {   -102,   70,   10, 29, 44,  2 }, {   -103,   70,   10, 29, 44,  2 }, {   -104,   69,   10, 29, 44,  2 },
    {   -105,   68,   10, 29, 44,  2 }, {   -106,   68,   10, 29, 44,  2 }, {   -107,   67,   11, 29, 44,  2 }, {   -108,   66,   11, 29, 44,  2 }, {   -109,   66,   11, 29, 44,  2 },
    {   -110,   65,   11, 29, 44,  2 }, {   -111,   64,   11, 29, 44,  2 }, {   -112,   64,   11, 29, 44,  2 }, {   -113,   63,   11, 29, 44,  2 }, {   -114,   62,   11, 28, 44,  2 },
    {   -115,   61,   11, 28, 44,  2 }, {   -116,   61,   11, 28, 44,  2 }, {   -117,   60,   11, 28, 44,  2 }, {   -118,   59,   11, 28, 44,  2 }, {   -119,   58,   11, 28, 44,  2 },
    {   -120,   57,   11, 28, 44,  2 }, {   -121,   57,   12, 28, 44,  2 }, {   -122,   56,   12, 28, 44,  2 }, {   -123,   55,   12, 28, 44,  2 }, {   -124,   54,   12, 28, 44,  2 },
    {   -125,   53,   12, 28, 44,  2 }, {   -125,   52,   12, 28, 44,  2 }, {   -126,   51,   12, 27, 44,  2 }, {   -127,   50,   12, 27, 44,  2 }, {   -128,   49,   12, 27, 44,  2 },
    {   -128,   48,   12, 27, 44,  2 }, {   -129,   47,   12, 27, 44,  2 }, {   -130,   46,   12, 27, 44,  2 }, {   -130,   45,   12, 27, 44,  2 }, {   -131,   44,   12, 27, 44,  2 },
    {   -132,   43,   12, 27, 44,  2 }, {   -132,   42,   13, 27, 44,  2 }, {   -133,   41,   13, 27, 44,  2 }, {   -134,   40,   13, 27, 44,  2 }, {   -134,   39,   13, 27, 44,  2 },
    {   -135,   38,   13, 26, 44,  2 }, {   -135,   37,   13, 26, 44,  2 }, {   -136,   36,   13, 26, 44,  2 }, {   -136,   35,   13, 26, 44,  2 }, {   -137,   34,   13, 26, 44,  2 },
    {   -137,   33,   13, 26, 44,  2 }, {   -138,   32,   13, 26, 44,  2 }, {   -138,   31,   13, 26, 44,  2 }, {   -139,   30,   13, 26, 44,  2 }, {   -139,   29,   13, 26, 44,  2 },
    {   -139,   28,   14, 26, 44,  2 }, {   -140,   27,   14, 26, 44,  2 }, {   -140,   26,   14, 26, 44,  2 }, {   -140,   25,   14, 26, 44,  2 }, {   -141,   24,   14, 25, 44,  2 },
    {   -141,   23,   14, 25, 44,  2 }, {   -141,   22,   14, 25, 44,  2 }, {   -141,   21,   14, 25, 44,  2 }, {   -142,   20,   14, 25, 44,  2 }, {   -142,   19,   14, 25, 44,  2 },
    {   -142,   18,   14, 25, 44,  2 }, {   -142,   17,   14, 25, 44,  2 }, {   -142,   16,   14, 25, 44,  2 }, {   -143,   15,   14, 25, 44,  2 }, {   -143,   14,   15, 25, 44,  2 },
    {   -143,   13,   15, 25, 44,  2 }, {   -143,   12,   15, 25, 44,  2 }, {   -143,   11,   15, 25, 44,  2 }, {   -143,   10,   15, 25, 44,  2 }, {   -144,    9,   15, 25, 44,  2 },
    {   -144,    8,   15, 24, 44,  2 }, {   -144,    7,   15, 24, 44,  2 }, {   -144,    6,   15, 24, 44,  2 }, {   -144,    5,   15, 24, 44,  2 }, {   -144,    4,   15, 24, 44,  2 },
    {   -144,    3,   15, 24, 44,  2 }, {   -144,    2,   15, 24, 44,  2 }, {   -144,    1,   15, 24, 44,  2 }, {   -144,    0,   16, 24, 44,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F1C2E, {
    {      0,   16,    0, 16, 44,  2 }, {      1,   16,    0, 16, 44,  2 }, {      2,   16,    0, 16, 44,  2 }, {      3,   16,    0, 16, 44,  2 }, {      4,   16,    0, 16, 44,  2 },
    {      5,   16,    0, 16, 44,  2 }, {      6,   16,    0, 16, 44,  2 }, {      7,   16,    0, 16, 44,  2 }, {      8,   16,    0, 15, 44,  2 }, {      9,   17,    0, 15, 44,  2 },
    {     10,   17,    0, 15, 44,  2 }, {     11,   17,    0, 15, 44,  2 }, {     12,   17,    0, 15, 44,  2 }, {     13,   17,    0, 15, 44,  2 }, {     14,   17,    0, 15, 44,  2 },
    {     15,   18,    1, 15, 44,  2 }, {     16,   18,    1, 15, 44,  2 }, {     17,   18,    1, 15, 44,  2 }, {     18,   18,    1, 15, 44,  2 }, {     19,   18,    1, 15, 44,  2 },
    {     20,   19,    1, 15, 44,  2 }, {     21,   19,    1, 15, 44,  2 }, {     22,   19,    1, 14, 44,  2 }, {     23,   19,    1, 14, 44,  2 }, {     24,   20,    1, 14, 44,  2 },
    {     25,   20,    1, 14, 44,  2 }, {     26,   20,    1, 14, 44,  2 }, {     27,   21,    1, 14, 44,  2 }, {     28,   21,    1, 14, 44,  2 }, {     29,   21,    2, 14, 44,  2 },
    {     30,   22,    2, 14, 44,  2 }, {     31,   22,    2, 14, 44,  2 }, {     32,   23,    2, 14, 44,  2 }, {     33,   23,    2, 14, 44,  2 }, {     34,   24,    2, 14, 44,  2 },
    {     35,   24,    2, 14, 44,  2 }, {     36,   25,    2, 14, 44,  2 }, {     37,   25,    2, 13, 44,  2 }, {     38,   26,    2, 13, 44,  2 }, {     39,   26,    2, 13, 44,  2 },
    {     40,   27,    2, 13, 44,  2 }, {     41,   28,    2, 13, 44,  2 }, {     42,   28,    2, 13, 44,  2 }, {     43,   29,    3, 13, 44,  2 }, {     44,   30,    3, 13, 44,  2 },
    {     45,   30,    3, 13, 44,  2 }, {     46,   31,    3, 13, 44,  2 }, {     47,   32,    3, 13, 44,  2 }, {     48,   32,    3, 13, 44,  2 }, {     49,   33,    3, 13, 44,  2 },
    {     50,   34,    3, 12, 44,  2 }, {     51,   35,    3, 12, 44,  2 }, {     52,   35,    3, 12, 44,  2 }, {     53,   36,    3, 12, 44,  2 }, {     54,   37,    3, 12, 44,  2 },
    {     55,   38,    3, 12, 44,  2 }, {     56,   39,    3, 12, 44,  2 }, {     57,   39,    4, 12, 44,  2 }, {     58,   40,    4, 12, 44,  2 }, {     59,   41,    4, 12, 44,  2 },
    {     60,   42,    4, 12, 44,  2 }, {     61,   43,    4, 12, 44,  2 }, {     61,   44,    4, 12, 44,  2 }, {     62,   45,    4, 11, 44,  2 }, {     63,   46,    4, 11, 44,  2 },
    {     64,   47,    4, 11, 44,  2 }, {     64,   48,    4, 11, 44,  2 }, {     65,   49,    4, 11, 44,  2 }, {     66,   50,    4, 11, 44,  2 }, {     66,   51,    4, 11, 44,  2 },
    {     67,   52,    4, 11, 44,  2 }, {     68,   53,    4, 11, 44,  2 }, {     68,   54,    5, 11, 44,  2 }, {     69,   55,    5, 11, 44,  2 }, {     70,   56,    5, 11, 44,  2 },
    {     70,   57,    5, 11, 44,  2 }, {     71,   58,    5, 10, 44,  2 }, {     71,   59,    5, 10, 44,  2 }, {     72,   60,    5, 10, 44,  2 }, {     72,   61,    5, 10, 44,  2 },
    {     73,   62,    5, 10, 44,  2 }, {     73,   63,    5, 10, 44,  2 }, {     74,   64,    5, 10, 44,  2 }, {     74,   65,    5, 10, 44,  2 }, {     75,   66,    5, 10, 44,  2 },
    {     75,   67,    5, 10, 44,  2 }, {     75,   68,    6, 10, 44,  2 }, {     76,   69,    6, 10, 44,  2 }, {     76,   70,    6, 10, 44,  2 }, {     76,   71,    6, 10, 44,  2 },
    {     77,   72,    6,  9, 44,  2 }, {     77,   73,    6,  9, 44,  2 }, {     77,   74,    6,  9, 44,  2 }, {     77,   75,    6,  9, 44,  2 }, {     78,   76,    6,  9, 44,  2 },
    {     78,   77,    6,  9, 44,  2 }, {     78,   78,    6,  9, 44,  2 }, {     78,   79,    6,  9, 44,  2 }, {     78,   80,    6,  9, 44,  2 }, {     79,   81,    6,  9, 44,  2 },
    {     79,   82,    7,  9, 44,  2 }, {     79,   83,    7,  9, 44,  2 }, {     79,   84,    7,  9, 44,  2 }, {     79,   85,    7,  9, 44,  2 }, {     79,   86,    7,  9, 44,  2 },
    {     80,   87,    7,  9, 44,  2 }, {     80,   88,    7,  8, 44,  2 }, {     80,   89,    7,  8, 44,  2 }, {     80,   90,    7,  8, 44,  2 }, {     80,   91,    7,  8, 44,  2 },
    {     80,   92,    7,  8, 44,  2 }, {     80,   93,    7,  8, 44,  2 }, {     80,   94,    7,  8, 44,  2 }, {     80,   95,    7,  8, 44,  2 }, {     80,   96,    8,  8, 44,  2 },
    {     80,   97,    8,  8, 44,  2 }, {     80,   98,    8,  8, 44,  2 }, {     80,   99,    8,  8, 44,  2 }, {     80,  100,    8,  8, 44,  2 }, {     80,  101,    8,  8, 44,  2 },
    {     80,  102,    8,  8, 44,  2 }, {     80,  103,    8,  8, 44,  2 }, {     80,  104,    8,  7, 44,  2 }, {     79,  105,    8,  7, 44,  2 }, {     79,  106,    8,  7, 44,  2 },
    {     79,  107,    8,  7, 44,  2 }, {     79,  108,    8,  7, 44,  2 }, {     79,  109,    8,  7, 44,  2 }, {     79,  110,    8,  7, 44,  2 }, {     78,  111,    9,  7, 44,  2 },
    {     78,  112,    9,  7, 44,  2 }, {     78,  113,    9,  7, 44,  2 }, {     78,  114,    9,  7, 44,  2 }, {     78,  115,    9,  7, 44,  2 }, {     77,  116,    9,  7, 44,  2 },
    {     77,  117,    9,  7, 44,  2 }, {     77,  118,    9,  6, 44,  2 }, {     77,  119,    9,  6, 44,  2 }, {     76,  120,    9,  6, 44,  2 }, {     76,  121,    9,  6, 44,  2 },
    {     76,  122,    9,  6, 44,  2 }, {     75,  123,    9,  6, 44,  2 }, {     75,  124,    9,  6, 44,  2 }, {     75,  125,   10,  6, 44,  2 }, {     74,  126,   10,  6, 44,  2 },
    {     74,  127,   10,  6, 44,  2 }, {     73,  128,   10,  6, 44,  2 }, {     73,  129,   10,  6, 44,  2 }, {     72,  130,   10,  6, 44,  2 }, {     72,  131,   10,  6, 44,  2 },
    {     71,  132,   10,  6, 44,  2 }, {     71,  133,   10,  5, 44,  2 }, {     70,  134,   10,  5, 44,  2 }, {     70,  135,   10,  5, 44,  2 }, {     69,  136,   10,  5, 44,  2 },
    {     68,  137,   10,  5, 44,  2 }, {     68,  138,   10,  5, 44,  2 }, {     67,  139,   10,  5, 44,  2 }, {     66,  140,   11,  5, 44,  2 }, {     66,  141,   11,  5, 44,  2 },
    {     65,  142,   11,  5, 44,  2 }, {     64,  143,   11,  5, 44,  2 }, {     64,  144,   11,  5, 44,  2 }, {     63,  145,   11,  5, 44,  2 }, {     62,  146,   11,  4, 44,  2 },
    {     61,  147,   11,  4, 44,  2 }, {     61,  148,   11,  4, 44,  2 }, {     60,  149,   11,  4, 44,  2 }, {     59,  150,   11,  4, 44,  2 }, {     58,  151,   11,  4, 44,  2 },
    {     57,  152,   11,  4, 44,  2 }, {     57,  153,   11,  4, 44,  2 }, {     56,  154,   12,  4, 44,  2 }, {     55,  155,   12,  4, 44,  2 }, {     54,  156,   12,  4, 44,  2 },
    {     53,  157,   12,  4, 44,  2 }, {     52,  157,   12,  4, 44,  2 }, {     51,  158,   12,  3, 44,  2 }, {     50,  159,   12,  3, 44,  2 }, {     49,  160,   12,  3, 44,  2 },
    {     48,  160,   12,  3, 44,  2 }, {     47,  161,   12,  3, 44,  2 }, {     46,  162,   12,  3, 44,  2 }, {     45,  162,   12,  3, 44,  2 }, {     44,  163,   12,  3, 44,  2 },
    {     43,  164,   12,  3, 44,  2 }, {     42,  164,   13,  3, 44,  2 }, {     41,  165,   13,  3, 44,  2 }, {     40,  166,   13,  3, 44,  2 }, {     39,  166,   13,  3, 44,  2 },
    {     38,  167,   13,  2, 44,  2 }, {     37,  167,   13,  2, 44,  2 }, {     36,  168,   13,  2, 44,  2 }, {     35,  168,   13,  2, 44,  2 }, {     34,  169,   13,  2, 44,  2 },
    {     33,  169,   13,  2, 44,  2 }, {     32,  170,   13,  2, 44,  2 }, {     31,  170,   13,  2, 44,  2 }, {     30,  171,   13,  2, 44,  2 }, {     29,  171,   13,  2, 44,  2 },
    {     28,  171,   13,  2, 44,  2 }, {     27,  172,   14,  2, 44,  2 }, {     26,  172,   14,  2, 44,  2 }, {     25,  172,   14,  2, 44,  2 }, {     24,  173,   14,  1, 44,  2 },
    {     23,  173,   14,  1, 44,  2 }, {     22,  173,   14,  1, 44,  2 }, {     21,  173,   14,  1, 44,  2 }, {     20,  174,   14,  1, 44,  2 }, {     19,  174,   14,  1, 44,  2 },
    {     18,  174,   14,  1, 44,  2 }, {     17,  174,   14,  1, 44,  2 }, {     16,  174,   14,  1, 44,  2 }, {     15,  175,   14,  1, 44,  2 }, {     14,  175,   14,  1, 44,  2 },
    {     13,  175,   15,  1, 44,  2 }, {     12,  175,   15,  1, 44,  2 }, {     11,  175,   15,  1, 44,  2 }, {     10,  175,   15,  1, 44,  2 }, {      9,  176,   15,  1, 44,  2 },
    {      8,  176,   15,  0, 44,  2 }, {      7,  176,   15,  0, 44,  2 }, {      6,  176,   15,  0, 44,  2 }, {      5,  176,   15,  0, 44,  2 }, {      4,  176,   15,  0, 44,  2 },
    {      3,  176,   15,  0, 44,  2 }, {      2,  176,   15,  0, 44,  2 }, {      1,  176,   15,  0, 44,  2 }, {      0,  176,   15,  0, 44,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F243D, {
    {     16,   31,    0, 24, 44,  2 }, {     16,   30,    0, 24, 44,  2 }, {     16,   29,    0, 24, 44,  2 }, {     16,   28,    0, 24, 44,  2 }, {     16,   27,    0, 24, 44,  2 },
    {     16,   26,    0, 24, 44,  2 }, {     16,   25,    0, 24, 44,  2 }, {     16,   24,    0, 23, 44,  2 }, {     17,   23,    0, 23, 44,  2 }, {     17,   22,    0, 23, 44,  2 },
    {     17,   21,    0, 23, 44,  2 }, {     17,   20,    0, 23, 44,  2 }, {     17,   19,    0, 23, 44,  2 }, {     17,   18,    0, 23, 44,  2 }, {     18,   17,    1, 23, 44,  2 },
    {     18,   16,    1, 23, 44,  2 }, {     18,   15,    1, 23, 44,  2 }, {     18,   14,    1, 23, 44,  2 }, {     18,   13,    1, 23, 44,  2 }, {     19,   12,    1, 23, 44,  2 },
    {     19,   11,    1, 23, 44,  2 }, {     19,   10,    1, 22, 44,  2 }, {     19,    9,    1, 22, 44,  2 }, {     20,    8,    1, 22, 44,  2 }, {     20,    7,    1, 22, 44,  2 },
    {     20,    6,    1, 22, 44,  2 }, {     21,    5,    1, 22, 44,  2 }, {     21,    4,    1, 22, 44,  2 }, {     21,    3,    2, 22, 44,  2 }, {     22,    2,    2, 22, 44,  2 },
    {     22,    1,    2, 22, 44,  2 }, {     23,    0,    2, 22, 44,  2 }, {     23,   -1,    2, 22, 44,  2 }, {     24,   -2,    2, 22, 44,  2 }, {     24,   -3,    2, 22, 44,  2 },
    {     25,   -4,    2, 22, 44,  2 }, {     25,   -5,    2, 21, 44,  2 }, {     26,   -6,    2, 21, 44,  2 }, {     26,   -7,    2, 21, 44,  2 }, {     27,   -8,    2, 21, 44,  2 },
    {     28,   -9,    2, 21, 44,  2 }, {     28,  -10,    2, 21, 44,  2 }, {     29,  -11,    3, 21, 44,  2 }, {     30,  -12,    3, 21, 44,  2 }, {     30,  -13,    3, 21, 44,  2 },
    {     31,  -14,    3, 21, 44,  2 }, {     32,  -15,    3, 21, 44,  2 }, {     32,  -16,    3, 21, 44,  2 }, {     33,  -17,    3, 21, 44,  2 }, {     34,  -18,    3, 20, 44,  2 },
    {     35,  -19,    3, 20, 44,  2 }, {     35,  -20,    3, 20, 44,  2 }, {     36,  -21,    3, 20, 44,  2 }, {     37,  -22,    3, 20, 44,  2 }, {     38,  -23,    3, 20, 44,  2 },
    {     39,  -24,    3, 20, 44,  2 }, {     39,  -25,    4, 20, 44,  2 }, {     40,  -26,    4, 20, 44,  2 }, {     41,  -27,    4, 20, 44,  2 }, {     42,  -28,    4, 20, 44,  2 },
    {     43,  -29,    4, 20, 44,  2 }, {     44,  -29,    4, 20, 44,  2 }, {     45,  -30,    4, 19, 44,  2 }, {     46,  -31,    4, 19, 44,  2 }, {     47,  -32,    4, 19, 44,  2 },
    {     48,  -32,    4, 19, 44,  2 }, {     49,  -33,    4, 19, 44,  2 }, {     50,  -34,    4, 19, 44,  2 }, {     51,  -34,    4, 19, 44,  2 }, {     52,  -35,    4, 19, 44,  2 },
    {     53,  -36,    5, 19, 44,  2 }, {     54,  -36,    5, 19, 44,  2 }, {     55,  -37,    5, 19, 44,  2 }, {     56,  -38,    5, 19, 44,  2 }, {     57,  -38,    5, 19, 44,  2 },
    {     58,  -39,    5, 18, 44,  2 }, {     59,  -39,    5, 18, 44,  2 }, {     60,  -40,    5, 18, 44,  2 }, {     61,  -40,    5, 18, 44,  2 }, {     62,  -41,    5, 18, 44,  2 },
    {     63,  -41,    5, 18, 44,  2 }, {     64,  -42,    5, 18, 44,  2 }, {     65,  -42,    5, 18, 44,  2 }, {     66,  -43,    5, 18, 44,  2 }, {     67,  -43,    6, 18, 44,  2 },
    {     68,  -43,    6, 18, 44,  2 }, {     69,  -44,    6, 18, 44,  2 }, {     70,  -44,    6, 18, 44,  2 }, {     71,  -44,    6, 18, 44,  2 }, {     72,  -45,    6, 17, 44,  2 },
    {     73,  -45,    6, 17, 44,  2 }, {     74,  -45,    6, 17, 44,  2 }, {     75,  -45,    6, 17, 44,  2 }, {     76,  -46,    6, 17, 44,  2 }, {     77,  -46,    6, 17, 44,  2 },
    {     78,  -46,    6, 17, 44,  2 }, {     79,  -46,    6, 17, 44,  2 }, {     80,  -46,    6, 17, 44,  2 }, {     81,  -47,    7, 17, 44,  2 }, {     82,  -47,    7, 17, 44,  2 },
    {     83,  -47,    7, 17, 44,  2 }, {     84,  -47,    7, 17, 44,  2 }, {     85,  -47,    7, 17, 44,  2 }, {     86,  -47,    7, 17, 44,  2 }, {     87,  -48,    7, 17, 44,  2 },
    {     88,  -48,    7, 16, 44,  2 }, {     89,  -48,    7, 16, 44,  2 }, {     90,  -48,    7, 16, 44,  2 }, {     91,  -48,    7, 16, 44,  2 }, {     92,  -48,    7, 16, 44,  2 },
    {     93,  -48,    7, 16, 44,  2 }, {     94,  -48,    7, 16, 44,  2 }, {     95,  -48,    8, 16, 44,  2 }, {     96,  -48,    8, 16, 44,  2 }, {     97,  -48,    8, 16, 44,  2 },
    {     98,  -48,    8, 16, 44,  2 }, {     99,  -48,    8, 16, 44,  2 }, {    100,  -48,    8, 16, 44,  2 }, {    101,  -48,    8, 16, 44,  2 }, {    102,  -48,    8, 16, 44,  2 },
    {    103,  -48,    8, 16, 44,  2 }, {    104,  -48,    8, 15, 44,  2 }, {    105,  -47,    8, 15, 44,  2 }, {    106,  -47,    8, 15, 44,  2 }, {    107,  -47,    8, 15, 44,  2 },
    {    108,  -47,    8, 15, 44,  2 }, {    109,  -47,    8, 15, 44,  2 }, {    110,  -47,    8, 15, 44,  2 }, {    111,  -46,    9, 15, 44,  2 }, {    112,  -46,    9, 15, 44,  2 },
    {    113,  -46,    9, 15, 44,  2 }, {    114,  -46,    9, 15, 44,  2 }, {    115,  -46,    9, 15, 44,  2 }, {    116,  -45,    9, 15, 44,  2 }, {    117,  -45,    9, 15, 44,  2 },
    {    118,  -45,    9, 14, 44,  2 }, {    119,  -45,    9, 14, 44,  2 }, {    120,  -44,    9, 14, 44,  2 }, {    121,  -44,    9, 14, 44,  2 }, {    122,  -44,    9, 14, 44,  2 },
    {    123,  -43,    9, 14, 44,  2 }, {    124,  -43,    9, 14, 44,  2 }, {    125,  -43,   10, 14, 44,  2 }, {    126,  -42,   10, 14, 44,  2 }, {    127,  -42,   10, 14, 44,  2 },
    {    128,  -41,   10, 14, 44,  2 }, {    129,  -41,   10, 14, 44,  2 }, {    130,  -40,   10, 14, 44,  2 }, {    131,  -40,   10, 14, 44,  2 }, {    132,  -39,   10, 14, 44,  2 },
    {    133,  -39,   10, 13, 44,  2 }, {    134,  -38,   10, 13, 44,  2 }, {    135,  -38,   10, 13, 44,  2 }, {    136,  -37,   10, 13, 44,  2 }, {    137,  -36,   10, 13, 44,  2 },
    {    138,  -36,   10, 13, 44,  2 }, {    139,  -35,   11, 13, 44,  2 }, {    140,  -34,   11, 13, 44,  2 }, {    141,  -34,   11, 13, 44,  2 }, {    142,  -33,   11, 13, 44,  2 },
    {    143,  -32,   11, 13, 44,  2 }, {    144,  -32,   11, 13, 44,  2 }, {    145,  -31,   11, 13, 44,  2 }, {    146,  -30,   11, 12, 44,  2 }, {    147,  -29,   11, 12, 44,  2 },
    {    148,  -29,   11, 12, 44,  2 }, {    149,  -28,   11, 12, 44,  2 }, {    150,  -27,   11, 12, 44,  2 }, {    151,  -26,   11, 12, 44,  2 }, {    152,  -25,   11, 12, 44,  2 },
    {    153,  -25,   12, 12, 44,  2 }, {    154,  -24,   12, 12, 44,  2 }, {    155,  -23,   12, 12, 44,  2 }, {    156,  -22,   12, 12, 44,  2 }, {    157,  -21,   12, 12, 44,  2 },
    {    157,  -20,   12, 12, 44,  2 }, {    158,  -19,   12, 11, 44,  2 }, {    159,  -18,   12, 11, 44,  2 }, {    160,  -17,   12, 11, 44,  2 }, {    160,  -16,   12, 11, 44,  2 },
    {    161,  -15,   12, 11, 44,  2 }, {    162,  -14,   12, 11, 44,  2 }, {    162,  -13,   12, 11, 44,  2 }, {    163,  -12,   12, 11, 44,  2 }, {    164,  -11,   12, 11, 44,  2 },
    {    164,  -10,   13, 11, 44,  2 }, {    165,   -9,   13, 11, 44,  2 }, {    166,   -8,   13, 11, 44,  2 }, {    166,   -7,   13, 11, 44,  2 }, {    167,   -6,   13, 10, 44,  2 },
    {    167,   -5,   13, 10, 44,  2 }, {    168,   -4,   13, 10, 44,  2 }, {    168,   -3,   13, 10, 44,  2 }, {    169,   -2,   13, 10, 44,  2 }, {    169,   -1,   13, 10, 44,  2 },
    {    170,    0,   13, 10, 44,  2 }, {    170,    1,   13, 10, 44,  2 }, {    171,    2,   13, 10, 44,  2 }, {    171,    3,   13, 10, 44,  2 }, {    171,    4,   14, 10, 44,  2 },
    {    172,    5,   14, 10, 44,  2 }, {    172,    6,   14, 10, 44,  2 }, {    172,    7,   14, 10, 44,  2 }, {    173,    8,   14,  9, 44,  2 }, {    173,    9,   14,  9, 44,  2 },
    {    173,   10,   14,  9, 44,  2 }, {    173,   11,   14,  9, 44,  2 }, {    174,   12,   14,  9, 44,  2 }, {    174,   13,   14,  9, 44,  2 }, {    174,   14,   14,  9, 44,  2 },
    {    174,   15,   14,  9, 44,  2 }, {    174,   16,   14,  9, 44,  2 }, {    175,   17,   14,  9, 44,  2 }, {    175,   18,   15,  9, 44,  2 }, {    175,   19,   15,  9, 44,  2 },
    {    175,   20,   15,  9, 44,  2 }, {    175,   21,   15,  9, 44,  2 }, {    175,   22,   15,  9, 44,  2 }, {    176,   23,   15,  9, 44,  2 }, {    176,   24,   15,  8, 44,  2 },
    {    176,   25,   15,  8, 44,  2 }, {    176,   26,   15,  8, 44,  2 }, {    176,   27,   15,  8, 44,  2 }, {    176,   28,   15,  8, 44,  2 }, {    176,   29,   15,  8, 44,  2 },
    {    176,   30,   15,  8, 44,  2 }, {    176,   31,   15,  8, 44,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F2C3A, {
    {     31,   16,    0,  0, 44,  4 }, {     30,   16,    0,  0, 44,  4 }, {     29,   16,    0,  0, 44,  4 }, {     28,   16,    0,  0, 44,  4 }, {     27,   16,    0,  0, 44,  4 },
    {     26,   16,    0,  0, 44,  4 }, {     25,   16,    0,  0, 44,  4 }, {     24,   16,    0,  1, 44,  4 }, {     23,   17,    0,  1, 44,  4 }, {     22,   17,    0,  1, 44,  4 },
    {     21,   17,    0,  1, 44,  4 }, {     20,   17,    0,  1, 44,  4 }, {     19,   17,    0,  1, 44,  4 }, {     18,   17,    0,  1, 44,  4 }, {     17,   18,    1,  1, 44,  4 },
    {     16,   18,    1,  1, 44,  4 }, {     15,   18,    1,  1, 44,  4 }, {     14,   18,    1,  1, 44,  4 }, {     13,   18,    1,  1, 44,  4 }, {     12,   19,    1,  1, 44,  4 },
    {     11,   19,    1,  1, 44,  4 }, {     10,   19,    1,  2, 44,  4 }, {      9,   19,    1,  2, 44,  4 }, {      8,   20,    1,  2, 44,  4 }, {      7,   20,    1,  2, 44,  4 },
    {      6,   20,    1,  2, 44,  4 }, {      5,   21,    1,  2, 44,  4 }, {      4,   21,    1,  2, 44,  4 }, {      3,   21,    2,  2, 44,  4 }, {      2,   22,    2,  2, 44,  4 },
    {      1,   22,    2,  2, 44,  4 }, {      0,   23,    2,  2, 44,  4 }, {     -1,   23,    2,  2, 44,  4 }, {     -2,   24,    2,  2, 44,  4 }, {     -3,   24,    2,  2, 44,  4 },
    {     -4,   25,    2,  2, 44,  4 }, {     -5,   25,    2,  3, 44,  4 }, {     -6,   26,    2,  3, 44,  4 }, {     -7,   26,    2,  3, 44,  4 }, {     -8,   27,    2,  3, 44,  4 },
    {     -9,   28,    2,  3, 44,  4 }, {    -10,   28,    2,  3, 44,  4 }, {    -11,   29,    3,  3, 44,  4 }, {    -12,   30,    3,  3, 44,  4 }, {    -13,   30,    3,  3, 44,  4 },
    {    -14,   31,    3,  3, 44,  4 }, {    -15,   32,    3,  3, 44,  4 }, {    -16,   32,    3,  3, 44,  4 }, {    -17,   33,    3,  3, 44,  4 }, {    -18,   34,    3,  4, 44,  4 },
    {    -19,   35,    3,  4, 44,  4 }, {    -20,   35,    3,  4, 44,  4 }, {    -21,   36,    3,  4, 44,  4 }, {    -22,   37,    3,  4, 44,  4 }, {    -23,   38,    3,  4, 44,  4 },
    {    -24,   39,    3,  4, 44,  4 }, {    -25,   39,    4,  4, 44,  4 }, {    -26,   40,    4,  4, 44,  4 }, {    -27,   41,    4,  4, 44,  4 }, {    -28,   42,    4,  4, 44,  4 },
    {    -29,   43,    4,  4, 44,  4 }, {    -29,   44,    4,  4, 44,  4 }, {    -30,   45,    4,  5, 44,  4 }, {    -31,   46,    4,  5, 44,  4 }, {    -32,   47,    4,  5, 44,  4 },
    {    -32,   48,    4,  5, 44,  4 }, {    -33,   49,    4,  5, 44,  4 }, {    -34,   50,    4,  5, 44,  4 }, {    -34,   51,    4,  5, 44,  4 }, {    -35,   52,    4,  5, 44,  4 },
    {    -36,   53,    5,  5, 44,  4 }, {    -36,   54,    5,  5, 44,  4 }, {    -37,   55,    5,  5, 44,  4 }, {    -38,   56,    5,  5, 44,  4 }, {    -38,   57,    5,  5, 44,  4 },
    {    -39,   58,    5,  6, 44,  4 }, {    -39,   59,    5,  6, 44,  4 }, {    -40,   60,    5,  6, 44,  4 }, {    -40,   61,    5,  6, 44,  4 }, {    -41,   62,    5,  6, 44,  4 },
    {    -41,   63,    5,  6, 44,  4 }, {    -42,   64,    5,  6, 44,  4 }, {    -42,   65,    5,  6, 44,  4 }, {    -43,   66,    5,  6, 44,  4 }, {    -43,   67,    6,  6, 44,  4 },
    {    -43,   68,    6,  6, 44,  4 }, {    -44,   69,    6,  6, 44,  4 }, {    -44,   70,    6,  6, 44,  4 }, {    -44,   71,    6,  6, 44,  4 }, {    -45,   72,    6,  7, 44,  4 },
    {    -45,   73,    6,  7, 44,  4 }, {    -45,   74,    6,  7, 44,  4 }, {    -45,   75,    6,  7, 44,  4 }, {    -46,   76,    6,  7, 44,  4 }, {    -46,   77,    6,  7, 44,  4 },
    {    -46,   78,    6,  7, 44,  4 }, {    -46,   79,    6,  7, 44,  4 }, {    -46,   80,    6,  7, 44,  4 }, {    -47,   81,    7,  7, 44,  4 }, {    -47,   82,    7,  7, 44,  4 },
    {    -47,   83,    7,  7, 44,  4 }, {    -47,   84,    7,  7, 44,  4 }, {    -47,   85,    7,  7, 44,  4 }, {    -47,   86,    7,  7, 44,  4 }, {    -48,   87,    7,  7, 44,  4 },
    {    -48,   88,    7,  8, 44,  4 }, {    -48,   89,    7,  8, 44,  4 }, {    -48,   90,    7,  8, 44,  4 }, {    -48,   91,    7,  8, 44,  4 }, {    -48,   92,    7,  8, 44,  4 },
    {    -48,   93,    7,  8, 44,  4 }, {    -48,   94,    7,  8, 44,  4 }, {    -48,   95,    8,  8, 44,  4 }, {    -48,   96,    8,  8, 44,  4 }, {    -48,   97,    8,  8, 44,  4 },
    {    -48,   98,    8,  8, 44,  4 }, {    -48,   99,    8,  8, 44,  4 }, {    -48,  100,    8,  8, 44,  4 }, {    -48,  101,    8,  8, 44,  4 }, {    -48,  102,    8,  8, 44,  4 },
    {    -48,  103,    8,  8, 44,  4 }, {    -48,  104,    8,  9, 44,  4 }, {    -47,  105,    8,  9, 44,  4 }, {    -47,  106,    8,  9, 44,  4 }, {    -47,  107,    8,  9, 44,  4 },
    {    -47,  108,    8,  9, 44,  4 }, {    -47,  109,    8,  9, 44,  4 }, {    -47,  110,    8,  9, 44,  4 }, {    -46,  111,    9,  9, 44,  4 }, {    -46,  112,    9,  9, 44,  4 },
    {    -46,  113,    9,  9, 44,  4 }, {    -46,  114,    9,  9, 44,  4 }, {    -46,  115,    9,  9, 44,  4 }, {    -45,  116,    9,  9, 44,  4 }, {    -45,  117,    9,  9, 44,  4 },
    {    -45,  118,    9, 10, 44,  4 }, {    -45,  119,    9, 10, 44,  4 }, {    -44,  120,    9, 10, 44,  4 }, {    -44,  121,    9, 10, 44,  4 }, {    -44,  122,    9, 10, 44,  4 },
    {    -43,  123,    9, 10, 44,  4 }, {    -43,  124,    9, 10, 44,  4 }, {    -43,  125,   10, 10, 44,  4 }, {    -42,  126,   10, 10, 44,  4 }, {    -42,  127,   10, 10, 44,  4 },
    {    -41,  128,   10, 10, 44,  4 }, {    -41,  129,   10, 10, 44,  4 }, {    -40,  130,   10, 10, 44,  4 }, {    -40,  131,   10, 10, 44,  4 }, {    -39,  132,   10, 10, 44,  4 },
    {    -39,  133,   10, 11, 44,  4 }, {    -38,  134,   10, 11, 44,  4 }, {    -38,  135,   10, 11, 44,  4 }, {    -37,  136,   10, 11, 44,  4 }, {    -36,  137,   10, 11, 44,  4 },
    {    -36,  138,   10, 11, 44,  4 }, {    -35,  139,   11, 11, 44,  4 }, {    -34,  140,   11, 11, 44,  4 }, {    -34,  141,   11, 11, 44,  4 }, {    -33,  142,   11, 11, 44,  4 },
    {    -32,  143,   11, 11, 44,  4 }, {    -32,  144,   11, 11, 44,  4 }, {    -31,  145,   11, 11, 44,  4 }, {    -30,  146,   11, 12, 44,  4 }, {    -29,  147,   11, 12, 44,  4 },
    {    -29,  148,   11, 12, 44,  4 }, {    -28,  149,   11, 12, 44,  4 }, {    -27,  150,   11, 12, 44,  4 }, {    -26,  151,   11, 12, 44,  4 }, {    -25,  152,   11, 12, 44,  4 },
    {    -25,  153,   12, 12, 44,  4 }, {    -24,  154,   12, 12, 44,  4 }, {    -23,  155,   12, 12, 44,  4 }, {    -22,  156,   12, 12, 44,  4 }, {    -21,  157,   12, 12, 44,  4 },
    {    -20,  157,   12, 12, 44,  4 }, {    -19,  158,   12, 13, 44,  4 }, {    -18,  159,   12, 13, 44,  4 }, {    -17,  160,   12, 13, 44,  4 }, {    -16,  160,   12, 13, 44,  4 },
    {    -15,  161,   12, 13, 44,  4 }, {    -14,  162,   12, 13, 44,  4 }, {    -13,  162,   12, 13, 44,  4 }, {    -12,  163,   12, 13, 44,  4 }, {    -11,  164,   12, 13, 44,  4 },
    {    -10,  164,   13, 13, 44,  4 }, {     -9,  165,   13, 13, 44,  4 }, {     -8,  166,   13, 13, 44,  4 }, {     -7,  166,   13, 13, 44,  4 }, {     -6,  167,   13, 14, 44,  4 },
    {     -5,  167,   13, 14, 44,  4 }, {     -4,  168,   13, 14, 44,  4 }, {     -3,  168,   13, 14, 44,  4 }, {     -2,  169,   13, 14, 44,  4 }, {     -1,  169,   13, 14, 44,  4 },
    {      0,  170,   13, 14, 44,  4 }, {      1,  170,   13, 14, 44,  4 }, {      2,  171,   13, 14, 44,  4 }, {      3,  171,   13, 14, 44,  4 }, {      4,  171,   14, 14, 44,  4 },
    {      5,  172,   14, 14, 44,  4 }, {      6,  172,   14, 14, 44,  4 }, {      7,  172,   14, 14, 44,  4 }, {      8,  173,   14, 15, 44,  4 }, {      9,  173,   14, 15, 44,  4 },
    {     10,  173,   14, 15, 44,  4 }, {     11,  173,   14, 15, 44,  4 }, {     12,  174,   14, 15, 44,  4 }, {     13,  174,   14, 15, 44,  4 }, {     14,  174,   14, 15, 44,  4 },
    {     15,  174,   14, 15, 44,  4 }, {     16,  174,   14, 15, 44,  4 }, {     17,  175,   14, 15, 44,  4 }, {     18,  175,   15, 15, 44,  4 }, {     19,  175,   15, 15, 44,  4 },
    {     20,  175,   15, 15, 44,  4 }, {     21,  175,   15, 15, 44,  4 }, {     22,  175,   15, 15, 44,  4 }, {     23,  176,   15, 15, 44,  4 }, {     24,  176,   15, 16, 44,  4 },
    {     25,  176,   15, 16, 44,  4 }, {     26,  176,   15, 16, 44,  4 }, {     27,  176,   15, 16, 44,  4 }, {     28,  176,   15, 16, 44,  4 }, {     29,  176,   15, 16, 44,  4 },
    {     30,  176,   15, 16, 44,  4 }, {     31,  176,   15, 16, 44,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F3437, {
    {     16,    0,    0,  8, 44,  4 }, {     16,    1,    0,  8, 44,  4 }, {     16,    2,    0,  8, 44,  4 }, {     16,    3,    0,  8, 44,  4 }, {     16,    4,    0,  8, 44,  4 },
    {     16,    5,    0,  8, 44,  4 }, {     16,    6,    0,  8, 44,  4 }, {     16,    7,    0,  8, 44,  4 }, {     16,    8,    0,  9, 44,  4 }, {     17,    9,    0,  9, 44,  4 },
    {     17,   10,    0,  9, 44,  4 }, {     17,   11,    0,  9, 44,  4 }, {     17,   12,    0,  9, 44,  4 }, {     17,   13,    0,  9, 44,  4 }, {     17,   14,    0,  9, 44,  4 },
    {     18,   15,    1,  9, 44,  4 }, {     18,   16,    1,  9, 44,  4 }, {     18,   17,    1,  9, 44,  4 }, {     18,   18,    1,  9, 44,  4 }, {     18,   19,    1,  9, 44,  4 },
    {     19,   20,    1,  9, 44,  4 }, {     19,   21,    1,  9, 44,  4 }, {     19,   22,    1, 10, 44,  4 }, {     19,   23,    1, 10, 44,  4 }, {     20,   24,    1, 10, 44,  4 },
    {     20,   25,    1, 10, 44,  4 }, {     20,   26,    1, 10, 44,  4 }, {     21,   27,    1, 10, 44,  4 }, {     21,   28,    1, 10, 44,  4 }, {     21,   29,    2, 10, 44,  4 },
    {     22,   30,    2, 10, 44,  4 }, {     22,   31,    2, 10, 44,  4 }, {     23,   32,    2, 10, 44,  4 }, {     23,   33,    2, 10, 44,  4 }, {     24,   34,    2, 10, 44,  4 },
    {     24,   35,    2, 10, 44,  4 }, {     25,   36,    2, 10, 44,  4 }, {     25,   37,    2, 11, 44,  4 }, {     26,   38,    2, 11, 44,  4 }, {     26,   39,    2, 11, 44,  4 },
    {     27,   40,    2, 11, 44,  4 }, {     28,   41,    2, 11, 44,  4 }, {     28,   42,    2, 11, 44,  4 }, {     29,   43,    3, 11, 44,  4 }, {     30,   44,    3, 11, 44,  4 },
    {     30,   45,    3, 11, 44,  4 }, {     31,   46,    3, 11, 44,  4 }, {     32,   47,    3, 11, 44,  4 }, {     32,   48,    3, 11, 44,  4 }, {     33,   49,    3, 11, 44,  4 },
    {     34,   50,    3, 12, 44,  4 }, {     35,   51,    3, 12, 44,  4 }, {     35,   52,    3, 12, 44,  4 }, {     36,   53,    3, 12, 44,  4 }, {     37,   54,    3, 12, 44,  4 },
    {     38,   55,    3, 12, 44,  4 }, {     39,   56,    3, 12, 44,  4 }, {     39,   57,    4, 12, 44,  4 }, {     40,   58,    4, 12, 44,  4 }, {     41,   59,    4, 12, 44,  4 },
    {     42,   60,    4, 12, 44,  4 }, {     43,   61,    4, 12, 44,  4 }, {     44,   61,    4, 12, 44,  4 }, {     45,   62,    4, 13, 44,  4 }, {     46,   63,    4, 13, 44,  4 },
    {     47,   64,    4, 13, 44,  4 }, {     48,   64,    4, 13, 44,  4 }, {     49,   65,    4, 13, 44,  4 }, {     50,   66,    4, 13, 44,  4 }, {     51,   66,    4, 13, 44,  4 },
    {     52,   67,    4, 13, 44,  4 }, {     53,   68,    4, 13, 44,  4 }, {     54,   68,    5, 13, 44,  4 }, {     55,   69,    5, 13, 44,  4 }, {     56,   70,    5, 13, 44,  4 },
    {     57,   70,    5, 13, 44,  4 }, {     58,   71,    5, 14, 44,  4 }, {     59,   71,    5, 14, 44,  4 }, {     60,   72,    5, 14, 44,  4 }, {     61,   72,    5, 14, 44,  4 },
    {     62,   73,    5, 14, 44,  4 }, {     63,   73,    5, 14, 44,  4 }, {     64,   74,    5, 14, 44,  4 }, {     65,   74,    5, 14, 44,  4 }, {     66,   75,    5, 14, 44,  4 },
    {     67,   75,    5, 14, 44,  4 }, {     68,   75,    6, 14, 44,  4 }, {     69,   76,    6, 14, 44,  4 }, {     70,   76,    6, 14, 44,  4 }, {     71,   76,    6, 14, 44,  4 },
    {     72,   77,    6, 15, 44,  4 }, {     73,   77,    6, 15, 44,  4 }, {     74,   77,    6, 15, 44,  4 }, {     75,   77,    6, 15, 44,  4 }, {     76,   78,    6, 15, 44,  4 },
    {     77,   78,    6, 15, 44,  4 }, {     78,   78,    6, 15, 44,  4 }, {     79,   78,    6, 15, 44,  4 }, {     80,   78,    6, 15, 44,  4 }, {     81,   79,    6, 15, 44,  4 },
    {     82,   79,    7, 15, 44,  4 }, {     83,   79,    7, 15, 44,  4 }, {     84,   79,    7, 15, 44,  4 }, {     85,   79,    7, 15, 44,  4 }, {     86,   79,    7, 15, 44,  4 },
    {     87,   80,    7, 15, 44,  4 }, {     88,   80,    7, 16, 44,  4 }, {     89,   80,    7, 16, 44,  4 }, {     90,   80,    7, 16, 44,  4 }, {     91,   80,    7, 16, 44,  4 },
    {     92,   80,    7, 16, 44,  4 }, {     93,   80,    7, 16, 44,  4 }, {     94,   80,    7, 16, 44,  4 }, {     95,   80,    7, 16, 44,  4 }, {     96,   80,    8, 16, 44,  4 },
    {     97,   80,    8, 16, 44,  4 }, {     98,   80,    8, 16, 44,  4 }, {     99,   80,    8, 16, 44,  4 }, {    100,   80,    8, 16, 44,  4 }, {    101,   80,    8, 16, 44,  4 },
    {    102,   80,    8, 16, 44,  4 }, {    103,   80,    8, 16, 44,  4 }, {    104,   80,    8, 17, 44,  4 }, {    105,   79,    8, 17, 44,  4 }, {    106,   79,    8, 17, 44,  4 },
    {    107,   79,    8, 17, 44,  4 }, {    108,   79,    8, 17, 44,  4 }, {    109,   79,    8, 17, 44,  4 }, {    110,   79,    8, 17, 44,  4 }, {    111,   78,    9, 17, 44,  4 },
    {    112,   78,    9, 17, 44,  4 }, {    113,   78,    9, 17, 44,  4 }, {    114,   78,    9, 17, 44,  4 }, {    115,   78,    9, 17, 44,  4 }, {    116,   77,    9, 17, 44,  4 },
    {    117,   77,    9, 17, 44,  4 }, {    118,   77,    9, 18, 44,  4 }, {    119,   77,    9, 18, 44,  4 }, {    120,   76,    9, 18, 44,  4 }, {    121,   76,    9, 18, 44,  4 },
    {    122,   76,    9, 18, 44,  4 }, {    123,   75,    9, 18, 44,  4 }, {    124,   75,    9, 18, 44,  4 }, {    125,   75,   10, 18, 44,  4 }, {    126,   74,   10, 18, 44,  4 },
    {    127,   74,   10, 18, 44,  4 }, {    128,   73,   10, 18, 44,  4 }, {    129,   73,   10, 18, 44,  4 }, {    130,   72,   10, 18, 44,  4 }, {    131,   72,   10, 18, 44,  4 },
    {    132,   71,   10, 18, 44,  4 }, {    133,   71,   10, 19, 44,  4 }, {    134,   70,   10, 19, 44,  4 }, {    135,   70,   10, 19, 44,  4 }, {    136,   69,   10, 19, 44,  4 },
    {    137,   68,   10, 19, 44,  4 }, {    138,   68,   10, 19, 44,  4 }, {    139,   67,   10, 19, 44,  4 }, {    140,   66,   11, 19, 44,  4 }, {    141,   66,   11, 19, 44,  4 },
    {    142,   65,   11, 19, 44,  4 }, {    143,   64,   11, 19, 44,  4 }, {    144,   64,   11, 19, 44,  4 }, {    145,   63,   11, 19, 44,  4 }, {    146,   62,   11, 20, 44,  4 },
    {    147,   61,   11, 20, 44,  4 }, {    148,   61,   11, 20, 44,  4 }, {    149,   60,   11, 20, 44,  4 }, {    150,   59,   11, 20, 44,  4 }, {    151,   58,   11, 20, 44,  4 },
    {    152,   57,   11, 20, 44,  4 }, {    153,   57,   11, 20, 44,  4 }, {    154,   56,   12, 20, 44,  4 }, {    155,   55,   12, 20, 44,  4 }, {    156,   54,   12, 20, 44,  4 },
    {    157,   53,   12, 20, 44,  4 }, {    157,   52,   12, 20, 44,  4 }, {    158,   51,   12, 21, 44,  4 }, {    159,   50,   12, 21, 44,  4 }, {    160,   49,   12, 21, 44,  4 },
    {    160,   48,   12, 21, 44,  4 }, {    161,   47,   12, 21, 44,  4 }, {    162,   46,   12, 21, 44,  4 }, {    162,   45,   12, 21, 44,  4 }, {    163,   44,   12, 21, 44,  4 },
    {    164,   43,   12, 21, 44,  4 }, {    164,   42,   13, 21, 44,  4 }, {    165,   41,   13, 21, 44,  4 }, {    166,   40,   13, 21, 44,  4 }, {    166,   39,   13, 21, 44,  4 },
    {    167,   38,   13, 22, 44,  4 }, {    167,   37,   13, 22, 44,  4 }, {    168,   36,   13, 22, 44,  4 }, {    168,   35,   13, 22, 44,  4 }, {    169,   34,   13, 22, 44,  4 },
    {    169,   33,   13, 22, 44,  4 }, {    170,   32,   13, 22, 44,  4 }, {    170,   31,   13, 22, 44,  4 }, {    171,   30,   13, 22, 44,  4 }, {    171,   29,   13, 22, 44,  4 },
    {    171,   28,   13, 22, 44,  4 }, {    172,   27,   14, 22, 44,  4 }, {    172,   26,   14, 22, 44,  4 }, {    172,   25,   14, 22, 44,  4 }, {    173,   24,   14, 23, 44,  4 },
    {    173,   23,   14, 23, 44,  4 }, {    173,   22,   14, 23, 44,  4 }, {    173,   21,   14, 23, 44,  4 }, {    174,   20,   14, 23, 44,  4 }, {    174,   19,   14, 23, 44,  4 },
    {    174,   18,   14, 23, 44,  4 }, {    174,   17,   14, 23, 44,  4 }, {    174,   16,   14, 23, 44,  4 }, {    175,   15,   14, 23, 44,  4 }, {    175,   14,   14, 23, 44,  4 },
    {    175,   13,   15, 23, 44,  4 }, {    175,   12,   15, 23, 44,  4 }, {    175,   11,   15, 23, 44,  4 }, {    175,   10,   15, 23, 44,  4 }, {    176,    9,   15, 23, 44,  4 },
    {    176,    8,   15, 24, 44,  4 }, {    176,    7,   15, 24, 44,  4 }, {    176,    6,   15, 24, 44,  4 }, {    176,    5,   15, 24, 44,  4 }, {    176,    4,   15, 24, 44,  4 },
    {    176,    3,   15, 24, 44,  4 }, {    176,    2,   15, 24, 44,  4 }, {    176,    1,   15, 24, 44,  4 }, {    176,    0,   15, 24, 44,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F3C46, {
    {      0,   16,    0, 16, 44,  4 }, {      1,   16,    0, 16, 44,  4 }, {      2,   16,    0, 16, 44,  4 }, {      3,   16,    0, 16, 44,  4 }, {      4,   16,    0, 16, 44,  4 },
    {      5,   16,    0, 16, 44,  4 }, {      6,   16,    0, 16, 44,  4 }, {      7,   16,    0, 16, 44,  4 }, {      8,   16,    0, 17, 44,  4 }, {      9,   15,    0, 17, 44,  4 },
    {     10,   15,    0, 17, 44,  4 }, {     11,   15,    0, 17, 44,  4 }, {     12,   15,    0, 17, 44,  4 }, {     13,   15,    0, 17, 44,  4 }, {     14,   15,    0, 17, 44,  4 },
    {     15,   14,    1, 17, 44,  4 }, {     16,   14,    1, 17, 44,  4 }, {     17,   14,    1, 17, 44,  4 }, {     18,   14,    1, 17, 44,  4 }, {     19,   14,    1, 17, 44,  4 },
    {     20,   13,    1, 17, 44,  4 }, {     21,   13,    1, 17, 44,  4 }, {     22,   13,    1, 18, 44,  4 }, {     23,   13,    1, 18, 44,  4 }, {     24,   12,    1, 18, 44,  4 },
    {     25,   12,    1, 18, 44,  4 }, {     26,   12,    1, 18, 44,  4 }, {     27,   11,    1, 18, 44,  4 }, {     28,   11,    1, 18, 44,  4 }, {     29,   11,    2, 18, 44,  4 },
    {     30,   10,    2, 18, 44,  4 }, {     31,   10,    2, 18, 44,  4 }, {     32,    9,    2, 18, 44,  4 }, {     33,    9,    2, 18, 44,  4 }, {     34,    8,    2, 18, 44,  4 },
    {     35,    8,    2, 18, 44,  4 }, {     36,    7,    2, 18, 44,  4 }, {     37,    7,    2, 19, 44,  4 }, {     38,    6,    2, 19, 44,  4 }, {     39,    6,    2, 19, 44,  4 },
    {     40,    5,    2, 19, 44,  4 }, {     41,    4,    2, 19, 44,  4 }, {     42,    4,    2, 19, 44,  4 }, {     43,    3,    2, 19, 44,  4 }, {     44,    2,    3, 19, 44,  4 },
    {     45,    2,    3, 19, 44,  4 }, {     46,    1,    3, 19, 44,  4 }, {     47,    0,    3, 19, 44,  4 }, {     48,    0,    3, 19, 44,  4 }, {     49,   -1,    3, 19, 44,  4 },
    {     50,   -2,    3, 20, 44,  4 }, {     51,   -3,    3, 20, 44,  4 }, {     52,   -3,    3, 20, 44,  4 }, {     53,   -4,    3, 20, 44,  4 }, {     54,   -5,    3, 20, 44,  4 },
    {     55,   -6,    3, 20, 44,  4 }, {     56,   -7,    3, 20, 44,  4 }, {     57,   -7,    3, 20, 44,  4 }, {     58,   -8,    4, 20, 44,  4 }, {     59,   -9,    4, 20, 44,  4 },
    {     60,  -10,    4, 20, 44,  4 }, {     61,  -11,    4, 20, 44,  4 }, {     61,  -12,    4, 20, 44,  4 }, {     62,  -13,    4, 21, 44,  4 }, {     63,  -14,    4, 21, 44,  4 },
    {     64,  -15,    4, 21, 44,  4 }, {     64,  -16,    4, 21, 44,  4 }, {     65,  -17,    4, 21, 44,  4 }, {     66,  -18,    4, 21, 44,  4 }, {     66,  -19,    4, 21, 44,  4 },
    {     67,  -20,    4, 21, 44,  4 }, {     68,  -21,    4, 21, 44,  4 }, {     68,  -22,    5, 21, 44,  4 }, {     69,  -23,    5, 21, 44,  4 }, {     70,  -24,    5, 21, 44,  4 },
    {     70,  -25,    5, 21, 44,  4 }, {     71,  -26,    5, 22, 44,  4 }, {     71,  -27,    5, 22, 44,  4 }, {     72,  -28,    5, 22, 44,  4 }, {     72,  -29,    5, 22, 44,  4 },
    {     73,  -30,    5, 22, 44,  4 }, {     73,  -31,    5, 22, 44,  4 }, {     74,  -32,    5, 22, 44,  4 }, {     74,  -33,    5, 22, 44,  4 }, {     75,  -34,    5, 22, 44,  4 },
    {     75,  -35,    5, 22, 44,  4 }, {     75,  -36,    5, 22, 44,  4 }, {     76,  -37,    6, 22, 44,  4 }, {     76,  -38,    6, 22, 44,  4 }, {     76,  -39,    6, 22, 44,  4 },
    {     77,  -40,    6, 23, 44,  4 }, {     77,  -41,    6, 23, 44,  4 }, {     77,  -42,    6, 23, 44,  4 }, {     77,  -43,    6, 23, 44,  4 }, {     78,  -44,    6, 23, 44,  4 },
    {     78,  -45,    6, 23, 44,  4 }, {     78,  -46,    6, 23, 44,  4 }, {     78,  -47,    6, 23, 44,  4 }, {     78,  -48,    6, 23, 44,  4 }, {     79,  -49,    6, 23, 44,  4 },
    {     79,  -50,    6, 23, 44,  4 }, {     79,  -51,    7, 23, 44,  4 }, {     79,  -52,    7, 23, 44,  4 }, {     79,  -53,    7, 23, 44,  4 }, {     79,  -54,    7, 23, 44,  4 },
    {     80,  -55,    7, 23, 44,  4 }, {     80,  -56,    7, 24, 44,  4 }, {     80,  -57,    7, 24, 44,  4 }, {     80,  -58,    7, 24, 44,  4 }, {     80,  -59,    7, 24, 44,  4 },
    {     80,  -60,    7, 24, 44,  4 }, {     80,  -61,    7, 24, 44,  4 }, {     80,  -62,    7, 24, 44,  4 }, {     80,  -63,    7, 24, 44,  4 }, {     80,  -64,    7, 24, 44,  4 },
    {     80,  -65,    8, 24, 44,  4 }, {     80,  -66,    8, 24, 44,  4 }, {     80,  -67,    8, 24, 44,  4 }, {     80,  -68,    8, 24, 44,  4 }, {     80,  -69,    8, 24, 44,  4 },
    {     80,  -70,    8, 24, 44,  4 }, {     80,  -71,    8, 24, 44,  4 }, {     80,  -72,    8, 25, 44,  4 }, {     79,  -73,    8, 25, 44,  4 }, {     79,  -74,    8, 25, 44,  4 },
    {     79,  -75,    8, 25, 44,  4 }, {     79,  -76,    8, 25, 44,  4 }, {     79,  -77,    8, 25, 44,  4 }, {     79,  -78,    8, 25, 44,  4 }, {     78,  -79,    9, 25, 44,  4 },
    {     78,  -80,    9, 25, 44,  4 }, {     78,  -81,    9, 25, 44,  4 }, {     78,  -82,    9, 25, 44,  4 }, {     78,  -83,    9, 25, 44,  4 }, {     77,  -84,    9, 25, 44,  4 },
    {     77,  -85,    9, 25, 44,  4 }, {     77,  -86,    9, 26, 44,  4 }, {     77,  -87,    9, 26, 44,  4 }, {     76,  -88,    9, 26, 44,  4 }, {     76,  -89,    9, 26, 44,  4 },
    {     76,  -90,    9, 26, 44,  4 }, {     75,  -91,    9, 26, 44,  4 }, {     75,  -92,    9, 26, 44,  4 }, {     75,  -93,   10, 26, 44,  4 }, {     74,  -94,   10, 26, 44,  4 },
    {     74,  -95,   10, 26, 44,  4 }, {     73,  -96,   10, 26, 44,  4 }, {     73,  -97,   10, 26, 44,  4 }, {     72,  -98,   10, 26, 44,  4 }, {     72,  -99,   10, 26, 44,  4 },
    {     71, -100,   10, 26, 44,  4 }, {     71, -101,   10, 27, 44,  4 }, {     70, -102,   10, 27, 44,  4 }, {     70, -103,   10, 27, 44,  4 }, {     69, -104,   10, 27, 44,  4 },
    {     68, -105,   10, 27, 44,  4 }, {     68, -106,   10, 27, 44,  4 }, {     67, -107,   11, 27, 44,  4 }, {     66, -108,   11, 27, 44,  4 }, {     66, -109,   11, 27, 44,  4 },
    {     65, -110,   11, 27, 44,  4 }, {     64, -111,   11, 27, 44,  4 }, {     64, -112,   11, 27, 44,  4 }, {     63, -113,   11, 27, 44,  4 }, {     62, -114,   11, 28, 44,  4 },
    {     61, -115,   11, 28, 44,  4 }, {     61, -116,   11, 28, 44,  4 }, {     60, -117,   11, 28, 44,  4 }, {     59, -118,   11, 28, 44,  4 }, {     58, -119,   11, 28, 44,  4 },
    {     57, -120,   11, 28, 44,  4 }, {     57, -121,   12, 28, 44,  4 }, {     56, -122,   12, 28, 44,  4 }, {     55, -123,   12, 28, 44,  4 }, {     54, -124,   12, 28, 44,  4 },
    {     53, -125,   12, 28, 44,  4 }, {     52, -125,   12, 28, 44,  4 }, {     51, -126,   12, 29, 44,  4 }, {     50, -127,   12, 29, 44,  4 }, {     49, -128,   12, 29, 44,  4 },
    {     48, -128,   12, 29, 44,  4 }, {     47, -129,   12, 29, 44,  4 }, {     46, -130,   12, 29, 44,  4 }, {     45, -130,   12, 29, 44,  4 }, {     44, -131,   12, 29, 44,  4 },
    {     43, -132,   12, 29, 44,  4 }, {     42, -132,   13, 29, 44,  4 }, {     41, -133,   13, 29, 44,  4 }, {     40, -134,   13, 29, 44,  4 }, {     39, -134,   13, 29, 44,  4 },
    {     38, -135,   13, 30, 44,  4 }, {     37, -135,   13, 30, 44,  4 }, {     36, -136,   13, 30, 44,  4 }, {     35, -136,   13, 30, 44,  4 }, {     34, -137,   13, 30, 44,  4 },
    {     33, -137,   13, 30, 44,  4 }, {     32, -138,   13, 30, 44,  4 }, {     31, -138,   13, 30, 44,  4 }, {     30, -139,   13, 30, 44,  4 }, {     29, -139,   13, 30, 44,  4 },
    {     28, -139,   14, 30, 44,  4 }, {     27, -140,   14, 30, 44,  4 }, {     26, -140,   14, 30, 44,  4 }, {     25, -140,   14, 30, 44,  4 }, {     24, -141,   14, 31, 44,  4 },
    {     23, -141,   14, 31, 44,  4 }, {     22, -141,   14, 31, 44,  4 }, {     21, -141,   14, 31, 44,  4 }, {     20, -142,   14, 31, 44,  4 }, {     19, -142,   14, 31, 44,  4 },
    {     18, -142,   14, 31, 44,  4 }, {     17, -142,   14, 31, 44,  4 }, {     16, -142,   14, 31, 44,  4 }, {     15, -143,   14, 31, 44,  4 }, {     14, -143,   15, 31, 44,  4 },
    {     13, -143,   15, 31, 44,  4 }, {     12, -143,   15, 31, 44,  4 }, {     11, -143,   15, 31, 44,  4 }, {     10, -143,   15, 31, 44,  4 }, {      9, -144,   15, 31, 44,  4 },
    {      8, -144,   15,  0, 44,  4 }, {      7, -144,   15,  0, 44,  4 }, {      6, -144,   15,  0, 44,  4 }, {      5, -144,   15,  0, 44,  4 }, {      4, -144,   15,  0, 44,  4 },
    {      3, -144,   15,  0, 44,  4 }, {      2, -144,   15,  0, 44,  4 }, {      1, -144,   15,  0, 44,  4 }, {      0, -144,   16,  0, 44,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F4455, {
    {     16,   31,    0, 24, 44,  4 }, {     16,   30,    0, 24, 44,  4 }, {     16,   29,    0, 24, 44,  4 }, {     16,   28,    0, 24, 44,  4 }, {     16,   27,    0, 24, 44,  4 },
    {     16,   26,    0, 24, 44,  4 }, {     16,   25,    0, 24, 44,  4 }, {     16,   24,    0, 25, 44,  4 }, {     15,   23,    0, 25, 44,  4 }, {     15,   22,    0, 25, 44,  4 },
    {     15,   21,    0, 25, 44,  4 }, {     15,   20,    0, 25, 44,  4 }, {     15,   19,    0, 25, 44,  4 }, {     15,   18,    0, 25, 44,  4 }, {     14,   17,    1, 25, 44,  4 },
    {     14,   16,    1, 25, 44,  4 }, {     14,   15,    1, 25, 44,  4 }, {     14,   14,    1, 25, 44,  4 }, {     14,   13,    1, 25, 44,  4 }, {     13,   12,    1, 25, 44,  4 },
    {     13,   11,    1, 25, 44,  4 }, {     13,   10,    1, 26, 44,  4 }, {     13,    9,    1, 26, 44,  4 }, {     12,    8,    1, 26, 44,  4 }, {     12,    7,    1, 26, 44,  4 },
    {     12,    6,    1, 26, 44,  4 }, {     11,    5,    1, 26, 44,  4 }, {     11,    4,    1, 26, 44,  4 }, {     11,    3,    2, 26, 44,  4 }, {     10,    2,    2, 26, 44,  4 },
    {     10,    1,    2, 26, 44,  4 }, {      9,    0,    2, 26, 44,  4 }, {      9,   -1,    2, 26, 44,  4 }, {      8,   -2,    2, 26, 44,  4 }, {      8,   -3,    2, 26, 44,  4 },
    {      7,   -4,    2, 26, 44,  4 }, {      7,   -5,    2, 27, 44,  4 }, {      6,   -6,    2, 27, 44,  4 }, {      6,   -7,    2, 27, 44,  4 }, {      5,   -8,    2, 27, 44,  4 },
    {      4,   -9,    2, 27, 44,  4 }, {      4,  -10,    2, 27, 44,  4 }, {      3,  -11,    3, 27, 44,  4 }, {      2,  -12,    3, 27, 44,  4 }, {      2,  -13,    3, 27, 44,  4 },
    {      1,  -14,    3, 27, 44,  4 }, {      0,  -15,    3, 27, 44,  4 }, {      0,  -16,    3, 27, 44,  4 }, {     -1,  -17,    3, 27, 44,  4 }, {     -2,  -18,    3, 28, 44,  4 },
    {     -3,  -19,    3, 28, 44,  4 }, {     -3,  -20,    3, 28, 44,  4 }, {     -4,  -21,    3, 28, 44,  4 }, {     -5,  -22,    3, 28, 44,  4 }, {     -6,  -23,    3, 28, 44,  4 },
    {     -7,  -24,    3, 28, 44,  4 }, {     -7,  -25,    4, 28, 44,  4 }, {     -8,  -26,    4, 28, 44,  4 }, {     -9,  -27,    4, 28, 44,  4 }, {    -10,  -28,    4, 28, 44,  4 },
    {    -11,  -29,    4, 28, 44,  4 }, {    -12,  -29,    4, 28, 44,  4 }, {    -13,  -30,    4, 29, 44,  4 }, {    -14,  -31,    4, 29, 44,  4 }, {    -15,  -32,    4, 29, 44,  4 },
    {    -16,  -32,    4, 29, 44,  4 }, {    -17,  -33,    4, 29, 44,  4 }, {    -18,  -34,    4, 29, 44,  4 }, {    -19,  -34,    4, 29, 44,  4 }, {    -20,  -35,    4, 29, 44,  4 },
    {    -21,  -36,    4, 29, 44,  4 }, {    -22,  -36,    5, 29, 44,  4 }, {    -23,  -37,    5, 29, 44,  4 }, {    -24,  -38,    5, 29, 44,  4 }, {    -25,  -38,    5, 29, 44,  4 },
    {    -26,  -39,    5, 30, 44,  4 }, {    -27,  -39,    5, 30, 44,  4 }, {    -28,  -40,    5, 30, 44,  4 }, {    -29,  -40,    5, 30, 44,  4 }, {    -30,  -41,    5, 30, 44,  4 },
    {    -31,  -41,    5, 30, 44,  4 }, {    -32,  -42,    5, 30, 44,  4 }, {    -33,  -42,    5, 30, 44,  4 }, {    -34,  -43,    5, 30, 44,  4 }, {    -35,  -43,    5, 30, 44,  4 },
    {    -36,  -43,    6, 30, 44,  4 }, {    -37,  -44,    6, 30, 44,  4 }, {    -38,  -44,    6, 30, 44,  4 }, {    -39,  -44,    6, 30, 44,  4 }, {    -40,  -45,    6, 31, 44,  4 },
    {    -41,  -45,    6, 31, 44,  4 }, {    -42,  -45,    6, 31, 44,  4 }, {    -43,  -45,    6, 31, 44,  4 }, {    -44,  -46,    6, 31, 44,  4 }, {    -45,  -46,    6, 31, 44,  4 },
    {    -46,  -46,    6, 31, 44,  4 }, {    -47,  -46,    6, 31, 44,  4 }, {    -48,  -46,    6, 31, 44,  4 }, {    -49,  -47,    6, 31, 44,  4 }, {    -50,  -47,    7, 31, 44,  4 },
    {    -51,  -47,    7, 31, 44,  4 }, {    -52,  -47,    7, 31, 44,  4 }, {    -53,  -47,    7, 31, 44,  4 }, {    -54,  -47,    7, 31, 44,  4 }, {    -55,  -48,    7, 31, 44,  4 },
    {    -56,  -48,    7,  0, 44,  4 }, {    -57,  -48,    7,  0, 44,  4 }, {    -58,  -48,    7,  0, 44,  4 }, {    -59,  -48,    7,  0, 44,  4 }, {    -60,  -48,    7,  0, 44,  4 },
    {    -61,  -48,    7,  0, 44,  4 }, {    -62,  -48,    7,  0, 44,  4 }, {    -63,  -48,    7,  0, 44,  4 }, {    -64,  -48,    8,  0, 44,  4 }, {    -65,  -48,    8,  0, 44,  4 },
    {    -66,  -48,    8,  0, 44,  4 }, {    -67,  -48,    8,  0, 44,  4 }, {    -68,  -48,    8,  0, 44,  4 }, {    -69,  -48,    8,  0, 44,  4 }, {    -70,  -48,    8,  0, 44,  4 },
    {    -71,  -48,    8,  0, 44,  4 }, {    -72,  -48,    8,  1, 44,  4 }, {    -73,  -47,    8,  1, 44,  4 }, {    -74,  -47,    8,  1, 44,  4 }, {    -75,  -47,    8,  1, 44,  4 },
    {    -76,  -47,    8,  1, 44,  4 }, {    -77,  -47,    8,  1, 44,  4 }, {    -78,  -47,    8,  1, 44,  4 }, {    -79,  -46,    9,  1, 44,  4 }, {    -80,  -46,    9,  1, 44,  4 },
    {    -81,  -46,    9,  1, 44,  4 }, {    -82,  -46,    9,  1, 44,  4 }, {    -83,  -46,    9,  1, 44,  4 }, {    -84,  -45,    9,  1, 44,  4 }, {    -85,  -45,    9,  1, 44,  4 },
    {    -86,  -45,    9,  2, 44,  4 }, {    -87,  -45,    9,  2, 44,  4 }, {    -88,  -44,    9,  2, 44,  4 }, {    -89,  -44,    9,  2, 44,  4 }, {    -90,  -44,    9,  2, 44,  4 },
    {    -91,  -43,    9,  2, 44,  4 }, {    -92,  -43,    9,  2, 44,  4 }, {    -93,  -43,   10,  2, 44,  4 }, {    -94,  -42,   10,  2, 44,  4 }, {    -95,  -42,   10,  2, 44,  4 },
    {    -96,  -41,   10,  2, 44,  4 }, {    -97,  -41,   10,  2, 44,  4 }, {    -98,  -40,   10,  2, 44,  4 }, {    -99,  -40,   10,  2, 44,  4 }, {   -100,  -39,   10,  2, 44,  4 },
    {   -101,  -39,   10,  3, 44,  4 }, {   -102,  -38,   10,  3, 44,  4 }, {   -103,  -38,   10,  3, 44,  4 }, {   -104,  -37,   10,  3, 44,  4 }, {   -105,  -36,   10,  3, 44,  4 },
    {   -106,  -36,   10,  3, 44,  4 }, {   -107,  -35,   11,  3, 44,  4 }, {   -108,  -34,   11,  3, 44,  4 }, {   -109,  -34,   11,  3, 44,  4 }, {   -110,  -33,   11,  3, 44,  4 },
    {   -111,  -32,   11,  3, 44,  4 }, {   -112,  -32,   11,  3, 44,  4 }, {   -113,  -31,   11,  3, 44,  4 }, {   -114,  -30,   11,  4, 44,  4 }, {   -115,  -29,   11,  4, 44,  4 },
    {   -116,  -29,   11,  4, 44,  4 }, {   -117,  -28,   11,  4, 44,  4 }, {   -118,  -27,   11,  4, 44,  4 }, {   -119,  -26,   11,  4, 44,  4 }, {   -120,  -25,   11,  4, 44,  4 },
    {   -121,  -25,   12,  4, 44,  4 }, {   -122,  -24,   12,  4, 44,  4 }, {   -123,  -23,   12,  4, 44,  4 }, {   -124,  -22,   12,  4, 44,  4 }, {   -125,  -21,   12,  4, 44,  4 },
    {   -125,  -20,   12,  4, 44,  4 }, {   -126,  -19,   12,  5, 44,  4 }, {   -127,  -18,   12,  5, 44,  4 }, {   -128,  -17,   12,  5, 44,  4 }, {   -128,  -16,   12,  5, 44,  4 },
    {   -129,  -15,   12,  5, 44,  4 }, {   -130,  -14,   12,  5, 44,  4 }, {   -130,  -13,   12,  5, 44,  4 }, {   -131,  -12,   12,  5, 44,  4 }, {   -132,  -11,   13,  5, 44,  4 },
    {   -132,  -10,   13,  5, 44,  4 }, {   -133,   -9,   13,  5, 44,  4 }, {   -134,   -8,   13,  5, 44,  4 }, {   -134,   -7,   13,  5, 44,  4 }, {   -135,   -6,   13,  6, 44,  4 },
    {   -135,   -5,   13,  6, 44,  4 }, {   -136,   -4,   13,  6, 44,  4 }, {   -136,   -3,   13,  6, 44,  4 }, {   -137,   -2,   13,  6, 44,  4 }, {   -137,   -1,   13,  6, 44,  4 },
    {   -138,    0,   13,  6, 44,  4 }, {   -138,    1,   13,  6, 44,  4 }, {   -139,    2,   13,  6, 44,  4 }, {   -139,    3,   14,  6, 44,  4 }, {   -139,    4,   14,  6, 44,  4 },
    {   -140,    5,   14,  6, 44,  4 }, {   -140,    6,   14,  6, 44,  4 }, {   -140,    7,   14,  6, 44,  4 }, {   -141,    8,   14,  7, 44,  4 }, {   -141,    9,   14,  7, 44,  4 },
    {   -141,   10,   14,  7, 44,  4 }, {   -141,   11,   14,  7, 44,  4 }, {   -142,   12,   14,  7, 44,  4 }, {   -142,   13,   14,  7, 44,  4 }, {   -142,   14,   14,  7, 44,  4 },
    {   -142,   15,   14,  7, 44,  4 }, {   -142,   16,   14,  7, 44,  4 }, {   -143,   17,   15,  7, 44,  4 }, {   -143,   18,   15,  7, 44,  4 }, {   -143,   19,   15,  7, 44,  4 },
    {   -143,   20,   15,  7, 44,  4 }, {   -143,   21,   15,  7, 44,  4 }, {   -143,   22,   15,  7, 44,  4 }, {   -144,   23,   15,  7, 44,  4 }, {   -144,   24,   15,  8, 44,  4 },
    {   -144,   25,   15,  8, 44,  4 }, {   -144,   26,   15,  8, 44,  4 }, {   -144,   27,   15,  8, 44,  4 }, {   -144,   28,   15,  8, 44,  4 }, {   -144,   29,   15,  8, 44,  4 },
    {   -144,   30,   15,  8, 44,  4 }, {   -144,   31,   16,  8, 44,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F4C52, {
    {     31,   16,    8,  0, 46,  2 }, {     30,   16,    8,  0, 46,  2 }, {     29,   16,    8,  0, 46,  2 }, {     28,   16,    8,  0, 46,  2 }, {     27,   16,    8,  0, 46,  2 },
    {     26,   16,    8,  0, 46,  2 }, {     25,   16,    8,  0, 46,  2 }, {     24,   16,    8, 31, 46,  2 }, {     23,   15,    8, 31, 46,  2 }, {     22,   15,    8, 31, 46,  2 },
    {     21,   15,    8, 31, 46,  2 }, {     20,   15,    8, 31, 46,  2 }, {     19,   15,    8, 31, 46,  2 }, {     18,   15,    8, 31, 46,  2 }, {     17,   14,    7, 31, 46,  2 },
    {     16,   14,    7, 31, 46,  2 }, {     15,   14,    7, 31, 46,  2 }, {     14,   14,    7, 31, 46,  2 }, {     13,   14,    7, 31, 46,  2 }, {     12,   13,    7, 31, 46,  2 },
    {     11,   13,    7, 31, 46,  2 }, {     10,   13,    7, 30, 46,  2 }, {      9,   13,    7, 30, 46,  2 }, {      8,   12,    7, 30, 46,  2 }, {      7,   12,    7, 30, 46,  2 },
    {      6,   12,    7, 30, 46,  2 }, {      5,   11,    7, 30, 46,  2 }, {      4,   11,    7, 30, 46,  2 }, {      3,   11,    6, 30, 46,  2 }, {      2,   10,    6, 30, 46,  2 },
    {      1,   10,    6, 30, 46,  2 }, {      0,    9,    6, 30, 46,  2 }, {     -1,    9,    6, 30, 46,  2 }, {     -2,    8,    6, 30, 46,  2 }, {     -3,    8,    6, 30, 46,  2 },
    {     -4,    7,    6, 30, 46,  2 }, {     -5,    7,    6, 29, 46,  2 }, {     -6,    6,    6, 29, 46,  2 }, {     -7,    6,    6, 29, 46,  2 }, {     -8,    5,    6, 29, 46,  2 },
    {     -9,    4,    6, 29, 46,  2 }, {    -10,    4,    6, 29, 46,  2 }, {    -11,    3,    5, 29, 46,  2 }, {    -12,    2,    5, 29, 46,  2 }, {    -13,    2,    5, 29, 46,  2 },
    {    -14,    1,    5, 29, 46,  2 }, {    -15,    0,    5, 29, 46,  2 }, {    -16,    0,    5, 29, 46,  2 }, {    -17,   -1,    5, 29, 46,  2 }, {    -18,   -2,    5, 28, 46,  2 },
    {    -19,   -3,    5, 28, 46,  2 }, {    -20,   -3,    5, 28, 46,  2 }, {    -21,   -4,    5, 28, 46,  2 }, {    -22,   -5,    5, 28, 46,  2 }, {    -23,   -6,    5, 28, 46,  2 },
    {    -24,   -7,    5, 28, 46,  2 }, {    -25,   -7,    4, 28, 46,  2 }, {    -26,   -8,    4, 28, 46,  2 }, {    -27,   -9,    4, 28, 46,  2 }, {    -28,  -10,    4, 28, 46,  2 },
    {    -29,  -11,    4, 28, 46,  2 }, {    -29,  -12,    4, 28, 46,  2 }, {    -30,  -13,    4, 27, 46,  2 }, {    -31,  -14,    4, 27, 46,  2 }, {    -32,  -15,    4, 27, 46,  2 },
    {    -32,  -16,    4, 27, 46,  2 }, {    -33,  -17,    4, 27, 46,  2 }, {    -34,  -18,    4, 27, 46,  2 }, {    -34,  -19,    4, 27, 46,  2 }, {    -35,  -20,    4, 27, 46,  2 },
    {    -36,  -21,    4, 27, 46,  2 }, {    -36,  -22,    3, 27, 46,  2 }, {    -37,  -23,    3, 27, 46,  2 }, {    -38,  -24,    3, 27, 46,  2 }, {    -38,  -25,    3, 27, 46,  2 },
    {    -39,  -26,    3, 26, 46,  2 }, {    -39,  -27,    3, 26, 46,  2 }, {    -40,  -28,    3, 26, 46,  2 }, {    -40,  -29,    3, 26, 46,  2 }, {    -41,  -30,    3, 26, 46,  2 },
    {    -41,  -31,    3, 26, 46,  2 }, {    -42,  -32,    3, 26, 46,  2 }, {    -42,  -33,    3, 26, 46,  2 }, {    -43,  -34,    3, 26, 46,  2 }, {    -43,  -35,    3, 26, 46,  2 },
    {    -43,  -36,    2, 26, 46,  2 }, {    -44,  -37,    2, 26, 46,  2 }, {    -44,  -38,    2, 26, 46,  2 }, {    -44,  -39,    2, 26, 46,  2 }, {    -45,  -40,    2, 25, 46,  2 },
    {    -45,  -41,    2, 25, 46,  2 }, {    -45,  -42,    2, 25, 46,  2 }, {    -45,  -43,    2, 25, 46,  2 }, {    -46,  -44,    2, 25, 46,  2 }, {    -46,  -45,    2, 25, 46,  2 },
    {    -46,  -46,    2, 25, 46,  2 }, {    -46,  -47,    2, 25, 46,  2 }, {    -46,  -48,    2, 25, 46,  2 }, {    -47,  -49,    2, 25, 46,  2 }, {    -47,  -50,    1, 25, 46,  2 },
    {    -47,  -51,    1, 25, 46,  2 }, {    -47,  -52,    1, 25, 46,  2 }, {    -47,  -53,    1, 25, 46,  2 }, {    -47,  -54,    1, 25, 46,  2 }, {    -48,  -55,    1, 25, 46,  2 },
    {    -48,  -56,    1, 24, 46,  2 }, {    -48,  -57,    1, 24, 46,  2 }, {    -48,  -58,    1, 24, 46,  2 }, {    -48,  -59,    1, 24, 46,  2 }, {    -48,  -60,    1, 24, 46,  2 },
    {    -48,  -61,    1, 24, 46,  2 }, {    -48,  -62,    1, 24, 46,  2 }, {    -48,  -63,    1, 24, 46,  2 }, {    -48,  -64,    0, 24, 46,  2 }, {    -48,  -65,    0, 24, 46,  2 },
    {    -48,  -66,    0, 24, 46,  2 }, {    -48,  -67,    0, 24, 46,  2 }, {    -48,  -68,    0, 24, 46,  2 }, {    -48,  -69,    0, 24, 46,  2 }, {    -48,  -70,    0, 24, 46,  2 },
    {    -48,  -71,    0, 24, 46,  2 }, {    -48,  -72,    0, 23, 46,  2 }, {    -47,  -73,    0, 23, 46,  2 }, {    -47,  -74,    0, 23, 46,  2 }, {    -47,  -75,    0, 23, 46,  2 },
    {    -47,  -76,    0, 23, 46,  2 }, {    -47,  -77,    0, 23, 46,  2 }, {    -47,  -78,    0, 23, 46,  2 }, {    -46,  -79,   -1, 23, 46,  2 }, {    -46,  -80,   -1, 23, 46,  2 },
    {    -46,  -81,   -1, 23, 46,  2 }, {    -46,  -82,   -1, 23, 46,  2 }, {    -46,  -83,   -1, 23, 46,  2 }, {    -45,  -84,   -1, 23, 46,  2 }, {    -45,  -85,   -1, 23, 46,  2 },
    {    -45,  -86,   -1, 22, 46,  2 }, {    -45,  -87,   -1, 22, 46,  2 }, {    -44,  -88,   -1, 22, 46,  2 }, {    -44,  -89,   -1, 22, 46,  2 }, {    -44,  -90,   -1, 22, 46,  2 },
    {    -43,  -91,   -1, 22, 46,  2 }, {    -43,  -92,   -1, 22, 46,  2 }, {    -43,  -93,   -2, 22, 46,  2 }, {    -42,  -94,   -2, 22, 46,  2 }, {    -42,  -95,   -2, 22, 46,  2 },
    {    -41,  -96,   -2, 22, 46,  2 }, {    -41,  -97,   -2, 22, 46,  2 }, {    -40,  -98,   -2, 22, 46,  2 }, {    -40,  -99,   -2, 22, 46,  2 }, {    -39, -100,   -2, 22, 46,  2 },
    {    -39, -101,   -2, 21, 46,  2 }, {    -38, -102,   -2, 21, 46,  2 }, {    -38, -103,   -2, 21, 46,  2 }, {    -37, -104,   -2, 21, 46,  2 }, {    -36, -105,   -2, 21, 46,  2 },
    {    -36, -106,   -2, 21, 46,  2 }, {    -35, -107,   -3, 21, 46,  2 }, {    -34, -108,   -3, 21, 46,  2 }, {    -34, -109,   -3, 21, 46,  2 }, {    -33, -110,   -3, 21, 46,  2 },
    {    -32, -111,   -3, 21, 46,  2 }, {    -32, -112,   -3, 21, 46,  2 }, {    -31, -113,   -3, 21, 46,  2 }, {    -30, -114,   -3, 20, 46,  2 }, {    -29, -115,   -3, 20, 46,  2 },
    {    -29, -116,   -3, 20, 46,  2 }, {    -28, -117,   -3, 20, 46,  2 }, {    -27, -118,   -3, 20, 46,  2 }, {    -26, -119,   -3, 20, 46,  2 }, {    -25, -120,   -3, 20, 46,  2 },
    {    -25, -121,   -4, 20, 46,  2 }, {    -24, -122,   -4, 20, 46,  2 }, {    -23, -123,   -4, 20, 46,  2 }, {    -22, -124,   -4, 20, 46,  2 }, {    -21, -125,   -4, 20, 46,  2 },
    {    -20, -125,   -4, 20, 46,  2 }, {    -19, -126,   -4, 19, 46,  2 }, {    -18, -127,   -4, 19, 46,  2 }, {    -17, -128,   -4, 19, 46,  2 }, {    -16, -128,   -4, 19, 46,  2 },
    {    -15, -129,   -4, 19, 46,  2 }, {    -14, -130,   -4, 19, 46,  2 }, {    -13, -130,   -4, 19, 46,  2 }, {    -12, -131,   -4, 19, 46,  2 }, {    -11, -132,   -5, 19, 46,  2 },
    {    -10, -132,   -5, 19, 46,  2 }, {     -9, -133,   -5, 19, 46,  2 }, {     -8, -134,   -5, 19, 46,  2 }, {     -7, -134,   -5, 19, 46,  2 }, {     -6, -135,   -5, 18, 46,  2 },
    {     -5, -135,   -5, 18, 46,  2 }, {     -4, -136,   -5, 18, 46,  2 }, {     -3, -136,   -5, 18, 46,  2 }, {     -2, -137,   -5, 18, 46,  2 }, {     -1, -137,   -5, 18, 46,  2 },
    {      0, -138,   -5, 18, 46,  2 }, {      1, -138,   -5, 18, 46,  2 }, {      2, -139,   -5, 18, 46,  2 }, {      3, -139,   -6, 18, 46,  2 }, {      4, -139,   -6, 18, 46,  2 },
    {      5, -140,   -6, 18, 46,  2 }, {      6, -140,   -6, 18, 46,  2 }, {      7, -140,   -6, 18, 46,  2 }, {      8, -141,   -6, 17, 46,  2 }, {      9, -141,   -6, 17, 46,  2 },
    {     10, -141,   -6, 17, 46,  2 }, {     11, -141,   -6, 17, 46,  2 }, {     12, -142,   -6, 17, 46,  2 }, {     13, -142,   -6, 17, 46,  2 }, {     14, -142,   -6, 17, 46,  2 },
    {     15, -142,   -6, 17, 46,  2 }, {     16, -142,   -6, 17, 46,  2 }, {     17, -143,   -7, 17, 46,  2 }, {     18, -143,   -7, 17, 46,  2 }, {     19, -143,   -7, 17, 46,  2 },
    {     20, -143,   -7, 17, 46,  2 }, {     21, -143,   -7, 17, 46,  2 }, {     22, -143,   -7, 17, 46,  2 }, {     23, -144,   -7, 17, 46,  2 }, {     24, -144,   -7, 16, 46,  2 },
    {     25, -144,   -7, 16, 46,  2 }, {     26, -144,   -7, 16, 46,  2 }, {     27, -144,   -7, 16, 46,  2 }, {     28, -144,   -7, 16, 46,  2 }, {     29, -144,   -7, 16, 46,  2 },
    {     30, -144,   -7, 16, 46,  2 }, {     31, -144,   -8, 16, 46,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F544F, {
    {     16,    0,    8,  8, 46,  2 }, {     16,    1,    8,  8, 46,  2 }, {     16,    2,    8,  8, 46,  2 }, {     16,    3,    8,  8, 46,  2 }, {     16,    4,    8,  8, 46,  2 },
    {     16,    5,    8,  8, 46,  2 }, {     16,    6,    8,  8, 46,  2 }, {     16,    7,    8,  8, 46,  2 }, {     16,    8,    8,  7, 46,  2 }, {     15,    9,    8,  7, 46,  2 },
    {     15,   10,    8,  7, 46,  2 }, {     15,   11,    8,  7, 46,  2 }, {     15,   12,    8,  7, 46,  2 }, {     15,   13,    8,  7, 46,  2 }, {     15,   14,    8,  7, 46,  2 },
    {     14,   15,    7,  7, 46,  2 }, {     14,   16,    7,  7, 46,  2 }, {     14,   17,    7,  7, 46,  2 }, {     14,   18,    7,  7, 46,  2 }, {     14,   19,    7,  7, 46,  2 },
    {     13,   20,    7,  7, 46,  2 }, {     13,   21,    7,  7, 46,  2 }, {     13,   22,    7,  6, 46,  2 }, {     13,   23,    7,  6, 46,  2 }, {     12,   24,    7,  6, 46,  2 },
    {     12,   25,    7,  6, 46,  2 }, {     12,   26,    7,  6, 46,  2 }, {     11,   27,    7,  6, 46,  2 }, {     11,   28,    7,  6, 46,  2 }, {     11,   29,    6,  6, 46,  2 },
    {     10,   30,    6,  6, 46,  2 }, {     10,   31,    6,  6, 46,  2 }, {      9,   32,    6,  6, 46,  2 }, {      9,   33,    6,  6, 46,  2 }, {      8,   34,    6,  6, 46,  2 },
    {      8,   35,    6,  6, 46,  2 }, {      7,   36,    6,  6, 46,  2 }, {      7,   37,    6,  5, 46,  2 }, {      6,   38,    6,  5, 46,  2 }, {      6,   39,    6,  5, 46,  2 },
    {      5,   40,    6,  5, 46,  2 }, {      4,   41,    6,  5, 46,  2 }, {      4,   42,    6,  5, 46,  2 }, {      3,   43,    6,  5, 46,  2 }, {      2,   44,    5,  5, 46,  2 },
    {      2,   45,    5,  5, 46,  2 }, {      1,   46,    5,  5, 46,  2 }, {      0,   47,    5,  5, 46,  2 }, {      0,   48,    5,  5, 46,  2 }, {     -1,   49,    5,  5, 46,  2 },
    {     -2,   50,    5,  4, 46,  2 }, {     -3,   51,    5,  4, 46,  2 }, {     -3,   52,    5,  4, 46,  2 }, {     -4,   53,    5,  4, 46,  2 }, {     -5,   54,    5,  4, 46,  2 },
    {     -6,   55,    5,  4, 46,  2 }, {     -7,   56,    5,  4, 46,  2 }, {     -7,   57,    5,  4, 46,  2 }, {     -8,   58,    4,  4, 46,  2 }, {     -9,   59,    4,  4, 46,  2 },
    {    -10,   60,    4,  4, 46,  2 }, {    -11,   61,    4,  4, 46,  2 }, {    -12,   61,    4,  4, 46,  2 }, {    -13,   62,    4,  3, 46,  2 }, {    -14,   63,    4,  3, 46,  2 },
    {    -15,   64,    4,  3, 46,  2 }, {    -16,   64,    4,  3, 46,  2 }, {    -17,   65,    4,  3, 46,  2 }, {    -18,   66,    4,  3, 46,  2 }, {    -19,   66,    4,  3, 46,  2 },
    {    -20,   67,    4,  3, 46,  2 }, {    -21,   68,    4,  3, 46,  2 }, {    -22,   68,    3,  3, 46,  2 }, {    -23,   69,    3,  3, 46,  2 }, {    -24,   70,    3,  3, 46,  2 },
    {    -25,   70,    3,  3, 46,  2 }, {    -26,   71,    3,  2, 46,  2 }, {    -27,   71,    3,  2, 46,  2 }, {    -28,   72,    3,  2, 46,  2 }, {    -29,   72,    3,  2, 46,  2 },
    {    -30,   73,    3,  2, 46,  2 }, {    -31,   73,    3,  2, 46,  2 }, {    -32,   74,    3,  2, 46,  2 }, {    -33,   74,    3,  2, 46,  2 }, {    -34,   75,    3,  2, 46,  2 },
    {    -35,   75,    3,  2, 46,  2 }, {    -36,   75,    3,  2, 46,  2 }, {    -37,   76,    2,  2, 46,  2 }, {    -38,   76,    2,  2, 46,  2 }, {    -39,   76,    2,  2, 46,  2 },
    {    -40,   77,    2,  1, 46,  2 }, {    -41,   77,    2,  1, 46,  2 }, {    -42,   77,    2,  1, 46,  2 }, {    -43,   77,    2,  1, 46,  2 }, {    -44,   78,    2,  1, 46,  2 },
    {    -45,   78,    2,  1, 46,  2 }, {    -46,   78,    2,  1, 46,  2 }, {    -47,   78,    2,  1, 46,  2 }, {    -48,   78,    2,  1, 46,  2 }, {    -49,   79,    2,  1, 46,  2 },
    {    -50,   79,    2,  1, 46,  2 }, {    -51,   79,    1,  1, 46,  2 }, {    -52,   79,    1,  1, 46,  2 }, {    -53,   79,    1,  1, 46,  2 }, {    -54,   79,    1,  1, 46,  2 },
    {    -55,   80,    1,  1, 46,  2 }, {    -56,   80,    1,  0, 46,  2 }, {    -57,   80,    1,  0, 46,  2 }, {    -58,   80,    1,  0, 46,  2 }, {    -59,   80,    1,  0, 46,  2 },
    {    -60,   80,    1,  0, 46,  2 }, {    -61,   80,    1,  0, 46,  2 }, {    -62,   80,    1,  0, 46,  2 }, {    -63,   80,    1,  0, 46,  2 }, {    -64,   80,    1,  0, 46,  2 },
    {    -65,   80,    0,  0, 46,  2 }, {    -66,   80,    0,  0, 46,  2 }, {    -67,   80,    0,  0, 46,  2 }, {    -68,   80,    0,  0, 46,  2 }, {    -69,   80,    0,  0, 46,  2 },
    {    -70,   80,    0,  0, 46,  2 }, {    -71,   80,    0,  0, 46,  2 }, {    -72,   80,    0, 31, 46,  2 }, {    -73,   79,    0, 31, 46,  2 }, {    -74,   79,    0, 31, 46,  2 },
    {    -75,   79,    0, 31, 46,  2 }, {    -76,   79,    0, 31, 46,  2 }, {    -77,   79,    0, 31, 46,  2 }, {    -78,   79,    0, 31, 46,  2 }, {    -79,   78,   -1, 31, 46,  2 },
    {    -80,   78,   -1, 31, 46,  2 }, {    -81,   78,   -1, 31, 46,  2 }, {    -82,   78,   -1, 31, 46,  2 }, {    -83,   78,   -1, 31, 46,  2 }, {    -84,   77,   -1, 31, 46,  2 },
    {    -85,   77,   -1, 31, 46,  2 }, {    -86,   77,   -1, 30, 46,  2 }, {    -87,   77,   -1, 30, 46,  2 }, {    -88,   76,   -1, 30, 46,  2 }, {    -89,   76,   -1, 30, 46,  2 },
    {    -90,   76,   -1, 30, 46,  2 }, {    -91,   75,   -1, 30, 46,  2 }, {    -92,   75,   -1, 30, 46,  2 }, {    -93,   75,   -2, 30, 46,  2 }, {    -94,   74,   -2, 30, 46,  2 },
    {    -95,   74,   -2, 30, 46,  2 }, {    -96,   73,   -2, 30, 46,  2 }, {    -97,   73,   -2, 30, 46,  2 }, {    -98,   72,   -2, 30, 46,  2 }, {    -99,   72,   -2, 30, 46,  2 },
    {   -100,   71,   -2, 30, 46,  2 }, {   -101,   71,   -2, 29, 46,  2 }, {   -102,   70,   -2, 29, 46,  2 }, {   -103,   70,   -2, 29, 46,  2 }, {   -104,   69,   -2, 29, 46,  2 },
    {   -105,   68,   -2, 29, 46,  2 }, {   -106,   68,   -2, 29, 46,  2 }, {   -107,   67,   -3, 29, 46,  2 }, {   -108,   66,   -3, 29, 46,  2 }, {   -109,   66,   -3, 29, 46,  2 },
    {   -110,   65,   -3, 29, 46,  2 }, {   -111,   64,   -3, 29, 46,  2 }, {   -112,   64,   -3, 29, 46,  2 }, {   -113,   63,   -3, 29, 46,  2 }, {   -114,   62,   -3, 28, 46,  2 },
    {   -115,   61,   -3, 28, 46,  2 }, {   -116,   61,   -3, 28, 46,  2 }, {   -117,   60,   -3, 28, 46,  2 }, {   -118,   59,   -3, 28, 46,  2 }, {   -119,   58,   -3, 28, 46,  2 },
    {   -120,   57,   -3, 28, 46,  2 }, {   -121,   57,   -4, 28, 46,  2 }, {   -122,   56,   -4, 28, 46,  2 }, {   -123,   55,   -4, 28, 46,  2 }, {   -124,   54,   -4, 28, 46,  2 },
    {   -125,   53,   -4, 28, 46,  2 }, {   -125,   52,   -4, 28, 46,  2 }, {   -126,   51,   -4, 27, 46,  2 }, {   -127,   50,   -4, 27, 46,  2 }, {   -128,   49,   -4, 27, 46,  2 },
    {   -128,   48,   -4, 27, 46,  2 }, {   -129,   47,   -4, 27, 46,  2 }, {   -130,   46,   -4, 27, 46,  2 }, {   -130,   45,   -4, 27, 46,  2 }, {   -131,   44,   -4, 27, 46,  2 },
    {   -132,   43,   -4, 27, 46,  2 }, {   -132,   42,   -5, 27, 46,  2 }, {   -133,   41,   -5, 27, 46,  2 }, {   -134,   40,   -5, 27, 46,  2 }, {   -134,   39,   -5, 27, 46,  2 },
    {   -135,   38,   -5, 26, 46,  2 }, {   -135,   37,   -5, 26, 46,  2 }, {   -136,   36,   -5, 26, 46,  2 }, {   -136,   35,   -5, 26, 46,  2 }, {   -137,   34,   -5, 26, 46,  2 },
    {   -137,   33,   -5, 26, 46,  2 }, {   -138,   32,   -5, 26, 46,  2 }, {   -138,   31,   -5, 26, 46,  2 }, {   -139,   30,   -5, 26, 46,  2 }, {   -139,   29,   -5, 26, 46,  2 },
    {   -139,   28,   -6, 26, 46,  2 }, {   -140,   27,   -6, 26, 46,  2 }, {   -140,   26,   -6, 26, 46,  2 }, {   -140,   25,   -6, 26, 46,  2 }, {   -141,   24,   -6, 25, 46,  2 },
    {   -141,   23,   -6, 25, 46,  2 }, {   -141,   22,   -6, 25, 46,  2 }, {   -141,   21,   -6, 25, 46,  2 }, {   -142,   20,   -6, 25, 46,  2 }, {   -142,   19,   -6, 25, 46,  2 },
    {   -142,   18,   -6, 25, 46,  2 }, {   -142,   17,   -6, 25, 46,  2 }, {   -142,   16,   -6, 25, 46,  2 }, {   -143,   15,   -6, 25, 46,  2 }, {   -143,   14,   -7, 25, 46,  2 },
    {   -143,   13,   -7, 25, 46,  2 }, {   -143,   12,   -7, 25, 46,  2 }, {   -143,   11,   -7, 25, 46,  2 }, {   -143,   10,   -7, 25, 46,  2 }, {   -144,    9,   -7, 25, 46,  2 },
    {   -144,    8,   -7, 24, 46,  2 }, {   -144,    7,   -7, 24, 46,  2 }, {   -144,    6,   -7, 24, 46,  2 }, {   -144,    5,   -7, 24, 46,  2 }, {   -144,    4,   -7, 24, 46,  2 },
    {   -144,    3,   -7, 24, 46,  2 }, {   -144,    2,   -7, 24, 46,  2 }, {   -144,    1,   -7, 24, 46,  2 }, {   -144,    0,   -8, 24, 46,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F5C5E, {
    {      0,   16,    8, 16, 46,  2 }, {      1,   16,    8, 16, 46,  2 }, {      2,   16,    8, 16, 46,  2 }, {      3,   16,    8, 16, 46,  2 }, {      4,   16,    8, 16, 46,  2 },
    {      5,   16,    8, 16, 46,  2 }, {      6,   16,    8, 16, 46,  2 }, {      7,   16,    8, 16, 46,  2 }, {      8,   16,    8, 15, 46,  2 }, {      9,   17,    8, 15, 46,  2 },
    {     10,   17,    8, 15, 46,  2 }, {     11,   17,    8, 15, 46,  2 }, {     12,   17,    8, 15, 46,  2 }, {     13,   17,    8, 15, 46,  2 }, {     14,   17,    8, 15, 46,  2 },
    {     15,   18,    7, 15, 46,  2 }, {     16,   18,    7, 15, 46,  2 }, {     17,   18,    7, 15, 46,  2 }, {     18,   18,    7, 15, 46,  2 }, {     19,   18,    7, 15, 46,  2 },
    {     20,   19,    7, 15, 46,  2 }, {     21,   19,    7, 15, 46,  2 }, {     22,   19,    7, 14, 46,  2 }, {     23,   19,    7, 14, 46,  2 }, {     24,   20,    7, 14, 46,  2 },
    {     25,   20,    7, 14, 46,  2 }, {     26,   20,    7, 14, 46,  2 }, {     27,   21,    7, 14, 46,  2 }, {     28,   21,    7, 14, 46,  2 }, {     29,   21,    6, 14, 46,  2 },
    {     30,   22,    6, 14, 46,  2 }, {     31,   22,    6, 14, 46,  2 }, {     32,   23,    6, 14, 46,  2 }, {     33,   23,    6, 14, 46,  2 }, {     34,   24,    6, 14, 46,  2 },
    {     35,   24,    6, 14, 46,  2 }, {     36,   25,    6, 14, 46,  2 }, {     37,   25,    6, 13, 46,  2 }, {     38,   26,    6, 13, 46,  2 }, {     39,   26,    6, 13, 46,  2 },
    {     40,   27,    6, 13, 46,  2 }, {     41,   28,    6, 13, 46,  2 }, {     42,   28,    6, 13, 46,  2 }, {     43,   29,    5, 13, 46,  2 }, {     44,   30,    5, 13, 46,  2 },
    {     45,   30,    5, 13, 46,  2 }, {     46,   31,    5, 13, 46,  2 }, {     47,   32,    5, 13, 46,  2 }, {     48,   32,    5, 13, 46,  2 }, {     49,   33,    5, 13, 46,  2 },
    {     50,   34,    5, 12, 46,  2 }, {     51,   35,    5, 12, 46,  2 }, {     52,   35,    5, 12, 46,  2 }, {     53,   36,    5, 12, 46,  2 }, {     54,   37,    5, 12, 46,  2 },
    {     55,   38,    5, 12, 46,  2 }, {     56,   39,    5, 12, 46,  2 }, {     57,   39,    4, 12, 46,  2 }, {     58,   40,    4, 12, 46,  2 }, {     59,   41,    4, 12, 46,  2 },
    {     60,   42,    4, 12, 46,  2 }, {     61,   43,    4, 12, 46,  2 }, {     61,   44,    4, 12, 46,  2 }, {     62,   45,    4, 11, 46,  2 }, {     63,   46,    4, 11, 46,  2 },
    {     64,   47,    4, 11, 46,  2 }, {     64,   48,    4, 11, 46,  2 }, {     65,   49,    4, 11, 46,  2 }, {     66,   50,    4, 11, 46,  2 }, {     66,   51,    4, 11, 46,  2 },
    {     67,   52,    4, 11, 46,  2 }, {     68,   53,    4, 11, 46,  2 }, {     68,   54,    3, 11, 46,  2 }, {     69,   55,    3, 11, 46,  2 }, {     70,   56,    3, 11, 46,  2 },
    {     70,   57,    3, 11, 46,  2 }, {     71,   58,    3, 10, 46,  2 }, {     71,   59,    3, 10, 46,  2 }, {     72,   60,    3, 10, 46,  2 }, {     72,   61,    3, 10, 46,  2 },
    {     73,   62,    3, 10, 46,  2 }, {     73,   63,    3, 10, 46,  2 }, {     74,   64,    3, 10, 46,  2 }, {     74,   65,    3, 10, 46,  2 }, {     75,   66,    3, 10, 46,  2 },
    {     75,   67,    3, 10, 46,  2 }, {     75,   68,    2, 10, 46,  2 }, {     76,   69,    2, 10, 46,  2 }, {     76,   70,    2, 10, 46,  2 }, {     76,   71,    2, 10, 46,  2 },
    {     77,   72,    2,  9, 46,  2 }, {     77,   73,    2,  9, 46,  2 }, {     77,   74,    2,  9, 46,  2 }, {     77,   75,    2,  9, 46,  2 }, {     78,   76,    2,  9, 46,  2 },
    {     78,   77,    2,  9, 46,  2 }, {     78,   78,    2,  9, 46,  2 }, {     78,   79,    2,  9, 46,  2 }, {     78,   80,    2,  9, 46,  2 }, {     79,   81,    2,  9, 46,  2 },
    {     79,   82,    1,  9, 46,  2 }, {     79,   83,    1,  9, 46,  2 }, {     79,   84,    1,  9, 46,  2 }, {     79,   85,    1,  9, 46,  2 }, {     79,   86,    1,  9, 46,  2 },
    {     80,   87,    1,  9, 46,  2 }, {     80,   88,    1,  8, 46,  2 }, {     80,   89,    1,  8, 46,  2 }, {     80,   90,    1,  8, 46,  2 }, {     80,   91,    1,  8, 46,  2 },
    {     80,   92,    1,  8, 46,  2 }, {     80,   93,    1,  8, 46,  2 }, {     80,   94,    1,  8, 46,  2 }, {     80,   95,    1,  8, 46,  2 }, {     80,   96,    0,  8, 46,  2 },
    {     80,   97,    0,  8, 46,  2 }, {     80,   98,    0,  8, 46,  2 }, {     80,   99,    0,  8, 46,  2 }, {     80,  100,    0,  8, 46,  2 }, {     80,  101,    0,  8, 46,  2 },
    {     80,  102,    0,  8, 46,  2 }, {     80,  103,    0,  8, 46,  2 }, {     80,  104,    0,  7, 46,  2 }, {     79,  105,    0,  7, 46,  2 }, {     79,  106,    0,  7, 46,  2 },
    {     79,  107,    0,  7, 46,  2 }, {     79,  108,    0,  7, 46,  2 }, {     79,  109,    0,  7, 46,  2 }, {     79,  110,    0,  7, 46,  2 }, {     78,  111,   -1,  7, 46,  2 },
    {     78,  112,   -1,  7, 46,  2 }, {     78,  113,   -1,  7, 46,  2 }, {     78,  114,   -1,  7, 46,  2 }, {     78,  115,   -1,  7, 46,  2 }, {     77,  116,   -1,  7, 46,  2 },
    {     77,  117,   -1,  7, 46,  2 }, {     77,  118,   -1,  6, 46,  2 }, {     77,  119,   -1,  6, 46,  2 }, {     76,  120,   -1,  6, 46,  2 }, {     76,  121,   -1,  6, 46,  2 },
    {     76,  122,   -1,  6, 46,  2 }, {     75,  123,   -1,  6, 46,  2 }, {     75,  124,   -1,  6, 46,  2 }, {     75,  125,   -2,  6, 46,  2 }, {     74,  126,   -2,  6, 46,  2 },
    {     74,  127,   -2,  6, 46,  2 }, {     73,  128,   -2,  6, 46,  2 }, {     73,  129,   -2,  6, 46,  2 }, {     72,  130,   -2,  6, 46,  2 }, {     72,  131,   -2,  6, 46,  2 },
    {     71,  132,   -2,  6, 46,  2 }, {     71,  133,   -2,  5, 46,  2 }, {     70,  134,   -2,  5, 46,  2 }, {     70,  135,   -2,  5, 46,  2 }, {     69,  136,   -2,  5, 46,  2 },
    {     68,  137,   -2,  5, 46,  2 }, {     68,  138,   -2,  5, 46,  2 }, {     67,  139,   -2,  5, 46,  2 }, {     66,  140,   -3,  5, 46,  2 }, {     66,  141,   -3,  5, 46,  2 },
    {     65,  142,   -3,  5, 46,  2 }, {     64,  143,   -3,  5, 46,  2 }, {     64,  144,   -3,  5, 46,  2 }, {     63,  145,   -3,  5, 46,  2 }, {     62,  146,   -3,  4, 46,  2 },
    {     61,  147,   -3,  4, 46,  2 }, {     61,  148,   -3,  4, 46,  2 }, {     60,  149,   -3,  4, 46,  2 }, {     59,  150,   -3,  4, 46,  2 }, {     58,  151,   -3,  4, 46,  2 },
    {     57,  152,   -3,  4, 46,  2 }, {     57,  153,   -3,  4, 46,  2 }, {     56,  154,   -4,  4, 46,  2 }, {     55,  155,   -4,  4, 46,  2 }, {     54,  156,   -4,  4, 46,  2 },
    {     53,  157,   -4,  4, 46,  2 }, {     52,  157,   -4,  4, 46,  2 }, {     51,  158,   -4,  3, 46,  2 }, {     50,  159,   -4,  3, 46,  2 }, {     49,  160,   -4,  3, 46,  2 },
    {     48,  160,   -4,  3, 46,  2 }, {     47,  161,   -4,  3, 46,  2 }, {     46,  162,   -4,  3, 46,  2 }, {     45,  162,   -4,  3, 46,  2 }, {     44,  163,   -4,  3, 46,  2 },
    {     43,  164,   -4,  3, 46,  2 }, {     42,  164,   -5,  3, 46,  2 }, {     41,  165,   -5,  3, 46,  2 }, {     40,  166,   -5,  3, 46,  2 }, {     39,  166,   -5,  3, 46,  2 },
    {     38,  167,   -5,  2, 46,  2 }, {     37,  167,   -5,  2, 46,  2 }, {     36,  168,   -5,  2, 46,  2 }, {     35,  168,   -5,  2, 46,  2 }, {     34,  169,   -5,  2, 46,  2 },
    {     33,  169,   -5,  2, 46,  2 }, {     32,  170,   -5,  2, 46,  2 }, {     31,  170,   -5,  2, 46,  2 }, {     30,  171,   -5,  2, 46,  2 }, {     29,  171,   -5,  2, 46,  2 },
    {     28,  171,   -5,  2, 46,  2 }, {     27,  172,   -6,  2, 46,  2 }, {     26,  172,   -6,  2, 46,  2 }, {     25,  172,   -6,  2, 46,  2 }, {     24,  173,   -6,  1, 46,  2 },
    {     23,  173,   -6,  1, 46,  2 }, {     22,  173,   -6,  1, 46,  2 }, {     21,  173,   -6,  1, 46,  2 }, {     20,  174,   -6,  1, 46,  2 }, {     19,  174,   -6,  1, 46,  2 },
    {     18,  174,   -6,  1, 46,  2 }, {     17,  174,   -6,  1, 46,  2 }, {     16,  174,   -6,  1, 46,  2 }, {     15,  175,   -6,  1, 46,  2 }, {     14,  175,   -6,  1, 46,  2 },
    {     13,  175,   -7,  1, 46,  2 }, {     12,  175,   -7,  1, 46,  2 }, {     11,  175,   -7,  1, 46,  2 }, {     10,  175,   -7,  1, 46,  2 }, {      9,  176,   -7,  1, 46,  2 },
    {      8,  176,   -7,  0, 46,  2 }, {      7,  176,   -7,  0, 46,  2 }, {      6,  176,   -7,  0, 46,  2 }, {      5,  176,   -7,  0, 46,  2 }, {      4,  176,   -7,  0, 46,  2 },
    {      3,  176,   -7,  0, 46,  2 }, {      2,  176,   -7,  0, 46,  2 }, {      1,  176,   -7,  0, 46,  2 }, {      0,  176,   -7,  0, 46,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F646D, {
    {     16,   31,    8, 24, 46,  2 }, {     16,   30,    8, 24, 46,  2 }, {     16,   29,    8, 24, 46,  2 }, {     16,   28,    8, 24, 46,  2 }, {     16,   27,    8, 24, 46,  2 },
    {     16,   26,    8, 24, 46,  2 }, {     16,   25,    8, 24, 46,  2 }, {     16,   24,    8, 23, 46,  2 }, {     17,   23,    8, 23, 46,  2 }, {     17,   22,    8, 23, 46,  2 },
    {     17,   21,    8, 23, 46,  2 }, {     17,   20,    8, 23, 46,  2 }, {     17,   19,    8, 23, 46,  2 }, {     17,   18,    8, 23, 46,  2 }, {     18,   17,    7, 23, 46,  2 },
    {     18,   16,    7, 23, 46,  2 }, {     18,   15,    7, 23, 46,  2 }, {     18,   14,    7, 23, 46,  2 }, {     18,   13,    7, 23, 46,  2 }, {     19,   12,    7, 23, 46,  2 },
    {     19,   11,    7, 23, 46,  2 }, {     19,   10,    7, 22, 46,  2 }, {     19,    9,    7, 22, 46,  2 }, {     20,    8,    7, 22, 46,  2 }, {     20,    7,    7, 22, 46,  2 },
    {     20,    6,    7, 22, 46,  2 }, {     21,    5,    7, 22, 46,  2 }, {     21,    4,    7, 22, 46,  2 }, {     21,    3,    6, 22, 46,  2 }, {     22,    2,    6, 22, 46,  2 },
    {     22,    1,    6, 22, 46,  2 }, {     23,    0,    6, 22, 46,  2 }, {     23,   -1,    6, 22, 46,  2 }, {     24,   -2,    6, 22, 46,  2 }, {     24,   -3,    6, 22, 46,  2 },
    {     25,   -4,    6, 22, 46,  2 }, {     25,   -5,    6, 21, 46,  2 }, {     26,   -6,    6, 21, 46,  2 }, {     26,   -7,    6, 21, 46,  2 }, {     27,   -8,    6, 21, 46,  2 },
    {     28,   -9,    6, 21, 46,  2 }, {     28,  -10,    6, 21, 46,  2 }, {     29,  -11,    5, 21, 46,  2 }, {     30,  -12,    5, 21, 46,  2 }, {     30,  -13,    5, 21, 46,  2 },
    {     31,  -14,    5, 21, 46,  2 }, {     32,  -15,    5, 21, 46,  2 }, {     32,  -16,    5, 21, 46,  2 }, {     33,  -17,    5, 21, 46,  2 }, {     34,  -18,    5, 20, 46,  2 },
    {     35,  -19,    5, 20, 46,  2 }, {     35,  -20,    5, 20, 46,  2 }, {     36,  -21,    5, 20, 46,  2 }, {     37,  -22,    5, 20, 46,  2 }, {     38,  -23,    5, 20, 46,  2 },
    {     39,  -24,    5, 20, 46,  2 }, {     39,  -25,    4, 20, 46,  2 }, {     40,  -26,    4, 20, 46,  2 }, {     41,  -27,    4, 20, 46,  2 }, {     42,  -28,    4, 20, 46,  2 },
    {     43,  -29,    4, 20, 46,  2 }, {     44,  -29,    4, 20, 46,  2 }, {     45,  -30,    4, 19, 46,  2 }, {     46,  -31,    4, 19, 46,  2 }, {     47,  -32,    4, 19, 46,  2 },
    {     48,  -32,    4, 19, 46,  2 }, {     49,  -33,    4, 19, 46,  2 }, {     50,  -34,    4, 19, 46,  2 }, {     51,  -34,    4, 19, 46,  2 }, {     52,  -35,    4, 19, 46,  2 },
    {     53,  -36,    3, 19, 46,  2 }, {     54,  -36,    3, 19, 46,  2 }, {     55,  -37,    3, 19, 46,  2 }, {     56,  -38,    3, 19, 46,  2 }, {     57,  -38,    3, 19, 46,  2 },
    {     58,  -39,    3, 18, 46,  2 }, {     59,  -39,    3, 18, 46,  2 }, {     60,  -40,    3, 18, 46,  2 }, {     61,  -40,    3, 18, 46,  2 }, {     62,  -41,    3, 18, 46,  2 },
    {     63,  -41,    3, 18, 46,  2 }, {     64,  -42,    3, 18, 46,  2 }, {     65,  -42,    3, 18, 46,  2 }, {     66,  -43,    3, 18, 46,  2 }, {     67,  -43,    2, 18, 46,  2 },
    {     68,  -43,    2, 18, 46,  2 }, {     69,  -44,    2, 18, 46,  2 }, {     70,  -44,    2, 18, 46,  2 }, {     71,  -44,    2, 18, 46,  2 }, {     72,  -45,    2, 17, 46,  2 },
    {     73,  -45,    2, 17, 46,  2 }, {     74,  -45,    2, 17, 46,  2 }, {     75,  -45,    2, 17, 46,  2 }, {     76,  -46,    2, 17, 46,  2 }, {     77,  -46,    2, 17, 46,  2 },
    {     78,  -46,    2, 17, 46,  2 }, {     79,  -46,    2, 17, 46,  2 }, {     80,  -46,    2, 17, 46,  2 }, {     81,  -47,    1, 17, 46,  2 }, {     82,  -47,    1, 17, 46,  2 },
    {     83,  -47,    1, 17, 46,  2 }, {     84,  -47,    1, 17, 46,  2 }, {     85,  -47,    1, 17, 46,  2 }, {     86,  -47,    1, 17, 46,  2 }, {     87,  -48,    1, 17, 46,  2 },
    {     88,  -48,    1, 16, 46,  2 }, {     89,  -48,    1, 16, 46,  2 }, {     90,  -48,    1, 16, 46,  2 }, {     91,  -48,    1, 16, 46,  2 }, {     92,  -48,    1, 16, 46,  2 },
    {     93,  -48,    1, 16, 46,  2 }, {     94,  -48,    1, 16, 46,  2 }, {     95,  -48,    0, 16, 46,  2 }, {     96,  -48,    0, 16, 46,  2 }, {     97,  -48,    0, 16, 46,  2 },
    {     98,  -48,    0, 16, 46,  2 }, {     99,  -48,    0, 16, 46,  2 }, {    100,  -48,    0, 16, 46,  2 }, {    101,  -48,    0, 16, 46,  2 }, {    102,  -48,    0, 16, 46,  2 },
    {    103,  -48,    0, 16, 46,  2 }, {    104,  -48,    0, 15, 46,  2 }, {    105,  -47,    0, 15, 46,  2 }, {    106,  -47,    0, 15, 46,  2 }, {    107,  -47,    0, 15, 46,  2 },
    {    108,  -47,    0, 15, 46,  2 }, {    109,  -47,    0, 15, 46,  2 }, {    110,  -47,    0, 15, 46,  2 }, {    111,  -46,   -1, 15, 46,  2 }, {    112,  -46,   -1, 15, 46,  2 },
    {    113,  -46,   -1, 15, 46,  2 }, {    114,  -46,   -1, 15, 46,  2 }, {    115,  -46,   -1, 15, 46,  2 }, {    116,  -45,   -1, 15, 46,  2 }, {    117,  -45,   -1, 15, 46,  2 },
    {    118,  -45,   -1, 14, 46,  2 }, {    119,  -45,   -1, 14, 46,  2 }, {    120,  -44,   -1, 14, 46,  2 }, {    121,  -44,   -1, 14, 46,  2 }, {    122,  -44,   -1, 14, 46,  2 },
    {    123,  -43,   -1, 14, 46,  2 }, {    124,  -43,   -1, 14, 46,  2 }, {    125,  -43,   -2, 14, 46,  2 }, {    126,  -42,   -2, 14, 46,  2 }, {    127,  -42,   -2, 14, 46,  2 },
    {    128,  -41,   -2, 14, 46,  2 }, {    129,  -41,   -2, 14, 46,  2 }, {    130,  -40,   -2, 14, 46,  2 }, {    131,  -40,   -2, 14, 46,  2 }, {    132,  -39,   -2, 14, 46,  2 },
    {    133,  -39,   -2, 13, 46,  2 }, {    134,  -38,   -2, 13, 46,  2 }, {    135,  -38,   -2, 13, 46,  2 }, {    136,  -37,   -2, 13, 46,  2 }, {    137,  -36,   -2, 13, 46,  2 },
    {    138,  -36,   -2, 13, 46,  2 }, {    139,  -35,   -3, 13, 46,  2 }, {    140,  -34,   -3, 13, 46,  2 }, {    141,  -34,   -3, 13, 46,  2 }, {    142,  -33,   -3, 13, 46,  2 },
    {    143,  -32,   -3, 13, 46,  2 }, {    144,  -32,   -3, 13, 46,  2 }, {    145,  -31,   -3, 13, 46,  2 }, {    146,  -30,   -3, 12, 46,  2 }, {    147,  -29,   -3, 12, 46,  2 },
    {    148,  -29,   -3, 12, 46,  2 }, {    149,  -28,   -3, 12, 46,  2 }, {    150,  -27,   -3, 12, 46,  2 }, {    151,  -26,   -3, 12, 46,  2 }, {    152,  -25,   -3, 12, 46,  2 },
    {    153,  -25,   -4, 12, 46,  2 }, {    154,  -24,   -4, 12, 46,  2 }, {    155,  -23,   -4, 12, 46,  2 }, {    156,  -22,   -4, 12, 46,  2 }, {    157,  -21,   -4, 12, 46,  2 },
    {    157,  -20,   -4, 12, 46,  2 }, {    158,  -19,   -4, 11, 46,  2 }, {    159,  -18,   -4, 11, 46,  2 }, {    160,  -17,   -4, 11, 46,  2 }, {    160,  -16,   -4, 11, 46,  2 },
    {    161,  -15,   -4, 11, 46,  2 }, {    162,  -14,   -4, 11, 46,  2 }, {    162,  -13,   -4, 11, 46,  2 }, {    163,  -12,   -4, 11, 46,  2 }, {    164,  -11,   -4, 11, 46,  2 },
    {    164,  -10,   -5, 11, 46,  2 }, {    165,   -9,   -5, 11, 46,  2 }, {    166,   -8,   -5, 11, 46,  2 }, {    166,   -7,   -5, 11, 46,  2 }, {    167,   -6,   -5, 10, 46,  2 },
    {    167,   -5,   -5, 10, 46,  2 }, {    168,   -4,   -5, 10, 46,  2 }, {    168,   -3,   -5, 10, 46,  2 }, {    169,   -2,   -5, 10, 46,  2 }, {    169,   -1,   -5, 10, 46,  2 },
    {    170,    0,   -5, 10, 46,  2 }, {    170,    1,   -5, 10, 46,  2 }, {    171,    2,   -5, 10, 46,  2 }, {    171,    3,   -5, 10, 46,  2 }, {    171,    4,   -6, 10, 46,  2 },
    {    172,    5,   -6, 10, 46,  2 }, {    172,    6,   -6, 10, 46,  2 }, {    172,    7,   -6, 10, 46,  2 }, {    173,    8,   -6,  9, 46,  2 }, {    173,    9,   -6,  9, 46,  2 },
    {    173,   10,   -6,  9, 46,  2 }, {    173,   11,   -6,  9, 46,  2 }, {    174,   12,   -6,  9, 46,  2 }, {    174,   13,   -6,  9, 46,  2 }, {    174,   14,   -6,  9, 46,  2 },
    {    174,   15,   -6,  9, 46,  2 }, {    174,   16,   -6,  9, 46,  2 }, {    175,   17,   -6,  9, 46,  2 }, {    175,   18,   -7,  9, 46,  2 }, {    175,   19,   -7,  9, 46,  2 },
    {    175,   20,   -7,  9, 46,  2 }, {    175,   21,   -7,  9, 46,  2 }, {    175,   22,   -7,  9, 46,  2 }, {    176,   23,   -7,  9, 46,  2 }, {    176,   24,   -7,  8, 46,  2 },
    {    176,   25,   -7,  8, 46,  2 }, {    176,   26,   -7,  8, 46,  2 }, {    176,   27,   -7,  8, 46,  2 }, {    176,   28,   -7,  8, 46,  2 }, {    176,   29,   -7,  8, 46,  2 },
    {    176,   30,   -7,  8, 46,  2 }, {    176,   31,   -7,  8, 46,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F6C6A, {
    {     31,   16,    8,  0, 46,  4 }, {     30,   16,    8,  0, 46,  4 }, {     29,   16,    8,  0, 46,  4 }, {     28,   16,    8,  0, 46,  4 }, {     27,   16,    8,  0, 46,  4 },
    {     26,   16,    8,  0, 46,  4 }, {     25,   16,    8,  0, 46,  4 }, {     24,   16,    8,  1, 46,  4 }, {     23,   17,    8,  1, 46,  4 }, {     22,   17,    8,  1, 46,  4 },
    {     21,   17,    8,  1, 46,  4 }, {     20,   17,    8,  1, 46,  4 }, {     19,   17,    8,  1, 46,  4 }, {     18,   17,    8,  1, 46,  4 }, {     17,   18,    7,  1, 46,  4 },
    {     16,   18,    7,  1, 46,  4 }, {     15,   18,    7,  1, 46,  4 }, {     14,   18,    7,  1, 46,  4 }, {     13,   18,    7,  1, 46,  4 }, {     12,   19,    7,  1, 46,  4 },
    {     11,   19,    7,  1, 46,  4 }, {     10,   19,    7,  2, 46,  4 }, {      9,   19,    7,  2, 46,  4 }, {      8,   20,    7,  2, 46,  4 }, {      7,   20,    7,  2, 46,  4 },
    {      6,   20,    7,  2, 46,  4 }, {      5,   21,    7,  2, 46,  4 }, {      4,   21,    7,  2, 46,  4 }, {      3,   21,    6,  2, 46,  4 }, {      2,   22,    6,  2, 46,  4 },
    {      1,   22,    6,  2, 46,  4 }, {      0,   23,    6,  2, 46,  4 }, {     -1,   23,    6,  2, 46,  4 }, {     -2,   24,    6,  2, 46,  4 }, {     -3,   24,    6,  2, 46,  4 },
    {     -4,   25,    6,  2, 46,  4 }, {     -5,   25,    6,  3, 46,  4 }, {     -6,   26,    6,  3, 46,  4 }, {     -7,   26,    6,  3, 46,  4 }, {     -8,   27,    6,  3, 46,  4 },
    {     -9,   28,    6,  3, 46,  4 }, {    -10,   28,    6,  3, 46,  4 }, {    -11,   29,    5,  3, 46,  4 }, {    -12,   30,    5,  3, 46,  4 }, {    -13,   30,    5,  3, 46,  4 },
    {    -14,   31,    5,  3, 46,  4 }, {    -15,   32,    5,  3, 46,  4 }, {    -16,   32,    5,  3, 46,  4 }, {    -17,   33,    5,  3, 46,  4 }, {    -18,   34,    5,  4, 46,  4 },
    {    -19,   35,    5,  4, 46,  4 }, {    -20,   35,    5,  4, 46,  4 }, {    -21,   36,    5,  4, 46,  4 }, {    -22,   37,    5,  4, 46,  4 }, {    -23,   38,    5,  4, 46,  4 },
    {    -24,   39,    5,  4, 46,  4 }, {    -25,   39,    4,  4, 46,  4 }, {    -26,   40,    4,  4, 46,  4 }, {    -27,   41,    4,  4, 46,  4 }, {    -28,   42,    4,  4, 46,  4 },
    {    -29,   43,    4,  4, 46,  4 }, {    -29,   44,    4,  4, 46,  4 }, {    -30,   45,    4,  5, 46,  4 }, {    -31,   46,    4,  5, 46,  4 }, {    -32,   47,    4,  5, 46,  4 },
    {    -32,   48,    4,  5, 46,  4 }, {    -33,   49,    4,  5, 46,  4 }, {    -34,   50,    4,  5, 46,  4 }, {    -34,   51,    4,  5, 46,  4 }, {    -35,   52,    4,  5, 46,  4 },
    {    -36,   53,    3,  5, 46,  4 }, {    -36,   54,    3,  5, 46,  4 }, {    -37,   55,    3,  5, 46,  4 }, {    -38,   56,    3,  5, 46,  4 }, {    -38,   57,    3,  5, 46,  4 },
    {    -39,   58,    3,  6, 46,  4 }, {    -39,   59,    3,  6, 46,  4 }, {    -40,   60,    3,  6, 46,  4 }, {    -40,   61,    3,  6, 46,  4 }, {    -41,   62,    3,  6, 46,  4 },
    {    -41,   63,    3,  6, 46,  4 }, {    -42,   64,    3,  6, 46,  4 }, {    -42,   65,    3,  6, 46,  4 }, {    -43,   66,    3,  6, 46,  4 }, {    -43,   67,    2,  6, 46,  4 },
    {    -43,   68,    2,  6, 46,  4 }, {    -44,   69,    2,  6, 46,  4 }, {    -44,   70,    2,  6, 46,  4 }, {    -44,   71,    2,  6, 46,  4 }, {    -45,   72,    2,  7, 46,  4 },
    {    -45,   73,    2,  7, 46,  4 }, {    -45,   74,    2,  7, 46,  4 }, {    -45,   75,    2,  7, 46,  4 }, {    -46,   76,    2,  7, 46,  4 }, {    -46,   77,    2,  7, 46,  4 },
    {    -46,   78,    2,  7, 46,  4 }, {    -46,   79,    2,  7, 46,  4 }, {    -46,   80,    2,  7, 46,  4 }, {    -47,   81,    1,  7, 46,  4 }, {    -47,   82,    1,  7, 46,  4 },
    {    -47,   83,    1,  7, 46,  4 }, {    -47,   84,    1,  7, 46,  4 }, {    -47,   85,    1,  7, 46,  4 }, {    -47,   86,    1,  7, 46,  4 }, {    -48,   87,    1,  7, 46,  4 },
    {    -48,   88,    1,  8, 46,  4 }, {    -48,   89,    1,  8, 46,  4 }, {    -48,   90,    1,  8, 46,  4 }, {    -48,   91,    1,  8, 46,  4 }, {    -48,   92,    1,  8, 46,  4 },
    {    -48,   93,    1,  8, 46,  4 }, {    -48,   94,    1,  8, 46,  4 }, {    -48,   95,    0,  8, 46,  4 }, {    -48,   96,    0,  8, 46,  4 }, {    -48,   97,    0,  8, 46,  4 },
    {    -48,   98,    0,  8, 46,  4 }, {    -48,   99,    0,  8, 46,  4 }, {    -48,  100,    0,  8, 46,  4 }, {    -48,  101,    0,  8, 46,  4 }, {    -48,  102,    0,  8, 46,  4 },
    {    -48,  103,    0,  8, 46,  4 }, {    -48,  104,    0,  9, 46,  4 }, {    -47,  105,    0,  9, 46,  4 }, {    -47,  106,    0,  9, 46,  4 }, {    -47,  107,    0,  9, 46,  4 },
    {    -47,  108,    0,  9, 46,  4 }, {    -47,  109,    0,  9, 46,  4 }, {    -47,  110,    0,  9, 46,  4 }, {    -46,  111,   -1,  9, 46,  4 }, {    -46,  112,   -1,  9, 46,  4 },
    {    -46,  113,   -1,  9, 46,  4 }, {    -46,  114,   -1,  9, 46,  4 }, {    -46,  115,   -1,  9, 46,  4 }, {    -45,  116,   -1,  9, 46,  4 }, {    -45,  117,   -1,  9, 46,  4 },
    {    -45,  118,   -1, 10, 46,  4 }, {    -45,  119,   -1, 10, 46,  4 }, {    -44,  120,   -1, 10, 46,  4 }, {    -44,  121,   -1, 10, 46,  4 }, {    -44,  122,   -1, 10, 46,  4 },
    {    -43,  123,   -1, 10, 46,  4 }, {    -43,  124,   -1, 10, 46,  4 }, {    -43,  125,   -2, 10, 46,  4 }, {    -42,  126,   -2, 10, 46,  4 }, {    -42,  127,   -2, 10, 46,  4 },
    {    -41,  128,   -2, 10, 46,  4 }, {    -41,  129,   -2, 10, 46,  4 }, {    -40,  130,   -2, 10, 46,  4 }, {    -40,  131,   -2, 10, 46,  4 }, {    -39,  132,   -2, 10, 46,  4 },
    {    -39,  133,   -2, 11, 46,  4 }, {    -38,  134,   -2, 11, 46,  4 }, {    -38,  135,   -2, 11, 46,  4 }, {    -37,  136,   -2, 11, 46,  4 }, {    -36,  137,   -2, 11, 46,  4 },
    {    -36,  138,   -2, 11, 46,  4 }, {    -35,  139,   -3, 11, 46,  4 }, {    -34,  140,   -3, 11, 46,  4 }, {    -34,  141,   -3, 11, 46,  4 }, {    -33,  142,   -3, 11, 46,  4 },
    {    -32,  143,   -3, 11, 46,  4 }, {    -32,  144,   -3, 11, 46,  4 }, {    -31,  145,   -3, 11, 46,  4 }, {    -30,  146,   -3, 12, 46,  4 }, {    -29,  147,   -3, 12, 46,  4 },
    {    -29,  148,   -3, 12, 46,  4 }, {    -28,  149,   -3, 12, 46,  4 }, {    -27,  150,   -3, 12, 46,  4 }, {    -26,  151,   -3, 12, 46,  4 }, {    -25,  152,   -3, 12, 46,  4 },
    {    -25,  153,   -4, 12, 46,  4 }, {    -24,  154,   -4, 12, 46,  4 }, {    -23,  155,   -4, 12, 46,  4 }, {    -22,  156,   -4, 12, 46,  4 }, {    -21,  157,   -4, 12, 46,  4 },
    {    -20,  157,   -4, 12, 46,  4 }, {    -19,  158,   -4, 13, 46,  4 }, {    -18,  159,   -4, 13, 46,  4 }, {    -17,  160,   -4, 13, 46,  4 }, {    -16,  160,   -4, 13, 46,  4 },
    {    -15,  161,   -4, 13, 46,  4 }, {    -14,  162,   -4, 13, 46,  4 }, {    -13,  162,   -4, 13, 46,  4 }, {    -12,  163,   -4, 13, 46,  4 }, {    -11,  164,   -4, 13, 46,  4 },
    {    -10,  164,   -5, 13, 46,  4 }, {     -9,  165,   -5, 13, 46,  4 }, {     -8,  166,   -5, 13, 46,  4 }, {     -7,  166,   -5, 13, 46,  4 }, {     -6,  167,   -5, 14, 46,  4 },
    {     -5,  167,   -5, 14, 46,  4 }, {     -4,  168,   -5, 14, 46,  4 }, {     -3,  168,   -5, 14, 46,  4 }, {     -2,  169,   -5, 14, 46,  4 }, {     -1,  169,   -5, 14, 46,  4 },
    {      0,  170,   -5, 14, 46,  4 }, {      1,  170,   -5, 14, 46,  4 }, {      2,  171,   -5, 14, 46,  4 }, {      3,  171,   -5, 14, 46,  4 }, {      4,  171,   -6, 14, 46,  4 },
    {      5,  172,   -6, 14, 46,  4 }, {      6,  172,   -6, 14, 46,  4 }, {      7,  172,   -6, 14, 46,  4 }, {      8,  173,   -6, 15, 46,  4 }, {      9,  173,   -6, 15, 46,  4 },
    {     10,  173,   -6, 15, 46,  4 }, {     11,  173,   -6, 15, 46,  4 }, {     12,  174,   -6, 15, 46,  4 }, {     13,  174,   -6, 15, 46,  4 }, {     14,  174,   -6, 15, 46,  4 },
    {     15,  174,   -6, 15, 46,  4 }, {     16,  174,   -6, 15, 46,  4 }, {     17,  175,   -6, 15, 46,  4 }, {     18,  175,   -7, 15, 46,  4 }, {     19,  175,   -7, 15, 46,  4 },
    {     20,  175,   -7, 15, 46,  4 }, {     21,  175,   -7, 15, 46,  4 }, {     22,  175,   -7, 15, 46,  4 }, {     23,  176,   -7, 15, 46,  4 }, {     24,  176,   -7, 16, 46,  4 },
    {     25,  176,   -7, 16, 46,  4 }, {     26,  176,   -7, 16, 46,  4 }, {     27,  176,   -7, 16, 46,  4 }, {     28,  176,   -7, 16, 46,  4 }, {     29,  176,   -7, 16, 46,  4 },
    {     30,  176,   -7, 16, 46,  4 }, {     31,  176,   -7, 16, 46,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F7467, {
    {     16,    0,    8,  8, 46,  4 }, {     16,    1,    8,  8, 46,  4 }, {     16,    2,    8,  8, 46,  4 }, {     16,    3,    8,  8, 46,  4 }, {     16,    4,    8,  8, 46,  4 },
    {     16,    5,    8,  8, 46,  4 }, {     16,    6,    8,  8, 46,  4 }, {     16,    7,    8,  8, 46,  4 }, {     16,    8,    8,  9, 46,  4 }, {     17,    9,    8,  9, 46,  4 },
    {     17,   10,    8,  9, 46,  4 }, {     17,   11,    8,  9, 46,  4 }, {     17,   12,    8,  9, 46,  4 }, {     17,   13,    8,  9, 46,  4 }, {     17,   14,    8,  9, 46,  4 },
    {     18,   15,    7,  9, 46,  4 }, {     18,   16,    7,  9, 46,  4 }, {     18,   17,    7,  9, 46,  4 }, {     18,   18,    7,  9, 46,  4 }, {     18,   19,    7,  9, 46,  4 },
    {     19,   20,    7,  9, 46,  4 }, {     19,   21,    7,  9, 46,  4 }, {     19,   22,    7, 10, 46,  4 }, {     19,   23,    7, 10, 46,  4 }, {     20,   24,    7, 10, 46,  4 },
    {     20,   25,    7, 10, 46,  4 }, {     20,   26,    7, 10, 46,  4 }, {     21,   27,    7, 10, 46,  4 }, {     21,   28,    7, 10, 46,  4 }, {     21,   29,    6, 10, 46,  4 },
    {     22,   30,    6, 10, 46,  4 }, {     22,   31,    6, 10, 46,  4 }, {     23,   32,    6, 10, 46,  4 }, {     23,   33,    6, 10, 46,  4 }, {     24,   34,    6, 10, 46,  4 },
    {     24,   35,    6, 10, 46,  4 }, {     25,   36,    6, 10, 46,  4 }, {     25,   37,    6, 11, 46,  4 }, {     26,   38,    6, 11, 46,  4 }, {     26,   39,    6, 11, 46,  4 },
    {     27,   40,    6, 11, 46,  4 }, {     28,   41,    6, 11, 46,  4 }, {     28,   42,    6, 11, 46,  4 }, {     29,   43,    5, 11, 46,  4 }, {     30,   44,    5, 11, 46,  4 },
    {     30,   45,    5, 11, 46,  4 }, {     31,   46,    5, 11, 46,  4 }, {     32,   47,    5, 11, 46,  4 }, {     32,   48,    5, 11, 46,  4 }, {     33,   49,    5, 11, 46,  4 },
    {     34,   50,    5, 12, 46,  4 }, {     35,   51,    5, 12, 46,  4 }, {     35,   52,    5, 12, 46,  4 }, {     36,   53,    5, 12, 46,  4 }, {     37,   54,    5, 12, 46,  4 },
    {     38,   55,    5, 12, 46,  4 }, {     39,   56,    5, 12, 46,  4 }, {     39,   57,    4, 12, 46,  4 }, {     40,   58,    4, 12, 46,  4 }, {     41,   59,    4, 12, 46,  4 },
    {     42,   60,    4, 12, 46,  4 }, {     43,   61,    4, 12, 46,  4 }, {     44,   61,    4, 12, 46,  4 }, {     45,   62,    4, 13, 46,  4 }, {     46,   63,    4, 13, 46,  4 },
    {     47,   64,    4, 13, 46,  4 }, {     48,   64,    4, 13, 46,  4 }, {     49,   65,    4, 13, 46,  4 }, {     50,   66,    4, 13, 46,  4 }, {     51,   66,    4, 13, 46,  4 },
    {     52,   67,    4, 13, 46,  4 }, {     53,   68,    4, 13, 46,  4 }, {     54,   68,    3, 13, 46,  4 }, {     55,   69,    3, 13, 46,  4 }, {     56,   70,    3, 13, 46,  4 },
    {     57,   70,    3, 13, 46,  4 }, {     58,   71,    3, 14, 46,  4 }, {     59,   71,    3, 14, 46,  4 }, {     60,   72,    3, 14, 46,  4 }, {     61,   72,    3, 14, 46,  4 },
    {     62,   73,    3, 14, 46,  4 }, {     63,   73,    3, 14, 46,  4 }, {     64,   74,    3, 14, 46,  4 }, {     65,   74,    3, 14, 46,  4 }, {     66,   75,    3, 14, 46,  4 },
    {     67,   75,    3, 14, 46,  4 }, {     68,   75,    2, 14, 46,  4 }, {     69,   76,    2, 14, 46,  4 }, {     70,   76,    2, 14, 46,  4 }, {     71,   76,    2, 14, 46,  4 },
    {     72,   77,    2, 15, 46,  4 }, {     73,   77,    2, 15, 46,  4 }, {     74,   77,    2, 15, 46,  4 }, {     75,   77,    2, 15, 46,  4 }, {     76,   78,    2, 15, 46,  4 },
    {     77,   78,    2, 15, 46,  4 }, {     78,   78,    2, 15, 46,  4 }, {     79,   78,    2, 15, 46,  4 }, {     80,   78,    2, 15, 46,  4 }, {     81,   79,    2, 15, 46,  4 },
    {     82,   79,    1, 15, 46,  4 }, {     83,   79,    1, 15, 46,  4 }, {     84,   79,    1, 15, 46,  4 }, {     85,   79,    1, 15, 46,  4 }, {     86,   79,    1, 15, 46,  4 },
    {     87,   80,    1, 15, 46,  4 }, {     88,   80,    1, 16, 46,  4 }, {     89,   80,    1, 16, 46,  4 }, {     90,   80,    1, 16, 46,  4 }, {     91,   80,    1, 16, 46,  4 },
    {     92,   80,    1, 16, 46,  4 }, {     93,   80,    1, 16, 46,  4 }, {     94,   80,    1, 16, 46,  4 }, {     95,   80,    1, 16, 46,  4 }, {     96,   80,    0, 16, 46,  4 },
    {     97,   80,    0, 16, 46,  4 }, {     98,   80,    0, 16, 46,  4 }, {     99,   80,    0, 16, 46,  4 }, {    100,   80,    0, 16, 46,  4 }, {    101,   80,    0, 16, 46,  4 },
    {    102,   80,    0, 16, 46,  4 }, {    103,   80,    0, 16, 46,  4 }, {    104,   80,    0, 17, 46,  4 }, {    105,   79,    0, 17, 46,  4 }, {    106,   79,    0, 17, 46,  4 },
    {    107,   79,    0, 17, 46,  4 }, {    108,   79,    0, 17, 46,  4 }, {    109,   79,    0, 17, 46,  4 }, {    110,   79,    0, 17, 46,  4 }, {    111,   78,   -1, 17, 46,  4 },
    {    112,   78,   -1, 17, 46,  4 }, {    113,   78,   -1, 17, 46,  4 }, {    114,   78,   -1, 17, 46,  4 }, {    115,   78,   -1, 17, 46,  4 }, {    116,   77,   -1, 17, 46,  4 },
    {    117,   77,   -1, 17, 46,  4 }, {    118,   77,   -1, 18, 46,  4 }, {    119,   77,   -1, 18, 46,  4 }, {    120,   76,   -1, 18, 46,  4 }, {    121,   76,   -1, 18, 46,  4 },
    {    122,   76,   -1, 18, 46,  4 }, {    123,   75,   -1, 18, 46,  4 }, {    124,   75,   -1, 18, 46,  4 }, {    125,   75,   -2, 18, 46,  4 }, {    126,   74,   -2, 18, 46,  4 },
    {    127,   74,   -2, 18, 46,  4 }, {    128,   73,   -2, 18, 46,  4 }, {    129,   73,   -2, 18, 46,  4 }, {    130,   72,   -2, 18, 46,  4 }, {    131,   72,   -2, 18, 46,  4 },
    {    132,   71,   -2, 18, 46,  4 }, {    133,   71,   -2, 19, 46,  4 }, {    134,   70,   -2, 19, 46,  4 }, {    135,   70,   -2, 19, 46,  4 }, {    136,   69,   -2, 19, 46,  4 },
    {    137,   68,   -2, 19, 46,  4 }, {    138,   68,   -2, 19, 46,  4 }, {    139,   67,   -2, 19, 46,  4 }, {    140,   66,   -3, 19, 46,  4 }, {    141,   66,   -3, 19, 46,  4 },
    {    142,   65,   -3, 19, 46,  4 }, {    143,   64,   -3, 19, 46,  4 }, {    144,   64,   -3, 19, 46,  4 }, {    145,   63,   -3, 19, 46,  4 }, {    146,   62,   -3, 20, 46,  4 },
    {    147,   61,   -3, 20, 46,  4 }, {    148,   61,   -3, 20, 46,  4 }, {    149,   60,   -3, 20, 46,  4 }, {    150,   59,   -3, 20, 46,  4 }, {    151,   58,   -3, 20, 46,  4 },
    {    152,   57,   -3, 20, 46,  4 }, {    153,   57,   -3, 20, 46,  4 }, {    154,   56,   -4, 20, 46,  4 }, {    155,   55,   -4, 20, 46,  4 }, {    156,   54,   -4, 20, 46,  4 },
    {    157,   53,   -4, 20, 46,  4 }, {    157,   52,   -4, 20, 46,  4 }, {    158,   51,   -4, 21, 46,  4 }, {    159,   50,   -4, 21, 46,  4 }, {    160,   49,   -4, 21, 46,  4 },
    {    160,   48,   -4, 21, 46,  4 }, {    161,   47,   -4, 21, 46,  4 }, {    162,   46,   -4, 21, 46,  4 }, {    162,   45,   -4, 21, 46,  4 }, {    163,   44,   -4, 21, 46,  4 },
    {    164,   43,   -4, 21, 46,  4 }, {    164,   42,   -5, 21, 46,  4 }, {    165,   41,   -5, 21, 46,  4 }, {    166,   40,   -5, 21, 46,  4 }, {    166,   39,   -5, 21, 46,  4 },
    {    167,   38,   -5, 22, 46,  4 }, {    167,   37,   -5, 22, 46,  4 }, {    168,   36,   -5, 22, 46,  4 }, {    168,   35,   -5, 22, 46,  4 }, {    169,   34,   -5, 22, 46,  4 },
    {    169,   33,   -5, 22, 46,  4 }, {    170,   32,   -5, 22, 46,  4 }, {    170,   31,   -5, 22, 46,  4 }, {    171,   30,   -5, 22, 46,  4 }, {    171,   29,   -5, 22, 46,  4 },
    {    171,   28,   -5, 22, 46,  4 }, {    172,   27,   -6, 22, 46,  4 }, {    172,   26,   -6, 22, 46,  4 }, {    172,   25,   -6, 22, 46,  4 }, {    173,   24,   -6, 23, 46,  4 },
    {    173,   23,   -6, 23, 46,  4 }, {    173,   22,   -6, 23, 46,  4 }, {    173,   21,   -6, 23, 46,  4 }, {    174,   20,   -6, 23, 46,  4 }, {    174,   19,   -6, 23, 46,  4 },
    {    174,   18,   -6, 23, 46,  4 }, {    174,   17,   -6, 23, 46,  4 }, {    174,   16,   -6, 23, 46,  4 }, {    175,   15,   -6, 23, 46,  4 }, {    175,   14,   -6, 23, 46,  4 },
    {    175,   13,   -7, 23, 46,  4 }, {    175,   12,   -7, 23, 46,  4 }, {    175,   11,   -7, 23, 46,  4 }, {    175,   10,   -7, 23, 46,  4 }, {    176,    9,   -7, 23, 46,  4 },
    {    176,    8,   -7, 24, 46,  4 }, {    176,    7,   -7, 24, 46,  4 }, {    176,    6,   -7, 24, 46,  4 }, {    176,    5,   -7, 24, 46,  4 }, {    176,    4,   -7, 24, 46,  4 },
    {    176,    3,   -7, 24, 46,  4 }, {    176,    2,   -7, 24, 46,  4 }, {    176,    1,   -7, 24, 46,  4 }, {    176,    0,   -7, 24, 46,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F7C76, {
    {      0,   16,    8, 16, 46,  4 }, {      1,   16,    8, 16, 46,  4 }, {      2,   16,    8, 16, 46,  4 }, {      3,   16,    8, 16, 46,  4 }, {      4,   16,    8, 16, 46,  4 },
    {      5,   16,    8, 16, 46,  4 }, {      6,   16,    8, 16, 46,  4 }, {      7,   16,    8, 16, 46,  4 }, {      8,   16,    8, 17, 46,  4 }, {      9,   15,    8, 17, 46,  4 },
    {     10,   15,    8, 17, 46,  4 }, {     11,   15,    8, 17, 46,  4 }, {     12,   15,    8, 17, 46,  4 }, {     13,   15,    8, 17, 46,  4 }, {     14,   15,    8, 17, 46,  4 },
    {     15,   14,    7, 17, 46,  4 }, {     16,   14,    7, 17, 46,  4 }, {     17,   14,    7, 17, 46,  4 }, {     18,   14,    7, 17, 46,  4 }, {     19,   14,    7, 17, 46,  4 },
    {     20,   13,    7, 17, 46,  4 }, {     21,   13,    7, 17, 46,  4 }, {     22,   13,    7, 18, 46,  4 }, {     23,   13,    7, 18, 46,  4 }, {     24,   12,    7, 18, 46,  4 },
    {     25,   12,    7, 18, 46,  4 }, {     26,   12,    7, 18, 46,  4 }, {     27,   11,    7, 18, 46,  4 }, {     28,   11,    7, 18, 46,  4 }, {     29,   11,    6, 18, 46,  4 },
    {     30,   10,    6, 18, 46,  4 }, {     31,   10,    6, 18, 46,  4 }, {     32,    9,    6, 18, 46,  4 }, {     33,    9,    6, 18, 46,  4 }, {     34,    8,    6, 18, 46,  4 },
    {     35,    8,    6, 18, 46,  4 }, {     36,    7,    6, 18, 46,  4 }, {     37,    7,    6, 19, 46,  4 }, {     38,    6,    6, 19, 46,  4 }, {     39,    6,    6, 19, 46,  4 },
    {     40,    5,    6, 19, 46,  4 }, {     41,    4,    6, 19, 46,  4 }, {     42,    4,    6, 19, 46,  4 }, {     43,    3,    6, 19, 46,  4 }, {     44,    2,    5, 19, 46,  4 },
    {     45,    2,    5, 19, 46,  4 }, {     46,    1,    5, 19, 46,  4 }, {     47,    0,    5, 19, 46,  4 }, {     48,    0,    5, 19, 46,  4 }, {     49,   -1,    5, 19, 46,  4 },
    {     50,   -2,    5, 20, 46,  4 }, {     51,   -3,    5, 20, 46,  4 }, {     52,   -3,    5, 20, 46,  4 }, {     53,   -4,    5, 20, 46,  4 }, {     54,   -5,    5, 20, 46,  4 },
    {     55,   -6,    5, 20, 46,  4 }, {     56,   -7,    5, 20, 46,  4 }, {     57,   -7,    5, 20, 46,  4 }, {     58,   -8,    4, 20, 46,  4 }, {     59,   -9,    4, 20, 46,  4 },
    {     60,  -10,    4, 20, 46,  4 }, {     61,  -11,    4, 20, 46,  4 }, {     61,  -12,    4, 20, 46,  4 }, {     62,  -13,    4, 21, 46,  4 }, {     63,  -14,    4, 21, 46,  4 },
    {     64,  -15,    4, 21, 46,  4 }, {     64,  -16,    4, 21, 46,  4 }, {     65,  -17,    4, 21, 46,  4 }, {     66,  -18,    4, 21, 46,  4 }, {     66,  -19,    4, 21, 46,  4 },
    {     67,  -20,    4, 21, 46,  4 }, {     68,  -21,    4, 21, 46,  4 }, {     68,  -22,    3, 21, 46,  4 }, {     69,  -23,    3, 21, 46,  4 }, {     70,  -24,    3, 21, 46,  4 },
    {     70,  -25,    3, 21, 46,  4 }, {     71,  -26,    3, 22, 46,  4 }, {     71,  -27,    3, 22, 46,  4 }, {     72,  -28,    3, 22, 46,  4 }, {     72,  -29,    3, 22, 46,  4 },
    {     73,  -30,    3, 22, 46,  4 }, {     73,  -31,    3, 22, 46,  4 }, {     74,  -32,    3, 22, 46,  4 }, {     74,  -33,    3, 22, 46,  4 }, {     75,  -34,    3, 22, 46,  4 },
    {     75,  -35,    3, 22, 46,  4 }, {     75,  -36,    3, 22, 46,  4 }, {     76,  -37,    2, 22, 46,  4 }, {     76,  -38,    2, 22, 46,  4 }, {     76,  -39,    2, 22, 46,  4 },
    {     77,  -40,    2, 23, 46,  4 }, {     77,  -41,    2, 23, 46,  4 }, {     77,  -42,    2, 23, 46,  4 }, {     77,  -43,    2, 23, 46,  4 }, {     78,  -44,    2, 23, 46,  4 },
    {     78,  -45,    2, 23, 46,  4 }, {     78,  -46,    2, 23, 46,  4 }, {     78,  -47,    2, 23, 46,  4 }, {     78,  -48,    2, 23, 46,  4 }, {     79,  -49,    2, 23, 46,  4 },
    {     79,  -50,    2, 23, 46,  4 }, {     79,  -51,    1, 23, 46,  4 }, {     79,  -52,    1, 23, 46,  4 }, {     79,  -53,    1, 23, 46,  4 }, {     79,  -54,    1, 23, 46,  4 },
    {     80,  -55,    1, 23, 46,  4 }, {     80,  -56,    1, 24, 46,  4 }, {     80,  -57,    1, 24, 46,  4 }, {     80,  -58,    1, 24, 46,  4 }, {     80,  -59,    1, 24, 46,  4 },
    {     80,  -60,    1, 24, 46,  4 }, {     80,  -61,    1, 24, 46,  4 }, {     80,  -62,    1, 24, 46,  4 }, {     80,  -63,    1, 24, 46,  4 }, {     80,  -64,    1, 24, 46,  4 },
    {     80,  -65,    0, 24, 46,  4 }, {     80,  -66,    0, 24, 46,  4 }, {     80,  -67,    0, 24, 46,  4 }, {     80,  -68,    0, 24, 46,  4 }, {     80,  -69,    0, 24, 46,  4 },
    {     80,  -70,    0, 24, 46,  4 }, {     80,  -71,    0, 24, 46,  4 }, {     80,  -72,    0, 25, 46,  4 }, {     79,  -73,    0, 25, 46,  4 }, {     79,  -74,    0, 25, 46,  4 },
    {     79,  -75,    0, 25, 46,  4 }, {     79,  -76,    0, 25, 46,  4 }, {     79,  -77,    0, 25, 46,  4 }, {     79,  -78,    0, 25, 46,  4 }, {     78,  -79,   -1, 25, 46,  4 },
    {     78,  -80,   -1, 25, 46,  4 }, {     78,  -81,   -1, 25, 46,  4 }, {     78,  -82,   -1, 25, 46,  4 }, {     78,  -83,   -1, 25, 46,  4 }, {     77,  -84,   -1, 25, 46,  4 },
    {     77,  -85,   -1, 25, 46,  4 }, {     77,  -86,   -1, 26, 46,  4 }, {     77,  -87,   -1, 26, 46,  4 }, {     76,  -88,   -1, 26, 46,  4 }, {     76,  -89,   -1, 26, 46,  4 },
    {     76,  -90,   -1, 26, 46,  4 }, {     75,  -91,   -1, 26, 46,  4 }, {     75,  -92,   -1, 26, 46,  4 }, {     75,  -93,   -2, 26, 46,  4 }, {     74,  -94,   -2, 26, 46,  4 },
    {     74,  -95,   -2, 26, 46,  4 }, {     73,  -96,   -2, 26, 46,  4 }, {     73,  -97,   -2, 26, 46,  4 }, {     72,  -98,   -2, 26, 46,  4 }, {     72,  -99,   -2, 26, 46,  4 },
    {     71, -100,   -2, 26, 46,  4 }, {     71, -101,   -2, 27, 46,  4 }, {     70, -102,   -2, 27, 46,  4 }, {     70, -103,   -2, 27, 46,  4 }, {     69, -104,   -2, 27, 46,  4 },
    {     68, -105,   -2, 27, 46,  4 }, {     68, -106,   -2, 27, 46,  4 }, {     67, -107,   -3, 27, 46,  4 }, {     66, -108,   -3, 27, 46,  4 }, {     66, -109,   -3, 27, 46,  4 },
    {     65, -110,   -3, 27, 46,  4 }, {     64, -111,   -3, 27, 46,  4 }, {     64, -112,   -3, 27, 46,  4 }, {     63, -113,   -3, 27, 46,  4 }, {     62, -114,   -3, 28, 46,  4 },
    {     61, -115,   -3, 28, 46,  4 }, {     61, -116,   -3, 28, 46,  4 }, {     60, -117,   -3, 28, 46,  4 }, {     59, -118,   -3, 28, 46,  4 }, {     58, -119,   -3, 28, 46,  4 },
    {     57, -120,   -3, 28, 46,  4 }, {     57, -121,   -4, 28, 46,  4 }, {     56, -122,   -4, 28, 46,  4 }, {     55, -123,   -4, 28, 46,  4 }, {     54, -124,   -4, 28, 46,  4 },
    {     53, -125,   -4, 28, 46,  4 }, {     52, -125,   -4, 28, 46,  4 }, {     51, -126,   -4, 29, 46,  4 }, {     50, -127,   -4, 29, 46,  4 }, {     49, -128,   -4, 29, 46,  4 },
    {     48, -128,   -4, 29, 46,  4 }, {     47, -129,   -4, 29, 46,  4 }, {     46, -130,   -4, 29, 46,  4 }, {     45, -130,   -4, 29, 46,  4 }, {     44, -131,   -4, 29, 46,  4 },
    {     43, -132,   -4, 29, 46,  4 }, {     42, -132,   -5, 29, 46,  4 }, {     41, -133,   -5, 29, 46,  4 }, {     40, -134,   -5, 29, 46,  4 }, {     39, -134,   -5, 29, 46,  4 },
    {     38, -135,   -5, 30, 46,  4 }, {     37, -135,   -5, 30, 46,  4 }, {     36, -136,   -5, 30, 46,  4 }, {     35, -136,   -5, 30, 46,  4 }, {     34, -137,   -5, 30, 46,  4 },
    {     33, -137,   -5, 30, 46,  4 }, {     32, -138,   -5, 30, 46,  4 }, {     31, -138,   -5, 30, 46,  4 }, {     30, -139,   -5, 30, 46,  4 }, {     29, -139,   -5, 30, 46,  4 },
    {     28, -139,   -6, 30, 46,  4 }, {     27, -140,   -6, 30, 46,  4 }, {     26, -140,   -6, 30, 46,  4 }, {     25, -140,   -6, 30, 46,  4 }, {     24, -141,   -6, 31, 46,  4 },
    {     23, -141,   -6, 31, 46,  4 }, {     22, -141,   -6, 31, 46,  4 }, {     21, -141,   -6, 31, 46,  4 }, {     20, -142,   -6, 31, 46,  4 }, {     19, -142,   -6, 31, 46,  4 },
    {     18, -142,   -6, 31, 46,  4 }, {     17, -142,   -6, 31, 46,  4 }, {     16, -142,   -6, 31, 46,  4 }, {     15, -143,   -6, 31, 46,  4 }, {     14, -143,   -7, 31, 46,  4 },
    {     13, -143,   -7, 31, 46,  4 }, {     12, -143,   -7, 31, 46,  4 }, {     11, -143,   -7, 31, 46,  4 }, {     10, -143,   -7, 31, 46,  4 }, {      9, -144,   -7, 31, 46,  4 },
    {      8, -144,   -7,  0, 46,  4 }, {      7, -144,   -7,  0, 46,  4 }, {      6, -144,   -7,  0, 46,  4 }, {      5, -144,   -7,  0, 46,  4 }, {      4, -144,   -7,  0, 46,  4 },
    {      3, -144,   -7,  0, 46,  4 }, {      2, -144,   -7,  0, 46,  4 }, {      1, -144,   -7,  0, 46,  4 }, {      0, -144,   -8,  0, 46,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8F8485, {
    {     16,   31,    8, 24, 46,  4 }, {     16,   30,    8, 24, 46,  4 }, {     16,   29,    8, 24, 46,  4 }, {     16,   28,    8, 24, 46,  4 }, {     16,   27,    8, 24, 46,  4 },
    {     16,   26,    8, 24, 46,  4 }, {     16,   25,    8, 24, 46,  4 }, {     16,   24,    8, 25, 46,  4 }, {     15,   23,    8, 25, 46,  4 }, {     15,   22,    8, 25, 46,  4 },
    {     15,   21,    8, 25, 46,  4 }, {     15,   20,    8, 25, 46,  4 }, {     15,   19,    8, 25, 46,  4 }, {     15,   18,    8, 25, 46,  4 }, {     14,   17,    7, 25, 46,  4 },
    {     14,   16,    7, 25, 46,  4 }, {     14,   15,    7, 25, 46,  4 }, {     14,   14,    7, 25, 46,  4 }, {     14,   13,    7, 25, 46,  4 }, {     13,   12,    7, 25, 46,  4 },
    {     13,   11,    7, 25, 46,  4 }, {     13,   10,    7, 26, 46,  4 }, {     13,    9,    7, 26, 46,  4 }, {     12,    8,    7, 26, 46,  4 }, {     12,    7,    7, 26, 46,  4 },
    {     12,    6,    7, 26, 46,  4 }, {     11,    5,    7, 26, 46,  4 }, {     11,    4,    7, 26, 46,  4 }, {     11,    3,    6, 26, 46,  4 }, {     10,    2,    6, 26, 46,  4 },
    {     10,    1,    6, 26, 46,  4 }, {      9,    0,    6, 26, 46,  4 }, {      9,   -1,    6, 26, 46,  4 }, {      8,   -2,    6, 26, 46,  4 }, {      8,   -3,    6, 26, 46,  4 },
    {      7,   -4,    6, 26, 46,  4 }, {      7,   -5,    6, 27, 46,  4 }, {      6,   -6,    6, 27, 46,  4 }, {      6,   -7,    6, 27, 46,  4 }, {      5,   -8,    6, 27, 46,  4 },
    {      4,   -9,    6, 27, 46,  4 }, {      4,  -10,    6, 27, 46,  4 }, {      3,  -11,    5, 27, 46,  4 }, {      2,  -12,    5, 27, 46,  4 }, {      2,  -13,    5, 27, 46,  4 },
    {      1,  -14,    5, 27, 46,  4 }, {      0,  -15,    5, 27, 46,  4 }, {      0,  -16,    5, 27, 46,  4 }, {     -1,  -17,    5, 27, 46,  4 }, {     -2,  -18,    5, 28, 46,  4 },
    {     -3,  -19,    5, 28, 46,  4 }, {     -3,  -20,    5, 28, 46,  4 }, {     -4,  -21,    5, 28, 46,  4 }, {     -5,  -22,    5, 28, 46,  4 }, {     -6,  -23,    5, 28, 46,  4 },
    {     -7,  -24,    5, 28, 46,  4 }, {     -7,  -25,    4, 28, 46,  4 }, {     -8,  -26,    4, 28, 46,  4 }, {     -9,  -27,    4, 28, 46,  4 }, {    -10,  -28,    4, 28, 46,  4 },
    {    -11,  -29,    4, 28, 46,  4 }, {    -12,  -29,    4, 28, 46,  4 }, {    -13,  -30,    4, 29, 46,  4 }, {    -14,  -31,    4, 29, 46,  4 }, {    -15,  -32,    4, 29, 46,  4 },
    {    -16,  -32,    4, 29, 46,  4 }, {    -17,  -33,    4, 29, 46,  4 }, {    -18,  -34,    4, 29, 46,  4 }, {    -19,  -34,    4, 29, 46,  4 }, {    -20,  -35,    4, 29, 46,  4 },
    {    -21,  -36,    4, 29, 46,  4 }, {    -22,  -36,    3, 29, 46,  4 }, {    -23,  -37,    3, 29, 46,  4 }, {    -24,  -38,    3, 29, 46,  4 }, {    -25,  -38,    3, 29, 46,  4 },
    {    -26,  -39,    3, 30, 46,  4 }, {    -27,  -39,    3, 30, 46,  4 }, {    -28,  -40,    3, 30, 46,  4 }, {    -29,  -40,    3, 30, 46,  4 }, {    -30,  -41,    3, 30, 46,  4 },
    {    -31,  -41,    3, 30, 46,  4 }, {    -32,  -42,    3, 30, 46,  4 }, {    -33,  -42,    3, 30, 46,  4 }, {    -34,  -43,    3, 30, 46,  4 }, {    -35,  -43,    3, 30, 46,  4 },
    {    -36,  -43,    2, 30, 46,  4 }, {    -37,  -44,    2, 30, 46,  4 }, {    -38,  -44,    2, 30, 46,  4 }, {    -39,  -44,    2, 30, 46,  4 }, {    -40,  -45,    2, 31, 46,  4 },
    {    -41,  -45,    2, 31, 46,  4 }, {    -42,  -45,    2, 31, 46,  4 }, {    -43,  -45,    2, 31, 46,  4 }, {    -44,  -46,    2, 31, 46,  4 }, {    -45,  -46,    2, 31, 46,  4 },
    {    -46,  -46,    2, 31, 46,  4 }, {    -47,  -46,    2, 31, 46,  4 }, {    -48,  -46,    2, 31, 46,  4 }, {    -49,  -47,    2, 31, 46,  4 }, {    -50,  -47,    1, 31, 46,  4 },
    {    -51,  -47,    1, 31, 46,  4 }, {    -52,  -47,    1, 31, 46,  4 }, {    -53,  -47,    1, 31, 46,  4 }, {    -54,  -47,    1, 31, 46,  4 }, {    -55,  -48,    1, 31, 46,  4 },
    {    -56,  -48,    1,  0, 46,  4 }, {    -57,  -48,    1,  0, 46,  4 }, {    -58,  -48,    1,  0, 46,  4 }, {    -59,  -48,    1,  0, 46,  4 }, {    -60,  -48,    1,  0, 46,  4 },
    {    -61,  -48,    1,  0, 46,  4 }, {    -62,  -48,    1,  0, 46,  4 }, {    -63,  -48,    1,  0, 46,  4 }, {    -64,  -48,    0,  0, 46,  4 }, {    -65,  -48,    0,  0, 46,  4 },
    {    -66,  -48,    0,  0, 46,  4 }, {    -67,  -48,    0,  0, 46,  4 }, {    -68,  -48,    0,  0, 46,  4 }, {    -69,  -48,    0,  0, 46,  4 }, {    -70,  -48,    0,  0, 46,  4 },
    {    -71,  -48,    0,  0, 46,  4 }, {    -72,  -48,    0,  1, 46,  4 }, {    -73,  -47,    0,  1, 46,  4 }, {    -74,  -47,    0,  1, 46,  4 }, {    -75,  -47,    0,  1, 46,  4 },
    {    -76,  -47,    0,  1, 46,  4 }, {    -77,  -47,    0,  1, 46,  4 }, {    -78,  -47,    0,  1, 46,  4 }, {    -79,  -46,   -1,  1, 46,  4 }, {    -80,  -46,   -1,  1, 46,  4 },
    {    -81,  -46,   -1,  1, 46,  4 }, {    -82,  -46,   -1,  1, 46,  4 }, {    -83,  -46,   -1,  1, 46,  4 }, {    -84,  -45,   -1,  1, 46,  4 }, {    -85,  -45,   -1,  1, 46,  4 },
    {    -86,  -45,   -1,  2, 46,  4 }, {    -87,  -45,   -1,  2, 46,  4 }, {    -88,  -44,   -1,  2, 46,  4 }, {    -89,  -44,   -1,  2, 46,  4 }, {    -90,  -44,   -1,  2, 46,  4 },
    {    -91,  -43,   -1,  2, 46,  4 }, {    -92,  -43,   -1,  2, 46,  4 }, {    -93,  -43,   -2,  2, 46,  4 }, {    -94,  -42,   -2,  2, 46,  4 }, {    -95,  -42,   -2,  2, 46,  4 },
    {    -96,  -41,   -2,  2, 46,  4 }, {    -97,  -41,   -2,  2, 46,  4 }, {    -98,  -40,   -2,  2, 46,  4 }, {    -99,  -40,   -2,  2, 46,  4 }, {   -100,  -39,   -2,  2, 46,  4 },
    {   -101,  -39,   -2,  3, 46,  4 }, {   -102,  -38,   -2,  3, 46,  4 }, {   -103,  -38,   -2,  3, 46,  4 }, {   -104,  -37,   -2,  3, 46,  4 }, {   -105,  -36,   -2,  3, 46,  4 },
    {   -106,  -36,   -2,  3, 46,  4 }, {   -107,  -35,   -3,  3, 46,  4 }, {   -108,  -34,   -3,  3, 46,  4 }, {   -109,  -34,   -3,  3, 46,  4 }, {   -110,  -33,   -3,  3, 46,  4 },
    {   -111,  -32,   -3,  3, 46,  4 }, {   -112,  -32,   -3,  3, 46,  4 }, {   -113,  -31,   -3,  3, 46,  4 }, {   -114,  -30,   -3,  4, 46,  4 }, {   -115,  -29,   -3,  4, 46,  4 },
    {   -116,  -29,   -3,  4, 46,  4 }, {   -117,  -28,   -3,  4, 46,  4 }, {   -118,  -27,   -3,  4, 46,  4 }, {   -119,  -26,   -3,  4, 46,  4 }, {   -120,  -25,   -3,  4, 46,  4 },
    {   -121,  -25,   -4,  4, 46,  4 }, {   -122,  -24,   -4,  4, 46,  4 }, {   -123,  -23,   -4,  4, 46,  4 }, {   -124,  -22,   -4,  4, 46,  4 }, {   -125,  -21,   -4,  4, 46,  4 },
    {   -125,  -20,   -4,  4, 46,  4 }, {   -126,  -19,   -4,  5, 46,  4 }, {   -127,  -18,   -4,  5, 46,  4 }, {   -128,  -17,   -4,  5, 46,  4 }, {   -128,  -16,   -4,  5, 46,  4 },
    {   -129,  -15,   -4,  5, 46,  4 }, {   -130,  -14,   -4,  5, 46,  4 }, {   -130,  -13,   -4,  5, 46,  4 }, {   -131,  -12,   -4,  5, 46,  4 }, {   -132,  -11,   -5,  5, 46,  4 },
    {   -132,  -10,   -5,  5, 46,  4 }, {   -133,   -9,   -5,  5, 46,  4 }, {   -134,   -8,   -5,  5, 46,  4 }, {   -134,   -7,   -5,  5, 46,  4 }, {   -135,   -6,   -5,  6, 46,  4 },
    {   -135,   -5,   -5,  6, 46,  4 }, {   -136,   -4,   -5,  6, 46,  4 }, {   -136,   -3,   -5,  6, 46,  4 }, {   -137,   -2,   -5,  6, 46,  4 }, {   -137,   -1,   -5,  6, 46,  4 },
    {   -138,    0,   -5,  6, 46,  4 }, {   -138,    1,   -5,  6, 46,  4 }, {   -139,    2,   -5,  6, 46,  4 }, {   -139,    3,   -6,  6, 46,  4 }, {   -139,    4,   -6,  6, 46,  4 },
    {   -140,    5,   -6,  6, 46,  4 }, {   -140,    6,   -6,  6, 46,  4 }, {   -140,    7,   -6,  6, 46,  4 }, {   -141,    8,   -6,  7, 46,  4 }, {   -141,    9,   -6,  7, 46,  4 },
    {   -141,   10,   -6,  7, 46,  4 }, {   -141,   11,   -6,  7, 46,  4 }, {   -142,   12,   -6,  7, 46,  4 }, {   -142,   13,   -6,  7, 46,  4 }, {   -142,   14,   -6,  7, 46,  4 },
    {   -142,   15,   -6,  7, 46,  4 }, {   -142,   16,   -6,  7, 46,  4 }, {   -143,   17,   -7,  7, 46,  4 }, {   -143,   18,   -7,  7, 46,  4 }, {   -143,   19,   -7,  7, 46,  4 },
    {   -143,   20,   -7,  7, 46,  4 }, {   -143,   21,   -7,  7, 46,  4 }, {   -143,   22,   -7,  7, 46,  4 }, {   -144,   23,   -7,  7, 46,  4 }, {   -144,   24,   -7,  8, 46,  4 },
    {   -144,   25,   -7,  8, 46,  4 }, {   -144,   26,   -7,  8, 46,  4 }, {   -144,   27,   -7,  8, 46,  4 }, {   -144,   28,   -7,  8, 46,  4 }, {   -144,   29,   -7,  8, 46,  4 },
    {   -144,   30,   -7,  8, 46,  4 }, {   -144,   31,   -8,  8, 46,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E402E, {
    {     31,   16,    0,  0,  4,  0 }, {     31,   16,    1,  0,  4,  0 }, {     30,   16,    2,  0,  4,  0 }, {     30,   16,    3,  0,  4,  0 }, {     30,   16,    4,  0,  4,  0 },
    {     29,   16,    5, 31,  4,  0 }, {     29,   16,    6, 31,  4,  0 }, {     28,   15,    7, 31,  4,  0 }, {     28,   15,    8, 31,  4,  0 }, {     28,   15,    9, 31,  4,  0 },
    {     27,   15,   10, 30,  4,  0 }, {     27,   15,   11, 30,  4,  0 }, {     27,   15,   12, 30,  4,  0 }, {     26,   15,   13, 30,  4,  0 }, {     26,   15,   14, 30,  4,  0 },
    {     26,   15,   15, 30,  4,  0 }, {     25,   14,   16, 30,  4,  0 }, {     25,   14,   17, 30,  4,  0 }, {     25,   14,   18, 30,  4,  0 }, {     24,   14,   19, 29,  4,  0 },
    {     24,   14,   20, 29,  4,  0 }, {     24,   14,   21, 29,  4,  0 }, {     23,   13,   22, 29,  4,  0 }, {     23,   13,   23, 29,  4,  0 }, {     23,   13,   24, 29,  4,  0 },
    {     22,   12,   25, 28,  4,  0 }, {     22,   12,   26, 28,  4,  0 }, {     22,   12,   27, 28,  4,  0 }, {     21,   11,   28, 28,  4,  0 }, {     21,   11,   29, 28,  4,  0 },
    {     21,   11,   30, 28,  4,  0 }, {     20,   10,   31, 28,  4,  0 }, {     20,   10,   32, 28,  4,  0 }, {     20,   10,   33, 28,  4,  0 }, {     19,    9,   34, 27,  4,  0 },
    {     19,    9,   35, 27,  4,  0 }, {     19,    9,   36, 27,  4,  0 }, {     18,    8,   37, 27,  4,  0 }, {     18,    8,   38, 27,  4,  0 }, {     18,    8,   39, 27,  4,  0 },
    {     18,    7,   40, 26,  4,  0 }, {     18,    7,   41, 26,  4,  0 }, {     18,    7,   42, 26,  4,  0 }, {     17,    6,   43, 26,  4,  0 }, {     17,    6,   44, 26,  4,  0 },
    {     17,    6,   45, 26,  4,  0 }, {     17,    5,   46, 26,  4,  0 }, {     17,    5,   47, 26,  4,  0 }, {     17,    5,   48, 26,  4,  0 }, {     17,    4,   49, 25,  4,  0 },
    {     17,    4,   50, 25,  4,  0 }, {     17,    4,   51, 25,  4,  0 }, {     16,    3,   52, 25,  4,  0 }, {     16,    3,   53, 25,  4,  0 }, {     16,    3,   54, 25,  4,  0 },
    {     16,    2,   55, 24,  4,  0 }, {     16,    2,   56, 24,  4,  0 }, {     16,    2,   57, 24,  4,  0 }, {     16,    1,   58, 24,  4,  0 }, {     16,    1,   59, 24,  4,  0 },
    {     16,    1,   60, 24,  4,  0 }, {     16,    0,   61, 24,  4,  0 }, {     16,    0,   62, 24,  4,  0 }, {     16,    0,   63, 24,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E4270, {
    {     16,    0,    0,  8,  4,  0 }, {     16,    0,    1,  8,  4,  0 }, {     16,    1,    2,  8,  4,  0 }, {     16,    1,    3,  8,  4,  0 }, {     16,    2,    4,  8,  4,  0 },
    {     16,    2,    5,  8,  4,  0 }, {     16,    3,    6,  7,  4,  0 }, {     16,    3,    7,  7,  4,  0 }, {     15,    4,    8,  7,  4,  0 }, {     15,    4,    9,  7,  4,  0 },
    {     15,    4,   10,  7,  4,  0 }, {     15,    5,   11,  6,  4,  0 }, {     15,    5,   12,  6,  4,  0 }, {     15,    5,   13,  6,  4,  0 }, {     15,    6,   14,  6,  4,  0 },
    {     15,    6,   15,  6,  4,  0 }, {     15,    6,   16,  6,  4,  0 }, {     14,    7,   17,  6,  4,  0 }, {     14,    7,   18,  6,  4,  0 }, {     14,    7,   19,  6,  4,  0 },
    {     14,    8,   20,  5,  4,  0 }, {     14,    8,   21,  5,  4,  0 }, {     13,    9,   22,  5,  4,  0 }, {     13,    9,   23,  5,  4,  0 }, {     13,    9,   24,  5,  4,  0 },
    {     12,   10,   25,  4,  4,  0 }, {     12,   10,   26,  4,  4,  0 }, {     12,   10,   27,  4,  4,  0 }, {     11,   11,   28,  4,  4,  0 }, {     11,   11,   29,  4,  4,  0 },
    {     11,   11,   30,  4,  4,  0 }, {     10,   12,   31,  4,  4,  0 }, {     10,   12,   32,  4,  4,  0 }, {     10,   12,   33,  4,  4,  0 }, {      9,   13,   34,  3,  4,  0 },
    {      9,   13,   35,  3,  4,  0 }, {      9,   13,   36,  3,  4,  0 }, {      8,   14,   37,  3,  4,  0 }, {      8,   14,   38,  3,  4,  0 }, {      8,   14,   39,  3,  4,  0 },
    {      7,   14,   40,  2,  4,  0 }, {      7,   14,   41,  2,  4,  0 }, {      7,   14,   42,  2,  4,  0 }, {      6,   15,   43,  2,  4,  0 }, {      6,   15,   44,  2,  4,  0 },
    {      6,   15,   45,  2,  4,  0 }, {      5,   15,   46,  2,  4,  0 }, {      5,   15,   47,  2,  4,  0 }, {      5,   15,   48,  2,  4,  0 }, {      4,   15,   49,  1,  4,  0 },
    {      4,   15,   50,  1,  4,  0 }, {      4,   15,   51,  1,  4,  0 }, {      3,   16,   52,  1,  4,  0 }, {      3,   16,   53,  1,  4,  0 }, {      3,   16,   54,  1,  4,  0 },
    {      2,   16,   55,  0,  4,  0 }, {      2,   16,   56,  0,  4,  0 }, {      2,   16,   57,  0,  4,  0 }, {      1,   16,   58,  0,  4,  0 }, {      1,   16,   59,  0,  4,  0 },
    {      1,   16,   60,  0,  4,  0 }, {      0,   16,   61,  0,  4,  0 }, {      0,   16,   62,  0,  4,  0 }, {      0,   16,   63,  0,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E44B2, {
    {      0,   16,    0, 16,  4,  0 }, {      0,   16,    1, 16,  4,  0 }, {      1,   16,    2, 16,  4,  0 }, {      1,   16,    3, 16,  4,  0 }, {      1,   16,    4, 16,  4,  0 },
    {      2,   16,    5, 16,  4,  0 }, {      2,   16,    6, 16,  4,  0 }, {      3,   16,    7, 15,  4,  0 }, {      3,   16,    8, 15,  4,  0 }, {      3,   16,    9, 15,  4,  0 },
    {      4,   17,   10, 15,  4,  0 }, {      4,   17,   11, 15,  4,  0 }, {      4,   17,   12, 15,  4,  0 }, {      5,   17,   13, 14,  4,  0 }, {      5,   17,   14, 14,  4,  0 },
    {      5,   17,   15, 14,  4,  0 }, {      6,   17,   16, 14,  4,  0 }, {      6,   17,   17, 14,  4,  0 }, {      6,   17,   18, 14,  4,  0 }, {      7,   18,   19, 14,  4,  0 },
    {      7,   18,   20, 14,  4,  0 }, {      7,   18,   21, 14,  4,  0 }, {      8,   18,   22, 13,  4,  0 }, {      8,   18,   23, 13,  4,  0 }, {      8,   18,   24, 13,  4,  0 },
    {      9,   19,   25, 13,  4,  0 }, {      9,   19,   26, 13,  4,  0 }, {      9,   19,   27, 13,  4,  0 }, {     10,   20,   28, 12,  4,  0 }, {     10,   20,   29, 12,  4,  0 },
    {     10,   20,   30, 12,  4,  0 }, {     11,   21,   31, 12,  4,  0 }, {     11,   21,   32, 12,  4,  0 }, {     11,   21,   33, 12,  4,  0 }, {     12,   22,   34, 12,  4,  0 },
    {     12,   22,   35, 12,  4,  0 }, {     12,   22,   36, 12,  4,  0 }, {     13,   23,   37, 11,  4,  0 }, {     13,   23,   38, 11,  4,  0 }, {     13,   23,   39, 11,  4,  0 },
    {     14,   24,   40, 11,  4,  0 }, {     14,   24,   41, 11,  4,  0 }, {     14,   24,   42, 11,  4,  0 }, {     14,   25,   43, 10,  4,  0 }, {     14,   25,   44, 10,  4,  0 },
    {     14,   25,   45, 10,  4,  0 }, {     15,   26,   46, 10,  4,  0 }, {     15,   26,   47, 10,  4,  0 }, {     15,   26,   48, 10,  4,  0 }, {     15,   27,   49, 10,  4,  0 },
    {     15,   27,   50, 10,  4,  0 }, {     15,   27,   51, 10,  4,  0 }, {     15,   28,   52,  9,  4,  0 }, {     15,   28,   53,  9,  4,  0 }, {     15,   28,   54,  9,  4,  0 },
    {     16,   29,   55,  9,  4,  0 }, {     16,   29,   56,  9,  4,  0 }, {     16,   29,   57,  9,  4,  0 }, {     16,   30,   58,  8,  4,  0 }, {     16,   30,   59,  8,  4,  0 },
    {     16,   30,   60,  8,  4,  0 }, {     16,   31,   61,  8,  4,  0 }, {     16,   31,   62,  8,  4,  0 }, {     16,   31,   63,  8,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E46F4, {
    {     16,   31,    0, 24,  4,  0 }, {     16,   31,    1, 24,  4,  0 }, {     16,   30,    2, 24,  4,  0 }, {     16,   30,    3, 24,  4,  0 }, {     16,   29,    4, 23,  4,  0 },
    {     16,   29,    5, 23,  4,  0 }, {     17,   28,    6, 23,  4,  0 }, {     17,   28,    7, 23,  4,  0 }, {     17,   28,    8, 23,  4,  0 }, {     17,   27,    9, 22,  4,  0 },
    {     17,   27,   10, 22,  4,  0 }, {     17,   27,   11, 22,  4,  0 }, {     17,   27,   12, 22,  4,  0 }, {     17,   26,   13, 22,  4,  0 }, {     17,   26,   14, 22,  4,  0 },
    {     17,   26,   15, 22,  4,  0 }, {     18,   25,   16, 22,  4,  0 }, {     18,   25,   17, 22,  4,  0 }, {     18,   25,   18, 22,  4,  0 }, {     18,   24,   19, 21,  4,  0 },
    {     18,   24,   20, 21,  4,  0 }, {     18,   24,   21, 21,  4,  0 }, {     19,   23,   22, 21,  4,  0 }, {     19,   23,   23, 21,  4,  0 }, {     19,   23,   24, 21,  4,  0 },
    {     20,   22,   25, 20,  4,  0 }, {     20,   22,   26, 20,  4,  0 }, {     20,   22,   27, 20,  4,  0 }, {     20,   22,   28, 20,  4,  0 }, {     21,   21,   29, 20,  4,  0 },
    {     21,   21,   30, 20,  4,  0 }, {     21,   21,   31, 20,  4,  0 }, {     22,   20,   32, 20,  4,  0 }, {     22,   20,   33, 20,  4,  0 }, {     22,   20,   34, 20,  4,  0 },
    {     23,   19,   35, 19,  4,  0 }, {     23,   19,   36, 19,  4,  0 }, {     23,   19,   37, 19,  4,  0 }, {     24,   18,   38, 19,  4,  0 }, {     24,   18,   39, 19,  4,  0 },
    {     24,   18,   40, 19,  4,  0 }, {     25,   18,   41, 18,  4,  0 }, {     25,   18,   42, 18,  4,  0 }, {     25,   18,   43, 18,  4,  0 }, {     26,   17,   44, 18,  4,  0 },
    {     26,   17,   45, 18,  4,  0 }, {     26,   17,   46, 18,  4,  0 }, {     26,   17,   47, 18,  4,  0 }, {     27,   17,   48, 18,  4,  0 }, {     27,   17,   49, 18,  4,  0 },
    {     27,   17,   50, 18,  4,  0 }, {     28,   17,   51, 17,  4,  0 }, {     28,   17,   52, 17,  4,  0 }, {     28,   17,   53, 17,  4,  0 }, {     29,   16,   54, 17,  4,  0 },
    {     29,   16,   55, 17,  4,  0 }, {     29,   16,   56, 17,  4,  0 }, {     30,   16,   57, 16,  4,  0 }, {     30,   16,   58, 16,  4,  0 }, {     30,   16,   59, 16,  4,  0 },
    {     31,   16,   60, 16,  4,  0 }, {     31,   16,   61, 16,  4,  0 }, {     31,   16,   62, 16,  4,  0 }, {     31,   16,   63, 16,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E4936, {
    {     31,   16,    0,  0,  4,  0 }, {     31,   16,    1,  0,  4,  0 }, {     30,   16,    2,  0,  4,  0 }, {     30,   16,    3,  0,  4,  0 }, {     30,   16,    4,  0,  4,  0 },
    {     29,   16,    5,  1,  4,  0 }, {     29,   16,    6,  1,  4,  0 }, {     29,   16,    7,  1,  4,  0 }, {     28,   17,    8,  1,  4,  0 }, {     28,   17,    9,  1,  4,  0 },
    {     28,   17,   10,  1,  4,  0 }, {     27,   17,   11,  2,  4,  0 }, {     27,   17,   12,  2,  4,  0 }, {     27,   17,   13,  2,  4,  0 }, {     26,   17,   14,  2,  4,  0 },
    {     26,   17,   15,  2,  4,  0 }, {     26,   17,   16,  2,  4,  0 }, {     25,   18,   17,  2,  4,  0 }, {     25,   18,   18,  2,  4,  0 }, {     25,   18,   19,  2,  4,  0 },
    {     24,   18,   20,  3,  4,  0 }, {     24,   18,   21,  3,  4,  0 }, {     24,   18,   22,  3,  4,  0 }, {     23,   19,   23,  3,  4,  0 }, {     23,   19,   24,  3,  4,  0 },
    {     23,   19,   25,  3,  4,  0 }, {     22,   20,   26,  4,  4,  0 }, {     22,   20,   27,  4,  4,  0 }, {     22,   20,   28,  4,  4,  0 }, {     22,   20,   29,  4,  4,  0 },
    {     21,   21,   30,  4,  4,  0 }, {     21,   21,   31,  4,  4,  0 }, {     21,   21,   32,  4,  4,  0 }, {     20,   22,   33,  4,  4,  0 }, {     20,   22,   34,  4,  4,  0 },
    {     20,   22,   35,  4,  4,  0 }, {     19,   23,   36,  5,  4,  0 }, {     19,   23,   37,  5,  4,  0 }, {     19,   23,   38,  5,  4,  0 }, {     18,   24,   39,  5,  4,  0 },
    {     18,   24,   40,  5,  4,  0 }, {     18,   24,   41,  5,  4,  0 }, {     18,   25,   42,  6,  4,  0 }, {     18,   25,   43,  6,  4,  0 }, {     18,   25,   44,  6,  4,  0 },
    {     17,   26,   45,  6,  4,  0 }, {     17,   26,   46,  6,  4,  0 }, {     17,   26,   47,  6,  4,  0 }, {     17,   27,   48,  6,  4,  0 }, {     17,   27,   49,  6,  4,  0 },
    {     17,   27,   50,  6,  4,  0 }, {     17,   28,   51,  7,  4,  0 }, {     17,   28,   52,  7,  4,  0 }, {     17,   28,   53,  7,  4,  0 }, {     16,   29,   54,  7,  4,  0 },
    {     16,   29,   55,  7,  4,  0 }, {     16,   29,   56,  7,  4,  0 }, {     16,   30,   57,  8,  4,  0 }, {     16,   30,   58,  8,  4,  0 }, {     16,   30,   59,  8,  4,  0 },
    {     16,   31,   60,  8,  4,  0 }, {     16,   31,   61,  8,  4,  0 }, {     16,   31,   62,  8,  4,  0 }, {     16,   31,   63,  8,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E4B78, {
    {     16,    0,    0,  8,  4,  0 }, {     16,    0,    1,  8,  4,  0 }, {     16,    1,    2,  8,  4,  0 }, {     16,    1,    3,  8,  4,  0 }, {     16,    2,    4,  8,  4,  0 },
    {     16,    2,    5,  8,  4,  0 }, {     16,    3,    6,  9,  4,  0 }, {     16,    3,    7,  9,  4,  0 }, {     17,    4,    8,  9,  4,  0 }, {     17,    4,    9,  9,  4,  0 },
    {     17,    4,   10,  9,  4,  0 }, {     17,    5,   11, 10,  4,  0 }, {     17,    5,   12, 10,  4,  0 }, {     17,    5,   13, 10,  4,  0 }, {     17,    6,   14, 10,  4,  0 },
    {     17,    6,   15, 10,  4,  0 }, {     17,    6,   16, 10,  4,  0 }, {     18,    7,   17, 10,  4,  0 }, {     18,    7,   18, 10,  4,  0 }, {     18,    7,   19, 10,  4,  0 },
    {     18,    8,   20, 11,  4,  0 }, {     18,    8,   21, 11,  4,  0 }, {     18,    8,   22, 11,  4,  0 }, {     18,    8,   23, 11,  4,  0 }, {     19,    9,   24, 11,  4,  0 },
    {     19,    9,   25, 11,  4,  0 }, {     19,    9,   26, 11,  4,  0 }, {     20,   10,   27, 12,  4,  0 }, {     20,   10,   28, 12,  4,  0 }, {     20,   10,   29, 12,  4,  0 },
    {     21,   11,   30, 12,  4,  0 }, {     21,   11,   31, 12,  4,  0 }, {     21,   11,   32, 12,  4,  0 }, {     22,   12,   33, 12,  4,  0 }, {     22,   12,   34, 12,  4,  0 },
    {     22,   12,   35, 12,  4,  0 }, {     23,   13,   36, 13,  4,  0 }, {     23,   13,   37, 13,  4,  0 }, {     23,   13,   38, 13,  4,  0 }, {     24,   14,   39, 13,  4,  0 },
    {     24,   14,   40, 13,  4,  0 }, {     24,   14,   41, 13,  4,  0 }, {     25,   14,   42, 14,  4,  0 }, {     25,   14,   43, 14,  4,  0 }, {     25,   14,   44, 14,  4,  0 },
    {     26,   15,   45, 14,  4,  0 }, {     26,   15,   46, 14,  4,  0 }, {     26,   15,   47, 14,  4,  0 }, {     27,   15,   48, 14,  4,  0 }, {     27,   15,   49, 14,  4,  0 },
    {     27,   15,   50, 14,  4,  0 }, {     28,   15,   51, 15,  4,  0 }, {     28,   15,   52, 15,  4,  0 }, {     28,   15,   53, 15,  4,  0 }, {     29,   16,   54, 15,  4,  0 },
    {     29,   16,   55, 15,  4,  0 }, {     29,   16,   56, 15,  4,  0 }, {     30,   16,   57, 16,  4,  0 }, {     30,   16,   58, 16,  4,  0 }, {     30,   16,   59, 16,  4,  0 },
    {     31,   16,   60, 16,  4,  0 }, {     31,   16,   61, 16,  4,  0 }, {     31,   16,   62, 16,  4,  0 }, {     31,   16,   63, 16,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E4DBA, {
    {      0,   16,    0, 16,  4,  0 }, {      1,   16,    1, 16,  4,  0 }, {      1,   16,    2, 16,  4,  0 }, {      1,   16,    3, 16,  4,  0 }, {      2,   16,    4, 16,  4,  0 },
    {      2,   16,    5, 16,  4,  0 }, {      2,   16,    6, 16,  4,  0 }, {      3,   16,    7, 17,  4,  0 }, {      3,   16,    8, 17,  4,  0 }, {      3,   16,    9, 17,  4,  0 },
    {      4,   15,   10, 17,  4,  0 }, {      4,   15,   11, 17,  4,  0 }, {      4,   15,   12, 17,  4,  0 }, {      5,   15,   13, 18,  4,  0 }, {      5,   15,   14, 18,  4,  0 },
    {      5,   15,   15, 18,  4,  0 }, {      6,   15,   16, 18,  4,  0 }, {      6,   15,   17, 18,  4,  0 }, {      7,   14,   18, 18,  4,  0 }, {      7,   14,   19, 18,  4,  0 },
    {      7,   14,   20, 18,  4,  0 }, {      8,   14,   21, 19,  4,  0 }, {      8,   14,   22, 19,  4,  0 }, {      8,   14,   23, 19,  4,  0 }, {      9,   13,   24, 19,  4,  0 },
    {      9,   13,   25, 19,  4,  0 }, {      9,   13,   26, 19,  4,  0 }, {     10,   12,   27, 20,  4,  0 }, {     10,   12,   28, 20,  4,  0 }, {     10,   12,   29, 20,  4,  0 },
    {     11,   11,   30, 20,  4,  0 }, {     11,   11,   31, 20,  4,  0 }, {     12,   10,   32, 20,  4,  0 }, {     12,   10,   33, 20,  4,  0 }, {     12,   10,   34, 20,  4,  0 },
    {     13,    9,   35, 21,  4,  0 }, {     13,    9,   36, 21,  4,  0 }, {     13,    9,   37, 21,  4,  0 }, {     14,    8,   38, 21,  4,  0 }, {     14,    8,   39, 21,  4,  0 },
    {     14,    8,   40, 21,  4,  0 }, {     14,    7,   41, 22,  4,  0 }, {     14,    7,   42, 22,  4,  0 }, {     14,    7,   43, 22,  4,  0 }, {     15,    6,   44, 22,  4,  0 },
    {     15,    6,   45, 22,  4,  0 }, {     15,    6,   46, 22,  4,  0 }, {     15,    5,   47, 22,  4,  0 }, {     15,    5,   48, 22,  4,  0 }, {     15,    4,   49, 23,  4,  0 },
    {     15,    4,   50, 23,  4,  0 }, {     15,    4,   51, 23,  4,  0 }, {     16,    3,   52, 23,  4,  0 }, {     16,    3,   53, 23,  4,  0 }, {     16,    3,   54, 23,  4,  0 },
    {     16,    2,   55, 24,  4,  0 }, {     16,    2,   56, 24,  4,  0 }, {     16,    2,   57, 24,  4,  0 }, {     16,    1,   58, 24,  4,  0 }, {     16,    1,   59, 24,  4,  0 },
    {     16,    1,   60, 24,  4,  0 }, {     16,    0,   61, 24,  4,  0 }, {     16,    0,   62, 24,  4,  0 }, {     16,    0,   63, 24,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E4FFC, {
    {     16,   31,    0, 24,  4,  0 }, {     16,   31,    1, 24,  4,  0 }, {     16,   30,    2, 24,  4,  0 }, {     16,   30,    3, 24,  4,  0 }, {     16,   29,    4, 25,  4,  0 },
    {     16,   29,    5, 25,  4,  0 }, {     15,   28,    6, 25,  4,  0 }, {     15,   28,    7, 25,  4,  0 }, {     15,   28,    8, 25,  4,  0 }, {     15,   27,    9, 26,  4,  0 },
    {     15,   27,   10, 26,  4,  0 }, {     15,   27,   11, 26,  4,  0 }, {     15,   26,   12, 26,  4,  0 }, {     15,   26,   13, 26,  4,  0 }, {     15,   26,   14, 26,  4,  0 },
    {     14,   25,   15, 26,  4,  0 }, {     14,   25,   16, 26,  4,  0 }, {     14,   25,   17, 26,  4,  0 }, {     14,   24,   18, 27,  4,  0 }, {     14,   24,   19, 27,  4,  0 },
    {     14,   24,   20, 27,  4,  0 }, {     13,   23,   21, 27,  4,  0 }, {     13,   23,   22, 27,  4,  0 }, {     13,   23,   23, 27,  4,  0 }, {     12,   22,   24, 28,  4,  0 },
    {     12,   22,   25, 28,  4,  0 }, {     12,   22,   26, 28,  4,  0 }, {     11,   21,   27, 28,  4,  0 }, {     11,   21,   28, 28,  4,  0 }, {     11,   21,   29, 28,  4,  0 },
    {     10,   20,   30, 28,  4,  0 }, {     10,   20,   31, 28,  4,  0 }, {     10,   20,   32, 28,  4,  0 }, {      9,   19,   33, 29,  4,  0 }, {      9,   19,   34, 29,  4,  0 },
    {      9,   19,   35, 29,  4,  0 }, {      8,   18,   36, 29,  4,  0 }, {      8,   18,   37, 29,  4,  0 }, {      8,   18,   38, 29,  4,  0 }, {      7,   18,   39, 30,  4,  0 },
    {      7,   18,   40, 30,  4,  0 }, {      7,   18,   41, 30,  4,  0 }, {      6,   17,   42, 30,  4,  0 }, {      6,   17,   43, 30,  4,  0 }, {      6,   17,   44, 30,  4,  0 },
    {      5,   17,   45, 30,  4,  0 }, {      5,   17,   46, 30,  4,  0 }, {      5,   17,   47, 30,  4,  0 }, {      4,   17,   48, 31,  4,  0 }, {      4,   17,   49, 31,  4,  0 },
    {      4,   17,   50, 31,  4,  0 }, {      3,   16,   51, 31,  4,  0 }, {      3,   16,   52, 31,  4,  0 }, {      3,   16,   53, 31,  4,  0 }, {      2,   16,   54,  0,  4,  0 },
    {      2,   16,   55,  0,  4,  0 }, {      2,   16,   56,  0,  4,  0 }, {      1,   16,   57,  0,  4,  0 }, {      1,   16,   58,  0,  4,  0 }, {      1,   16,   59,  0,  4,  0 },
    {      0,   16,   60,  0,  4,  0 }, {      0,   16,   61,  0,  4,  0 }, {      0,   16,   62,  0,  4,  0 }, {      0,   16,   63,  0,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E523E, {
    {     31,   16,   63,  0,  8,  0 }, {     31,   16,   62,  0,  8,  0 }, {     30,   16,   61,  0,  8,  0 }, {     30,   16,   60,  0,  8,  0 }, {     30,   16,   59,  0,  8,  0 },
    {     29,   16,   58, 31,  8,  0 }, {     29,   16,   57, 31,  8,  0 }, {     28,   15,   56, 31,  8,  0 }, {     28,   15,   55, 31,  8,  0 }, {     28,   15,   54, 31,  8,  0 },
    {     27,   15,   53, 30,  8,  0 }, {     27,   15,   52, 30,  8,  0 }, {     27,   15,   51, 30,  8,  0 }, {     26,   15,   50, 30,  8,  0 }, {     26,   15,   49, 30,  8,  0 },
    {     26,   15,   48, 30,  8,  0 }, {     25,   14,   47, 30,  8,  0 }, {     25,   14,   46, 30,  8,  0 }, {     25,   14,   45, 30,  8,  0 }, {     24,   14,   44, 29,  8,  0 },
    {     24,   14,   43, 29,  8,  0 }, {     24,   14,   42, 29,  8,  0 }, {     23,   13,   41, 29,  8,  0 }, {     23,   13,   40, 29,  8,  0 }, {     23,   13,   39, 29,  8,  0 },
    {     22,   12,   38, 28,  8,  0 }, {     22,   12,   37, 28,  8,  0 }, {     22,   12,   36, 28,  8,  0 }, {     21,   11,   35, 28,  8,  0 }, {     21,   11,   34, 28,  8,  0 },
    {     21,   11,   33, 28,  8,  0 }, {     20,   10,   32, 28,  8,  0 }, {     20,   10,   31, 28,  8,  0 }, {     20,   10,   30, 28,  8,  0 }, {     19,    9,   29, 27,  8,  0 },
    {     19,    9,   28, 27,  8,  0 }, {     19,    9,   27, 27,  8,  0 }, {     18,    8,   26, 27,  8,  0 }, {     18,    8,   25, 27,  8,  0 }, {     18,    8,   24, 27,  8,  0 },
    {     18,    7,   23, 26,  8,  0 }, {     18,    7,   22, 26,  8,  0 }, {     18,    7,   21, 26,  8,  0 }, {     17,    6,   20, 26,  8,  0 }, {     17,    6,   19, 26,  8,  0 },
    {     17,    6,   18, 26,  8,  0 }, {     17,    5,   17, 26,  8,  0 }, {     17,    5,   16, 26,  8,  0 }, {     17,    5,   15, 26,  8,  0 }, {     17,    4,   14, 25,  8,  0 },
    {     17,    4,   13, 25,  8,  0 }, {     17,    4,   12, 25,  8,  0 }, {     16,    3,   11, 25,  8,  0 }, {     16,    3,   10, 25,  8,  0 }, {     16,    3,    9, 25,  8,  0 },
    {     16,    2,    8, 24,  8,  0 }, {     16,    2,    7, 24,  8,  0 }, {     16,    2,    6, 24,  8,  0 }, {     16,    1,    5, 24,  8,  0 }, {     16,    1,    4, 24,  8,  0 },
    {     16,    1,    3, 24,  8,  0 }, {     16,    0,    2, 24,  8,  0 }, {     16,    0,    1, 24,  8,  0 }, {     16,    0,    0, 24,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E5480, {
    {     16,    0,   63,  8,  8,  0 }, {     16,    0,   62,  8,  8,  0 }, {     16,    1,   61,  8,  8,  0 }, {     16,    1,   60,  8,  8,  0 }, {     16,    2,   59,  8,  8,  0 },
    {     16,    2,   58,  8,  8,  0 }, {     16,    3,   57,  7,  8,  0 }, {     16,    3,   56,  7,  8,  0 }, {     15,    4,   55,  7,  8,  0 }, {     15,    4,   54,  7,  8,  0 },
    {     15,    4,   53,  7,  8,  0 }, {     15,    5,   52,  6,  8,  0 }, {     15,    5,   51,  6,  8,  0 }, {     15,    5,   50,  6,  8,  0 }, {     15,    6,   49,  6,  8,  0 },
    {     15,    6,   48,  6,  8,  0 }, {     15,    6,   47,  6,  8,  0 }, {     14,    7,   46,  6,  8,  0 }, {     14,    7,   45,  6,  8,  0 }, {     14,    7,   44,  6,  8,  0 },
    {     14,    8,   43,  5,  8,  0 }, {     14,    8,   42,  5,  8,  0 }, {     13,    9,   41,  5,  8,  0 }, {     13,    9,   40,  5,  8,  0 }, {     13,    9,   39,  5,  8,  0 },
    {     12,   10,   38,  4,  8,  0 }, {     12,   10,   37,  4,  8,  0 }, {     12,   10,   36,  4,  8,  0 }, {     11,   11,   35,  4,  8,  0 }, {     11,   11,   34,  4,  8,  0 },
    {     11,   11,   33,  4,  8,  0 }, {     10,   12,   32,  4,  8,  0 }, {     10,   12,   31,  4,  8,  0 }, {     10,   12,   30,  4,  8,  0 }, {      9,   13,   29,  3,  8,  0 },
    {      9,   13,   28,  3,  8,  0 }, {      9,   13,   27,  3,  8,  0 }, {      8,   14,   26,  3,  8,  0 }, {      8,   14,   25,  3,  8,  0 }, {      8,   14,   24,  3,  8,  0 },
    {      7,   14,   23,  2,  8,  0 }, {      7,   14,   22,  2,  8,  0 }, {      7,   14,   21,  2,  8,  0 }, {      6,   15,   20,  2,  8,  0 }, {      6,   15,   19,  2,  8,  0 },
    {      6,   15,   18,  2,  8,  0 }, {      5,   15,   17,  2,  8,  0 }, {      5,   15,   16,  2,  8,  0 }, {      5,   15,   15,  2,  8,  0 }, {      4,   15,   14,  1,  8,  0 },
    {      4,   15,   13,  1,  8,  0 }, {      4,   15,   12,  1,  8,  0 }, {      3,   16,   11,  1,  8,  0 }, {      3,   16,   10,  1,  8,  0 }, {      3,   16,    9,  1,  8,  0 },
    {      2,   16,    8,  0,  8,  0 }, {      2,   16,    7,  0,  8,  0 }, {      2,   16,    6,  0,  8,  0 }, {      1,   16,    5,  0,  8,  0 }, {      1,   16,    4,  0,  8,  0 },
    {      1,   16,    3,  0,  8,  0 }, {      0,   16,    2,  0,  8,  0 }, {      0,   16,    1,  0,  8,  0 }, {      0,   16,    0,  0,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E56C2, {
    {      0,   16,   63, 16,  8,  0 }, {      0,   16,   62, 16,  8,  0 }, {      1,   16,   61, 16,  8,  0 }, {      1,   16,   60, 16,  8,  0 }, {      1,   16,   59, 16,  8,  0 },
    {      2,   16,   58, 16,  8,  0 }, {      2,   16,   57, 16,  8,  0 }, {      3,   16,   56, 15,  8,  0 }, {      3,   16,   55, 15,  8,  0 }, {      3,   16,   54, 15,  8,  0 },
    {      4,   17,   53, 15,  8,  0 }, {      4,   17,   52, 15,  8,  0 }, {      4,   17,   51, 15,  8,  0 }, {      5,   17,   50, 14,  8,  0 }, {      5,   17,   49, 14,  8,  0 },
    {      5,   17,   48, 14,  8,  0 }, {      6,   17,   47, 14,  8,  0 }, {      6,   17,   46, 14,  8,  0 }, {      6,   17,   45, 14,  8,  0 }, {      7,   18,   44, 14,  8,  0 },
    {      7,   18,   43, 14,  8,  0 }, {      7,   18,   42, 14,  8,  0 }, {      8,   18,   41, 13,  8,  0 }, {      8,   18,   40, 13,  8,  0 }, {      8,   18,   39, 13,  8,  0 },
    {      9,   19,   38, 13,  8,  0 }, {      9,   19,   37, 13,  8,  0 }, {      9,   19,   36, 13,  8,  0 }, {     10,   20,   35, 12,  8,  0 }, {     10,   20,   34, 12,  8,  0 },
    {     10,   20,   33, 12,  8,  0 }, {     11,   21,   32, 12,  8,  0 }, {     11,   21,   31, 12,  8,  0 }, {     11,   21,   30, 12,  8,  0 }, {     12,   22,   29, 12,  8,  0 },
    {     12,   22,   28, 12,  8,  0 }, {     12,   22,   27, 12,  8,  0 }, {     13,   23,   26, 11,  8,  0 }, {     13,   23,   25, 11,  8,  0 }, {     13,   23,   24, 11,  8,  0 },
    {     14,   24,   23, 11,  8,  0 }, {     14,   24,   22, 11,  8,  0 }, {     14,   24,   21, 11,  8,  0 }, {     14,   25,   20, 10,  8,  0 }, {     14,   25,   19, 10,  8,  0 },
    {     14,   25,   18, 10,  8,  0 }, {     15,   26,   17, 10,  8,  0 }, {     15,   26,   16, 10,  8,  0 }, {     15,   26,   15, 10,  8,  0 }, {     15,   27,   14, 10,  8,  0 },
    {     15,   27,   13, 10,  8,  0 }, {     15,   27,   12, 10,  8,  0 }, {     15,   28,   11,  9,  8,  0 }, {     15,   28,   10,  9,  8,  0 }, {     15,   28,    9,  9,  8,  0 },
    {     16,   29,    8,  9,  8,  0 }, {     16,   29,    7,  9,  8,  0 }, {     16,   29,    6,  9,  8,  0 }, {     16,   30,    5,  8,  8,  0 }, {     16,   30,    4,  8,  8,  0 },
    {     16,   30,    3,  8,  8,  0 }, {     16,   31,    2,  8,  8,  0 }, {     16,   31,    1,  8,  8,  0 }, {     16,   31,    0,  8,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E5904, {
    {     16,   31,   63, 24,  8,  0 }, {     16,   31,   62, 24,  8,  0 }, {     16,   30,   61, 24,  8,  0 }, {     16,   30,   60, 24,  8,  0 }, {     16,   29,   59, 23,  8,  0 },
    {     16,   29,   58, 23,  8,  0 }, {     17,   28,   57, 23,  8,  0 }, {     17,   28,   56, 23,  8,  0 }, {     17,   28,   55, 23,  8,  0 }, {     17,   27,   54, 22,  8,  0 },
    {     17,   27,   53, 22,  8,  0 }, {     17,   27,   52, 22,  8,  0 }, {     17,   27,   51, 22,  8,  0 }, {     17,   26,   50, 22,  8,  0 }, {     17,   26,   49, 22,  8,  0 },
    {     17,   26,   48, 22,  8,  0 }, {     18,   25,   47, 22,  8,  0 }, {     18,   25,   46, 22,  8,  0 }, {     18,   25,   45, 22,  8,  0 }, {     18,   24,   44, 21,  8,  0 },
    {     18,   24,   43, 21,  8,  0 }, {     18,   24,   42, 21,  8,  0 }, {     19,   23,   41, 21,  8,  0 }, {     19,   23,   40, 21,  8,  0 }, {     19,   23,   39, 21,  8,  0 },
    {     20,   22,   38, 20,  8,  0 }, {     20,   22,   37, 20,  8,  0 }, {     20,   22,   36, 20,  8,  0 }, {     20,   22,   35, 20,  8,  0 }, {     21,   21,   34, 20,  8,  0 },
    {     21,   21,   33, 20,  8,  0 }, {     21,   21,   32, 20,  8,  0 }, {     22,   20,   31, 20,  8,  0 }, {     22,   20,   30, 20,  8,  0 }, {     22,   20,   29, 20,  8,  0 },
    {     23,   19,   28, 19,  8,  0 }, {     23,   19,   27, 19,  8,  0 }, {     23,   19,   26, 19,  8,  0 }, {     24,   18,   25, 19,  8,  0 }, {     24,   18,   24, 19,  8,  0 },
    {     24,   18,   23, 19,  8,  0 }, {     25,   18,   22, 18,  8,  0 }, {     25,   18,   21, 18,  8,  0 }, {     25,   18,   20, 18,  8,  0 }, {     26,   17,   19, 18,  8,  0 },
    {     26,   17,   18, 18,  8,  0 }, {     26,   17,   17, 18,  8,  0 }, {     26,   17,   16, 18,  8,  0 }, {     27,   17,   15, 18,  8,  0 }, {     27,   17,   14, 18,  8,  0 },
    {     27,   17,   13, 18,  8,  0 }, {     28,   17,   12, 17,  8,  0 }, {     28,   17,   11, 17,  8,  0 }, {     28,   17,   10, 17,  8,  0 }, {     29,   16,    9, 17,  8,  0 },
    {     29,   16,    8, 17,  8,  0 }, {     29,   16,    7, 17,  8,  0 }, {     30,   16,    6, 16,  8,  0 }, {     30,   16,    5, 16,  8,  0 }, {     30,   16,    4, 16,  8,  0 },
    {     31,   16,    3, 16,  8,  0 }, {     31,   16,    2, 16,  8,  0 }, {     31,   16,    1, 16,  8,  0 }, {     31,   16,    0, 16,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E5B46, {
    {     31,   16,   63,  0,  8,  0 }, {     31,   16,   62,  0,  8,  0 }, {     30,   16,   61,  0,  8,  0 }, {     30,   16,   60,  0,  8,  0 }, {     30,   16,   59,  0,  8,  0 },
    {     29,   16,   58,  1,  8,  0 }, {     29,   16,   57,  1,  8,  0 }, {     29,   16,   56,  1,  8,  0 }, {     28,   17,   55,  1,  8,  0 }, {     28,   17,   54,  1,  8,  0 },
    {     28,   17,   53,  1,  8,  0 }, {     27,   17,   52,  2,  8,  0 }, {     27,   17,   51,  2,  8,  0 }, {     27,   17,   50,  2,  8,  0 }, {     26,   17,   49,  2,  8,  0 },
    {     26,   17,   48,  2,  8,  0 }, {     26,   17,   47,  2,  8,  0 }, {     25,   18,   46,  2,  8,  0 }, {     25,   18,   45,  2,  8,  0 }, {     25,   18,   44,  2,  8,  0 },
    {     24,   18,   43,  3,  8,  0 }, {     24,   18,   42,  3,  8,  0 }, {     24,   18,   41,  3,  8,  0 }, {     23,   19,   40,  3,  8,  0 }, {     23,   19,   39,  3,  8,  0 },
    {     23,   19,   38,  3,  8,  0 }, {     22,   20,   37,  4,  8,  0 }, {     22,   20,   36,  4,  8,  0 }, {     22,   20,   35,  4,  8,  0 }, {     22,   20,   34,  4,  8,  0 },
    {     21,   21,   33,  4,  8,  0 }, {     21,   21,   32,  4,  8,  0 }, {     21,   21,   31,  4,  8,  0 }, {     20,   22,   30,  4,  8,  0 }, {     20,   22,   29,  4,  8,  0 },
    {     20,   22,   28,  4,  8,  0 }, {     19,   23,   27,  5,  8,  0 }, {     19,   23,   26,  5,  8,  0 }, {     19,   23,   25,  5,  8,  0 }, {     18,   24,   24,  5,  8,  0 },
    {     18,   24,   23,  5,  8,  0 }, {     18,   24,   22,  5,  8,  0 }, {     18,   25,   21,  6,  8,  0 }, {     18,   25,   20,  6,  8,  0 }, {     18,   25,   19,  6,  8,  0 },
    {     17,   26,   18,  6,  8,  0 }, {     17,   26,   17,  6,  8,  0 }, {     17,   26,   16,  6,  8,  0 }, {     17,   27,   15,  6,  8,  0 }, {     17,   27,   14,  6,  8,  0 },
    {     17,   27,   13,  6,  8,  0 }, {     17,   28,   12,  7,  8,  0 }, {     17,   28,   11,  7,  8,  0 }, {     17,   28,   10,  7,  8,  0 }, {     16,   29,    9,  7,  8,  0 },
    {     16,   29,    8,  7,  8,  0 }, {     16,   29,    7,  7,  8,  0 }, {     16,   30,    6,  8,  8,  0 }, {     16,   30,    5,  8,  8,  0 }, {     16,   30,    4,  8,  8,  0 },
    {     16,   31,    3,  8,  8,  0 }, {     16,   31,    2,  8,  8,  0 }, {     16,   31,    1,  8,  8,  0 }, {     16,   31,    0,  8,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E5D88, {
    {     16,    0,   63,  8,  8,  0 }, {     16,    0,   62,  8,  8,  0 }, {     16,    1,   61,  8,  8,  0 }, {     16,    1,   60,  8,  8,  0 }, {     16,    2,   59,  8,  8,  0 },
    {     16,    2,   58,  8,  8,  0 }, {     16,    3,   57,  9,  8,  0 }, {     16,    3,   56,  9,  8,  0 }, {     17,    4,   55,  9,  8,  0 }, {     17,    4,   54,  9,  8,  0 },
    {     17,    4,   53,  9,  8,  0 }, {     17,    5,   52, 10,  8,  0 }, {     17,    5,   51, 10,  8,  0 }, {     17,    5,   50, 10,  8,  0 }, {     17,    6,   49, 10,  8,  0 },
    {     17,    6,   48, 10,  8,  0 }, {     17,    6,   47, 10,  8,  0 }, {     18,    7,   46, 10,  8,  0 }, {     18,    7,   45, 10,  8,  0 }, {     18,    7,   44, 10,  8,  0 },
    {     18,    8,   43, 11,  8,  0 }, {     18,    8,   42, 11,  8,  0 }, {     18,    8,   41, 11,  8,  0 }, {     18,    8,   40, 11,  8,  0 }, {     19,    9,   39, 11,  8,  0 },
    {     19,    9,   38, 11,  8,  0 }, {     19,    9,   37, 11,  8,  0 }, {     20,   10,   36, 12,  8,  0 }, {     20,   10,   35, 12,  8,  0 }, {     20,   10,   34, 12,  8,  0 },
    {     21,   11,   33, 12,  8,  0 }, {     21,   11,   32, 12,  8,  0 }, {     21,   11,   31, 12,  8,  0 }, {     22,   12,   30, 12,  8,  0 }, {     22,   12,   29, 12,  8,  0 },
    {     22,   12,   28, 12,  8,  0 }, {     23,   13,   27, 13,  8,  0 }, {     23,   13,   26, 13,  8,  0 }, {     23,   13,   25, 13,  8,  0 }, {     24,   14,   24, 13,  8,  0 },
    {     24,   14,   23, 13,  8,  0 }, {     24,   14,   22, 13,  8,  0 }, {     25,   14,   21, 14,  8,  0 }, {     25,   14,   20, 14,  8,  0 }, {     25,   14,   19, 14,  8,  0 },
    {     26,   15,   18, 14,  8,  0 }, {     26,   15,   17, 14,  8,  0 }, {     26,   15,   16, 14,  8,  0 }, {     27,   15,   15, 14,  8,  0 }, {     27,   15,   14, 14,  8,  0 },
    {     27,   15,   13, 14,  8,  0 }, {     28,   15,   12, 15,  8,  0 }, {     28,   15,   11, 15,  8,  0 }, {     28,   15,   10, 15,  8,  0 }, {     29,   16,    9, 15,  8,  0 },
    {     29,   16,    8, 15,  8,  0 }, {     29,   16,    7, 15,  8,  0 }, {     30,   16,    6, 16,  8,  0 }, {     30,   16,    5, 16,  8,  0 }, {     30,   16,    4, 16,  8,  0 },
    {     31,   16,    3, 16,  8,  0 }, {     31,   16,    2, 16,  8,  0 }, {     31,   16,    1, 16,  8,  0 }, {     31,   16,    0, 16,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E5FCA, {
    {      0,   16,   63, 16,  8,  0 }, {      1,   16,   62, 16,  8,  0 }, {      1,   16,   61, 16,  8,  0 }, {      1,   16,   60, 16,  8,  0 }, {      2,   16,   59, 16,  8,  0 },
    {      2,   16,   58, 16,  8,  0 }, {      2,   16,   57, 16,  8,  0 }, {      3,   16,   56, 17,  8,  0 }, {      3,   16,   55, 17,  8,  0 }, {      3,   16,   54, 17,  8,  0 },
    {      4,   15,   53, 17,  8,  0 }, {      4,   15,   52, 17,  8,  0 }, {      4,   15,   51, 17,  8,  0 }, {      5,   15,   50, 18,  8,  0 }, {      5,   15,   49, 18,  8,  0 },
    {      5,   15,   48, 18,  8,  0 }, {      6,   15,   47, 18,  8,  0 }, {      6,   15,   46, 18,  8,  0 }, {      7,   14,   45, 18,  8,  0 }, {      7,   14,   44, 18,  8,  0 },
    {      7,   14,   43, 18,  8,  0 }, {      8,   14,   42, 19,  8,  0 }, {      8,   14,   41, 19,  8,  0 }, {      8,   14,   40, 19,  8,  0 }, {      9,   13,   39, 19,  8,  0 },
    {      9,   13,   38, 19,  8,  0 }, {      9,   13,   37, 19,  8,  0 }, {     10,   12,   36, 20,  8,  0 }, {     10,   12,   35, 20,  8,  0 }, {     10,   12,   34, 20,  8,  0 },
    {     11,   11,   33, 20,  8,  0 }, {     11,   11,   32, 20,  8,  0 }, {     12,   10,   31, 20,  8,  0 }, {     12,   10,   30, 20,  8,  0 }, {     12,   10,   29, 20,  8,  0 },
    {     13,    9,   28, 21,  8,  0 }, {     13,    9,   27, 21,  8,  0 }, {     13,    9,   26, 21,  8,  0 }, {     14,    8,   25, 21,  8,  0 }, {     14,    8,   24, 21,  8,  0 },
    {     14,    8,   23, 21,  8,  0 }, {     14,    7,   22, 22,  8,  0 }, {     14,    7,   21, 22,  8,  0 }, {     14,    7,   20, 22,  8,  0 }, {     15,    6,   19, 22,  8,  0 },
    {     15,    6,   18, 22,  8,  0 }, {     15,    6,   17, 22,  8,  0 }, {     15,    5,   16, 22,  8,  0 }, {     15,    5,   15, 22,  8,  0 }, {     15,    4,   14, 23,  8,  0 },
    {     15,    4,   13, 23,  8,  0 }, {     15,    4,   12, 23,  8,  0 }, {     16,    3,   11, 23,  8,  0 }, {     16,    3,   10, 23,  8,  0 }, {     16,    3,    9, 23,  8,  0 },
    {     16,    2,    8, 24,  8,  0 }, {     16,    2,    7, 24,  8,  0 }, {     16,    2,    6, 24,  8,  0 }, {     16,    1,    5, 24,  8,  0 }, {     16,    1,    4, 24,  8,  0 },
    {     16,    1,    3, 24,  8,  0 }, {     16,    0,    2, 24,  8,  0 }, {     16,    0,    1, 24,  8,  0 }, {     16,    0,    0, 24,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E620C, {
    {     16,   31,   63, 24,  8,  0 }, {     16,   31,   62, 24,  8,  0 }, {     16,   30,   61, 24,  8,  0 }, {     16,   30,   60, 24,  8,  0 }, {     16,   29,   59, 25,  8,  0 },
    {     16,   29,   58, 25,  8,  0 }, {     15,   28,   57, 25,  8,  0 }, {     15,   28,   56, 25,  8,  0 }, {     15,   28,   55, 25,  8,  0 }, {     15,   27,   54, 26,  8,  0 },
    {     15,   27,   53, 26,  8,  0 }, {     15,   27,   52, 26,  8,  0 }, {     15,   26,   51, 26,  8,  0 }, {     15,   26,   50, 26,  8,  0 }, {     15,   26,   49, 26,  8,  0 },
    {     14,   25,   48, 26,  8,  0 }, {     14,   25,   47, 26,  8,  0 }, {     14,   25,   46, 26,  8,  0 }, {     14,   24,   45, 27,  8,  0 }, {     14,   24,   44, 27,  8,  0 },
    {     14,   24,   43, 27,  8,  0 }, {     13,   23,   42, 27,  8,  0 }, {     13,   23,   41, 27,  8,  0 }, {     13,   23,   40, 27,  8,  0 }, {     12,   22,   39, 28,  8,  0 },
    {     12,   22,   38, 28,  8,  0 }, {     12,   22,   37, 28,  8,  0 }, {     11,   21,   36, 28,  8,  0 }, {     11,   21,   35, 28,  8,  0 }, {     11,   21,   34, 28,  8,  0 },
    {     10,   20,   33, 28,  8,  0 }, {     10,   20,   32, 28,  8,  0 }, {     10,   20,   31, 28,  8,  0 }, {      9,   19,   30, 29,  8,  0 }, {      9,   19,   29, 29,  8,  0 },
    {      9,   19,   28, 29,  8,  0 }, {      8,   18,   27, 29,  8,  0 }, {      8,   18,   26, 29,  8,  0 }, {      8,   18,   25, 29,  8,  0 }, {      7,   18,   24, 30,  8,  0 },
    {      7,   18,   23, 30,  8,  0 }, {      7,   18,   22, 30,  8,  0 }, {      6,   17,   21, 30,  8,  0 }, {      6,   17,   20, 30,  8,  0 }, {      6,   17,   19, 30,  8,  0 },
    {      5,   17,   18, 30,  8,  0 }, {      5,   17,   17, 30,  8,  0 }, {      5,   17,   16, 30,  8,  0 }, {      4,   17,   15, 31,  8,  0 }, {      4,   17,   14, 31,  8,  0 },
    {      4,   17,   13, 31,  8,  0 }, {      3,   16,   12, 31,  8,  0 }, {      3,   16,   11, 31,  8,  0 }, {      3,   16,   10, 31,  8,  0 }, {      2,   16,    9,  0,  8,  0 },
    {      2,   16,    8,  0,  8,  0 }, {      2,   16,    7,  0,  8,  0 }, {      1,   16,    6,  0,  8,  0 }, {      1,   16,    5,  0,  8,  0 }, {      1,   16,    4,  0,  8,  0 },
    {      0,   16,    3,  0,  8,  0 }, {      0,   16,    2,  0,  8,  0 }, {      0,   16,    1,  0,  8,  0 }, {      0,   16,    0,  0,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B0EB2, {
    {     31,   16,    0,  0, 48,  2 }, {     30,   16,    0,  0, 48,  2 }, {     29,   16,    0,  0, 48,  2 }, {     28,   16,    0,  0, 48,  2 }, {     27,   16,    0,  0, 48,  2 },
    {     26,   16,    0,  0, 48,  2 }, {     25,   16,    0,  0, 48,  2 }, {     24,   16,    1, 31, 48,  2 }, {     23,   15,    1, 31, 48,  2 }, {     22,   15,    1, 31, 48,  2 },
    {     21,   15,    1, 31, 48,  2 }, {     20,   15,    1, 31, 48,  2 }, {     19,   15,    1, 31, 48,  2 }, {     18,   15,    1, 31, 48,  2 }, {     17,   14,    2, 31, 48,  2 },
    {     16,   14,    2, 31, 48,  2 }, {     15,   14,    2, 31, 48,  2 }, {     14,   14,    2, 31, 48,  2 }, {     13,   14,    2, 31, 48,  2 }, {     12,   13,    2, 31, 48,  2 },
    {     11,   13,    2, 31, 48,  2 }, {     10,   13,    3, 30, 48,  2 }, {      9,   13,    3, 30, 48,  2 }, {      8,   12,    3, 30, 48,  2 }, {      7,   12,    3, 30, 48,  2 },
    {      6,   12,    3, 30, 48,  2 }, {      5,   11,    3, 30, 48,  2 }, {      4,   11,    3, 30, 48,  2 }, {      3,   11,    4, 30, 48,  2 }, {      2,   10,    4, 30, 48,  2 },
    {      1,   10,    4, 30, 48,  2 }, {      0,    9,    4, 30, 48,  2 }, {     -1,    9,    4, 30, 48,  2 }, {     -2,    8,    4, 30, 48,  2 }, {     -3,    8,    4, 30, 48,  2 },
    {     -4,    7,    5, 30, 48,  2 }, {     -5,    7,    5, 29, 48,  2 }, {     -6,    6,    5, 29, 48,  2 }, {     -7,    6,    5, 29, 48,  2 }, {     -8,    5,    5, 29, 48,  2 },
    {     -9,    4,    5, 29, 48,  2 }, {    -10,    4,    5, 29, 48,  2 }, {    -11,    3,    6, 29, 48,  2 }, {    -12,    2,    6, 29, 48,  2 }, {    -13,    2,    6, 29, 48,  2 },
    {    -14,    1,    6, 29, 48,  2 }, {    -15,    0,    6, 29, 48,  2 }, {    -16,    0,    6, 29, 48,  2 }, {    -17,   -1,    6, 29, 48,  2 }, {    -18,   -2,    7, 28, 48,  2 },
    {    -19,   -3,    7, 28, 48,  2 }, {    -20,   -3,    7, 28, 48,  2 }, {    -21,   -4,    7, 28, 48,  2 }, {    -22,   -5,    7, 28, 48,  2 }, {    -23,   -6,    7, 28, 48,  2 },
    {    -24,   -7,    7, 28, 48,  2 }, {    -25,   -7,    8, 28, 48,  2 }, {    -26,   -8,    8, 28, 48,  2 }, {    -27,   -9,    8, 28, 48,  2 }, {    -28,  -10,    8, 28, 48,  2 },
    {    -29,  -11,    8, 28, 48,  2 }, {    -29,  -12,    8, 28, 48,  2 }, {    -30,  -13,    8, 27, 48,  2 }, {    -31,  -14,    8, 27, 48,  2 }, {    -32,  -15,    9, 27, 48,  2 },
    {    -32,  -16,    9, 27, 48,  2 }, {    -33,  -17,    9, 27, 48,  2 }, {    -34,  -18,    9, 27, 48,  2 }, {    -34,  -19,    9, 27, 48,  2 }, {    -35,  -20,    9, 27, 48,  2 },
    {    -36,  -21,    9, 27, 48,  2 }, {    -36,  -22,   10, 27, 48,  2 }, {    -37,  -23,   10, 27, 48,  2 }, {    -38,  -24,   10, 27, 48,  2 }, {    -38,  -25,   10, 27, 48,  2 },
    {    -39,  -26,   10, 26, 48,  2 }, {    -39,  -27,   10, 26, 48,  2 }, {    -40,  -28,   10, 26, 48,  2 }, {    -40,  -29,   11, 26, 48,  2 }, {    -41,  -30,   11, 26, 48,  2 },
    {    -41,  -31,   11, 26, 48,  2 }, {    -42,  -32,   11, 26, 48,  2 }, {    -42,  -33,   11, 26, 48,  2 }, {    -43,  -34,   11, 26, 48,  2 }, {    -43,  -35,   11, 26, 48,  2 },
    {    -43,  -36,   12, 26, 48,  2 }, {    -44,  -37,   12, 26, 48,  2 }, {    -44,  -38,   12, 26, 48,  2 }, {    -44,  -39,   12, 26, 48,  2 }, {    -45,  -40,   12, 25, 48,  2 },
    {    -45,  -41,   12, 25, 48,  2 }, {    -45,  -42,   12, 25, 48,  2 }, {    -45,  -43,   13, 25, 48,  2 }, {    -46,  -44,   13, 25, 48,  2 }, {    -46,  -45,   13, 25, 48,  2 },
    {    -46,  -46,   13, 25, 48,  2 }, {    -46,  -47,   13, 25, 48,  2 }, {    -46,  -48,   13, 25, 48,  2 }, {    -47,  -49,   13, 25, 48,  2 }, {    -47,  -50,   14, 25, 48,  2 },
    {    -47,  -51,   14, 25, 48,  2 }, {    -47,  -52,   14, 25, 48,  2 }, {    -47,  -53,   14, 25, 48,  2 }, {    -47,  -54,   14, 25, 48,  2 }, {    -48,  -55,   14, 25, 48,  2 },
    {    -48,  -56,   14, 24, 48,  2 }, {    -48,  -57,   15, 24, 48,  2 }, {    -48,  -58,   15, 24, 48,  2 }, {    -48,  -59,   15, 24, 48,  2 }, {    -48,  -60,   15, 24, 48,  2 },
    {    -48,  -61,   15, 24, 48,  2 }, {    -48,  -62,   15, 24, 48,  2 }, {    -48,  -63,   15, 24, 48,  2 }, {    -48,  -64,   16, 24, 48,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B12B6, {
    {     16,    0,    0,  8, 48,  2 }, {     16,    1,    0,  8, 48,  2 }, {     16,    2,    0,  8, 48,  2 }, {     16,    3,    0,  8, 48,  2 }, {     16,    4,    0,  8, 48,  2 },
    {     16,    5,    0,  8, 48,  2 }, {     16,    6,    0,  8, 48,  2 }, {     16,    7,    0,  8, 48,  2 }, {     16,    8,    1,  7, 48,  2 }, {     15,    9,    1,  7, 48,  2 },
    {     15,   10,    1,  7, 48,  2 }, {     15,   11,    1,  7, 48,  2 }, {     15,   12,    1,  7, 48,  2 }, {     15,   13,    1,  7, 48,  2 }, {     15,   14,    1,  7, 48,  2 },
    {     14,   15,    2,  7, 48,  2 }, {     14,   16,    2,  7, 48,  2 }, {     14,   17,    2,  7, 48,  2 }, {     14,   18,    2,  7, 48,  2 }, {     14,   19,    2,  7, 48,  2 },
    {     13,   20,    2,  7, 48,  2 }, {     13,   21,    2,  7, 48,  2 }, {     13,   22,    3,  6, 48,  2 }, {     13,   23,    3,  6, 48,  2 }, {     12,   24,    3,  6, 48,  2 },
    {     12,   25,    3,  6, 48,  2 }, {     12,   26,    3,  6, 48,  2 }, {     11,   27,    3,  6, 48,  2 }, {     11,   28,    3,  6, 48,  2 }, {     11,   29,    4,  6, 48,  2 },
    {     10,   30,    4,  6, 48,  2 }, {     10,   31,    4,  6, 48,  2 }, {      9,   32,    4,  6, 48,  2 }, {      9,   33,    4,  6, 48,  2 }, {      8,   34,    4,  6, 48,  2 },
    {      8,   35,    4,  6, 48,  2 }, {      7,   36,    5,  6, 48,  2 }, {      7,   37,    5,  5, 48,  2 }, {      6,   38,    5,  5, 48,  2 }, {      6,   39,    5,  5, 48,  2 },
    {      5,   40,    5,  5, 48,  2 }, {      4,   41,    5,  5, 48,  2 }, {      4,   42,    5,  5, 48,  2 }, {      3,   43,    5,  5, 48,  2 }, {      2,   44,    6,  5, 48,  2 },
    {      2,   45,    6,  5, 48,  2 }, {      1,   46,    6,  5, 48,  2 }, {      0,   47,    6,  5, 48,  2 }, {      0,   48,    6,  5, 48,  2 }, {     -1,   49,    6,  5, 48,  2 },
    {     -2,   50,    6,  4, 48,  2 }, {     -3,   51,    7,  4, 48,  2 }, {     -3,   52,    7,  4, 48,  2 }, {     -4,   53,    7,  4, 48,  2 }, {     -5,   54,    7,  4, 48,  2 },
    {     -6,   55,    7,  4, 48,  2 }, {     -7,   56,    7,  4, 48,  2 }, {     -7,   57,    7,  4, 48,  2 }, {     -8,   58,    8,  4, 48,  2 }, {     -9,   59,    8,  4, 48,  2 },
    {    -10,   60,    8,  4, 48,  2 }, {    -11,   61,    8,  4, 48,  2 }, {    -12,   61,    8,  4, 48,  2 }, {    -13,   62,    8,  3, 48,  2 }, {    -14,   63,    8,  3, 48,  2 },
    {    -15,   64,    9,  3, 48,  2 }, {    -16,   64,    9,  3, 48,  2 }, {    -17,   65,    9,  3, 48,  2 }, {    -18,   66,    9,  3, 48,  2 }, {    -19,   66,    9,  3, 48,  2 },
    {    -20,   67,    9,  3, 48,  2 }, {    -21,   68,    9,  3, 48,  2 }, {    -22,   68,   10,  3, 48,  2 }, {    -23,   69,   10,  3, 48,  2 }, {    -24,   70,   10,  3, 48,  2 },
    {    -25,   70,   10,  3, 48,  2 }, {    -26,   71,   10,  2, 48,  2 }, {    -27,   71,   10,  2, 48,  2 }, {    -28,   72,   10,  2, 48,  2 }, {    -29,   72,   10,  2, 48,  2 },
    {    -30,   73,   11,  2, 48,  2 }, {    -31,   73,   11,  2, 48,  2 }, {    -32,   74,   11,  2, 48,  2 }, {    -33,   74,   11,  2, 48,  2 }, {    -34,   75,   11,  2, 48,  2 },
    {    -35,   75,   11,  2, 48,  2 }, {    -36,   75,   11,  2, 48,  2 }, {    -37,   76,   12,  2, 48,  2 }, {    -38,   76,   12,  2, 48,  2 }, {    -39,   76,   12,  2, 48,  2 },
    {    -40,   77,   12,  1, 48,  2 }, {    -41,   77,   12,  1, 48,  2 }, {    -42,   77,   12,  1, 48,  2 }, {    -43,   77,   12,  1, 48,  2 }, {    -44,   78,   13,  1, 48,  2 },
    {    -45,   78,   13,  1, 48,  2 }, {    -46,   78,   13,  1, 48,  2 }, {    -47,   78,   13,  1, 48,  2 }, {    -48,   78,   13,  1, 48,  2 }, {    -49,   79,   13,  1, 48,  2 },
    {    -50,   79,   13,  1, 48,  2 }, {    -51,   79,   14,  1, 48,  2 }, {    -52,   79,   14,  1, 48,  2 }, {    -53,   79,   14,  1, 48,  2 }, {    -54,   79,   14,  1, 48,  2 },
    {    -55,   80,   14,  1, 48,  2 }, {    -56,   80,   14,  0, 48,  2 }, {    -57,   80,   14,  0, 48,  2 }, {    -58,   80,   15,  0, 48,  2 }, {    -59,   80,   15,  0, 48,  2 },
    {    -60,   80,   15,  0, 48,  2 }, {    -61,   80,   15,  0, 48,  2 }, {    -62,   80,   15,  0, 48,  2 }, {    -63,   80,   15,  0, 48,  2 }, {    -64,   80,   15,  0, 48,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B16C3, {
    {      0,   16,    0, 16, 48,  2 }, {      1,   16,    0, 16, 48,  2 }, {      2,   16,    0, 16, 48,  2 }, {      3,   16,    0, 16, 48,  2 }, {      4,   16,    0, 16, 48,  2 },
    {      5,   16,    0, 16, 48,  2 }, {      6,   16,    0, 16, 48,  2 }, {      7,   16,    0, 16, 48,  2 }, {      8,   16,    1, 15, 48,  2 }, {      9,   17,    1, 15, 48,  2 },
    {     10,   17,    1, 15, 48,  2 }, {     11,   17,    1, 15, 48,  2 }, {     12,   17,    1, 15, 48,  2 }, {     13,   17,    1, 15, 48,  2 }, {     14,   17,    1, 15, 48,  2 },
    {     15,   18,    2, 15, 48,  2 }, {     16,   18,    2, 15, 48,  2 }, {     17,   18,    2, 15, 48,  2 }, {     18,   18,    2, 15, 48,  2 }, {     19,   18,    2, 15, 48,  2 },
    {     20,   19,    2, 15, 48,  2 }, {     21,   19,    2, 15, 48,  2 }, {     22,   19,    3, 14, 48,  2 }, {     23,   19,    3, 14, 48,  2 }, {     24,   20,    3, 14, 48,  2 },
    {     25,   20,    3, 14, 48,  2 }, {     26,   20,    3, 14, 48,  2 }, {     27,   21,    3, 14, 48,  2 }, {     28,   21,    3, 14, 48,  2 }, {     29,   21,    4, 14, 48,  2 },
    {     30,   22,    4, 14, 48,  2 }, {     31,   22,    4, 14, 48,  2 }, {     32,   23,    4, 14, 48,  2 }, {     33,   23,    4, 14, 48,  2 }, {     34,   24,    4, 14, 48,  2 },
    {     35,   24,    4, 14, 48,  2 }, {     36,   25,    5, 14, 48,  2 }, {     37,   25,    5, 13, 48,  2 }, {     38,   26,    5, 13, 48,  2 }, {     39,   26,    5, 13, 48,  2 },
    {     40,   27,    5, 13, 48,  2 }, {     41,   28,    5, 13, 48,  2 }, {     42,   28,    5, 13, 48,  2 }, {     43,   29,    6, 13, 48,  2 }, {     44,   30,    6, 13, 48,  2 },
    {     45,   30,    6, 13, 48,  2 }, {     46,   31,    6, 13, 48,  2 }, {     47,   32,    6, 13, 48,  2 }, {     48,   32,    6, 13, 48,  2 }, {     49,   33,    6, 13, 48,  2 },
    {     50,   34,    7, 12, 48,  2 }, {     51,   35,    7, 12, 48,  2 }, {     52,   35,    7, 12, 48,  2 }, {     53,   36,    7, 12, 48,  2 }, {     54,   37,    7, 12, 48,  2 },
    {     55,   38,    7, 12, 48,  2 }, {     56,   39,    7, 12, 48,  2 }, {     57,   39,    8, 12, 48,  2 }, {     58,   40,    8, 12, 48,  2 }, {     59,   41,    8, 12, 48,  2 },
    {     60,   42,    8, 12, 48,  2 }, {     61,   43,    8, 12, 48,  2 }, {     61,   44,    8, 12, 48,  2 }, {     62,   45,    8, 11, 48,  2 }, {     63,   46,    8, 11, 48,  2 },
    {     64,   47,    9, 11, 48,  2 }, {     64,   48,    9, 11, 48,  2 }, {     65,   49,    9, 11, 48,  2 }, {     66,   50,    9, 11, 48,  2 }, {     66,   51,    9, 11, 48,  2 },
    {     67,   52,    9, 11, 48,  2 }, {     68,   53,    9, 11, 48,  2 }, {     68,   54,   10, 11, 48,  2 }, {     69,   55,   10, 11, 48,  2 }, {     70,   56,   10, 11, 48,  2 },
    {     70,   57,   10, 11, 48,  2 }, {     71,   58,   10, 10, 48,  2 }, {     71,   59,   10, 10, 48,  2 }, {     72,   60,   10, 10, 48,  2 }, {     72,   61,   11, 10, 48,  2 },
    {     73,   62,   11, 10, 48,  2 }, {     73,   63,   11, 10, 48,  2 }, {     74,   64,   11, 10, 48,  2 }, {     74,   65,   11, 10, 48,  2 }, {     75,   66,   11, 10, 48,  2 },
    {     75,   67,   11, 10, 48,  2 }, {     75,   68,   12, 10, 48,  2 }, {     76,   69,   12, 10, 48,  2 }, {     76,   70,   12, 10, 48,  2 }, {     76,   71,   12, 10, 48,  2 },
    {     77,   72,   12,  9, 48,  2 }, {     77,   73,   12,  9, 48,  2 }, {     77,   74,   12,  9, 48,  2 }, {     77,   75,   13,  9, 48,  2 }, {     78,   76,   13,  9, 48,  2 },
    {     78,   77,   13,  9, 48,  2 }, {     78,   78,   13,  9, 48,  2 }, {     78,   79,   13,  9, 48,  2 }, {     78,   80,   13,  9, 48,  2 }, {     79,   81,   13,  9, 48,  2 },
    {     79,   82,   14,  9, 48,  2 }, {     79,   83,   14,  9, 48,  2 }, {     79,   84,   14,  9, 48,  2 }, {     79,   85,   14,  9, 48,  2 }, {     79,   86,   14,  9, 48,  2 },
    {     80,   87,   14,  9, 48,  2 }, {     80,   88,   14,  8, 48,  2 }, {     80,   89,   15,  8, 48,  2 }, {     80,   90,   15,  8, 48,  2 }, {     80,   91,   15,  8, 48,  2 },
    {     80,   92,   15,  8, 48,  2 }, {     80,   93,   15,  8, 48,  2 }, {     80,   94,   15,  8, 48,  2 }, {     80,   95,   15,  8, 48,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B1AC7, {
    {     16,   31,    0, 24, 48,  2 }, {     16,   30,    0, 24, 48,  2 }, {     16,   29,    0, 24, 48,  2 }, {     16,   28,    0, 24, 48,  2 }, {     16,   27,    0, 24, 48,  2 },
    {     16,   26,    0, 24, 48,  2 }, {     16,   25,    0, 24, 48,  2 }, {     16,   24,    1, 23, 48,  2 }, {     17,   23,    1, 23, 48,  2 }, {     17,   22,    1, 23, 48,  2 },
    {     17,   21,    1, 23, 48,  2 }, {     17,   20,    1, 23, 48,  2 }, {     17,   19,    1, 23, 48,  2 }, {     17,   18,    1, 23, 48,  2 }, {     18,   17,    2, 23, 48,  2 },
    {     18,   16,    2, 23, 48,  2 }, {     18,   15,    2, 23, 48,  2 }, {     18,   14,    2, 23, 48,  2 }, {     18,   13,    2, 23, 48,  2 }, {     19,   12,    2, 23, 48,  2 },
    {     19,   11,    2, 23, 48,  2 }, {     19,   10,    3, 22, 48,  2 }, {     19,    9,    3, 22, 48,  2 }, {     20,    8,    3, 22, 48,  2 }, {     20,    7,    3, 22, 48,  2 },
    {     20,    6,    3, 22, 48,  2 }, {     21,    5,    3, 22, 48,  2 }, {     21,    4,    3, 22, 48,  2 }, {     21,    3,    4, 22, 48,  2 }, {     22,    2,    4, 22, 48,  2 },
    {     22,    1,    4, 22, 48,  2 }, {     23,    0,    4, 22, 48,  2 }, {     23,   -1,    4, 22, 48,  2 }, {     24,   -2,    4, 22, 48,  2 }, {     24,   -3,    4, 22, 48,  2 },
    {     25,   -4,    5, 22, 48,  2 }, {     25,   -5,    5, 21, 48,  2 }, {     26,   -6,    5, 21, 48,  2 }, {     26,   -7,    5, 21, 48,  2 }, {     27,   -8,    5, 21, 48,  2 },
    {     28,   -9,    5, 21, 48,  2 }, {     28,  -10,    5, 21, 48,  2 }, {     29,  -11,    6, 21, 48,  2 }, {     30,  -12,    6, 21, 48,  2 }, {     30,  -13,    6, 21, 48,  2 },
    {     31,  -14,    6, 21, 48,  2 }, {     32,  -15,    6, 21, 48,  2 }, {     32,  -16,    6, 21, 48,  2 }, {     33,  -17,    6, 21, 48,  2 }, {     34,  -18,    7, 20, 48,  2 },
    {     35,  -19,    7, 20, 48,  2 }, {     35,  -20,    7, 20, 48,  2 }, {     36,  -21,    7, 20, 48,  2 }, {     37,  -22,    7, 20, 48,  2 }, {     38,  -23,    7, 20, 48,  2 },
    {     39,  -24,    7, 20, 48,  2 }, {     39,  -25,    8, 20, 48,  2 }, {     40,  -26,    8, 20, 48,  2 }, {     41,  -27,    8, 20, 48,  2 }, {     42,  -28,    8, 20, 48,  2 },
    {     43,  -29,    8, 20, 48,  2 }, {     44,  -29,    8, 20, 48,  2 }, {     45,  -30,    8, 19, 48,  2 }, {     46,  -31,    9, 19, 48,  2 }, {     47,  -32,    9, 19, 48,  2 },
    {     48,  -32,    9, 19, 48,  2 }, {     49,  -33,    9, 19, 48,  2 }, {     50,  -34,    9, 19, 48,  2 }, {     51,  -34,    9, 19, 48,  2 }, {     52,  -35,    9, 19, 48,  2 },
    {     53,  -36,   10, 19, 48,  2 }, {     54,  -36,   10, 19, 48,  2 }, {     55,  -37,   10, 19, 48,  2 }, {     56,  -38,   10, 19, 48,  2 }, {     57,  -38,   10, 19, 48,  2 },
    {     58,  -39,   10, 18, 48,  2 }, {     59,  -39,   10, 18, 48,  2 }, {     60,  -40,   11, 18, 48,  2 }, {     61,  -40,   11, 18, 48,  2 }, {     62,  -41,   11, 18, 48,  2 },
    {     63,  -41,   11, 18, 48,  2 }, {     64,  -42,   11, 18, 48,  2 }, {     65,  -42,   11, 18, 48,  2 }, {     66,  -43,   11, 18, 48,  2 }, {     67,  -43,   12, 18, 48,  2 },
    {     68,  -43,   12, 18, 48,  2 }, {     69,  -44,   12, 18, 48,  2 }, {     70,  -44,   12, 18, 48,  2 }, {     71,  -44,   12, 18, 48,  2 }, {     72,  -45,   12, 17, 48,  2 },
    {     73,  -45,   12, 17, 48,  2 }, {     74,  -45,   13, 17, 48,  2 }, {     75,  -45,   13, 17, 48,  2 }, {     76,  -46,   13, 17, 48,  2 }, {     77,  -46,   13, 17, 48,  2 },
    {     78,  -46,   13, 17, 48,  2 }, {     79,  -46,   13, 17, 48,  2 }, {     80,  -46,   13, 17, 48,  2 }, {     81,  -47,   14, 17, 48,  2 }, {     82,  -47,   14, 17, 48,  2 },
    {     83,  -47,   14, 17, 48,  2 }, {     84,  -47,   14, 17, 48,  2 }, {     85,  -47,   14, 17, 48,  2 }, {     86,  -47,   14, 17, 48,  2 }, {     87,  -48,   14, 17, 48,  2 },
    {     88,  -48,   15, 16, 48,  2 }, {     89,  -48,   15, 16, 48,  2 }, {     90,  -48,   15, 16, 48,  2 }, {     91,  -48,   15, 16, 48,  2 }, {     92,  -48,   15, 16, 48,  2 },
    {     93,  -48,   15, 16, 48,  2 }, {     94,  -48,   15, 16, 48,  2 }, {     95,  -48,   16, 16, 48,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B1EC2, {
    {     31,   16,    0,  0, 48,  4 }, {     30,   16,    0,  0, 48,  4 }, {     29,   16,    0,  0, 48,  4 }, {     28,   16,    0,  0, 48,  4 }, {     27,   16,    0,  0, 48,  4 },
    {     26,   16,    0,  0, 48,  4 }, {     25,   16,    0,  0, 48,  4 }, {     24,   16,    1,  1, 48,  4 }, {     23,   17,    1,  1, 48,  4 }, {     22,   17,    1,  1, 48,  4 },
    {     21,   17,    1,  1, 48,  4 }, {     20,   17,    1,  1, 48,  4 }, {     19,   17,    1,  1, 48,  4 }, {     18,   17,    1,  1, 48,  4 }, {     17,   18,    2,  1, 48,  4 },
    {     16,   18,    2,  1, 48,  4 }, {     15,   18,    2,  1, 48,  4 }, {     14,   18,    2,  1, 48,  4 }, {     13,   18,    2,  1, 48,  4 }, {     12,   19,    2,  1, 48,  4 },
    {     11,   19,    2,  1, 48,  4 }, {     10,   19,    3,  2, 48,  4 }, {      9,   19,    3,  2, 48,  4 }, {      8,   20,    3,  2, 48,  4 }, {      7,   20,    3,  2, 48,  4 },
    {      6,   20,    3,  2, 48,  4 }, {      5,   21,    3,  2, 48,  4 }, {      4,   21,    3,  2, 48,  4 }, {      3,   21,    4,  2, 48,  4 }, {      2,   22,    4,  2, 48,  4 },
    {      1,   22,    4,  2, 48,  4 }, {      0,   23,    4,  2, 48,  4 }, {     -1,   23,    4,  2, 48,  4 }, {     -2,   24,    4,  2, 48,  4 }, {     -3,   24,    4,  2, 48,  4 },
    {     -4,   25,    5,  2, 48,  4 }, {     -5,   25,    5,  3, 48,  4 }, {     -6,   26,    5,  3, 48,  4 }, {     -7,   26,    5,  3, 48,  4 }, {     -8,   27,    5,  3, 48,  4 },
    {     -9,   28,    5,  3, 48,  4 }, {    -10,   28,    5,  3, 48,  4 }, {    -11,   29,    6,  3, 48,  4 }, {    -12,   30,    6,  3, 48,  4 }, {    -13,   30,    6,  3, 48,  4 },
    {    -14,   31,    6,  3, 48,  4 }, {    -15,   32,    6,  3, 48,  4 }, {    -16,   32,    6,  3, 48,  4 }, {    -17,   33,    6,  3, 48,  4 }, {    -18,   34,    7,  4, 48,  4 },
    {    -19,   35,    7,  4, 48,  4 }, {    -20,   35,    7,  4, 48,  4 }, {    -21,   36,    7,  4, 48,  4 }, {    -22,   37,    7,  4, 48,  4 }, {    -23,   38,    7,  4, 48,  4 },
    {    -24,   39,    7,  4, 48,  4 }, {    -25,   39,    8,  4, 48,  4 }, {    -26,   40,    8,  4, 48,  4 }, {    -27,   41,    8,  4, 48,  4 }, {    -28,   42,    8,  4, 48,  4 },
    {    -29,   43,    8,  4, 48,  4 }, {    -29,   44,    8,  4, 48,  4 }, {    -30,   45,    8,  5, 48,  4 }, {    -31,   46,    9,  5, 48,  4 }, {    -32,   47,    9,  5, 48,  4 },
    {    -32,   48,    9,  5, 48,  4 }, {    -33,   49,    9,  5, 48,  4 }, {    -34,   50,    9,  5, 48,  4 }, {    -34,   51,    9,  5, 48,  4 }, {    -35,   52,    9,  5, 48,  4 },
    {    -36,   53,   10,  5, 48,  4 }, {    -36,   54,   10,  5, 48,  4 }, {    -37,   55,   10,  5, 48,  4 }, {    -38,   56,   10,  5, 48,  4 }, {    -38,   57,   10,  5, 48,  4 },
    {    -39,   58,   10,  6, 48,  4 }, {    -39,   59,   10,  6, 48,  4 }, {    -40,   60,   11,  6, 48,  4 }, {    -40,   61,   11,  6, 48,  4 }, {    -41,   62,   11,  6, 48,  4 },
    {    -41,   63,   11,  6, 48,  4 }, {    -42,   64,   11,  6, 48,  4 }, {    -42,   65,   11,  6, 48,  4 }, {    -43,   66,   11,  6, 48,  4 }, {    -43,   67,   12,  6, 48,  4 },
    {    -43,   68,   12,  6, 48,  4 }, {    -44,   69,   12,  6, 48,  4 }, {    -44,   70,   12,  6, 48,  4 }, {    -44,   71,   12,  6, 48,  4 }, {    -45,   72,   12,  7, 48,  4 },
    {    -45,   73,   12,  7, 48,  4 }, {    -45,   74,   13,  7, 48,  4 }, {    -45,   75,   13,  7, 48,  4 }, {    -46,   76,   13,  7, 48,  4 }, {    -46,   77,   13,  7, 48,  4 },
    {    -46,   78,   13,  7, 48,  4 }, {    -46,   79,   13,  7, 48,  4 }, {    -46,   80,   13,  7, 48,  4 }, {    -47,   81,   14,  7, 48,  4 }, {    -47,   82,   14,  7, 48,  4 },
    {    -47,   83,   14,  7, 48,  4 }, {    -47,   84,   14,  7, 48,  4 }, {    -47,   85,   14,  7, 48,  4 }, {    -47,   86,   14,  7, 48,  4 }, {    -48,   87,   14,  7, 48,  4 },
    {    -48,   88,   15,  8, 48,  4 }, {    -48,   89,   15,  8, 48,  4 }, {    -48,   90,   15,  8, 48,  4 }, {    -48,   91,   15,  8, 48,  4 }, {    -48,   92,   15,  8, 48,  4 },
    {    -48,   93,   15,  8, 48,  4 }, {    -48,   94,   15,  8, 48,  4 }, {    -48,   95,   16,  8, 48,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B22BD, {
    {     16,    0,    0,  8, 48,  4 }, {     16,    1,    0,  8, 48,  4 }, {     16,    2,    0,  8, 48,  4 }, {     16,    3,    0,  8, 48,  4 }, {     16,    4,    0,  8, 48,  4 },
    {     16,    5,    0,  8, 48,  4 }, {     16,    6,    0,  8, 48,  4 }, {     16,    7,    0,  8, 48,  4 }, {     16,    8,    1,  9, 48,  4 }, {     17,    9,    1,  9, 48,  4 },
    {     17,   10,    1,  9, 48,  4 }, {     17,   11,    1,  9, 48,  4 }, {     17,   12,    1,  9, 48,  4 }, {     17,   13,    1,  9, 48,  4 }, {     17,   14,    1,  9, 48,  4 },
    {     18,   15,    2,  9, 48,  4 }, {     18,   16,    2,  9, 48,  4 }, {     18,   17,    2,  9, 48,  4 }, {     18,   18,    2,  9, 48,  4 }, {     18,   19,    2,  9, 48,  4 },
    {     19,   20,    2,  9, 48,  4 }, {     19,   21,    2,  9, 48,  4 }, {     19,   22,    3, 10, 48,  4 }, {     19,   23,    3, 10, 48,  4 }, {     20,   24,    3, 10, 48,  4 },
    {     20,   25,    3, 10, 48,  4 }, {     20,   26,    3, 10, 48,  4 }, {     21,   27,    3, 10, 48,  4 }, {     21,   28,    3, 10, 48,  4 }, {     21,   29,    4, 10, 48,  4 },
    {     22,   30,    4, 10, 48,  4 }, {     22,   31,    4, 10, 48,  4 }, {     23,   32,    4, 10, 48,  4 }, {     23,   33,    4, 10, 48,  4 }, {     24,   34,    4, 10, 48,  4 },
    {     24,   35,    4, 10, 48,  4 }, {     25,   36,    5, 10, 48,  4 }, {     25,   37,    5, 11, 48,  4 }, {     26,   38,    5, 11, 48,  4 }, {     26,   39,    5, 11, 48,  4 },
    {     27,   40,    5, 11, 48,  4 }, {     28,   41,    5, 11, 48,  4 }, {     28,   42,    5, 11, 48,  4 }, {     29,   43,    6, 11, 48,  4 }, {     30,   44,    6, 11, 48,  4 },
    {     30,   45,    6, 11, 48,  4 }, {     31,   46,    6, 11, 48,  4 }, {     32,   47,    6, 11, 48,  4 }, {     32,   48,    6, 11, 48,  4 }, {     33,   49,    6, 11, 48,  4 },
    {     34,   50,    7, 12, 48,  4 }, {     35,   51,    7, 12, 48,  4 }, {     35,   52,    7, 12, 48,  4 }, {     36,   53,    7, 12, 48,  4 }, {     37,   54,    7, 12, 48,  4 },
    {     38,   55,    7, 12, 48,  4 }, {     39,   56,    7, 12, 48,  4 }, {     39,   57,    8, 12, 48,  4 }, {     40,   58,    8, 12, 48,  4 }, {     41,   59,    8, 12, 48,  4 },
    {     42,   60,    8, 12, 48,  4 }, {     43,   61,    8, 12, 48,  4 }, {     44,   61,    8, 12, 48,  4 }, {     45,   62,    8, 13, 48,  4 }, {     46,   63,    8, 13, 48,  4 },
    {     47,   64,    9, 13, 48,  4 }, {     48,   64,    9, 13, 48,  4 }, {     49,   65,    9, 13, 48,  4 }, {     50,   66,    9, 13, 48,  4 }, {     51,   66,    9, 13, 48,  4 },
    {     52,   67,    9, 13, 48,  4 }, {     53,   68,    9, 13, 48,  4 }, {     54,   68,   10, 13, 48,  4 }, {     55,   69,   10, 13, 48,  4 }, {     56,   70,   10, 13, 48,  4 },
    {     57,   70,   10, 13, 48,  4 }, {     58,   71,   10, 14, 48,  4 }, {     59,   71,   10, 14, 48,  4 }, {     60,   72,   10, 14, 48,  4 }, {     61,   72,   11, 14, 48,  4 },
    {     62,   73,   11, 14, 48,  4 }, {     63,   73,   11, 14, 48,  4 }, {     64,   74,   11, 14, 48,  4 }, {     65,   74,   11, 14, 48,  4 }, {     66,   75,   11, 14, 48,  4 },
    {     67,   75,   11, 14, 48,  4 }, {     68,   75,   12, 14, 48,  4 }, {     69,   76,   12, 14, 48,  4 }, {     70,   76,   12, 14, 48,  4 }, {     71,   76,   12, 14, 48,  4 },
    {     72,   77,   12, 15, 48,  4 }, {     73,   77,   12, 15, 48,  4 }, {     74,   77,   12, 15, 48,  4 }, {     75,   77,   13, 15, 48,  4 }, {     76,   78,   13, 15, 48,  4 },
    {     77,   78,   13, 15, 48,  4 }, {     78,   78,   13, 15, 48,  4 }, {     79,   78,   13, 15, 48,  4 }, {     80,   78,   13, 15, 48,  4 }, {     81,   79,   13, 15, 48,  4 },
    {     82,   79,   14, 15, 48,  4 }, {     83,   79,   14, 15, 48,  4 }, {     84,   79,   14, 15, 48,  4 }, {     85,   79,   14, 15, 48,  4 }, {     86,   79,   14, 15, 48,  4 },
    {     87,   80,   14, 15, 48,  4 }, {     88,   80,   14, 16, 48,  4 }, {     89,   80,   15, 16, 48,  4 }, {     90,   80,   15, 16, 48,  4 }, {     91,   80,   15, 16, 48,  4 },
    {     92,   80,   15, 16, 48,  4 }, {     93,   80,   15, 16, 48,  4 }, {     94,   80,   15, 16, 48,  4 }, {     95,   80,   15, 16, 48,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B26C1, {
    {      0,   16,    0, 16, 48,  4 }, {      1,   16,    0, 16, 48,  4 }, {      2,   16,    0, 16, 48,  4 }, {      3,   16,    0, 16, 48,  4 }, {      4,   16,    0, 16, 48,  4 },
    {      5,   16,    0, 16, 48,  4 }, {      6,   16,    0, 16, 48,  4 }, {      7,   16,    0, 16, 48,  4 }, {      8,   16,    1, 17, 48,  4 }, {      9,   15,    1, 17, 48,  4 },
    {     10,   15,    1, 17, 48,  4 }, {     11,   15,    1, 17, 48,  4 }, {     12,   15,    1, 17, 48,  4 }, {     13,   15,    1, 17, 48,  4 }, {     14,   15,    1, 17, 48,  4 },
    {     15,   14,    2, 17, 48,  4 }, {     16,   14,    2, 17, 48,  4 }, {     17,   14,    2, 17, 48,  4 }, {     18,   14,    2, 17, 48,  4 }, {     19,   14,    2, 17, 48,  4 },
    {     20,   13,    2, 17, 48,  4 }, {     21,   13,    2, 17, 48,  4 }, {     22,   13,    3, 18, 48,  4 }, {     23,   13,    3, 18, 48,  4 }, {     24,   12,    3, 18, 48,  4 },
    {     25,   12,    3, 18, 48,  4 }, {     26,   12,    3, 18, 48,  4 }, {     27,   11,    3, 18, 48,  4 }, {     28,   11,    3, 18, 48,  4 }, {     29,   11,    4, 18, 48,  4 },
    {     30,   10,    4, 18, 48,  4 }, {     31,   10,    4, 18, 48,  4 }, {     32,    9,    4, 18, 48,  4 }, {     33,    9,    4, 18, 48,  4 }, {     34,    8,    4, 18, 48,  4 },
    {     35,    8,    4, 18, 48,  4 }, {     36,    7,    5, 18, 48,  4 }, {     37,    7,    5, 19, 48,  4 }, {     38,    6,    5, 19, 48,  4 }, {     39,    6,    5, 19, 48,  4 },
    {     40,    5,    5, 19, 48,  4 }, {     41,    4,    5, 19, 48,  4 }, {     42,    4,    5, 19, 48,  4 }, {     43,    3,    5, 19, 48,  4 }, {     44,    2,    6, 19, 48,  4 },
    {     45,    2,    6, 19, 48,  4 }, {     46,    1,    6, 19, 48,  4 }, {     47,    0,    6, 19, 48,  4 }, {     48,    0,    6, 19, 48,  4 }, {     49,   -1,    6, 19, 48,  4 },
    {     50,   -2,    6, 20, 48,  4 }, {     51,   -3,    7, 20, 48,  4 }, {     52,   -3,    7, 20, 48,  4 }, {     53,   -4,    7, 20, 48,  4 }, {     54,   -5,    7, 20, 48,  4 },
    {     55,   -6,    7, 20, 48,  4 }, {     56,   -7,    7, 20, 48,  4 }, {     57,   -7,    7, 20, 48,  4 }, {     58,   -8,    8, 20, 48,  4 }, {     59,   -9,    8, 20, 48,  4 },
    {     60,  -10,    8, 20, 48,  4 }, {     61,  -11,    8, 20, 48,  4 }, {     61,  -12,    8, 20, 48,  4 }, {     62,  -13,    8, 21, 48,  4 }, {     63,  -14,    8, 21, 48,  4 },
    {     64,  -15,    9, 21, 48,  4 }, {     64,  -16,    9, 21, 48,  4 }, {     65,  -17,    9, 21, 48,  4 }, {     66,  -18,    9, 21, 48,  4 }, {     66,  -19,    9, 21, 48,  4 },
    {     67,  -20,    9, 21, 48,  4 }, {     68,  -21,    9, 21, 48,  4 }, {     68,  -22,   10, 21, 48,  4 }, {     69,  -23,   10, 21, 48,  4 }, {     70,  -24,   10, 21, 48,  4 },
    {     70,  -25,   10, 21, 48,  4 }, {     71,  -26,   10, 22, 48,  4 }, {     71,  -27,   10, 22, 48,  4 }, {     72,  -28,   10, 22, 48,  4 }, {     72,  -29,   10, 22, 48,  4 },
    {     73,  -30,   11, 22, 48,  4 }, {     73,  -31,   11, 22, 48,  4 }, {     74,  -32,   11, 22, 48,  4 }, {     74,  -33,   11, 22, 48,  4 }, {     75,  -34,   11, 22, 48,  4 },
    {     75,  -35,   11, 22, 48,  4 }, {     75,  -36,   11, 22, 48,  4 }, {     76,  -37,   12, 22, 48,  4 }, {     76,  -38,   12, 22, 48,  4 }, {     76,  -39,   12, 22, 48,  4 },
    {     77,  -40,   12, 23, 48,  4 }, {     77,  -41,   12, 23, 48,  4 }, {     77,  -42,   12, 23, 48,  4 }, {     77,  -43,   12, 23, 48,  4 }, {     78,  -44,   13, 23, 48,  4 },
    {     78,  -45,   13, 23, 48,  4 }, {     78,  -46,   13, 23, 48,  4 }, {     78,  -47,   13, 23, 48,  4 }, {     78,  -48,   13, 23, 48,  4 }, {     79,  -49,   13, 23, 48,  4 },
    {     79,  -50,   13, 23, 48,  4 }, {     79,  -51,   14, 23, 48,  4 }, {     79,  -52,   14, 23, 48,  4 }, {     79,  -53,   14, 23, 48,  4 }, {     79,  -54,   14, 23, 48,  4 },
    {     80,  -55,   14, 23, 48,  4 }, {     80,  -56,   14, 24, 48,  4 }, {     80,  -57,   14, 24, 48,  4 }, {     80,  -58,   15, 24, 48,  4 }, {     80,  -59,   15, 24, 48,  4 },
    {     80,  -60,   15, 24, 48,  4 }, {     80,  -61,   15, 24, 48,  4 }, {     80,  -62,   15, 24, 48,  4 }, {     80,  -63,   15, 24, 48,  4 }, {     80,  -64,   15, 24, 48,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B2ACE, {
    {     16,   31,    0, 24, 48,  4 }, {     16,   30,    0, 24, 48,  4 }, {     16,   29,    0, 24, 48,  4 }, {     16,   28,    0, 24, 48,  4 }, {     16,   27,    0, 24, 48,  4 },
    {     16,   26,    0, 24, 48,  4 }, {     16,   25,    0, 24, 48,  4 }, {     16,   24,    1, 25, 48,  4 }, {     15,   23,    1, 25, 48,  4 }, {     15,   22,    1, 25, 48,  4 },
    {     15,   21,    1, 25, 48,  4 }, {     15,   20,    1, 25, 48,  4 }, {     15,   19,    1, 25, 48,  4 }, {     15,   18,    1, 25, 48,  4 }, {     14,   17,    2, 25, 48,  4 },
    {     14,   16,    2, 25, 48,  4 }, {     14,   15,    2, 25, 48,  4 }, {     14,   14,    2, 25, 48,  4 }, {     14,   13,    2, 25, 48,  4 }, {     13,   12,    2, 25, 48,  4 },
    {     13,   11,    2, 25, 48,  4 }, {     13,   10,    3, 26, 48,  4 }, {     13,    9,    3, 26, 48,  4 }, {     12,    8,    3, 26, 48,  4 }, {     12,    7,    3, 26, 48,  4 },
    {     12,    6,    3, 26, 48,  4 }, {     11,    5,    3, 26, 48,  4 }, {     11,    4,    3, 26, 48,  4 }, {     11,    3,    4, 26, 48,  4 }, {     10,    2,    4, 26, 48,  4 },
    {     10,    1,    4, 26, 48,  4 }, {      9,    0,    4, 26, 48,  4 }, {      9,   -1,    4, 26, 48,  4 }, {      8,   -2,    4, 26, 48,  4 }, {      8,   -3,    4, 26, 48,  4 },
    {      7,   -4,    5, 26, 48,  4 }, {      7,   -5,    5, 27, 48,  4 }, {      6,   -6,    5, 27, 48,  4 }, {      6,   -7,    5, 27, 48,  4 }, {      5,   -8,    5, 27, 48,  4 },
    {      4,   -9,    5, 27, 48,  4 }, {      4,  -10,    5, 27, 48,  4 }, {      3,  -11,    6, 27, 48,  4 }, {      2,  -12,    6, 27, 48,  4 }, {      2,  -13,    6, 27, 48,  4 },
    {      1,  -14,    6, 27, 48,  4 }, {      0,  -15,    6, 27, 48,  4 }, {      0,  -16,    6, 27, 48,  4 }, {     -1,  -17,    6, 27, 48,  4 }, {     -2,  -18,    7, 28, 48,  4 },
    {     -3,  -19,    7, 28, 48,  4 }, {     -3,  -20,    7, 28, 48,  4 }, {     -4,  -21,    7, 28, 48,  4 }, {     -5,  -22,    7, 28, 48,  4 }, {     -6,  -23,    7, 28, 48,  4 },
    {     -7,  -24,    7, 28, 48,  4 }, {     -7,  -25,    8, 28, 48,  4 }, {     -8,  -26,    8, 28, 48,  4 }, {     -9,  -27,    8, 28, 48,  4 }, {    -10,  -28,    8, 28, 48,  4 },
    {    -11,  -29,    8, 28, 48,  4 }, {    -12,  -29,    8, 28, 48,  4 }, {    -13,  -30,    8, 29, 48,  4 }, {    -14,  -31,    8, 29, 48,  4 }, {    -15,  -32,    9, 29, 48,  4 },
    {    -16,  -32,    9, 29, 48,  4 }, {    -17,  -33,    9, 29, 48,  4 }, {    -18,  -34,    9, 29, 48,  4 }, {    -19,  -34,    9, 29, 48,  4 }, {    -20,  -35,    9, 29, 48,  4 },
    {    -21,  -36,    9, 29, 48,  4 }, {    -22,  -36,   10, 29, 48,  4 }, {    -23,  -37,   10, 29, 48,  4 }, {    -24,  -38,   10, 29, 48,  4 }, {    -25,  -38,   10, 29, 48,  4 },
    {    -26,  -39,   10, 30, 48,  4 }, {    -27,  -39,   10, 30, 48,  4 }, {    -28,  -40,   10, 30, 48,  4 }, {    -29,  -40,   11, 30, 48,  4 }, {    -30,  -41,   11, 30, 48,  4 },
    {    -31,  -41,   11, 30, 48,  4 }, {    -32,  -42,   11, 30, 48,  4 }, {    -33,  -42,   11, 30, 48,  4 }, {    -34,  -43,   11, 30, 48,  4 }, {    -35,  -43,   11, 30, 48,  4 },
    {    -36,  -43,   12, 30, 48,  4 }, {    -37,  -44,   12, 30, 48,  4 }, {    -38,  -44,   12, 30, 48,  4 }, {    -39,  -44,   12, 30, 48,  4 }, {    -40,  -45,   12, 31, 48,  4 },
    {    -41,  -45,   12, 31, 48,  4 }, {    -42,  -45,   12, 31, 48,  4 }, {    -43,  -45,   13, 31, 48,  4 }, {    -44,  -46,   13, 31, 48,  4 }, {    -45,  -46,   13, 31, 48,  4 },
    {    -46,  -46,   13, 31, 48,  4 }, {    -47,  -46,   13, 31, 48,  4 }, {    -48,  -46,   13, 31, 48,  4 }, {    -49,  -47,   13, 31, 48,  4 }, {    -50,  -47,   14, 31, 48,  4 },
    {    -51,  -47,   14, 31, 48,  4 }, {    -52,  -47,   14, 31, 48,  4 }, {    -53,  -47,   14, 31, 48,  4 }, {    -54,  -47,   14, 31, 48,  4 }, {    -55,  -48,   14, 31, 48,  4 },
    {    -56,  -48,   14,  0, 48,  4 }, {    -57,  -48,   15,  0, 48,  4 }, {    -58,  -48,   15,  0, 48,  4 }, {    -59,  -48,   15,  0, 48,  4 }, {    -60,  -48,   15,  0, 48,  4 },
    {    -61,  -48,   15,  0, 48,  4 }, {    -62,  -48,   15,  0, 48,  4 }, {    -63,  -48,   15,  0, 48,  4 }, {    -64,  -48,   16,  0, 48,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B2ED2, {
    {     31,   16,   16,  0, 49,  2 }, {     30,   16,   16,  0, 49,  2 }, {     29,   16,   16,  0, 49,  2 }, {     28,   16,   16,  0, 49,  2 }, {     27,   16,   16,  0, 49,  2 },
    {     26,   16,   16,  0, 49,  2 }, {     25,   16,   16,  0, 49,  2 }, {     24,   16,   15, 31, 49,  2 }, {     23,   15,   15, 31, 49,  2 }, {     22,   15,   15, 31, 49,  2 },
    {     21,   15,   15, 31, 49,  2 }, {     20,   15,   15, 31, 49,  2 }, {     19,   15,   15, 31, 49,  2 }, {     18,   15,   15, 31, 49,  2 }, {     17,   14,   14, 31, 49,  2 },
    {     16,   14,   14, 31, 49,  2 }, {     15,   14,   14, 31, 49,  2 }, {     14,   14,   14, 31, 49,  2 }, {     13,   14,   14, 31, 49,  2 }, {     12,   13,   14, 31, 49,  2 },
    {     11,   13,   14, 31, 49,  2 }, {     10,   13,   13, 30, 49,  2 }, {      9,   13,   13, 30, 49,  2 }, {      8,   12,   13, 30, 49,  2 }, {      7,   12,   13, 30, 49,  2 },
    {      6,   12,   13, 30, 49,  2 }, {      5,   11,   13, 30, 49,  2 }, {      4,   11,   13, 30, 49,  2 }, {      3,   11,   12, 30, 49,  2 }, {      2,   10,   12, 30, 49,  2 },
    {      1,   10,   12, 30, 49,  2 }, {      0,    9,   12, 30, 49,  2 }, {     -1,    9,   12, 30, 49,  2 }, {     -2,    8,   12, 30, 49,  2 }, {     -3,    8,   12, 30, 49,  2 },
    {     -4,    7,   11, 30, 49,  2 }, {     -5,    7,   11, 29, 49,  2 }, {     -6,    6,   11, 29, 49,  2 }, {     -7,    6,   11, 29, 49,  2 }, {     -8,    5,   11, 29, 49,  2 },
    {     -9,    4,   11, 29, 49,  2 }, {    -10,    4,   11, 29, 49,  2 }, {    -11,    3,   10, 29, 49,  2 }, {    -12,    2,   10, 29, 49,  2 }, {    -13,    2,   10, 29, 49,  2 },
    {    -14,    1,   10, 29, 49,  2 }, {    -15,    0,   10, 29, 49,  2 }, {    -16,    0,   10, 29, 49,  2 }, {    -17,   -1,   10, 29, 49,  2 }, {    -18,   -2,    9, 28, 49,  2 },
    {    -19,   -3,    9, 28, 49,  2 }, {    -20,   -3,    9, 28, 49,  2 }, {    -21,   -4,    9, 28, 49,  2 }, {    -22,   -5,    9, 28, 49,  2 }, {    -23,   -6,    9, 28, 49,  2 },
    {    -24,   -7,    9, 28, 49,  2 }, {    -25,   -7,    8, 28, 49,  2 }, {    -26,   -8,    8, 28, 49,  2 }, {    -27,   -9,    8, 28, 49,  2 }, {    -28,  -10,    8, 28, 49,  2 },
    {    -29,  -11,    8, 28, 49,  2 }, {    -29,  -12,    8, 28, 49,  2 }, {    -30,  -13,    8, 27, 49,  2 }, {    -31,  -14,    8, 27, 49,  2 }, {    -32,  -15,    7, 27, 49,  2 },
    {    -32,  -16,    7, 27, 49,  2 }, {    -33,  -17,    7, 27, 49,  2 }, {    -34,  -18,    7, 27, 49,  2 }, {    -34,  -19,    7, 27, 49,  2 }, {    -35,  -20,    7, 27, 49,  2 },
    {    -36,  -21,    7, 27, 49,  2 }, {    -36,  -22,    6, 27, 49,  2 }, {    -37,  -23,    6, 27, 49,  2 }, {    -38,  -24,    6, 27, 49,  2 }, {    -38,  -25,    6, 27, 49,  2 },
    {    -39,  -26,    6, 26, 49,  2 }, {    -39,  -27,    6, 26, 49,  2 }, {    -40,  -28,    6, 26, 49,  2 }, {    -40,  -29,    5, 26, 49,  2 }, {    -41,  -30,    5, 26, 49,  2 },
    {    -41,  -31,    5, 26, 49,  2 }, {    -42,  -32,    5, 26, 49,  2 }, {    -42,  -33,    5, 26, 49,  2 }, {    -43,  -34,    5, 26, 49,  2 }, {    -43,  -35,    5, 26, 49,  2 },
    {    -43,  -36,    4, 26, 49,  2 }, {    -44,  -37,    4, 26, 49,  2 }, {    -44,  -38,    4, 26, 49,  2 }, {    -44,  -39,    4, 26, 49,  2 }, {    -45,  -40,    4, 25, 49,  2 },
    {    -45,  -41,    4, 25, 49,  2 }, {    -45,  -42,    4, 25, 49,  2 }, {    -45,  -43,    3, 25, 49,  2 }, {    -46,  -44,    3, 25, 49,  2 }, {    -46,  -45,    3, 25, 49,  2 },
    {    -46,  -46,    3, 25, 49,  2 }, {    -46,  -47,    3, 25, 49,  2 }, {    -46,  -48,    3, 25, 49,  2 }, {    -47,  -49,    3, 25, 49,  2 }, {    -47,  -50,    2, 25, 49,  2 },
    {    -47,  -51,    2, 25, 49,  2 }, {    -47,  -52,    2, 25, 49,  2 }, {    -47,  -53,    2, 25, 49,  2 }, {    -47,  -54,    2, 25, 49,  2 }, {    -48,  -55,    2, 25, 49,  2 },
    {    -48,  -56,    2, 24, 49,  2 }, {    -48,  -57,    1, 24, 49,  2 }, {    -48,  -58,    1, 24, 49,  2 }, {    -48,  -59,    1, 24, 49,  2 }, {    -48,  -60,    1, 24, 49,  2 },
    {    -48,  -61,    1, 24, 49,  2 }, {    -48,  -62,    1, 24, 49,  2 }, {    -48,  -63,    1, 24, 49,  2 }, {    -48,  -64,    0, 24, 49,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B32D6, {
    {     16,    0,   16,  8, 49,  2 }, {     16,    1,   16,  8, 49,  2 }, {     16,    2,   16,  8, 49,  2 }, {     16,    3,   16,  8, 49,  2 }, {     16,    4,   16,  8, 49,  2 },
    {     16,    5,   16,  8, 49,  2 }, {     16,    6,   16,  8, 49,  2 }, {     16,    7,   16,  8, 49,  2 }, {     16,    8,   15,  7, 49,  2 }, {     15,    9,   15,  7, 49,  2 },
    {     15,   10,   15,  7, 49,  2 }, {     15,   11,   15,  7, 49,  2 }, {     15,   12,   15,  7, 49,  2 }, {     15,   13,   15,  7, 49,  2 }, {     15,   14,   15,  7, 49,  2 },
    {     14,   15,   14,  7, 49,  2 }, {     14,   16,   14,  7, 49,  2 }, {     14,   17,   14,  7, 49,  2 }, {     14,   18,   14,  7, 49,  2 }, {     14,   19,   14,  7, 49,  2 },
    {     13,   20,   14,  7, 49,  2 }, {     13,   21,   14,  7, 49,  2 }, {     13,   22,   13,  6, 49,  2 }, {     13,   23,   13,  6, 49,  2 }, {     12,   24,   13,  6, 49,  2 },
    {     12,   25,   13,  6, 49,  2 }, {     12,   26,   13,  6, 49,  2 }, {     11,   27,   13,  6, 49,  2 }, {     11,   28,   13,  6, 49,  2 }, {     11,   29,   12,  6, 49,  2 },
    {     10,   30,   12,  6, 49,  2 }, {     10,   31,   12,  6, 49,  2 }, {      9,   32,   12,  6, 49,  2 }, {      9,   33,   12,  6, 49,  2 }, {      8,   34,   12,  6, 49,  2 },
    {      8,   35,   12,  6, 49,  2 }, {      7,   36,   11,  6, 49,  2 }, {      7,   37,   11,  5, 49,  2 }, {      6,   38,   11,  5, 49,  2 }, {      6,   39,   11,  5, 49,  2 },
    {      5,   40,   11,  5, 49,  2 }, {      4,   41,   11,  5, 49,  2 }, {      4,   42,   11,  5, 49,  2 }, {      3,   43,   11,  5, 49,  2 }, {      2,   44,   10,  5, 49,  2 },
    {      2,   45,   10,  5, 49,  2 }, {      1,   46,   10,  5, 49,  2 }, {      0,   47,   10,  5, 49,  2 }, {      0,   48,   10,  5, 49,  2 }, {     -1,   49,   10,  5, 49,  2 },
    {     -2,   50,   10,  4, 49,  2 }, {     -3,   51,    9,  4, 49,  2 }, {     -3,   52,    9,  4, 49,  2 }, {     -4,   53,    9,  4, 49,  2 }, {     -5,   54,    9,  4, 49,  2 },
    {     -6,   55,    9,  4, 49,  2 }, {     -7,   56,    9,  4, 49,  2 }, {     -7,   57,    9,  4, 49,  2 }, {     -8,   58,    8,  4, 49,  2 }, {     -9,   59,    8,  4, 49,  2 },
    {    -10,   60,    8,  4, 49,  2 }, {    -11,   61,    8,  4, 49,  2 }, {    -12,   61,    8,  4, 49,  2 }, {    -13,   62,    8,  3, 49,  2 }, {    -14,   63,    8,  3, 49,  2 },
    {    -15,   64,    7,  3, 49,  2 }, {    -16,   64,    7,  3, 49,  2 }, {    -17,   65,    7,  3, 49,  2 }, {    -18,   66,    7,  3, 49,  2 }, {    -19,   66,    7,  3, 49,  2 },
    {    -20,   67,    7,  3, 49,  2 }, {    -21,   68,    7,  3, 49,  2 }, {    -22,   68,    6,  3, 49,  2 }, {    -23,   69,    6,  3, 49,  2 }, {    -24,   70,    6,  3, 49,  2 },
    {    -25,   70,    6,  3, 49,  2 }, {    -26,   71,    6,  2, 49,  2 }, {    -27,   71,    6,  2, 49,  2 }, {    -28,   72,    6,  2, 49,  2 }, {    -29,   72,    6,  2, 49,  2 },
    {    -30,   73,    5,  2, 49,  2 }, {    -31,   73,    5,  2, 49,  2 }, {    -32,   74,    5,  2, 49,  2 }, {    -33,   74,    5,  2, 49,  2 }, {    -34,   75,    5,  2, 49,  2 },
    {    -35,   75,    5,  2, 49,  2 }, {    -36,   75,    5,  2, 49,  2 }, {    -37,   76,    4,  2, 49,  2 }, {    -38,   76,    4,  2, 49,  2 }, {    -39,   76,    4,  2, 49,  2 },
    {    -40,   77,    4,  1, 49,  2 }, {    -41,   77,    4,  1, 49,  2 }, {    -42,   77,    4,  1, 49,  2 }, {    -43,   77,    4,  1, 49,  2 }, {    -44,   78,    3,  1, 49,  2 },
    {    -45,   78,    3,  1, 49,  2 }, {    -46,   78,    3,  1, 49,  2 }, {    -47,   78,    3,  1, 49,  2 }, {    -48,   78,    3,  1, 49,  2 }, {    -49,   79,    3,  1, 49,  2 },
    {    -50,   79,    3,  1, 49,  2 }, {    -51,   79,    2,  1, 49,  2 }, {    -52,   79,    2,  1, 49,  2 }, {    -53,   79,    2,  1, 49,  2 }, {    -54,   79,    2,  1, 49,  2 },
    {    -55,   80,    2,  1, 49,  2 }, {    -56,   80,    2,  0, 49,  2 }, {    -57,   80,    2,  0, 49,  2 }, {    -58,   80,    1,  0, 49,  2 }, {    -59,   80,    1,  0, 49,  2 },
    {    -60,   80,    1,  0, 49,  2 }, {    -61,   80,    1,  0, 49,  2 }, {    -62,   80,    1,  0, 49,  2 }, {    -63,   80,    1,  0, 49,  2 }, {    -64,   80,    1,  0, 49,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B36E3, {
    {      0,   16,   16, 16, 49,  2 }, {      1,   16,   16, 16, 49,  2 }, {      2,   16,   16, 16, 49,  2 }, {      3,   16,   16, 16, 49,  2 }, {      4,   16,   16, 16, 49,  2 },
    {      5,   16,   16, 16, 49,  2 }, {      6,   16,   16, 16, 49,  2 }, {      7,   16,   16, 16, 49,  2 }, {      8,   16,   15, 15, 49,  2 }, {      9,   17,   15, 15, 49,  2 },
    {     10,   17,   15, 15, 49,  2 }, {     11,   17,   15, 15, 49,  2 }, {     12,   17,   15, 15, 49,  2 }, {     13,   17,   15, 15, 49,  2 }, {     14,   17,   15, 15, 49,  2 },
    {     15,   18,   14, 15, 49,  2 }, {     16,   18,   14, 15, 49,  2 }, {     17,   18,   14, 15, 49,  2 }, {     18,   18,   14, 15, 49,  2 }, {     19,   18,   14, 15, 49,  2 },
    {     20,   19,   14, 15, 49,  2 }, {     21,   19,   14, 15, 49,  2 }, {     22,   19,   13, 14, 49,  2 }, {     23,   19,   13, 14, 49,  2 }, {     24,   20,   13, 14, 49,  2 },
    {     25,   20,   13, 14, 49,  2 }, {     26,   20,   13, 14, 49,  2 }, {     27,   21,   13, 14, 49,  2 }, {     28,   21,   13, 14, 49,  2 }, {     29,   21,   12, 14, 49,  2 },
    {     30,   22,   12, 14, 49,  2 }, {     31,   22,   12, 14, 49,  2 }, {     32,   23,   12, 14, 49,  2 }, {     33,   23,   12, 14, 49,  2 }, {     34,   24,   12, 14, 49,  2 },
    {     35,   24,   12, 14, 49,  2 }, {     36,   25,   11, 14, 49,  2 }, {     37,   25,   11, 13, 49,  2 }, {     38,   26,   11, 13, 49,  2 }, {     39,   26,   11, 13, 49,  2 },
    {     40,   27,   11, 13, 49,  2 }, {     41,   28,   11, 13, 49,  2 }, {     42,   28,   11, 13, 49,  2 }, {     43,   29,   10, 13, 49,  2 }, {     44,   30,   10, 13, 49,  2 },
    {     45,   30,   10, 13, 49,  2 }, {     46,   31,   10, 13, 49,  2 }, {     47,   32,   10, 13, 49,  2 }, {     48,   32,   10, 13, 49,  2 }, {     49,   33,   10, 13, 49,  2 },
    {     50,   34,    9, 12, 49,  2 }, {     51,   35,    9, 12, 49,  2 }, {     52,   35,    9, 12, 49,  2 }, {     53,   36,    9, 12, 49,  2 }, {     54,   37,    9, 12, 49,  2 },
    {     55,   38,    9, 12, 49,  2 }, {     56,   39,    9, 12, 49,  2 }, {     57,   39,    8, 12, 49,  2 }, {     58,   40,    8, 12, 49,  2 }, {     59,   41,    8, 12, 49,  2 },
    {     60,   42,    8, 12, 49,  2 }, {     61,   43,    8, 12, 49,  2 }, {     61,   44,    8, 12, 49,  2 }, {     62,   45,    8, 11, 49,  2 }, {     63,   46,    8, 11, 49,  2 },
    {     64,   47,    7, 11, 49,  2 }, {     64,   48,    7, 11, 49,  2 }, {     65,   49,    7, 11, 49,  2 }, {     66,   50,    7, 11, 49,  2 }, {     66,   51,    7, 11, 49,  2 },
    {     67,   52,    7, 11, 49,  2 }, {     68,   53,    7, 11, 49,  2 }, {     68,   54,    6, 11, 49,  2 }, {     69,   55,    6, 11, 49,  2 }, {     70,   56,    6, 11, 49,  2 },
    {     70,   57,    6, 11, 49,  2 }, {     71,   58,    6, 10, 49,  2 }, {     71,   59,    6, 10, 49,  2 }, {     72,   60,    6, 10, 49,  2 }, {     72,   61,    5, 10, 49,  2 },
    {     73,   62,    5, 10, 49,  2 }, {     73,   63,    5, 10, 49,  2 }, {     74,   64,    5, 10, 49,  2 }, {     74,   65,    5, 10, 49,  2 }, {     75,   66,    5, 10, 49,  2 },
    {     75,   67,    5, 10, 49,  2 }, {     75,   68,    4, 10, 49,  2 }, {     76,   69,    4, 10, 49,  2 }, {     76,   70,    4, 10, 49,  2 }, {     76,   71,    4, 10, 49,  2 },
    {     77,   72,    4,  9, 49,  2 }, {     77,   73,    4,  9, 49,  2 }, {     77,   74,    4,  9, 49,  2 }, {     77,   75,    3,  9, 49,  2 }, {     78,   76,    3,  9, 49,  2 },
    {     78,   77,    3,  9, 49,  2 }, {     78,   78,    3,  9, 49,  2 }, {     78,   79,    3,  9, 49,  2 }, {     78,   80,    3,  9, 49,  2 }, {     79,   81,    3,  9, 49,  2 },
    {     79,   82,    2,  9, 49,  2 }, {     79,   83,    2,  9, 49,  2 }, {     79,   84,    2,  9, 49,  2 }, {     79,   85,    2,  9, 49,  2 }, {     79,   86,    2,  9, 49,  2 },
    {     80,   87,    2,  9, 49,  2 }, {     80,   88,    2,  8, 49,  2 }, {     80,   89,    1,  8, 49,  2 }, {     80,   90,    1,  8, 49,  2 }, {     80,   91,    1,  8, 49,  2 },
    {     80,   92,    1,  8, 49,  2 }, {     80,   93,    1,  8, 49,  2 }, {     80,   94,    1,  8, 49,  2 }, {     80,   95,    1,  8, 49,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B3AE7, {
    {     16,   31,   16, 24, 49,  2 }, {     16,   30,   16, 24, 49,  2 }, {     16,   29,   16, 24, 49,  2 }, {     16,   28,   16, 24, 49,  2 }, {     16,   27,   16, 24, 49,  2 },
    {     16,   26,   16, 24, 49,  2 }, {     16,   25,   16, 24, 49,  2 }, {     16,   24,   15, 23, 49,  2 }, {     17,   23,   15, 23, 49,  2 }, {     17,   22,   15, 23, 49,  2 },
    {     17,   21,   15, 23, 49,  2 }, {     17,   20,   15, 23, 49,  2 }, {     17,   19,   15, 23, 49,  2 }, {     17,   18,   15, 23, 49,  2 }, {     18,   17,   14, 23, 49,  2 },
    {     18,   16,   14, 23, 49,  2 }, {     18,   15,   14, 23, 49,  2 }, {     18,   14,   14, 23, 49,  2 }, {     18,   13,   14, 23, 49,  2 }, {     19,   12,   14, 23, 49,  2 },
    {     19,   11,   14, 23, 49,  2 }, {     19,   10,   13, 22, 49,  2 }, {     19,    9,   13, 22, 49,  2 }, {     20,    8,   13, 22, 49,  2 }, {     20,    7,   13, 22, 49,  2 },
    {     20,    6,   13, 22, 49,  2 }, {     21,    5,   13, 22, 49,  2 }, {     21,    4,   13, 22, 49,  2 }, {     21,    3,   12, 22, 49,  2 }, {     22,    2,   12, 22, 49,  2 },
    {     22,    1,   12, 22, 49,  2 }, {     23,    0,   12, 22, 49,  2 }, {     23,   -1,   12, 22, 49,  2 }, {     24,   -2,   12, 22, 49,  2 }, {     24,   -3,   12, 22, 49,  2 },
    {     25,   -4,   11, 22, 49,  2 }, {     25,   -5,   11, 21, 49,  2 }, {     26,   -6,   11, 21, 49,  2 }, {     26,   -7,   11, 21, 49,  2 }, {     27,   -8,   11, 21, 49,  2 },
    {     28,   -9,   11, 21, 49,  2 }, {     28,  -10,   11, 21, 49,  2 }, {     29,  -11,   10, 21, 49,  2 }, {     30,  -12,   10, 21, 49,  2 }, {     30,  -13,   10, 21, 49,  2 },
    {     31,  -14,   10, 21, 49,  2 }, {     32,  -15,   10, 21, 49,  2 }, {     32,  -16,   10, 21, 49,  2 }, {     33,  -17,   10, 21, 49,  2 }, {     34,  -18,    9, 20, 49,  2 },
    {     35,  -19,    9, 20, 49,  2 }, {     35,  -20,    9, 20, 49,  2 }, {     36,  -21,    9, 20, 49,  2 }, {     37,  -22,    9, 20, 49,  2 }, {     38,  -23,    9, 20, 49,  2 },
    {     39,  -24,    9, 20, 49,  2 }, {     39,  -25,    8, 20, 49,  2 }, {     40,  -26,    8, 20, 49,  2 }, {     41,  -27,    8, 20, 49,  2 }, {     42,  -28,    8, 20, 49,  2 },
    {     43,  -29,    8, 20, 49,  2 }, {     44,  -29,    8, 20, 49,  2 }, {     45,  -30,    8, 19, 49,  2 }, {     46,  -31,    7, 19, 49,  2 }, {     47,  -32,    7, 19, 49,  2 },
    {     48,  -32,    7, 19, 49,  2 }, {     49,  -33,    7, 19, 49,  2 }, {     50,  -34,    7, 19, 49,  2 }, {     51,  -34,    7, 19, 49,  2 }, {     52,  -35,    7, 19, 49,  2 },
    {     53,  -36,    6, 19, 49,  2 }, {     54,  -36,    6, 19, 49,  2 }, {     55,  -37,    6, 19, 49,  2 }, {     56,  -38,    6, 19, 49,  2 }, {     57,  -38,    6, 19, 49,  2 },
    {     58,  -39,    6, 18, 49,  2 }, {     59,  -39,    6, 18, 49,  2 }, {     60,  -40,    5, 18, 49,  2 }, {     61,  -40,    5, 18, 49,  2 }, {     62,  -41,    5, 18, 49,  2 },
    {     63,  -41,    5, 18, 49,  2 }, {     64,  -42,    5, 18, 49,  2 }, {     65,  -42,    5, 18, 49,  2 }, {     66,  -43,    5, 18, 49,  2 }, {     67,  -43,    4, 18, 49,  2 },
    {     68,  -43,    4, 18, 49,  2 }, {     69,  -44,    4, 18, 49,  2 }, {     70,  -44,    4, 18, 49,  2 }, {     71,  -44,    4, 18, 49,  2 }, {     72,  -45,    4, 17, 49,  2 },
    {     73,  -45,    4, 17, 49,  2 }, {     74,  -45,    3, 17, 49,  2 }, {     75,  -45,    3, 17, 49,  2 }, {     76,  -46,    3, 17, 49,  2 }, {     77,  -46,    3, 17, 49,  2 },
    {     78,  -46,    3, 17, 49,  2 }, {     79,  -46,    3, 17, 49,  2 }, {     80,  -46,    3, 17, 49,  2 }, {     81,  -47,    2, 17, 49,  2 }, {     82,  -47,    2, 17, 49,  2 },
    {     83,  -47,    2, 17, 49,  2 }, {     84,  -47,    2, 17, 49,  2 }, {     85,  -47,    2, 17, 49,  2 }, {     86,  -47,    2, 17, 49,  2 }, {     87,  -48,    2, 17, 49,  2 },
    {     88,  -48,    1, 16, 49,  2 }, {     89,  -48,    1, 16, 49,  2 }, {     90,  -48,    1, 16, 49,  2 }, {     91,  -48,    1, 16, 49,  2 }, {     92,  -48,    1, 16, 49,  2 },
    {     93,  -48,    1, 16, 49,  2 }, {     94,  -48,    1, 16, 49,  2 }, {     95,  -48,    0, 16, 49,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B3EE2, {
    {     31,   16,   16,  0, 49,  4 }, {     30,   16,   16,  0, 49,  4 }, {     29,   16,   16,  0, 49,  4 }, {     28,   16,   16,  0, 49,  4 }, {     27,   16,   16,  0, 49,  4 },
    {     26,   16,   16,  0, 49,  4 }, {     25,   16,   16,  0, 49,  4 }, {     24,   16,   15,  1, 49,  4 }, {     23,   17,   15,  1, 49,  4 }, {     22,   17,   15,  1, 49,  4 },
    {     21,   17,   15,  1, 49,  4 }, {     20,   17,   15,  1, 49,  4 }, {     19,   17,   15,  1, 49,  4 }, {     18,   17,   15,  1, 49,  4 }, {     17,   18,   14,  1, 49,  4 },
    {     16,   18,   14,  1, 49,  4 }, {     15,   18,   14,  1, 49,  4 }, {     14,   18,   14,  1, 49,  4 }, {     13,   18,   14,  1, 49,  4 }, {     12,   19,   14,  1, 49,  4 },
    {     11,   19,   14,  1, 49,  4 }, {     10,   19,   13,  2, 49,  4 }, {      9,   19,   13,  2, 49,  4 }, {      8,   20,   13,  2, 49,  4 }, {      7,   20,   13,  2, 49,  4 },
    {      6,   20,   13,  2, 49,  4 }, {      5,   21,   13,  2, 49,  4 }, {      4,   21,   13,  2, 49,  4 }, {      3,   21,   12,  2, 49,  4 }, {      2,   22,   12,  2, 49,  4 },
    {      1,   22,   12,  2, 49,  4 }, {      0,   23,   12,  2, 49,  4 }, {     -1,   23,   12,  2, 49,  4 }, {     -2,   24,   12,  2, 49,  4 }, {     -3,   24,   12,  2, 49,  4 },
    {     -4,   25,   11,  2, 49,  4 }, {     -5,   25,   11,  3, 49,  4 }, {     -6,   26,   11,  3, 49,  4 }, {     -7,   26,   11,  3, 49,  4 }, {     -8,   27,   11,  3, 49,  4 },
    {     -9,   28,   11,  3, 49,  4 }, {    -10,   28,   11,  3, 49,  4 }, {    -11,   29,   10,  3, 49,  4 }, {    -12,   30,   10,  3, 49,  4 }, {    -13,   30,   10,  3, 49,  4 },
    {    -14,   31,   10,  3, 49,  4 }, {    -15,   32,   10,  3, 49,  4 }, {    -16,   32,   10,  3, 49,  4 }, {    -17,   33,   10,  3, 49,  4 }, {    -18,   34,    9,  4, 49,  4 },
    {    -19,   35,    9,  4, 49,  4 }, {    -20,   35,    9,  4, 49,  4 }, {    -21,   36,    9,  4, 49,  4 }, {    -22,   37,    9,  4, 49,  4 }, {    -23,   38,    9,  4, 49,  4 },
    {    -24,   39,    9,  4, 49,  4 }, {    -25,   39,    8,  4, 49,  4 }, {    -26,   40,    8,  4, 49,  4 }, {    -27,   41,    8,  4, 49,  4 }, {    -28,   42,    8,  4, 49,  4 },
    {    -29,   43,    8,  4, 49,  4 }, {    -29,   44,    8,  4, 49,  4 }, {    -30,   45,    8,  5, 49,  4 }, {    -31,   46,    7,  5, 49,  4 }, {    -32,   47,    7,  5, 49,  4 },
    {    -32,   48,    7,  5, 49,  4 }, {    -33,   49,    7,  5, 49,  4 }, {    -34,   50,    7,  5, 49,  4 }, {    -34,   51,    7,  5, 49,  4 }, {    -35,   52,    7,  5, 49,  4 },
    {    -36,   53,    6,  5, 49,  4 }, {    -36,   54,    6,  5, 49,  4 }, {    -37,   55,    6,  5, 49,  4 }, {    -38,   56,    6,  5, 49,  4 }, {    -38,   57,    6,  5, 49,  4 },
    {    -39,   58,    6,  6, 49,  4 }, {    -39,   59,    6,  6, 49,  4 }, {    -40,   60,    5,  6, 49,  4 }, {    -40,   61,    5,  6, 49,  4 }, {    -41,   62,    5,  6, 49,  4 },
    {    -41,   63,    5,  6, 49,  4 }, {    -42,   64,    5,  6, 49,  4 }, {    -42,   65,    5,  6, 49,  4 }, {    -43,   66,    5,  6, 49,  4 }, {    -43,   67,    4,  6, 49,  4 },
    {    -43,   68,    4,  6, 49,  4 }, {    -44,   69,    4,  6, 49,  4 }, {    -44,   70,    4,  6, 49,  4 }, {    -44,   71,    4,  6, 49,  4 }, {    -45,   72,    4,  7, 49,  4 },
    {    -45,   73,    4,  7, 49,  4 }, {    -45,   74,    3,  7, 49,  4 }, {    -45,   75,    3,  7, 49,  4 }, {    -46,   76,    3,  7, 49,  4 }, {    -46,   77,    3,  7, 49,  4 },
    {    -46,   78,    3,  7, 49,  4 }, {    -46,   79,    3,  7, 49,  4 }, {    -46,   80,    3,  7, 49,  4 }, {    -47,   81,    2,  7, 49,  4 }, {    -47,   82,    2,  7, 49,  4 },
    {    -47,   83,    2,  7, 49,  4 }, {    -47,   84,    2,  7, 49,  4 }, {    -47,   85,    2,  7, 49,  4 }, {    -47,   86,    2,  7, 49,  4 }, {    -48,   87,    2,  7, 49,  4 },
    {    -48,   88,    1,  8, 49,  4 }, {    -48,   89,    1,  8, 49,  4 }, {    -48,   90,    1,  8, 49,  4 }, {    -48,   91,    1,  8, 49,  4 }, {    -48,   92,    1,  8, 49,  4 },
    {    -48,   93,    1,  8, 49,  4 }, {    -48,   94,    1,  8, 49,  4 }, {    -48,   95,    0,  8, 49,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B42DD, {
    {     16,    0,   16,  8, 49,  4 }, {     16,    1,   16,  8, 49,  4 }, {     16,    2,   16,  8, 49,  4 }, {     16,    3,   16,  8, 49,  4 }, {     16,    4,   16,  8, 49,  4 },
    {     16,    5,   16,  8, 49,  4 }, {     16,    6,   16,  8, 49,  4 }, {     16,    7,   16,  8, 49,  4 }, {     16,    8,   15,  9, 49,  4 }, {     17,    9,   15,  9, 49,  4 },
    {     17,   10,   15,  9, 49,  4 }, {     17,   11,   15,  9, 49,  4 }, {     17,   12,   15,  9, 49,  4 }, {     17,   13,   15,  9, 49,  4 }, {     17,   14,   15,  9, 49,  4 },
    {     18,   15,   14,  9, 49,  4 }, {     18,   16,   14,  9, 49,  4 }, {     18,   17,   14,  9, 49,  4 }, {     18,   18,   14,  9, 49,  4 }, {     18,   19,   14,  9, 49,  4 },
    {     19,   20,   14,  9, 49,  4 }, {     19,   21,   14,  9, 49,  4 }, {     19,   22,   13, 10, 49,  4 }, {     19,   23,   13, 10, 49,  4 }, {     20,   24,   13, 10, 49,  4 },
    {     20,   25,   13, 10, 49,  4 }, {     20,   26,   13, 10, 49,  4 }, {     21,   27,   13, 10, 49,  4 }, {     21,   28,   13, 10, 49,  4 }, {     21,   29,   12, 10, 49,  4 },
    {     22,   30,   12, 10, 49,  4 }, {     22,   31,   12, 10, 49,  4 }, {     23,   32,   12, 10, 49,  4 }, {     23,   33,   12, 10, 49,  4 }, {     24,   34,   12, 10, 49,  4 },
    {     24,   35,   12, 10, 49,  4 }, {     25,   36,   11, 10, 49,  4 }, {     25,   37,   11, 11, 49,  4 }, {     26,   38,   11, 11, 49,  4 }, {     26,   39,   11, 11, 49,  4 },
    {     27,   40,   11, 11, 49,  4 }, {     28,   41,   11, 11, 49,  4 }, {     28,   42,   11, 11, 49,  4 }, {     29,   43,   10, 11, 49,  4 }, {     30,   44,   10, 11, 49,  4 },
    {     30,   45,   10, 11, 49,  4 }, {     31,   46,   10, 11, 49,  4 }, {     32,   47,   10, 11, 49,  4 }, {     32,   48,   10, 11, 49,  4 }, {     33,   49,   10, 11, 49,  4 },
    {     34,   50,    9, 12, 49,  4 }, {     35,   51,    9, 12, 49,  4 }, {     35,   52,    9, 12, 49,  4 }, {     36,   53,    9, 12, 49,  4 }, {     37,   54,    9, 12, 49,  4 },
    {     38,   55,    9, 12, 49,  4 }, {     39,   56,    9, 12, 49,  4 }, {     39,   57,    8, 12, 49,  4 }, {     40,   58,    8, 12, 49,  4 }, {     41,   59,    8, 12, 49,  4 },
    {     42,   60,    8, 12, 49,  4 }, {     43,   61,    8, 12, 49,  4 }, {     44,   61,    8, 12, 49,  4 }, {     45,   62,    8, 13, 49,  4 }, {     46,   63,    8, 13, 49,  4 },
    {     47,   64,    7, 13, 49,  4 }, {     48,   64,    7, 13, 49,  4 }, {     49,   65,    7, 13, 49,  4 }, {     50,   66,    7, 13, 49,  4 }, {     51,   66,    7, 13, 49,  4 },
    {     52,   67,    7, 13, 49,  4 }, {     53,   68,    7, 13, 49,  4 }, {     54,   68,    6, 13, 49,  4 }, {     55,   69,    6, 13, 49,  4 }, {     56,   70,    6, 13, 49,  4 },
    {     57,   70,    6, 13, 49,  4 }, {     58,   71,    6, 14, 49,  4 }, {     59,   71,    6, 14, 49,  4 }, {     60,   72,    6, 14, 49,  4 }, {     61,   72,    5, 14, 49,  4 },
    {     62,   73,    5, 14, 49,  4 }, {     63,   73,    5, 14, 49,  4 }, {     64,   74,    5, 14, 49,  4 }, {     65,   74,    5, 14, 49,  4 }, {     66,   75,    5, 14, 49,  4 },
    {     67,   75,    5, 14, 49,  4 }, {     68,   75,    4, 14, 49,  4 }, {     69,   76,    4, 14, 49,  4 }, {     70,   76,    4, 14, 49,  4 }, {     71,   76,    4, 14, 49,  4 },
    {     72,   77,    4, 15, 49,  4 }, {     73,   77,    4, 15, 49,  4 }, {     74,   77,    4, 15, 49,  4 }, {     75,   77,    3, 15, 49,  4 }, {     76,   78,    3, 15, 49,  4 },
    {     77,   78,    3, 15, 49,  4 }, {     78,   78,    3, 15, 49,  4 }, {     79,   78,    3, 15, 49,  4 }, {     80,   78,    3, 15, 49,  4 }, {     81,   79,    3, 15, 49,  4 },
    {     82,   79,    2, 15, 49,  4 }, {     83,   79,    2, 15, 49,  4 }, {     84,   79,    2, 15, 49,  4 }, {     85,   79,    2, 15, 49,  4 }, {     86,   79,    2, 15, 49,  4 },
    {     87,   80,    2, 15, 49,  4 }, {     88,   80,    2, 16, 49,  4 }, {     89,   80,    1, 16, 49,  4 }, {     90,   80,    1, 16, 49,  4 }, {     91,   80,    1, 16, 49,  4 },
    {     92,   80,    1, 16, 49,  4 }, {     93,   80,    1, 16, 49,  4 }, {     94,   80,    1, 16, 49,  4 }, {     95,   80,    1, 16, 49,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B46E1, {
    {      0,   16,   16, 16, 49,  4 }, {      1,   16,   16, 16, 49,  4 }, {      2,   16,   16, 16, 49,  4 }, {      3,   16,   16, 16, 49,  4 }, {      4,   16,   16, 16, 49,  4 },
    {      5,   16,   16, 16, 49,  4 }, {      6,   16,   16, 16, 49,  4 }, {      7,   16,   16, 16, 49,  4 }, {      8,   16,   15, 17, 49,  4 }, {      9,   15,   15, 17, 49,  4 },
    {     10,   15,   15, 17, 49,  4 }, {     11,   15,   15, 17, 49,  4 }, {     12,   15,   15, 17, 49,  4 }, {     13,   15,   15, 17, 49,  4 }, {     14,   15,   15, 17, 49,  4 },
    {     15,   14,   14, 17, 49,  4 }, {     16,   14,   14, 17, 49,  4 }, {     17,   14,   14, 17, 49,  4 }, {     18,   14,   14, 17, 49,  4 }, {     19,   14,   14, 17, 49,  4 },
    {     20,   13,   14, 17, 49,  4 }, {     21,   13,   14, 17, 49,  4 }, {     22,   13,   13, 18, 49,  4 }, {     23,   13,   13, 18, 49,  4 }, {     24,   12,   13, 18, 49,  4 },
    {     25,   12,   13, 18, 49,  4 }, {     26,   12,   13, 18, 49,  4 }, {     27,   11,   13, 18, 49,  4 }, {     28,   11,   13, 18, 49,  4 }, {     29,   11,   12, 18, 49,  4 },
    {     30,   10,   12, 18, 49,  4 }, {     31,   10,   12, 18, 49,  4 }, {     32,    9,   12, 18, 49,  4 }, {     33,    9,   12, 18, 49,  4 }, {     34,    8,   12, 18, 49,  4 },
    {     35,    8,   12, 18, 49,  4 }, {     36,    7,   11, 18, 49,  4 }, {     37,    7,   11, 19, 49,  4 }, {     38,    6,   11, 19, 49,  4 }, {     39,    6,   11, 19, 49,  4 },
    {     40,    5,   11, 19, 49,  4 }, {     41,    4,   11, 19, 49,  4 }, {     42,    4,   11, 19, 49,  4 }, {     43,    3,   11, 19, 49,  4 }, {     44,    2,   10, 19, 49,  4 },
    {     45,    2,   10, 19, 49,  4 }, {     46,    1,   10, 19, 49,  4 }, {     47,    0,   10, 19, 49,  4 }, {     48,    0,   10, 19, 49,  4 }, {     49,   -1,   10, 19, 49,  4 },
    {     50,   -2,   10, 20, 49,  4 }, {     51,   -3,    9, 20, 49,  4 }, {     52,   -3,    9, 20, 49,  4 }, {     53,   -4,    9, 20, 49,  4 }, {     54,   -5,    9, 20, 49,  4 },
    {     55,   -6,    9, 20, 49,  4 }, {     56,   -7,    9, 20, 49,  4 }, {     57,   -7,    9, 20, 49,  4 }, {     58,   -8,    8, 20, 49,  4 }, {     59,   -9,    8, 20, 49,  4 },
    {     60,  -10,    8, 20, 49,  4 }, {     61,  -11,    8, 20, 49,  4 }, {     61,  -12,    8, 20, 49,  4 }, {     62,  -13,    8, 21, 49,  4 }, {     63,  -14,    8, 21, 49,  4 },
    {     64,  -15,    7, 21, 49,  4 }, {     64,  -16,    7, 21, 49,  4 }, {     65,  -17,    7, 21, 49,  4 }, {     66,  -18,    7, 21, 49,  4 }, {     66,  -19,    7, 21, 49,  4 },
    {     67,  -20,    7, 21, 49,  4 }, {     68,  -21,    7, 21, 49,  4 }, {     68,  -22,    6, 21, 49,  4 }, {     69,  -23,    6, 21, 49,  4 }, {     70,  -24,    6, 21, 49,  4 },
    {     70,  -25,    6, 21, 49,  4 }, {     71,  -26,    6, 22, 49,  4 }, {     71,  -27,    6, 22, 49,  4 }, {     72,  -28,    6, 22, 49,  4 }, {     72,  -29,    6, 22, 49,  4 },
    {     73,  -30,    5, 22, 49,  4 }, {     73,  -31,    5, 22, 49,  4 }, {     74,  -32,    5, 22, 49,  4 }, {     74,  -33,    5, 22, 49,  4 }, {     75,  -34,    5, 22, 49,  4 },
    {     75,  -35,    5, 22, 49,  4 }, {     75,  -36,    5, 22, 49,  4 }, {     76,  -37,    4, 22, 49,  4 }, {     76,  -38,    4, 22, 49,  4 }, {     76,  -39,    4, 22, 49,  4 },
    {     77,  -40,    4, 23, 49,  4 }, {     77,  -41,    4, 23, 49,  4 }, {     77,  -42,    4, 23, 49,  4 }, {     77,  -43,    4, 23, 49,  4 }, {     78,  -44,    3, 23, 49,  4 },
    {     78,  -45,    3, 23, 49,  4 }, {     78,  -46,    3, 23, 49,  4 }, {     78,  -47,    3, 23, 49,  4 }, {     78,  -48,    3, 23, 49,  4 }, {     79,  -49,    3, 23, 49,  4 },
    {     79,  -50,    3, 23, 49,  4 }, {     79,  -51,    2, 23, 49,  4 }, {     79,  -52,    2, 23, 49,  4 }, {     79,  -53,    2, 23, 49,  4 }, {     79,  -54,    2, 23, 49,  4 },
    {     80,  -55,    2, 23, 49,  4 }, {     80,  -56,    2, 24, 49,  4 }, {     80,  -57,    2, 24, 49,  4 }, {     80,  -58,    1, 24, 49,  4 }, {     80,  -59,    1, 24, 49,  4 },
    {     80,  -60,    1, 24, 49,  4 }, {     80,  -61,    1, 24, 49,  4 }, {     80,  -62,    1, 24, 49,  4 }, {     80,  -63,    1, 24, 49,  4 }, {     80,  -64,    1, 24, 49,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B4AEE, {
    {     16,   31,   16, 24, 49,  4 }, {     16,   30,   16, 24, 49,  4 }, {     16,   29,   16, 24, 49,  4 }, {     16,   28,   16, 24, 49,  4 }, {     16,   27,   16, 24, 49,  4 },
    {     16,   26,   16, 24, 49,  4 }, {     16,   25,   16, 24, 49,  4 }, {     16,   24,   15, 25, 49,  4 }, {     15,   23,   15, 25, 49,  4 }, {     15,   22,   15, 25, 49,  4 },
    {     15,   21,   15, 25, 49,  4 }, {     15,   20,   15, 25, 49,  4 }, {     15,   19,   15, 25, 49,  4 }, {     15,   18,   15, 25, 49,  4 }, {     14,   17,   14, 25, 49,  4 },
    {     14,   16,   14, 25, 49,  4 }, {     14,   15,   14, 25, 49,  4 }, {     14,   14,   14, 25, 49,  4 }, {     14,   13,   14, 25, 49,  4 }, {     13,   12,   14, 25, 49,  4 },
    {     13,   11,   14, 25, 49,  4 }, {     13,   10,   13, 26, 49,  4 }, {     13,    9,   13, 26, 49,  4 }, {     12,    8,   13, 26, 49,  4 }, {     12,    7,   13, 26, 49,  4 },
    {     12,    6,   13, 26, 49,  4 }, {     11,    5,   13, 26, 49,  4 }, {     11,    4,   13, 26, 49,  4 }, {     11,    3,   12, 26, 49,  4 }, {     10,    2,   12, 26, 49,  4 },
    {     10,    1,   12, 26, 49,  4 }, {      9,    0,   12, 26, 49,  4 }, {      9,   -1,   12, 26, 49,  4 }, {      8,   -2,   12, 26, 49,  4 }, {      8,   -3,   12, 26, 49,  4 },
    {      7,   -4,   11, 26, 49,  4 }, {      7,   -5,   11, 27, 49,  4 }, {      6,   -6,   11, 27, 49,  4 }, {      6,   -7,   11, 27, 49,  4 }, {      5,   -8,   11, 27, 49,  4 },
    {      4,   -9,   11, 27, 49,  4 }, {      4,  -10,   11, 27, 49,  4 }, {      3,  -11,   10, 27, 49,  4 }, {      2,  -12,   10, 27, 49,  4 }, {      2,  -13,   10, 27, 49,  4 },
    {      1,  -14,   10, 27, 49,  4 }, {      0,  -15,   10, 27, 49,  4 }, {      0,  -16,   10, 27, 49,  4 }, {     -1,  -17,   10, 27, 49,  4 }, {     -2,  -18,    9, 28, 49,  4 },
    {     -3,  -19,    9, 28, 49,  4 }, {     -3,  -20,    9, 28, 49,  4 }, {     -4,  -21,    9, 28, 49,  4 }, {     -5,  -22,    9, 28, 49,  4 }, {     -6,  -23,    9, 28, 49,  4 },
    {     -7,  -24,    9, 28, 49,  4 }, {     -7,  -25,    8, 28, 49,  4 }, {     -8,  -26,    8, 28, 49,  4 }, {     -9,  -27,    8, 28, 49,  4 }, {    -10,  -28,    8, 28, 49,  4 },
    {    -11,  -29,    8, 28, 49,  4 }, {    -12,  -29,    8, 28, 49,  4 }, {    -13,  -30,    8, 29, 49,  4 }, {    -14,  -31,    8, 29, 49,  4 }, {    -15,  -32,    7, 29, 49,  4 },
    {    -16,  -32,    7, 29, 49,  4 }, {    -17,  -33,    7, 29, 49,  4 }, {    -18,  -34,    7, 29, 49,  4 }, {    -19,  -34,    7, 29, 49,  4 }, {    -20,  -35,    7, 29, 49,  4 },
    {    -21,  -36,    7, 29, 49,  4 }, {    -22,  -36,    6, 29, 49,  4 }, {    -23,  -37,    6, 29, 49,  4 }, {    -24,  -38,    6, 29, 49,  4 }, {    -25,  -38,    6, 29, 49,  4 },
    {    -26,  -39,    6, 30, 49,  4 }, {    -27,  -39,    6, 30, 49,  4 }, {    -28,  -40,    6, 30, 49,  4 }, {    -29,  -40,    5, 30, 49,  4 }, {    -30,  -41,    5, 30, 49,  4 },
    {    -31,  -41,    5, 30, 49,  4 }, {    -32,  -42,    5, 30, 49,  4 }, {    -33,  -42,    5, 30, 49,  4 }, {    -34,  -43,    5, 30, 49,  4 }, {    -35,  -43,    5, 30, 49,  4 },
    {    -36,  -43,    4, 30, 49,  4 }, {    -37,  -44,    4, 30, 49,  4 }, {    -38,  -44,    4, 30, 49,  4 }, {    -39,  -44,    4, 30, 49,  4 }, {    -40,  -45,    4, 31, 49,  4 },
    {    -41,  -45,    4, 31, 49,  4 }, {    -42,  -45,    4, 31, 49,  4 }, {    -43,  -45,    3, 31, 49,  4 }, {    -44,  -46,    3, 31, 49,  4 }, {    -45,  -46,    3, 31, 49,  4 },
    {    -46,  -46,    3, 31, 49,  4 }, {    -47,  -46,    3, 31, 49,  4 }, {    -48,  -46,    3, 31, 49,  4 }, {    -49,  -47,    3, 31, 49,  4 }, {    -50,  -47,    2, 31, 49,  4 },
    {    -51,  -47,    2, 31, 49,  4 }, {    -52,  -47,    2, 31, 49,  4 }, {    -53,  -47,    2, 31, 49,  4 }, {    -54,  -47,    2, 31, 49,  4 }, {    -55,  -48,    2, 31, 49,  4 },
    {    -56,  -48,    2,  0, 49,  4 }, {    -57,  -48,    1,  0, 49,  4 }, {    -58,  -48,    1,  0, 49,  4 }, {    -59,  -48,    1,  0, 49,  4 }, {    -60,  -48,    1,  0, 49,  4 },
    {    -61,  -48,    1,  0, 49,  4 }, {    -62,  -48,    1,  0, 49,  4 }, {    -63,  -48,    1,  0, 49,  4 }, {    -64,  -48,    0,  0, 49,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B4EF2, {
    {     31,   16,    0,  0, 48,  0 }, {     30,   16,    0,  0, 48,  0 }, {     29,   16,    0,  0, 48,  0 }, {     28,   16,    0,  0, 48,  0 }, {     27,   16,    0,  0, 48,  0 },
    {     26,   16,    0,  0, 48,  0 }, {     25,   16,    0,  0, 48,  0 }, {     24,   16,    1, 31, 48,  0 }, {     23,   15,    1, 31, 48,  0 }, {     22,   15,    1, 31, 48,  0 },
    {     21,   15,    1, 31, 48,  0 }, {     20,   15,    1, 31, 48,  0 }, {     19,   15,    1, 31, 48,  0 }, {     18,   15,    1, 31, 48,  0 }, {     17,   14,    2, 31, 48,  0 },
    {     16,   14,    2, 31, 48,  0 }, {     15,   14,    2, 31, 48,  0 }, {     14,   14,    2, 31, 48,  0 }, {     13,   14,    2, 31, 48,  0 }, {     12,   13,    2, 31, 48,  0 },
    {     11,   13,    2, 31, 48,  0 }, {     10,   13,    3, 30, 48,  0 }, {      9,   13,    3, 30, 48,  0 }, {      8,   12,    3, 30, 48,  0 }, {      7,   12,    3, 30, 48,  0 },
    {      6,   12,    3, 30, 48,  0 }, {      5,   11,    3, 30, 48,  0 }, {      4,   11,    3, 30, 48,  0 }, {      3,   11,    4, 30, 48,  0 }, {      2,   10,    4, 30, 48,  0 },
    {      1,   10,    4, 30, 48,  0 }, {      0,    9,    4, 30, 48,  0 }, {     -1,    9,    4, 30, 48,  0 }, {     -2,    8,    4, 30, 48,  0 }, {     -3,    8,    4, 30, 48,  0 },
    {     -4,    7,    5, 30, 48,  0 }, {     -5,    7,    5, 29, 48,  0 }, {     -6,    6,    5, 29, 48,  0 }, {     -7,    6,    5, 29, 48,  0 }, {     -8,    5,    5, 29, 48,  0 },
    {     -9,    4,    5, 29, 48,  0 }, {    -10,    4,    5, 29, 48,  0 }, {    -11,    3,    6, 29, 48,  0 }, {    -12,    2,    6, 29, 48,  0 }, {    -13,    2,    6, 29, 48,  0 },
    {    -14,    1,    6, 29, 48,  0 }, {    -15,    0,    6, 29, 48,  0 }, {    -16,    0,    6, 29, 48,  0 }, {    -17,   -1,    6, 29, 48,  0 }, {    -18,   -2,    7, 28, 48,  0 },
    {    -19,   -3,    7, 28, 48,  0 }, {    -20,   -3,    7, 28, 48,  0 }, {    -21,   -4,    7, 28, 48,  0 }, {    -22,   -5,    7, 28, 48,  0 }, {    -23,   -6,    7, 28, 48,  0 },
    {    -24,   -7,    7, 28, 48,  0 }, {    -25,   -7,    8, 28, 48,  0 }, {    -26,   -8,    8, 28, 48,  0 }, {    -27,   -9,    8, 28, 48,  0 }, {    -28,  -10,    8, 28, 48,  0 },
    {    -29,  -11,    8, 28, 48,  0 }, {    -29,  -12,    8, 28, 48,  0 }, {    -30,  -13,    8, 27, 48,  0 }, {    -31,  -14,    8, 27, 48,  0 }, {    -32,  -15,    9, 27, 48,  0 },
    {    -32,  -16,    9, 27, 48,  0 }, {    -33,  -17,    9, 27, 48,  0 }, {    -34,  -18,    9, 27, 48,  0 }, {    -34,  -19,    9, 27, 48,  0 }, {    -35,  -20,    9, 27, 48,  0 },
    {    -36,  -21,    9, 27, 48,  0 }, {    -36,  -22,   10, 27, 48,  0 }, {    -37,  -23,   10, 27, 48,  0 }, {    -38,  -24,   10, 27, 48,  0 }, {    -38,  -25,   10, 27, 48,  0 },
    {    -39,  -26,   10, 26, 48,  0 }, {    -39,  -27,   10, 26, 48,  0 }, {    -40,  -28,   10, 26, 48,  0 }, {    -40,  -29,   11, 26, 48,  0 }, {    -41,  -30,   11, 26, 48,  0 },
    {    -41,  -31,   11, 26, 48,  0 }, {    -42,  -32,   11, 26, 48,  0 }, {    -42,  -33,   11, 26, 48,  0 }, {    -43,  -34,   11, 26, 48,  0 }, {    -43,  -35,   11, 26, 48,  0 },
    {    -43,  -36,   12, 26, 48,  0 }, {    -44,  -37,   12, 26, 48,  0 }, {    -44,  -38,   12, 26, 48,  0 }, {    -44,  -39,   12, 26, 48,  0 }, {    -45,  -40,   12, 25, 48,  0 },
    {    -45,  -41,   12, 25, 48,  0 }, {    -45,  -42,   12, 25, 48,  0 }, {    -45,  -43,   13, 25, 48,  0 }, {    -46,  -44,   13, 25, 48,  0 }, {    -46,  -45,   13, 25, 48,  0 },
    {    -46,  -46,   13, 25, 48,  0 }, {    -46,  -47,   13, 25, 48,  0 }, {    -46,  -48,   13, 25, 48,  0 }, {    -47,  -49,   13, 25, 48,  0 }, {    -47,  -50,   14, 25, 48,  0 },
    {    -47,  -51,   14, 25, 48,  0 }, {    -47,  -52,   14, 25, 48,  0 }, {    -47,  -53,   14, 25, 48,  0 }, {    -47,  -54,   14, 25, 48,  0 }, {    -48,  -55,   14, 25, 48,  0 },
    {    -48,  -56,   14, 24, 48,  0 }, {    -48,  -57,   15, 24, 48,  0 }, {    -48,  -58,   15, 24, 48,  0 }, {    -48,  -59,   15, 24, 48,  0 }, {    -48,  -60,   15, 24, 48,  0 },
    {    -48,  -61,   15, 24, 48,  0 }, {    -48,  -62,   15, 24, 48,  0 }, {    -48,  -63,   15, 24, 48,  0 }, {    -48,  -64,   16, 24, 48,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B52F6, {
    {     16,    0,    0,  8, 48,  0 }, {     16,    1,    0,  8, 48,  0 }, {     16,    2,    0,  8, 48,  0 }, {     16,    3,    0,  8, 48,  0 }, {     16,    4,    0,  8, 48,  0 },
    {     16,    5,    0,  8, 48,  0 }, {     16,    6,    0,  8, 48,  0 }, {     16,    7,    0,  8, 48,  0 }, {     16,    8,    1,  7, 48,  0 }, {     15,    9,    1,  7, 48,  0 },
    {     15,   10,    1,  7, 48,  0 }, {     15,   11,    1,  7, 48,  0 }, {     15,   12,    1,  7, 48,  0 }, {     15,   13,    1,  7, 48,  0 }, {     15,   14,    1,  7, 48,  0 },
    {     14,   15,    2,  7, 48,  0 }, {     14,   16,    2,  7, 48,  0 }, {     14,   17,    2,  7, 48,  0 }, {     14,   18,    2,  7, 48,  0 }, {     14,   19,    2,  7, 48,  0 },
    {     13,   20,    2,  7, 48,  0 }, {     13,   21,    2,  7, 48,  0 }, {     13,   22,    3,  6, 48,  0 }, {     13,   23,    3,  6, 48,  0 }, {     12,   24,    3,  6, 48,  0 },
    {     12,   25,    3,  6, 48,  0 }, {     12,   26,    3,  6, 48,  0 }, {     11,   27,    3,  6, 48,  0 }, {     11,   28,    3,  6, 48,  0 }, {     11,   29,    4,  6, 48,  0 },
    {     10,   30,    4,  6, 48,  0 }, {     10,   31,    4,  6, 48,  0 }, {      9,   32,    4,  6, 48,  0 }, {      9,   33,    4,  6, 48,  0 }, {      8,   34,    4,  6, 48,  0 },
    {      8,   35,    4,  6, 48,  0 }, {      7,   36,    5,  6, 48,  0 }, {      7,   37,    5,  5, 48,  0 }, {      6,   38,    5,  5, 48,  0 }, {      6,   39,    5,  5, 48,  0 },
    {      5,   40,    5,  5, 48,  0 }, {      4,   41,    5,  5, 48,  0 }, {      4,   42,    5,  5, 48,  0 }, {      3,   43,    5,  5, 48,  0 }, {      2,   44,    6,  5, 48,  0 },
    {      2,   45,    6,  5, 48,  0 }, {      1,   46,    6,  5, 48,  0 }, {      0,   47,    6,  5, 48,  0 }, {      0,   48,    6,  5, 48,  0 }, {     -1,   49,    6,  5, 48,  0 },
    {     -2,   50,    6,  4, 48,  0 }, {     -3,   51,    7,  4, 48,  0 }, {     -3,   52,    7,  4, 48,  0 }, {     -4,   53,    7,  4, 48,  0 }, {     -5,   54,    7,  4, 48,  0 },
    {     -6,   55,    7,  4, 48,  0 }, {     -7,   56,    7,  4, 48,  0 }, {     -7,   57,    7,  4, 48,  0 }, {     -8,   58,    8,  4, 48,  0 }, {     -9,   59,    8,  4, 48,  0 },
    {    -10,   60,    8,  4, 48,  0 }, {    -11,   61,    8,  4, 48,  0 }, {    -12,   61,    8,  4, 48,  0 }, {    -13,   62,    8,  3, 48,  0 }, {    -14,   63,    8,  3, 48,  0 },
    {    -15,   64,    9,  3, 48,  0 }, {    -16,   64,    9,  3, 48,  0 }, {    -17,   65,    9,  3, 48,  0 }, {    -18,   66,    9,  3, 48,  0 }, {    -19,   66,    9,  3, 48,  0 },
    {    -20,   67,    9,  3, 48,  0 }, {    -21,   68,    9,  3, 48,  0 }, {    -22,   68,   10,  3, 48,  0 }, {    -23,   69,   10,  3, 48,  0 }, {    -24,   70,   10,  3, 48,  0 },
    {    -25,   70,   10,  3, 48,  0 }, {    -26,   71,   10,  2, 48,  0 }, {    -27,   71,   10,  2, 48,  0 }, {    -28,   72,   10,  2, 48,  0 }, {    -29,   72,   10,  2, 48,  0 },
    {    -30,   73,   11,  2, 48,  0 }, {    -31,   73,   11,  2, 48,  0 }, {    -32,   74,   11,  2, 48,  0 }, {    -33,   74,   11,  2, 48,  0 }, {    -34,   75,   11,  2, 48,  0 },
    {    -35,   75,   11,  2, 48,  0 }, {    -36,   75,   11,  2, 48,  0 }, {    -37,   76,   12,  2, 48,  0 }, {    -38,   76,   12,  2, 48,  0 }, {    -39,   76,   12,  2, 48,  0 },
    {    -40,   77,   12,  1, 48,  0 }, {    -41,   77,   12,  1, 48,  0 }, {    -42,   77,   12,  1, 48,  0 }, {    -43,   77,   12,  1, 48,  0 }, {    -44,   78,   13,  1, 48,  0 },
    {    -45,   78,   13,  1, 48,  0 }, {    -46,   78,   13,  1, 48,  0 }, {    -47,   78,   13,  1, 48,  0 }, {    -48,   78,   13,  1, 48,  0 }, {    -49,   79,   13,  1, 48,  0 },
    {    -50,   79,   13,  1, 48,  0 }, {    -51,   79,   14,  1, 48,  0 }, {    -52,   79,   14,  1, 48,  0 }, {    -53,   79,   14,  1, 48,  0 }, {    -54,   79,   14,  1, 48,  0 },
    {    -55,   80,   14,  1, 48,  0 }, {    -56,   80,   14,  0, 48,  0 }, {    -57,   80,   14,  0, 48,  0 }, {    -58,   80,   15,  0, 48,  0 }, {    -59,   80,   15,  0, 48,  0 },
    {    -60,   80,   15,  0, 48,  0 }, {    -61,   80,   15,  0, 48,  0 }, {    -62,   80,   15,  0, 48,  0 }, {    -63,   80,   15,  0, 48,  0 }, {    -64,   80,   15,  0, 48,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B5703, {
    {      0,   16,    0, 16, 48,  0 }, {      1,   16,    0, 16, 48,  0 }, {      2,   16,    0, 16, 48,  0 }, {      3,   16,    0, 16, 48,  0 }, {      4,   16,    0, 16, 48,  0 },
    {      5,   16,    0, 16, 48,  0 }, {      6,   16,    0, 16, 48,  0 }, {      7,   16,    0, 16, 48,  0 }, {      8,   16,    1, 15, 48,  0 }, {      9,   17,    1, 15, 48,  0 },
    {     10,   17,    1, 15, 48,  0 }, {     11,   17,    1, 15, 48,  0 }, {     12,   17,    1, 15, 48,  0 }, {     13,   17,    1, 15, 48,  0 }, {     14,   17,    1, 15, 48,  0 },
    {     15,   18,    2, 15, 48,  0 }, {     16,   18,    2, 15, 48,  0 }, {     17,   18,    2, 15, 48,  0 }, {     18,   18,    2, 15, 48,  0 }, {     19,   18,    2, 15, 48,  0 },
    {     20,   19,    2, 15, 48,  0 }, {     21,   19,    2, 15, 48,  0 }, {     22,   19,    3, 14, 48,  0 }, {     23,   19,    3, 14, 48,  0 }, {     24,   20,    3, 14, 48,  0 },
    {     25,   20,    3, 14, 48,  0 }, {     26,   20,    3, 14, 48,  0 }, {     27,   21,    3, 14, 48,  0 }, {     28,   21,    3, 14, 48,  0 }, {     29,   21,    4, 14, 48,  0 },
    {     30,   22,    4, 14, 48,  0 }, {     31,   22,    4, 14, 48,  0 }, {     32,   23,    4, 14, 48,  0 }, {     33,   23,    4, 14, 48,  0 }, {     34,   24,    4, 14, 48,  0 },
    {     35,   24,    4, 14, 48,  0 }, {     36,   25,    5, 14, 48,  0 }, {     37,   25,    5, 13, 48,  0 }, {     38,   26,    5, 13, 48,  0 }, {     39,   26,    5, 13, 48,  0 },
    {     40,   27,    5, 13, 48,  0 }, {     41,   28,    5, 13, 48,  0 }, {     42,   28,    5, 13, 48,  0 }, {     43,   29,    6, 13, 48,  0 }, {     44,   30,    6, 13, 48,  0 },
    {     45,   30,    6, 13, 48,  0 }, {     46,   31,    6, 13, 48,  0 }, {     47,   32,    6, 13, 48,  0 }, {     48,   32,    6, 13, 48,  0 }, {     49,   33,    6, 13, 48,  0 },
    {     50,   34,    7, 12, 48,  0 }, {     51,   35,    7, 12, 48,  0 }, {     52,   35,    7, 12, 48,  0 }, {     53,   36,    7, 12, 48,  0 }, {     54,   37,    7, 12, 48,  0 },
    {     55,   38,    7, 12, 48,  0 }, {     56,   39,    7, 12, 48,  0 }, {     57,   39,    8, 12, 48,  0 }, {     58,   40,    8, 12, 48,  0 }, {     59,   41,    8, 12, 48,  0 },
    {     60,   42,    8, 12, 48,  0 }, {     61,   43,    8, 12, 48,  0 }, {     61,   44,    8, 12, 48,  0 }, {     62,   45,    8, 11, 48,  0 }, {     63,   46,    8, 11, 48,  0 },
    {     64,   47,    9, 11, 48,  0 }, {     64,   48,    9, 11, 48,  0 }, {     65,   49,    9, 11, 48,  0 }, {     66,   50,    9, 11, 48,  0 }, {     66,   51,    9, 11, 48,  0 },
    {     67,   52,    9, 11, 48,  0 }, {     68,   53,    9, 11, 48,  0 }, {     68,   54,   10, 11, 48,  0 }, {     69,   55,   10, 11, 48,  0 }, {     70,   56,   10, 11, 48,  0 },
    {     70,   57,   10, 11, 48,  0 }, {     71,   58,   10, 10, 48,  0 }, {     71,   59,   10, 10, 48,  0 }, {     72,   60,   10, 10, 48,  0 }, {     72,   61,   11, 10, 48,  0 },
    {     73,   62,   11, 10, 48,  0 }, {     73,   63,   11, 10, 48,  0 }, {     74,   64,   11, 10, 48,  0 }, {     74,   65,   11, 10, 48,  0 }, {     75,   66,   11, 10, 48,  0 },
    {     75,   67,   11, 10, 48,  0 }, {     75,   68,   12, 10, 48,  0 }, {     76,   69,   12, 10, 48,  0 }, {     76,   70,   12, 10, 48,  0 }, {     76,   71,   12, 10, 48,  0 },
    {     77,   72,   12,  9, 48,  0 }, {     77,   73,   12,  9, 48,  0 }, {     77,   74,   12,  9, 48,  0 }, {     77,   75,   13,  9, 48,  0 }, {     78,   76,   13,  9, 48,  0 },
    {     78,   77,   13,  9, 48,  0 }, {     78,   78,   13,  9, 48,  0 }, {     78,   79,   13,  9, 48,  0 }, {     78,   80,   13,  9, 48,  0 }, {     79,   81,   13,  9, 48,  0 },
    {     79,   82,   14,  9, 48,  0 }, {     79,   83,   14,  9, 48,  0 }, {     79,   84,   14,  9, 48,  0 }, {     79,   85,   14,  9, 48,  0 }, {     79,   86,   14,  9, 48,  0 },
    {     80,   87,   14,  9, 48,  0 }, {     80,   88,   14,  8, 48,  0 }, {     80,   89,   15,  8, 48,  0 }, {     80,   90,   15,  8, 48,  0 }, {     80,   91,   15,  8, 48,  0 },
    {     80,   92,   15,  8, 48,  0 }, {     80,   93,   15,  8, 48,  0 }, {     80,   94,   15,  8, 48,  0 }, {     80,   95,   15,  8, 48,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B5B07, {
    {     16,   31,    0, 24, 48,  0 }, {     16,   30,    0, 24, 48,  0 }, {     16,   29,    0, 24, 48,  0 }, {     16,   28,    0, 24, 48,  0 }, {     16,   27,    0, 24, 48,  0 },
    {     16,   26,    0, 24, 48,  0 }, {     16,   25,    0, 24, 48,  0 }, {     16,   24,    1, 23, 48,  0 }, {     17,   23,    1, 23, 48,  0 }, {     17,   22,    1, 23, 48,  0 },
    {     17,   21,    1, 23, 48,  0 }, {     17,   20,    1, 23, 48,  0 }, {     17,   19,    1, 23, 48,  0 }, {     17,   18,    1, 23, 48,  0 }, {     18,   17,    2, 23, 48,  0 },
    {     18,   16,    2, 23, 48,  0 }, {     18,   15,    2, 23, 48,  0 }, {     18,   14,    2, 23, 48,  0 }, {     18,   13,    2, 23, 48,  0 }, {     19,   12,    2, 23, 48,  0 },
    {     19,   11,    2, 23, 48,  0 }, {     19,   10,    3, 22, 48,  0 }, {     19,    9,    3, 22, 48,  0 }, {     20,    8,    3, 22, 48,  0 }, {     20,    7,    3, 22, 48,  0 },
    {     20,    6,    3, 22, 48,  0 }, {     21,    5,    3, 22, 48,  0 }, {     21,    4,    3, 22, 48,  0 }, {     21,    3,    4, 22, 48,  0 }, {     22,    2,    4, 22, 48,  0 },
    {     22,    1,    4, 22, 48,  0 }, {     23,    0,    4, 22, 48,  0 }, {     23,   -1,    4, 22, 48,  0 }, {     24,   -2,    4, 22, 48,  0 }, {     24,   -3,    4, 22, 48,  0 },
    {     25,   -4,    5, 22, 48,  0 }, {     25,   -5,    5, 21, 48,  0 }, {     26,   -6,    5, 21, 48,  0 }, {     26,   -7,    5, 21, 48,  0 }, {     27,   -8,    5, 21, 48,  0 },
    {     28,   -9,    5, 21, 48,  0 }, {     28,  -10,    5, 21, 48,  0 }, {     29,  -11,    6, 21, 48,  0 }, {     30,  -12,    6, 21, 48,  0 }, {     30,  -13,    6, 21, 48,  0 },
    {     31,  -14,    6, 21, 48,  0 }, {     32,  -15,    6, 21, 48,  0 }, {     32,  -16,    6, 21, 48,  0 }, {     33,  -17,    6, 21, 48,  0 }, {     34,  -18,    7, 20, 48,  0 },
    {     35,  -19,    7, 20, 48,  0 }, {     35,  -20,    7, 20, 48,  0 }, {     36,  -21,    7, 20, 48,  0 }, {     37,  -22,    7, 20, 48,  0 }, {     38,  -23,    7, 20, 48,  0 },
    {     39,  -24,    7, 20, 48,  0 }, {     39,  -25,    8, 20, 48,  0 }, {     40,  -26,    8, 20, 48,  0 }, {     41,  -27,    8, 20, 48,  0 }, {     42,  -28,    8, 20, 48,  0 },
    {     43,  -29,    8, 20, 48,  0 }, {     44,  -29,    8, 20, 48,  0 }, {     45,  -30,    8, 19, 48,  0 }, {     46,  -31,    9, 19, 48,  0 }, {     47,  -32,    9, 19, 48,  0 },
    {     48,  -32,    9, 19, 48,  0 }, {     49,  -33,    9, 19, 48,  0 }, {     50,  -34,    9, 19, 48,  0 }, {     51,  -34,    9, 19, 48,  0 }, {     52,  -35,    9, 19, 48,  0 },
    {     53,  -36,   10, 19, 48,  0 }, {     54,  -36,   10, 19, 48,  0 }, {     55,  -37,   10, 19, 48,  0 }, {     56,  -38,   10, 19, 48,  0 }, {     57,  -38,   10, 19, 48,  0 },
    {     58,  -39,   10, 18, 48,  0 }, {     59,  -39,   10, 18, 48,  0 }, {     60,  -40,   11, 18, 48,  0 }, {     61,  -40,   11, 18, 48,  0 }, {     62,  -41,   11, 18, 48,  0 },
    {     63,  -41,   11, 18, 48,  0 }, {     64,  -42,   11, 18, 48,  0 }, {     65,  -42,   11, 18, 48,  0 }, {     66,  -43,   11, 18, 48,  0 }, {     67,  -43,   12, 18, 48,  0 },
    {     68,  -43,   12, 18, 48,  0 }, {     69,  -44,   12, 18, 48,  0 }, {     70,  -44,   12, 18, 48,  0 }, {     71,  -44,   12, 18, 48,  0 }, {     72,  -45,   12, 17, 48,  0 },
    {     73,  -45,   12, 17, 48,  0 }, {     74,  -45,   13, 17, 48,  0 }, {     75,  -45,   13, 17, 48,  0 }, {     76,  -46,   13, 17, 48,  0 }, {     77,  -46,   13, 17, 48,  0 },
    {     78,  -46,   13, 17, 48,  0 }, {     79,  -46,   13, 17, 48,  0 }, {     80,  -46,   13, 17, 48,  0 }, {     81,  -47,   14, 17, 48,  0 }, {     82,  -47,   14, 17, 48,  0 },
    {     83,  -47,   14, 17, 48,  0 }, {     84,  -47,   14, 17, 48,  0 }, {     85,  -47,   14, 17, 48,  0 }, {     86,  -47,   14, 17, 48,  0 }, {     87,  -48,   14, 17, 48,  0 },
    {     88,  -48,   15, 16, 48,  0 }, {     89,  -48,   15, 16, 48,  0 }, {     90,  -48,   15, 16, 48,  0 }, {     91,  -48,   15, 16, 48,  0 }, {     92,  -48,   15, 16, 48,  0 },
    {     93,  -48,   15, 16, 48,  0 }, {     94,  -48,   15, 16, 48,  0 }, {     95,  -48,   16, 16, 48,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B5F02, {
    {     31,   16,    0,  0, 48,  0 }, {     30,   16,    0,  0, 48,  0 }, {     29,   16,    0,  0, 48,  0 }, {     28,   16,    0,  0, 48,  0 }, {     27,   16,    0,  0, 48,  0 },
    {     26,   16,    0,  0, 48,  0 }, {     25,   16,    0,  0, 48,  0 }, {     24,   16,    1,  1, 48,  0 }, {     23,   17,    1,  1, 48,  0 }, {     22,   17,    1,  1, 48,  0 },
    {     21,   17,    1,  1, 48,  0 }, {     20,   17,    1,  1, 48,  0 }, {     19,   17,    1,  1, 48,  0 }, {     18,   17,    1,  1, 48,  0 }, {     17,   18,    2,  1, 48,  0 },
    {     16,   18,    2,  1, 48,  0 }, {     15,   18,    2,  1, 48,  0 }, {     14,   18,    2,  1, 48,  0 }, {     13,   18,    2,  1, 48,  0 }, {     12,   19,    2,  1, 48,  0 },
    {     11,   19,    2,  1, 48,  0 }, {     10,   19,    3,  2, 48,  0 }, {      9,   19,    3,  2, 48,  0 }, {      8,   20,    3,  2, 48,  0 }, {      7,   20,    3,  2, 48,  0 },
    {      6,   20,    3,  2, 48,  0 }, {      5,   21,    3,  2, 48,  0 }, {      4,   21,    3,  2, 48,  0 }, {      3,   21,    4,  2, 48,  0 }, {      2,   22,    4,  2, 48,  0 },
    {      1,   22,    4,  2, 48,  0 }, {      0,   23,    4,  2, 48,  0 }, {     -1,   23,    4,  2, 48,  0 }, {     -2,   24,    4,  2, 48,  0 }, {     -3,   24,    4,  2, 48,  0 },
    {     -4,   25,    5,  2, 48,  0 }, {     -5,   25,    5,  3, 48,  0 }, {     -6,   26,    5,  3, 48,  0 }, {     -7,   26,    5,  3, 48,  0 }, {     -8,   27,    5,  3, 48,  0 },
    {     -9,   28,    5,  3, 48,  0 }, {    -10,   28,    5,  3, 48,  0 }, {    -11,   29,    6,  3, 48,  0 }, {    -12,   30,    6,  3, 48,  0 }, {    -13,   30,    6,  3, 48,  0 },
    {    -14,   31,    6,  3, 48,  0 }, {    -15,   32,    6,  3, 48,  0 }, {    -16,   32,    6,  3, 48,  0 }, {    -17,   33,    6,  3, 48,  0 }, {    -18,   34,    7,  4, 48,  0 },
    {    -19,   35,    7,  4, 48,  0 }, {    -20,   35,    7,  4, 48,  0 }, {    -21,   36,    7,  4, 48,  0 }, {    -22,   37,    7,  4, 48,  0 }, {    -23,   38,    7,  4, 48,  0 },
    {    -24,   39,    7,  4, 48,  0 }, {    -25,   39,    8,  4, 48,  0 }, {    -26,   40,    8,  4, 48,  0 }, {    -27,   41,    8,  4, 48,  0 }, {    -28,   42,    8,  4, 48,  0 },
    {    -29,   43,    8,  4, 48,  0 }, {    -29,   44,    8,  4, 48,  0 }, {    -30,   45,    8,  5, 48,  0 }, {    -31,   46,    9,  5, 48,  0 }, {    -32,   47,    9,  5, 48,  0 },
    {    -32,   48,    9,  5, 48,  0 }, {    -33,   49,    9,  5, 48,  0 }, {    -34,   50,    9,  5, 48,  0 }, {    -34,   51,    9,  5, 48,  0 }, {    -35,   52,    9,  5, 48,  0 },
    {    -36,   53,   10,  5, 48,  0 }, {    -36,   54,   10,  5, 48,  0 }, {    -37,   55,   10,  5, 48,  0 }, {    -38,   56,   10,  5, 48,  0 }, {    -38,   57,   10,  5, 48,  0 },
    {    -39,   58,   10,  6, 48,  0 }, {    -39,   59,   10,  6, 48,  0 }, {    -40,   60,   11,  6, 48,  0 }, {    -40,   61,   11,  6, 48,  0 }, {    -41,   62,   11,  6, 48,  0 },
    {    -41,   63,   11,  6, 48,  0 }, {    -42,   64,   11,  6, 48,  0 }, {    -42,   65,   11,  6, 48,  0 }, {    -43,   66,   11,  6, 48,  0 }, {    -43,   67,   12,  6, 48,  0 },
    {    -43,   68,   12,  6, 48,  0 }, {    -44,   69,   12,  6, 48,  0 }, {    -44,   70,   12,  6, 48,  0 }, {    -44,   71,   12,  6, 48,  0 }, {    -45,   72,   12,  7, 48,  0 },
    {    -45,   73,   12,  7, 48,  0 }, {    -45,   74,   13,  7, 48,  0 }, {    -45,   75,   13,  7, 48,  0 }, {    -46,   76,   13,  7, 48,  0 }, {    -46,   77,   13,  7, 48,  0 },
    {    -46,   78,   13,  7, 48,  0 }, {    -46,   79,   13,  7, 48,  0 }, {    -46,   80,   13,  7, 48,  0 }, {    -47,   81,   14,  7, 48,  0 }, {    -47,   82,   14,  7, 48,  0 },
    {    -47,   83,   14,  7, 48,  0 }, {    -47,   84,   14,  7, 48,  0 }, {    -47,   85,   14,  7, 48,  0 }, {    -47,   86,   14,  7, 48,  0 }, {    -48,   87,   14,  7, 48,  0 },
    {    -48,   88,   15,  8, 48,  0 }, {    -48,   89,   15,  8, 48,  0 }, {    -48,   90,   15,  8, 48,  0 }, {    -48,   91,   15,  8, 48,  0 }, {    -48,   92,   15,  8, 48,  0 },
    {    -48,   93,   15,  8, 48,  0 }, {    -48,   94,   15,  8, 48,  0 }, {    -48,   95,   16,  8, 48,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B62FD, {
    {     16,    0,    0,  8, 48,  0 }, {     16,    1,    0,  8, 48,  0 }, {     16,    2,    0,  8, 48,  0 }, {     16,    3,    0,  8, 48,  0 }, {     16,    4,    0,  8, 48,  0 },
    {     16,    5,    0,  8, 48,  0 }, {     16,    6,    0,  8, 48,  0 }, {     16,    7,    0,  8, 48,  0 }, {     16,    8,    1,  9, 48,  0 }, {     17,    9,    1,  9, 48,  0 },
    {     17,   10,    1,  9, 48,  0 }, {     17,   11,    1,  9, 48,  0 }, {     17,   12,    1,  9, 48,  0 }, {     17,   13,    1,  9, 48,  0 }, {     17,   14,    1,  9, 48,  0 },
    {     18,   15,    2,  9, 48,  0 }, {     18,   16,    2,  9, 48,  0 }, {     18,   17,    2,  9, 48,  0 }, {     18,   18,    2,  9, 48,  0 }, {     18,   19,    2,  9, 48,  0 },
    {     19,   20,    2,  9, 48,  0 }, {     19,   21,    2,  9, 48,  0 }, {     19,   22,    3, 10, 48,  0 }, {     19,   23,    3, 10, 48,  0 }, {     20,   24,    3, 10, 48,  0 },
    {     20,   25,    3, 10, 48,  0 }, {     20,   26,    3, 10, 48,  0 }, {     21,   27,    3, 10, 48,  0 }, {     21,   28,    3, 10, 48,  0 }, {     21,   29,    4, 10, 48,  0 },
    {     22,   30,    4, 10, 48,  0 }, {     22,   31,    4, 10, 48,  0 }, {     23,   32,    4, 10, 48,  0 }, {     23,   33,    4, 10, 48,  0 }, {     24,   34,    4, 10, 48,  0 },
    {     24,   35,    4, 10, 48,  0 }, {     25,   36,    5, 10, 48,  0 }, {     25,   37,    5, 11, 48,  0 }, {     26,   38,    5, 11, 48,  0 }, {     26,   39,    5, 11, 48,  0 },
    {     27,   40,    5, 11, 48,  0 }, {     28,   41,    5, 11, 48,  0 }, {     28,   42,    5, 11, 48,  0 }, {     29,   43,    6, 11, 48,  0 }, {     30,   44,    6, 11, 48,  0 },
    {     30,   45,    6, 11, 48,  0 }, {     31,   46,    6, 11, 48,  0 }, {     32,   47,    6, 11, 48,  0 }, {     32,   48,    6, 11, 48,  0 }, {     33,   49,    6, 11, 48,  0 },
    {     34,   50,    7, 12, 48,  0 }, {     35,   51,    7, 12, 48,  0 }, {     35,   52,    7, 12, 48,  0 }, {     36,   53,    7, 12, 48,  0 }, {     37,   54,    7, 12, 48,  0 },
    {     38,   55,    7, 12, 48,  0 }, {     39,   56,    7, 12, 48,  0 }, {     39,   57,    8, 12, 48,  0 }, {     40,   58,    8, 12, 48,  0 }, {     41,   59,    8, 12, 48,  0 },
    {     42,   60,    8, 12, 48,  0 }, {     43,   61,    8, 12, 48,  0 }, {     44,   61,    8, 12, 48,  0 }, {     45,   62,    8, 13, 48,  0 }, {     46,   63,    8, 13, 48,  0 },
    {     47,   64,    9, 13, 48,  0 }, {     48,   64,    9, 13, 48,  0 }, {     49,   65,    9, 13, 48,  0 }, {     50,   66,    9, 13, 48,  0 }, {     51,   66,    9, 13, 48,  0 },
    {     52,   67,    9, 13, 48,  0 }, {     53,   68,    9, 13, 48,  0 }, {     54,   68,   10, 13, 48,  0 }, {     55,   69,   10, 13, 48,  0 }, {     56,   70,   10, 13, 48,  0 },
    {     57,   70,   10, 13, 48,  0 }, {     58,   71,   10, 14, 48,  0 }, {     59,   71,   10, 14, 48,  0 }, {     60,   72,   10, 14, 48,  0 }, {     61,   72,   11, 14, 48,  0 },
    {     62,   73,   11, 14, 48,  0 }, {     63,   73,   11, 14, 48,  0 }, {     64,   74,   11, 14, 48,  0 }, {     65,   74,   11, 14, 48,  0 }, {     66,   75,   11, 14, 48,  0 },
    {     67,   75,   11, 14, 48,  0 }, {     68,   75,   12, 14, 48,  0 }, {     69,   76,   12, 14, 48,  0 }, {     70,   76,   12, 14, 48,  0 }, {     71,   76,   12, 14, 48,  0 },
    {     72,   77,   12, 15, 48,  0 }, {     73,   77,   12, 15, 48,  0 }, {     74,   77,   12, 15, 48,  0 }, {     75,   77,   13, 15, 48,  0 }, {     76,   78,   13, 15, 48,  0 },
    {     77,   78,   13, 15, 48,  0 }, {     78,   78,   13, 15, 48,  0 }, {     79,   78,   13, 15, 48,  0 }, {     80,   78,   13, 15, 48,  0 }, {     81,   79,   13, 15, 48,  0 },
    {     82,   79,   14, 15, 48,  0 }, {     83,   79,   14, 15, 48,  0 }, {     84,   79,   14, 15, 48,  0 }, {     85,   79,   14, 15, 48,  0 }, {     86,   79,   14, 15, 48,  0 },
    {     87,   80,   14, 15, 48,  0 }, {     88,   80,   14, 16, 48,  0 }, {     89,   80,   15, 16, 48,  0 }, {     90,   80,   15, 16, 48,  0 }, {     91,   80,   15, 16, 48,  0 },
    {     92,   80,   15, 16, 48,  0 }, {     93,   80,   15, 16, 48,  0 }, {     94,   80,   15, 16, 48,  0 }, {     95,   80,   15, 16, 48,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B6701, {
    {      0,   16,    0, 16, 48,  0 }, {      1,   16,    0, 16, 48,  0 }, {      2,   16,    0, 16, 48,  0 }, {      3,   16,    0, 16, 48,  0 }, {      4,   16,    0, 16, 48,  0 },
    {      5,   16,    0, 16, 48,  0 }, {      6,   16,    0, 16, 48,  0 }, {      7,   16,    0, 16, 48,  0 }, {      8,   16,    1, 17, 48,  0 }, {      9,   15,    1, 17, 48,  0 },
    {     10,   15,    1, 17, 48,  0 }, {     11,   15,    1, 17, 48,  0 }, {     12,   15,    1, 17, 48,  0 }, {     13,   15,    1, 17, 48,  0 }, {     14,   15,    1, 17, 48,  0 },
    {     15,   14,    2, 17, 48,  0 }, {     16,   14,    2, 17, 48,  0 }, {     17,   14,    2, 17, 48,  0 }, {     18,   14,    2, 17, 48,  0 }, {     19,   14,    2, 17, 48,  0 },
    {     20,   13,    2, 17, 48,  0 }, {     21,   13,    2, 17, 48,  0 }, {     22,   13,    3, 18, 48,  0 }, {     23,   13,    3, 18, 48,  0 }, {     24,   12,    3, 18, 48,  0 },
    {     25,   12,    3, 18, 48,  0 }, {     26,   12,    3, 18, 48,  0 }, {     27,   11,    3, 18, 48,  0 }, {     28,   11,    3, 18, 48,  0 }, {     29,   11,    4, 18, 48,  0 },
    {     30,   10,    4, 18, 48,  0 }, {     31,   10,    4, 18, 48,  0 }, {     32,    9,    4, 18, 48,  0 }, {     33,    9,    4, 18, 48,  0 }, {     34,    8,    4, 18, 48,  0 },
    {     35,    8,    4, 18, 48,  0 }, {     36,    7,    5, 18, 48,  0 }, {     37,    7,    5, 19, 48,  0 }, {     38,    6,    5, 19, 48,  0 }, {     39,    6,    5, 19, 48,  0 },
    {     40,    5,    5, 19, 48,  0 }, {     41,    4,    5, 19, 48,  0 }, {     42,    4,    5, 19, 48,  0 }, {     43,    3,    5, 19, 48,  0 }, {     44,    2,    6, 19, 48,  0 },
    {     45,    2,    6, 19, 48,  0 }, {     46,    1,    6, 19, 48,  0 }, {     47,    0,    6, 19, 48,  0 }, {     48,    0,    6, 19, 48,  0 }, {     49,   -1,    6, 19, 48,  0 },
    {     50,   -2,    6, 20, 48,  0 }, {     51,   -3,    7, 20, 48,  0 }, {     52,   -3,    7, 20, 48,  0 }, {     53,   -4,    7, 20, 48,  0 }, {     54,   -5,    7, 20, 48,  0 },
    {     55,   -6,    7, 20, 48,  0 }, {     56,   -7,    7, 20, 48,  0 }, {     57,   -7,    7, 20, 48,  0 }, {     58,   -8,    8, 20, 48,  0 }, {     59,   -9,    8, 20, 48,  0 },
    {     60,  -10,    8, 20, 48,  0 }, {     61,  -11,    8, 20, 48,  0 }, {     61,  -12,    8, 20, 48,  0 }, {     62,  -13,    8, 21, 48,  0 }, {     63,  -14,    8, 21, 48,  0 },
    {     64,  -15,    9, 21, 48,  0 }, {     64,  -16,    9, 21, 48,  0 }, {     65,  -17,    9, 21, 48,  0 }, {     66,  -18,    9, 21, 48,  0 }, {     66,  -19,    9, 21, 48,  0 },
    {     67,  -20,    9, 21, 48,  0 }, {     68,  -21,    9, 21, 48,  0 }, {     68,  -22,   10, 21, 48,  0 }, {     69,  -23,   10, 21, 48,  0 }, {     70,  -24,   10, 21, 48,  0 },
    {     70,  -25,   10, 21, 48,  0 }, {     71,  -26,   10, 22, 48,  0 }, {     71,  -27,   10, 22, 48,  0 }, {     72,  -28,   10, 22, 48,  0 }, {     72,  -29,   10, 22, 48,  0 },
    {     73,  -30,   11, 22, 48,  0 }, {     73,  -31,   11, 22, 48,  0 }, {     74,  -32,   11, 22, 48,  0 }, {     74,  -33,   11, 22, 48,  0 }, {     75,  -34,   11, 22, 48,  0 },
    {     75,  -35,   11, 22, 48,  0 }, {     75,  -36,   11, 22, 48,  0 }, {     76,  -37,   12, 22, 48,  0 }, {     76,  -38,   12, 22, 48,  0 }, {     76,  -39,   12, 22, 48,  0 },
    {     77,  -40,   12, 23, 48,  0 }, {     77,  -41,   12, 23, 48,  0 }, {     77,  -42,   12, 23, 48,  0 }, {     77,  -43,   12, 23, 48,  0 }, {     78,  -44,   13, 23, 48,  0 },
    {     78,  -45,   13, 23, 48,  0 }, {     78,  -46,   13, 23, 48,  0 }, {     78,  -47,   13, 23, 48,  0 }, {     78,  -48,   13, 23, 48,  0 }, {     79,  -49,   13, 23, 48,  0 },
    {     79,  -50,   13, 23, 48,  0 }, {     79,  -51,   14, 23, 48,  0 }, {     79,  -52,   14, 23, 48,  0 }, {     79,  -53,   14, 23, 48,  0 }, {     79,  -54,   14, 23, 48,  0 },
    {     80,  -55,   14, 23, 48,  0 }, {     80,  -56,   14, 24, 48,  0 }, {     80,  -57,   14, 24, 48,  0 }, {     80,  -58,   15, 24, 48,  0 }, {     80,  -59,   15, 24, 48,  0 },
    {     80,  -60,   15, 24, 48,  0 }, {     80,  -61,   15, 24, 48,  0 }, {     80,  -62,   15, 24, 48,  0 }, {     80,  -63,   15, 24, 48,  0 }, {     80,  -64,   15, 24, 48,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B6B0E, {
    {     16,   31,    0, 24, 48,  0 }, {     16,   30,    0, 24, 48,  0 }, {     16,   29,    0, 24, 48,  0 }, {     16,   28,    0, 24, 48,  0 }, {     16,   27,    0, 24, 48,  0 },
    {     16,   26,    0, 24, 48,  0 }, {     16,   25,    0, 24, 48,  0 }, {     16,   24,    1, 25, 48,  0 }, {     15,   23,    1, 25, 48,  0 }, {     15,   22,    1, 25, 48,  0 },
    {     15,   21,    1, 25, 48,  0 }, {     15,   20,    1, 25, 48,  0 }, {     15,   19,    1, 25, 48,  0 }, {     15,   18,    1, 25, 48,  0 }, {     14,   17,    2, 25, 48,  0 },
    {     14,   16,    2, 25, 48,  0 }, {     14,   15,    2, 25, 48,  0 }, {     14,   14,    2, 25, 48,  0 }, {     14,   13,    2, 25, 48,  0 }, {     13,   12,    2, 25, 48,  0 },
    {     13,   11,    2, 25, 48,  0 }, {     13,   10,    3, 26, 48,  0 }, {     13,    9,    3, 26, 48,  0 }, {     12,    8,    3, 26, 48,  0 }, {     12,    7,    3, 26, 48,  0 },
    {     12,    6,    3, 26, 48,  0 }, {     11,    5,    3, 26, 48,  0 }, {     11,    4,    3, 26, 48,  0 }, {     11,    3,    4, 26, 48,  0 }, {     10,    2,    4, 26, 48,  0 },
    {     10,    1,    4, 26, 48,  0 }, {      9,    0,    4, 26, 48,  0 }, {      9,   -1,    4, 26, 48,  0 }, {      8,   -2,    4, 26, 48,  0 }, {      8,   -3,    4, 26, 48,  0 },
    {      7,   -4,    5, 26, 48,  0 }, {      7,   -5,    5, 27, 48,  0 }, {      6,   -6,    5, 27, 48,  0 }, {      6,   -7,    5, 27, 48,  0 }, {      5,   -8,    5, 27, 48,  0 },
    {      4,   -9,    5, 27, 48,  0 }, {      4,  -10,    5, 27, 48,  0 }, {      3,  -11,    6, 27, 48,  0 }, {      2,  -12,    6, 27, 48,  0 }, {      2,  -13,    6, 27, 48,  0 },
    {      1,  -14,    6, 27, 48,  0 }, {      0,  -15,    6, 27, 48,  0 }, {      0,  -16,    6, 27, 48,  0 }, {     -1,  -17,    6, 27, 48,  0 }, {     -2,  -18,    7, 28, 48,  0 },
    {     -3,  -19,    7, 28, 48,  0 }, {     -3,  -20,    7, 28, 48,  0 }, {     -4,  -21,    7, 28, 48,  0 }, {     -5,  -22,    7, 28, 48,  0 }, {     -6,  -23,    7, 28, 48,  0 },
    {     -7,  -24,    7, 28, 48,  0 }, {     -7,  -25,    8, 28, 48,  0 }, {     -8,  -26,    8, 28, 48,  0 }, {     -9,  -27,    8, 28, 48,  0 }, {    -10,  -28,    8, 28, 48,  0 },
    {    -11,  -29,    8, 28, 48,  0 }, {    -12,  -29,    8, 28, 48,  0 }, {    -13,  -30,    8, 29, 48,  0 }, {    -14,  -31,    8, 29, 48,  0 }, {    -15,  -32,    9, 29, 48,  0 },
    {    -16,  -32,    9, 29, 48,  0 }, {    -17,  -33,    9, 29, 48,  0 }, {    -18,  -34,    9, 29, 48,  0 }, {    -19,  -34,    9, 29, 48,  0 }, {    -20,  -35,    9, 29, 48,  0 },
    {    -21,  -36,    9, 29, 48,  0 }, {    -22,  -36,   10, 29, 48,  0 }, {    -23,  -37,   10, 29, 48,  0 }, {    -24,  -38,   10, 29, 48,  0 }, {    -25,  -38,   10, 29, 48,  0 },
    {    -26,  -39,   10, 30, 48,  0 }, {    -27,  -39,   10, 30, 48,  0 }, {    -28,  -40,   10, 30, 48,  0 }, {    -29,  -40,   11, 30, 48,  0 }, {    -30,  -41,   11, 30, 48,  0 },
    {    -31,  -41,   11, 30, 48,  0 }, {    -32,  -42,   11, 30, 48,  0 }, {    -33,  -42,   11, 30, 48,  0 }, {    -34,  -43,   11, 30, 48,  0 }, {    -35,  -43,   11, 30, 48,  0 },
    {    -36,  -43,   12, 30, 48,  0 }, {    -37,  -44,   12, 30, 48,  0 }, {    -38,  -44,   12, 30, 48,  0 }, {    -39,  -44,   12, 30, 48,  0 }, {    -40,  -45,   12, 31, 48,  0 },
    {    -41,  -45,   12, 31, 48,  0 }, {    -42,  -45,   12, 31, 48,  0 }, {    -43,  -45,   13, 31, 48,  0 }, {    -44,  -46,   13, 31, 48,  0 }, {    -45,  -46,   13, 31, 48,  0 },
    {    -46,  -46,   13, 31, 48,  0 }, {    -47,  -46,   13, 31, 48,  0 }, {    -48,  -46,   13, 31, 48,  0 }, {    -49,  -47,   13, 31, 48,  0 }, {    -50,  -47,   14, 31, 48,  0 },
    {    -51,  -47,   14, 31, 48,  0 }, {    -52,  -47,   14, 31, 48,  0 }, {    -53,  -47,   14, 31, 48,  0 }, {    -54,  -47,   14, 31, 48,  0 }, {    -55,  -48,   14, 31, 48,  0 },
    {    -56,  -48,   14,  0, 48,  0 }, {    -57,  -48,   15,  0, 48,  0 }, {    -58,  -48,   15,  0, 48,  0 }, {    -59,  -48,   15,  0, 48,  0 }, {    -60,  -48,   15,  0, 48,  0 },
    {    -61,  -48,   15,  0, 48,  0 }, {    -62,  -48,   15,  0, 48,  0 }, {    -63,  -48,   15,  0, 48,  0 }, {    -64,  -48,   16,  0, 48,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B6F12, {
    {     31,   16,   16,  0, 49,  0 }, {     30,   16,   16,  0, 49,  0 }, {     29,   16,   16,  0, 49,  0 }, {     28,   16,   16,  0, 49,  0 }, {     27,   16,   16,  0, 49,  0 },
    {     26,   16,   16,  0, 49,  0 }, {     25,   16,   16,  0, 49,  0 }, {     24,   16,   15, 31, 49,  0 }, {     23,   15,   15, 31, 49,  0 }, {     22,   15,   15, 31, 49,  0 },
    {     21,   15,   15, 31, 49,  0 }, {     20,   15,   15, 31, 49,  0 }, {     19,   15,   15, 31, 49,  0 }, {     18,   15,   15, 31, 49,  0 }, {     17,   14,   14, 31, 49,  0 },
    {     16,   14,   14, 31, 49,  0 }, {     15,   14,   14, 31, 49,  0 }, {     14,   14,   14, 31, 49,  0 }, {     13,   14,   14, 31, 49,  0 }, {     12,   13,   14, 31, 49,  0 },
    {     11,   13,   14, 31, 49,  0 }, {     10,   13,   13, 30, 49,  0 }, {      9,   13,   13, 30, 49,  0 }, {      8,   12,   13, 30, 49,  0 }, {      7,   12,   13, 30, 49,  0 },
    {      6,   12,   13, 30, 49,  0 }, {      5,   11,   13, 30, 49,  0 }, {      4,   11,   13, 30, 49,  0 }, {      3,   11,   12, 30, 49,  0 }, {      2,   10,   12, 30, 49,  0 },
    {      1,   10,   12, 30, 49,  0 }, {      0,    9,   12, 30, 49,  0 }, {     -1,    9,   12, 30, 49,  0 }, {     -2,    8,   12, 30, 49,  0 }, {     -3,    8,   12, 30, 49,  0 },
    {     -4,    7,   11, 30, 49,  0 }, {     -5,    7,   11, 29, 49,  0 }, {     -6,    6,   11, 29, 49,  0 }, {     -7,    6,   11, 29, 49,  0 }, {     -8,    5,   11, 29, 49,  0 },
    {     -9,    4,   11, 29, 49,  0 }, {    -10,    4,   11, 29, 49,  0 }, {    -11,    3,   10, 29, 49,  0 }, {    -12,    2,   10, 29, 49,  0 }, {    -13,    2,   10, 29, 49,  0 },
    {    -14,    1,   10, 29, 49,  0 }, {    -15,    0,   10, 29, 49,  0 }, {    -16,    0,   10, 29, 49,  0 }, {    -17,   -1,   10, 29, 49,  0 }, {    -18,   -2,    9, 28, 49,  0 },
    {    -19,   -3,    9, 28, 49,  0 }, {    -20,   -3,    9, 28, 49,  0 }, {    -21,   -4,    9, 28, 49,  0 }, {    -22,   -5,    9, 28, 49,  0 }, {    -23,   -6,    9, 28, 49,  0 },
    {    -24,   -7,    9, 28, 49,  0 }, {    -25,   -7,    8, 28, 49,  0 }, {    -26,   -8,    8, 28, 49,  0 }, {    -27,   -9,    8, 28, 49,  0 }, {    -28,  -10,    8, 28, 49,  0 },
    {    -29,  -11,    8, 28, 49,  0 }, {    -29,  -12,    8, 28, 49,  0 }, {    -30,  -13,    8, 27, 49,  0 }, {    -31,  -14,    8, 27, 49,  0 }, {    -32,  -15,    7, 27, 49,  0 },
    {    -32,  -16,    7, 27, 49,  0 }, {    -33,  -17,    7, 27, 49,  0 }, {    -34,  -18,    7, 27, 49,  0 }, {    -34,  -19,    7, 27, 49,  0 }, {    -35,  -20,    7, 27, 49,  0 },
    {    -36,  -21,    7, 27, 49,  0 }, {    -36,  -22,    6, 27, 49,  0 }, {    -37,  -23,    6, 27, 49,  0 }, {    -38,  -24,    6, 27, 49,  0 }, {    -38,  -25,    6, 27, 49,  0 },
    {    -39,  -26,    6, 26, 49,  0 }, {    -39,  -27,    6, 26, 49,  0 }, {    -40,  -28,    6, 26, 49,  0 }, {    -40,  -29,    5, 26, 49,  0 }, {    -41,  -30,    5, 26, 49,  0 },
    {    -41,  -31,    5, 26, 49,  0 }, {    -42,  -32,    5, 26, 49,  0 }, {    -42,  -33,    5, 26, 49,  0 }, {    -43,  -34,    5, 26, 49,  0 }, {    -43,  -35,    5, 26, 49,  0 },
    {    -43,  -36,    4, 26, 49,  0 }, {    -44,  -37,    4, 26, 49,  0 }, {    -44,  -38,    4, 26, 49,  0 }, {    -44,  -39,    4, 26, 49,  0 }, {    -45,  -40,    4, 25, 49,  0 },
    {    -45,  -41,    4, 25, 49,  0 }, {    -45,  -42,    4, 25, 49,  0 }, {    -45,  -43,    3, 25, 49,  0 }, {    -46,  -44,    3, 25, 49,  0 }, {    -46,  -45,    3, 25, 49,  0 },
    {    -46,  -46,    3, 25, 49,  0 }, {    -46,  -47,    3, 25, 49,  0 }, {    -46,  -48,    3, 25, 49,  0 }, {    -47,  -49,    3, 25, 49,  0 }, {    -47,  -50,    2, 25, 49,  0 },
    {    -47,  -51,    2, 25, 49,  0 }, {    -47,  -52,    2, 25, 49,  0 }, {    -47,  -53,    2, 25, 49,  0 }, {    -47,  -54,    2, 25, 49,  0 }, {    -48,  -55,    2, 25, 49,  0 },
    {    -48,  -56,    2, 24, 49,  0 }, {    -48,  -57,    1, 24, 49,  0 }, {    -48,  -58,    1, 24, 49,  0 }, {    -48,  -59,    1, 24, 49,  0 }, {    -48,  -60,    1, 24, 49,  0 },
    {    -48,  -61,    1, 24, 49,  0 }, {    -48,  -62,    1, 24, 49,  0 }, {    -48,  -63,    1, 24, 49,  0 }, {    -48,  -64,    0, 24, 49,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B7316, {
    {     16,    0,   16,  8, 49,  0 }, {     16,    1,   16,  8, 49,  0 }, {     16,    2,   16,  8, 49,  0 }, {     16,    3,   16,  8, 49,  0 }, {     16,    4,   16,  8, 49,  0 },
    {     16,    5,   16,  8, 49,  0 }, {     16,    6,   16,  8, 49,  0 }, {     16,    7,   16,  8, 49,  0 }, {     16,    8,   15,  7, 49,  0 }, {     15,    9,   15,  7, 49,  0 },
    {     15,   10,   15,  7, 49,  0 }, {     15,   11,   15,  7, 49,  0 }, {     15,   12,   15,  7, 49,  0 }, {     15,   13,   15,  7, 49,  0 }, {     15,   14,   15,  7, 49,  0 },
    {     14,   15,   14,  7, 49,  0 }, {     14,   16,   14,  7, 49,  0 }, {     14,   17,   14,  7, 49,  0 }, {     14,   18,   14,  7, 49,  0 }, {     14,   19,   14,  7, 49,  0 },
    {     13,   20,   14,  7, 49,  0 }, {     13,   21,   14,  7, 49,  0 }, {     13,   22,   13,  6, 49,  0 }, {     13,   23,   13,  6, 49,  0 }, {     12,   24,   13,  6, 49,  0 },
    {     12,   25,   13,  6, 49,  0 }, {     12,   26,   13,  6, 49,  0 }, {     11,   27,   13,  6, 49,  0 }, {     11,   28,   13,  6, 49,  0 }, {     11,   29,   12,  6, 49,  0 },
    {     10,   30,   12,  6, 49,  0 }, {     10,   31,   12,  6, 49,  0 }, {      9,   32,   12,  6, 49,  0 }, {      9,   33,   12,  6, 49,  0 }, {      8,   34,   12,  6, 49,  0 },
    {      8,   35,   12,  6, 49,  0 }, {      7,   36,   11,  6, 49,  0 }, {      7,   37,   11,  5, 49,  0 }, {      6,   38,   11,  5, 49,  0 }, {      6,   39,   11,  5, 49,  0 },
    {      5,   40,   11,  5, 49,  0 }, {      4,   41,   11,  5, 49,  0 }, {      4,   42,   11,  5, 49,  0 }, {      3,   43,   11,  5, 49,  0 }, {      2,   44,   10,  5, 49,  0 },
    {      2,   45,   10,  5, 49,  0 }, {      1,   46,   10,  5, 49,  0 }, {      0,   47,   10,  5, 49,  0 }, {      0,   48,   10,  5, 49,  0 }, {     -1,   49,   10,  5, 49,  0 },
    {     -2,   50,   10,  4, 49,  0 }, {     -3,   51,    9,  4, 49,  0 }, {     -3,   52,    9,  4, 49,  0 }, {     -4,   53,    9,  4, 49,  0 }, {     -5,   54,    9,  4, 49,  0 },
    {     -6,   55,    9,  4, 49,  0 }, {     -7,   56,    9,  4, 49,  0 }, {     -7,   57,    9,  4, 49,  0 }, {     -8,   58,    8,  4, 49,  0 }, {     -9,   59,    8,  4, 49,  0 },
    {    -10,   60,    8,  4, 49,  0 }, {    -11,   61,    8,  4, 49,  0 }, {    -12,   61,    8,  4, 49,  0 }, {    -13,   62,    8,  3, 49,  0 }, {    -14,   63,    8,  3, 49,  0 },
    {    -15,   64,    7,  3, 49,  0 }, {    -16,   64,    7,  3, 49,  0 }, {    -17,   65,    7,  3, 49,  0 }, {    -18,   66,    7,  3, 49,  0 }, {    -19,   66,    7,  3, 49,  0 },
    {    -20,   67,    7,  3, 49,  0 }, {    -21,   68,    7,  3, 49,  0 }, {    -22,   68,    6,  3, 49,  0 }, {    -23,   69,    6,  3, 49,  0 }, {    -24,   70,    6,  3, 49,  0 },
    {    -25,   70,    6,  3, 49,  0 }, {    -26,   71,    6,  2, 49,  0 }, {    -27,   71,    6,  2, 49,  0 }, {    -28,   72,    6,  2, 49,  0 }, {    -29,   72,    6,  2, 49,  0 },
    {    -30,   73,    5,  2, 49,  0 }, {    -31,   73,    5,  2, 49,  0 }, {    -32,   74,    5,  2, 49,  0 }, {    -33,   74,    5,  2, 49,  0 }, {    -34,   75,    5,  2, 49,  0 },
    {    -35,   75,    5,  2, 49,  0 }, {    -36,   75,    5,  2, 49,  0 }, {    -37,   76,    4,  2, 49,  0 }, {    -38,   76,    4,  2, 49,  0 }, {    -39,   76,    4,  2, 49,  0 },
    {    -40,   77,    4,  1, 49,  0 }, {    -41,   77,    4,  1, 49,  0 }, {    -42,   77,    4,  1, 49,  0 }, {    -43,   77,    4,  1, 49,  0 }, {    -44,   78,    3,  1, 49,  0 },
    {    -45,   78,    3,  1, 49,  0 }, {    -46,   78,    3,  1, 49,  0 }, {    -47,   78,    3,  1, 49,  0 }, {    -48,   78,    3,  1, 49,  0 }, {    -49,   79,    3,  1, 49,  0 },
    {    -50,   79,    3,  1, 49,  0 }, {    -51,   79,    2,  1, 49,  0 }, {    -52,   79,    2,  1, 49,  0 }, {    -53,   79,    2,  1, 49,  0 }, {    -54,   79,    2,  1, 49,  0 },
    {    -55,   80,    2,  1, 49,  0 }, {    -56,   80,    2,  0, 49,  0 }, {    -57,   80,    2,  0, 49,  0 }, {    -58,   80,    1,  0, 49,  0 }, {    -59,   80,    1,  0, 49,  0 },
    {    -60,   80,    1,  0, 49,  0 }, {    -61,   80,    1,  0, 49,  0 }, {    -62,   80,    1,  0, 49,  0 }, {    -63,   80,    1,  0, 49,  0 }, {    -64,   80,    1,  0, 49,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B7723, {
    {      0,   16,   16, 16, 49,  0 }, {      1,   16,   16, 16, 49,  0 }, {      2,   16,   16, 16, 49,  0 }, {      3,   16,   16, 16, 49,  0 }, {      4,   16,   16, 16, 49,  0 },
    {      5,   16,   16, 16, 49,  0 }, {      6,   16,   16, 16, 49,  0 }, {      7,   16,   16, 16, 49,  0 }, {      8,   16,   15, 15, 49,  0 }, {      9,   17,   15, 15, 49,  0 },
    {     10,   17,   15, 15, 49,  0 }, {     11,   17,   15, 15, 49,  0 }, {     12,   17,   15, 15, 49,  0 }, {     13,   17,   15, 15, 49,  0 }, {     14,   17,   15, 15, 49,  0 },
    {     15,   18,   14, 15, 49,  0 }, {     16,   18,   14, 15, 49,  0 }, {     17,   18,   14, 15, 49,  0 }, {     18,   18,   14, 15, 49,  0 }, {     19,   18,   14, 15, 49,  0 },
    {     20,   19,   14, 15, 49,  0 }, {     21,   19,   14, 15, 49,  0 }, {     22,   19,   13, 14, 49,  0 }, {     23,   19,   13, 14, 49,  0 }, {     24,   20,   13, 14, 49,  0 },
    {     25,   20,   13, 14, 49,  0 }, {     26,   20,   13, 14, 49,  0 }, {     27,   21,   13, 14, 49,  0 }, {     28,   21,   13, 14, 49,  0 }, {     29,   21,   12, 14, 49,  0 },
    {     30,   22,   12, 14, 49,  0 }, {     31,   22,   12, 14, 49,  0 }, {     32,   23,   12, 14, 49,  0 }, {     33,   23,   12, 14, 49,  0 }, {     34,   24,   12, 14, 49,  0 },
    {     35,   24,   12, 14, 49,  0 }, {     36,   25,   11, 14, 49,  0 }, {     37,   25,   11, 13, 49,  0 }, {     38,   26,   11, 13, 49,  0 }, {     39,   26,   11, 13, 49,  0 },
    {     40,   27,   11, 13, 49,  0 }, {     41,   28,   11, 13, 49,  0 }, {     42,   28,   11, 13, 49,  0 }, {     43,   29,   10, 13, 49,  0 }, {     44,   30,   10, 13, 49,  0 },
    {     45,   30,   10, 13, 49,  0 }, {     46,   31,   10, 13, 49,  0 }, {     47,   32,   10, 13, 49,  0 }, {     48,   32,   10, 13, 49,  0 }, {     49,   33,   10, 13, 49,  0 },
    {     50,   34,    9, 12, 49,  0 }, {     51,   35,    9, 12, 49,  0 }, {     52,   35,    9, 12, 49,  0 }, {     53,   36,    9, 12, 49,  0 }, {     54,   37,    9, 12, 49,  0 },
    {     55,   38,    9, 12, 49,  0 }, {     56,   39,    9, 12, 49,  0 }, {     57,   39,    8, 12, 49,  0 }, {     58,   40,    8, 12, 49,  0 }, {     59,   41,    8, 12, 49,  0 },
    {     60,   42,    8, 12, 49,  0 }, {     61,   43,    8, 12, 49,  0 }, {     61,   44,    8, 12, 49,  0 }, {     62,   45,    8, 11, 49,  0 }, {     63,   46,    8, 11, 49,  0 },
    {     64,   47,    7, 11, 49,  0 }, {     64,   48,    7, 11, 49,  0 }, {     65,   49,    7, 11, 49,  0 }, {     66,   50,    7, 11, 49,  0 }, {     66,   51,    7, 11, 49,  0 },
    {     67,   52,    7, 11, 49,  0 }, {     68,   53,    7, 11, 49,  0 }, {     68,   54,    6, 11, 49,  0 }, {     69,   55,    6, 11, 49,  0 }, {     70,   56,    6, 11, 49,  0 },
    {     70,   57,    6, 11, 49,  0 }, {     71,   58,    6, 10, 49,  0 }, {     71,   59,    6, 10, 49,  0 }, {     72,   60,    6, 10, 49,  0 }, {     72,   61,    5, 10, 49,  0 },
    {     73,   62,    5, 10, 49,  0 }, {     73,   63,    5, 10, 49,  0 }, {     74,   64,    5, 10, 49,  0 }, {     74,   65,    5, 10, 49,  0 }, {     75,   66,    5, 10, 49,  0 },
    {     75,   67,    5, 10, 49,  0 }, {     75,   68,    4, 10, 49,  0 }, {     76,   69,    4, 10, 49,  0 }, {     76,   70,    4, 10, 49,  0 }, {     76,   71,    4, 10, 49,  0 },
    {     77,   72,    4,  9, 49,  0 }, {     77,   73,    4,  9, 49,  0 }, {     77,   74,    4,  9, 49,  0 }, {     77,   75,    3,  9, 49,  0 }, {     78,   76,    3,  9, 49,  0 },
    {     78,   77,    3,  9, 49,  0 }, {     78,   78,    3,  9, 49,  0 }, {     78,   79,    3,  9, 49,  0 }, {     78,   80,    3,  9, 49,  0 }, {     79,   81,    3,  9, 49,  0 },
    {     79,   82,    2,  9, 49,  0 }, {     79,   83,    2,  9, 49,  0 }, {     79,   84,    2,  9, 49,  0 }, {     79,   85,    2,  9, 49,  0 }, {     79,   86,    2,  9, 49,  0 },
    {     80,   87,    2,  9, 49,  0 }, {     80,   88,    2,  8, 49,  0 }, {     80,   89,    1,  8, 49,  0 }, {     80,   90,    1,  8, 49,  0 }, {     80,   91,    1,  8, 49,  0 },
    {     80,   92,    1,  8, 49,  0 }, {     80,   93,    1,  8, 49,  0 }, {     80,   94,    1,  8, 49,  0 }, {     80,   95,    1,  8, 49,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B7B27, {
    {     16,   31,   16, 24, 49,  0 }, {     16,   30,   16, 24, 49,  0 }, {     16,   29,   16, 24, 49,  0 }, {     16,   28,   16, 24, 49,  0 }, {     16,   27,   16, 24, 49,  0 },
    {     16,   26,   16, 24, 49,  0 }, {     16,   25,   16, 24, 49,  0 }, {     16,   24,   15, 23, 49,  0 }, {     17,   23,   15, 23, 49,  0 }, {     17,   22,   15, 23, 49,  0 },
    {     17,   21,   15, 23, 49,  0 }, {     17,   20,   15, 23, 49,  0 }, {     17,   19,   15, 23, 49,  0 }, {     17,   18,   15, 23, 49,  0 }, {     18,   17,   14, 23, 49,  0 },
    {     18,   16,   14, 23, 49,  0 }, {     18,   15,   14, 23, 49,  0 }, {     18,   14,   14, 23, 49,  0 }, {     18,   13,   14, 23, 49,  0 }, {     19,   12,   14, 23, 49,  0 },
    {     19,   11,   14, 23, 49,  0 }, {     19,   10,   13, 22, 49,  0 }, {     19,    9,   13, 22, 49,  0 }, {     20,    8,   13, 22, 49,  0 }, {     20,    7,   13, 22, 49,  0 },
    {     20,    6,   13, 22, 49,  0 }, {     21,    5,   13, 22, 49,  0 }, {     21,    4,   13, 22, 49,  0 }, {     21,    3,   12, 22, 49,  0 }, {     22,    2,   12, 22, 49,  0 },
    {     22,    1,   12, 22, 49,  0 }, {     23,    0,   12, 22, 49,  0 }, {     23,   -1,   12, 22, 49,  0 }, {     24,   -2,   12, 22, 49,  0 }, {     24,   -3,   12, 22, 49,  0 },
    {     25,   -4,   11, 22, 49,  0 }, {     25,   -5,   11, 21, 49,  0 }, {     26,   -6,   11, 21, 49,  0 }, {     26,   -7,   11, 21, 49,  0 }, {     27,   -8,   11, 21, 49,  0 },
    {     28,   -9,   11, 21, 49,  0 }, {     28,  -10,   11, 21, 49,  0 }, {     29,  -11,   10, 21, 49,  0 }, {     30,  -12,   10, 21, 49,  0 }, {     30,  -13,   10, 21, 49,  0 },
    {     31,  -14,   10, 21, 49,  0 }, {     32,  -15,   10, 21, 49,  0 }, {     32,  -16,   10, 21, 49,  0 }, {     33,  -17,   10, 21, 49,  0 }, {     34,  -18,    9, 20, 49,  0 },
    {     35,  -19,    9, 20, 49,  0 }, {     35,  -20,    9, 20, 49,  0 }, {     36,  -21,    9, 20, 49,  0 }, {     37,  -22,    9, 20, 49,  0 }, {     38,  -23,    9, 20, 49,  0 },
    {     39,  -24,    9, 20, 49,  0 }, {     39,  -25,    8, 20, 49,  0 }, {     40,  -26,    8, 20, 49,  0 }, {     41,  -27,    8, 20, 49,  0 }, {     42,  -28,    8, 20, 49,  0 },
    {     43,  -29,    8, 20, 49,  0 }, {     44,  -29,    8, 20, 49,  0 }, {     45,  -30,    8, 19, 49,  0 }, {     46,  -31,    7, 19, 49,  0 }, {     47,  -32,    7, 19, 49,  0 },
    {     48,  -32,    7, 19, 49,  0 }, {     49,  -33,    7, 19, 49,  0 }, {     50,  -34,    7, 19, 49,  0 }, {     51,  -34,    7, 19, 49,  0 }, {     52,  -35,    7, 19, 49,  0 },
    {     53,  -36,    6, 19, 49,  0 }, {     54,  -36,    6, 19, 49,  0 }, {     55,  -37,    6, 19, 49,  0 }, {     56,  -38,    6, 19, 49,  0 }, {     57,  -38,    6, 19, 49,  0 },
    {     58,  -39,    6, 18, 49,  0 }, {     59,  -39,    6, 18, 49,  0 }, {     60,  -40,    5, 18, 49,  0 }, {     61,  -40,    5, 18, 49,  0 }, {     62,  -41,    5, 18, 49,  0 },
    {     63,  -41,    5, 18, 49,  0 }, {     64,  -42,    5, 18, 49,  0 }, {     65,  -42,    5, 18, 49,  0 }, {     66,  -43,    5, 18, 49,  0 }, {     67,  -43,    4, 18, 49,  0 },
    {     68,  -43,    4, 18, 49,  0 }, {     69,  -44,    4, 18, 49,  0 }, {     70,  -44,    4, 18, 49,  0 }, {     71,  -44,    4, 18, 49,  0 }, {     72,  -45,    4, 17, 49,  0 },
    {     73,  -45,    4, 17, 49,  0 }, {     74,  -45,    3, 17, 49,  0 }, {     75,  -45,    3, 17, 49,  0 }, {     76,  -46,    3, 17, 49,  0 }, {     77,  -46,    3, 17, 49,  0 },
    {     78,  -46,    3, 17, 49,  0 }, {     79,  -46,    3, 17, 49,  0 }, {     80,  -46,    3, 17, 49,  0 }, {     81,  -47,    2, 17, 49,  0 }, {     82,  -47,    2, 17, 49,  0 },
    {     83,  -47,    2, 17, 49,  0 }, {     84,  -47,    2, 17, 49,  0 }, {     85,  -47,    2, 17, 49,  0 }, {     86,  -47,    2, 17, 49,  0 }, {     87,  -48,    2, 17, 49,  0 },
    {     88,  -48,    1, 16, 49,  0 }, {     89,  -48,    1, 16, 49,  0 }, {     90,  -48,    1, 16, 49,  0 }, {     91,  -48,    1, 16, 49,  0 }, {     92,  -48,    1, 16, 49,  0 },
    {     93,  -48,    1, 16, 49,  0 }, {     94,  -48,    1, 16, 49,  0 }, {     95,  -48,    0, 16, 49,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B7F22, {
    {     31,   16,   16,  0, 49,  0 }, {     30,   16,   16,  0, 49,  0 }, {     29,   16,   16,  0, 49,  0 }, {     28,   16,   16,  0, 49,  0 }, {     27,   16,   16,  0, 49,  0 },
    {     26,   16,   16,  0, 49,  0 }, {     25,   16,   16,  0, 49,  0 }, {     24,   16,   15,  1, 49,  0 }, {     23,   17,   15,  1, 49,  0 }, {     22,   17,   15,  1, 49,  0 },
    {     21,   17,   15,  1, 49,  0 }, {     20,   17,   15,  1, 49,  0 }, {     19,   17,   15,  1, 49,  0 }, {     18,   17,   15,  1, 49,  0 }, {     17,   18,   14,  1, 49,  0 },
    {     16,   18,   14,  1, 49,  0 }, {     15,   18,   14,  1, 49,  0 }, {     14,   18,   14,  1, 49,  0 }, {     13,   18,   14,  1, 49,  0 }, {     12,   19,   14,  1, 49,  0 },
    {     11,   19,   14,  1, 49,  0 }, {     10,   19,   13,  2, 49,  0 }, {      9,   19,   13,  2, 49,  0 }, {      8,   20,   13,  2, 49,  0 }, {      7,   20,   13,  2, 49,  0 },
    {      6,   20,   13,  2, 49,  0 }, {      5,   21,   13,  2, 49,  0 }, {      4,   21,   13,  2, 49,  0 }, {      3,   21,   12,  2, 49,  0 }, {      2,   22,   12,  2, 49,  0 },
    {      1,   22,   12,  2, 49,  0 }, {      0,   23,   12,  2, 49,  0 }, {     -1,   23,   12,  2, 49,  0 }, {     -2,   24,   12,  2, 49,  0 }, {     -3,   24,   12,  2, 49,  0 },
    {     -4,   25,   11,  2, 49,  0 }, {     -5,   25,   11,  3, 49,  0 }, {     -6,   26,   11,  3, 49,  0 }, {     -7,   26,   11,  3, 49,  0 }, {     -8,   27,   11,  3, 49,  0 },
    {     -9,   28,   11,  3, 49,  0 }, {    -10,   28,   11,  3, 49,  0 }, {    -11,   29,   10,  3, 49,  0 }, {    -12,   30,   10,  3, 49,  0 }, {    -13,   30,   10,  3, 49,  0 },
    {    -14,   31,   10,  3, 49,  0 }, {    -15,   32,   10,  3, 49,  0 }, {    -16,   32,   10,  3, 49,  0 }, {    -17,   33,   10,  3, 49,  0 }, {    -18,   34,    9,  4, 49,  0 },
    {    -19,   35,    9,  4, 49,  0 }, {    -20,   35,    9,  4, 49,  0 }, {    -21,   36,    9,  4, 49,  0 }, {    -22,   37,    9,  4, 49,  0 }, {    -23,   38,    9,  4, 49,  0 },
    {    -24,   39,    9,  4, 49,  0 }, {    -25,   39,    8,  4, 49,  0 }, {    -26,   40,    8,  4, 49,  0 }, {    -27,   41,    8,  4, 49,  0 }, {    -28,   42,    8,  4, 49,  0 },
    {    -29,   43,    8,  4, 49,  0 }, {    -29,   44,    8,  4, 49,  0 }, {    -30,   45,    8,  5, 49,  0 }, {    -31,   46,    7,  5, 49,  0 }, {    -32,   47,    7,  5, 49,  0 },
    {    -32,   48,    7,  5, 49,  0 }, {    -33,   49,    7,  5, 49,  0 }, {    -34,   50,    7,  5, 49,  0 }, {    -34,   51,    7,  5, 49,  0 }, {    -35,   52,    7,  5, 49,  0 },
    {    -36,   53,    6,  5, 49,  0 }, {    -36,   54,    6,  5, 49,  0 }, {    -37,   55,    6,  5, 49,  0 }, {    -38,   56,    6,  5, 49,  0 }, {    -38,   57,    6,  5, 49,  0 },
    {    -39,   58,    6,  6, 49,  0 }, {    -39,   59,    6,  6, 49,  0 }, {    -40,   60,    5,  6, 49,  0 }, {    -40,   61,    5,  6, 49,  0 }, {    -41,   62,    5,  6, 49,  0 },
    {    -41,   63,    5,  6, 49,  0 }, {    -42,   64,    5,  6, 49,  0 }, {    -42,   65,    5,  6, 49,  0 }, {    -43,   66,    5,  6, 49,  0 }, {    -43,   67,    4,  6, 49,  0 },
    {    -43,   68,    4,  6, 49,  0 }, {    -44,   69,    4,  6, 49,  0 }, {    -44,   70,    4,  6, 49,  0 }, {    -44,   71,    4,  6, 49,  0 }, {    -45,   72,    4,  7, 49,  0 },
    {    -45,   73,    4,  7, 49,  0 }, {    -45,   74,    3,  7, 49,  0 }, {    -45,   75,    3,  7, 49,  0 }, {    -46,   76,    3,  7, 49,  0 }, {    -46,   77,    3,  7, 49,  0 },
    {    -46,   78,    3,  7, 49,  0 }, {    -46,   79,    3,  7, 49,  0 }, {    -46,   80,    3,  7, 49,  0 }, {    -47,   81,    2,  7, 49,  0 }, {    -47,   82,    2,  7, 49,  0 },
    {    -47,   83,    2,  7, 49,  0 }, {    -47,   84,    2,  7, 49,  0 }, {    -47,   85,    2,  7, 49,  0 }, {    -47,   86,    2,  7, 49,  0 }, {    -48,   87,    2,  7, 49,  0 },
    {    -48,   88,    1,  8, 49,  0 }, {    -48,   89,    1,  8, 49,  0 }, {    -48,   90,    1,  8, 49,  0 }, {    -48,   91,    1,  8, 49,  0 }, {    -48,   92,    1,  8, 49,  0 },
    {    -48,   93,    1,  8, 49,  0 }, {    -48,   94,    1,  8, 49,  0 }, {    -48,   95,    0,  8, 49,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B831D, {
    {     16,    0,   16,  8, 49,  0 }, {     16,    1,   16,  8, 49,  0 }, {     16,    2,   16,  8, 49,  0 }, {     16,    3,   16,  8, 49,  0 }, {     16,    4,   16,  8, 49,  0 },
    {     16,    5,   16,  8, 49,  0 }, {     16,    6,   16,  8, 49,  0 }, {     16,    7,   16,  8, 49,  0 }, {     16,    8,   15,  9, 49,  0 }, {     17,    9,   15,  9, 49,  0 },
    {     17,   10,   15,  9, 49,  0 }, {     17,   11,   15,  9, 49,  0 }, {     17,   12,   15,  9, 49,  0 }, {     17,   13,   15,  9, 49,  0 }, {     17,   14,   15,  9, 49,  0 },
    {     18,   15,   14,  9, 49,  0 }, {     18,   16,   14,  9, 49,  0 }, {     18,   17,   14,  9, 49,  0 }, {     18,   18,   14,  9, 49,  0 }, {     18,   19,   14,  9, 49,  0 },
    {     19,   20,   14,  9, 49,  0 }, {     19,   21,   14,  9, 49,  0 }, {     19,   22,   13, 10, 49,  0 }, {     19,   23,   13, 10, 49,  0 }, {     20,   24,   13, 10, 49,  0 },
    {     20,   25,   13, 10, 49,  0 }, {     20,   26,   13, 10, 49,  0 }, {     21,   27,   13, 10, 49,  0 }, {     21,   28,   13, 10, 49,  0 }, {     21,   29,   12, 10, 49,  0 },
    {     22,   30,   12, 10, 49,  0 }, {     22,   31,   12, 10, 49,  0 }, {     23,   32,   12, 10, 49,  0 }, {     23,   33,   12, 10, 49,  0 }, {     24,   34,   12, 10, 49,  0 },
    {     24,   35,   12, 10, 49,  0 }, {     25,   36,   11, 10, 49,  0 }, {     25,   37,   11, 11, 49,  0 }, {     26,   38,   11, 11, 49,  0 }, {     26,   39,   11, 11, 49,  0 },
    {     27,   40,   11, 11, 49,  0 }, {     28,   41,   11, 11, 49,  0 }, {     28,   42,   11, 11, 49,  0 }, {     29,   43,   10, 11, 49,  0 }, {     30,   44,   10, 11, 49,  0 },
    {     30,   45,   10, 11, 49,  0 }, {     31,   46,   10, 11, 49,  0 }, {     32,   47,   10, 11, 49,  0 }, {     32,   48,   10, 11, 49,  0 }, {     33,   49,   10, 11, 49,  0 },
    {     34,   50,    9, 12, 49,  0 }, {     35,   51,    9, 12, 49,  0 }, {     35,   52,    9, 12, 49,  0 }, {     36,   53,    9, 12, 49,  0 }, {     37,   54,    9, 12, 49,  0 },
    {     38,   55,    9, 12, 49,  0 }, {     39,   56,    9, 12, 49,  0 }, {     39,   57,    8, 12, 49,  0 }, {     40,   58,    8, 12, 49,  0 }, {     41,   59,    8, 12, 49,  0 },
    {     42,   60,    8, 12, 49,  0 }, {     43,   61,    8, 12, 49,  0 }, {     44,   61,    8, 12, 49,  0 }, {     45,   62,    8, 13, 49,  0 }, {     46,   63,    8, 13, 49,  0 },
    {     47,   64,    7, 13, 49,  0 }, {     48,   64,    7, 13, 49,  0 }, {     49,   65,    7, 13, 49,  0 }, {     50,   66,    7, 13, 49,  0 }, {     51,   66,    7, 13, 49,  0 },
    {     52,   67,    7, 13, 49,  0 }, {     53,   68,    7, 13, 49,  0 }, {     54,   68,    6, 13, 49,  0 }, {     55,   69,    6, 13, 49,  0 }, {     56,   70,    6, 13, 49,  0 },
    {     57,   70,    6, 13, 49,  0 }, {     58,   71,    6, 14, 49,  0 }, {     59,   71,    6, 14, 49,  0 }, {     60,   72,    6, 14, 49,  0 }, {     61,   72,    5, 14, 49,  0 },
    {     62,   73,    5, 14, 49,  0 }, {     63,   73,    5, 14, 49,  0 }, {     64,   74,    5, 14, 49,  0 }, {     65,   74,    5, 14, 49,  0 }, {     66,   75,    5, 14, 49,  0 },
    {     67,   75,    5, 14, 49,  0 }, {     68,   75,    4, 14, 49,  0 }, {     69,   76,    4, 14, 49,  0 }, {     70,   76,    4, 14, 49,  0 }, {     71,   76,    4, 14, 49,  0 },
    {     72,   77,    4, 15, 49,  0 }, {     73,   77,    4, 15, 49,  0 }, {     74,   77,    4, 15, 49,  0 }, {     75,   77,    3, 15, 49,  0 }, {     76,   78,    3, 15, 49,  0 },
    {     77,   78,    3, 15, 49,  0 }, {     78,   78,    3, 15, 49,  0 }, {     79,   78,    3, 15, 49,  0 }, {     80,   78,    3, 15, 49,  0 }, {     81,   79,    3, 15, 49,  0 },
    {     82,   79,    2, 15, 49,  0 }, {     83,   79,    2, 15, 49,  0 }, {     84,   79,    2, 15, 49,  0 }, {     85,   79,    2, 15, 49,  0 }, {     86,   79,    2, 15, 49,  0 },
    {     87,   80,    2, 15, 49,  0 }, {     88,   80,    2, 16, 49,  0 }, {     89,   80,    1, 16, 49,  0 }, {     90,   80,    1, 16, 49,  0 }, {     91,   80,    1, 16, 49,  0 },
    {     92,   80,    1, 16, 49,  0 }, {     93,   80,    1, 16, 49,  0 }, {     94,   80,    1, 16, 49,  0 }, {     95,   80,    1, 16, 49,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B8721, {
    {      0,   16,   16, 16, 49,  0 }, {      1,   16,   16, 16, 49,  0 }, {      2,   16,   16, 16, 49,  0 }, {      3,   16,   16, 16, 49,  0 }, {      4,   16,   16, 16, 49,  0 },
    {      5,   16,   16, 16, 49,  0 }, {      6,   16,   16, 16, 49,  0 }, {      7,   16,   16, 16, 49,  0 }, {      8,   16,   15, 17, 49,  0 }, {      9,   15,   15, 17, 49,  0 },
    {     10,   15,   15, 17, 49,  0 }, {     11,   15,   15, 17, 49,  0 }, {     12,   15,   15, 17, 49,  0 }, {     13,   15,   15, 17, 49,  0 }, {     14,   15,   15, 17, 49,  0 },
    {     15,   14,   14, 17, 49,  0 }, {     16,   14,   14, 17, 49,  0 }, {     17,   14,   14, 17, 49,  0 }, {     18,   14,   14, 17, 49,  0 }, {     19,   14,   14, 17, 49,  0 },
    {     20,   13,   14, 17, 49,  0 }, {     21,   13,   14, 17, 49,  0 }, {     22,   13,   13, 18, 49,  0 }, {     23,   13,   13, 18, 49,  0 }, {     24,   12,   13, 18, 49,  0 },
    {     25,   12,   13, 18, 49,  0 }, {     26,   12,   13, 18, 49,  0 }, {     27,   11,   13, 18, 49,  0 }, {     28,   11,   13, 18, 49,  0 }, {     29,   11,   12, 18, 49,  0 },
    {     30,   10,   12, 18, 49,  0 }, {     31,   10,   12, 18, 49,  0 }, {     32,    9,   12, 18, 49,  0 }, {     33,    9,   12, 18, 49,  0 }, {     34,    8,   12, 18, 49,  0 },
    {     35,    8,   12, 18, 49,  0 }, {     36,    7,   11, 18, 49,  0 }, {     37,    7,   11, 19, 49,  0 }, {     38,    6,   11, 19, 49,  0 }, {     39,    6,   11, 19, 49,  0 },
    {     40,    5,   11, 19, 49,  0 }, {     41,    4,   11, 19, 49,  0 }, {     42,    4,   11, 19, 49,  0 }, {     43,    3,   11, 19, 49,  0 }, {     44,    2,   10, 19, 49,  0 },
    {     45,    2,   10, 19, 49,  0 }, {     46,    1,   10, 19, 49,  0 }, {     47,    0,   10, 19, 49,  0 }, {     48,    0,   10, 19, 49,  0 }, {     49,   -1,   10, 19, 49,  0 },
    {     50,   -2,   10, 20, 49,  0 }, {     51,   -3,    9, 20, 49,  0 }, {     52,   -3,    9, 20, 49,  0 }, {     53,   -4,    9, 20, 49,  0 }, {     54,   -5,    9, 20, 49,  0 },
    {     55,   -6,    9, 20, 49,  0 }, {     56,   -7,    9, 20, 49,  0 }, {     57,   -7,    9, 20, 49,  0 }, {     58,   -8,    8, 20, 49,  0 }, {     59,   -9,    8, 20, 49,  0 },
    {     60,  -10,    8, 20, 49,  0 }, {     61,  -11,    8, 20, 49,  0 }, {     61,  -12,    8, 20, 49,  0 }, {     62,  -13,    8, 21, 49,  0 }, {     63,  -14,    8, 21, 49,  0 },
    {     64,  -15,    7, 21, 49,  0 }, {     64,  -16,    7, 21, 49,  0 }, {     65,  -17,    7, 21, 49,  0 }, {     66,  -18,    7, 21, 49,  0 }, {     66,  -19,    7, 21, 49,  0 },
    {     67,  -20,    7, 21, 49,  0 }, {     68,  -21,    7, 21, 49,  0 }, {     68,  -22,    6, 21, 49,  0 }, {     69,  -23,    6, 21, 49,  0 }, {     70,  -24,    6, 21, 49,  0 },
    {     70,  -25,    6, 21, 49,  0 }, {     71,  -26,    6, 22, 49,  0 }, {     71,  -27,    6, 22, 49,  0 }, {     72,  -28,    6, 22, 49,  0 }, {     72,  -29,    6, 22, 49,  0 },
    {     73,  -30,    5, 22, 49,  0 }, {     73,  -31,    5, 22, 49,  0 }, {     74,  -32,    5, 22, 49,  0 }, {     74,  -33,    5, 22, 49,  0 }, {     75,  -34,    5, 22, 49,  0 },
    {     75,  -35,    5, 22, 49,  0 }, {     75,  -36,    5, 22, 49,  0 }, {     76,  -37,    4, 22, 49,  0 }, {     76,  -38,    4, 22, 49,  0 }, {     76,  -39,    4, 22, 49,  0 },
    {     77,  -40,    4, 23, 49,  0 }, {     77,  -41,    4, 23, 49,  0 }, {     77,  -42,    4, 23, 49,  0 }, {     77,  -43,    4, 23, 49,  0 }, {     78,  -44,    3, 23, 49,  0 },
    {     78,  -45,    3, 23, 49,  0 }, {     78,  -46,    3, 23, 49,  0 }, {     78,  -47,    3, 23, 49,  0 }, {     78,  -48,    3, 23, 49,  0 }, {     79,  -49,    3, 23, 49,  0 },
    {     79,  -50,    3, 23, 49,  0 }, {     79,  -51,    2, 23, 49,  0 }, {     79,  -52,    2, 23, 49,  0 }, {     79,  -53,    2, 23, 49,  0 }, {     79,  -54,    2, 23, 49,  0 },
    {     80,  -55,    2, 23, 49,  0 }, {     80,  -56,    2, 24, 49,  0 }, {     80,  -57,    2, 24, 49,  0 }, {     80,  -58,    1, 24, 49,  0 }, {     80,  -59,    1, 24, 49,  0 },
    {     80,  -60,    1, 24, 49,  0 }, {     80,  -61,    1, 24, 49,  0 }, {     80,  -62,    1, 24, 49,  0 }, {     80,  -63,    1, 24, 49,  0 }, {     80,  -64,    1, 24, 49,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8B8B2E, {
    {     16,   31,   16, 24, 49,  0 }, {     16,   30,   16, 24, 49,  0 }, {     16,   29,   16, 24, 49,  0 }, {     16,   28,   16, 24, 49,  0 }, {     16,   27,   16, 24, 49,  0 },
    {     16,   26,   16, 24, 49,  0 }, {     16,   25,   16, 24, 49,  0 }, {     16,   24,   15, 25, 49,  0 }, {     15,   23,   15, 25, 49,  0 }, {     15,   22,   15, 25, 49,  0 },
    {     15,   21,   15, 25, 49,  0 }, {     15,   20,   15, 25, 49,  0 }, {     15,   19,   15, 25, 49,  0 }, {     15,   18,   15, 25, 49,  0 }, {     14,   17,   14, 25, 49,  0 },
    {     14,   16,   14, 25, 49,  0 }, {     14,   15,   14, 25, 49,  0 }, {     14,   14,   14, 25, 49,  0 }, {     14,   13,   14, 25, 49,  0 }, {     13,   12,   14, 25, 49,  0 },
    {     13,   11,   14, 25, 49,  0 }, {     13,   10,   13, 26, 49,  0 }, {     13,    9,   13, 26, 49,  0 }, {     12,    8,   13, 26, 49,  0 }, {     12,    7,   13, 26, 49,  0 },
    {     12,    6,   13, 26, 49,  0 }, {     11,    5,   13, 26, 49,  0 }, {     11,    4,   13, 26, 49,  0 }, {     11,    3,   12, 26, 49,  0 }, {     10,    2,   12, 26, 49,  0 },
    {     10,    1,   12, 26, 49,  0 }, {      9,    0,   12, 26, 49,  0 }, {      9,   -1,   12, 26, 49,  0 }, {      8,   -2,   12, 26, 49,  0 }, {      8,   -3,   12, 26, 49,  0 },
    {      7,   -4,   11, 26, 49,  0 }, {      7,   -5,   11, 27, 49,  0 }, {      6,   -6,   11, 27, 49,  0 }, {      6,   -7,   11, 27, 49,  0 }, {      5,   -8,   11, 27, 49,  0 },
    {      4,   -9,   11, 27, 49,  0 }, {      4,  -10,   11, 27, 49,  0 }, {      3,  -11,   10, 27, 49,  0 }, {      2,  -12,   10, 27, 49,  0 }, {      2,  -13,   10, 27, 49,  0 },
    {      1,  -14,   10, 27, 49,  0 }, {      0,  -15,   10, 27, 49,  0 }, {      0,  -16,   10, 27, 49,  0 }, {     -1,  -17,   10, 27, 49,  0 }, {     -2,  -18,    9, 28, 49,  0 },
    {     -3,  -19,    9, 28, 49,  0 }, {     -3,  -20,    9, 28, 49,  0 }, {     -4,  -21,    9, 28, 49,  0 }, {     -5,  -22,    9, 28, 49,  0 }, {     -6,  -23,    9, 28, 49,  0 },
    {     -7,  -24,    9, 28, 49,  0 }, {     -7,  -25,    8, 28, 49,  0 }, {     -8,  -26,    8, 28, 49,  0 }, {     -9,  -27,    8, 28, 49,  0 }, {    -10,  -28,    8, 28, 49,  0 },
    {    -11,  -29,    8, 28, 49,  0 }, {    -12,  -29,    8, 28, 49,  0 }, {    -13,  -30,    8, 29, 49,  0 }, {    -14,  -31,    8, 29, 49,  0 }, {    -15,  -32,    7, 29, 49,  0 },
    {    -16,  -32,    7, 29, 49,  0 }, {    -17,  -33,    7, 29, 49,  0 }, {    -18,  -34,    7, 29, 49,  0 }, {    -19,  -34,    7, 29, 49,  0 }, {    -20,  -35,    7, 29, 49,  0 },
    {    -21,  -36,    7, 29, 49,  0 }, {    -22,  -36,    6, 29, 49,  0 }, {    -23,  -37,    6, 29, 49,  0 }, {    -24,  -38,    6, 29, 49,  0 }, {    -25,  -38,    6, 29, 49,  0 },
    {    -26,  -39,    6, 30, 49,  0 }, {    -27,  -39,    6, 30, 49,  0 }, {    -28,  -40,    6, 30, 49,  0 }, {    -29,  -40,    5, 30, 49,  0 }, {    -30,  -41,    5, 30, 49,  0 },
    {    -31,  -41,    5, 30, 49,  0 }, {    -32,  -42,    5, 30, 49,  0 }, {    -33,  -42,    5, 30, 49,  0 }, {    -34,  -43,    5, 30, 49,  0 }, {    -35,  -43,    5, 30, 49,  0 },
    {    -36,  -43,    4, 30, 49,  0 }, {    -37,  -44,    4, 30, 49,  0 }, {    -38,  -44,    4, 30, 49,  0 }, {    -39,  -44,    4, 30, 49,  0 }, {    -40,  -45,    4, 31, 49,  0 },
    {    -41,  -45,    4, 31, 49,  0 }, {    -42,  -45,    4, 31, 49,  0 }, {    -43,  -45,    3, 31, 49,  0 }, {    -44,  -46,    3, 31, 49,  0 }, {    -45,  -46,    3, 31, 49,  0 },
    {    -46,  -46,    3, 31, 49,  0 }, {    -47,  -46,    3, 31, 49,  0 }, {    -48,  -46,    3, 31, 49,  0 }, {    -49,  -47,    3, 31, 49,  0 }, {    -50,  -47,    2, 31, 49,  0 },
    {    -51,  -47,    2, 31, 49,  0 }, {    -52,  -47,    2, 31, 49,  0 }, {    -53,  -47,    2, 31, 49,  0 }, {    -54,  -47,    2, 31, 49,  0 }, {    -55,  -48,    2, 31, 49,  0 },
    {    -56,  -48,    2,  0, 49,  0 }, {    -57,  -48,    1,  0, 49,  0 }, {    -58,  -48,    1,  0, 49,  0 }, {    -59,  -48,    1,  0, 49,  0 }, {    -60,  -48,    1,  0, 49,  0 },
    {    -61,  -48,    1,  0, 49,  0 }, {    -62,  -48,    1,  0, 49,  0 }, {    -63,  -48,    1,  0, 49,  0 }, {    -64,  -48,    0,  0, 49,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_968C6E, {
    {     31,   16,    0,  0,  2,  2 }, {     30,   16,    1,  0,  2,  2 }, {     29,   16,    1,  0,  2,  2 }, {     28,   16,    2,  0,  2,  2 }, {     27,   16,    2,  0,  2,  2 },
    {     26,   16,    3,  0,  2,  2 }, {     25,   16,    3,  0,  2,  2 }, {     24,   16,    4,  0,  2,  2 }, {     23,   16,    4,  0,  2,  2 }, {     22,   16,    5,  0,  2,  2 },
    {     21,   16,    5,  0,  2,  2 }, {     20,   16,    6,  0,  2,  2 }, {     19,   16,    6,  0,  2,  2 }, {     18,   16,    7,  0,  2,  2 }, {     17,   16,    7,  0,  2,  2 },
    {     16,   16,    8,  0,  2,  2 }, {     15,   16,    8,  0,  2,  2 }, {     14,   16,    9,  0,  2,  2 }, {     13,   16,    9,  0,  2,  2 }, {     12,   16,   10,  0,  2,  2 },
    {     11,   16,   10,  0,  2,  2 }, {     10,   16,   11,  0,  2,  2 }, {      9,   16,   11,  0,  2,  2 }, {      8,   16,   12,  0,  2,  2 }, {      7,   16,   12,  0,  2,  2 },
    {      6,   16,   13,  0,  2,  2 }, {      5,   16,   13,  0,  2,  2 }, {      4,   16,   14,  0,  2,  2 }, {      3,   16,   14,  0,  2,  2 }, {      2,   16,   15,  0,  2,  2 },
    {      1,   16,   15,  0,  2,  2 }, {      0,   16,   16,  0,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_968D90, {
    {     16,    0,    0,  8,  2,  2 }, {     16,    1,    0,  8,  2,  2 }, {     16,    2,    1,  8,  2,  2 }, {     16,    3,    1,  8,  2,  2 }, {     16,    4,    2,  8,  2,  2 },
    {     16,    5,    2,  8,  2,  2 }, {     16,    6,    3,  8,  2,  2 }, {     16,    7,    3,  8,  2,  2 }, {     16,    8,    4,  8,  2,  2 }, {     16,    9,    4,  8,  2,  2 },
    {     16,   10,    5,  8,  2,  2 }, {     16,   11,    5,  8,  2,  2 }, {     16,   12,    6,  8,  2,  2 }, {     16,   13,    6,  8,  2,  2 }, {     16,   14,    7,  8,  2,  2 },
    {     16,   15,    7,  8,  2,  2 }, {     16,   16,    8,  8,  2,  2 }, {     16,   17,    8,  8,  2,  2 }, {     16,   18,    9,  8,  2,  2 }, {     16,   19,    9,  8,  2,  2 },
    {     16,   20,   10,  8,  2,  2 }, {     16,   21,   10,  8,  2,  2 }, {     16,   22,   11,  8,  2,  2 }, {     16,   23,   11,  8,  2,  2 }, {     16,   24,   12,  8,  2,  2 },
    {     16,   25,   12,  8,  2,  2 }, {     16,   26,   13,  8,  2,  2 }, {     16,   27,   13,  8,  2,  2 }, {     16,   28,   14,  8,  2,  2 }, {     16,   29,   14,  8,  2,  2 },
    {     16,   30,   15,  8,  2,  2 }, {     16,   31,   15,  8,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_968EB2, {
    {      0,   16,    0, 16,  2,  2 }, {      1,   16,    0, 16,  2,  2 }, {      2,   16,    1, 16,  2,  2 }, {      3,   16,    1, 16,  2,  2 }, {      4,   16,    2, 16,  2,  2 },
    {      5,   16,    2, 16,  2,  2 }, {      6,   16,    3, 16,  2,  2 }, {      7,   16,    3, 16,  2,  2 }, {      8,   16,    4, 16,  2,  2 }, {      9,   16,    4, 16,  2,  2 },
    {     10,   16,    5, 16,  2,  2 }, {     11,   16,    5, 16,  2,  2 }, {     12,   16,    6, 16,  2,  2 }, {     13,   16,    6, 16,  2,  2 }, {     14,   16,    7, 16,  2,  2 },
    {     15,   16,    7, 16,  2,  2 }, {     16,   16,    8, 16,  2,  2 }, {     17,   16,    8, 16,  2,  2 }, {     18,   16,    9, 16,  2,  2 }, {     19,   16,    9, 16,  2,  2 },
    {     20,   16,   10, 16,  2,  2 }, {     21,   16,   10, 16,  2,  2 }, {     22,   16,   11, 16,  2,  2 }, {     23,   16,   11, 16,  2,  2 }, {     24,   16,   12, 16,  2,  2 },
    {     25,   16,   12, 16,  2,  2 }, {     26,   16,   13, 16,  2,  2 }, {     27,   16,   13, 16,  2,  2 }, {     28,   16,   14, 16,  2,  2 }, {     29,   16,   14, 16,  2,  2 },
    {     30,   16,   15, 16,  2,  2 }, {     31,   16,   15, 16,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_968FD4, {
    {     16,   31,    0, 24,  2,  2 }, {     16,   30,    1, 24,  2,  2 }, {     16,   29,    1, 24,  2,  2 }, {     16,   28,    2, 24,  2,  2 }, {     16,   27,    2, 24,  2,  2 },
    {     16,   26,    3, 24,  2,  2 }, {     16,   25,    3, 24,  2,  2 }, {     16,   24,    4, 24,  2,  2 }, {     16,   23,    4, 24,  2,  2 }, {     16,   22,    5, 24,  2,  2 },
    {     16,   21,    5, 24,  2,  2 }, {     16,   20,    6, 24,  2,  2 }, {     16,   19,    6, 24,  2,  2 }, {     16,   18,    7, 24,  2,  2 }, {     16,   17,    7, 24,  2,  2 },
    {     16,   16,    8, 24,  2,  2 }, {     16,   15,    8, 24,  2,  2 }, {     16,   14,    9, 24,  2,  2 }, {     16,   13,    9, 24,  2,  2 }, {     16,   12,   10, 24,  2,  2 },
    {     16,   11,   10, 24,  2,  2 }, {     16,   10,   11, 24,  2,  2 }, {     16,    9,   11, 24,  2,  2 }, {     16,    8,   12, 24,  2,  2 }, {     16,    7,   12, 24,  2,  2 },
    {     16,    6,   13, 24,  2,  2 }, {     16,    5,   13, 24,  2,  2 }, {     16,    4,   14, 24,  2,  2 }, {     16,    3,   14, 24,  2,  2 }, {     16,    2,   15, 24,  2,  2 },
    {     16,    1,   15, 24,  2,  2 }, {     16,    0,   16, 24,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96957E, {
    {     31,   16,    0,  0,  2,  4 }, {     30,   16,    1,  0,  2,  4 }, {     29,   16,    1,  0,  2,  4 }, {     28,   16,    2,  0,  2,  4 }, {     27,   16,    2,  0,  2,  4 },
    {     26,   16,    3,  0,  2,  4 }, {     25,   16,    3,  0,  2,  4 }, {     24,   16,    4,  0,  2,  4 }, {     23,   16,    4,  0,  2,  4 }, {     22,   16,    5,  0,  2,  4 },
    {     21,   16,    5,  0,  2,  4 }, {     20,   16,    6,  0,  2,  4 }, {     19,   16,    6,  0,  2,  4 }, {     18,   16,    7,  0,  2,  4 }, {     17,   16,    7,  0,  2,  4 },
    {     16,   16,    8,  0,  2,  4 }, {     15,   16,    8,  0,  2,  4 }, {     14,   16,    9,  0,  2,  4 }, {     13,   16,    9,  0,  2,  4 }, {     12,   16,   10,  0,  2,  4 },
    {     11,   16,   10,  0,  2,  4 }, {     10,   16,   11,  0,  2,  4 }, {      9,   16,   11,  0,  2,  4 }, {      8,   16,   12,  0,  2,  4 }, {      7,   16,   12,  0,  2,  4 },
    {      6,   16,   13,  0,  2,  4 }, {      5,   16,   13,  0,  2,  4 }, {      4,   16,   14,  0,  2,  4 }, {      3,   16,   14,  0,  2,  4 }, {      2,   16,   15,  0,  2,  4 },
    {      1,   16,   15,  0,  2,  4 }, {      0,   16,   16,  0,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9696A0, {
    {     16,    0,    0,  8,  2,  4 }, {     16,    1,    0,  8,  2,  4 }, {     16,    2,    1,  8,  2,  4 }, {     16,    3,    1,  8,  2,  4 }, {     16,    4,    2,  8,  2,  4 },
    {     16,    5,    2,  8,  2,  4 }, {     16,    6,    3,  8,  2,  4 }, {     16,    7,    3,  8,  2,  4 }, {     16,    8,    4,  8,  2,  4 }, {     16,    9,    4,  8,  2,  4 },
    {     16,   10,    5,  8,  2,  4 }, {     16,   11,    5,  8,  2,  4 }, {     16,   12,    6,  8,  2,  4 }, {     16,   13,    6,  8,  2,  4 }, {     16,   14,    7,  8,  2,  4 },
    {     16,   15,    7,  8,  2,  4 }, {     16,   16,    8,  8,  2,  4 }, {     16,   17,    8,  8,  2,  4 }, {     16,   18,    9,  8,  2,  4 }, {     16,   19,    9,  8,  2,  4 },
    {     16,   20,   10,  8,  2,  4 }, {     16,   21,   10,  8,  2,  4 }, {     16,   22,   11,  8,  2,  4 }, {     16,   23,   11,  8,  2,  4 }, {     16,   24,   12,  8,  2,  4 },
    {     16,   25,   12,  8,  2,  4 }, {     16,   26,   13,  8,  2,  4 }, {     16,   27,   13,  8,  2,  4 }, {     16,   28,   14,  8,  2,  4 }, {     16,   29,   14,  8,  2,  4 },
    {     16,   30,   15,  8,  2,  4 }, {     16,   31,   15,  8,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9697C2, {
    {      0,   16,    0, 16,  2,  4 }, {      1,   16,    0, 16,  2,  4 }, {      2,   16,    1, 16,  2,  4 }, {      3,   16,    1, 16,  2,  4 }, {      4,   16,    2, 16,  2,  4 },
    {      5,   16,    2, 16,  2,  4 }, {      6,   16,    3, 16,  2,  4 }, {      7,   16,    3, 16,  2,  4 }, {      8,   16,    4, 16,  2,  4 }, {      9,   16,    4, 16,  2,  4 },
    {     10,   16,    5, 16,  2,  4 }, {     11,   16,    5, 16,  2,  4 }, {     12,   16,    6, 16,  2,  4 }, {     13,   16,    6, 16,  2,  4 }, {     14,   16,    7, 16,  2,  4 },
    {     15,   16,    7, 16,  2,  4 }, {     16,   16,    8, 16,  2,  4 }, {     17,   16,    8, 16,  2,  4 }, {     18,   16,    9, 16,  2,  4 }, {     19,   16,    9, 16,  2,  4 },
    {     20,   16,   10, 16,  2,  4 }, {     21,   16,   10, 16,  2,  4 }, {     22,   16,   11, 16,  2,  4 }, {     23,   16,   11, 16,  2,  4 }, {     24,   16,   12, 16,  2,  4 },
    {     25,   16,   12, 16,  2,  4 }, {     26,   16,   13, 16,  2,  4 }, {     27,   16,   13, 16,  2,  4 }, {     28,   16,   14, 16,  2,  4 }, {     29,   16,   14, 16,  2,  4 },
    {     30,   16,   15, 16,  2,  4 }, {     31,   16,   15, 16,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9698E4, {
    {     16,   31,    0, 24,  2,  4 }, {     16,   30,    1, 24,  2,  4 }, {     16,   29,    1, 24,  2,  4 }, {     16,   28,    2, 24,  2,  4 }, {     16,   27,    2, 24,  2,  4 },
    {     16,   26,    3, 24,  2,  4 }, {     16,   25,    3, 24,  2,  4 }, {     16,   24,    4, 24,  2,  4 }, {     16,   23,    4, 24,  2,  4 }, {     16,   22,    5, 24,  2,  4 },
    {     16,   21,    5, 24,  2,  4 }, {     16,   20,    6, 24,  2,  4 }, {     16,   19,    6, 24,  2,  4 }, {     16,   18,    7, 24,  2,  4 }, {     16,   17,    7, 24,  2,  4 },
    {     16,   16,    8, 24,  2,  4 }, {     16,   15,    8, 24,  2,  4 }, {     16,   14,    9, 24,  2,  4 }, {     16,   13,    9, 24,  2,  4 }, {     16,   12,   10, 24,  2,  4 },
    {     16,   11,   10, 24,  2,  4 }, {     16,   10,   11, 24,  2,  4 }, {     16,    9,   11, 24,  2,  4 }, {     16,    8,   12, 24,  2,  4 }, {     16,    7,   12, 24,  2,  4 },
    {     16,    6,   13, 24,  2,  4 }, {     16,    5,   13, 24,  2,  4 }, {     16,    4,   14, 24,  2,  4 }, {     16,    3,   14, 24,  2,  4 }, {     16,    2,   15, 24,  2,  4 },
    {     16,    1,   15, 24,  2,  4 }, {     16,    0,   16, 24,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9048E8, {
    {     31,   16,    0,  0,  1,  0 }, {     30,   16,    0,  0,  1,  0 }, {     29,   16,    0,  0,  1,  0 }, {     28,   16,    0,  0,  1,  0 }, {     27,   16,    0,  0,  1,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  5,  0 }, {     22,   16,    0,  0,  5,  0 },
    {     21,   16,    0,  0,  5,  0 }, {     20,   16,    0,  0,  5,  0 }, {     19,   16,    0,  0,  5,  0 }, {     18,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  1,  0 }, {     14,   16,    0,  0,  1,  0 }, {     13,   16,    0,  0,  1,  0 }, {     12,   16,    0,  0,  1,  0 },
    {     11,   16,    0,  0,  1,  0 }, {     10,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  5,  0 },
    {      6,   16,    0,  0,  5,  0 }, {      5,   16,    0,  0,  5,  0 }, {      4,   16,    0,  0,  5,  0 }, {      3,   16,    0,  0,  5,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_904A0A, {
    {     16,    0,    0,  8,  1,  0 }, {     16,    1,    0,  8,  1,  0 }, {     16,    2,    0,  8,  1,  0 }, {     16,    3,    0,  8,  1,  0 }, {     16,    4,    0,  8,  1,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  5,  0 }, {     16,    9,    0,  8,  5,  0 },
    {     16,   10,    0,  8,  5,  0 }, {     16,   11,    0,  8,  5,  0 }, {     16,   12,    0,  8,  5,  0 }, {     16,   13,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   15,    0,  8,  0,  0 }, {     16,   16,    0,  8,  1,  0 }, {     16,   17,    0,  8,  1,  0 }, {     16,   18,    0,  8,  1,  0 }, {     16,   19,    0,  8,  1,  0 },
    {     16,   20,    0,  8,  1,  0 }, {     16,   21,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 }, {     16,   24,    0,  8,  5,  0 },
    {     16,   25,    0,  8,  5,  0 }, {     16,   26,    0,  8,  5,  0 }, {     16,   27,    0,  8,  5,  0 }, {     16,   28,    0,  8,  5,  0 }, {     16,   29,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_904B2C, {
    {      0,   16,    0, 16,  1,  0 }, {      1,   16,    0, 16,  1,  0 }, {      2,   16,    0, 16,  1,  0 }, {      3,   16,    0, 16,  1,  0 }, {      4,   16,    0, 16,  1,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  5,  0 }, {      9,   16,    0, 16,  5,  0 },
    {     10,   16,    0, 16,  5,  0 }, {     11,   16,    0, 16,  5,  0 }, {     12,   16,    0, 16,  5,  0 }, {     13,   16,    0, 16,  0,  0 }, {     14,   16,    0, 16,  0,  0 },
    {     15,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  1,  0 }, {     17,   16,    0, 16,  1,  0 }, {     18,   16,    0, 16,  1,  0 }, {     19,   16,    0, 16,  1,  0 },
    {     20,   16,    0, 16,  1,  0 }, {     21,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  5,  0 },
    {     25,   16,    0, 16,  5,  0 }, {     26,   16,    0, 16,  5,  0 }, {     27,   16,    0, 16,  5,  0 }, {     28,   16,    0, 16,  5,  0 }, {     29,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_904C4E, {
    {     16,   31,    0, 24,  1,  0 }, {     16,   30,    0, 24,  1,  0 }, {     16,   29,    0, 24,  1,  0 }, {     16,   28,    0, 24,  1,  0 }, {     16,   27,    0, 24,  1,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  5,  0 }, {     16,   22,    0, 24,  5,  0 },
    {     16,   21,    0, 24,  5,  0 }, {     16,   20,    0, 24,  5,  0 }, {     16,   19,    0, 24,  5,  0 }, {     16,   18,    0, 24,  0,  0 }, {     16,   17,    0, 24,  0,  0 },
    {     16,   16,    0, 24,  0,  0 }, {     16,   15,    0, 24,  1,  0 }, {     16,   14,    0, 24,  1,  0 }, {     16,   13,    0, 24,  1,  0 }, {     16,   12,    0, 24,  1,  0 },
    {     16,   11,    0, 24,  1,  0 }, {     16,   10,    0, 24,  0,  0 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 }, {     16,    7,    0, 24,  5,  0 },
    {     16,    6,    0, 24,  5,  0 }, {     16,    5,    0, 24,  5,  0 }, {     16,    4,    0, 24,  5,  0 }, {     16,    3,    0, 24,  5,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9690F6, {
    {     31,   16,   15,  0,  6,  2 }, {     30,   16,   15,  0,  6,  2 }, {     29,   16,   14,  0,  6,  2 }, {     28,   16,   14,  0,  6,  2 }, {     27,   16,   13,  0,  6,  2 },
    {     26,   16,   13,  0,  6,  2 }, {     25,   16,   12,  0,  6,  2 }, {     24,   16,   12,  0,  6,  2 }, {     23,   16,   11,  0,  6,  2 }, {     22,   16,   11,  0,  6,  2 },
    {     21,   16,   10,  0,  6,  2 }, {     20,   16,   10,  0,  6,  2 }, {     19,   16,    9,  0,  6,  2 }, {     18,   16,    9,  0,  6,  2 }, {     17,   16,    8,  0,  6,  2 },
    {     16,   16,    8,  0,  6,  2 }, {     15,   16,    7,  0,  6,  2 }, {     14,   16,    7,  0,  6,  2 }, {     13,   16,    6,  0,  6,  2 }, {     12,   16,    6,  0,  6,  2 },
    {     11,   16,    5,  0,  6,  2 }, {     10,   16,    5,  0,  6,  2 }, {      9,   16,    4,  0,  6,  2 }, {      8,   16,    4,  0,  6,  2 }, {      7,   16,    3,  0,  6,  2 },
    {      6,   16,    3,  0,  6,  2 }, {      5,   16,    2,  0,  6,  2 }, {      4,   16,    2,  0,  6,  2 }, {      3,   16,    1,  0,  6,  2 }, {      2,   16,    1,  0,  6,  2 },
    {      1,   16,    0,  0,  6,  2 }, {      0,   16,    0,  0,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_969218, {
    {     16,    0,   15,  8,  6,  2 }, {     16,    1,   14,  8,  6,  2 }, {     16,    2,   14,  8,  6,  2 }, {     16,    3,   13,  8,  6,  2 }, {     16,    4,   13,  8,  6,  2 },
    {     16,    5,   12,  8,  6,  2 }, {     16,    6,   12,  8,  6,  2 }, {     16,    7,   11,  8,  6,  2 }, {     16,    8,   11,  8,  6,  2 }, {     16,    9,   10,  8,  6,  2 },
    {     16,   10,   10,  8,  6,  2 }, {     16,   11,    9,  8,  6,  2 }, {     16,   12,    9,  8,  6,  2 }, {     16,   13,    8,  8,  6,  2 }, {     16,   14,    8,  8,  6,  2 },
    {     16,   15,    7,  8,  6,  2 }, {     16,   16,    7,  8,  6,  2 }, {     16,   17,    6,  8,  6,  2 }, {     16,   18,    6,  8,  6,  2 }, {     16,   19,    5,  8,  6,  2 },
    {     16,   20,    5,  8,  6,  2 }, {     16,   21,    4,  8,  6,  2 }, {     16,   22,    4,  8,  6,  2 }, {     16,   23,    3,  8,  6,  2 }, {     16,   24,    3,  8,  6,  2 },
    {     16,   25,    2,  8,  6,  2 }, {     16,   26,    2,  8,  6,  2 }, {     16,   27,    1,  8,  6,  2 }, {     16,   28,    1,  8,  6,  2 }, {     16,   29,    0,  8,  6,  2 },
    {     16,   30,    0,  8,  6,  2 }, {     16,   31,   -1,  8,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96933A, {
    {      0,   16,   15, 16,  6,  2 }, {      1,   16,   14, 16,  6,  2 }, {      2,   16,   14, 16,  6,  2 }, {      3,   16,   13, 16,  6,  2 }, {      4,   16,   13, 16,  6,  2 },
    {      5,   16,   12, 16,  6,  2 }, {      6,   16,   12, 16,  6,  2 }, {      7,   16,   11, 16,  6,  2 }, {      8,   16,   11, 16,  6,  2 }, {      9,   16,   10, 16,  6,  2 },
    {     10,   16,   10, 16,  6,  2 }, {     11,   16,    9, 16,  6,  2 }, {     12,   16,    9, 16,  6,  2 }, {     13,   16,    8, 16,  6,  2 }, {     14,   16,    8, 16,  6,  2 },
    {     15,   16,    7, 16,  6,  2 }, {     16,   16,    7, 16,  6,  2 }, {     17,   16,    6, 16,  6,  2 }, {     18,   16,    6, 16,  6,  2 }, {     19,   16,    5, 16,  6,  2 },
    {     20,   16,    5, 16,  6,  2 }, {     21,   16,    4, 16,  6,  2 }, {     22,   16,    4, 16,  6,  2 }, {     23,   16,    3, 16,  6,  2 }, {     24,   16,    3, 16,  6,  2 },
    {     25,   16,    2, 16,  6,  2 }, {     26,   16,    2, 16,  6,  2 }, {     27,   16,    1, 16,  6,  2 }, {     28,   16,    1, 16,  6,  2 }, {     29,   16,    0, 16,  6,  2 },
    {     30,   16,    0, 16,  6,  2 }, {     31,   16,   -1, 16,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96945C, {
    {     16,   31,   15, 24,  6,  2 }, {     16,   30,   15, 24,  6,  2 }, {     16,   29,   14, 24,  6,  2 }, {     16,   28,   14, 24,  6,  2 }, {     16,   27,   13, 24,  6,  2 },
    {     16,   26,   13, 24,  6,  2 }, {     16,   25,   12, 24,  6,  2 }, {     16,   24,   12, 24,  6,  2 }, {     16,   23,   11, 24,  6,  2 }, {     16,   22,   11, 24,  6,  2 },
    {     16,   21,   10, 24,  6,  2 }, {     16,   20,   10, 24,  6,  2 }, {     16,   19,    9, 24,  6,  2 }, {     16,   18,    9, 24,  6,  2 }, {     16,   17,    8, 24,  6,  2 },
    {     16,   16,    8, 24,  6,  2 }, {     16,   15,    7, 24,  6,  2 }, {     16,   14,    7, 24,  6,  2 }, {     16,   13,    6, 24,  6,  2 }, {     16,   12,    6, 24,  6,  2 },
    {     16,   11,    5, 24,  6,  2 }, {     16,   10,    5, 24,  6,  2 }, {     16,    9,    4, 24,  6,  2 }, {     16,    8,    4, 24,  6,  2 }, {     16,    7,    3, 24,  6,  2 },
    {     16,    6,    3, 24,  6,  2 }, {     16,    5,    2, 24,  6,  2 }, {     16,    4,    2, 24,  6,  2 }, {     16,    3,    1, 24,  6,  2 }, {     16,    2,    1, 24,  6,  2 },
    {     16,    1,    0, 24,  6,  2 }, {     16,    0,    0, 24,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_969A06, {
    {     31,   16,   15,  0,  6,  4 }, {     30,   16,   15,  0,  6,  4 }, {     29,   16,   14,  0,  6,  4 }, {     28,   16,   14,  0,  6,  4 }, {     27,   16,   13,  0,  6,  4 },
    {     26,   16,   13,  0,  6,  4 }, {     25,   16,   12,  0,  6,  4 }, {     24,   16,   12,  0,  6,  4 }, {     23,   16,   11,  0,  6,  4 }, {     22,   16,   11,  0,  6,  4 },
    {     21,   16,   10,  0,  6,  4 }, {     20,   16,   10,  0,  6,  4 }, {     19,   16,    9,  0,  6,  4 }, {     18,   16,    9,  0,  6,  4 }, {     17,   16,    8,  0,  6,  4 },
    {     16,   16,    8,  0,  6,  4 }, {     15,   16,    7,  0,  6,  4 }, {     14,   16,    7,  0,  6,  4 }, {     13,   16,    6,  0,  6,  4 }, {     12,   16,    6,  0,  6,  4 },
    {     11,   16,    5,  0,  6,  4 }, {     10,   16,    5,  0,  6,  4 }, {      9,   16,    4,  0,  6,  4 }, {      8,   16,    4,  0,  6,  4 }, {      7,   16,    3,  0,  6,  4 },
    {      6,   16,    3,  0,  6,  4 }, {      5,   16,    2,  0,  6,  4 }, {      4,   16,    2,  0,  6,  4 }, {      3,   16,    1,  0,  6,  4 }, {      2,   16,    1,  0,  6,  4 },
    {      1,   16,    0,  0,  6,  4 }, {      0,   16,    0,  0,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_969B28, {
    {     16,    0,   15,  8,  6,  4 }, {     16,    1,   14,  8,  6,  4 }, {     16,    2,   14,  8,  6,  4 }, {     16,    3,   13,  8,  6,  4 }, {     16,    4,   13,  8,  6,  4 },
    {     16,    5,   12,  8,  6,  4 }, {     16,    6,   12,  8,  6,  4 }, {     16,    7,   11,  8,  6,  4 }, {     16,    8,   11,  8,  6,  4 }, {     16,    9,   10,  8,  6,  4 },
    {     16,   10,   10,  8,  6,  4 }, {     16,   11,    9,  8,  6,  4 }, {     16,   12,    9,  8,  6,  4 }, {     16,   13,    8,  8,  6,  4 }, {     16,   14,    8,  8,  6,  4 },
    {     16,   15,    7,  8,  6,  4 }, {     16,   16,    7,  8,  6,  4 }, {     16,   17,    6,  8,  6,  4 }, {     16,   18,    6,  8,  6,  4 }, {     16,   19,    5,  8,  6,  4 },
    {     16,   20,    5,  8,  6,  4 }, {     16,   21,    4,  8,  6,  4 }, {     16,   22,    4,  8,  6,  4 }, {     16,   23,    3,  8,  6,  4 }, {     16,   24,    3,  8,  6,  4 },
    {     16,   25,    2,  8,  6,  4 }, {     16,   26,    2,  8,  6,  4 }, {     16,   27,    1,  8,  6,  4 }, {     16,   28,    1,  8,  6,  4 }, {     16,   29,    0,  8,  6,  4 },
    {     16,   30,    0,  8,  6,  4 }, {     16,   31,   -1,  8,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_969C4A, {
    {      0,   16,   15, 16,  6,  4 }, {      1,   16,   14, 16,  6,  4 }, {      2,   16,   14, 16,  6,  4 }, {      3,   16,   13, 16,  6,  4 }, {      4,   16,   13, 16,  6,  4 },
    {      5,   16,   12, 16,  6,  4 }, {      6,   16,   12, 16,  6,  4 }, {      7,   16,   11, 16,  6,  4 }, {      8,   16,   11, 16,  6,  4 }, {      9,   16,   10, 16,  6,  4 },
    {     10,   16,   10, 16,  6,  4 }, {     11,   16,    9, 16,  6,  4 }, {     12,   16,    9, 16,  6,  4 }, {     13,   16,    8, 16,  6,  4 }, {     14,   16,    8, 16,  6,  4 },
    {     15,   16,    7, 16,  6,  4 }, {     16,   16,    7, 16,  6,  4 }, {     17,   16,    6, 16,  6,  4 }, {     18,   16,    6, 16,  6,  4 }, {     19,   16,    5, 16,  6,  4 },
    {     20,   16,    5, 16,  6,  4 }, {     21,   16,    4, 16,  6,  4 }, {     22,   16,    4, 16,  6,  4 }, {     23,   16,    3, 16,  6,  4 }, {     24,   16,    3, 16,  6,  4 },
    {     25,   16,    2, 16,  6,  4 }, {     26,   16,    2, 16,  6,  4 }, {     27,   16,    1, 16,  6,  4 }, {     28,   16,    1, 16,  6,  4 }, {     29,   16,    0, 16,  6,  4 },
    {     30,   16,    0, 16,  6,  4 }, {     31,   16,   -1, 16,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_969D6C, {
    {     16,   31,   15, 24,  6,  4 }, {     16,   30,   15, 24,  6,  4 }, {     16,   29,   14, 24,  6,  4 }, {     16,   28,   14, 24,  6,  4 }, {     16,   27,   13, 24,  6,  4 },
    {     16,   26,   13, 24,  6,  4 }, {     16,   25,   12, 24,  6,  4 }, {     16,   24,   12, 24,  6,  4 }, {     16,   23,   11, 24,  6,  4 }, {     16,   22,   11, 24,  6,  4 },
    {     16,   21,   10, 24,  6,  4 }, {     16,   20,   10, 24,  6,  4 }, {     16,   19,    9, 24,  6,  4 }, {     16,   18,    9, 24,  6,  4 }, {     16,   17,    8, 24,  6,  4 },
    {     16,   16,    8, 24,  6,  4 }, {     16,   15,    7, 24,  6,  4 }, {     16,   14,    7, 24,  6,  4 }, {     16,   13,    6, 24,  6,  4 }, {     16,   12,    6, 24,  6,  4 },
    {     16,   11,    5, 24,  6,  4 }, {     16,   10,    5, 24,  6,  4 }, {     16,    9,    4, 24,  6,  4 }, {     16,    8,    4, 24,  6,  4 }, {     16,    7,    3, 24,  6,  4 },
    {     16,    6,    3, 24,  6,  4 }, {     16,    5,    2, 24,  6,  4 }, {     16,    4,    2, 24,  6,  4 }, {     16,    3,    1, 24,  6,  4 }, {     16,    2,    1, 24,  6,  4 },
    {     16,    1,    0, 24,  6,  4 }, {     16,    0,    0, 24,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_904D72, {
    {     31,   16,   16,  0,  0,  0 }, {     30,   16,   16,  0,  0,  0 }, {     29,   16,   16,  0,  0,  0 }, {     28,   16,   16,  0,  0,  0 }, {     27,   16,   16,  0,  0,  0 },
    {     26,   16,   16,  0,  0,  0 }, {     25,   16,   16,  0,  0,  0 }, {     24,   16,   16,  0,  0,  0 }, {     23,   16,   16,  0,  0,  0 }, {     22,   16,   16,  0,  0,  0 },
    {     21,   16,   16,  0,  0,  0 }, {     20,   16,   16,  0,  0,  0 }, {     19,   16,   16,  0,  0,  0 }, {     18,   16,   16,  0,  0,  0 }, {     17,   16,   15,  0,  0,  0 },
    {     16,   16,   15,  0,  0,  0 }, {     15,   16,   15,  0,  0,  0 }, {     14,   16,   15,  0,  0,  0 }, {     13,   16,   15,  0,  0,  0 }, {     12,   16,   15,  0,  0,  0 },
    {     11,   16,   15,  0,  0,  0 }, {     10,   16,   14,  0,  5,  0 }, {      9,   16,   14,  0,  5,  0 }, {      8,   16,   14,  0,  5,  0 }, {      7,   16,   14,  0,  5,  0 },
    {      6,   16,   14,  0,  5,  0 }, {      5,   16,   13,  0,  5,  0 }, {      4,   16,   13,  0,  5,  0 }, {      3,   16,   13,  0,  5,  0 }, {      2,   16,   13,  0,  5,  0 },
    {      1,   16,   12,  0,  5,  0 }, {      0,   16,   12,  0,  5,  0 }, {     -1,   16,   12,  0,  5,  0 }, {     -2,   16,   12,  0,  5,  0 }, {     -3,   16,   11,  0,  5,  0 },
    {     -4,   16,   11,  0,  5,  0 }, {     -5,   16,   11,  0,  5,  0 }, {     -6,   16,   11,  0,  5,  0 }, {     -7,   16,   10,  0,  5,  0 }, {     -8,   16,   10,  0,  5,  0 },
    {     -9,   16,   10,  0,  5,  0 }, {    -10,   16,   10,  0,  5,  0 }, {    -11,   16,   10,  0,  5,  0 }, {    -12,   16,    9,  0,  0,  0 }, {    -13,   16,    9,  0,  0,  0 },
    {    -14,   16,    9,  0,  0,  0 }, {    -15,   16,    9,  0,  0,  0 }, {    -16,   16,    9,  0,  0,  0 }, {    -17,   16,    9,  0,  0,  0 }, {    -18,   16,    9,  0,  0,  0 },
    {    -19,   16,    8,  0,  0,  0 }, {    -20,   16,    8,  0,  0,  0 }, {    -21,   16,    8,  0,  0,  0 }, {    -22,   16,    8,  0,  0,  0 }, {    -23,   16,    8,  0,  0,  0 },
    {    -24,   16,    8,  0,  0,  0 }, {    -25,   16,    8,  0,  0,  0 }, {    -26,   16,    8,  0,  0,  0 }, {    -27,   16,    8,  0,  0,  0 }, {    -28,   16,    8,  0,  0,  0 },
    {    -29,   16,    8,  0,  0,  0 }, {    -30,   16,    8,  0,  0,  0 }, {    -31,   16,    8,  0,  0,  0 }, {    -32,   16,    8,  0,  0,  0 }, {    -33,   16,    8,  0,  0,  0 },
    {    -34,   16,    8,  0,  0,  0 }, {    -35,   16,    8,  0,  0,  0 }, {    -36,   16,    8,  0,  0,  0 }, {    -37,   16,    8,  0,  0,  0 }, {    -38,   16,    8,  0,  0,  0 },
    {    -39,   16,    8,  0,  0,  0 }, {    -40,   16,    8,  0,  0,  0 }, {    -41,   16,    8,  0,  0,  0 }, {    -42,   16,    8,  0,  0,  0 }, {    -43,   16,    8,  0,  0,  0 },
    {    -44,   16,    8,  0,  0,  0 }, {    -45,   16,    8,  0,  0,  0 }, {    -46,   16,    8,  0,  0,  0 }, {    -47,   16,    8,  0,  0,  0 }, {    -48,   16,    8,  0,  0,  0 },
    {    -49,   16,    8,  0,  0,  0 }, {    -50,   16,    8,  0,  0,  0 }, {    -51,   16,    8,  0,  0,  0 }, {    -52,   16,    8,  0,  0,  0 }, {    -53,   16,    8,  0,  0,  0 },
    {    -54,   16,    8,  0,  0,  0 }, {    -55,   16,    8,  0,  0,  0 }, {    -56,   16,    8,  0,  0,  0 }, {    -57,   16,    8,  0,  0,  0 }, {    -58,   16,    8,  0,  0,  0 },
    {    -59,   16,    8,  0,  0,  0 }, {    -60,   16,    8,  0,  0,  0 }, {    -61,   16,    8,  0,  0,  0 }, {    -62,   16,    8,  0,  0,  0 }, {    -63,   16,    8,  0,  0,  0 },
    {    -64,   16,    8,  0,  0,  0 }, {    -65,   16,    8,  0,  0,  0 }, {    -66,   16,    8,  0,  0,  0 }, {    -67,   16,    8,  0,  0,  0 }, {    -68,   16,    8,  0,  0,  0 },
    {    -69,   16,    8,  0,  0,  0 }, {    -70,   16,    8,  0,  0,  0 }, {    -71,   16,    8,  0,  0,  0 }, {    -72,   16,    8,  0,  0,  0 }, {    -73,   16,    8,  0,  0,  0 },
    {    -74,   16,    8,  0,  0,  0 }, {    -75,   16,    8,  0,  0,  0 }, {    -76,   16,    8,  0,  0,  0 }, {    -77,   16,    8,  0,  0,  0 }, {    -78,   16,    8,  0,  0,  0 },
    {    -79,   16,    9,  0,  0,  0 }, {    -80,   16,    9,  0,  0,  0 }, {    -81,   16,    9,  0,  0,  0 }, {    -82,   16,    9,  0,  0,  0 }, {    -83,   16,    9,  0,  0,  0 },
    {    -84,   16,    9,  0,  0,  0 }, {    -85,   16,    9,  0,  0,  0 }, {    -86,   16,   10,  0,  1,  0 }, {    -87,   16,   10,  0,  1,  0 }, {    -88,   16,   10,  0,  1,  0 },
    {    -89,   16,   10,  0,  1,  0 }, {    -90,   16,   10,  0,  1,  0 }, {    -91,   16,   11,  0,  1,  0 }, {    -92,   16,   11,  0,  1,  0 }, {    -93,   16,   11,  0,  1,  0 },
    {    -94,   16,   11,  0,  1,  0 }, {    -95,   16,   12,  0,  1,  0 }, {    -96,   16,   12,  0,  1,  0 }, {    -97,   16,   12,  0,  1,  0 }, {    -98,   16,   12,  0,  1,  0 },
    {    -99,   16,   13,  0,  1,  0 }, {   -100,   16,   13,  0,  1,  0 }, {   -101,   16,   13,  0,  1,  0 }, {   -102,   16,   13,  0,  1,  0 }, {   -103,   16,   14,  0,  1,  0 },
    {   -104,   16,   14,  0,  1,  0 }, {   -105,   16,   14,  0,  1,  0 }, {   -106,   16,   14,  0,  1,  0 }, {   -107,   16,   14,  0,  1,  0 }, {   -108,   16,   15,  0,  0,  0 },
    {   -109,   16,   15,  0,  0,  0 }, {   -110,   16,   15,  0,  0,  0 }, {   -111,   16,   15,  0,  0,  0 }, {   -112,   16,   15,  0,  0,  0 }, {   -113,   16,   15,  0,  0,  0 },
    {   -114,   16,   15,  0,  0,  0 }, {   -115,   16,   16,  0,  0,  0 }, {   -116,   16,   16,  0,  0,  0 }, {   -117,   16,   16,  0,  0,  0 }, {   -118,   16,   16,  0,  0,  0 },
    {   -119,   16,   16,  0,  0,  0 }, {   -120,   16,   16,  0,  0,  0 }, {   -121,   16,   16,  0,  0,  0 }, {   -122,   16,   16,  0,  0,  0 }, {   -123,   16,   16,  0,  0,  0 },
    {   -124,   16,   16,  0,  0,  0 }, {   -125,   16,   16,  0,  0,  0 }, {   -126,   16,   16,  0,  0,  0 }, {   -127,   16,   16,  0,  0,  0 }, {   -128,   16,   16,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_905314, {
    {     16,    0,   16,  8,  0,  0 }, {     16,    1,   16,  8,  0,  0 }, {     16,    2,   16,  8,  0,  0 }, {     16,    3,   16,  8,  0,  0 }, {     16,    4,   16,  8,  0,  0 },
    {     16,    5,   16,  8,  0,  0 }, {     16,    6,   16,  8,  0,  0 }, {     16,    7,   16,  8,  0,  0 }, {     16,    8,   16,  8,  0,  0 }, {     16,    9,   16,  8,  0,  0 },
    {     16,   10,   16,  8,  0,  0 }, {     16,   11,   16,  8,  0,  0 }, {     16,   12,   16,  8,  0,  0 }, {     16,   13,   16,  8,  0,  0 }, {     16,   14,   15,  8,  0,  0 },
    {     16,   15,   15,  8,  0,  0 }, {     16,   16,   15,  8,  0,  0 }, {     16,   17,   15,  8,  0,  0 }, {     16,   18,   15,  8,  0,  0 }, {     16,   19,   15,  8,  0,  0 },
    {     16,   20,   15,  8,  0,  0 }, {     16,   21,   14,  8,  5,  0 }, {     16,   22,   14,  8,  5,  0 }, {     16,   23,   14,  8,  5,  0 }, {     16,   24,   14,  8,  5,  0 },
    {     16,   25,   14,  8,  5,  0 }, {     16,   26,   13,  8,  5,  0 }, {     16,   27,   13,  8,  5,  0 }, {     16,   28,   13,  8,  5,  0 }, {     16,   29,   13,  8,  5,  0 },
    {     16,   30,   12,  8,  5,  0 }, {     16,   31,   12,  8,  5,  0 }, {     16,   32,   12,  8,  5,  0 }, {     16,   33,   12,  8,  5,  0 }, {     16,   34,   11,  8,  5,  0 },
    {     16,   35,   11,  8,  5,  0 }, {     16,   36,   11,  8,  5,  0 }, {     16,   37,   11,  8,  5,  0 }, {     16,   38,   10,  8,  5,  0 }, {     16,   39,   10,  8,  5,  0 },
    {     16,   40,   10,  8,  5,  0 }, {     16,   41,   10,  8,  5,  0 }, {     16,   42,   10,  8,  5,  0 }, {     16,   43,    9,  8,  0,  0 }, {     16,   44,    9,  8,  0,  0 },
    {     16,   45,    9,  8,  0,  0 }, {     16,   46,    9,  8,  0,  0 }, {     16,   47,    9,  8,  0,  0 }, {     16,   48,    9,  8,  0,  0 }, {     16,   49,    9,  8,  0,  0 },
    {     16,   50,    8,  8,  0,  0 }, {     16,   51,    8,  8,  0,  0 }, {     16,   52,    8,  8,  0,  0 }, {     16,   53,    8,  8,  0,  0 }, {     16,   54,    8,  8,  0,  0 },
    {     16,   55,    8,  8,  0,  0 }, {     16,   56,    8,  8,  0,  0 }, {     16,   57,    8,  8,  0,  0 }, {     16,   58,    8,  8,  0,  0 }, {     16,   59,    8,  8,  0,  0 },
    {     16,   60,    8,  8,  0,  0 }, {     16,   61,    8,  8,  0,  0 }, {     16,   62,    8,  8,  0,  0 }, {     16,   63,    8,  8,  0,  0 }, {     16,   64,    8,  8,  0,  0 },
    {     16,   65,    8,  8,  0,  0 }, {     16,   66,    8,  8,  0,  0 }, {     16,   67,    8,  8,  0,  0 }, {     16,   68,    8,  8,  0,  0 }, {     16,   69,    8,  8,  0,  0 },
    {     16,   70,    8,  8,  0,  0 }, {     16,   71,    8,  8,  0,  0 }, {     16,   72,    8,  8,  0,  0 }, {     16,   73,    8,  8,  0,  0 }, {     16,   74,    8,  8,  0,  0 },
    {     16,   75,    8,  8,  0,  0 }, {     16,   76,    8,  8,  0,  0 }, {     16,   77,    8,  8,  0,  0 }, {     16,   78,    8,  8,  0,  0 }, {     16,   79,    8,  8,  0,  0 },
    {     16,   80,    8,  8,  0,  0 }, {     16,   81,    8,  8,  0,  0 }, {     16,   82,    8,  8,  0,  0 }, {     16,   83,    8,  8,  0,  0 }, {     16,   84,    8,  8,  0,  0 },
    {     16,   85,    8,  8,  0,  0 }, {     16,   86,    8,  8,  0,  0 }, {     16,   87,    8,  8,  0,  0 }, {     16,   88,    8,  8,  0,  0 }, {     16,   89,    8,  8,  0,  0 },
    {     16,   90,    8,  8,  0,  0 }, {     16,   91,    8,  8,  0,  0 }, {     16,   92,    8,  8,  0,  0 }, {     16,   93,    8,  8,  0,  0 }, {     16,   94,    8,  8,  0,  0 },
    {     16,   95,    8,  8,  0,  0 }, {     16,   96,    8,  8,  0,  0 }, {     16,   97,    8,  8,  0,  0 }, {     16,   98,    8,  8,  0,  0 }, {     16,   99,    8,  8,  0,  0 },
    {     16,  100,    8,  8,  0,  0 }, {     16,  101,    8,  8,  0,  0 }, {     16,  102,    8,  8,  0,  0 }, {     16,  103,    8,  8,  0,  0 }, {     16,  104,    8,  8,  0,  0 },
    {     16,  105,    8,  8,  0,  0 }, {     16,  106,    8,  8,  0,  0 }, {     16,  107,    8,  8,  0,  0 }, {     16,  108,    8,  8,  0,  0 }, {     16,  109,    8,  8,  0,  0 },
    {     16,  110,    9,  8,  0,  0 }, {     16,  111,    9,  8,  0,  0 }, {     16,  112,    9,  8,  0,  0 }, {     16,  113,    9,  8,  0,  0 }, {     16,  114,    9,  8,  0,  0 },
    {     16,  115,    9,  8,  0,  0 }, {     16,  116,    9,  8,  0,  0 }, {     16,  117,   10,  8,  1,  0 }, {     16,  118,   10,  8,  1,  0 }, {     16,  119,   10,  8,  1,  0 },
    {     16,  120,   10,  8,  1,  0 }, {     16,  121,   10,  8,  1,  0 }, {     16,  122,   11,  8,  1,  0 }, {     16,  123,   11,  8,  1,  0 }, {     16,  124,   11,  8,  1,  0 },
    {     16,  125,   11,  8,  1,  0 }, {     16,  126,   12,  8,  1,  0 }, {     16,  127,   12,  8,  1,  0 }, {     16,  128,   12,  8,  1,  0 }, {     16,  129,   12,  8,  1,  0 },
    {     16,  130,   13,  8,  1,  0 }, {     16,  131,   13,  8,  1,  0 }, {     16,  132,   13,  8,  1,  0 }, {     16,  133,   13,  8,  1,  0 }, {     16,  134,   14,  8,  1,  0 },
    {     16,  135,   14,  8,  1,  0 }, {     16,  136,   14,  8,  1,  0 }, {     16,  137,   14,  8,  1,  0 }, {     16,  138,   14,  8,  1,  0 }, {     16,  139,   15,  8,  0,  0 },
    {     16,  140,   15,  8,  0,  0 }, {     16,  141,   15,  8,  0,  0 }, {     16,  142,   15,  8,  0,  0 }, {     16,  143,   15,  8,  0,  0 }, {     16,  144,   15,  8,  0,  0 },
    {     16,  145,   15,  8,  0,  0 }, {     16,  146,   16,  8,  0,  0 }, {     16,  147,   16,  8,  0,  0 }, {     16,  148,   16,  8,  0,  0 }, {     16,  149,   16,  8,  0,  0 },
    {     16,  150,   16,  8,  0,  0 }, {     16,  151,   16,  8,  0,  0 }, {     16,  152,   16,  8,  0,  0 }, {     16,  153,   16,  8,  0,  0 }, {     16,  154,   16,  8,  0,  0 },
    {     16,  155,   16,  8,  0,  0 }, {     16,  156,   16,  8,  0,  0 }, {     16,  157,   16,  8,  0,  0 }, {     16,  158,   16,  8,  0,  0 }, {     16,  159,   16,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9058B6, {
    {      0,   16,   16, 16,  0,  0 }, {      1,   16,   16, 16,  0,  0 }, {      2,   16,   16, 16,  0,  0 }, {      3,   16,   16, 16,  0,  0 }, {      4,   16,   16, 16,  0,  0 },
    {      5,   16,   16, 16,  0,  0 }, {      6,   16,   16, 16,  0,  0 }, {      7,   16,   16, 16,  0,  0 }, {      8,   16,   16, 16,  0,  0 }, {      9,   16,   16, 16,  0,  0 },
    {     10,   16,   16, 16,  0,  0 }, {     11,   16,   16, 16,  0,  0 }, {     12,   16,   16, 16,  0,  0 }, {     13,   16,   16, 16,  0,  0 }, {     14,   16,   15, 16,  0,  0 },
    {     15,   16,   15, 16,  0,  0 }, {     16,   16,   15, 16,  0,  0 }, {     17,   16,   15, 16,  0,  0 }, {     18,   16,   15, 16,  0,  0 }, {     19,   16,   15, 16,  0,  0 },
    {     20,   16,   15, 16,  0,  0 }, {     21,   16,   14, 16,  5,  0 }, {     22,   16,   14, 16,  5,  0 }, {     23,   16,   14, 16,  5,  0 }, {     24,   16,   14, 16,  5,  0 },
    {     25,   16,   14, 16,  5,  0 }, {     26,   16,   13, 16,  5,  0 }, {     27,   16,   13, 16,  5,  0 }, {     28,   16,   13, 16,  5,  0 }, {     29,   16,   13, 16,  5,  0 },
    {     30,   16,   12, 16,  5,  0 }, {     31,   16,   12, 16,  5,  0 }, {     32,   16,   12, 16,  5,  0 }, {     33,   16,   12, 16,  5,  0 }, {     34,   16,   11, 16,  5,  0 },
    {     35,   16,   11, 16,  5,  0 }, {     36,   16,   11, 16,  5,  0 }, {     37,   16,   11, 16,  5,  0 }, {     38,   16,   10, 16,  5,  0 }, {     39,   16,   10, 16,  5,  0 },
    {     40,   16,   10, 16,  5,  0 }, {     41,   16,   10, 16,  5,  0 }, {     42,   16,   10, 16,  5,  0 }, {     43,   16,    9, 16,  0,  0 }, {     44,   16,    9, 16,  0,  0 },
    {     45,   16,    9, 16,  0,  0 }, {     46,   16,    9, 16,  0,  0 }, {     47,   16,    9, 16,  0,  0 }, {     48,   16,    9, 16,  0,  0 }, {     49,   16,    9, 16,  0,  0 },
    {     50,   16,    8, 16,  0,  0 }, {     51,   16,    8, 16,  0,  0 }, {     52,   16,    8, 16,  0,  0 }, {     53,   16,    8, 16,  0,  0 }, {     54,   16,    8, 16,  0,  0 },
    {     55,   16,    8, 16,  0,  0 }, {     56,   16,    8, 16,  0,  0 }, {     57,   16,    8, 16,  0,  0 }, {     58,   16,    8, 16,  0,  0 }, {     59,   16,    8, 16,  0,  0 },
    {     60,   16,    8, 16,  0,  0 }, {     61,   16,    8, 16,  0,  0 }, {     62,   16,    8, 16,  0,  0 }, {     63,   16,    8, 16,  0,  0 }, {     64,   16,    8, 16,  0,  0 },
    {     65,   16,    8, 16,  0,  0 }, {     66,   16,    8, 16,  0,  0 }, {     67,   16,    8, 16,  0,  0 }, {     68,   16,    8, 16,  0,  0 }, {     69,   16,    8, 16,  0,  0 },
    {     70,   16,    8, 16,  0,  0 }, {     71,   16,    8, 16,  0,  0 }, {     72,   16,    8, 16,  0,  0 }, {     73,   16,    8, 16,  0,  0 }, {     74,   16,    8, 16,  0,  0 },
    {     75,   16,    8, 16,  0,  0 }, {     76,   16,    8, 16,  0,  0 }, {     77,   16,    8, 16,  0,  0 }, {     78,   16,    8, 16,  0,  0 }, {     79,   16,    8, 16,  0,  0 },
    {     80,   16,    8, 16,  0,  0 }, {     81,   16,    8, 16,  0,  0 }, {     82,   16,    8, 16,  0,  0 }, {     83,   16,    8, 16,  0,  0 }, {     84,   16,    8, 16,  0,  0 },
    {     85,   16,    8, 16,  0,  0 }, {     86,   16,    8, 16,  0,  0 }, {     87,   16,    8, 16,  0,  0 }, {     88,   16,    8, 16,  0,  0 }, {     89,   16,    8, 16,  0,  0 },
    {     90,   16,    8, 16,  0,  0 }, {     91,   16,    8, 16,  0,  0 }, {     92,   16,    8, 16,  0,  0 }, {     93,   16,    8, 16,  0,  0 }, {     94,   16,    8, 16,  0,  0 },
    {     95,   16,    8, 16,  0,  0 }, {     96,   16,    8, 16,  0,  0 }, {     97,   16,    8, 16,  0,  0 }, {     98,   16,    8, 16,  0,  0 }, {     99,   16,    8, 16,  0,  0 },
    {    100,   16,    8, 16,  0,  0 }, {    101,   16,    8, 16,  0,  0 }, {    102,   16,    8, 16,  0,  0 }, {    103,   16,    8, 16,  0,  0 }, {    104,   16,    8, 16,  0,  0 },
    {    105,   16,    8, 16,  0,  0 }, {    106,   16,    8, 16,  0,  0 }, {    107,   16,    8, 16,  0,  0 }, {    108,   16,    8, 16,  0,  0 }, {    109,   16,    8, 16,  0,  0 },
    {    110,   16,    9, 16,  0,  0 }, {    111,   16,    9, 16,  0,  0 }, {    112,   16,    9, 16,  0,  0 }, {    113,   16,    9, 16,  0,  0 }, {    114,   16,    9, 16,  0,  0 },
    {    115,   16,    9, 16,  0,  0 }, {    116,   16,    9, 16,  0,  0 }, {    117,   16,   10, 16,  1,  0 }, {    118,   16,   10, 16,  1,  0 }, {    119,   16,   10, 16,  1,  0 },
    {    120,   16,   10, 16,  1,  0 }, {    121,   16,   10, 16,  1,  0 }, {    122,   16,   11, 16,  1,  0 }, {    123,   16,   11, 16,  1,  0 }, {    124,   16,   11, 16,  1,  0 },
    {    125,   16,   11, 16,  1,  0 }, {    126,   16,   12, 16,  1,  0 }, {    127,   16,   12, 16,  1,  0 }, {    128,   16,   12, 16,  1,  0 }, {    129,   16,   12, 16,  1,  0 },
    {    130,   16,   13, 16,  1,  0 }, {    131,   16,   13, 16,  1,  0 }, {    132,   16,   13, 16,  1,  0 }, {    133,   16,   13, 16,  1,  0 }, {    134,   16,   14, 16,  1,  0 },
    {    135,   16,   14, 16,  1,  0 }, {    136,   16,   14, 16,  1,  0 }, {    137,   16,   14, 16,  1,  0 }, {    138,   16,   14, 16,  1,  0 }, {    139,   16,   15, 16,  0,  0 },
    {    140,   16,   15, 16,  0,  0 }, {    141,   16,   15, 16,  0,  0 }, {    142,   16,   15, 16,  0,  0 }, {    143,   16,   15, 16,  0,  0 }, {    144,   16,   15, 16,  0,  0 },
    {    145,   16,   15, 16,  0,  0 }, {    146,   16,   16, 16,  0,  0 }, {    147,   16,   16, 16,  0,  0 }, {    148,   16,   16, 16,  0,  0 }, {    149,   16,   16, 16,  0,  0 },
    {    150,   16,   16, 16,  0,  0 }, {    151,   16,   16, 16,  0,  0 }, {    152,   16,   16, 16,  0,  0 }, {    153,   16,   16, 16,  0,  0 }, {    154,   16,   16, 16,  0,  0 },
    {    155,   16,   16, 16,  0,  0 }, {    156,   16,   16, 16,  0,  0 }, {    157,   16,   16, 16,  0,  0 }, {    158,   16,   16, 16,  0,  0 }, {    159,   16,   16, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_905E58, {
    {     16,   31,   16, 24,  0,  0 }, {     16,   30,   16, 24,  0,  0 }, {     16,   29,   16, 24,  0,  0 }, {     16,   28,   16, 24,  0,  0 }, {     16,   27,   16, 24,  0,  0 },
    {     16,   26,   16, 24,  0,  0 }, {     16,   25,   16, 24,  0,  0 }, {     16,   24,   16, 24,  0,  0 }, {     16,   23,   16, 24,  0,  0 }, {     16,   22,   16, 24,  0,  0 },
    {     16,   21,   16, 24,  0,  0 }, {     16,   20,   16, 24,  0,  0 }, {     16,   19,   16, 24,  0,  0 }, {     16,   18,   16, 24,  0,  0 }, {     16,   17,   15, 24,  0,  0 },
    {     16,   16,   15, 24,  0,  0 }, {     16,   15,   15, 24,  0,  0 }, {     16,   14,   15, 24,  0,  0 }, {     16,   13,   15, 24,  0,  0 }, {     16,   12,   15, 24,  0,  0 },
    {     16,   11,   15, 24,  0,  0 }, {     16,   10,   14, 24,  5,  0 }, {     16,    9,   14, 24,  5,  0 }, {     16,    8,   14, 24,  5,  0 }, {     16,    7,   14, 24,  5,  0 },
    {     16,    6,   14, 24,  5,  0 }, {     16,    5,   13, 24,  5,  0 }, {     16,    4,   13, 24,  5,  0 }, {     16,    3,   13, 24,  5,  0 }, {     16,    2,   13, 24,  5,  0 },
    {     16,    1,   12, 24,  5,  0 }, {     16,    0,   12, 24,  5,  0 }, {     16,   -1,   12, 24,  5,  0 }, {     16,   -2,   12, 24,  5,  0 }, {     16,   -3,   11, 24,  5,  0 },
    {     16,   -4,   11, 24,  5,  0 }, {     16,   -5,   11, 24,  5,  0 }, {     16,   -6,   11, 24,  5,  0 }, {     16,   -7,   10, 24,  5,  0 }, {     16,   -8,   10, 24,  5,  0 },
    {     16,   -9,   10, 24,  5,  0 }, {     16,  -10,   10, 24,  5,  0 }, {     16,  -11,   10, 24,  5,  0 }, {     16,  -12,    9, 24,  0,  0 }, {     16,  -13,    9, 24,  0,  0 },
    {     16,  -14,    9, 24,  0,  0 }, {     16,  -15,    9, 24,  0,  0 }, {     16,  -16,    9, 24,  0,  0 }, {     16,  -17,    9, 24,  0,  0 }, {     16,  -18,    9, 24,  0,  0 },
    {     16,  -19,    8, 24,  0,  0 }, {     16,  -20,    8, 24,  0,  0 }, {     16,  -21,    8, 24,  0,  0 }, {     16,  -22,    8, 24,  0,  0 }, {     16,  -23,    8, 24,  0,  0 },
    {     16,  -24,    8, 24,  0,  0 }, {     16,  -25,    8, 24,  0,  0 }, {     16,  -26,    8, 24,  0,  0 }, {     16,  -27,    8, 24,  0,  0 }, {     16,  -28,    8, 24,  0,  0 },
    {     16,  -29,    8, 24,  0,  0 }, {     16,  -30,    8, 24,  0,  0 }, {     16,  -31,    8, 24,  0,  0 }, {     16,  -32,    8, 24,  0,  0 }, {     16,  -33,    8, 24,  0,  0 },
    {     16,  -34,    8, 24,  0,  0 }, {     16,  -35,    8, 24,  0,  0 }, {     16,  -36,    8, 24,  0,  0 }, {     16,  -37,    8, 24,  0,  0 }, {     16,  -38,    8, 24,  0,  0 },
    {     16,  -39,    8, 24,  0,  0 }, {     16,  -40,    8, 24,  0,  0 }, {     16,  -41,    8, 24,  0,  0 }, {     16,  -42,    8, 24,  0,  0 }, {     16,  -43,    8, 24,  0,  0 },
    {     16,  -44,    8, 24,  0,  0 }, {     16,  -45,    8, 24,  0,  0 }, {     16,  -46,    8, 24,  0,  0 }, {     16,  -47,    8, 24,  0,  0 }, {     16,  -48,    8, 24,  0,  0 },
    {     16,  -49,    8, 24,  0,  0 }, {     16,  -50,    8, 24,  0,  0 }, {     16,  -51,    8, 24,  0,  0 }, {     16,  -52,    8, 24,  0,  0 }, {     16,  -53,    8, 24,  0,  0 },
    {     16,  -54,    8, 24,  0,  0 }, {     16,  -55,    8, 24,  0,  0 }, {     16,  -56,    8, 24,  0,  0 }, {     16,  -57,    8, 24,  0,  0 }, {     16,  -58,    8, 24,  0,  0 },
    {     16,  -59,    8, 24,  0,  0 }, {     16,  -60,    8, 24,  0,  0 }, {     16,  -61,    8, 24,  0,  0 }, {     16,  -62,    8, 24,  0,  0 }, {     16,  -63,    8, 24,  0,  0 },
    {     16,  -64,    8, 24,  0,  0 }, {     16,  -65,    8, 24,  0,  0 }, {     16,  -66,    8, 24,  0,  0 }, {     16,  -67,    8, 24,  0,  0 }, {     16,  -68,    8, 24,  0,  0 },
    {     16,  -69,    8, 24,  0,  0 }, {     16,  -70,    8, 24,  0,  0 }, {     16,  -71,    8, 24,  0,  0 }, {     16,  -72,    8, 24,  0,  0 }, {     16,  -73,    8, 24,  0,  0 },
    {     16,  -74,    8, 24,  0,  0 }, {     16,  -75,    8, 24,  0,  0 }, {     16,  -76,    8, 24,  0,  0 }, {     16,  -77,    8, 24,  0,  0 }, {     16,  -78,    8, 24,  0,  0 },
    {     16,  -79,    9, 24,  0,  0 }, {     16,  -80,    9, 24,  0,  0 }, {     16,  -81,    9, 24,  0,  0 }, {     16,  -82,    9, 24,  0,  0 }, {     16,  -83,    9, 24,  0,  0 },
    {     16,  -84,    9, 24,  0,  0 }, {     16,  -85,    9, 24,  0,  0 }, {     16,  -86,   10, 24,  1,  0 }, {     16,  -87,   10, 24,  1,  0 }, {     16,  -88,   10, 24,  1,  0 },
    {     16,  -89,   10, 24,  1,  0 }, {     16,  -90,   10, 24,  1,  0 }, {     16,  -91,   11, 24,  1,  0 }, {     16,  -92,   11, 24,  1,  0 }, {     16,  -93,   11, 24,  1,  0 },
    {     16,  -94,   11, 24,  1,  0 }, {     16,  -95,   12, 24,  1,  0 }, {     16,  -96,   12, 24,  1,  0 }, {     16,  -97,   12, 24,  1,  0 }, {     16,  -98,   12, 24,  1,  0 },
    {     16,  -99,   13, 24,  1,  0 }, {     16, -100,   13, 24,  1,  0 }, {     16, -101,   13, 24,  1,  0 }, {     16, -102,   13, 24,  1,  0 }, {     16, -103,   14, 24,  1,  0 },
    {     16, -104,   14, 24,  1,  0 }, {     16, -105,   14, 24,  1,  0 }, {     16, -106,   14, 24,  1,  0 }, {     16, -107,   14, 24,  1,  0 }, {     16, -108,   15, 24,  0,  0 },
    {     16, -109,   15, 24,  0,  0 }, {     16, -110,   15, 24,  0,  0 }, {     16, -111,   15, 24,  0,  0 }, {     16, -112,   15, 24,  0,  0 }, {     16, -113,   15, 24,  0,  0 },
    {     16, -114,   15, 24,  0,  0 }, {     16, -115,   16, 24,  0,  0 }, {     16, -116,   16, 24,  0,  0 }, {     16, -117,   16, 24,  0,  0 }, {     16, -118,   16, 24,  0,  0 },
    {     16, -119,   16, 24,  0,  0 }, {     16, -120,   16, 24,  0,  0 }, {     16, -121,   16, 24,  0,  0 }, {     16, -122,   16, 24,  0,  0 }, {     16, -123,   16, 24,  0,  0 },
    {     16, -124,   16, 24,  0,  0 }, {     16, -125,   16, 24,  0,  0 }, {     16, -126,   16, 24,  0,  0 }, {     16, -127,   16, 24,  0,  0 }, {     16, -128,   16, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96D4AE, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     21,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     14,   16,    1,  0,  0,  0 }, {     13,   16,    1,  0,  1,  0 }, {     12,   16,    1,  0,  1,  0 },
    {     11,   16,    1,  0,  1,  0 }, {     10,   16,    1,  0,  1,  0 }, {      9,   16,    1,  0,  1,  0 }, {      8,   16,    2,  0,  1,  0 }, {      7,   16,    2,  0,  1,  0 },
    {      6,   16,    2,  0,  1,  0 }, {      5,   16,    2,  0,  1,  0 }, {      4,   16,    3,  0,  1,  0 }, {      3,   16,    3,  0,  1,  0 }, {      2,   16,    3,  0,  1,  0 },
    {      1,   16,    3,  0,  1,  0 }, {      0,   16,    4,  0,  1,  0 }, {     -1,   16,    4,  0,  1,  0 }, {     -2,   16,    4,  0,  1,  0 }, {     -3,   16,    4,  0,  1,  0 },
    {     -4,   16,    5,  0,  1,  0 }, {     -5,   16,    5,  0,  1,  0 }, {     -6,   16,    6,  0,  1,  0 }, {     -7,   16,    6,  0,  1,  0 }, {     -8,   16,    6,  0,  1,  0 },
    {     -9,   16,    6,  0,  1,  0 }, {    -10,   16,    7,  0,  2,  0 }, {    -11,   16,    7,  0,  2,  0 }, {    -12,   16,    7,  0,  2,  0 }, {    -13,   16,    8,  0,  2,  0 },
    {    -14,   16,    8,  0,  2,  0 }, {    -15,   16,    9,  0,  2,  0 }, {    -16,   16,    9,  0,  2,  0 }, {    -17,   16,    9,  0,  2,  0 }, {    -18,   16,   10,  0,  2,  0 },
    {    -19,   16,   10,  0,  2,  0 }, {    -20,   16,   11,  0,  2,  0 }, {    -21,   16,   12,  0,  2,  0 }, {    -22,   16,   12,  0,  2,  0 }, {    -23,   16,   12,  0,  2,  0 },
    {    -24,   16,   12,  0,  2,  0 }, {    -25,   16,   13,  0,  2,  0 }, {    -26,   16,   14,  0,  2,  0 }, {    -27,   16,   14,  0,  2,  0 }, {    -28,   16,   14,  0,  2,  0 },
    {    -29,   16,   15,  0,  2,  0 }, {    -30,   16,   16,  0,  2,  0 }, {    -31,   16,   16,  0,  2,  0 }, {    -32,   16,   17,  0,  2,  0 }, {    -33,   16,   18,  0,  2,  0 },
    {    -34,   16,   18,  0,  2,  0 }, {    -35,   16,   18,  0,  2,  0 }, {    -36,   16,   19,  0,  2,  0 }, {    -37,   16,   20,  0,  2,  0 }, {    -38,   16,   20,  0,  2,  0 },
    {    -39,   16,   21,  0,  2,  0 }, {    -40,   16,   22,  0,  3,  0 }, {    -41,   16,   22,  0,  3,  0 }, {    -42,   16,   23,  0,  3,  0 }, {    -43,   16,   24,  0,  3,  0 },
    {    -44,   16,   25,  0,  3,  0 }, {    -45,   16,   26,  0,  3,  0 }, {    -46,   16,   26,  0,  3,  0 }, {    -47,   16,   27,  0,  3,  0 }, {    -48,   16,   28,  0,  3,  0 },
    {    -49,   16,   28,  0,  3,  0 }, {    -50,   16,   29,  0,  3,  0 }, {    -51,   16,   30,  0,  3,  0 }, {    -52,   16,   30,  0,  3,  0 }, {    -53,   16,   31,  0,  3,  0 },
    {    -54,   16,   32,  0,  3,  0 }, {    -55,   16,   33,  0,  3,  0 }, {    -56,   16,   34,  0,  3,  0 }, {    -57,   16,   35,  0,  3,  0 }, {    -58,   16,   36,  0,  3,  0 },
    {    -59,   16,   37,  0,  3,  0 }, {    -60,   16,   38,  0,  3,  0 }, {    -61,   16,   39,  0,  3,  0 }, {    -62,   16,   40,  0,  3,  0 }, {    -63,   16,   41,  0,  3,  0 },
    {    -64,   16,   42,  0,  3,  0 }, {    -65,   16,   43,  0,  3,  0 }, {    -66,   16,   44,  0,  3,  0 }, {    -67,   16,   45,  0,  3,  0 }, {    -68,   16,   46,  0,  3,  0 },
    {    -69,   16,   47,  0,  3,  0 }, {    -70,   16,   48,  0,  3,  0 }, {    -71,   16,   49,  0,  3,  0 }, {    -72,   16,   50,  0,  3,  0 }, {    -73,   16,   51,  0,  3,  0 },
    {    -73,   16,   52,  0,  3,  0 }, {    -74,   16,   53,  0,  4,  0 }, {    -74,   16,   54,  0,  4,  0 }, {    -75,   16,   55,  0,  4,  0 }, {    -76,   16,   56,  0,  4,  0 },
    {    -77,   16,   57,  0,  4,  0 }, {    -78,   16,   58,  0,  4,  0 }, {    -79,   16,   59,  0,  4,  0 }, {    -79,   16,   60,  0,  4,  0 }, {    -80,   16,   61,  0,  4,  0 },
    {    -81,   16,   62,  0,  4,  0 }, {    -82,   16,   63,  0,  4,  0 }, {    -82,   16,   64,  0,  4,  0 }, {    -83,   16,   65,  0,  4,  0 }, {    -84,   16,   66,  0,  4,  0 },
    {    -84,   16,   67,  0,  4,  0 }, {    -85,   16,   68,  0,  4,  0 }, {    -86,   16,   69,  0,  4,  0 }, {    -86,   16,   70,  0,  4,  0 }, {    -87,   16,   71,  0,  4,  0 },
    {    -88,   16,   72,  0,  4,  0 }, {    -88,   16,   73,  0,  4,  0 }, {    -89,   16,   74,  0,  4,  0 }, {    -89,   16,   75,  0,  4,  0 }, {    -90,   16,   76,  0,  4,  0 },
    {    -91,   16,   77,  0,  4,  0 }, {    -91,   16,   78,  0,  4,  0 }, {    -92,   16,   79,  0,  4,  0 }, {    -92,   16,   80,  0,  4,  0 }, {    -93,   16,   81,  0,  4,  0 },
    {    -93,   16,   82,  0,  4,  0 }, {    -94,   16,   83,  0,  4,  0 }, {    -94,   16,   84,  0,  4,  0 }, {    -95,   16,   85,  0,  4,  0 }, {    -96,   16,   86,  0,  4,  0 },
    {    -96,   16,   87,  0,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96D9A5, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   15,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   17,    1,  8,  0,  0 }, {     16,   18,    1,  8,  1,  0 }, {     16,   19,    1,  8,  1,  0 },
    {     16,   20,    1,  8,  1,  0 }, {     16,   21,    1,  8,  1,  0 }, {     16,   22,    1,  8,  1,  0 }, {     16,   23,    2,  8,  1,  0 }, {     16,   24,    2,  8,  1,  0 },
    {     16,   25,    2,  8,  1,  0 }, {     16,   26,    2,  8,  1,  0 }, {     16,   27,    3,  8,  1,  0 }, {     16,   28,    3,  8,  1,  0 }, {     16,   29,    3,  8,  1,  0 },
    {     16,   30,    3,  8,  1,  0 }, {     16,   31,    4,  8,  1,  0 }, {     16,   32,    4,  8,  1,  0 }, {     16,   33,    4,  8,  1,  0 }, {     16,   34,    4,  8,  1,  0 },
    {     16,   35,    5,  8,  1,  0 }, {     16,   36,    5,  8,  1,  0 }, {     16,   37,    6,  8,  1,  0 }, {     16,   38,    6,  8,  1,  0 }, {     16,   39,    6,  8,  1,  0 },
    {     16,   40,    6,  8,  1,  0 }, {     16,   41,    7,  8,  2,  0 }, {     16,   42,    7,  8,  2,  0 }, {     16,   43,    7,  8,  2,  0 }, {     16,   44,    8,  8,  2,  0 },
    {     16,   45,    8,  8,  2,  0 }, {     16,   46,    9,  8,  2,  0 }, {     16,   47,    9,  8,  2,  0 }, {     16,   48,    9,  8,  2,  0 }, {     16,   49,   10,  8,  2,  0 },
    {     16,   50,   10,  8,  2,  0 }, {     16,   51,   11,  8,  2,  0 }, {     16,   52,   12,  8,  2,  0 }, {     16,   53,   12,  8,  2,  0 }, {     16,   54,   12,  8,  2,  0 },
    {     16,   55,   12,  8,  2,  0 }, {     16,   56,   13,  8,  2,  0 }, {     16,   57,   14,  8,  2,  0 }, {     16,   58,   14,  8,  2,  0 }, {     16,   59,   14,  8,  2,  0 },
    {     16,   60,   15,  8,  2,  0 }, {     16,   61,   16,  8,  2,  0 }, {     16,   62,   16,  8,  2,  0 }, {     16,   63,   17,  8,  2,  0 }, {     16,   64,   18,  8,  2,  0 },
    {     16,   65,   18,  8,  2,  0 }, {     16,   66,   18,  8,  2,  0 }, {     16,   67,   19,  8,  2,  0 }, {     16,   68,   20,  8,  2,  0 }, {     16,   69,   20,  8,  2,  0 },
    {     16,   70,   21,  8,  2,  0 }, {     16,   71,   22,  8,  3,  0 }, {     16,   72,   22,  8,  3,  0 }, {     16,   73,   23,  8,  3,  0 }, {     16,   74,   24,  8,  3,  0 },
    {     16,   75,   25,  8,  3,  0 }, {     16,   76,   26,  8,  3,  0 }, {     16,   77,   26,  8,  3,  0 }, {     16,   78,   27,  8,  3,  0 }, {     16,   79,   28,  8,  3,  0 },
    {     16,   80,   28,  8,  3,  0 }, {     16,   81,   29,  8,  3,  0 }, {     16,   82,   30,  8,  3,  0 }, {     16,   83,   30,  8,  3,  0 }, {     16,   84,   31,  8,  3,  0 },
    {     16,   85,   32,  8,  3,  0 }, {     16,   86,   33,  8,  3,  0 }, {     16,   87,   34,  8,  3,  0 }, {     16,   88,   35,  8,  3,  0 }, {     16,   89,   36,  8,  3,  0 },
    {     16,   90,   37,  8,  3,  0 }, {     16,   91,   38,  8,  3,  0 }, {     16,   92,   39,  8,  3,  0 }, {     16,   93,   40,  8,  3,  0 }, {     16,   94,   41,  8,  3,  0 },
    {     16,   95,   42,  8,  3,  0 }, {     16,   96,   43,  8,  3,  0 }, {     16,   97,   44,  8,  3,  0 }, {     16,   98,   45,  8,  3,  0 }, {     16,   99,   46,  8,  3,  0 },
    {     16,  100,   47,  8,  3,  0 }, {     16,  101,   48,  8,  3,  0 }, {     16,  102,   49,  8,  3,  0 }, {     16,  103,   50,  8,  3,  0 }, {     16,  104,   51,  8,  3,  0 },
    {     16,  104,   52,  8,  3,  0 }, {     16,  105,   53,  8,  4,  0 }, {     16,  105,   54,  8,  4,  0 }, {     16,  106,   55,  8,  4,  0 }, {     16,  107,   56,  8,  4,  0 },
    {     16,  108,   57,  8,  4,  0 }, {     16,  109,   58,  8,  4,  0 }, {     16,  110,   59,  8,  4,  0 }, {     16,  110,   60,  8,  4,  0 }, {     16,  111,   61,  8,  4,  0 },
    {     16,  112,   62,  8,  4,  0 }, {     16,  113,   63,  8,  4,  0 }, {     16,  113,   64,  8,  4,  0 }, {     16,  114,   65,  8,  4,  0 }, {     16,  115,   66,  8,  4,  0 },
    {     16,  115,   67,  8,  4,  0 }, {     16,  116,   68,  8,  4,  0 }, {     16,  117,   69,  8,  4,  0 }, {     16,  117,   70,  8,  4,  0 }, {     16,  118,   71,  8,  4,  0 },
    {     16,  119,   72,  8,  4,  0 }, {     16,  119,   73,  8,  4,  0 }, {     16,  120,   74,  8,  4,  0 }, {     16,  120,   75,  8,  4,  0 }, {     16,  121,   76,  8,  4,  0 },
    {     16,  122,   77,  8,  4,  0 }, {     16,  122,   78,  8,  4,  0 }, {     16,  123,   79,  8,  4,  0 }, {     16,  123,   80,  8,  4,  0 }, {     16,  124,   81,  8,  4,  0 },
    {     16,  124,   82,  8,  4,  0 }, {     16,  125,   83,  8,  4,  0 }, {     16,  125,   84,  8,  4,  0 }, {     16,  126,   85,  8,  4,  0 }, {     16,  127,   86,  8,  4,  0 },
    {     16,  127,   87,  8,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96DE9C, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 }, {      9,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     13,   16,    0, 16,  0,  0 }, {     14,   16,    0, 16,  0,  0 },
    {     15,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     17,   16,    1, 16,  0,  0 }, {     18,   16,    1, 16,  1,  0 }, {     19,   16,    1, 16,  1,  0 },
    {     20,   16,    1, 16,  1,  0 }, {     21,   16,    1, 16,  1,  0 }, {     22,   16,    1, 16,  1,  0 }, {     23,   16,    2, 16,  1,  0 }, {     24,   16,    2, 16,  1,  0 },
    {     25,   16,    2, 16,  1,  0 }, {     26,   16,    2, 16,  1,  0 }, {     27,   16,    3, 16,  1,  0 }, {     28,   16,    3, 16,  1,  0 }, {     29,   16,    3, 16,  1,  0 },
    {     30,   16,    3, 16,  1,  0 }, {     31,   16,    4, 16,  1,  0 }, {     32,   16,    4, 16,  1,  0 }, {     33,   16,    4, 16,  1,  0 }, {     34,   16,    4, 16,  1,  0 },
    {     35,   16,    5, 16,  1,  0 }, {     36,   16,    5, 16,  1,  0 }, {     37,   16,    6, 16,  1,  0 }, {     38,   16,    6, 16,  1,  0 }, {     39,   16,    6, 16,  1,  0 },
    {     40,   16,    6, 16,  1,  0 }, {     41,   16,    7, 16,  2,  0 }, {     42,   16,    7, 16,  2,  0 }, {     43,   16,    7, 16,  2,  0 }, {     44,   16,    8, 16,  2,  0 },
    {     45,   16,    8, 16,  2,  0 }, {     46,   16,    9, 16,  2,  0 }, {     47,   16,    9, 16,  2,  0 }, {     48,   16,    9, 16,  2,  0 }, {     49,   16,   10, 16,  2,  0 },
    {     50,   16,   10, 16,  2,  0 }, {     51,   16,   11, 16,  2,  0 }, {     52,   16,   12, 16,  2,  0 }, {     53,   16,   12, 16,  2,  0 }, {     54,   16,   12, 16,  2,  0 },
    {     55,   16,   12, 16,  2,  0 }, {     56,   16,   13, 16,  2,  0 }, {     57,   16,   14, 16,  2,  0 }, {     58,   16,   14, 16,  2,  0 }, {     59,   16,   14, 16,  2,  0 },
    {     60,   16,   15, 16,  2,  0 }, {     61,   16,   16, 16,  2,  0 }, {     62,   16,   16, 16,  2,  0 }, {     63,   16,   17, 16,  2,  0 }, {     64,   16,   18, 16,  2,  0 },
    {     65,   16,   18, 16,  2,  0 }, {     66,   16,   18, 16,  2,  0 }, {     67,   16,   19, 16,  2,  0 }, {     68,   16,   20, 16,  2,  0 }, {     69,   16,   20, 16,  2,  0 },
    {     70,   16,   21, 16,  2,  0 }, {     71,   16,   22, 16,  3,  0 }, {     72,   16,   22, 16,  3,  0 }, {     73,   16,   23, 16,  3,  0 }, {     74,   16,   24, 16,  3,  0 },
    {     75,   16,   25, 16,  3,  0 }, {     76,   16,   26, 16,  3,  0 }, {     77,   16,   26, 16,  3,  0 }, {     78,   16,   27, 16,  3,  0 }, {     79,   16,   28, 16,  3,  0 },
    {     80,   16,   28, 16,  3,  0 }, {     81,   16,   29, 16,  3,  0 }, {     82,   16,   30, 16,  3,  0 }, {     83,   16,   30, 16,  3,  0 }, {     84,   16,   31, 16,  3,  0 },
    {     85,   16,   32, 16,  3,  0 }, {     86,   16,   33, 16,  3,  0 }, {     87,   16,   34, 16,  3,  0 }, {     88,   16,   35, 16,  3,  0 }, {     89,   16,   36, 16,  3,  0 },
    {     90,   16,   37, 16,  3,  0 }, {     91,   16,   38, 16,  3,  0 }, {     92,   16,   39, 16,  3,  0 }, {     93,   16,   40, 16,  3,  0 }, {     94,   16,   41, 16,  3,  0 },
    {     95,   16,   42, 16,  3,  0 }, {     96,   16,   43, 16,  3,  0 }, {     97,   16,   44, 16,  3,  0 }, {     98,   16,   45, 16,  3,  0 }, {     99,   16,   46, 16,  3,  0 },
    {    100,   16,   47, 16,  3,  0 }, {    101,   16,   48, 16,  3,  0 }, {    102,   16,   49, 16,  3,  0 }, {    103,   16,   50, 16,  3,  0 }, {    104,   16,   51, 16,  3,  0 },
    {    104,   16,   52, 16,  3,  0 }, {    105,   16,   53, 16,  4,  0 }, {    105,   16,   54, 16,  4,  0 }, {    106,   16,   55, 16,  4,  0 }, {    107,   16,   56, 16,  4,  0 },
    {    108,   16,   57, 16,  4,  0 }, {    109,   16,   58, 16,  4,  0 }, {    110,   16,   59, 16,  4,  0 }, {    110,   16,   60, 16,  4,  0 }, {    111,   16,   61, 16,  4,  0 },
    {    112,   16,   62, 16,  4,  0 }, {    113,   16,   63, 16,  4,  0 }, {    113,   16,   64, 16,  4,  0 }, {    114,   16,   65, 16,  4,  0 }, {    115,   16,   66, 16,  4,  0 },
    {    115,   16,   67, 16,  4,  0 }, {    116,   16,   68, 16,  4,  0 }, {    117,   16,   69, 16,  4,  0 }, {    117,   16,   70, 16,  4,  0 }, {    118,   16,   71, 16,  4,  0 },
    {    119,   16,   72, 16,  4,  0 }, {    119,   16,   73, 16,  4,  0 }, {    120,   16,   74, 16,  4,  0 }, {    120,   16,   75, 16,  4,  0 }, {    121,   16,   76, 16,  4,  0 },
    {    122,   16,   77, 16,  4,  0 }, {    122,   16,   78, 16,  4,  0 }, {    123,   16,   79, 16,  4,  0 }, {    123,   16,   80, 16,  4,  0 }, {    124,   16,   81, 16,  4,  0 },
    {    124,   16,   82, 16,  4,  0 }, {    125,   16,   83, 16,  4,  0 }, {    125,   16,   84, 16,  4,  0 }, {    126,   16,   85, 16,  4,  0 }, {    127,   16,   86, 16,  4,  0 },
    {    127,   16,   87, 16,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96E393, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   21,    0, 24,  0,  0 }, {     16,   20,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 }, {     16,   17,    0, 24,  0,  0 },
    {     16,   16,    0, 24,  0,  0 }, {     16,   15,    0, 24,  0,  0 }, {     16,   14,    1, 24,  0,  0 }, {     16,   13,    1, 24,  1,  0 }, {     16,   12,    1, 24,  1,  0 },
    {     16,   11,    1, 24,  1,  0 }, {     16,   10,    1, 24,  1,  0 }, {     16,    9,    1, 24,  1,  0 }, {     16,    8,    2, 24,  1,  0 }, {     16,    7,    2, 24,  1,  0 },
    {     16,    6,    2, 24,  1,  0 }, {     16,    5,    2, 24,  1,  0 }, {     16,    4,    3, 24,  1,  0 }, {     16,    3,    3, 24,  1,  0 }, {     16,    2,    3, 24,  1,  0 },
    {     16,    1,    3, 24,  1,  0 }, {     16,    0,    4, 24,  1,  0 }, {     16,   -1,    4, 24,  1,  0 }, {     16,   -2,    4, 24,  1,  0 }, {     16,   -3,    4, 24,  1,  0 },
    {     16,   -4,    5, 24,  1,  0 }, {     16,   -5,    5, 24,  1,  0 }, {     16,   -6,    6, 24,  1,  0 }, {     16,   -7,    6, 24,  1,  0 }, {     16,   -8,    6, 24,  1,  0 },
    {     16,   -9,    6, 24,  1,  0 }, {     16,  -10,    7, 24,  2,  0 }, {     16,  -11,    7, 24,  2,  0 }, {     16,  -12,    7, 24,  2,  0 }, {     16,  -13,    8, 24,  2,  0 },
    {     16,  -14,    8, 24,  2,  0 }, {     16,  -15,    9, 24,  2,  0 }, {     16,  -16,    9, 24,  2,  0 }, {     16,  -17,    9, 24,  2,  0 }, {     16,  -18,   10, 24,  2,  0 },
    {     16,  -19,   10, 24,  2,  0 }, {     16,  -20,   11, 24,  2,  0 }, {     16,  -21,   12, 24,  2,  0 }, {     16,  -22,   12, 24,  2,  0 }, {     16,  -23,   12, 24,  2,  0 },
    {     16,  -24,   12, 24,  2,  0 }, {     16,  -25,   13, 24,  2,  0 }, {     16,  -26,   14, 24,  2,  0 }, {     16,  -27,   14, 24,  2,  0 }, {     16,  -28,   14, 24,  2,  0 },
    {     16,  -29,   15, 24,  2,  0 }, {     16,  -30,   16, 24,  2,  0 }, {     16,  -31,   16, 24,  2,  0 }, {     16,  -32,   17, 24,  2,  0 }, {     16,  -33,   18, 24,  2,  0 },
    {     16,  -34,   18, 24,  2,  0 }, {     16,  -35,   18, 24,  2,  0 }, {     16,  -36,   19, 24,  2,  0 }, {     16,  -37,   20, 24,  2,  0 }, {     16,  -38,   20, 24,  2,  0 },
    {     16,  -39,   21, 24,  2,  0 }, {     16,  -40,   22, 24,  3,  0 }, {     16,  -41,   22, 24,  3,  0 }, {     16,  -42,   23, 24,  3,  0 }, {     16,  -43,   24, 24,  3,  0 },
    {     16,  -44,   25, 24,  3,  0 }, {     16,  -45,   26, 24,  3,  0 }, {     16,  -46,   26, 24,  3,  0 }, {     16,  -47,   27, 24,  3,  0 }, {     16,  -48,   28, 24,  3,  0 },
    {     16,  -49,   28, 24,  3,  0 }, {     16,  -50,   29, 24,  3,  0 }, {     16,  -51,   30, 24,  3,  0 }, {     16,  -52,   30, 24,  3,  0 }, {     16,  -53,   31, 24,  3,  0 },
    {     16,  -54,   32, 24,  3,  0 }, {     16,  -55,   33, 24,  3,  0 }, {     16,  -56,   34, 24,  3,  0 }, {     16,  -57,   35, 24,  3,  0 }, {     16,  -58,   36, 24,  3,  0 },
    {     16,  -59,   37, 24,  3,  0 }, {     16,  -60,   38, 24,  3,  0 }, {     16,  -61,   39, 24,  3,  0 }, {     16,  -62,   40, 24,  3,  0 }, {     16,  -63,   41, 24,  3,  0 },
    {     16,  -64,   42, 24,  3,  0 }, {     16,  -65,   43, 24,  3,  0 }, {     16,  -66,   44, 24,  3,  0 }, {     16,  -67,   45, 24,  3,  0 }, {     16,  -68,   46, 24,  3,  0 },
    {     16,  -69,   47, 24,  3,  0 }, {     16,  -70,   48, 24,  3,  0 }, {     16,  -71,   49, 24,  3,  0 }, {     16,  -72,   50, 24,  3,  0 }, {     16,  -73,   51, 24,  3,  0 },
    {     16,  -73,   52, 24,  3,  0 }, {     16,  -74,   53, 24,  4,  0 }, {     16,  -74,   54, 24,  4,  0 }, {     16,  -75,   55, 24,  4,  0 }, {     16,  -76,   56, 24,  4,  0 },
    {     16,  -77,   57, 24,  4,  0 }, {     16,  -78,   58, 24,  4,  0 }, {     16,  -79,   59, 24,  4,  0 }, {     16,  -79,   60, 24,  4,  0 }, {     16,  -80,   61, 24,  4,  0 },
    {     16,  -81,   62, 24,  4,  0 }, {     16,  -82,   63, 24,  4,  0 }, {     16,  -82,   64, 24,  4,  0 }, {     16,  -83,   65, 24,  4,  0 }, {     16,  -84,   66, 24,  4,  0 },
    {     16,  -84,   67, 24,  4,  0 }, {     16,  -85,   68, 24,  4,  0 }, {     16,  -86,   69, 24,  4,  0 }, {     16,  -86,   70, 24,  4,  0 }, {     16,  -87,   71, 24,  4,  0 },
    {     16,  -88,   72, 24,  4,  0 }, {     16,  -88,   73, 24,  4,  0 }, {     16,  -89,   74, 24,  4,  0 }, {     16,  -89,   75, 24,  4,  0 }, {     16,  -90,   76, 24,  4,  0 },
    {     16,  -91,   77, 24,  4,  0 }, {     16,  -91,   78, 24,  4,  0 }, {     16,  -92,   79, 24,  4,  0 }, {     16,  -92,   80, 24,  4,  0 }, {     16,  -93,   81, 24,  4,  0 },
    {     16,  -93,   82, 24,  4,  0 }, {     16,  -94,   83, 24,  4,  0 }, {     16,  -94,   84, 24,  4,  0 }, {     16,  -95,   85, 24,  4,  0 }, {     16,  -96,   86, 24,  4,  0 },
    {     16,  -96,   87, 24,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96E88A, {
    {     31,   16,    0,  0,  4,  0 }, {     31,   16,    1,  0,  4,  0 }, {     30,   16,    2,  0,  4,  0 }, {     29,   16,    3,  0,  4,  0 }, {     29,   16,    4,  0,  4,  0 },
    {     28,   16,    5,  0,  4,  0 }, {     28,   16,    6,  0,  4,  0 }, {     27,   16,    7,  0,  4,  0 }, {     27,   16,    8,  0,  4,  0 }, {     26,   16,    9,  0,  4,  0 },
    {     26,   16,   10,  0,  4,  0 }, {     25,   16,   11,  0,  4,  0 }, {     24,   16,   12,  0,  4,  0 }, {     24,   16,   13,  0,  4,  0 }, {     23,   16,   14,  0,  4,  0 },
    {     23,   16,   15,  0,  4,  0 }, {     22,   16,   16,  0,  4,  0 }, {     21,   16,   17,  0,  4,  0 }, {     21,   16,   18,  0,  4,  0 }, {     20,   16,   19,  0,  4,  0 },
    {     19,   16,   20,  0,  4,  0 }, {     19,   16,   21,  0,  4,  0 }, {     18,   16,   22,  0,  4,  0 }, {     17,   16,   23,  0,  4,  0 }, {     17,   16,   24,  0,  4,  0 },
    {     16,   16,   25,  0,  4,  0 }, {     15,   16,   26,  0,  4,  0 }, {     14,   16,   27,  0,  4,  0 }, {     14,   16,   28,  0,  4,  0 }, {     13,   16,   29,  0,  4,  0 },
    {     12,   16,   30,  0,  4,  0 }, {     11,   16,   31,  0,  4,  0 }, {     10,   16,   32,  0,  4,  0 }, {      9,   16,   33,  0,  4,  0 }, {      9,   16,   34,  0,  4,  0 },
    {      8,   16,   35,  0,  3,  0 }, {      8,   16,   36,  0,  3,  0 }, {      7,   16,   37,  0,  3,  0 }, {      6,   16,   38,  0,  3,  0 }, {      5,   16,   39,  0,  3,  0 },
    {      4,   16,   40,  0,  3,  0 }, {      3,   16,   41,  0,  3,  0 }, {      2,   16,   42,  0,  3,  0 }, {      1,   16,   43,  0,  3,  0 }, {      0,   16,   44,  0,  3,  0 },
    {     -1,   16,   45,  0,  3,  0 }, {     -2,   16,   46,  0,  3,  0 }, {     -3,   16,   47,  0,  3,  0 }, {     -4,   16,   48,  0,  3,  0 }, {     -5,   16,   49,  0,  3,  0 },
    {     -6,   16,   50,  0,  3,  0 }, {     -7,   16,   51,  0,  3,  0 }, {     -8,   16,   52,  0,  3,  0 }, {     -9,   16,   53,  0,  3,  0 }, {    -10,   16,   54,  0,  3,  0 },
    {    -11,   16,   55,  0,  3,  0 }, {    -12,   16,   56,  0,  3,  0 }, {    -13,   16,   57,  0,  3,  0 }, {    -14,   16,   57,  0,  3,  0 }, {    -15,   16,   58,  0,  3,  0 },
    {    -16,   16,   59,  0,  3,  0 }, {    -17,   16,   59,  0,  3,  0 }, {    -18,   16,   60,  0,  3,  0 }, {    -19,   16,   61,  0,  3,  0 }, {    -20,   16,   61,  0,  3,  0 },
    {    -21,   16,   62,  0,  3,  0 }, {    -22,   16,   63,  0,  3,  0 }, {    -23,   16,   64,  0,  3,  0 }, {    -24,   16,   65,  0,  3,  0 }, {    -25,   16,   65,  0,  3,  0 },
    {    -26,   16,   66,  0,  2,  0 }, {    -27,   16,   67,  0,  2,  0 }, {    -28,   16,   67,  0,  2,  0 }, {    -29,   16,   68,  0,  2,  0 }, {    -30,   16,   69,  0,  2,  0 },
    {    -31,   16,   69,  0,  2,  0 }, {    -32,   16,   69,  0,  2,  0 }, {    -33,   16,   70,  0,  2,  0 }, {    -34,   16,   71,  0,  2,  0 }, {    -35,   16,   71,  0,  2,  0 },
    {    -36,   16,   72,  0,  2,  0 }, {    -37,   16,   73,  0,  2,  0 }, {    -38,   16,   73,  0,  2,  0 }, {    -39,   16,   73,  0,  2,  0 }, {    -40,   16,   74,  0,  2,  0 },
    {    -41,   16,   75,  0,  2,  0 }, {    -42,   16,   75,  0,  2,  0 }, {    -43,   16,   75,  0,  2,  0 }, {    -44,   16,   75,  0,  2,  0 }, {    -45,   16,   76,  0,  2,  0 },
    {    -46,   16,   77,  0,  2,  0 }, {    -47,   16,   77,  0,  2,  0 }, {    -48,   16,   78,  0,  2,  0 }, {    -49,   16,   78,  0,  2,  0 }, {    -50,   16,   78,  0,  2,  0 },
    {    -51,   16,   79,  0,  2,  0 }, {    -52,   16,   79,  0,  2,  0 }, {    -53,   16,   80,  0,  2,  0 }, {    -54,   16,   80,  0,  2,  0 }, {    -55,   16,   80,  0,  2,  0 },
    {    -56,   16,   81,  0,  1,  0 }, {    -57,   16,   81,  0,  1,  0 }, {    -58,   16,   81,  0,  1,  0 }, {    -59,   16,   81,  0,  1,  0 }, {    -60,   16,   82,  0,  1,  0 },
    {    -61,   16,   82,  0,  1,  0 }, {    -62,   16,   83,  0,  1,  0 }, {    -63,   16,   83,  0,  1,  0 }, {    -64,   16,   83,  0,  1,  0 }, {    -65,   16,   83,  0,  1,  0 },
    {    -66,   16,   84,  0,  1,  0 }, {    -67,   16,   84,  0,  1,  0 }, {    -68,   16,   84,  0,  1,  0 }, {    -69,   16,   84,  0,  1,  0 }, {    -70,   16,   85,  0,  1,  0 },
    {    -71,   16,   85,  0,  1,  0 }, {    -72,   16,   85,  0,  1,  0 }, {    -73,   16,   85,  0,  1,  0 }, {    -74,   16,   86,  0,  1,  0 }, {    -75,   16,   86,  0,  1,  0 },
    {    -76,   16,   86,  0,  1,  0 }, {    -77,   16,   86,  0,  1,  0 }, {    -78,   16,   86,  0,  1,  0 }, {    -79,   16,   86,  0,  0,  0 }, {    -80,   16,   87,  0,  0,  0 },
    {    -81,   16,   87,  0,  0,  0 }, {    -82,   16,   87,  0,  0,  0 }, {    -83,   16,   87,  0,  0,  0 }, {    -84,   16,   87,  0,  0,  0 }, {    -85,   16,   87,  0,  0,  0 },
    {    -86,   16,   87,  0,  0,  0 }, {    -87,   16,   87,  0,  0,  0 }, {    -88,   16,   87,  0,  0,  0 }, {    -89,   16,   87,  0,  0,  0 }, {    -90,   16,   87,  0,  0,  0 },
    {    -91,   16,   87,  0,  0,  0 }, {    -92,   16,   87,  0,  0,  0 }, {    -93,   16,   87,  0,  0,  0 }, {    -94,   16,   87,  0,  0,  0 }, {    -95,   16,   87,  0,  0,  0 },
    {    -96,   16,   87,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96ED81, {
    {     16,    0,    0,  8,  4,  0 }, {     16,    0,    1,  8,  4,  0 }, {     16,    1,    2,  8,  4,  0 }, {     16,    2,    3,  8,  4,  0 }, {     16,    2,    4,  8,  4,  0 },
    {     16,    3,    5,  8,  4,  0 }, {     16,    3,    6,  8,  4,  0 }, {     16,    4,    7,  8,  4,  0 }, {     16,    4,    8,  8,  4,  0 }, {     16,    5,    9,  8,  4,  0 },
    {     16,    5,   10,  8,  4,  0 }, {     16,    6,   11,  8,  4,  0 }, {     16,    7,   12,  8,  4,  0 }, {     16,    7,   13,  8,  4,  0 }, {     16,    8,   14,  8,  4,  0 },
    {     16,    8,   15,  8,  4,  0 }, {     16,    9,   16,  8,  4,  0 }, {     16,   10,   17,  8,  4,  0 }, {     16,   10,   18,  8,  4,  0 }, {     16,   11,   19,  8,  4,  0 },
    {     16,   12,   20,  8,  4,  0 }, {     16,   12,   21,  8,  4,  0 }, {     16,   13,   22,  8,  4,  0 }, {     16,   14,   23,  8,  4,  0 }, {     16,   14,   24,  8,  4,  0 },
    {     16,   15,   25,  8,  4,  0 }, {     16,   16,   26,  8,  4,  0 }, {     16,   17,   27,  8,  4,  0 }, {     16,   17,   28,  8,  4,  0 }, {     16,   18,   29,  8,  4,  0 },
    {     16,   19,   30,  8,  4,  0 }, {     16,   20,   31,  8,  4,  0 }, {     16,   21,   32,  8,  4,  0 }, {     16,   22,   33,  8,  4,  0 }, {     16,   22,   34,  8,  4,  0 },
    {     16,   23,   35,  8,  3,  0 }, {     16,   23,   36,  8,  3,  0 }, {     16,   24,   37,  8,  3,  0 }, {     16,   25,   38,  8,  3,  0 }, {     16,   26,   39,  8,  3,  0 },
    {     16,   27,   40,  8,  3,  0 }, {     16,   28,   41,  8,  3,  0 }, {     16,   29,   42,  8,  3,  0 }, {     16,   30,   43,  8,  3,  0 }, {     16,   31,   44,  8,  3,  0 },
    {     16,   32,   45,  8,  3,  0 }, {     16,   33,   46,  8,  3,  0 }, {     16,   34,   47,  8,  3,  0 }, {     16,   35,   48,  8,  3,  0 }, {     16,   36,   49,  8,  3,  0 },
    {     16,   37,   50,  8,  3,  0 }, {     16,   38,   51,  8,  3,  0 }, {     16,   39,   52,  8,  3,  0 }, {     16,   40,   53,  8,  3,  0 }, {     16,   41,   54,  8,  3,  0 },
    {     16,   42,   55,  8,  3,  0 }, {     16,   43,   56,  8,  3,  0 }, {     16,   44,   57,  8,  3,  0 }, {     16,   45,   57,  8,  3,  0 }, {     16,   46,   58,  8,  3,  0 },
    {     16,   47,   59,  8,  3,  0 }, {     16,   48,   59,  8,  3,  0 }, {     16,   49,   60,  8,  3,  0 }, {     16,   50,   61,  8,  3,  0 }, {     16,   51,   61,  8,  3,  0 },
    {     16,   52,   62,  8,  3,  0 }, {     16,   53,   63,  8,  3,  0 }, {     16,   54,   64,  8,  3,  0 }, {     16,   55,   65,  8,  3,  0 }, {     16,   56,   65,  8,  3,  0 },
    {     16,   57,   66,  8,  2,  0 }, {     16,   58,   67,  8,  2,  0 }, {     16,   59,   67,  8,  2,  0 }, {     16,   60,   68,  8,  2,  0 }, {     16,   61,   69,  8,  2,  0 },
    {     16,   62,   69,  8,  2,  0 }, {     16,   63,   69,  8,  2,  0 }, {     16,   64,   70,  8,  2,  0 }, {     16,   65,   71,  8,  2,  0 }, {     16,   66,   71,  8,  2,  0 },
    {     16,   67,   72,  8,  2,  0 }, {     16,   68,   73,  8,  2,  0 }, {     16,   69,   73,  8,  2,  0 }, {     16,   70,   73,  8,  2,  0 }, {     16,   71,   74,  8,  2,  0 },
    {     16,   72,   75,  8,  2,  0 }, {     16,   73,   75,  8,  2,  0 }, {     16,   74,   75,  8,  2,  0 }, {     16,   75,   75,  8,  2,  0 }, {     16,   76,   76,  8,  2,  0 },
    {     16,   77,   77,  8,  2,  0 }, {     16,   78,   77,  8,  2,  0 }, {     16,   79,   78,  8,  2,  0 }, {     16,   80,   78,  8,  2,  0 }, {     16,   81,   78,  8,  2,  0 },
    {     16,   82,   79,  8,  2,  0 }, {     16,   83,   79,  8,  2,  0 }, {     16,   84,   80,  8,  2,  0 }, {     16,   85,   80,  8,  2,  0 }, {     16,   86,   80,  8,  2,  0 },
    {     16,   87,   81,  8,  1,  0 }, {     16,   88,   81,  8,  1,  0 }, {     16,   89,   81,  8,  1,  0 }, {     16,   90,   81,  8,  1,  0 }, {     16,   91,   82,  8,  1,  0 },
    {     16,   92,   82,  8,  1,  0 }, {     16,   93,   83,  8,  1,  0 }, {     16,   94,   83,  8,  1,  0 }, {     16,   95,   83,  8,  1,  0 }, {     16,   96,   83,  8,  1,  0 },
    {     16,   97,   84,  8,  1,  0 }, {     16,   98,   84,  8,  1,  0 }, {     16,   99,   84,  8,  1,  0 }, {     16,  100,   84,  8,  1,  0 }, {     16,  101,   85,  8,  1,  0 },
    {     16,  102,   85,  8,  1,  0 }, {     16,  103,   85,  8,  1,  0 }, {     16,  104,   85,  8,  1,  0 }, {     16,  105,   86,  8,  1,  0 }, {     16,  106,   86,  8,  1,  0 },
    {     16,  107,   86,  8,  1,  0 }, {     16,  108,   86,  8,  1,  0 }, {     16,  109,   86,  8,  1,  0 }, {     16,  110,   86,  8,  0,  0 }, {     16,  111,   87,  8,  0,  0 },
    {     16,  112,   87,  8,  0,  0 }, {     16,  113,   87,  8,  0,  0 }, {     16,  114,   87,  8,  0,  0 }, {     16,  115,   87,  8,  0,  0 }, {     16,  116,   87,  8,  0,  0 },
    {     16,  117,   87,  8,  0,  0 }, {     16,  118,   87,  8,  0,  0 }, {     16,  119,   87,  8,  0,  0 }, {     16,  120,   87,  8,  0,  0 }, {     16,  121,   87,  8,  0,  0 },
    {     16,  122,   87,  8,  0,  0 }, {     16,  123,   87,  8,  0,  0 }, {     16,  124,   87,  8,  0,  0 }, {     16,  125,   87,  8,  0,  0 }, {     16,  126,   87,  8,  0,  0 },
    {     16,  127,   87,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96F278, {
    {      0,   16,    0, 16,  4,  0 }, {      0,   16,    1, 16,  4,  0 }, {      1,   16,    2, 16,  4,  0 }, {      2,   16,    3, 16,  4,  0 }, {      2,   16,    4, 16,  4,  0 },
    {      3,   16,    5, 16,  4,  0 }, {      3,   16,    6, 16,  4,  0 }, {      4,   16,    7, 16,  4,  0 }, {      4,   16,    8, 16,  4,  0 }, {      5,   16,    9, 16,  4,  0 },
    {      5,   16,   10, 16,  4,  0 }, {      6,   16,   11, 16,  4,  0 }, {      7,   16,   12, 16,  4,  0 }, {      7,   16,   13, 16,  4,  0 }, {      8,   16,   14, 16,  4,  0 },
    {      8,   16,   15, 16,  4,  0 }, {      9,   16,   16, 16,  4,  0 }, {     10,   16,   17, 16,  4,  0 }, {     10,   16,   18, 16,  4,  0 }, {     11,   16,   19, 16,  4,  0 },
    {     12,   16,   20, 16,  4,  0 }, {     12,   16,   21, 16,  4,  0 }, {     13,   16,   22, 16,  4,  0 }, {     14,   16,   23, 16,  4,  0 }, {     14,   16,   24, 16,  4,  0 },
    {     15,   16,   25, 16,  4,  0 }, {     16,   16,   26, 16,  4,  0 }, {     17,   16,   27, 16,  4,  0 }, {     17,   16,   28, 16,  4,  0 }, {     18,   16,   29, 16,  4,  0 },
    {     19,   16,   30, 16,  4,  0 }, {     20,   16,   31, 16,  4,  0 }, {     21,   16,   32, 16,  4,  0 }, {     22,   16,   33, 16,  4,  0 }, {     22,   16,   34, 16,  4,  0 },
    {     23,   16,   35, 16,  3,  0 }, {     23,   16,   36, 16,  3,  0 }, {     24,   16,   37, 16,  3,  0 }, {     25,   16,   38, 16,  3,  0 }, {     26,   16,   39, 16,  3,  0 },
    {     27,   16,   40, 16,  3,  0 }, {     28,   16,   41, 16,  3,  0 }, {     29,   16,   42, 16,  3,  0 }, {     30,   16,   43, 16,  3,  0 }, {     31,   16,   44, 16,  3,  0 },
    {     32,   16,   45, 16,  3,  0 }, {     33,   16,   46, 16,  3,  0 }, {     34,   16,   47, 16,  3,  0 }, {     35,   16,   48, 16,  3,  0 }, {     36,   16,   49, 16,  3,  0 },
    {     37,   16,   50, 16,  3,  0 }, {     38,   16,   51, 16,  3,  0 }, {     39,   16,   52, 16,  3,  0 }, {     40,   16,   53, 16,  3,  0 }, {     41,   16,   54, 16,  3,  0 },
    {     42,   16,   55, 16,  3,  0 }, {     43,   16,   56, 16,  3,  0 }, {     44,   16,   57, 16,  3,  0 }, {     45,   16,   57, 16,  3,  0 }, {     46,   16,   58, 16,  3,  0 },
    {     47,   16,   59, 16,  3,  0 }, {     48,   16,   59, 16,  3,  0 }, {     49,   16,   60, 16,  3,  0 }, {     50,   16,   61, 16,  3,  0 }, {     51,   16,   61, 16,  3,  0 },
    {     52,   16,   62, 16,  3,  0 }, {     53,   16,   63, 16,  3,  0 }, {     54,   16,   64, 16,  3,  0 }, {     55,   16,   65, 16,  3,  0 }, {     56,   16,   65, 16,  3,  0 },
    {     57,   16,   66, 16,  2,  0 }, {     58,   16,   67, 16,  2,  0 }, {     59,   16,   67, 16,  2,  0 }, {     60,   16,   68, 16,  2,  0 }, {     61,   16,   69, 16,  2,  0 },
    {     62,   16,   69, 16,  2,  0 }, {     63,   16,   69, 16,  2,  0 }, {     64,   16,   70, 16,  2,  0 }, {     65,   16,   71, 16,  2,  0 }, {     66,   16,   71, 16,  2,  0 },
    {     67,   16,   72, 16,  2,  0 }, {     68,   16,   73, 16,  2,  0 }, {     69,   16,   73, 16,  2,  0 }, {     70,   16,   73, 16,  2,  0 }, {     71,   16,   74, 16,  2,  0 },
    {     72,   16,   75, 16,  2,  0 }, {     73,   16,   75, 16,  2,  0 }, {     74,   16,   75, 16,  2,  0 }, {     75,   16,   75, 16,  2,  0 }, {     76,   16,   76, 16,  2,  0 },
    {     77,   16,   77, 16,  2,  0 }, {     78,   16,   77, 16,  2,  0 }, {     79,   16,   78, 16,  2,  0 }, {     80,   16,   78, 16,  2,  0 }, {     81,   16,   78, 16,  2,  0 },
    {     82,   16,   79, 16,  2,  0 }, {     83,   16,   79, 16,  2,  0 }, {     84,   16,   80, 16,  2,  0 }, {     85,   16,   80, 16,  2,  0 }, {     86,   16,   80, 16,  2,  0 },
    {     87,   16,   81, 16,  1,  0 }, {     88,   16,   81, 16,  1,  0 }, {     89,   16,   81, 16,  1,  0 }, {     90,   16,   81, 16,  1,  0 }, {     91,   16,   82, 16,  1,  0 },
    {     92,   16,   82, 16,  1,  0 }, {     93,   16,   83, 16,  1,  0 }, {     94,   16,   83, 16,  1,  0 }, {     95,   16,   83, 16,  1,  0 }, {     96,   16,   83, 16,  1,  0 },
    {     97,   16,   84, 16,  1,  0 }, {     98,   16,   84, 16,  1,  0 }, {     99,   16,   84, 16,  1,  0 }, {    100,   16,   84, 16,  1,  0 }, {    101,   16,   85, 16,  1,  0 },
    {    102,   16,   85, 16,  1,  0 }, {    103,   16,   85, 16,  1,  0 }, {    104,   16,   85, 16,  1,  0 }, {    105,   16,   86, 16,  1,  0 }, {    106,   16,   86, 16,  1,  0 },
    {    107,   16,   86, 16,  1,  0 }, {    108,   16,   86, 16,  1,  0 }, {    109,   16,   86, 16,  1,  0 }, {    110,   16,   86, 16,  0,  0 }, {    111,   16,   87, 16,  0,  0 },
    {    112,   16,   87, 16,  0,  0 }, {    113,   16,   87, 16,  0,  0 }, {    114,   16,   87, 16,  0,  0 }, {    115,   16,   87, 16,  0,  0 }, {    116,   16,   87, 16,  0,  0 },
    {    117,   16,   87, 16,  0,  0 }, {    118,   16,   87, 16,  0,  0 }, {    119,   16,   87, 16,  0,  0 }, {    120,   16,   87, 16,  0,  0 }, {    121,   16,   87, 16,  0,  0 },
    {    122,   16,   87, 16,  0,  0 }, {    123,   16,   87, 16,  0,  0 }, {    124,   16,   87, 16,  0,  0 }, {    125,   16,   87, 16,  0,  0 }, {    126,   16,   87, 16,  0,  0 },
    {    127,   16,   87, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96F76F, {
    {     16,   31,    0, 24,  4,  0 }, {     16,   31,    1, 24,  4,  0 }, {     16,   30,    2, 24,  4,  0 }, {     16,   29,    3, 24,  4,  0 }, {     16,   29,    4, 24,  4,  0 },
    {     16,   28,    5, 24,  4,  0 }, {     16,   28,    6, 24,  4,  0 }, {     16,   27,    7, 24,  4,  0 }, {     16,   27,    8, 24,  4,  0 }, {     16,   26,    9, 24,  4,  0 },
    {     16,   26,   10, 24,  4,  0 }, {     16,   25,   11, 24,  4,  0 }, {     16,   24,   12, 24,  4,  0 }, {     16,   24,   13, 24,  4,  0 }, {     16,   23,   14, 24,  4,  0 },
    {     16,   23,   15, 24,  4,  0 }, {     16,   22,   16, 24,  4,  0 }, {     16,   21,   17, 24,  4,  0 }, {     16,   21,   18, 24,  4,  0 }, {     16,   20,   19, 24,  4,  0 },
    {     16,   19,   20, 24,  4,  0 }, {     16,   19,   21, 24,  4,  0 }, {     16,   18,   22, 24,  4,  0 }, {     16,   17,   23, 24,  4,  0 }, {     16,   17,   24, 24,  4,  0 },
    {     16,   16,   25, 24,  4,  0 }, {     16,   15,   26, 24,  4,  0 }, {     16,   14,   27, 24,  4,  0 }, {     16,   14,   28, 24,  4,  0 }, {     16,   13,   29, 24,  4,  0 },
    {     16,   12,   30, 24,  4,  0 }, {     16,   11,   31, 24,  4,  0 }, {     16,   10,   32, 24,  4,  0 }, {     16,    9,   33, 24,  4,  0 }, {     16,    9,   34, 24,  4,  0 },
    {     16,    8,   35, 24,  3,  0 }, {     16,    8,   36, 24,  3,  0 }, {     16,    7,   37, 24,  3,  0 }, {     16,    6,   38, 24,  3,  0 }, {     16,    5,   39, 24,  3,  0 },
    {     16,    4,   40, 24,  3,  0 }, {     16,    3,   41, 24,  3,  0 }, {     16,    2,   42, 24,  3,  0 }, {     16,    1,   43, 24,  3,  0 }, {     16,    0,   44, 24,  3,  0 },
    {     16,   -1,   45, 24,  3,  0 }, {     16,   -2,   46, 24,  3,  0 }, {     16,   -3,   47, 24,  3,  0 }, {     16,   -4,   48, 24,  3,  0 }, {     16,   -5,   49, 24,  3,  0 },
    {     16,   -6,   50, 24,  3,  0 }, {     16,   -7,   51, 24,  3,  0 }, {     16,   -8,   52, 24,  3,  0 }, {     16,   -9,   53, 24,  3,  0 }, {     16,  -10,   54, 24,  3,  0 },
    {     16,  -11,   55, 24,  3,  0 }, {     16,  -12,   56, 24,  3,  0 }, {     16,  -13,   57, 24,  3,  0 }, {     16,  -14,   57, 24,  3,  0 }, {     16,  -15,   58, 24,  3,  0 },
    {     16,  -16,   59, 24,  3,  0 }, {     16,  -17,   59, 24,  3,  0 }, {     16,  -18,   60, 24,  3,  0 }, {     16,  -19,   61, 24,  3,  0 }, {     16,  -20,   61, 24,  3,  0 },
    {     16,  -21,   62, 24,  3,  0 }, {     16,  -22,   63, 24,  3,  0 }, {     16,  -23,   64, 24,  3,  0 }, {     16,  -24,   65, 24,  3,  0 }, {     16,  -25,   65, 24,  3,  0 },
    {     16,  -26,   66, 24,  2,  0 }, {     16,  -27,   67, 24,  2,  0 }, {     16,  -28,   67, 24,  2,  0 }, {     16,  -29,   68, 24,  2,  0 }, {     16,  -30,   69, 24,  2,  0 },
    {     16,  -31,   69, 24,  2,  0 }, {     16,  -32,   69, 24,  2,  0 }, {     16,  -33,   70, 24,  2,  0 }, {     16,  -34,   71, 24,  2,  0 }, {     16,  -35,   71, 24,  2,  0 },
    {     16,  -36,   72, 24,  2,  0 }, {     16,  -37,   73, 24,  2,  0 }, {     16,  -38,   73, 24,  2,  0 }, {     16,  -39,   73, 24,  2,  0 }, {     16,  -40,   74, 24,  2,  0 },
    {     16,  -41,   75, 24,  2,  0 }, {     16,  -42,   75, 24,  2,  0 }, {     16,  -43,   75, 24,  2,  0 }, {     16,  -44,   75, 24,  2,  0 }, {     16,  -45,   76, 24,  2,  0 },
    {     16,  -46,   77, 24,  2,  0 }, {     16,  -47,   77, 24,  2,  0 }, {     16,  -48,   78, 24,  2,  0 }, {     16,  -49,   78, 24,  2,  0 }, {     16,  -50,   78, 24,  2,  0 },
    {     16,  -51,   79, 24,  2,  0 }, {     16,  -52,   79, 24,  2,  0 }, {     16,  -53,   80, 24,  2,  0 }, {     16,  -54,   80, 24,  2,  0 }, {     16,  -55,   80, 24,  2,  0 },
    {     16,  -56,   81, 24,  1,  0 }, {     16,  -57,   81, 24,  1,  0 }, {     16,  -58,   81, 24,  1,  0 }, {     16,  -59,   81, 24,  1,  0 }, {     16,  -60,   82, 24,  1,  0 },
    {     16,  -61,   82, 24,  1,  0 }, {     16,  -62,   83, 24,  1,  0 }, {     16,  -63,   83, 24,  1,  0 }, {     16,  -64,   83, 24,  1,  0 }, {     16,  -65,   83, 24,  1,  0 },
    {     16,  -66,   84, 24,  1,  0 }, {     16,  -67,   84, 24,  1,  0 }, {     16,  -68,   84, 24,  1,  0 }, {     16,  -69,   84, 24,  1,  0 }, {     16,  -70,   85, 24,  1,  0 },
    {     16,  -71,   85, 24,  1,  0 }, {     16,  -72,   85, 24,  1,  0 }, {     16,  -73,   85, 24,  1,  0 }, {     16,  -74,   86, 24,  1,  0 }, {     16,  -75,   86, 24,  1,  0 },
    {     16,  -76,   86, 24,  1,  0 }, {     16,  -77,   86, 24,  1,  0 }, {     16,  -78,   86, 24,  1,  0 }, {     16,  -79,   86, 24,  0,  0 }, {     16,  -80,   87, 24,  0,  0 },
    {     16,  -81,   87, 24,  0,  0 }, {     16,  -82,   87, 24,  0,  0 }, {     16,  -83,   87, 24,  0,  0 }, {     16,  -84,   87, 24,  0,  0 }, {     16,  -85,   87, 24,  0,  0 },
    {     16,  -86,   87, 24,  0,  0 }, {     16,  -87,   87, 24,  0,  0 }, {     16,  -88,   87, 24,  0,  0 }, {     16,  -89,   87, 24,  0,  0 }, {     16,  -90,   87, 24,  0,  0 },
    {     16,  -91,   87, 24,  0,  0 }, {     16,  -92,   87, 24,  0,  0 }, {     16,  -93,   87, 24,  0,  0 }, {     16,  -94,   87, 24,  0,  0 }, {     16,  -95,   87, 24,  0,  0 },
    {     16,  -96,   87, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_971042, {
    {     31,   16,   48,  0,  8,  0 }, {     31,   16,   47,  0,  8,  0 }, {     30,   16,   46,  0,  8,  0 }, {     29,   16,   45,  0,  8,  0 }, {     29,   16,   44,  0,  8,  0 },
    {     28,   16,   43,  0,  8,  0 }, {     28,   16,   42,  0,  8,  0 }, {     27,   16,   41,  0,  8,  0 }, {     27,   16,   40,  0,  8,  0 }, {     26,   16,   39,  0,  8,  0 },
    {     26,   16,   38,  0,  8,  0 }, {     25,   16,   37,  0,  8,  0 }, {     24,   16,   36,  0,  8,  0 }, {     24,   16,   35,  0,  8,  0 }, {     23,   16,   34,  0,  8,  0 },
    {     23,   16,   33,  0,  8,  0 }, {     22,   16,   32,  0,  8,  0 }, {     21,   16,   31,  0,  8,  0 }, {     21,   16,   30,  0,  8,  0 }, {     20,   16,   29,  0,  8,  0 },
    {     19,   16,   28,  0,  8,  0 }, {     19,   16,   27,  0,  8,  0 }, {     18,   16,   26,  0,  8,  0 }, {     17,   16,   25,  0,  8,  0 }, {     17,   16,   24,  0,  8,  0 },
    {     16,   16,   23,  0,  8,  0 }, {     15,   16,   22,  0,  8,  0 }, {     14,   16,   21,  0,  8,  0 }, {     14,   16,   20,  0,  8,  0 }, {     13,   16,   19,  0,  8,  0 },
    {     12,   16,   18,  0,  8,  0 }, {     11,   16,   17,  0,  8,  0 }, {     10,   16,   16,  0,  8,  0 }, {      9,   16,   15,  0,  8,  0 }, {      9,   16,   14,  0,  8,  0 },
    {      8,   16,   13,  0,  7,  0 }, {      8,   16,   12,  0,  7,  0 }, {      7,   16,   11,  0,  7,  0 }, {      6,   16,   10,  0,  7,  0 }, {      5,   16,    9,  0,  7,  0 },
    {      4,   16,    8,  0,  7,  0 }, {      3,   16,    7,  0,  7,  0 }, {      2,   16,    6,  0,  7,  0 }, {      1,   16,    5,  0,  7,  0 }, {      0,   16,    4,  0,  7,  0 },
    {     -1,   16,    3,  0,  7,  0 }, {     -2,   16,    2,  0,  7,  0 }, {     -3,   16,    1,  0,  7,  0 }, {     -4,   16,    0,  0,  7,  0 }, {     -5,   16,   -1,  0,  7,  0 },
    {     -6,   16,   -2,  0,  7,  0 }, {     -7,   16,   -3,  0,  7,  0 }, {     -8,   16,   -4,  0,  7,  0 }, {     -9,   16,   -5,  0,  7,  0 }, {    -10,   16,   -6,  0,  7,  0 },
    {    -11,   16,   -7,  0,  7,  0 }, {    -12,   16,   -8,  0,  7,  0 }, {    -13,   16,   -9,  0,  7,  0 }, {    -14,   16,   -9,  0,  7,  0 }, {    -15,   16,  -10,  0,  7,  0 },
    {    -16,   16,  -11,  0,  7,  0 }, {    -17,   16,  -11,  0,  7,  0 }, {    -18,   16,  -12,  0,  7,  0 }, {    -19,   16,  -13,  0,  7,  0 }, {    -20,   16,  -13,  0,  7,  0 },
    {    -21,   16,  -14,  0,  7,  0 }, {    -22,   16,  -15,  0,  7,  0 }, {    -23,   16,  -16,  0,  7,  0 }, {    -24,   16,  -17,  0,  7,  0 }, {    -25,   16,  -17,  0,  7,  0 },
    {    -26,   16,  -18,  0,  6,  0 }, {    -27,   16,  -19,  0,  6,  0 }, {    -28,   16,  -19,  0,  6,  0 }, {    -29,   16,  -20,  0,  6,  0 }, {    -30,   16,  -21,  0,  6,  0 },
    {    -31,   16,  -21,  0,  6,  0 }, {    -32,   16,  -21,  0,  6,  0 }, {    -33,   16,  -22,  0,  6,  0 }, {    -34,   16,  -23,  0,  6,  0 }, {    -35,   16,  -23,  0,  6,  0 },
    {    -36,   16,  -24,  0,  6,  0 }, {    -37,   16,  -25,  0,  6,  0 }, {    -38,   16,  -25,  0,  6,  0 }, {    -39,   16,  -25,  0,  6,  0 }, {    -40,   16,  -26,  0,  6,  0 },
    {    -41,   16,  -27,  0,  6,  0 }, {    -42,   16,  -27,  0,  6,  0 }, {    -43,   16,  -27,  0,  6,  0 }, {    -44,   16,  -27,  0,  6,  0 }, {    -45,   16,  -28,  0,  6,  0 },
    {    -46,   16,  -29,  0,  6,  0 }, {    -47,   16,  -29,  0,  6,  0 }, {    -48,   16,  -30,  0,  6,  0 }, {    -49,   16,  -30,  0,  6,  0 }, {    -50,   16,  -30,  0,  6,  0 },
    {    -51,   16,  -31,  0,  6,  0 }, {    -52,   16,  -31,  0,  6,  0 }, {    -53,   16,  -32,  0,  6,  0 }, {    -54,   16,  -32,  0,  6,  0 }, {    -55,   16,  -32,  0,  6,  0 },
    {    -56,   16,  -33,  0,  5,  0 }, {    -57,   16,  -33,  0,  5,  0 }, {    -58,   16,  -33,  0,  5,  0 }, {    -59,   16,  -33,  0,  5,  0 }, {    -60,   16,  -34,  0,  5,  0 },
    {    -61,   16,  -34,  0,  5,  0 }, {    -62,   16,  -35,  0,  5,  0 }, {    -63,   16,  -35,  0,  5,  0 }, {    -64,   16,  -35,  0,  5,  0 }, {    -65,   16,  -35,  0,  5,  0 },
    {    -66,   16,  -36,  0,  5,  0 }, {    -67,   16,  -36,  0,  5,  0 }, {    -68,   16,  -36,  0,  5,  0 }, {    -69,   16,  -36,  0,  5,  0 }, {    -70,   16,  -37,  0,  5,  0 },
    {    -71,   16,  -37,  0,  5,  0 }, {    -72,   16,  -37,  0,  5,  0 }, {    -73,   16,  -37,  0,  5,  0 }, {    -74,   16,  -38,  0,  5,  0 }, {    -75,   16,  -38,  0,  5,  0 },
    {    -76,   16,  -38,  0,  5,  0 }, {    -77,   16,  -38,  0,  5,  0 }, {    -78,   16,  -38,  0,  5,  0 }, {    -79,   16,  -38,  0,  0,  0 }, {    -80,   16,  -39,  0,  0,  0 },
    {    -81,   16,  -39,  0,  0,  0 }, {    -82,   16,  -39,  0,  0,  0 }, {    -83,   16,  -39,  0,  0,  0 }, {    -84,   16,  -39,  0,  0,  0 }, {    -85,   16,  -39,  0,  0,  0 },
    {    -86,   16,  -39,  0,  0,  0 }, {    -87,   16,  -39,  0,  0,  0 }, {    -88,   16,  -39,  0,  0,  0 }, {    -89,   16,  -39,  0,  0,  0 }, {    -90,   16,  -39,  0,  0,  0 },
    {    -91,   16,  -39,  0,  0,  0 }, {    -92,   16,  -39,  0,  0,  0 }, {    -93,   16,  -39,  0,  0,  0 }, {    -94,   16,  -39,  0,  0,  0 }, {    -95,   16,  -39,  0,  0,  0 },
    {    -96,   16,  -39,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_971539, {
    {     16,    0,   48,  8,  8,  0 }, {     16,    0,   47,  8,  8,  0 }, {     16,    1,   46,  8,  8,  0 }, {     16,    2,   45,  8,  8,  0 }, {     16,    2,   44,  8,  8,  0 },
    {     16,    3,   43,  8,  8,  0 }, {     16,    3,   42,  8,  8,  0 }, {     16,    4,   41,  8,  8,  0 }, {     16,    4,   40,  8,  8,  0 }, {     16,    5,   39,  8,  8,  0 },
    {     16,    5,   38,  8,  8,  0 }, {     16,    6,   37,  8,  8,  0 }, {     16,    7,   36,  8,  8,  0 }, {     16,    7,   35,  8,  8,  0 }, {     16,    8,   34,  8,  8,  0 },
    {     16,    8,   33,  8,  8,  0 }, {     16,    9,   32,  8,  8,  0 }, {     16,   10,   31,  8,  8,  0 }, {     16,   10,   30,  8,  8,  0 }, {     16,   11,   29,  8,  8,  0 },
    {     16,   12,   28,  8,  8,  0 }, {     16,   12,   27,  8,  8,  0 }, {     16,   13,   26,  8,  8,  0 }, {     16,   14,   25,  8,  8,  0 }, {     16,   14,   24,  8,  8,  0 },
    {     16,   15,   23,  8,  8,  0 }, {     16,   16,   22,  8,  8,  0 }, {     16,   17,   21,  8,  8,  0 }, {     16,   17,   20,  8,  8,  0 }, {     16,   18,   19,  8,  8,  0 },
    {     16,   19,   18,  8,  8,  0 }, {     16,   20,   17,  8,  8,  0 }, {     16,   21,   16,  8,  8,  0 }, {     16,   22,   15,  8,  8,  0 }, {     16,   22,   14,  8,  8,  0 },
    {     16,   23,   13,  8,  7,  0 }, {     16,   23,   12,  8,  7,  0 }, {     16,   24,   11,  8,  7,  0 }, {     16,   25,   10,  8,  7,  0 }, {     16,   26,    9,  8,  7,  0 },
    {     16,   27,    8,  8,  7,  0 }, {     16,   28,    7,  8,  7,  0 }, {     16,   29,    6,  8,  7,  0 }, {     16,   30,    5,  8,  7,  0 }, {     16,   31,    4,  8,  7,  0 },
    {     16,   32,    3,  8,  7,  0 }, {     16,   33,    2,  8,  7,  0 }, {     16,   34,    1,  8,  7,  0 }, {     16,   35,    0,  8,  7,  0 }, {     16,   36,   -1,  8,  7,  0 },
    {     16,   37,   -2,  8,  7,  0 }, {     16,   38,   -3,  8,  7,  0 }, {     16,   39,   -4,  8,  7,  0 }, {     16,   40,   -5,  8,  7,  0 }, {     16,   41,   -6,  8,  7,  0 },
    {     16,   42,   -7,  8,  7,  0 }, {     16,   43,   -8,  8,  7,  0 }, {     16,   44,   -9,  8,  7,  0 }, {     16,   45,   -9,  8,  7,  0 }, {     16,   46,  -10,  8,  7,  0 },
    {     16,   47,  -11,  8,  7,  0 }, {     16,   48,  -11,  8,  7,  0 }, {     16,   49,  -12,  8,  7,  0 }, {     16,   50,  -13,  8,  7,  0 }, {     16,   51,  -13,  8,  7,  0 },
    {     16,   52,  -14,  8,  7,  0 }, {     16,   53,  -15,  8,  7,  0 }, {     16,   54,  -16,  8,  7,  0 }, {     16,   55,  -17,  8,  7,  0 }, {     16,   56,  -17,  8,  7,  0 },
    {     16,   57,  -18,  8,  6,  0 }, {     16,   58,  -19,  8,  6,  0 }, {     16,   59,  -19,  8,  6,  0 }, {     16,   60,  -20,  8,  6,  0 }, {     16,   61,  -21,  8,  6,  0 },
    {     16,   62,  -21,  8,  6,  0 }, {     16,   63,  -21,  8,  6,  0 }, {     16,   64,  -22,  8,  6,  0 }, {     16,   65,  -23,  8,  6,  0 }, {     16,   66,  -23,  8,  6,  0 },
    {     16,   67,  -24,  8,  6,  0 }, {     16,   68,  -25,  8,  6,  0 }, {     16,   69,  -25,  8,  6,  0 }, {     16,   70,  -25,  8,  6,  0 }, {     16,   71,  -26,  8,  6,  0 },
    {     16,   72,  -27,  8,  6,  0 }, {     16,   73,  -27,  8,  6,  0 }, {     16,   74,  -27,  8,  6,  0 }, {     16,   75,  -27,  8,  6,  0 }, {     16,   76,  -28,  8,  6,  0 },
    {     16,   77,  -29,  8,  6,  0 }, {     16,   78,  -29,  8,  6,  0 }, {     16,   79,  -30,  8,  6,  0 }, {     16,   80,  -30,  8,  6,  0 }, {     16,   81,  -30,  8,  6,  0 },
    {     16,   82,  -31,  8,  6,  0 }, {     16,   83,  -31,  8,  6,  0 }, {     16,   84,  -32,  8,  6,  0 }, {     16,   85,  -32,  8,  6,  0 }, {     16,   86,  -32,  8,  6,  0 },
    {     16,   87,  -33,  8,  5,  0 }, {     16,   88,  -33,  8,  5,  0 }, {     16,   89,  -33,  8,  5,  0 }, {     16,   90,  -33,  8,  5,  0 }, {     16,   91,  -34,  8,  5,  0 },
    {     16,   92,  -34,  8,  5,  0 }, {     16,   93,  -35,  8,  5,  0 }, {     16,   94,  -35,  8,  5,  0 }, {     16,   95,  -35,  8,  5,  0 }, {     16,   96,  -35,  8,  5,  0 },
    {     16,   97,  -36,  8,  5,  0 }, {     16,   98,  -36,  8,  5,  0 }, {     16,   99,  -36,  8,  5,  0 }, {     16,  100,  -36,  8,  5,  0 }, {     16,  101,  -37,  8,  5,  0 },
    {     16,  102,  -37,  8,  5,  0 }, {     16,  103,  -37,  8,  5,  0 }, {     16,  104,  -37,  8,  5,  0 }, {     16,  105,  -38,  8,  5,  0 }, {     16,  106,  -38,  8,  5,  0 },
    {     16,  107,  -38,  8,  5,  0 }, {     16,  108,  -38,  8,  5,  0 }, {     16,  109,  -38,  8,  5,  0 }, {     16,  110,  -38,  8,  0,  0 }, {     16,  111,  -39,  8,  0,  0 },
    {     16,  112,  -39,  8,  0,  0 }, {     16,  113,  -39,  8,  0,  0 }, {     16,  114,  -39,  8,  0,  0 }, {     16,  115,  -39,  8,  0,  0 }, {     16,  116,  -39,  8,  0,  0 },
    {     16,  117,  -39,  8,  0,  0 }, {     16,  118,  -39,  8,  0,  0 }, {     16,  119,  -39,  8,  0,  0 }, {     16,  120,  -39,  8,  0,  0 }, {     16,  121,  -39,  8,  0,  0 },
    {     16,  122,  -39,  8,  0,  0 }, {     16,  123,  -39,  8,  0,  0 }, {     16,  124,  -39,  8,  0,  0 }, {     16,  125,  -39,  8,  0,  0 }, {     16,  126,  -39,  8,  0,  0 },
    {     16,  127,  -39,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_971A30, {
    {      0,   16,   48, 16,  8,  0 }, {      0,   16,   47, 16,  8,  0 }, {      1,   16,   46, 16,  8,  0 }, {      2,   16,   45, 16,  8,  0 }, {      2,   16,   44, 16,  8,  0 },
    {      3,   16,   43, 16,  8,  0 }, {      3,   16,   42, 16,  8,  0 }, {      4,   16,   41, 16,  8,  0 }, {      4,   16,   40, 16,  8,  0 }, {      5,   16,   39, 16,  8,  0 },
    {      5,   16,   38, 16,  8,  0 }, {      6,   16,   37, 16,  8,  0 }, {      7,   16,   36, 16,  8,  0 }, {      7,   16,   35, 16,  8,  0 }, {      8,   16,   34, 16,  8,  0 },
    {      8,   16,   33, 16,  8,  0 }, {      9,   16,   32, 16,  8,  0 }, {     10,   16,   31, 16,  8,  0 }, {     10,   16,   30, 16,  8,  0 }, {     11,   16,   29, 16,  8,  0 },
    {     12,   16,   28, 16,  8,  0 }, {     12,   16,   27, 16,  8,  0 }, {     13,   16,   26, 16,  8,  0 }, {     14,   16,   25, 16,  8,  0 }, {     14,   16,   24, 16,  8,  0 },
    {     15,   16,   23, 16,  8,  0 }, {     16,   16,   22, 16,  8,  0 }, {     17,   16,   21, 16,  8,  0 }, {     17,   16,   20, 16,  8,  0 }, {     18,   16,   19, 16,  8,  0 },
    {     19,   16,   18, 16,  8,  0 }, {     20,   16,   17, 16,  8,  0 }, {     21,   16,   16, 16,  8,  0 }, {     22,   16,   15, 16,  8,  0 }, {     22,   16,   14, 16,  8,  0 },
    {     23,   16,   13, 16,  7,  0 }, {     23,   16,   12, 16,  7,  0 }, {     24,   16,   11, 16,  7,  0 }, {     25,   16,   10, 16,  7,  0 }, {     26,   16,    9, 16,  7,  0 },
    {     27,   16,    8, 16,  7,  0 }, {     28,   16,    7, 16,  7,  0 }, {     29,   16,    6, 16,  7,  0 }, {     30,   16,    5, 16,  7,  0 }, {     31,   16,    4, 16,  7,  0 },
    {     32,   16,    3, 16,  7,  0 }, {     33,   16,    2, 16,  7,  0 }, {     34,   16,    1, 16,  7,  0 }, {     35,   16,    0, 16,  7,  0 }, {     36,   16,   -1, 16,  7,  0 },
    {     37,   16,   -2, 16,  7,  0 }, {     38,   16,   -3, 16,  7,  0 }, {     39,   16,   -4, 16,  7,  0 }, {     40,   16,   -5, 16,  7,  0 }, {     41,   16,   -6, 16,  7,  0 },
    {     42,   16,   -7, 16,  7,  0 }, {     43,   16,   -8, 16,  7,  0 }, {     44,   16,   -9, 16,  7,  0 }, {     45,   16,   -9, 16,  7,  0 }, {     46,   16,  -10, 16,  7,  0 },
    {     47,   16,  -11, 16,  7,  0 }, {     48,   16,  -11, 16,  7,  0 }, {     49,   16,  -12, 16,  7,  0 }, {     50,   16,  -13, 16,  7,  0 }, {     51,   16,  -13, 16,  7,  0 },
    {     52,   16,  -14, 16,  7,  0 }, {     53,   16,  -15, 16,  7,  0 }, {     54,   16,  -16, 16,  7,  0 }, {     55,   16,  -17, 16,  7,  0 }, {     56,   16,  -17, 16,  7,  0 },
    {     57,   16,  -18, 16,  6,  0 }, {     58,   16,  -19, 16,  6,  0 }, {     59,   16,  -19, 16,  6,  0 }, {     60,   16,  -20, 16,  6,  0 }, {     61,   16,  -21, 16,  6,  0 },
    {     62,   16,  -21, 16,  6,  0 }, {     63,   16,  -21, 16,  6,  0 }, {     64,   16,  -22, 16,  6,  0 }, {     65,   16,  -23, 16,  6,  0 }, {     66,   16,  -23, 16,  6,  0 },
    {     67,   16,  -24, 16,  6,  0 }, {     68,   16,  -25, 16,  6,  0 }, {     69,   16,  -25, 16,  6,  0 }, {     70,   16,  -25, 16,  6,  0 }, {     71,   16,  -26, 16,  6,  0 },
    {     72,   16,  -27, 16,  6,  0 }, {     73,   16,  -27, 16,  6,  0 }, {     74,   16,  -27, 16,  6,  0 }, {     75,   16,  -27, 16,  6,  0 }, {     76,   16,  -28, 16,  6,  0 },
    {     77,   16,  -29, 16,  6,  0 }, {     78,   16,  -29, 16,  6,  0 }, {     79,   16,  -30, 16,  6,  0 }, {     80,   16,  -30, 16,  6,  0 }, {     81,   16,  -30, 16,  6,  0 },
    {     82,   16,  -31, 16,  6,  0 }, {     83,   16,  -31, 16,  6,  0 }, {     84,   16,  -32, 16,  6,  0 }, {     85,   16,  -32, 16,  6,  0 }, {     86,   16,  -32, 16,  6,  0 },
    {     87,   16,  -33, 16,  5,  0 }, {     88,   16,  -33, 16,  5,  0 }, {     89,   16,  -33, 16,  5,  0 }, {     90,   16,  -33, 16,  5,  0 }, {     91,   16,  -34, 16,  5,  0 },
    {     92,   16,  -34, 16,  5,  0 }, {     93,   16,  -35, 16,  5,  0 }, {     94,   16,  -35, 16,  5,  0 }, {     95,   16,  -35, 16,  5,  0 }, {     96,   16,  -35, 16,  5,  0 },
    {     97,   16,  -36, 16,  5,  0 }, {     98,   16,  -36, 16,  5,  0 }, {     99,   16,  -36, 16,  5,  0 }, {    100,   16,  -36, 16,  5,  0 }, {    101,   16,  -37, 16,  5,  0 },
    {    102,   16,  -37, 16,  5,  0 }, {    103,   16,  -37, 16,  5,  0 }, {    104,   16,  -37, 16,  5,  0 }, {    105,   16,  -38, 16,  5,  0 }, {    106,   16,  -38, 16,  5,  0 },
    {    107,   16,  -38, 16,  5,  0 }, {    108,   16,  -38, 16,  5,  0 }, {    109,   16,  -38, 16,  5,  0 }, {    110,   16,  -38, 16,  0,  0 }, {    111,   16,  -39, 16,  0,  0 },
    {    112,   16,  -39, 16,  0,  0 }, {    113,   16,  -39, 16,  0,  0 }, {    114,   16,  -39, 16,  0,  0 }, {    115,   16,  -39, 16,  0,  0 }, {    116,   16,  -39, 16,  0,  0 },
    {    117,   16,  -39, 16,  0,  0 }, {    118,   16,  -39, 16,  0,  0 }, {    119,   16,  -39, 16,  0,  0 }, {    120,   16,  -39, 16,  0,  0 }, {    121,   16,  -39, 16,  0,  0 },
    {    122,   16,  -39, 16,  0,  0 }, {    123,   16,  -39, 16,  0,  0 }, {    124,   16,  -39, 16,  0,  0 }, {    125,   16,  -39, 16,  0,  0 }, {    126,   16,  -39, 16,  0,  0 },
    {    127,   16,  -39, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_971F27, {
    {     16,   31,   48, 24,  8,  0 }, {     16,   31,   47, 24,  8,  0 }, {     16,   30,   46, 24,  8,  0 }, {     16,   29,   45, 24,  8,  0 }, {     16,   29,   44, 24,  8,  0 },
    {     16,   28,   43, 24,  8,  0 }, {     16,   28,   42, 24,  8,  0 }, {     16,   27,   41, 24,  8,  0 }, {     16,   27,   40, 24,  8,  0 }, {     16,   26,   39, 24,  8,  0 },
    {     16,   26,   38, 24,  8,  0 }, {     16,   25,   37, 24,  8,  0 }, {     16,   24,   36, 24,  8,  0 }, {     16,   24,   35, 24,  8,  0 }, {     16,   23,   34, 24,  8,  0 },
    {     16,   23,   33, 24,  8,  0 }, {     16,   22,   32, 24,  8,  0 }, {     16,   21,   31, 24,  8,  0 }, {     16,   21,   30, 24,  8,  0 }, {     16,   20,   29, 24,  8,  0 },
    {     16,   19,   28, 24,  8,  0 }, {     16,   19,   27, 24,  8,  0 }, {     16,   18,   26, 24,  8,  0 }, {     16,   17,   25, 24,  8,  0 }, {     16,   17,   24, 24,  8,  0 },
    {     16,   16,   23, 24,  8,  0 }, {     16,   15,   22, 24,  8,  0 }, {     16,   14,   21, 24,  8,  0 }, {     16,   14,   20, 24,  8,  0 }, {     16,   13,   19, 24,  8,  0 },
    {     16,   12,   18, 24,  8,  0 }, {     16,   11,   17, 24,  8,  0 }, {     16,   10,   16, 24,  8,  0 }, {     16,    9,   15, 24,  8,  0 }, {     16,    9,   14, 24,  8,  0 },
    {     16,    8,   13, 24,  7,  0 }, {     16,    8,   12, 24,  7,  0 }, {     16,    7,   11, 24,  7,  0 }, {     16,    6,   10, 24,  7,  0 }, {     16,    5,    9, 24,  7,  0 },
    {     16,    4,    8, 24,  7,  0 }, {     16,    3,    7, 24,  7,  0 }, {     16,    2,    6, 24,  7,  0 }, {     16,    1,    5, 24,  7,  0 }, {     16,    0,    4, 24,  7,  0 },
    {     16,   -1,    3, 24,  7,  0 }, {     16,   -2,    2, 24,  7,  0 }, {     16,   -3,    1, 24,  7,  0 }, {     16,   -4,    0, 24,  7,  0 }, {     16,   -5,   -1, 24,  7,  0 },
    {     16,   -6,   -2, 24,  7,  0 }, {     16,   -7,   -3, 24,  7,  0 }, {     16,   -8,   -4, 24,  7,  0 }, {     16,   -9,   -5, 24,  7,  0 }, {     16,  -10,   -6, 24,  7,  0 },
    {     16,  -11,   -7, 24,  7,  0 }, {     16,  -12,   -8, 24,  7,  0 }, {     16,  -13,   -9, 24,  7,  0 }, {     16,  -14,   -9, 24,  7,  0 }, {     16,  -15,  -10, 24,  7,  0 },
    {     16,  -16,  -11, 24,  7,  0 }, {     16,  -17,  -11, 24,  7,  0 }, {     16,  -18,  -12, 24,  7,  0 }, {     16,  -19,  -13, 24,  7,  0 }, {     16,  -20,  -13, 24,  7,  0 },
    {     16,  -21,  -14, 24,  7,  0 }, {     16,  -22,  -15, 24,  7,  0 }, {     16,  -23,  -16, 24,  7,  0 }, {     16,  -24,  -17, 24,  7,  0 }, {     16,  -25,  -17, 24,  7,  0 },
    {     16,  -26,  -18, 24,  6,  0 }, {     16,  -27,  -19, 24,  6,  0 }, {     16,  -28,  -19, 24,  6,  0 }, {     16,  -29,  -20, 24,  6,  0 }, {     16,  -30,  -21, 24,  6,  0 },
    {     16,  -31,  -21, 24,  6,  0 }, {     16,  -32,  -21, 24,  6,  0 }, {     16,  -33,  -22, 24,  6,  0 }, {     16,  -34,  -23, 24,  6,  0 }, {     16,  -35,  -23, 24,  6,  0 },
    {     16,  -36,  -24, 24,  6,  0 }, {     16,  -37,  -25, 24,  6,  0 }, {     16,  -38,  -25, 24,  6,  0 }, {     16,  -39,  -25, 24,  6,  0 }, {     16,  -40,  -26, 24,  6,  0 },
    {     16,  -41,  -27, 24,  6,  0 }, {     16,  -42,  -27, 24,  6,  0 }, {     16,  -43,  -27, 24,  6,  0 }, {     16,  -44,  -27, 24,  6,  0 }, {     16,  -45,  -28, 24,  6,  0 },
    {     16,  -46,  -29, 24,  6,  0 }, {     16,  -47,  -29, 24,  6,  0 }, {     16,  -48,  -30, 24,  6,  0 }, {     16,  -49,  -30, 24,  6,  0 }, {     16,  -50,  -30, 24,  6,  0 },
    {     16,  -51,  -31, 24,  6,  0 }, {     16,  -52,  -31, 24,  6,  0 }, {     16,  -53,  -32, 24,  6,  0 }, {     16,  -54,  -32, 24,  6,  0 }, {     16,  -55,  -32, 24,  6,  0 },
    {     16,  -56,  -33, 24,  5,  0 }, {     16,  -57,  -33, 24,  5,  0 }, {     16,  -58,  -33, 24,  5,  0 }, {     16,  -59,  -33, 24,  5,  0 }, {     16,  -60,  -34, 24,  5,  0 },
    {     16,  -61,  -34, 24,  5,  0 }, {     16,  -62,  -35, 24,  5,  0 }, {     16,  -63,  -35, 24,  5,  0 }, {     16,  -64,  -35, 24,  5,  0 }, {     16,  -65,  -35, 24,  5,  0 },
    {     16,  -66,  -36, 24,  5,  0 }, {     16,  -67,  -36, 24,  5,  0 }, {     16,  -68,  -36, 24,  5,  0 }, {     16,  -69,  -36, 24,  5,  0 }, {     16,  -70,  -37, 24,  5,  0 },
    {     16,  -71,  -37, 24,  5,  0 }, {     16,  -72,  -37, 24,  5,  0 }, {     16,  -73,  -37, 24,  5,  0 }, {     16,  -74,  -38, 24,  5,  0 }, {     16,  -75,  -38, 24,  5,  0 },
    {     16,  -76,  -38, 24,  5,  0 }, {     16,  -77,  -38, 24,  5,  0 }, {     16,  -78,  -38, 24,  5,  0 }, {     16,  -79,  -38, 24,  0,  0 }, {     16,  -80,  -39, 24,  0,  0 },
    {     16,  -81,  -39, 24,  0,  0 }, {     16,  -82,  -39, 24,  0,  0 }, {     16,  -83,  -39, 24,  0,  0 }, {     16,  -84,  -39, 24,  0,  0 }, {     16,  -85,  -39, 24,  0,  0 },
    {     16,  -86,  -39, 24,  0,  0 }, {     16,  -87,  -39, 24,  0,  0 }, {     16,  -88,  -39, 24,  0,  0 }, {     16,  -89,  -39, 24,  0,  0 }, {     16,  -90,  -39, 24,  0,  0 },
    {     16,  -91,  -39, 24,  0,  0 }, {     16,  -92,  -39, 24,  0,  0 }, {     16,  -93,  -39, 24,  0,  0 }, {     16,  -94,  -39, 24,  0,  0 }, {     16,  -95,  -39, 24,  0,  0 },
    {     16,  -96,  -39, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96FC66, {
    {     31,   16,    8,  0,  0,  0 }, {     30,   16,    8,  0,  0,  0 }, {     29,   16,    8,  0,  0,  0 }, {     28,   16,    8,  0,  0,  0 }, {     27,   16,    8,  0,  0,  0 },
    {     26,   16,    8,  0,  0,  0 }, {     25,   16,    8,  0,  0,  0 }, {     24,   16,    8,  0,  0,  0 }, {     23,   16,    8,  0,  0,  0 }, {     22,   16,    8,  0,  0,  0 },
    {     21,   16,    8,  0,  0,  0 }, {     20,   16,    8,  0,  0,  0 }, {     19,   16,    8,  0,  0,  0 }, {     18,   16,    8,  0,  0,  0 }, {     17,   16,    8,  0,  0,  0 },
    {     16,   16,    8,  0,  0,  0 }, {     15,   16,    8,  0,  0,  0 }, {     14,   16,    7,  0,  0,  0 }, {     13,   16,    7,  0,  5,  0 }, {     12,   16,    7,  0,  5,  0 },
    {     11,   16,    7,  0,  5,  0 }, {     10,   16,    7,  0,  5,  0 }, {      9,   16,    7,  0,  5,  0 }, {      8,   16,    6,  0,  5,  0 }, {      7,   16,    6,  0,  5,  0 },
    {      6,   16,    6,  0,  5,  0 }, {      5,   16,    6,  0,  5,  0 }, {      4,   16,    5,  0,  5,  0 }, {      3,   16,    5,  0,  5,  0 }, {      2,   16,    5,  0,  5,  0 },
    {      1,   16,    5,  0,  5,  0 }, {      0,   16,    4,  0,  5,  0 }, {     -1,   16,    4,  0,  5,  0 }, {     -2,   16,    4,  0,  5,  0 }, {     -3,   16,    4,  0,  5,  0 },
    {     -4,   16,    3,  0,  5,  0 }, {     -5,   16,    3,  0,  5,  0 }, {     -6,   16,    2,  0,  5,  0 }, {     -7,   16,    2,  0,  5,  0 }, {     -8,   16,    2,  0,  5,  0 },
    {     -9,   16,    2,  0,  5,  0 }, {    -10,   16,    1,  0,  6,  0 }, {    -11,   16,    1,  0,  6,  0 }, {    -12,   16,    1,  0,  6,  0 }, {    -13,   16,    0,  0,  6,  0 },
    {    -14,   16,    0,  0,  6,  0 }, {    -15,   16,   -1,  0,  6,  0 }, {    -16,   16,   -1,  0,  6,  0 }, {    -17,   16,   -1,  0,  6,  0 }, {    -18,   16,   -2,  0,  6,  0 },
    {    -19,   16,   -2,  0,  6,  0 }, {    -20,   16,   -3,  0,  6,  0 }, {    -21,   16,   -4,  0,  6,  0 }, {    -22,   16,   -4,  0,  6,  0 }, {    -23,   16,   -4,  0,  6,  0 },
    {    -24,   16,   -4,  0,  6,  0 }, {    -25,   16,   -5,  0,  6,  0 }, {    -26,   16,   -6,  0,  6,  0 }, {    -27,   16,   -6,  0,  6,  0 }, {    -28,   16,   -6,  0,  6,  0 },
    {    -29,   16,   -7,  0,  6,  0 }, {    -30,   16,   -8,  0,  6,  0 }, {    -31,   16,   -8,  0,  6,  0 }, {    -32,   16,   -9,  0,  6,  0 }, {    -33,   16,  -10,  0,  6,  0 },
    {    -34,   16,  -10,  0,  6,  0 }, {    -35,   16,  -10,  0,  6,  0 }, {    -36,   16,  -11,  0,  6,  0 }, {    -37,   16,  -12,  0,  6,  0 }, {    -38,   16,  -12,  0,  6,  0 },
    {    -39,   16,  -13,  0,  6,  0 }, {    -40,   16,  -14,  0,  7,  0 }, {    -41,   16,  -14,  0,  7,  0 }, {    -42,   16,  -15,  0,  7,  0 }, {    -43,   16,  -16,  0,  7,  0 },
    {    -44,   16,  -17,  0,  7,  0 }, {    -45,   16,  -18,  0,  7,  0 }, {    -46,   16,  -18,  0,  7,  0 }, {    -47,   16,  -19,  0,  7,  0 }, {    -48,   16,  -20,  0,  7,  0 },
    {    -49,   16,  -20,  0,  7,  0 }, {    -50,   16,  -21,  0,  7,  0 }, {    -51,   16,  -22,  0,  7,  0 }, {    -52,   16,  -22,  0,  7,  0 }, {    -53,   16,  -23,  0,  7,  0 },
    {    -54,   16,  -24,  0,  7,  0 }, {    -55,   16,  -25,  0,  7,  0 }, {    -56,   16,  -26,  0,  7,  0 }, {    -57,   16,  -27,  0,  7,  0 }, {    -58,   16,  -28,  0,  7,  0 },
    {    -59,   16,  -29,  0,  7,  0 }, {    -60,   16,  -30,  0,  7,  0 }, {    -61,   16,  -31,  0,  7,  0 }, {    -62,   16,  -32,  0,  7,  0 }, {    -63,   16,  -33,  0,  7,  0 },
    {    -64,   16,  -34,  0,  7,  0 }, {    -65,   16,  -35,  0,  7,  0 }, {    -66,   16,  -36,  0,  7,  0 }, {    -67,   16,  -37,  0,  7,  0 }, {    -68,   16,  -38,  0,  7,  0 },
    {    -69,   16,  -39,  0,  7,  0 }, {    -70,   16,  -40,  0,  7,  0 }, {    -71,   16,  -41,  0,  7,  0 }, {    -72,   16,  -42,  0,  7,  0 }, {    -73,   16,  -43,  0,  7,  0 },
    {    -73,   16,  -44,  0,  7,  0 }, {    -74,   16,  -45,  0,  8,  0 }, {    -74,   16,  -46,  0,  8,  0 }, {    -75,   16,  -47,  0,  8,  0 }, {    -76,   16,  -48,  0,  8,  0 },
    {    -77,   16,  -49,  0,  8,  0 }, {    -78,   16,  -50,  0,  8,  0 }, {    -79,   16,  -51,  0,  8,  0 }, {    -79,   16,  -52,  0,  8,  0 }, {    -80,   16,  -53,  0,  8,  0 },
    {    -81,   16,  -54,  0,  8,  0 }, {    -82,   16,  -55,  0,  8,  0 }, {    -82,   16,  -56,  0,  8,  0 }, {    -83,   16,  -57,  0,  8,  0 }, {    -84,   16,  -58,  0,  8,  0 },
    {    -84,   16,  -59,  0,  8,  0 }, {    -85,   16,  -60,  0,  8,  0 }, {    -86,   16,  -61,  0,  8,  0 }, {    -86,   16,  -62,  0,  8,  0 }, {    -87,   16,  -63,  0,  8,  0 },
    {    -88,   16,  -64,  0,  8,  0 }, {    -88,   16,  -65,  0,  8,  0 }, {    -89,   16,  -66,  0,  8,  0 }, {    -89,   16,  -67,  0,  8,  0 }, {    -90,   16,  -68,  0,  8,  0 },
    {    -91,   16,  -69,  0,  8,  0 }, {    -91,   16,  -70,  0,  8,  0 }, {    -92,   16,  -71,  0,  8,  0 }, {    -92,   16,  -72,  0,  8,  0 }, {    -93,   16,  -73,  0,  8,  0 },
    {    -93,   16,  -74,  0,  8,  0 }, {    -94,   16,  -75,  0,  8,  0 }, {    -94,   16,  -76,  0,  8,  0 }, {    -95,   16,  -77,  0,  8,  0 }, {    -96,   16,  -78,  0,  8,  0 },
    {    -96,   16,  -79,  0,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_97015D, {
    {     16,    0,    8,  8,  0,  0 }, {     16,    1,    8,  8,  0,  0 }, {     16,    2,    8,  8,  0,  0 }, {     16,    3,    8,  8,  0,  0 }, {     16,    4,    8,  8,  0,  0 },
    {     16,    5,    8,  8,  0,  0 }, {     16,    6,    8,  8,  0,  0 }, {     16,    7,    8,  8,  0,  0 }, {     16,    8,    8,  8,  0,  0 }, {     16,    9,    8,  8,  0,  0 },
    {     16,   10,    8,  8,  0,  0 }, {     16,   11,    8,  8,  0,  0 }, {     16,   12,    8,  8,  0,  0 }, {     16,   13,    8,  8,  0,  0 }, {     16,   14,    8,  8,  0,  0 },
    {     16,   15,    8,  8,  0,  0 }, {     16,   16,    8,  8,  0,  0 }, {     16,   17,    7,  8,  0,  0 }, {     16,   18,    7,  8,  5,  0 }, {     16,   19,    7,  8,  5,  0 },
    {     16,   20,    7,  8,  5,  0 }, {     16,   21,    7,  8,  5,  0 }, {     16,   22,    7,  8,  5,  0 }, {     16,   23,    6,  8,  5,  0 }, {     16,   24,    6,  8,  5,  0 },
    {     16,   25,    6,  8,  5,  0 }, {     16,   26,    6,  8,  5,  0 }, {     16,   27,    5,  8,  5,  0 }, {     16,   28,    5,  8,  5,  0 }, {     16,   29,    5,  8,  5,  0 },
    {     16,   30,    5,  8,  5,  0 }, {     16,   31,    4,  8,  5,  0 }, {     16,   32,    4,  8,  5,  0 }, {     16,   33,    4,  8,  5,  0 }, {     16,   34,    4,  8,  5,  0 },
    {     16,   35,    3,  8,  5,  0 }, {     16,   36,    3,  8,  5,  0 }, {     16,   37,    2,  8,  5,  0 }, {     16,   38,    2,  8,  5,  0 }, {     16,   39,    2,  8,  5,  0 },
    {     16,   40,    2,  8,  5,  0 }, {     16,   41,    1,  8,  6,  0 }, {     16,   42,    1,  8,  6,  0 }, {     16,   43,    1,  8,  6,  0 }, {     16,   44,    0,  8,  6,  0 },
    {     16,   45,    0,  8,  6,  0 }, {     16,   46,   -1,  8,  6,  0 }, {     16,   47,   -1,  8,  6,  0 }, {     16,   48,   -1,  8,  6,  0 }, {     16,   49,   -2,  8,  6,  0 },
    {     16,   50,   -2,  8,  6,  0 }, {     16,   51,   -3,  8,  6,  0 }, {     16,   52,   -4,  8,  6,  0 }, {     16,   53,   -4,  8,  6,  0 }, {     16,   54,   -4,  8,  6,  0 },
    {     16,   55,   -4,  8,  6,  0 }, {     16,   56,   -5,  8,  6,  0 }, {     16,   57,   -6,  8,  6,  0 }, {     16,   58,   -6,  8,  6,  0 }, {     16,   59,   -6,  8,  6,  0 },
    {     16,   60,   -7,  8,  6,  0 }, {     16,   61,   -8,  8,  6,  0 }, {     16,   62,   -8,  8,  6,  0 }, {     16,   63,   -9,  8,  6,  0 }, {     16,   64,  -10,  8,  6,  0 },
    {     16,   65,  -10,  8,  6,  0 }, {     16,   66,  -10,  8,  6,  0 }, {     16,   67,  -11,  8,  6,  0 }, {     16,   68,  -12,  8,  6,  0 }, {     16,   69,  -12,  8,  6,  0 },
    {     16,   70,  -13,  8,  6,  0 }, {     16,   71,  -14,  8,  7,  0 }, {     16,   72,  -14,  8,  7,  0 }, {     16,   73,  -15,  8,  7,  0 }, {     16,   74,  -16,  8,  7,  0 },
    {     16,   75,  -17,  8,  7,  0 }, {     16,   76,  -18,  8,  7,  0 }, {     16,   77,  -18,  8,  7,  0 }, {     16,   78,  -19,  8,  7,  0 }, {     16,   79,  -20,  8,  7,  0 },
    {     16,   80,  -20,  8,  7,  0 }, {     16,   81,  -21,  8,  7,  0 }, {     16,   82,  -22,  8,  7,  0 }, {     16,   83,  -22,  8,  7,  0 }, {     16,   84,  -23,  8,  7,  0 },
    {     16,   85,  -24,  8,  7,  0 }, {     16,   86,  -25,  8,  7,  0 }, {     16,   87,  -26,  8,  7,  0 }, {     16,   88,  -27,  8,  7,  0 }, {     16,   89,  -28,  8,  7,  0 },
    {     16,   90,  -29,  8,  7,  0 }, {     16,   91,  -30,  8,  7,  0 }, {     16,   92,  -31,  8,  7,  0 }, {     16,   93,  -32,  8,  7,  0 }, {     16,   94,  -33,  8,  7,  0 },
    {     16,   95,  -34,  8,  7,  0 }, {     16,   96,  -35,  8,  7,  0 }, {     16,   97,  -36,  8,  7,  0 }, {     16,   98,  -37,  8,  7,  0 }, {     16,   99,  -38,  8,  7,  0 },
    {     16,  100,  -39,  8,  7,  0 }, {     16,  101,  -40,  8,  7,  0 }, {     16,  102,  -41,  8,  7,  0 }, {     16,  103,  -42,  8,  7,  0 }, {     16,  104,  -43,  8,  7,  0 },
    {     16,  104,  -44,  8,  7,  0 }, {     16,  105,  -45,  8,  8,  0 }, {     16,  105,  -46,  8,  8,  0 }, {     16,  106,  -47,  8,  8,  0 }, {     16,  107,  -48,  8,  8,  0 },
    {     16,  108,  -49,  8,  8,  0 }, {     16,  109,  -50,  8,  8,  0 }, {     16,  110,  -51,  8,  8,  0 }, {     16,  110,  -52,  8,  8,  0 }, {     16,  111,  -53,  8,  8,  0 },
    {     16,  112,  -54,  8,  8,  0 }, {     16,  113,  -55,  8,  8,  0 }, {     16,  113,  -56,  8,  8,  0 }, {     16,  114,  -57,  8,  8,  0 }, {     16,  115,  -58,  8,  8,  0 },
    {     16,  115,  -59,  8,  8,  0 }, {     16,  116,  -60,  8,  8,  0 }, {     16,  117,  -61,  8,  8,  0 }, {     16,  117,  -62,  8,  8,  0 }, {     16,  118,  -63,  8,  8,  0 },
    {     16,  119,  -64,  8,  8,  0 }, {     16,  119,  -65,  8,  8,  0 }, {     16,  120,  -66,  8,  8,  0 }, {     16,  120,  -67,  8,  8,  0 }, {     16,  121,  -68,  8,  8,  0 },
    {     16,  122,  -69,  8,  8,  0 }, {     16,  122,  -70,  8,  8,  0 }, {     16,  123,  -71,  8,  8,  0 }, {     16,  123,  -72,  8,  8,  0 }, {     16,  124,  -73,  8,  8,  0 },
    {     16,  124,  -74,  8,  8,  0 }, {     16,  125,  -75,  8,  8,  0 }, {     16,  125,  -76,  8,  8,  0 }, {     16,  126,  -77,  8,  8,  0 }, {     16,  127,  -78,  8,  8,  0 },
    {     16,  127,  -79,  8,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_970654, {
    {      0,   16,    8, 16,  0,  0 }, {      1,   16,    8, 16,  0,  0 }, {      2,   16,    8, 16,  0,  0 }, {      3,   16,    8, 16,  0,  0 }, {      4,   16,    8, 16,  0,  0 },
    {      5,   16,    8, 16,  0,  0 }, {      6,   16,    8, 16,  0,  0 }, {      7,   16,    8, 16,  0,  0 }, {      8,   16,    8, 16,  0,  0 }, {      9,   16,    8, 16,  0,  0 },
    {     10,   16,    8, 16,  0,  0 }, {     11,   16,    8, 16,  0,  0 }, {     12,   16,    8, 16,  0,  0 }, {     13,   16,    8, 16,  0,  0 }, {     14,   16,    8, 16,  0,  0 },
    {     15,   16,    8, 16,  0,  0 }, {     16,   16,    8, 16,  0,  0 }, {     17,   16,    7, 16,  0,  0 }, {     18,   16,    7, 16,  5,  0 }, {     19,   16,    7, 16,  5,  0 },
    {     20,   16,    7, 16,  5,  0 }, {     21,   16,    7, 16,  5,  0 }, {     22,   16,    7, 16,  5,  0 }, {     23,   16,    6, 16,  5,  0 }, {     24,   16,    6, 16,  5,  0 },
    {     25,   16,    6, 16,  5,  0 }, {     26,   16,    6, 16,  5,  0 }, {     27,   16,    5, 16,  5,  0 }, {     28,   16,    5, 16,  5,  0 }, {     29,   16,    5, 16,  5,  0 },
    {     30,   16,    5, 16,  5,  0 }, {     31,   16,    4, 16,  5,  0 }, {     32,   16,    4, 16,  5,  0 }, {     33,   16,    4, 16,  5,  0 }, {     34,   16,    4, 16,  5,  0 },
    {     35,   16,    3, 16,  5,  0 }, {     36,   16,    3, 16,  5,  0 }, {     37,   16,    2, 16,  5,  0 }, {     38,   16,    2, 16,  5,  0 }, {     39,   16,    2, 16,  5,  0 },
    {     40,   16,    2, 16,  5,  0 }, {     41,   16,    1, 16,  6,  0 }, {     42,   16,    1, 16,  6,  0 }, {     43,   16,    1, 16,  6,  0 }, {     44,   16,    0, 16,  6,  0 },
    {     45,   16,    0, 16,  6,  0 }, {     46,   16,   -1, 16,  6,  0 }, {     47,   16,   -1, 16,  6,  0 }, {     48,   16,   -1, 16,  6,  0 }, {     49,   16,   -2, 16,  6,  0 },
    {     50,   16,   -2, 16,  6,  0 }, {     51,   16,   -3, 16,  6,  0 }, {     52,   16,   -4, 16,  6,  0 }, {     53,   16,   -4, 16,  6,  0 }, {     54,   16,   -4, 16,  6,  0 },
    {     55,   16,   -4, 16,  6,  0 }, {     56,   16,   -5, 16,  6,  0 }, {     57,   16,   -6, 16,  6,  0 }, {     58,   16,   -6, 16,  6,  0 }, {     59,   16,   -6, 16,  6,  0 },
    {     60,   16,   -7, 16,  6,  0 }, {     61,   16,   -8, 16,  6,  0 }, {     62,   16,   -8, 16,  6,  0 }, {     63,   16,   -9, 16,  6,  0 }, {     64,   16,  -10, 16,  6,  0 },
    {     65,   16,  -10, 16,  6,  0 }, {     66,   16,  -10, 16,  6,  0 }, {     67,   16,  -11, 16,  6,  0 }, {     68,   16,  -12, 16,  6,  0 }, {     69,   16,  -12, 16,  6,  0 },
    {     70,   16,  -13, 16,  6,  0 }, {     71,   16,  -14, 16,  7,  0 }, {     72,   16,  -14, 16,  7,  0 }, {     73,   16,  -15, 16,  7,  0 }, {     74,   16,  -16, 16,  7,  0 },
    {     75,   16,  -17, 16,  7,  0 }, {     76,   16,  -18, 16,  7,  0 }, {     77,   16,  -18, 16,  7,  0 }, {     78,   16,  -19, 16,  7,  0 }, {     79,   16,  -20, 16,  7,  0 },
    {     80,   16,  -20, 16,  7,  0 }, {     81,   16,  -21, 16,  7,  0 }, {     82,   16,  -22, 16,  7,  0 }, {     83,   16,  -22, 16,  7,  0 }, {     84,   16,  -23, 16,  7,  0 },
    {     85,   16,  -24, 16,  7,  0 }, {     86,   16,  -25, 16,  7,  0 }, {     87,   16,  -26, 16,  7,  0 }, {     88,   16,  -27, 16,  7,  0 }, {     89,   16,  -28, 16,  7,  0 },
    {     90,   16,  -29, 16,  7,  0 }, {     91,   16,  -30, 16,  7,  0 }, {     92,   16,  -31, 16,  7,  0 }, {     93,   16,  -32, 16,  7,  0 }, {     94,   16,  -33, 16,  7,  0 },
    {     95,   16,  -34, 16,  7,  0 }, {     96,   16,  -35, 16,  7,  0 }, {     97,   16,  -36, 16,  7,  0 }, {     98,   16,  -37, 16,  7,  0 }, {     99,   16,  -38, 16,  7,  0 },
    {    100,   16,  -39, 16,  7,  0 }, {    101,   16,  -40, 16,  7,  0 }, {    102,   16,  -41, 16,  7,  0 }, {    103,   16,  -42, 16,  7,  0 }, {    104,   16,  -43, 16,  7,  0 },
    {    104,   16,  -44, 16,  7,  0 }, {    105,   16,  -45, 16,  8,  0 }, {    105,   16,  -46, 16,  8,  0 }, {    106,   16,  -47, 16,  8,  0 }, {    107,   16,  -48, 16,  8,  0 },
    {    108,   16,  -49, 16,  8,  0 }, {    109,   16,  -50, 16,  8,  0 }, {    110,   16,  -51, 16,  8,  0 }, {    110,   16,  -52, 16,  8,  0 }, {    111,   16,  -53, 16,  8,  0 },
    {    112,   16,  -54, 16,  8,  0 }, {    113,   16,  -55, 16,  8,  0 }, {    113,   16,  -56, 16,  8,  0 }, {    114,   16,  -57, 16,  8,  0 }, {    115,   16,  -58, 16,  8,  0 },
    {    115,   16,  -59, 16,  8,  0 }, {    116,   16,  -60, 16,  8,  0 }, {    117,   16,  -61, 16,  8,  0 }, {    117,   16,  -62, 16,  8,  0 }, {    118,   16,  -63, 16,  8,  0 },
    {    119,   16,  -64, 16,  8,  0 }, {    119,   16,  -65, 16,  8,  0 }, {    120,   16,  -66, 16,  8,  0 }, {    120,   16,  -67, 16,  8,  0 }, {    121,   16,  -68, 16,  8,  0 },
    {    122,   16,  -69, 16,  8,  0 }, {    122,   16,  -70, 16,  8,  0 }, {    123,   16,  -71, 16,  8,  0 }, {    123,   16,  -72, 16,  8,  0 }, {    124,   16,  -73, 16,  8,  0 },
    {    124,   16,  -74, 16,  8,  0 }, {    125,   16,  -75, 16,  8,  0 }, {    125,   16,  -76, 16,  8,  0 }, {    126,   16,  -77, 16,  8,  0 }, {    127,   16,  -78, 16,  8,  0 },
    {    127,   16,  -79, 16,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_970B4B, {
    {     16,   31,    8, 24,  0,  0 }, {     16,   30,    8, 24,  0,  0 }, {     16,   29,    8, 24,  0,  0 }, {     16,   28,    8, 24,  0,  0 }, {     16,   27,    8, 24,  0,  0 },
    {     16,   26,    8, 24,  0,  0 }, {     16,   25,    8, 24,  0,  0 }, {     16,   24,    8, 24,  0,  0 }, {     16,   23,    8, 24,  0,  0 }, {     16,   22,    8, 24,  0,  0 },
    {     16,   21,    8, 24,  0,  0 }, {     16,   20,    8, 24,  0,  0 }, {     16,   19,    8, 24,  0,  0 }, {     16,   18,    8, 24,  0,  0 }, {     16,   17,    8, 24,  0,  0 },
    {     16,   16,    8, 24,  0,  0 }, {     16,   15,    8, 24,  0,  0 }, {     16,   14,    7, 24,  0,  0 }, {     16,   13,    7, 24,  5,  0 }, {     16,   12,    7, 24,  5,  0 },
    {     16,   11,    7, 24,  5,  0 }, {     16,   10,    7, 24,  5,  0 }, {     16,    9,    7, 24,  5,  0 }, {     16,    8,    6, 24,  5,  0 }, {     16,    7,    6, 24,  5,  0 },
    {     16,    6,    6, 24,  5,  0 }, {     16,    5,    6, 24,  5,  0 }, {     16,    4,    5, 24,  5,  0 }, {     16,    3,    5, 24,  5,  0 }, {     16,    2,    5, 24,  5,  0 },
    {     16,    1,    5, 24,  5,  0 }, {     16,    0,    4, 24,  5,  0 }, {     16,   -1,    4, 24,  5,  0 }, {     16,   -2,    4, 24,  5,  0 }, {     16,   -3,    4, 24,  5,  0 },
    {     16,   -4,    3, 24,  5,  0 }, {     16,   -5,    3, 24,  5,  0 }, {     16,   -6,    2, 24,  5,  0 }, {     16,   -7,    2, 24,  5,  0 }, {     16,   -8,    2, 24,  5,  0 },
    {     16,   -9,    2, 24,  5,  0 }, {     16,  -10,    1, 24,  6,  0 }, {     16,  -11,    1, 24,  6,  0 }, {     16,  -12,    1, 24,  6,  0 }, {     16,  -13,    0, 24,  6,  0 },
    {     16,  -14,    0, 24,  6,  0 }, {     16,  -15,   -1, 24,  6,  0 }, {     16,  -16,   -1, 24,  6,  0 }, {     16,  -17,   -1, 24,  6,  0 }, {     16,  -18,   -2, 24,  6,  0 },
    {     16,  -19,   -2, 24,  6,  0 }, {     16,  -20,   -3, 24,  6,  0 }, {     16,  -21,   -4, 24,  6,  0 }, {     16,  -22,   -4, 24,  6,  0 }, {     16,  -23,   -4, 24,  6,  0 },
    {     16,  -24,   -4, 24,  6,  0 }, {     16,  -25,   -5, 24,  6,  0 }, {     16,  -26,   -6, 24,  6,  0 }, {     16,  -27,   -6, 24,  6,  0 }, {     16,  -28,   -6, 24,  6,  0 },
    {     16,  -29,   -7, 24,  6,  0 }, {     16,  -30,   -8, 24,  6,  0 }, {     16,  -31,   -8, 24,  6,  0 }, {     16,  -32,   -9, 24,  6,  0 }, {     16,  -33,  -10, 24,  6,  0 },
    {     16,  -34,  -10, 24,  6,  0 }, {     16,  -35,  -10, 24,  6,  0 }, {     16,  -36,  -11, 24,  6,  0 }, {     16,  -37,  -12, 24,  6,  0 }, {     16,  -38,  -12, 24,  6,  0 },
    {     16,  -39,  -13, 24,  6,  0 }, {     16,  -40,  -14, 24,  7,  0 }, {     16,  -41,  -14, 24,  7,  0 }, {     16,  -42,  -15, 24,  7,  0 }, {     16,  -43,  -16, 24,  7,  0 },
    {     16,  -44,  -17, 24,  7,  0 }, {     16,  -45,  -18, 24,  7,  0 }, {     16,  -46,  -18, 24,  7,  0 }, {     16,  -47,  -19, 24,  7,  0 }, {     16,  -48,  -20, 24,  7,  0 },
    {     16,  -49,  -20, 24,  7,  0 }, {     16,  -50,  -21, 24,  7,  0 }, {     16,  -51,  -22, 24,  7,  0 }, {     16,  -52,  -22, 24,  7,  0 }, {     16,  -53,  -23, 24,  7,  0 },
    {     16,  -54,  -24, 24,  7,  0 }, {     16,  -55,  -25, 24,  7,  0 }, {     16,  -56,  -26, 24,  7,  0 }, {     16,  -57,  -27, 24,  7,  0 }, {     16,  -58,  -28, 24,  7,  0 },
    {     16,  -59,  -29, 24,  7,  0 }, {     16,  -60,  -30, 24,  7,  0 }, {     16,  -61,  -31, 24,  7,  0 }, {     16,  -62,  -32, 24,  7,  0 }, {     16,  -63,  -33, 24,  7,  0 },
    {     16,  -64,  -34, 24,  7,  0 }, {     16,  -65,  -35, 24,  7,  0 }, {     16,  -66,  -36, 24,  7,  0 }, {     16,  -67,  -37, 24,  7,  0 }, {     16,  -68,  -38, 24,  7,  0 },
    {     16,  -69,  -39, 24,  7,  0 }, {     16,  -70,  -40, 24,  7,  0 }, {     16,  -71,  -41, 24,  7,  0 }, {     16,  -72,  -42, 24,  7,  0 }, {     16,  -73,  -43, 24,  7,  0 },
    {     16,  -73,  -44, 24,  7,  0 }, {     16,  -74,  -45, 24,  8,  0 }, {     16,  -74,  -46, 24,  8,  0 }, {     16,  -75,  -47, 24,  8,  0 }, {     16,  -76,  -48, 24,  8,  0 },
    {     16,  -77,  -49, 24,  8,  0 }, {     16,  -78,  -50, 24,  8,  0 }, {     16,  -79,  -51, 24,  8,  0 }, {     16,  -79,  -52, 24,  8,  0 }, {     16,  -80,  -53, 24,  8,  0 },
    {     16,  -81,  -54, 24,  8,  0 }, {     16,  -82,  -55, 24,  8,  0 }, {     16,  -82,  -56, 24,  8,  0 }, {     16,  -83,  -57, 24,  8,  0 }, {     16,  -84,  -58, 24,  8,  0 },
    {     16,  -84,  -59, 24,  8,  0 }, {     16,  -85,  -60, 24,  8,  0 }, {     16,  -86,  -61, 24,  8,  0 }, {     16,  -86,  -62, 24,  8,  0 }, {     16,  -87,  -63, 24,  8,  0 },
    {     16,  -88,  -64, 24,  8,  0 }, {     16,  -88,  -65, 24,  8,  0 }, {     16,  -89,  -66, 24,  8,  0 }, {     16,  -89,  -67, 24,  8,  0 }, {     16,  -90,  -68, 24,  8,  0 },
    {     16,  -91,  -69, 24,  8,  0 }, {     16,  -91,  -70, 24,  8,  0 }, {     16,  -92,  -71, 24,  8,  0 }, {     16,  -92,  -72, 24,  8,  0 }, {     16,  -93,  -73, 24,  8,  0 },
    {     16,  -93,  -74, 24,  8,  0 }, {     16,  -94,  -75, 24,  8,  0 }, {     16,  -94,  -76, 24,  8,  0 }, {     16,  -95,  -77, 24,  8,  0 }, {     16,  -96,  -78, 24,  8,  0 },
    {     16,  -96,  -79, 24,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_97241E, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    1,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    2,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    3,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    3,  0,  2,  0 }, {     23,   16,    4,  0,  1,  0 }, {     22,   16,    4,  0,  1,  0 },
    {     21,   16,    4,  0,  1,  0 }, {     20,   16,    5,  0,  1,  0 }, {     19,   16,    5,  0,  1,  0 }, {     18,   16,    5,  0,  1,  0 }, {     17,   16,    6,  0,  1,  0 },
    {     16,   16,    6,  0,  1,  0 }, {     15,   16,    6,  0,  1,  0 }, {     14,   16,    6,  0,  1,  0 }, {     13,   16,    7,  0,  1,  0 }, {     12,   16,    7,  0,  1,  0 },
    {     11,   16,    7,  0,  1,  0 }, {     10,   16,    7,  0,  1,  0 }, {      9,   16,    7,  0,  0,  0 }, {      8,   16,    7,  0,  0,  0 }, {      7,   16,    8,  0,  0,  0 },
    {      6,   16,    8,  0,  0,  0 }, {      5,   16,    8,  0,  0,  0 }, {      4,   16,    8,  0,  0,  0 }, {      3,   16,    8,  0,  0,  0 }, {      2,   16,    8,  0,  0,  0 },
    {      1,   16,    8,  0,  0,  0 }, {      0,   16,    8,  0,  0,  0 }, {     -1,   16,    8,  0,  0,  0 }, {     -2,   16,    8,  0,  0,  0 }, {     -3,   16,    8,  0,  0,  0 },
    {     -4,   16,    8,  0,  0,  0 }, {     -5,   16,    8,  0,  0,  0 }, {     -6,   16,    8,  0,  0,  0 }, {     -7,   16,    8,  0,  0,  0 }, {     -8,   16,    8,  0,  0,  0 },
    {     -9,   16,    7,  0,  5,  0 }, {    -10,   16,    7,  0,  5,  0 }, {    -11,   16,    7,  0,  5,  0 }, {    -12,   16,    7,  0,  5,  0 }, {    -13,   16,    7,  0,  5,  0 },
    {    -14,   16,    7,  0,  5,  0 }, {    -15,   16,    6,  0,  5,  0 }, {    -16,   16,    6,  0,  5,  0 }, {    -17,   16,    6,  0,  5,  0 }, {    -18,   16,    6,  0,  5,  0 },
    {    -19,   16,    5,  0,  5,  0 }, {    -20,   16,    5,  0,  5,  0 }, {    -21,   16,    5,  0,  5,  0 }, {    -22,   16,    4,  0,  5,  0 }, {    -23,   16,    4,  0,  5,  0 },
    {    -24,   16,    4,  0,  5,  0 }, {    -25,   16,    3,  0,  6,  0 }, {    -26,   16,    3,  0,  6,  0 }, {    -27,   16,    2,  0,  6,  0 }, {    -28,   16,    2,  0,  6,  0 },
    {    -29,   16,    1,  0,  6,  0 }, {    -30,   16,    1,  0,  6,  0 }, {    -31,   16,    0,  0,  6,  0 }, {    -32,   16,    0,  0,  6,  0 }, {    -33,   16,   -1,  0,  6,  0 },
    {    -34,   16,   -1,  0,  6,  0 }, {    -35,   16,   -2,  0,  6,  0 }, {    -36,   16,   -2,  0,  6,  0 }, {    -37,   16,   -3,  0,  6,  0 }, {    -38,   16,   -4,  0,  6,  0 },
    {    -39,   16,   -4,  0,  6,  0 }, {    -40,   16,   -5,  0,  6,  0 }, {    -41,   16,   -6,  0,  6,  0 }, {    -42,   16,   -6,  0,  6,  0 }, {    -43,   16,   -7,  0,  7,  0 },
    {    -44,   16,   -8,  0,  7,  0 }, {    -45,   16,   -9,  0,  7,  0 }, {    -46,   16,   -9,  0,  7,  0 }, {    -47,   16,  -10,  0,  7,  0 }, {    -48,   16,  -11,  0,  7,  0 },
    {    -49,   16,  -12,  0,  7,  0 }, {    -50,   16,  -13,  0,  7,  0 }, {    -51,   16,  -14,  0,  7,  0 }, {    -52,   16,  -16,  0,  7,  0 }, {    -53,   16,  -17,  0,  7,  0 },
    {    -54,   16,  -18,  0,  7,  0 }, {    -55,   16,  -19,  0,  7,  0 }, {    -56,   16,  -20,  0,  7,  0 }, {    -56,   16,  -21,  0,  7,  0 }, {    -57,   16,  -22,  0,  7,  0 },
    {    -58,   16,  -23,  0,  7,  0 }, {    -59,   16,  -24,  0,  8,  0 }, {    -59,   16,  -25,  0,  8,  0 }, {    -60,   16,  -26,  0,  8,  0 }, {    -61,   16,  -27,  0,  8,  0 },
    {    -61,   16,  -28,  0,  8,  0 }, {    -62,   16,  -29,  0,  8,  0 }, {    -63,   16,  -30,  0,  8,  0 }, {    -63,   16,  -31,  0,  8,  0 }, {    -64,   16,  -32,  0,  8,  0 },
    {    -64,   16,  -33,  0,  8,  0 }, {    -65,   16,  -33,  0,  8,  0 }, {    -65,   16,  -34,  0,  8,  0 }, {    -66,   16,  -35,  0,  8,  0 }, {    -66,   16,  -36,  0,  8,  0 },
    {    -67,   16,  -37,  0,  8,  0 }, {    -67,   16,  -38,  0,  8,  0 }, {    -68,   16,  -39,  0,  8,  0 }, {    -68,   16,  -40,  0,  8,  0 }, {    -69,   16,  -41,  0,  8,  0 },
    {    -69,   16,  -42,  0,  8,  0 }, {    -70,   16,  -43,  0,  8,  0 }, {    -70,   16,  -44,  0,  8,  0 }, {    -71,   16,  -45,  0,  8,  0 }, {    -71,   16,  -46,  0,  8,  0 },
    {    -72,   16,  -47,  0,  8,  0 }, {    -72,   16,  -48,  0,  8,  0 }, {    -73,   16,  -49,  0,  8,  0 }, {    -73,   16,  -50,  0,  8,  0 }, {    -74,   16,  -51,  0,  8,  0 },
    {    -74,   16,  -52,  0,  8,  0 }, {    -75,   16,  -53,  0,  8,  0 }, {    -75,   16,  -54,  0,  8,  0 }, {    -76,   16,  -55,  0,  8,  0 }, {    -76,   16,  -56,  0,  8,  0 },
    {    -77,   16,  -57,  0,  8,  0 }, {    -77,   16,  -58,  0,  8,  0 }, {    -78,   16,  -59,  0,  8,  0 }, {    -78,   16,  -60,  0,  8,  0 }, {    -79,   16,  -61,  0,  8,  0 },
    {    -79,   16,  -62,  0,  8,  0 }, {    -80,   16,  -63,  0,  8,  0 }, {    -80,   16,  -64,  0,  8,  0 }, {    -81,   16,  -65,  0,  8,  0 }, {    -81,   16,  -66,  0,  8,  0 },
    {    -82,   16,  -67,  0,  8,  0 }, {    -82,   16,  -68,  0,  8,  0 }, {    -83,   16,  -69,  0,  8,  0 }, {    -83,   16,  -70,  0,  8,  0 }, {    -84,   16,  -71,  0,  8,  0 },
    {    -84,   16,  -72,  0,  8,  0 }, {    -85,   16,  -73,  0,  8,  0 }, {    -85,   16,  -74,  0,  8,  0 }, {    -86,   16,  -75,  0,  8,  0 }, {    -86,   16,  -76,  0,  8,  0 },
    {    -87,   16,  -77,  0,  8,  0 }, {    -87,   16,  -78,  0,  8,  0 }, {    -88,   16,  -79,  0,  8,  0 }, {    -88,   16,  -80,  0,  8,  0 }, {    -89,   16,  -81,  0,  8,  0 },
    {    -89,   16,  -82,  0,  8,  0 }, {    -90,   16,  -83,  0,  8,  0 }, {    -90,   16,  -84,  0,  8,  0 }, {    -91,   16,  -85,  0,  8,  0 }, {    -91,   16,  -86,  0,  8,  0 },
    {    -92,   16,  -87,  0,  8,  0 }, {    -92,   16,  -88,  0,  8,  0 }, {    -93,   16,  -89,  0,  8,  0 }, {    -93,   16,  -90,  0,  8,  0 }, {    -94,   16,  -91,  0,  8,  0 },
    {    -94,   16,  -92,  0,  8,  0 }, {    -95,   16,  -93,  0,  8,  0 }, {    -95,   16,  -94,  0,  8,  0 }, {    -96,   16,  -95,  0,  8,  0 }, {    -96,   16,  -96,  0,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9729ED, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    2,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    3,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    4,  8,  1,  0 }, {     16,    9,    4,  8,  1,  0 },
    {     16,   10,    4,  8,  1,  0 }, {     16,   11,    5,  8,  1,  0 }, {     16,   12,    5,  8,  1,  0 }, {     16,   13,    5,  8,  1,  0 }, {     16,   14,    6,  8,  1,  0 },
    {     16,   15,    6,  8,  1,  0 }, {     16,   16,    6,  8,  1,  0 }, {     16,   17,    6,  8,  1,  0 }, {     16,   18,    7,  8,  1,  0 }, {     16,   19,    7,  8,  1,  0 },
    {     16,   20,    7,  8,  1,  0 }, {     16,   21,    7,  8,  1,  0 }, {     16,   22,    7,  8,  0,  0 }, {     16,   23,    7,  8,  0,  0 }, {     16,   24,    8,  8,  0,  0 },
    {     16,   25,    8,  8,  0,  0 }, {     16,   26,    8,  8,  0,  0 }, {     16,   27,    8,  8,  0,  0 }, {     16,   28,    8,  8,  0,  0 }, {     16,   29,    8,  8,  0,  0 },
    {     16,   30,    8,  8,  0,  0 }, {     16,   31,    8,  8,  0,  0 }, {     16,   32,    8,  8,  0,  0 }, {     16,   33,    8,  8,  0,  0 }, {     16,   34,    8,  8,  0,  0 },
    {     16,   35,    8,  8,  0,  0 }, {     16,   36,    8,  8,  0,  0 }, {     16,   37,    8,  8,  0,  0 }, {     16,   38,    8,  8,  0,  0 }, {     16,   39,    8,  8,  0,  0 },
    {     16,   40,    7,  8,  5,  0 }, {     16,   41,    7,  8,  5,  0 }, {     16,   42,    7,  8,  5,  0 }, {     16,   43,    7,  8,  5,  0 }, {     16,   44,    7,  8,  5,  0 },
    {     16,   45,    7,  8,  5,  0 }, {     16,   46,    6,  8,  5,  0 }, {     16,   47,    6,  8,  5,  0 }, {     16,   48,    6,  8,  5,  0 }, {     16,   49,    6,  8,  5,  0 },
    {     16,   50,    5,  8,  5,  0 }, {     16,   51,    5,  8,  5,  0 }, {     16,   52,    5,  8,  5,  0 }, {     16,   53,    4,  8,  5,  0 }, {     16,   54,    4,  8,  5,  0 },
    {     16,   55,    4,  8,  5,  0 }, {     16,   56,    3,  8,  6,  0 }, {     16,   57,    3,  8,  6,  0 }, {     16,   58,    3,  8,  6,  0 }, {     16,   59,    2,  8,  6,  0 },
    {     16,   60,    2,  8,  6,  0 }, {     16,   61,    1,  8,  6,  0 }, {     16,   62,    1,  8,  6,  0 }, {     16,   63,    0,  8,  6,  0 }, {     16,   64,   -1,  8,  6,  0 },
    {     16,   65,   -1,  8,  6,  0 }, {     16,   66,   -2,  8,  6,  0 }, {     16,   67,   -2,  8,  6,  0 }, {     16,   68,   -3,  8,  6,  0 }, {     16,   69,   -4,  8,  6,  0 },
    {     16,   70,   -4,  8,  6,  0 }, {     16,   71,   -5,  8,  6,  0 }, {     16,   72,   -6,  8,  6,  0 }, {     16,   73,   -6,  8,  6,  0 }, {     16,   74,   -7,  8,  7,  0 },
    {     16,   75,   -8,  8,  7,  0 }, {     16,   76,   -9,  8,  7,  0 }, {     16,   77,   -9,  8,  7,  0 }, {     16,   78,  -10,  8,  7,  0 }, {     16,   79,  -11,  8,  7,  0 },
    {     16,   80,  -12,  8,  7,  0 }, {     16,   81,  -13,  8,  7,  0 }, {     16,   82,  -14,  8,  7,  0 }, {     16,   83,  -16,  8,  7,  0 }, {     16,   84,  -17,  8,  7,  0 },
    {     16,   85,  -18,  8,  7,  0 }, {     16,   86,  -19,  8,  7,  0 }, {     16,   87,  -20,  8,  7,  0 }, {     16,   87,  -21,  8,  7,  0 }, {     16,   88,  -22,  8,  7,  0 },
    {     16,   89,  -23,  8,  7,  0 }, {     16,   90,  -24,  8,  8,  0 }, {     16,   90,  -25,  8,  8,  0 }, {     16,   91,  -26,  8,  8,  0 }, {     16,   92,  -27,  8,  8,  0 },
    {     16,   92,  -28,  8,  8,  0 }, {     16,   93,  -29,  8,  8,  0 }, {     16,   94,  -30,  8,  8,  0 }, {     16,   94,  -31,  8,  8,  0 }, {     16,   95,  -32,  8,  8,  0 },
    {     16,   95,  -33,  8,  8,  0 }, {     16,   96,  -33,  8,  8,  0 }, {     16,   96,  -34,  8,  8,  0 }, {     16,   97,  -35,  8,  8,  0 }, {     16,   97,  -36,  8,  8,  0 },
    {     16,   98,  -37,  8,  8,  0 }, {     16,   98,  -38,  8,  8,  0 }, {     16,   99,  -39,  8,  8,  0 }, {     16,   99,  -40,  8,  8,  0 }, {     16,  100,  -41,  8,  8,  0 },
    {     16,  100,  -42,  8,  8,  0 }, {     16,  101,  -43,  8,  8,  0 }, {     16,  101,  -44,  8,  8,  0 }, {     16,  102,  -45,  8,  8,  0 }, {     16,  102,  -46,  8,  8,  0 },
    {     16,  103,  -47,  8,  8,  0 }, {     16,  103,  -48,  8,  8,  0 }, {     16,  104,  -49,  8,  8,  0 }, {     16,  104,  -50,  8,  8,  0 }, {     16,  105,  -51,  8,  8,  0 },
    {     16,  105,  -52,  8,  8,  0 }, {     16,  106,  -53,  8,  8,  0 }, {     16,  106,  -54,  8,  8,  0 }, {     16,  107,  -55,  8,  8,  0 }, {     16,  107,  -56,  8,  8,  0 },
    {     16,  108,  -57,  8,  8,  0 }, {     16,  108,  -58,  8,  8,  0 }, {     16,  109,  -59,  8,  8,  0 }, {     16,  109,  -60,  8,  8,  0 }, {     16,  110,  -61,  8,  8,  0 },
    {     16,  110,  -62,  8,  8,  0 }, {     16,  111,  -63,  8,  8,  0 }, {     16,  111,  -64,  8,  8,  0 }, {     16,  112,  -65,  8,  8,  0 }, {     16,  112,  -66,  8,  8,  0 },
    {     16,  113,  -67,  8,  8,  0 }, {     16,  113,  -68,  8,  8,  0 }, {     16,  114,  -69,  8,  8,  0 }, {     16,  114,  -70,  8,  8,  0 }, {     16,  115,  -71,  8,  8,  0 },
    {     16,  115,  -72,  8,  8,  0 }, {     16,  116,  -73,  8,  8,  0 }, {     16,  116,  -74,  8,  8,  0 }, {     16,  117,  -75,  8,  8,  0 }, {     16,  117,  -76,  8,  8,  0 },
    {     16,  118,  -77,  8,  8,  0 }, {     16,  118,  -78,  8,  8,  0 }, {     16,  119,  -79,  8,  8,  0 }, {     16,  119,  -80,  8,  8,  0 }, {     16,  120,  -81,  8,  8,  0 },
    {     16,  120,  -82,  8,  8,  0 }, {     16,  121,  -83,  8,  8,  0 }, {     16,  121,  -84,  8,  8,  0 }, {     16,  122,  -85,  8,  8,  0 }, {     16,  122,  -86,  8,  8,  0 },
    {     16,  123,  -87,  8,  8,  0 }, {     16,  123,  -88,  8,  8,  0 }, {     16,  124,  -89,  8,  8,  0 }, {     16,  124,  -90,  8,  8,  0 }, {     16,  125,  -91,  8,  8,  0 },
    {     16,  125,  -92,  8,  8,  0 }, {     16,  126,  -93,  8,  8,  0 }, {     16,  126,  -94,  8,  8,  0 }, {     16,  127,  -95,  8,  8,  0 }, {     16,  127,  -96,  8,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_972FBC, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    2, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    3, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    4, 16,  1,  0 }, {      9,   16,    4, 16,  1,  0 },
    {     10,   16,    4, 16,  1,  0 }, {     11,   16,    5, 16,  1,  0 }, {     12,   16,    5, 16,  1,  0 }, {     13,   16,    5, 16,  1,  0 }, {     14,   16,    6, 16,  1,  0 },
    {     15,   16,    6, 16,  1,  0 }, {     16,   16,    6, 16,  1,  0 }, {     17,   16,    6, 16,  1,  0 }, {     18,   16,    7, 16,  1,  0 }, {     19,   16,    7, 16,  1,  0 },
    {     20,   16,    7, 16,  1,  0 }, {     21,   16,    7, 16,  1,  0 }, {     22,   16,    7, 16,  0,  0 }, {     23,   16,    7, 16,  0,  0 }, {     24,   16,    8, 16,  0,  0 },
    {     25,   16,    8, 16,  0,  0 }, {     26,   16,    8, 16,  0,  0 }, {     27,   16,    8, 16,  0,  0 }, {     28,   16,    8, 16,  0,  0 }, {     29,   16,    8, 16,  0,  0 },
    {     30,   16,    8, 16,  0,  0 }, {     31,   16,    8, 16,  0,  0 }, {     32,   16,    8, 16,  0,  0 }, {     33,   16,    8, 16,  0,  0 }, {     34,   16,    8, 16,  0,  0 },
    {     35,   16,    8, 16,  0,  0 }, {     36,   16,    8, 16,  0,  0 }, {     37,   16,    8, 16,  0,  0 }, {     38,   16,    8, 16,  0,  0 }, {     39,   16,    8, 16,  0,  0 },
    {     40,   16,    7, 16,  5,  0 }, {     41,   16,    7, 16,  5,  0 }, {     42,   16,    7, 16,  5,  0 }, {     43,   16,    7, 16,  5,  0 }, {     44,   16,    7, 16,  5,  0 },
    {     45,   16,    7, 16,  5,  0 }, {     46,   16,    6, 16,  5,  0 }, {     47,   16,    6, 16,  5,  0 }, {     48,   16,    6, 16,  5,  0 }, {     49,   16,    6, 16,  5,  0 },
    {     50,   16,    5, 16,  5,  0 }, {     51,   16,    5, 16,  5,  0 }, {     52,   16,    5, 16,  5,  0 }, {     53,   16,    4, 16,  5,  0 }, {     54,   16,    4, 16,  5,  0 },
    {     55,   16,    4, 16,  5,  0 }, {     56,   16,    3, 16,  6,  0 }, {     57,   16,    3, 16,  6,  0 }, {     58,   16,    3, 16,  6,  0 }, {     59,   16,    2, 16,  6,  0 },
    {     60,   16,    2, 16,  6,  0 }, {     61,   16,    1, 16,  6,  0 }, {     62,   16,    1, 16,  6,  0 }, {     63,   16,    0, 16,  6,  0 }, {     64,   16,   -1, 16,  6,  0 },
    {     65,   16,   -1, 16,  6,  0 }, {     66,   16,   -2, 16,  6,  0 }, {     67,   16,   -2, 16,  6,  0 }, {     68,   16,   -3, 16,  6,  0 }, {     69,   16,   -4, 16,  6,  0 },
    {     70,   16,   -4, 16,  6,  0 }, {     71,   16,   -5, 16,  6,  0 }, {     72,   16,   -6, 16,  6,  0 }, {     73,   16,   -6, 16,  6,  0 }, {     74,   16,   -7, 16,  7,  0 },
    {     75,   16,   -8, 16,  7,  0 }, {     76,   16,   -9, 16,  7,  0 }, {     77,   16,   -9, 16,  7,  0 }, {     78,   16,  -10, 16,  7,  0 }, {     79,   16,  -11, 16,  7,  0 },
    {     80,   16,  -12, 16,  7,  0 }, {     81,   16,  -13, 16,  7,  0 }, {     82,   16,  -14, 16,  7,  0 }, {     83,   16,  -16, 16,  7,  0 }, {     84,   16,  -17, 16,  7,  0 },
    {     85,   16,  -18, 16,  7,  0 }, {     86,   16,  -19, 16,  7,  0 }, {     87,   16,  -20, 16,  7,  0 }, {     87,   16,  -21, 16,  7,  0 }, {     88,   16,  -22, 16,  7,  0 },
    {     89,   16,  -23, 16,  7,  0 }, {     90,   16,  -24, 16,  8,  0 }, {     90,   16,  -25, 16,  8,  0 }, {     91,   16,  -26, 16,  8,  0 }, {     92,   16,  -27, 16,  8,  0 },
    {     92,   16,  -28, 16,  8,  0 }, {     93,   16,  -29, 16,  8,  0 }, {     94,   16,  -30, 16,  8,  0 }, {     94,   16,  -31, 16,  8,  0 }, {     95,   16,  -32, 16,  8,  0 },
    {     95,   16,  -33, 16,  8,  0 }, {     96,   16,  -33, 16,  8,  0 }, {     96,   16,  -34, 16,  8,  0 }, {     97,   16,  -35, 16,  8,  0 }, {     97,   16,  -36, 16,  8,  0 },
    {     98,   16,  -37, 16,  8,  0 }, {     98,   16,  -38, 16,  8,  0 }, {     99,   16,  -39, 16,  8,  0 }, {     99,   16,  -40, 16,  8,  0 }, {    100,   16,  -41, 16,  8,  0 },
    {    100,   16,  -42, 16,  8,  0 }, {    101,   16,  -43, 16,  8,  0 }, {    101,   16,  -44, 16,  8,  0 }, {    102,   16,  -45, 16,  8,  0 }, {    102,   16,  -46, 16,  8,  0 },
    {    103,   16,  -47, 16,  8,  0 }, {    103,   16,  -48, 16,  8,  0 }, {    104,   16,  -49, 16,  8,  0 }, {    104,   16,  -50, 16,  8,  0 }, {    105,   16,  -51, 16,  8,  0 },
    {    105,   16,  -52, 16,  8,  0 }, {    106,   16,  -53, 16,  8,  0 }, {    106,   16,  -54, 16,  8,  0 }, {    107,   16,  -55, 16,  8,  0 }, {    107,   16,  -56, 16,  8,  0 },
    {    108,   16,  -57, 16,  8,  0 }, {    108,   16,  -58, 16,  8,  0 }, {    109,   16,  -59, 16,  8,  0 }, {    109,   16,  -60, 16,  8,  0 }, {    110,   16,  -61, 16,  8,  0 },
    {    110,   16,  -62, 16,  8,  0 }, {    111,   16,  -63, 16,  8,  0 }, {    111,   16,  -64, 16,  8,  0 }, {    112,   16,  -65, 16,  8,  0 }, {    112,   16,  -66, 16,  8,  0 },
    {    113,   16,  -67, 16,  8,  0 }, {    113,   16,  -68, 16,  8,  0 }, {    114,   16,  -69, 16,  8,  0 }, {    114,   16,  -70, 16,  8,  0 }, {    115,   16,  -71, 16,  8,  0 },
    {    115,   16,  -72, 16,  8,  0 }, {    116,   16,  -73, 16,  8,  0 }, {    116,   16,  -74, 16,  8,  0 }, {    117,   16,  -75, 16,  8,  0 }, {    117,   16,  -76, 16,  8,  0 },
    {    118,   16,  -77, 16,  8,  0 }, {    118,   16,  -78, 16,  8,  0 }, {    119,   16,  -79, 16,  8,  0 }, {    119,   16,  -80, 16,  8,  0 }, {    120,   16,  -81, 16,  8,  0 },
    {    120,   16,  -82, 16,  8,  0 }, {    121,   16,  -83, 16,  8,  0 }, {    121,   16,  -84, 16,  8,  0 }, {    122,   16,  -85, 16,  8,  0 }, {    122,   16,  -86, 16,  8,  0 },
    {    123,   16,  -87, 16,  8,  0 }, {    123,   16,  -88, 16,  8,  0 }, {    124,   16,  -89, 16,  8,  0 }, {    124,   16,  -90, 16,  8,  0 }, {    125,   16,  -91, 16,  8,  0 },
    {    125,   16,  -92, 16,  8,  0 }, {    126,   16,  -93, 16,  8,  0 }, {    126,   16,  -94, 16,  8,  0 }, {    127,   16,  -95, 16,  8,  0 }, {    127,   16,  -96, 16,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_97358B, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    1, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    2, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    3, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    3, 24,  2,  0 }, {     16,   23,    4, 24,  1,  0 }, {     16,   22,    4, 24,  1,  0 },
    {     16,   21,    4, 24,  1,  0 }, {     16,   20,    5, 24,  1,  0 }, {     16,   19,    5, 24,  1,  0 }, {     16,   18,    5, 24,  1,  0 }, {     16,   17,    6, 24,  1,  0 },
    {     16,   16,    6, 24,  1,  0 }, {     16,   15,    6, 24,  1,  0 }, {     16,   14,    6, 24,  1,  0 }, {     16,   13,    7, 24,  1,  0 }, {     16,   12,    7, 24,  1,  0 },
    {     16,   11,    7, 24,  1,  0 }, {     16,   10,    7, 24,  1,  0 }, {     16,    9,    7, 24,  0,  0 }, {     16,    8,    7, 24,  0,  0 }, {     16,    7,    8, 24,  0,  0 },
    {     16,    6,    8, 24,  0,  0 }, {     16,    5,    8, 24,  0,  0 }, {     16,    4,    8, 24,  0,  0 }, {     16,    3,    8, 24,  0,  0 }, {     16,    2,    8, 24,  0,  0 },
    {     16,    1,    8, 24,  0,  0 }, {     16,    0,    8, 24,  0,  0 }, {     16,   -1,    8, 24,  0,  0 }, {     16,   -2,    8, 24,  0,  0 }, {     16,   -3,    8, 24,  0,  0 },
    {     16,   -4,    8, 24,  0,  0 }, {     16,   -5,    8, 24,  0,  0 }, {     16,   -6,    8, 24,  0,  0 }, {     16,   -7,    8, 24,  0,  0 }, {     16,   -8,    8, 24,  0,  0 },
    {     16,   -9,    7, 24,  5,  0 }, {     16,  -10,    7, 24,  5,  0 }, {     16,  -11,    7, 24,  5,  0 }, {     16,  -12,    7, 24,  5,  0 }, {     16,  -13,    7, 24,  5,  0 },
    {     16,  -14,    7, 24,  5,  0 }, {     16,  -15,    6, 24,  5,  0 }, {     16,  -16,    6, 24,  5,  0 }, {     16,  -17,    6, 24,  5,  0 }, {     16,  -18,    6, 24,  5,  0 },
    {     16,  -19,    5, 24,  5,  0 }, {     16,  -20,    5, 24,  5,  0 }, {     16,  -21,    5, 24,  5,  0 }, {     16,  -22,    4, 24,  5,  0 }, {     16,  -23,    4, 24,  5,  0 },
    {     16,  -24,    4, 24,  5,  0 }, {     16,  -25,    3, 24,  6,  0 }, {     16,  -26,    3, 24,  6,  0 }, {     16,  -27,    2, 24,  6,  0 }, {     16,  -28,    2, 24,  6,  0 },
    {     16,  -29,    1, 24,  6,  0 }, {     16,  -30,    1, 24,  6,  0 }, {     16,  -31,    0, 24,  6,  0 }, {     16,  -32,    0, 24,  6,  0 }, {     16,  -33,   -1, 24,  6,  0 },
    {     16,  -34,   -1, 24,  6,  0 }, {     16,  -35,   -2, 24,  6,  0 }, {     16,  -36,   -2, 24,  6,  0 }, {     16,  -37,   -3, 24,  6,  0 }, {     16,  -38,   -4, 24,  6,  0 },
    {     16,  -39,   -4, 24,  6,  0 }, {     16,  -40,   -5, 24,  6,  0 }, {     16,  -41,   -6, 24,  6,  0 }, {     16,  -42,   -6, 24,  6,  0 }, {     16,  -43,   -7, 24,  7,  0 },
    {     16,  -44,   -8, 24,  7,  0 }, {     16,  -45,   -9, 24,  7,  0 }, {     16,  -46,   -9, 24,  7,  0 }, {     16,  -47,  -10, 24,  7,  0 }, {     16,  -48,  -11, 24,  7,  0 },
    {     16,  -49,  -12, 24,  7,  0 }, {     16,  -50,  -13, 24,  7,  0 }, {     16,  -51,  -14, 24,  7,  0 }, {     16,  -52,  -16, 24,  7,  0 }, {     16,  -53,  -17, 24,  7,  0 },
    {     16,  -54,  -18, 24,  7,  0 }, {     16,  -55,  -19, 24,  7,  0 }, {     16,  -56,  -20, 24,  7,  0 }, {     16,  -56,  -21, 24,  7,  0 }, {     16,  -57,  -22, 24,  7,  0 },
    {     16,  -58,  -23, 24,  7,  0 }, {     16,  -59,  -24, 24,  8,  0 }, {     16,  -59,  -25, 24,  8,  0 }, {     16,  -60,  -26, 24,  8,  0 }, {     16,  -61,  -27, 24,  8,  0 },
    {     16,  -61,  -28, 24,  8,  0 }, {     16,  -62,  -29, 24,  8,  0 }, {     16,  -63,  -30, 24,  8,  0 }, {     16,  -63,  -31, 24,  8,  0 }, {     16,  -64,  -32, 24,  8,  0 },
    {     16,  -64,  -33, 24,  8,  0 }, {     16,  -65,  -33, 24,  8,  0 }, {     16,  -65,  -34, 24,  8,  0 }, {     16,  -66,  -35, 24,  8,  0 }, {     16,  -66,  -36, 24,  8,  0 },
    {     16,  -67,  -37, 24,  8,  0 }, {     16,  -67,  -38, 24,  8,  0 }, {     16,  -68,  -39, 24,  8,  0 }, {     16,  -68,  -40, 24,  8,  0 }, {     16,  -69,  -41, 24,  8,  0 },
    {     16,  -69,  -42, 24,  8,  0 }, {     16,  -70,  -43, 24,  8,  0 }, {     16,  -70,  -44, 24,  8,  0 }, {     16,  -71,  -45, 24,  8,  0 }, {     16,  -71,  -46, 24,  8,  0 },
    {     16,  -72,  -47, 24,  8,  0 }, {     16,  -72,  -48, 24,  8,  0 }, {     16,  -73,  -49, 24,  8,  0 }, {     16,  -73,  -50, 24,  8,  0 }, {     16,  -74,  -51, 24,  8,  0 },
    {     16,  -74,  -52, 24,  8,  0 }, {     16,  -75,  -53, 24,  8,  0 }, {     16,  -75,  -54, 24,  8,  0 }, {     16,  -76,  -55, 24,  8,  0 }, {     16,  -76,  -56, 24,  8,  0 },
    {     16,  -77,  -57, 24,  8,  0 }, {     16,  -77,  -58, 24,  8,  0 }, {     16,  -78,  -59, 24,  8,  0 }, {     16,  -78,  -60, 24,  8,  0 }, {     16,  -79,  -61, 24,  8,  0 },
    {     16,  -79,  -62, 24,  8,  0 }, {     16,  -80,  -63, 24,  8,  0 }, {     16,  -80,  -64, 24,  8,  0 }, {     16,  -81,  -65, 24,  8,  0 }, {     16,  -81,  -66, 24,  8,  0 },
    {     16,  -82,  -67, 24,  8,  0 }, {     16,  -82,  -68, 24,  8,  0 }, {     16,  -83,  -69, 24,  8,  0 }, {     16,  -83,  -70, 24,  8,  0 }, {     16,  -84,  -71, 24,  8,  0 },
    {     16,  -84,  -72, 24,  8,  0 }, {     16,  -85,  -73, 24,  8,  0 }, {     16,  -85,  -74, 24,  8,  0 }, {     16,  -86,  -75, 24,  8,  0 }, {     16,  -86,  -76, 24,  8,  0 },
    {     16,  -87,  -77, 24,  8,  0 }, {     16,  -87,  -78, 24,  8,  0 }, {     16,  -88,  -79, 24,  8,  0 }, {     16,  -88,  -80, 24,  8,  0 }, {     16,  -89,  -81, 24,  8,  0 },
    {     16,  -89,  -82, 24,  8,  0 }, {     16,  -90,  -83, 24,  8,  0 }, {     16,  -90,  -84, 24,  8,  0 }, {     16,  -91,  -85, 24,  8,  0 }, {     16,  -91,  -86, 24,  8,  0 },
    {     16,  -92,  -87, 24,  8,  0 }, {     16,  -92,  -88, 24,  8,  0 }, {     16,  -93,  -89, 24,  8,  0 }, {     16,  -93,  -90, 24,  8,  0 }, {     16,  -94,  -91, 24,  8,  0 },
    {     16,  -94,  -92, 24,  8,  0 }, {     16,  -95,  -93, 24,  8,  0 }, {     16,  -95,  -94, 24,  8,  0 }, {     16,  -96,  -95, 24,  8,  0 }, {     16,  -96,  -96, 24,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9063FA, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    1,  0,  0,  0 }, {     23,   16,    1,  0,  0,  0 }, {     22,   16,    1,  0,  0,  0 },
    {     21,   16,    1,  0,  0,  0 }, {     20,   16,    1,  0,  0,  0 }, {     19,   16,    1,  0,  0,  0 }, {     18,   16,    1,  0,  0,  0 }, {     17,   16,    1,  0,  0,  0 },
    {     16,   16,    1,  0,  0,  0 }, {     15,   16,    2,  0,  0,  0 }, {     14,   16,    2,  0,  1,  0 }, {     13,   16,    2,  0,  1,  0 }, {     12,   16,    2,  0,  1,  0 },
    {     11,   16,    2,  0,  1,  0 }, {     10,   16,    2,  0,  1,  0 }, {      9,   16,    2,  0,  1,  0 }, {      8,   16,    3,  0,  1,  0 }, {      7,   16,    3,  0,  1,  0 },
    {      6,   16,    3,  0,  1,  0 }, {      5,   16,    3,  0,  1,  0 }, {      4,   16,    3,  0,  1,  0 }, {      3,   16,    4,  0,  1,  0 }, {      2,   16,    4,  0,  1,  0 },
    {      1,   16,    4,  0,  1,  0 }, {      0,   16,    4,  0,  1,  0 }, {     -1,   16,    5,  0,  1,  0 }, {     -2,   16,    5,  0,  1,  0 }, {     -3,   16,    5,  0,  1,  0 },
    {     -4,   16,    5,  0,  1,  0 }, {     -5,   16,    6,  0,  1,  0 }, {     -6,   16,    6,  0,  1,  0 }, {     -7,   16,    6,  0,  1,  0 }, {     -8,   16,    6,  0,  1,  0 },
    {     -9,   16,    7,  0,  1,  0 }, {    -10,   16,    7,  0,  1,  0 }, {    -11,   16,    7,  0,  1,  0 }, {    -12,   16,    8,  0,  1,  0 }, {    -13,   16,    8,  0,  1,  0 },
    {    -14,   16,    8,  0,  1,  0 }, {    -15,   16,    9,  0,  1,  0 }, {    -16,   16,    9,  0,  1,  0 }, {    -17,   16,    9,  0,  1,  0 }, {    -18,   16,   10,  0,  1,  0 },
    {    -19,   16,   10,  0,  1,  0 }, {    -20,   16,   10,  0,  1,  0 }, {    -21,   16,   11,  0,  1,  0 }, {    -22,   16,   11,  0,  1,  0 }, {    -23,   16,   11,  0,  2,  0 },
    {    -24,   16,   12,  0,  2,  0 }, {    -25,   16,   12,  0,  2,  0 }, {    -26,   16,   13,  0,  2,  0 }, {    -27,   16,   13,  0,  2,  0 }, {    -28,   16,   13,  0,  2,  0 },
    {    -29,   16,   14,  0,  2,  0 }, {    -30,   16,   14,  0,  2,  0 }, {    -31,   16,   15,  0,  2,  0 }, {    -32,   16,   15,  0,  2,  0 }, {    -33,   16,   16,  0,  2,  0 },
    {    -34,   16,   16,  0,  2,  0 }, {    -35,   16,   17,  0,  2,  0 }, {    -36,   16,   17,  0,  2,  0 }, {    -37,   16,   18,  0,  2,  0 }, {    -38,   16,   18,  0,  2,  0 },
    {    -39,   16,   19,  0,  2,  0 }, {    -40,   16,   19,  0,  2,  0 }, {    -41,   16,   20,  0,  2,  0 }, {    -42,   16,   20,  0,  2,  0 }, {    -43,   16,   21,  0,  2,  0 },
    {    -44,   16,   21,  0,  2,  0 }, {    -45,   16,   22,  0,  2,  0 }, {    -46,   16,   22,  0,  2,  0 }, {    -47,   16,   23,  0,  2,  0 }, {    -48,   16,   24,  0,  2,  0 },
    {    -49,   16,   24,  0,  2,  0 }, {    -50,   16,   25,  0,  2,  0 }, {    -51,   16,   25,  0,  2,  0 }, {    -52,   16,   26,  0,  2,  0 }, {    -53,   16,   27,  0,  2,  0 },
    {    -54,   16,   27,  0,  2,  0 }, {    -55,   16,   28,  0,  2,  0 }, {    -56,   16,   29,  0,  2,  0 }, {    -57,   16,   29,  0,  2,  0 }, {    -58,   16,   30,  0,  2,  0 },
    {    -59,   16,   31,  0,  2,  0 }, {    -60,   16,   31,  0,  2,  0 }, {    -61,   16,   32,  0,  2,  0 }, {    -62,   16,   33,  0,  2,  0 }, {    -63,   16,   33,  0,  2,  0 },
    {    -64,   16,   34,  0,  2,  0 }, {    -65,   16,   35,  0,  2,  0 }, {    -66,   16,   36,  0,  2,  0 }, {    -67,   16,   36,  0,  2,  0 }, {    -68,   16,   37,  0,  2,  0 },
    {    -69,   16,   38,  0,  2,  0 }, {    -70,   16,   39,  0,  2,  0 }, {    -71,   16,   39,  0,  3,  0 }, {    -72,   16,   40,  0,  3,  0 }, {    -73,   16,   41,  0,  3,  0 },
    {    -74,   16,   42,  0,  3,  0 }, {    -75,   16,   43,  0,  3,  0 }, {    -76,   16,   44,  0,  3,  0 }, {    -77,   16,   45,  0,  3,  0 }, {    -78,   16,   45,  0,  3,  0 },
    {    -79,   16,   46,  0,  3,  0 }, {    -80,   16,   47,  0,  3,  0 }, {    -81,   16,   48,  0,  3,  0 }, {    -82,   16,   49,  0,  3,  0 }, {    -83,   16,   50,  0,  3,  0 },
    {    -84,   16,   51,  0,  3,  0 }, {    -85,   16,   52,  0,  3,  0 }, {    -86,   16,   53,  0,  3,  0 }, {    -87,   16,   54,  0,  3,  0 }, {    -88,   16,   55,  0,  3,  0 },
    {    -89,   16,   56,  0,  3,  0 }, {    -90,   16,   57,  0,  3,  0 }, {    -91,   16,   58,  0,  3,  0 }, {    -92,   16,   59,  0,  3,  0 }, {    -93,   16,   60,  0,  3,  0 },
    {    -94,   16,   61,  0,  3,  0 }, {    -95,   16,   62,  0,  3,  0 }, {    -96,   16,   63,  0,  3,  0 }, {    -96,   16,   64,  0,  3,  0 }, {    -97,   16,   65,  0,  3,  0 },
    {    -98,   16,   66,  0,  3,  0 }, {    -99,   16,   67,  0,  3,  0 }, {   -100,   16,   68,  0,  3,  0 }, {   -101,   16,   69,  0,  3,  0 }, {   -101,   16,   70,  0,  3,  0 },
    {   -102,   16,   71,  0,  3,  0 }, {   -103,   16,   72,  0,  3,  0 }, {   -104,   16,   73,  0,  3,  0 }, {   -105,   16,   74,  0,  3,  0 }, {   -105,   16,   75,  0,  3,  0 },
    {   -106,   16,   76,  0,  3,  0 }, {   -107,   16,   77,  0,  3,  0 }, {   -108,   16,   78,  0,  3,  0 }, {   -108,   16,   79,  0,  3,  0 }, {   -109,   16,   80,  0,  3,  0 },
    {   -110,   16,   81,  0,  3,  0 }, {   -110,   16,   82,  0,  3,  0 }, {   -111,   16,   83,  0,  3,  0 }, {   -112,   16,   84,  0,  3,  0 }, {   -113,   16,   85,  0,  3,  0 },
    {   -113,   16,   86,  0,  3,  0 }, {   -114,   16,   87,  0,  3,  0 }, {   -115,   16,   88,  0,  3,  0 }, {   -115,   16,   89,  0,  3,  0 }, {   -116,   16,   90,  0,  4,  0 },
    {   -116,   16,   91,  0,  4,  0 }, {   -117,   16,   92,  0,  4,  0 }, {   -118,   16,   93,  0,  4,  0 }, {   -118,   16,   94,  0,  4,  0 }, {   -119,   16,   95,  0,  4,  0 },
    {   -120,   16,   96,  0,  4,  0 }, {   -120,   16,   97,  0,  4,  0 }, {   -121,   16,   98,  0,  4,  0 }, {   -121,   16,   99,  0,  4,  0 }, {   -122,   16,  100,  0,  4,  0 },
    {   -122,   16,  101,  0,  4,  0 }, {   -123,   16,  102,  0,  4,  0 }, {   -124,   16,  103,  0,  4,  0 }, {   -124,   16,  104,  0,  4,  0 }, {   -125,   16,  105,  0,  4,  0 },
    {   -125,   16,  106,  0,  4,  0 }, {   -126,   16,  107,  0,  4,  0 }, {   -126,   16,  108,  0,  4,  0 }, {   -127,   16,  109,  0,  4,  0 }, {   -127,   16,  110,  0,  4,  0 },
    {   -128,   16,  111,  0,  4,  0 }, {   -128,   16,  112,  0,  4,  0 }, {   -129,   16,  113,  0,  4,  0 }, {   -129,   16,  114,  0,  4,  0 }, {   -130,   16,  115,  0,  4,  0 },
    {   -130,   16,  116,  0,  4,  0 }, {   -131,   16,  117,  0,  4,  0 }, {   -131,   16,  118,  0,  4,  0 }, {   -132,   16,  119,  0,  4,  0 }, {   -132,   16,  120,  0,  4,  0 },
    {   -133,   16,  121,  0,  4,  0 }, {   -133,   16,  122,  0,  4,  0 }, {   -133,   16,  123,  0,  4,  0 }, {   -134,   16,  124,  0,  4,  0 }, {   -134,   16,  125,  0,  4,  0 },
    {   -135,   16,  126,  0,  4,  0 }, {   -135,   16,  127,  0,  4,  0 }, {   -136,   16,  128,  0,  4,  0 }, {   -136,   16,  129,  0,  4,  0 }, {   -136,   16,  130,  0,  4,  0 },
    {   -137,   16,  131,  0,  4,  0 }, {   -137,   16,  132,  0,  4,  0 }, {   -138,   16,  133,  0,  4,  0 }, {   -138,   16,  134,  0,  4,  0 }, {   -138,   16,  135,  0,  9,  0 },
    {   -139,   16,  136,  0,  9,  0 }, {   -139,   16,  137,  0,  9,  0 }, {   -139,   16,  138,  0,  9,  0 }, {   -140,   16,  139,  0,  9,  0 }, {   -140,   16,  140,  0,  9,  0 },
    {   -140,   16,  141,  0,  9,  0 }, {   -141,   16,  142,  0,  9,  0 }, {   -141,   16,  143,  0,  9,  0 }, {   -141,   16,  144,  0,  9,  0 }, {   -142,   16,  145,  0,  9,  0 },
    {   -142,   16,  146,  0,  9,  0 }, {   -142,   16,  147,  0,  9,  0 }, {   -143,   16,  148,  0,  9,  0 }, {   -143,   16,  149,  0,  9,  0 }, {   -143,   16,  150,  0,  9,  0 },
    {   -144,   16,  151,  0,  9,  0 }, {   -144,   16,  152,  0,  9,  0 }, {   -144,   16,  153,  0,  9,  0 }, {   -145,   16,  154,  0,  9,  0 }, {   -145,   16,  155,  0,  9,  0 },
    {   -145,   16,  156,  0,  9,  0 }, {   -145,   16,  157,  0,  9,  0 }, {   -146,   16,  158,  0,  9,  0 }, {   -146,   16,  159,  0,  9,  0 }, {   -146,   16,  160,  0,  9,  0 },
    {   -147,   16,  161,  0,  9,  0 }, {   -147,   16,  162,  0,  9,  0 }, {   -147,   16,  163,  0,  9,  0 }, {   -147,   16,  164,  0,  9,  0 }, {   -148,   16,  165,  0,  9,  0 },
    {   -148,   16,  166,  0,  9,  0 }, {   -148,   16,  167,  0,  9,  0 }, {   -148,   16,  168,  0,  9,  0 }, {   -148,   16,  169,  0,  9,  0 }, {   -149,   16,  170,  0,  9,  0 },
    {   -149,   16,  171,  0,  9,  0 }, {   -149,   16,  172,  0,  9,  0 }, {   -149,   16,  173,  0,  9,  0 }, {   -150,   16,  174,  0,  9,  0 }, {   -150,   16,  175,  0,  9,  0 },
    {   -150,   16,  176,  0,  9,  0 }, {   -150,   16,  177,  0,  9,  0 }, {   -150,   16,  178,  0,  9,  0 }, {   -151,   16,  179,  0,  9,  0 }, {   -151,   16,  180,  0,  9,  0 },
    {   -151,   16,  181,  0,  9,  0 }, {   -151,   16,  182,  0,  9,  0 }, {   -151,   16,  183,  0,  9,  0 }, {   -151,   16,  184,  0,  9,  0 }, {   -152,   16,  185,  0,  9,  0 },
    {   -152,   16,  186,  0,  9,  0 }, {   -152,   16,  187,  0,  9,  0 }, {   -152,   16,  188,  0, 10,  0 }, {   -152,   16,  189,  0, 10,  0 }, {   -152,   16,  190,  0, 10,  0 },
    {   -152,   16,  191,  0, 10,  0 }, {   -153,   16,  192,  0, 10,  0 }, {   -153,   16,  193,  0, 10,  0 }, {   -153,   16,  194,  0, 10,  0 }, {   -153,   16,  195,  0, 10,  0 },
    {   -153,   16,  196,  0, 10,  0 }, {   -153,   16,  197,  0, 10,  0 }, {   -153,   16,  198,  0, 10,  0 }, {   -153,   16,  199,  0, 10,  0 }, {   -154,   16,  200,  0, 10,  0 },
    {   -154,   16,  201,  0, 10,  0 }, {   -154,   16,  202,  0, 10,  0 }, {   -154,   16,  203,  0, 10,  0 }, {   -154,   16,  204,  0, 10,  0 }, {   -154,   16,  205,  0, 10,  0 },
    {   -154,   16,  206,  0, 10,  0 }, {   -154,   16,  207,  0, 10,  0 }, {   -154,   16,  208,  0, 10,  0 }, {   -154,   16,  209,  0, 10,  0 }, {   -154,   16,  210,  0, 10,  0 },
    {   -154,   16,  211,  0, 10,  0 }, {   -155,   16,  212,  0, 10,  0 }, {   -155,   16,  213,  0, 10,  0 }, {   -155,   16,  214,  0, 10,  0 }, {   -155,   16,  215,  0, 10,  0 },
    {   -155,   16,  216,  0, 10,  0 }, {   -155,   16,  217,  0, 10,  0 }, {   -155,   16,  218,  0, 10,  0 }, {   -155,   16,  219,  0, 10,  0 }, {   -155,   16,  220,  0, 10,  0 },
    {   -155,   16,  221,  0, 10,  0 }, {   -155,   16,  222,  0, 10,  0 }, {   -155,   16,  223,  0, 10,  0 }, {   -155,   16,  224,  0, 10,  0 }, {   -155,   16,  225,  0, 10,  0 },
    {   -155,   16,  226,  0, 10,  0 }, {   -155,   16,  227,  0, 10,  0 }, {   -155,   16,  228,  0, 10,  0 }, {   -155,   16,  229,  0, 10,  0 }, {   -155,   16,  230,  0, 10,  0 },
    {   -155,   16,  230,  0, 10,  0 }, {   -155,   16,  231,  0, 10,  0 }, {   -155,   16,  232,  0, 10,  0 }, {   -155,   16,  233,  0, 10,  0 }, {   -155,   16,  234,  0, 10,  0 },
    {   -155,   16,  235,  0, 10,  0 }, {   -155,   16,  236,  0, 10,  0 }, {   -155,   16,  237,  0, 10,  0 }, {   -155,   16,  238,  0, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_906EAC, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    1,  8,  0,  0 }, {     16,    8,    1,  8,  0,  0 }, {     16,    9,    1,  8,  0,  0 },
    {     16,   10,    1,  8,  0,  0 }, {     16,   11,    1,  8,  0,  0 }, {     16,   12,    1,  8,  0,  0 }, {     16,   13,    1,  8,  0,  0 }, {     16,   14,    1,  8,  0,  0 },
    {     16,   15,    1,  8,  0,  0 }, {     16,   16,    2,  8,  0,  0 }, {     16,   17,    2,  8,  1,  0 }, {     16,   18,    2,  8,  1,  0 }, {     16,   19,    2,  8,  1,  0 },
    {     16,   20,    2,  8,  1,  0 }, {     16,   21,    2,  8,  1,  0 }, {     16,   22,    2,  8,  1,  0 }, {     16,   23,    3,  8,  1,  0 }, {     16,   24,    3,  8,  1,  0 },
    {     16,   25,    3,  8,  1,  0 }, {     16,   26,    3,  8,  1,  0 }, {     16,   27,    3,  8,  1,  0 }, {     16,   28,    4,  8,  1,  0 }, {     16,   29,    4,  8,  1,  0 },
    {     16,   30,    4,  8,  1,  0 }, {     16,   31,    4,  8,  1,  0 }, {     16,   32,    5,  8,  1,  0 }, {     16,   33,    5,  8,  1,  0 }, {     16,   34,    5,  8,  1,  0 },
    {     16,   35,    5,  8,  1,  0 }, {     16,   36,    6,  8,  1,  0 }, {     16,   37,    6,  8,  1,  0 }, {     16,   38,    6,  8,  1,  0 }, {     16,   39,    6,  8,  1,  0 },
    {     16,   40,    7,  8,  1,  0 }, {     16,   41,    7,  8,  1,  0 }, {     16,   42,    7,  8,  1,  0 }, {     16,   43,    8,  8,  1,  0 }, {     16,   44,    8,  8,  1,  0 },
    {     16,   45,    8,  8,  1,  0 }, {     16,   46,    9,  8,  1,  0 }, {     16,   47,    9,  8,  1,  0 }, {     16,   48,    9,  8,  1,  0 }, {     16,   49,   10,  8,  1,  0 },
    {     16,   50,   10,  8,  1,  0 }, {     16,   51,   10,  8,  1,  0 }, {     16,   52,   11,  8,  1,  0 }, {     16,   53,   11,  8,  1,  0 }, {     16,   54,   11,  8,  2,  0 },
    {     16,   55,   12,  8,  2,  0 }, {     16,   56,   12,  8,  2,  0 }, {     16,   57,   13,  8,  2,  0 }, {     16,   58,   13,  8,  2,  0 }, {     16,   59,   13,  8,  2,  0 },
    {     16,   60,   14,  8,  2,  0 }, {     16,   61,   14,  8,  2,  0 }, {     16,   62,   15,  8,  2,  0 }, {     16,   63,   15,  8,  2,  0 }, {     16,   64,   16,  8,  2,  0 },
    {     16,   65,   16,  8,  2,  0 }, {     16,   66,   17,  8,  2,  0 }, {     16,   67,   17,  8,  2,  0 }, {     16,   68,   18,  8,  2,  0 }, {     16,   69,   18,  8,  2,  0 },
    {     16,   70,   19,  8,  2,  0 }, {     16,   71,   19,  8,  2,  0 }, {     16,   72,   20,  8,  2,  0 }, {     16,   73,   20,  8,  2,  0 }, {     16,   74,   21,  8,  2,  0 },
    {     16,   75,   21,  8,  2,  0 }, {     16,   76,   22,  8,  2,  0 }, {     16,   77,   22,  8,  2,  0 }, {     16,   78,   23,  8,  2,  0 }, {     16,   79,   24,  8,  2,  0 },
    {     16,   80,   24,  8,  2,  0 }, {     16,   81,   25,  8,  2,  0 }, {     16,   82,   25,  8,  2,  0 }, {     16,   83,   26,  8,  2,  0 }, {     16,   84,   27,  8,  2,  0 },
    {     16,   85,   27,  8,  2,  0 }, {     16,   86,   28,  8,  2,  0 }, {     16,   87,   29,  8,  2,  0 }, {     16,   88,   29,  8,  2,  0 }, {     16,   89,   30,  8,  2,  0 },
    {     16,   90,   31,  8,  2,  0 }, {     16,   91,   31,  8,  2,  0 }, {     16,   92,   32,  8,  2,  0 }, {     16,   93,   33,  8,  2,  0 }, {     16,   94,   33,  8,  2,  0 },
    {     16,   95,   34,  8,  2,  0 }, {     16,   96,   35,  8,  2,  0 }, {     16,   97,   36,  8,  2,  0 }, {     16,   98,   36,  8,  2,  0 }, {     16,   99,   37,  8,  2,  0 },
    {     16,  100,   38,  8,  2,  0 }, {     16,  101,   39,  8,  2,  0 }, {     16,  102,   39,  8,  3,  0 }, {     16,  103,   40,  8,  3,  0 }, {     16,  104,   41,  8,  3,  0 },
    {     16,  105,   42,  8,  3,  0 }, {     16,  106,   43,  8,  3,  0 }, {     16,  107,   44,  8,  3,  0 }, {     16,  108,   45,  8,  3,  0 }, {     16,  109,   45,  8,  3,  0 },
    {     16,  110,   46,  8,  3,  0 }, {     16,  111,   47,  8,  3,  0 }, {     16,  112,   48,  8,  3,  0 }, {     16,  113,   49,  8,  3,  0 }, {     16,  114,   50,  8,  3,  0 },
    {     16,  115,   51,  8,  3,  0 }, {     16,  116,   52,  8,  3,  0 }, {     16,  117,   53,  8,  3,  0 }, {     16,  118,   54,  8,  3,  0 }, {     16,  119,   55,  8,  3,  0 },
    {     16,  120,   56,  8,  3,  0 }, {     16,  121,   57,  8,  3,  0 }, {     16,  122,   58,  8,  3,  0 }, {     16,  123,   59,  8,  3,  0 }, {     16,  124,   60,  8,  3,  0 },
    {     16,  125,   61,  8,  3,  0 }, {     16,  126,   62,  8,  3,  0 }, {     16,  127,   63,  8,  3,  0 }, {     16,  127,   64,  8,  3,  0 }, {     16,  128,   65,  8,  3,  0 },
    {     16,  129,   66,  8,  3,  0 }, {     16,  130,   67,  8,  3,  0 }, {     16,  131,   68,  8,  3,  0 }, {     16,  132,   69,  8,  3,  0 }, {     16,  132,   70,  8,  3,  0 },
    {     16,  133,   71,  8,  3,  0 }, {     16,  134,   72,  8,  3,  0 }, {     16,  135,   73,  8,  3,  0 }, {     16,  136,   74,  8,  3,  0 }, {     16,  136,   75,  8,  3,  0 },
    {     16,  137,   76,  8,  3,  0 }, {     16,  138,   77,  8,  3,  0 }, {     16,  139,   78,  8,  3,  0 }, {     16,  139,   79,  8,  3,  0 }, {     16,  140,   80,  8,  3,  0 },
    {     16,  141,   81,  8,  3,  0 }, {     16,  141,   82,  8,  3,  0 }, {     16,  142,   83,  8,  3,  0 }, {     16,  143,   84,  8,  3,  0 }, {     16,  144,   85,  8,  3,  0 },
    {     16,  144,   86,  8,  3,  0 }, {     16,  145,   87,  8,  3,  0 }, {     16,  146,   88,  8,  3,  0 }, {     16,  146,   89,  8,  3,  0 }, {     16,  147,   90,  8,  4,  0 },
    {     16,  147,   91,  8,  4,  0 }, {     16,  148,   92,  8,  4,  0 }, {     16,  149,   93,  8,  4,  0 }, {     16,  149,   94,  8,  4,  0 }, {     16,  150,   95,  8,  4,  0 },
    {     16,  151,   96,  8,  4,  0 }, {     16,  151,   97,  8,  4,  0 }, {     16,  152,   98,  8,  4,  0 }, {     16,  152,   99,  8,  4,  0 }, {     16,  153,  100,  8,  4,  0 },
    {     16,  153,  101,  8,  4,  0 }, {     16,  154,  102,  8,  4,  0 }, {     16,  155,  103,  8,  4,  0 }, {     16,  155,  104,  8,  4,  0 }, {     16,  156,  105,  8,  4,  0 },
    {     16,  156,  106,  8,  4,  0 }, {     16,  157,  107,  8,  4,  0 }, {     16,  157,  108,  8,  4,  0 }, {     16,  158,  109,  8,  4,  0 }, {     16,  158,  110,  8,  4,  0 },
    {     16,  159,  111,  8,  4,  0 }, {     16,  159,  112,  8,  4,  0 }, {     16,  160,  113,  8,  4,  0 }, {     16,  160,  114,  8,  4,  0 }, {     16,  161,  115,  8,  4,  0 },
    {     16,  161,  116,  8,  4,  0 }, {     16,  162,  117,  8,  4,  0 }, {     16,  162,  118,  8,  4,  0 }, {     16,  163,  119,  8,  4,  0 }, {     16,  163,  120,  8,  4,  0 },
    {     16,  164,  121,  8,  4,  0 }, {     16,  164,  122,  8,  4,  0 }, {     16,  164,  123,  8,  4,  0 }, {     16,  165,  124,  8,  4,  0 }, {     16,  165,  125,  8,  4,  0 },
    {     16,  166,  126,  8,  4,  0 }, {     16,  166,  127,  8,  4,  0 }, {     16,  167,  128,  8,  4,  0 }, {     16,  167,  129,  8,  4,  0 }, {     16,  167,  130,  8,  4,  0 },
    {     16,  168,  131,  8,  4,  0 }, {     16,  168,  132,  8,  4,  0 }, {     16,  169,  133,  8,  4,  0 }, {     16,  169,  134,  8,  4,  0 }, {     16,  169,  135,  8,  9,  0 },
    {     16,  170,  136,  8,  9,  0 }, {     16,  170,  137,  8,  9,  0 }, {     16,  170,  138,  8,  9,  0 }, {     16,  171,  139,  8,  9,  0 }, {     16,  171,  140,  8,  9,  0 },
    {     16,  171,  141,  8,  9,  0 }, {     16,  172,  142,  8,  9,  0 }, {     16,  172,  143,  8,  9,  0 }, {     16,  172,  144,  8,  9,  0 }, {     16,  173,  145,  8,  9,  0 },
    {     16,  173,  146,  8,  9,  0 }, {     16,  173,  147,  8,  9,  0 }, {     16,  174,  148,  8,  9,  0 }, {     16,  174,  149,  8,  9,  0 }, {     16,  174,  150,  8,  9,  0 },
    {     16,  175,  151,  8,  9,  0 }, {     16,  175,  152,  8,  9,  0 }, {     16,  175,  153,  8,  9,  0 }, {     16,  176,  154,  8,  9,  0 }, {     16,  176,  155,  8,  9,  0 },
    {     16,  176,  156,  8,  9,  0 }, {     16,  176,  157,  8,  9,  0 }, {     16,  177,  158,  8,  9,  0 }, {     16,  177,  159,  8,  9,  0 }, {     16,  177,  160,  8,  9,  0 },
    {     16,  178,  161,  8,  9,  0 }, {     16,  178,  162,  8,  9,  0 }, {     16,  178,  163,  8,  9,  0 }, {     16,  178,  164,  8,  9,  0 }, {     16,  179,  165,  8,  9,  0 },
    {     16,  179,  166,  8,  9,  0 }, {     16,  179,  167,  8,  9,  0 }, {     16,  179,  168,  8,  9,  0 }, {     16,  179,  169,  8,  9,  0 }, {     16,  180,  170,  8,  9,  0 },
    {     16,  180,  171,  8,  9,  0 }, {     16,  180,  172,  8,  9,  0 }, {     16,  180,  173,  8,  9,  0 }, {     16,  181,  174,  8,  9,  0 }, {     16,  181,  175,  8,  9,  0 },
    {     16,  181,  176,  8,  9,  0 }, {     16,  181,  177,  8,  9,  0 }, {     16,  181,  178,  8,  9,  0 }, {     16,  182,  179,  8,  9,  0 }, {     16,  182,  180,  8,  9,  0 },
    {     16,  182,  181,  8,  9,  0 }, {     16,  182,  182,  8,  9,  0 }, {     16,  182,  183,  8,  9,  0 }, {     16,  182,  184,  8,  9,  0 }, {     16,  183,  185,  8,  9,  0 },
    {     16,  183,  186,  8,  9,  0 }, {     16,  183,  187,  8,  9,  0 }, {     16,  183,  188,  8, 10,  0 }, {     16,  183,  189,  8, 10,  0 }, {     16,  183,  190,  8, 10,  0 },
    {     16,  183,  191,  8, 10,  0 }, {     16,  184,  192,  8, 10,  0 }, {     16,  184,  193,  8, 10,  0 }, {     16,  184,  194,  8, 10,  0 }, {     16,  184,  195,  8, 10,  0 },
    {     16,  184,  196,  8, 10,  0 }, {     16,  184,  197,  8, 10,  0 }, {     16,  184,  198,  8, 10,  0 }, {     16,  184,  199,  8, 10,  0 }, {     16,  185,  200,  8, 10,  0 },
    {     16,  185,  201,  8, 10,  0 }, {     16,  185,  202,  8, 10,  0 }, {     16,  185,  203,  8, 10,  0 }, {     16,  185,  204,  8, 10,  0 }, {     16,  185,  205,  8, 10,  0 },
    {     16,  185,  206,  8, 10,  0 }, {     16,  185,  207,  8, 10,  0 }, {     16,  185,  208,  8, 10,  0 }, {     16,  185,  209,  8, 10,  0 }, {     16,  185,  210,  8, 10,  0 },
    {     16,  185,  211,  8, 10,  0 }, {     16,  186,  212,  8, 10,  0 }, {     16,  186,  213,  8, 10,  0 }, {     16,  186,  214,  8, 10,  0 }, {     16,  186,  215,  8, 10,  0 },
    {     16,  186,  216,  8, 10,  0 }, {     16,  186,  217,  8, 10,  0 }, {     16,  186,  218,  8, 10,  0 }, {     16,  186,  219,  8, 10,  0 }, {     16,  186,  220,  8, 10,  0 },
    {     16,  186,  221,  8, 10,  0 }, {     16,  186,  222,  8, 10,  0 }, {     16,  186,  223,  8, 10,  0 }, {     16,  186,  224,  8, 10,  0 }, {     16,  186,  225,  8, 10,  0 },
    {     16,  186,  226,  8, 10,  0 }, {     16,  186,  227,  8, 10,  0 }, {     16,  186,  228,  8, 10,  0 }, {     16,  186,  229,  8, 10,  0 }, {     16,  186,  230,  8, 10,  0 },
    {     16,  186,  230,  8, 10,  0 }, {     16,  186,  231,  8, 10,  0 }, {     16,  186,  232,  8, 10,  0 }, {     16,  186,  233,  8, 10,  0 }, {     16,  186,  234,  8, 10,  0 },
    {     16,  186,  235,  8, 10,  0 }, {     16,  186,  236,  8, 10,  0 }, {     16,  186,  237,  8, 10,  0 }, {     16,  186,  238,  8, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90795E, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    1, 16,  0,  0 }, {      8,   16,    1, 16,  0,  0 }, {      9,   16,    1, 16,  0,  0 },
    {     10,   16,    1, 16,  0,  0 }, {     11,   16,    1, 16,  0,  0 }, {     12,   16,    1, 16,  0,  0 }, {     13,   16,    1, 16,  0,  0 }, {     14,   16,    1, 16,  0,  0 },
    {     15,   16,    1, 16,  0,  0 }, {     16,   16,    2, 16,  0,  0 }, {     17,   16,    2, 16,  1,  0 }, {     18,   16,    2, 16,  1,  0 }, {     19,   16,    2, 16,  1,  0 },
    {     20,   16,    2, 16,  1,  0 }, {     21,   16,    2, 16,  1,  0 }, {     22,   16,    2, 16,  1,  0 }, {     23,   16,    3, 16,  1,  0 }, {     24,   16,    3, 16,  1,  0 },
    {     25,   16,    3, 16,  1,  0 }, {     26,   16,    3, 16,  1,  0 }, {     27,   16,    3, 16,  1,  0 }, {     28,   16,    4, 16,  1,  0 }, {     29,   16,    4, 16,  1,  0 },
    {     30,   16,    4, 16,  1,  0 }, {     31,   16,    4, 16,  1,  0 }, {     32,   16,    5, 16,  1,  0 }, {     33,   16,    5, 16,  1,  0 }, {     34,   16,    5, 16,  1,  0 },
    {     35,   16,    5, 16,  1,  0 }, {     36,   16,    6, 16,  1,  0 }, {     37,   16,    6, 16,  1,  0 }, {     38,   16,    6, 16,  1,  0 }, {     39,   16,    6, 16,  1,  0 },
    {     40,   16,    7, 16,  1,  0 }, {     41,   16,    7, 16,  1,  0 }, {     42,   16,    7, 16,  1,  0 }, {     43,   16,    8, 16,  1,  0 }, {     44,   16,    8, 16,  1,  0 },
    {     45,   16,    8, 16,  1,  0 }, {     46,   16,    9, 16,  1,  0 }, {     47,   16,    9, 16,  1,  0 }, {     48,   16,    9, 16,  1,  0 }, {     49,   16,   10, 16,  1,  0 },
    {     50,   16,   10, 16,  1,  0 }, {     51,   16,   10, 16,  1,  0 }, {     52,   16,   11, 16,  1,  0 }, {     53,   16,   11, 16,  1,  0 }, {     54,   16,   11, 16,  2,  0 },
    {     55,   16,   12, 16,  2,  0 }, {     56,   16,   12, 16,  2,  0 }, {     57,   16,   13, 16,  2,  0 }, {     58,   16,   13, 16,  2,  0 }, {     59,   16,   13, 16,  2,  0 },
    {     60,   16,   14, 16,  2,  0 }, {     61,   16,   14, 16,  2,  0 }, {     62,   16,   15, 16,  2,  0 }, {     63,   16,   15, 16,  2,  0 }, {     64,   16,   16, 16,  2,  0 },
    {     65,   16,   16, 16,  2,  0 }, {     66,   16,   17, 16,  2,  0 }, {     67,   16,   17, 16,  2,  0 }, {     68,   16,   18, 16,  2,  0 }, {     69,   16,   18, 16,  2,  0 },
    {     70,   16,   19, 16,  2,  0 }, {     71,   16,   19, 16,  2,  0 }, {     72,   16,   20, 16,  2,  0 }, {     73,   16,   20, 16,  2,  0 }, {     74,   16,   21, 16,  2,  0 },
    {     75,   16,   21, 16,  2,  0 }, {     76,   16,   22, 16,  2,  0 }, {     77,   16,   22, 16,  2,  0 }, {     78,   16,   23, 16,  2,  0 }, {     79,   16,   24, 16,  2,  0 },
    {     80,   16,   24, 16,  2,  0 }, {     81,   16,   25, 16,  2,  0 }, {     82,   16,   25, 16,  2,  0 }, {     83,   16,   26, 16,  2,  0 }, {     84,   16,   27, 16,  2,  0 },
    {     85,   16,   27, 16,  2,  0 }, {     86,   16,   28, 16,  2,  0 }, {     87,   16,   29, 16,  2,  0 }, {     88,   16,   29, 16,  2,  0 }, {     89,   16,   30, 16,  2,  0 },
    {     90,   16,   31, 16,  2,  0 }, {     91,   16,   31, 16,  2,  0 }, {     92,   16,   32, 16,  2,  0 }, {     93,   16,   33, 16,  2,  0 }, {     94,   16,   33, 16,  2,  0 },
    {     95,   16,   34, 16,  2,  0 }, {     96,   16,   35, 16,  2,  0 }, {     97,   16,   36, 16,  2,  0 }, {     98,   16,   36, 16,  2,  0 }, {     99,   16,   37, 16,  2,  0 },
    {    100,   16,   38, 16,  2,  0 }, {    101,   16,   39, 16,  2,  0 }, {    102,   16,   39, 16,  3,  0 }, {    103,   16,   40, 16,  3,  0 }, {    104,   16,   41, 16,  3,  0 },
    {    105,   16,   42, 16,  3,  0 }, {    106,   16,   43, 16,  3,  0 }, {    107,   16,   44, 16,  3,  0 }, {    108,   16,   45, 16,  3,  0 }, {    109,   16,   45, 16,  3,  0 },
    {    110,   16,   46, 16,  3,  0 }, {    111,   16,   47, 16,  3,  0 }, {    112,   16,   48, 16,  3,  0 }, {    113,   16,   49, 16,  3,  0 }, {    114,   16,   50, 16,  3,  0 },
    {    115,   16,   51, 16,  3,  0 }, {    116,   16,   52, 16,  3,  0 }, {    117,   16,   53, 16,  3,  0 }, {    118,   16,   54, 16,  3,  0 }, {    119,   16,   55, 16,  3,  0 },
    {    120,   16,   56, 16,  3,  0 }, {    121,   16,   57, 16,  3,  0 }, {    122,   16,   58, 16,  3,  0 }, {    123,   16,   59, 16,  3,  0 }, {    124,   16,   60, 16,  3,  0 },
    {    125,   16,   61, 16,  3,  0 }, {    126,   16,   62, 16,  3,  0 }, {    127,   16,   63, 16,  3,  0 }, {    127,   16,   64, 16,  3,  0 }, {    128,   16,   65, 16,  3,  0 },
    {    129,   16,   66, 16,  3,  0 }, {    130,   16,   67, 16,  3,  0 }, {    131,   16,   68, 16,  3,  0 }, {    132,   16,   69, 16,  3,  0 }, {    132,   16,   70, 16,  3,  0 },
    {    133,   16,   71, 16,  3,  0 }, {    134,   16,   72, 16,  3,  0 }, {    135,   16,   73, 16,  3,  0 }, {    136,   16,   74, 16,  3,  0 }, {    136,   16,   75, 16,  3,  0 },
    {    137,   16,   76, 16,  3,  0 }, {    138,   16,   77, 16,  3,  0 }, {    139,   16,   78, 16,  3,  0 }, {    139,   16,   79, 16,  3,  0 }, {    140,   16,   80, 16,  3,  0 },
    {    141,   16,   81, 16,  3,  0 }, {    141,   16,   82, 16,  3,  0 }, {    142,   16,   83, 16,  3,  0 }, {    143,   16,   84, 16,  3,  0 }, {    144,   16,   85, 16,  3,  0 },
    {    144,   16,   86, 16,  3,  0 }, {    145,   16,   87, 16,  3,  0 }, {    146,   16,   88, 16,  3,  0 }, {    146,   16,   89, 16,  3,  0 }, {    147,   16,   90, 16,  4,  0 },
    {    147,   16,   91, 16,  4,  0 }, {    148,   16,   92, 16,  4,  0 }, {    149,   16,   93, 16,  4,  0 }, {    149,   16,   94, 16,  4,  0 }, {    150,   16,   95, 16,  4,  0 },
    {    151,   16,   96, 16,  4,  0 }, {    151,   16,   97, 16,  4,  0 }, {    152,   16,   98, 16,  4,  0 }, {    152,   16,   99, 16,  4,  0 }, {    153,   16,  100, 16,  4,  0 },
    {    153,   16,  101, 16,  4,  0 }, {    154,   16,  102, 16,  4,  0 }, {    155,   16,  103, 16,  4,  0 }, {    155,   16,  104, 16,  4,  0 }, {    156,   16,  105, 16,  4,  0 },
    {    156,   16,  106, 16,  4,  0 }, {    157,   16,  107, 16,  4,  0 }, {    157,   16,  108, 16,  4,  0 }, {    158,   16,  109, 16,  4,  0 }, {    158,   16,  110, 16,  4,  0 },
    {    159,   16,  111, 16,  4,  0 }, {    159,   16,  112, 16,  4,  0 }, {    160,   16,  113, 16,  4,  0 }, {    160,   16,  114, 16,  4,  0 }, {    161,   16,  115, 16,  4,  0 },
    {    161,   16,  116, 16,  4,  0 }, {    162,   16,  117, 16,  4,  0 }, {    162,   16,  118, 16,  4,  0 }, {    163,   16,  119, 16,  4,  0 }, {    163,   16,  120, 16,  4,  0 },
    {    164,   16,  121, 16,  4,  0 }, {    164,   16,  122, 16,  4,  0 }, {    164,   16,  123, 16,  4,  0 }, {    165,   16,  124, 16,  4,  0 }, {    165,   16,  125, 16,  4,  0 },
    {    166,   16,  126, 16,  4,  0 }, {    166,   16,  127, 16,  4,  0 }, {    167,   16,  128, 16,  4,  0 }, {    167,   16,  129, 16,  4,  0 }, {    167,   16,  130, 16,  4,  0 },
    {    168,   16,  131, 16,  4,  0 }, {    168,   16,  132, 16,  4,  0 }, {    169,   16,  133, 16,  4,  0 }, {    169,   16,  134, 16,  4,  0 }, {    169,   16,  135, 16,  9,  0 },
    {    170,   16,  136, 16,  9,  0 }, {    170,   16,  137, 16,  9,  0 }, {    170,   16,  138, 16,  9,  0 }, {    171,   16,  139, 16,  9,  0 }, {    171,   16,  140, 16,  9,  0 },
    {    171,   16,  141, 16,  9,  0 }, {    172,   16,  142, 16,  9,  0 }, {    172,   16,  143, 16,  9,  0 }, {    172,   16,  144, 16,  9,  0 }, {    173,   16,  145, 16,  9,  0 },
    {    173,   16,  146, 16,  9,  0 }, {    173,   16,  147, 16,  9,  0 }, {    174,   16,  148, 16,  9,  0 }, {    174,   16,  149, 16,  9,  0 }, {    174,   16,  150, 16,  9,  0 },
    {    175,   16,  151, 16,  9,  0 }, {    175,   16,  152, 16,  9,  0 }, {    175,   16,  153, 16,  9,  0 }, {    176,   16,  154, 16,  9,  0 }, {    176,   16,  155, 16,  9,  0 },
    {    176,   16,  156, 16,  9,  0 }, {    176,   16,  157, 16,  9,  0 }, {    177,   16,  158, 16,  9,  0 }, {    177,   16,  159, 16,  9,  0 }, {    177,   16,  160, 16,  9,  0 },
    {    178,   16,  161, 16,  9,  0 }, {    178,   16,  162, 16,  9,  0 }, {    178,   16,  163, 16,  9,  0 }, {    178,   16,  164, 16,  9,  0 }, {    179,   16,  165, 16,  9,  0 },
    {    179,   16,  166, 16,  9,  0 }, {    179,   16,  167, 16,  9,  0 }, {    179,   16,  168, 16,  9,  0 }, {    179,   16,  169, 16,  9,  0 }, {    180,   16,  170, 16,  9,  0 },
    {    180,   16,  171, 16,  9,  0 }, {    180,   16,  172, 16,  9,  0 }, {    180,   16,  173, 16,  9,  0 }, {    181,   16,  174, 16,  9,  0 }, {    181,   16,  175, 16,  9,  0 },
    {    181,   16,  176, 16,  9,  0 }, {    181,   16,  177, 16,  9,  0 }, {    181,   16,  178, 16,  9,  0 }, {    182,   16,  179, 16,  9,  0 }, {    182,   16,  180, 16,  9,  0 },
    {    182,   16,  181, 16,  9,  0 }, {    182,   16,  182, 16,  9,  0 }, {    182,   16,  183, 16,  9,  0 }, {    182,   16,  184, 16,  9,  0 }, {    183,   16,  185, 16,  9,  0 },
    {    183,   16,  186, 16,  9,  0 }, {    183,   16,  187, 16,  9,  0 }, {    183,   16,  188, 16, 10,  0 }, {    183,   16,  189, 16, 10,  0 }, {    183,   16,  190, 16, 10,  0 },
    {    183,   16,  191, 16, 10,  0 }, {    184,   16,  192, 16, 10,  0 }, {    184,   16,  193, 16, 10,  0 }, {    184,   16,  194, 16, 10,  0 }, {    184,   16,  195, 16, 10,  0 },
    {    184,   16,  196, 16, 10,  0 }, {    184,   16,  197, 16, 10,  0 }, {    184,   16,  198, 16, 10,  0 }, {    184,   16,  199, 16, 10,  0 }, {    185,   16,  200, 16, 10,  0 },
    {    185,   16,  201, 16, 10,  0 }, {    185,   16,  202, 16, 10,  0 }, {    185,   16,  203, 16, 10,  0 }, {    185,   16,  204, 16, 10,  0 }, {    185,   16,  205, 16, 10,  0 },
    {    185,   16,  206, 16, 10,  0 }, {    185,   16,  207, 16, 10,  0 }, {    185,   16,  208, 16, 10,  0 }, {    185,   16,  209, 16, 10,  0 }, {    185,   16,  210, 16, 10,  0 },
    {    185,   16,  211, 16, 10,  0 }, {    186,   16,  212, 16, 10,  0 }, {    186,   16,  213, 16, 10,  0 }, {    186,   16,  214, 16, 10,  0 }, {    186,   16,  215, 16, 10,  0 },
    {    186,   16,  216, 16, 10,  0 }, {    186,   16,  217, 16, 10,  0 }, {    186,   16,  218, 16, 10,  0 }, {    186,   16,  219, 16, 10,  0 }, {    186,   16,  220, 16, 10,  0 },
    {    186,   16,  221, 16, 10,  0 }, {    186,   16,  222, 16, 10,  0 }, {    186,   16,  223, 16, 10,  0 }, {    186,   16,  224, 16, 10,  0 }, {    186,   16,  225, 16, 10,  0 },
    {    186,   16,  226, 16, 10,  0 }, {    186,   16,  227, 16, 10,  0 }, {    186,   16,  228, 16, 10,  0 }, {    186,   16,  229, 16, 10,  0 }, {    186,   16,  230, 16, 10,  0 },
    {    186,   16,  230, 16, 10,  0 }, {    186,   16,  231, 16, 10,  0 }, {    186,   16,  232, 16, 10,  0 }, {    186,   16,  233, 16, 10,  0 }, {    186,   16,  234, 16, 10,  0 },
    {    186,   16,  235, 16, 10,  0 }, {    186,   16,  236, 16, 10,  0 }, {    186,   16,  237, 16, 10,  0 }, {    186,   16,  238, 16, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_908410, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    1, 24,  0,  0 }, {     16,   23,    1, 24,  0,  0 }, {     16,   22,    1, 24,  0,  0 },
    {     16,   21,    1, 24,  0,  0 }, {     16,   20,    1, 24,  0,  0 }, {     16,   19,    1, 24,  0,  0 }, {     16,   18,    1, 24,  0,  0 }, {     16,   17,    1, 24,  0,  0 },
    {     16,   16,    1, 24,  0,  0 }, {     16,   15,    2, 24,  0,  0 }, {     16,   14,    2, 24,  1,  0 }, {     16,   13,    2, 24,  1,  0 }, {     16,   12,    2, 24,  1,  0 },
    {     16,   11,    2, 24,  1,  0 }, {     16,   10,    2, 24,  1,  0 }, {     16,    9,    2, 24,  1,  0 }, {     16,    8,    3, 24,  1,  0 }, {     16,    7,    3, 24,  1,  0 },
    {     16,    6,    3, 24,  1,  0 }, {     16,    5,    3, 24,  1,  0 }, {     16,    4,    3, 24,  1,  0 }, {     16,    3,    4, 24,  1,  0 }, {     16,    2,    4, 24,  1,  0 },
    {     16,    1,    4, 24,  1,  0 }, {     16,    0,    4, 24,  1,  0 }, {     16,   -1,    5, 24,  1,  0 }, {     16,   -2,    5, 24,  1,  0 }, {     16,   -3,    5, 24,  1,  0 },
    {     16,   -4,    5, 24,  1,  0 }, {     16,   -5,    6, 24,  1,  0 }, {     16,   -6,    6, 24,  1,  0 }, {     16,   -7,    6, 24,  1,  0 }, {     16,   -8,    6, 24,  1,  0 },
    {     16,   -9,    7, 24,  1,  0 }, {     16,  -10,    7, 24,  1,  0 }, {     16,  -11,    7, 24,  1,  0 }, {     16,  -12,    8, 24,  1,  0 }, {     16,  -13,    8, 24,  1,  0 },
    {     16,  -14,    8, 24,  1,  0 }, {     16,  -15,    9, 24,  1,  0 }, {     16,  -16,    9, 24,  1,  0 }, {     16,  -17,    9, 24,  1,  0 }, {     16,  -18,   10, 24,  1,  0 },
    {     16,  -19,   10, 24,  1,  0 }, {     16,  -20,   10, 24,  1,  0 }, {     16,  -21,   11, 24,  1,  0 }, {     16,  -22,   11, 24,  1,  0 }, {     16,  -23,   11, 24,  2,  0 },
    {     16,  -24,   12, 24,  2,  0 }, {     16,  -25,   12, 24,  2,  0 }, {     16,  -26,   13, 24,  2,  0 }, {     16,  -27,   13, 24,  2,  0 }, {     16,  -28,   13, 24,  2,  0 },
    {     16,  -29,   14, 24,  2,  0 }, {     16,  -30,   14, 24,  2,  0 }, {     16,  -31,   15, 24,  2,  0 }, {     16,  -32,   15, 24,  2,  0 }, {     16,  -33,   16, 24,  2,  0 },
    {     16,  -34,   16, 24,  2,  0 }, {     16,  -35,   17, 24,  2,  0 }, {     16,  -36,   17, 24,  2,  0 }, {     16,  -37,   18, 24,  2,  0 }, {     16,  -38,   18, 24,  2,  0 },
    {     16,  -39,   19, 24,  2,  0 }, {     16,  -40,   19, 24,  2,  0 }, {     16,  -41,   20, 24,  2,  0 }, {     16,  -42,   20, 24,  2,  0 }, {     16,  -43,   21, 24,  2,  0 },
    {     16,  -44,   21, 24,  2,  0 }, {     16,  -45,   22, 24,  2,  0 }, {     16,  -46,   22, 24,  2,  0 }, {     16,  -47,   23, 24,  2,  0 }, {     16,  -48,   24, 24,  2,  0 },
    {     16,  -49,   24, 24,  2,  0 }, {     16,  -50,   25, 24,  2,  0 }, {     16,  -51,   25, 24,  2,  0 }, {     16,  -52,   26, 24,  2,  0 }, {     16,  -53,   27, 24,  2,  0 },
    {     16,  -54,   27, 24,  2,  0 }, {     16,  -55,   28, 24,  2,  0 }, {     16,  -56,   29, 24,  2,  0 }, {     16,  -57,   29, 24,  2,  0 }, {     16,  -58,   30, 24,  2,  0 },
    {     16,  -59,   31, 24,  2,  0 }, {     16,  -60,   31, 24,  2,  0 }, {     16,  -61,   32, 24,  2,  0 }, {     16,  -62,   33, 24,  2,  0 }, {     16,  -63,   33, 24,  2,  0 },
    {     16,  -64,   34, 24,  2,  0 }, {     16,  -65,   35, 24,  2,  0 }, {     16,  -66,   36, 24,  2,  0 }, {     16,  -67,   36, 24,  2,  0 }, {     16,  -68,   37, 24,  2,  0 },
    {     16,  -69,   38, 24,  2,  0 }, {     16,  -70,   39, 24,  2,  0 }, {     16,  -71,   39, 24,  3,  0 }, {     16,  -72,   40, 24,  3,  0 }, {     16,  -73,   41, 24,  3,  0 },
    {     16,  -74,   42, 24,  3,  0 }, {     16,  -75,   43, 24,  3,  0 }, {     16,  -76,   44, 24,  3,  0 }, {     16,  -77,   45, 24,  3,  0 }, {     16,  -78,   45, 24,  3,  0 },
    {     16,  -79,   46, 24,  3,  0 }, {     16,  -80,   47, 24,  3,  0 }, {     16,  -81,   48, 24,  3,  0 }, {     16,  -82,   49, 24,  3,  0 }, {     16,  -83,   50, 24,  3,  0 },
    {     16,  -84,   51, 24,  3,  0 }, {     16,  -85,   52, 24,  3,  0 }, {     16,  -86,   53, 24,  3,  0 }, {     16,  -87,   54, 24,  3,  0 }, {     16,  -88,   55, 24,  3,  0 },
    {     16,  -89,   56, 24,  3,  0 }, {     16,  -90,   57, 24,  3,  0 }, {     16,  -91,   58, 24,  3,  0 }, {     16,  -92,   59, 24,  3,  0 }, {     16,  -93,   60, 24,  3,  0 },
    {     16,  -94,   61, 24,  3,  0 }, {     16,  -95,   62, 24,  3,  0 }, {     16,  -96,   63, 24,  3,  0 }, {     16,  -96,   64, 24,  3,  0 }, {     16,  -97,   65, 24,  3,  0 },
    {     16,  -98,   66, 24,  3,  0 }, {     16,  -99,   67, 24,  3,  0 }, {     16, -100,   68, 24,  3,  0 }, {     16, -101,   69, 24,  3,  0 }, {     16, -101,   70, 24,  3,  0 },
    {     16, -102,   71, 24,  3,  0 }, {     16, -103,   72, 24,  3,  0 }, {     16, -104,   73, 24,  3,  0 }, {     16, -105,   74, 24,  3,  0 }, {     16, -105,   75, 24,  3,  0 },
    {     16, -106,   76, 24,  3,  0 }, {     16, -107,   77, 24,  3,  0 }, {     16, -108,   78, 24,  3,  0 }, {     16, -108,   79, 24,  3,  0 }, {     16, -109,   80, 24,  3,  0 },
    {     16, -110,   81, 24,  3,  0 }, {     16, -110,   82, 24,  3,  0 }, {     16, -111,   83, 24,  3,  0 }, {     16, -112,   84, 24,  3,  0 }, {     16, -113,   85, 24,  3,  0 },
    {     16, -113,   86, 24,  3,  0 }, {     16, -114,   87, 24,  3,  0 }, {     16, -115,   88, 24,  3,  0 }, {     16, -115,   89, 24,  3,  0 }, {     16, -116,   90, 24,  4,  0 },
    {     16, -116,   91, 24,  4,  0 }, {     16, -117,   92, 24,  4,  0 }, {     16, -118,   93, 24,  4,  0 }, {     16, -118,   94, 24,  4,  0 }, {     16, -119,   95, 24,  4,  0 },
    {     16, -120,   96, 24,  4,  0 }, {     16, -120,   97, 24,  4,  0 }, {     16, -121,   98, 24,  4,  0 }, {     16, -121,   99, 24,  4,  0 }, {     16, -122,  100, 24,  4,  0 },
    {     16, -122,  101, 24,  4,  0 }, {     16, -123,  102, 24,  4,  0 }, {     16, -124,  103, 24,  4,  0 }, {     16, -124,  104, 24,  4,  0 }, {     16, -125,  105, 24,  4,  0 },
    {     16, -125,  106, 24,  4,  0 }, {     16, -126,  107, 24,  4,  0 }, {     16, -126,  108, 24,  4,  0 }, {     16, -127,  109, 24,  4,  0 }, {     16, -127,  110, 24,  4,  0 },
    {     16, -128,  111, 24,  4,  0 }, {     16, -128,  112, 24,  4,  0 }, {     16, -129,  113, 24,  4,  0 }, {     16, -129,  114, 24,  4,  0 }, {     16, -130,  115, 24,  4,  0 },
    {     16, -130,  116, 24,  4,  0 }, {     16, -131,  117, 24,  4,  0 }, {     16, -131,  118, 24,  4,  0 }, {     16, -132,  119, 24,  4,  0 }, {     16, -132,  120, 24,  4,  0 },
    {     16, -133,  121, 24,  4,  0 }, {     16, -133,  122, 24,  4,  0 }, {     16, -133,  123, 24,  4,  0 }, {     16, -134,  124, 24,  4,  0 }, {     16, -134,  125, 24,  4,  0 },
    {     16, -135,  126, 24,  4,  0 }, {     16, -135,  127, 24,  4,  0 }, {     16, -136,  128, 24,  4,  0 }, {     16, -136,  129, 24,  4,  0 }, {     16, -136,  130, 24,  4,  0 },
    {     16, -137,  131, 24,  4,  0 }, {     16, -137,  132, 24,  4,  0 }, {     16, -138,  133, 24,  4,  0 }, {     16, -138,  134, 24,  4,  0 }, {     16, -138,  135, 24,  9,  0 },
    {     16, -139,  136, 24,  9,  0 }, {     16, -139,  137, 24,  9,  0 }, {     16, -139,  138, 24,  9,  0 }, {     16, -140,  139, 24,  9,  0 }, {     16, -140,  140, 24,  9,  0 },
    {     16, -140,  141, 24,  9,  0 }, {     16, -141,  142, 24,  9,  0 }, {     16, -141,  143, 24,  9,  0 }, {     16, -141,  144, 24,  9,  0 }, {     16, -142,  145, 24,  9,  0 },
    {     16, -142,  146, 24,  9,  0 }, {     16, -142,  147, 24,  9,  0 }, {     16, -143,  148, 24,  9,  0 }, {     16, -143,  149, 24,  9,  0 }, {     16, -143,  150, 24,  9,  0 },
    {     16, -144,  151, 24,  9,  0 }, {     16, -144,  152, 24,  9,  0 }, {     16, -144,  153, 24,  9,  0 }, {     16, -145,  154, 24,  9,  0 }, {     16, -145,  155, 24,  9,  0 },
    {     16, -145,  156, 24,  9,  0 }, {     16, -145,  157, 24,  9,  0 }, {     16, -146,  158, 24,  9,  0 }, {     16, -146,  159, 24,  9,  0 }, {     16, -146,  160, 24,  9,  0 },
    {     16, -147,  161, 24,  9,  0 }, {     16, -147,  162, 24,  9,  0 }, {     16, -147,  163, 24,  9,  0 }, {     16, -147,  164, 24,  9,  0 }, {     16, -148,  165, 24,  9,  0 },
    {     16, -148,  166, 24,  9,  0 }, {     16, -148,  167, 24,  9,  0 }, {     16, -148,  168, 24,  9,  0 }, {     16, -148,  169, 24,  9,  0 }, {     16, -149,  170, 24,  9,  0 },
    {     16, -149,  171, 24,  9,  0 }, {     16, -149,  172, 24,  9,  0 }, {     16, -149,  173, 24,  9,  0 }, {     16, -150,  174, 24,  9,  0 }, {     16, -150,  175, 24,  9,  0 },
    {     16, -150,  176, 24,  9,  0 }, {     16, -150,  177, 24,  9,  0 }, {     16, -150,  178, 24,  9,  0 }, {     16, -151,  179, 24,  9,  0 }, {     16, -151,  180, 24,  9,  0 },
    {     16, -151,  181, 24,  9,  0 }, {     16, -151,  182, 24,  9,  0 }, {     16, -151,  183, 24,  9,  0 }, {     16, -151,  184, 24,  9,  0 }, {     16, -152,  185, 24,  9,  0 },
    {     16, -152,  186, 24,  9,  0 }, {     16, -152,  187, 24,  9,  0 }, {     16, -152,  188, 24, 10,  0 }, {     16, -152,  189, 24, 10,  0 }, {     16, -152,  190, 24, 10,  0 },
    {     16, -152,  191, 24, 10,  0 }, {     16, -153,  192, 24, 10,  0 }, {     16, -153,  193, 24, 10,  0 }, {     16, -153,  194, 24, 10,  0 }, {     16, -153,  195, 24, 10,  0 },
    {     16, -153,  196, 24, 10,  0 }, {     16, -153,  197, 24, 10,  0 }, {     16, -153,  198, 24, 10,  0 }, {     16, -153,  199, 24, 10,  0 }, {     16, -154,  200, 24, 10,  0 },
    {     16, -154,  201, 24, 10,  0 }, {     16, -154,  202, 24, 10,  0 }, {     16, -154,  203, 24, 10,  0 }, {     16, -154,  204, 24, 10,  0 }, {     16, -154,  205, 24, 10,  0 },
    {     16, -154,  206, 24, 10,  0 }, {     16, -154,  207, 24, 10,  0 }, {     16, -154,  208, 24, 10,  0 }, {     16, -154,  209, 24, 10,  0 }, {     16, -154,  210, 24, 10,  0 },
    {     16, -154,  211, 24, 10,  0 }, {     16, -155,  212, 24, 10,  0 }, {     16, -155,  213, 24, 10,  0 }, {     16, -155,  214, 24, 10,  0 }, {     16, -155,  215, 24, 10,  0 },
    {     16, -155,  216, 24, 10,  0 }, {     16, -155,  217, 24, 10,  0 }, {     16, -155,  218, 24, 10,  0 }, {     16, -155,  219, 24, 10,  0 }, {     16, -155,  220, 24, 10,  0 },
    {     16, -155,  221, 24, 10,  0 }, {     16, -155,  222, 24, 10,  0 }, {     16, -155,  223, 24, 10,  0 }, {     16, -155,  224, 24, 10,  0 }, {     16, -155,  225, 24, 10,  0 },
    {     16, -155,  226, 24, 10,  0 }, {     16, -155,  227, 24, 10,  0 }, {     16, -155,  228, 24, 10,  0 }, {     16, -155,  229, 24, 10,  0 }, {     16, -155,  230, 24, 10,  0 },
    {     16, -155,  230, 24, 10,  0 }, {     16, -155,  231, 24, 10,  0 }, {     16, -155,  232, 24, 10,  0 }, {     16, -155,  233, 24, 10,  0 }, {     16, -155,  234, 24, 10,  0 },
    {     16, -155,  235, 24, 10,  0 }, {     16, -155,  236, 24, 10,  0 }, {     16, -155,  237, 24, 10,  0 }, {     16, -155,  238, 24, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90B98A, {
    {     37,   16,    0,  0, 10,  0 }, {     37,   16,    1,  0, 10,  0 }, {     37,   16,    2,  0, 10,  0 }, {     37,   16,    3,  0, 10,  0 }, {     37,   16,    4,  0, 10,  0 },
    {     37,   16,    5,  0, 10,  0 }, {     37,   16,    6,  0, 10,  0 }, {     37,   16,    7,  0, 10,  0 }, {     37,   16,    8,  0, 10,  0 }, {     37,   16,    9,  0, 10,  0 },
    {     37,   16,   10,  0, 10,  0 }, {     37,   16,   11,  0, 10,  0 }, {     37,   16,   12,  0, 10,  0 }, {     37,   16,   13,  0, 10,  0 }, {     37,   16,   14,  0, 10,  0 },
    {     37,   16,   15,  0, 10,  0 }, {     37,   16,   16,  0, 10,  0 }, {     37,   16,   17,  0, 10,  0 }, {     37,   16,   18,  0, 10,  0 }, {     37,   16,   19,  0, 10,  0 },
    {     37,   16,   20,  0, 10,  0 }, {     37,   16,   21,  0, 10,  0 }, {     37,   16,   22,  0, 10,  0 }, {     37,   16,   23,  0, 10,  0 }, {     37,   16,   24,  0, 10,  0 },
    {     37,   16,   25,  0, 10,  0 }, {     37,   16,   26,  0, 10,  0 }, {     37,   16,   27,  0, 10,  0 }, {     37,   16,   28,  0, 10,  0 }, {     37,   16,   29,  0, 10,  0 },
    {     37,   16,   30,  0, 10,  0 }, {     37,   16,   31,  0, 10,  0 }, {     37,   16,   32,  0, 10,  0 }, {     37,   16,   33,  0, 10,  0 }, {     37,   16,   34,  0, 10,  0 },
    {     37,   16,   35,  0, 10,  0 }, {     37,   16,   36,  0, 10,  0 }, {     37,   16,   37,  0, 10,  0 }, {     37,   16,   38,  0, 10,  0 }, {     37,   16,   39,  0, 10,  0 },
    {     37,   16,   40,  0, 10,  0 }, {     37,   16,   41,  0, 10,  0 }, {     37,   16,   42,  0, 10,  0 }, {     37,   16,   43,  0, 10,  0 }, {     37,   16,   44,  0, 10,  0 },
    {     37,   16,   45,  0, 10,  0 }, {     37,   16,   46,  0, 10,  0 }, {     37,   16,   47,  0, 10,  0 }, {     37,   16,   48,  0, 10,  0 }, {     37,   16,   49,  0, 10,  0 },
    {     37,   16,   50,  0, 10,  0 }, {     37,   16,   51,  0, 10,  0 }, {     37,   16,   52,  0, 10,  0 }, {     37,   16,   53,  0, 10,  0 }, {     37,   16,   54,  0, 10,  0 },
    {     37,   16,   55,  0, 10,  0 }, {     37,   16,   56,  0, 10,  0 }, {     37,   16,   57,  0, 10,  0 }, {     37,   16,   58,  0, 10,  0 }, {     37,   16,   59,  0, 10,  0 },
    {     37,   16,   60,  0, 10,  0 }, {     37,   16,   61,  0, 10,  0 }, {     37,   16,   62,  0, 10,  0 }, {     37,   16,   63,  0, 10,  0 }, {     37,   16,   64,  0, 10,  0 },
    {     37,   16,   65,  0, 10,  0 }, {     37,   16,   66,  0, 10,  0 }, {     37,   16,   67,  0, 10,  0 }, {     37,   16,   68,  0, 10,  0 }, {     37,   16,   69,  0, 10,  0 },
    {     37,   16,   70,  0, 10,  0 }, {     37,   16,   71,  0, 10,  0 }, {     37,   16,   72,  0, 10,  0 }, {     37,   16,   73,  0, 10,  0 }, {     37,   16,   74,  0, 10,  0 },
    {     37,   16,   75,  0, 10,  0 }, {     37,   16,   76,  0, 10,  0 }, {     37,   16,   77,  0, 10,  0 }, {     37,   16,   78,  0, 10,  0 }, {     37,   16,   79,  0, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90BC5C, {
    {     16,   -6,    0,  8, 10,  0 }, {     16,   -6,    1,  8, 10,  0 }, {     16,   -6,    2,  8, 10,  0 }, {     16,   -6,    3,  8, 10,  0 }, {     16,   -6,    4,  8, 10,  0 },
    {     16,   -6,    5,  8, 10,  0 }, {     16,   -6,    6,  8, 10,  0 }, {     16,   -6,    7,  8, 10,  0 }, {     16,   -6,    8,  8, 10,  0 }, {     16,   -6,    9,  8, 10,  0 },
    {     16,   -6,   10,  8, 10,  0 }, {     16,   -6,   11,  8, 10,  0 }, {     16,   -6,   12,  8, 10,  0 }, {     16,   -6,   13,  8, 10,  0 }, {     16,   -6,   14,  8, 10,  0 },
    {     16,   -6,   15,  8, 10,  0 }, {     16,   -6,   16,  8, 10,  0 }, {     16,   -6,   17,  8, 10,  0 }, {     16,   -6,   18,  8, 10,  0 }, {     16,   -6,   19,  8, 10,  0 },
    {     16,   -6,   20,  8, 10,  0 }, {     16,   -6,   21,  8, 10,  0 }, {     16,   -6,   22,  8, 10,  0 }, {     16,   -6,   23,  8, 10,  0 }, {     16,   -6,   24,  8, 10,  0 },
    {     16,   -6,   25,  8, 10,  0 }, {     16,   -6,   26,  8, 10,  0 }, {     16,   -6,   27,  8, 10,  0 }, {     16,   -6,   28,  8, 10,  0 }, {     16,   -6,   29,  8, 10,  0 },
    {     16,   -6,   30,  8, 10,  0 }, {     16,   -6,   31,  8, 10,  0 }, {     16,   -6,   32,  8, 10,  0 }, {     16,   -6,   33,  8, 10,  0 }, {     16,   -6,   34,  8, 10,  0 },
    {     16,   -6,   35,  8, 10,  0 }, {     16,   -6,   36,  8, 10,  0 }, {     16,   -6,   37,  8, 10,  0 }, {     16,   -6,   38,  8, 10,  0 }, {     16,   -6,   39,  8, 10,  0 },
    {     16,   -6,   40,  8, 10,  0 }, {     16,   -6,   41,  8, 10,  0 }, {     16,   -6,   42,  8, 10,  0 }, {     16,   -6,   43,  8, 10,  0 }, {     16,   -6,   44,  8, 10,  0 },
    {     16,   -6,   45,  8, 10,  0 }, {     16,   -6,   46,  8, 10,  0 }, {     16,   -6,   47,  8, 10,  0 }, {     16,   -6,   48,  8, 10,  0 }, {     16,   -6,   49,  8, 10,  0 },
    {     16,   -6,   50,  8, 10,  0 }, {     16,   -6,   51,  8, 10,  0 }, {     16,   -6,   52,  8, 10,  0 }, {     16,   -6,   53,  8, 10,  0 }, {     16,   -6,   54,  8, 10,  0 },
    {     16,   -6,   55,  8, 10,  0 }, {     16,   -6,   56,  8, 10,  0 }, {     16,   -6,   57,  8, 10,  0 }, {     16,   -6,   58,  8, 10,  0 }, {     16,   -6,   59,  8, 10,  0 },
    {     16,   -6,   60,  8, 10,  0 }, {     16,   -6,   61,  8, 10,  0 }, {     16,   -6,   62,  8, 10,  0 }, {     16,   -6,   63,  8, 10,  0 }, {     16,   -6,   64,  8, 10,  0 },
    {     16,   -6,   65,  8, 10,  0 }, {     16,   -6,   66,  8, 10,  0 }, {     16,   -6,   67,  8, 10,  0 }, {     16,   -6,   68,  8, 10,  0 }, {     16,   -6,   69,  8, 10,  0 },
    {     16,   -6,   70,  8, 10,  0 }, {     16,   -6,   71,  8, 10,  0 }, {     16,   -6,   72,  8, 10,  0 }, {     16,   -6,   73,  8, 10,  0 }, {     16,   -6,   74,  8, 10,  0 },
    {     16,   -6,   75,  8, 10,  0 }, {     16,   -6,   76,  8, 10,  0 }, {     16,   -6,   77,  8, 10,  0 }, {     16,   -6,   78,  8, 10,  0 }, {     16,   -6,   79,  8, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90BF2E, {
    {     -6,   16,    0, 16, 10,  0 }, {     -6,   16,    1, 16, 10,  0 }, {     -6,   16,    2, 16, 10,  0 }, {     -6,   16,    3, 16, 10,  0 }, {     -6,   16,    4, 16, 10,  0 },
    {     -6,   16,    5, 16, 10,  0 }, {     -6,   16,    6, 16, 10,  0 }, {     -6,   16,    7, 16, 10,  0 }, {     -6,   16,    8, 16, 10,  0 }, {     -6,   16,    9, 16, 10,  0 },
    {     -6,   16,   10, 16, 10,  0 }, {     -6,   16,   11, 16, 10,  0 }, {     -6,   16,   12, 16, 10,  0 }, {     -6,   16,   13, 16, 10,  0 }, {     -6,   16,   14, 16, 10,  0 },
    {     -6,   16,   15, 16, 10,  0 }, {     -6,   16,   16, 16, 10,  0 }, {     -6,   16,   17, 16, 10,  0 }, {     -6,   16,   18, 16, 10,  0 }, {     -6,   16,   19, 16, 10,  0 },
    {     -6,   16,   20, 16, 10,  0 }, {     -6,   16,   21, 16, 10,  0 }, {     -6,   16,   22, 16, 10,  0 }, {     -6,   16,   23, 16, 10,  0 }, {     -6,   16,   24, 16, 10,  0 },
    {     -6,   16,   25, 16, 10,  0 }, {     -6,   16,   26, 16, 10,  0 }, {     -6,   16,   27, 16, 10,  0 }, {     -6,   16,   28, 16, 10,  0 }, {     -6,   16,   29, 16, 10,  0 },
    {     -6,   16,   30, 16, 10,  0 }, {     -6,   16,   31, 16, 10,  0 }, {     -6,   16,   32, 16, 10,  0 }, {     -6,   16,   33, 16, 10,  0 }, {     -6,   16,   34, 16, 10,  0 },
    {     -6,   16,   35, 16, 10,  0 }, {     -6,   16,   36, 16, 10,  0 }, {     -6,   16,   37, 16, 10,  0 }, {     -6,   16,   38, 16, 10,  0 }, {     -6,   16,   39, 16, 10,  0 },
    {     -6,   16,   40, 16, 10,  0 }, {     -6,   16,   41, 16, 10,  0 }, {     -6,   16,   42, 16, 10,  0 }, {     -6,   16,   43, 16, 10,  0 }, {     -6,   16,   44, 16, 10,  0 },
    {     -6,   16,   45, 16, 10,  0 }, {     -6,   16,   46, 16, 10,  0 }, {     -6,   16,   47, 16, 10,  0 }, {     -6,   16,   48, 16, 10,  0 }, {     -6,   16,   49, 16, 10,  0 },
    {     -6,   16,   50, 16, 10,  0 }, {     -6,   16,   51, 16, 10,  0 }, {     -6,   16,   52, 16, 10,  0 }, {     -6,   16,   53, 16, 10,  0 }, {     -6,   16,   54, 16, 10,  0 },
    {     -6,   16,   55, 16, 10,  0 }, {     -6,   16,   56, 16, 10,  0 }, {     -6,   16,   57, 16, 10,  0 }, {     -6,   16,   58, 16, 10,  0 }, {     -6,   16,   59, 16, 10,  0 },
    {     -6,   16,   60, 16, 10,  0 }, {     -6,   16,   61, 16, 10,  0 }, {     -6,   16,   62, 16, 10,  0 }, {     -6,   16,   63, 16, 10,  0 }, {     -6,   16,   64, 16, 10,  0 },
    {     -6,   16,   65, 16, 10,  0 }, {     -6,   16,   66, 16, 10,  0 }, {     -6,   16,   67, 16, 10,  0 }, {     -6,   16,   68, 16, 10,  0 }, {     -6,   16,   69, 16, 10,  0 },
    {     -6,   16,   70, 16, 10,  0 }, {     -6,   16,   71, 16, 10,  0 }, {     -6,   16,   72, 16, 10,  0 }, {     -6,   16,   73, 16, 10,  0 }, {     -6,   16,   74, 16, 10,  0 },
    {     -6,   16,   75, 16, 10,  0 }, {     -6,   16,   76, 16, 10,  0 }, {     -6,   16,   77, 16, 10,  0 }, {     -6,   16,   78, 16, 10,  0 }, {     -6,   16,   79, 16, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90C200, {
    {     16,   37,    0, 24, 10,  0 }, {     16,   37,    1, 24, 10,  0 }, {     16,   37,    2, 24, 10,  0 }, {     16,   37,    3, 24, 10,  0 }, {     16,   37,    4, 24, 10,  0 },
    {     16,   37,    5, 24, 10,  0 }, {     16,   37,    6, 24, 10,  0 }, {     16,   37,    7, 24, 10,  0 }, {     16,   37,    8, 24, 10,  0 }, {     16,   37,    9, 24, 10,  0 },
    {     16,   37,   10, 24, 10,  0 }, {     16,   37,   11, 24, 10,  0 }, {     16,   37,   12, 24, 10,  0 }, {     16,   37,   13, 24, 10,  0 }, {     16,   37,   14, 24, 10,  0 },
    {     16,   37,   15, 24, 10,  0 }, {     16,   37,   16, 24, 10,  0 }, {     16,   37,   17, 24, 10,  0 }, {     16,   37,   18, 24, 10,  0 }, {     16,   37,   19, 24, 10,  0 },
    {     16,   37,   20, 24, 10,  0 }, {     16,   37,   21, 24, 10,  0 }, {     16,   37,   22, 24, 10,  0 }, {     16,   37,   23, 24, 10,  0 }, {     16,   37,   24, 24, 10,  0 },
    {     16,   37,   25, 24, 10,  0 }, {     16,   37,   26, 24, 10,  0 }, {     16,   37,   27, 24, 10,  0 }, {     16,   37,   28, 24, 10,  0 }, {     16,   37,   29, 24, 10,  0 },
    {     16,   37,   30, 24, 10,  0 }, {     16,   37,   31, 24, 10,  0 }, {     16,   37,   32, 24, 10,  0 }, {     16,   37,   33, 24, 10,  0 }, {     16,   37,   34, 24, 10,  0 },
    {     16,   37,   35, 24, 10,  0 }, {     16,   37,   36, 24, 10,  0 }, {     16,   37,   37, 24, 10,  0 }, {     16,   37,   38, 24, 10,  0 }, {     16,   37,   39, 24, 10,  0 },
    {     16,   37,   40, 24, 10,  0 }, {     16,   37,   41, 24, 10,  0 }, {     16,   37,   42, 24, 10,  0 }, {     16,   37,   43, 24, 10,  0 }, {     16,   37,   44, 24, 10,  0 },
    {     16,   37,   45, 24, 10,  0 }, {     16,   37,   46, 24, 10,  0 }, {     16,   37,   47, 24, 10,  0 }, {     16,   37,   48, 24, 10,  0 }, {     16,   37,   49, 24, 10,  0 },
    {     16,   37,   50, 24, 10,  0 }, {     16,   37,   51, 24, 10,  0 }, {     16,   37,   52, 24, 10,  0 }, {     16,   37,   53, 24, 10,  0 }, {     16,   37,   54, 24, 10,  0 },
    {     16,   37,   55, 24, 10,  0 }, {     16,   37,   56, 24, 10,  0 }, {     16,   37,   57, 24, 10,  0 }, {     16,   37,   58, 24, 10,  0 }, {     16,   37,   59, 24, 10,  0 },
    {     16,   37,   60, 24, 10,  0 }, {     16,   37,   61, 24, 10,  0 }, {     16,   37,   62, 24, 10,  0 }, {     16,   37,   63, 24, 10,  0 }, {     16,   37,   64, 24, 10,  0 },
    {     16,   37,   65, 24, 10,  0 }, {     16,   37,   66, 24, 10,  0 }, {     16,   37,   67, 24, 10,  0 }, {     16,   37,   68, 24, 10,  0 }, {     16,   37,   69, 24, 10,  0 },
    {     16,   37,   70, 24, 10,  0 }, {     16,   37,   71, 24, 10,  0 }, {     16,   37,   72, 24, 10,  0 }, {     16,   37,   73, 24, 10,  0 }, {     16,   37,   74, 24, 10,  0 },
    {     16,   37,   75, 24, 10,  0 }, {     16,   37,   76, 24, 10,  0 }, {     16,   37,   77, 24, 10,  0 }, {     16,   37,   78, 24, 10,  0 }, {     16,   37,   79, 24, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90E02A, {
    {     16,   16,    0,  0, 10,  0 }, {     16,   16,    1,  0, 10,  0 }, {     16,   16,    2,  0, 10,  0 }, {     16,   16,    3,  0, 10,  0 }, {     16,   16,    4,  0, 10,  0 },
    {     16,   16,    5,  0, 10,  0 }, {     16,   16,    6,  0, 10,  0 }, {     16,   16,    7,  0, 10,  0 }, {     16,   16,    8,  0, 10,  0 }, {     16,   16,    9,  0, 10,  0 },
    {     16,   16,   10,  0, 10,  0 }, {     16,   16,   11,  0, 10,  0 }, {     16,   16,   12,  0, 10,  0 }, {     16,   16,   13,  0, 10,  0 }, {     16,   16,   14,  0, 10,  0 },
    {     16,   16,   15,  0, 10,  0 }, {     16,   16,   16,  0, 10,  0 }, {     16,   16,   17,  0, 10,  0 }, {     16,   16,   18,  0, 10,  0 }, {     16,   16,   19,  0, 10,  0 },
    {     16,   16,   20,  0, 10,  0 }, {     16,   16,   21,  0, 10,  0 }, {     16,   16,   22,  0, 10,  0 }, {     16,   16,   23,  0, 10,  0 }, {     16,   16,   24,  0, 10,  0 },
    {     16,   16,   25,  0, 10,  0 }, {     16,   16,   26,  0, 10,  0 }, {     16,   16,   27,  0, 10,  0 }, {     16,   16,   28,  0, 10,  0 }, {     16,   16,   29,  0, 10,  0 },
    {     16,   16,   30,  0, 10,  0 }, {     16,   16,   31,  0, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90E14C, {
    {     16,   15,    0,  8, 10,  0 }, {     16,   15,    1,  8, 10,  0 }, {     16,   15,    2,  8, 10,  0 }, {     16,   15,    3,  8, 10,  0 }, {     16,   15,    4,  8, 10,  0 },
    {     16,   15,    5,  8, 10,  0 }, {     16,   15,    6,  8, 10,  0 }, {     16,   15,    7,  8, 10,  0 }, {     16,   15,    8,  8, 10,  0 }, {     16,   15,    9,  8, 10,  0 },
    {     16,   15,   10,  8, 10,  0 }, {     16,   15,   11,  8, 10,  0 }, {     16,   15,   12,  8, 10,  0 }, {     16,   15,   13,  8, 10,  0 }, {     16,   15,   14,  8, 10,  0 },
    {     16,   15,   15,  8, 10,  0 }, {     16,   15,   16,  8, 10,  0 }, {     16,   15,   17,  8, 10,  0 }, {     16,   15,   18,  8, 10,  0 }, {     16,   15,   19,  8, 10,  0 },
    {     16,   15,   20,  8, 10,  0 }, {     16,   15,   21,  8, 10,  0 }, {     16,   15,   22,  8, 10,  0 }, {     16,   15,   23,  8, 10,  0 }, {     16,   15,   24,  8, 10,  0 },
    {     16,   15,   25,  8, 10,  0 }, {     16,   15,   26,  8, 10,  0 }, {     16,   15,   27,  8, 10,  0 }, {     16,   15,   28,  8, 10,  0 }, {     16,   15,   29,  8, 10,  0 },
    {     16,   15,   30,  8, 10,  0 }, {     16,   15,   31,  8, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90E26E, {
    {     15,   16,    0, 16, 10,  0 }, {     15,   16,    1, 16, 10,  0 }, {     15,   16,    2, 16, 10,  0 }, {     15,   16,    3, 16, 10,  0 }, {     15,   16,    4, 16, 10,  0 },
    {     15,   16,    5, 16, 10,  0 }, {     15,   16,    6, 16, 10,  0 }, {     15,   16,    7, 16, 10,  0 }, {     15,   16,    8, 16, 10,  0 }, {     15,   16,    9, 16, 10,  0 },
    {     15,   16,   10, 16, 10,  0 }, {     15,   16,   11, 16, 10,  0 }, {     15,   16,   12, 16, 10,  0 }, {     15,   16,   13, 16, 10,  0 }, {     15,   16,   14, 16, 10,  0 },
    {     15,   16,   15, 16, 10,  0 }, {     15,   16,   16, 16, 10,  0 }, {     15,   16,   17, 16, 10,  0 }, {     15,   16,   18, 16, 10,  0 }, {     15,   16,   19, 16, 10,  0 },
    {     15,   16,   20, 16, 10,  0 }, {     15,   16,   21, 16, 10,  0 }, {     15,   16,   22, 16, 10,  0 }, {     15,   16,   23, 16, 10,  0 }, {     15,   16,   24, 16, 10,  0 },
    {     15,   16,   25, 16, 10,  0 }, {     15,   16,   26, 16, 10,  0 }, {     15,   16,   27, 16, 10,  0 }, {     15,   16,   28, 16, 10,  0 }, {     15,   16,   29, 16, 10,  0 },
    {     15,   16,   30, 16, 10,  0 }, {     15,   16,   31, 16, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90E390, {
    {     16,   16,    0, 24, 10,  0 }, {     16,   16,    1, 24, 10,  0 }, {     16,   16,    2, 24, 10,  0 }, {     16,   16,    3, 24, 10,  0 }, {     16,   16,    4, 24, 10,  0 },
    {     16,   16,    5, 24, 10,  0 }, {     16,   16,    6, 24, 10,  0 }, {     16,   16,    7, 24, 10,  0 }, {     16,   16,    8, 24, 10,  0 }, {     16,   16,    9, 24, 10,  0 },
    {     16,   16,   10, 24, 10,  0 }, {     16,   16,   11, 24, 10,  0 }, {     16,   16,   12, 24, 10,  0 }, {     16,   16,   13, 24, 10,  0 }, {     16,   16,   14, 24, 10,  0 },
    {     16,   16,   15, 24, 10,  0 }, {     16,   16,   16, 24, 10,  0 }, {     16,   16,   17, 24, 10,  0 }, {     16,   16,   18, 24, 10,  0 }, {     16,   16,   19, 24, 10,  0 },
    {     16,   16,   20, 24, 10,  0 }, {     16,   16,   21, 24, 10,  0 }, {     16,   16,   22, 24, 10,  0 }, {     16,   16,   23, 24, 10,  0 }, {     16,   16,   24, 24, 10,  0 },
    {     16,   16,   25, 24, 10,  0 }, {     16,   16,   26, 24, 10,  0 }, {     16,   16,   27, 24, 10,  0 }, {     16,   16,   28, 24, 10,  0 }, {     16,   16,   29, 24, 10,  0 },
    {     16,   16,   30, 24, 10,  0 }, {     16,   16,   31, 24, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90E4B2, {
    {     16,   16,   31,  0, 18,  0 }, {     16,   16,   30,  0, 18,  0 }, {     16,   16,   29,  0, 18,  0 }, {     16,   16,   28,  0, 18,  0 }, {     16,   16,   27,  0, 18,  0 },
    {     16,   16,   26,  0, 18,  0 }, {     16,   16,   25,  0, 18,  0 }, {     16,   16,   24,  0, 18,  0 }, {     16,   16,   23,  0, 18,  0 }, {     16,   16,   22,  0, 18,  0 },
    {     16,   16,   21,  0, 18,  0 }, {     16,   16,   20,  0, 18,  0 }, {     16,   16,   19,  0, 18,  0 }, {     16,   16,   18,  0, 18,  0 }, {     16,   16,   17,  0, 18,  0 },
    {     16,   16,   16,  0, 18,  0 }, {     16,   16,   15,  0, 18,  0 }, {     16,   16,   14,  0, 18,  0 }, {     16,   16,   13,  0, 18,  0 }, {     16,   16,   12,  0, 18,  0 },
    {     16,   16,   11,  0, 18,  0 }, {     16,   16,   10,  0, 18,  0 }, {     16,   16,    9,  0, 18,  0 }, {     16,   16,    8,  0, 18,  0 }, {     16,   16,    7,  0, 18,  0 },
    {     16,   16,    6,  0, 18,  0 }, {     16,   16,    5,  0, 18,  0 }, {     16,   16,    4,  0, 18,  0 }, {     16,   16,    3,  0, 18,  0 }, {     16,   16,    2,  0, 18,  0 },
    {     16,   16,    1,  0, 18,  0 }, {     16,   16,    0,  0, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90E5D4, {
    {     16,   15,   31,  8, 18,  0 }, {     16,   15,   30,  8, 18,  0 }, {     16,   15,   29,  8, 18,  0 }, {     16,   15,   28,  8, 18,  0 }, {     16,   15,   27,  8, 18,  0 },
    {     16,   15,   26,  8, 18,  0 }, {     16,   15,   25,  8, 18,  0 }, {     16,   15,   24,  8, 18,  0 }, {     16,   15,   23,  8, 18,  0 }, {     16,   15,   22,  8, 18,  0 },
    {     16,   15,   21,  8, 18,  0 }, {     16,   15,   20,  8, 18,  0 }, {     16,   15,   19,  8, 18,  0 }, {     16,   15,   18,  8, 18,  0 }, {     16,   15,   17,  8, 18,  0 },
    {     16,   15,   16,  8, 18,  0 }, {     16,   15,   15,  8, 18,  0 }, {     16,   15,   14,  8, 18,  0 }, {     16,   15,   13,  8, 18,  0 }, {     16,   15,   12,  8, 18,  0 },
    {     16,   15,   11,  8, 18,  0 }, {     16,   15,   10,  8, 18,  0 }, {     16,   15,    9,  8, 18,  0 }, {     16,   15,    8,  8, 18,  0 }, {     16,   15,    7,  8, 18,  0 },
    {     16,   15,    6,  8, 18,  0 }, {     16,   15,    5,  8, 18,  0 }, {     16,   15,    4,  8, 18,  0 }, {     16,   15,    3,  8, 18,  0 }, {     16,   15,    2,  8, 18,  0 },
    {     16,   15,    1,  8, 18,  0 }, {     16,   15,    0,  8, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90E6F6, {
    {     15,   16,   31, 16, 18,  0 }, {     15,   16,   30, 16, 18,  0 }, {     15,   16,   29, 16, 18,  0 }, {     15,   16,   28, 16, 18,  0 }, {     15,   16,   27, 16, 18,  0 },
    {     15,   16,   26, 16, 18,  0 }, {     15,   16,   25, 16, 18,  0 }, {     15,   16,   24, 16, 18,  0 }, {     15,   16,   23, 16, 18,  0 }, {     15,   16,   22, 16, 18,  0 },
    {     15,   16,   21, 16, 18,  0 }, {     15,   16,   20, 16, 18,  0 }, {     15,   16,   19, 16, 18,  0 }, {     15,   16,   18, 16, 18,  0 }, {     15,   16,   17, 16, 18,  0 },
    {     15,   16,   16, 16, 18,  0 }, {     15,   16,   15, 16, 18,  0 }, {     15,   16,   14, 16, 18,  0 }, {     15,   16,   13, 16, 18,  0 }, {     15,   16,   12, 16, 18,  0 },
    {     15,   16,   11, 16, 18,  0 }, {     15,   16,   10, 16, 18,  0 }, {     15,   16,    9, 16, 18,  0 }, {     15,   16,    8, 16, 18,  0 }, {     15,   16,    7, 16, 18,  0 },
    {     15,   16,    6, 16, 18,  0 }, {     15,   16,    5, 16, 18,  0 }, {     15,   16,    4, 16, 18,  0 }, {     15,   16,    3, 16, 18,  0 }, {     15,   16,    2, 16, 18,  0 },
    {     15,   16,    1, 16, 18,  0 }, {     15,   16,    0, 16, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90E818, {
    {     16,   16,   31, 24, 18,  0 }, {     16,   16,   30, 24, 18,  0 }, {     16,   16,   29, 24, 18,  0 }, {     16,   16,   28, 24, 18,  0 }, {     16,   16,   27, 24, 18,  0 },
    {     16,   16,   26, 24, 18,  0 }, {     16,   16,   25, 24, 18,  0 }, {     16,   16,   24, 24, 18,  0 }, {     16,   16,   23, 24, 18,  0 }, {     16,   16,   22, 24, 18,  0 },
    {     16,   16,   21, 24, 18,  0 }, {     16,   16,   20, 24, 18,  0 }, {     16,   16,   19, 24, 18,  0 }, {     16,   16,   18, 24, 18,  0 }, {     16,   16,   17, 24, 18,  0 },
    {     16,   16,   16, 24, 18,  0 }, {     16,   16,   15, 24, 18,  0 }, {     16,   16,   14, 24, 18,  0 }, {     16,   16,   13, 24, 18,  0 }, {     16,   16,   12, 24, 18,  0 },
    {     16,   16,   11, 24, 18,  0 }, {     16,   16,   10, 24, 18,  0 }, {     16,   16,    9, 24, 18,  0 }, {     16,   16,    8, 24, 18,  0 }, {     16,   16,    7, 24, 18,  0 },
    {     16,   16,    6, 24, 18,  0 }, {     16,   16,    5, 24, 18,  0 }, {     16,   16,    4, 24, 18,  0 }, {     16,   16,    3, 24, 18,  0 }, {     16,   16,    2, 24, 18,  0 },
    {     16,   16,    1, 24, 18,  0 }, {     16,   16,    0, 24, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90E93A, {
    {     31,   16,    0,  0,  4,  0 }, {     31,   16,    1,  0,  4,  0 }, {     30,   16,    2,  0,  4,  0 }, {     30,   16,    3,  0,  4,  0 }, {     29,   16,    4,  0,  4,  0 },
    {     29,   16,    5,  0,  4,  0 }, {     28,   16,    6,  0,  4,  0 }, {     28,   16,    7,  0,  4,  0 }, {     27,   16,    8,  0,  4,  0 }, {     27,   16,    9,  0,  4,  0 },
    {     26,   16,   10,  0,  4,  0 }, {     26,   16,   11,  0,  4,  0 }, {     25,   16,   12,  0,  4,  0 }, {     25,   16,   13,  0,  4,  0 }, {     25,   16,   14,  0,  4,  0 },
    {     24,   16,   15,  0,  4,  0 }, {     24,   16,   16,  0,  4,  0 }, {     23,   16,   17,  0,  9,  0 }, {     23,   16,   18,  0,  9,  0 }, {     23,   16,   19,  0,  9,  0 },
    {     22,   16,   20,  0,  9,  0 }, {     22,   16,   21,  0,  9,  0 }, {     22,   16,   22,  0,  9,  0 }, {     21,   16,   23,  0,  9,  0 }, {     21,   16,   24,  0,  9,  0 },
    {     21,   16,   25,  0,  9,  0 }, {     21,   16,   26,  0,  9,  0 }, {     20,   16,   27,  0,  9,  0 }, {     20,   16,   28,  0,  9,  0 }, {     20,   16,   29,  0,  9,  0 },
    {     20,   16,   30,  0,  9,  0 }, {     19,   16,   31,  0,  9,  0 }, {     19,   16,   32,  0,  9,  0 }, {     19,   16,   33,  0,  9,  0 }, {     19,   16,   34,  0,  9,  0 },
    {     18,   16,   35,  0,  9,  0 }, {     18,   16,   36,  0,  9,  0 }, {     18,   16,   37,  0,  9,  0 }, {     18,   16,   38,  0,  9,  0 }, {     17,   16,   39,  0,  9,  0 },
    {     17,   16,   40,  0,  9,  0 }, {     17,   16,   41,  0,  9,  0 }, {     17,   16,   42,  0,  9,  0 }, {     17,   16,   43,  0, 10,  0 }, {     17,   16,   44,  0, 10,  0 },
    {     17,   16,   45,  0, 10,  0 }, {     16,   16,   46,  0, 10,  0 }, {     16,   16,   47,  0, 10,  0 }, {     16,   16,   48,  0, 10,  0 }, {     16,   16,   49,  0, 10,  0 },
    {     16,   16,   50,  0, 10,  0 }, {     16,   16,   51,  0, 10,  0 }, {     16,   16,   52,  0, 10,  0 }, {     16,   16,   53,  0, 10,  0 }, {     16,   16,   54,  0, 10,  0 },
    {     16,   16,   55,  0, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90EB34, {
    {     16,    0,    0,  8,  4,  0 }, {     16,    0,    1,  8,  4,  0 }, {     16,    1,    2,  8,  4,  0 }, {     16,    1,    3,  8,  4,  0 }, {     16,    2,    4,  8,  4,  0 },
    {     16,    2,    5,  8,  4,  0 }, {     16,    3,    6,  8,  4,  0 }, {     16,    3,    7,  8,  4,  0 }, {     16,    4,    8,  8,  4,  0 }, {     16,    4,    9,  8,  4,  0 },
    {     16,    5,   10,  8,  4,  0 }, {     16,    5,   11,  8,  4,  0 }, {     16,    6,   12,  8,  4,  0 }, {     16,    6,   13,  8,  4,  0 }, {     16,    6,   14,  8,  4,  0 },
    {     16,    7,   15,  8,  4,  0 }, {     16,    7,   16,  8,  4,  0 }, {     16,    8,   17,  8,  9,  0 }, {     16,    8,   18,  8,  9,  0 }, {     16,    8,   19,  8,  9,  0 },
    {     16,    9,   20,  8,  9,  0 }, {     16,    9,   21,  8,  9,  0 }, {     16,    9,   22,  8,  9,  0 }, {     16,   10,   23,  8,  9,  0 }, {     16,   10,   24,  8,  9,  0 },
    {     16,   10,   25,  8,  9,  0 }, {     16,   10,   26,  8,  9,  0 }, {     16,   11,   27,  8,  9,  0 }, {     16,   11,   28,  8,  9,  0 }, {     16,   11,   29,  8,  9,  0 },
    {     16,   11,   30,  8,  9,  0 }, {     16,   12,   31,  8,  9,  0 }, {     16,   12,   32,  8,  9,  0 }, {     16,   12,   33,  8,  9,  0 }, {     16,   12,   34,  8,  9,  0 },
    {     16,   13,   35,  8,  9,  0 }, {     16,   13,   36,  8,  9,  0 }, {     16,   13,   37,  8,  9,  0 }, {     16,   13,   38,  8,  9,  0 }, {     16,   14,   39,  8,  9,  0 },
    {     16,   14,   40,  8,  9,  0 }, {     16,   14,   41,  8,  9,  0 }, {     16,   14,   42,  8,  9,  0 }, {     16,   14,   43,  8, 10,  0 }, {     16,   14,   44,  8, 10,  0 },
    {     16,   14,   45,  8, 10,  0 }, {     16,   15,   46,  8, 10,  0 }, {     16,   15,   47,  8, 10,  0 }, {     16,   15,   48,  8, 10,  0 }, {     16,   15,   49,  8, 10,  0 },
    {     16,   15,   50,  8, 10,  0 }, {     16,   15,   51,  8, 10,  0 }, {     16,   15,   52,  8, 10,  0 }, {     16,   15,   53,  8, 10,  0 }, {     16,   15,   54,  8, 10,  0 },
    {     16,   15,   55,  8, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90ED2E, {
    {      0,   16,    0, 16,  4,  0 }, {      0,   16,    1, 16,  4,  0 }, {      1,   16,    2, 16,  4,  0 }, {      1,   16,    3, 16,  4,  0 }, {      2,   16,    4, 16,  4,  0 },
    {      2,   16,    5, 16,  4,  0 }, {      3,   16,    6, 16,  4,  0 }, {      3,   16,    7, 16,  4,  0 }, {      4,   16,    8, 16,  4,  0 }, {      4,   16,    9, 16,  4,  0 },
    {      5,   16,   10, 16,  4,  0 }, {      5,   16,   11, 16,  4,  0 }, {      6,   16,   12, 16,  4,  0 }, {      6,   16,   13, 16,  4,  0 }, {      6,   16,   14, 16,  4,  0 },
    {      7,   16,   15, 16,  4,  0 }, {      7,   16,   16, 16,  4,  0 }, {      8,   16,   17, 16,  9,  0 }, {      8,   16,   18, 16,  9,  0 }, {      8,   16,   19, 16,  9,  0 },
    {      9,   16,   20, 16,  9,  0 }, {      9,   16,   21, 16,  9,  0 }, {      9,   16,   22, 16,  9,  0 }, {     10,   16,   23, 16,  9,  0 }, {     10,   16,   24, 16,  9,  0 },
    {     10,   16,   25, 16,  9,  0 }, {     10,   16,   26, 16,  9,  0 }, {     11,   16,   27, 16,  9,  0 }, {     11,   16,   28, 16,  9,  0 }, {     11,   16,   29, 16,  9,  0 },
    {     11,   16,   30, 16,  9,  0 }, {     12,   16,   31, 16,  9,  0 }, {     12,   16,   32, 16,  9,  0 }, {     12,   16,   33, 16,  9,  0 }, {     12,   16,   34, 16,  9,  0 },
    {     13,   16,   35, 16,  9,  0 }, {     13,   16,   36, 16,  9,  0 }, {     13,   16,   37, 16,  9,  0 }, {     13,   16,   38, 16,  9,  0 }, {     14,   16,   39, 16,  9,  0 },
    {     14,   16,   40, 16,  9,  0 }, {     14,   16,   41, 16,  9,  0 }, {     14,   16,   42, 16,  9,  0 }, {     14,   16,   43, 16, 10,  0 }, {     14,   16,   44, 16, 10,  0 },
    {     14,   16,   45, 16, 10,  0 }, {     15,   16,   46, 16, 10,  0 }, {     15,   16,   47, 16, 10,  0 }, {     15,   16,   48, 16, 10,  0 }, {     15,   16,   49, 16, 10,  0 },
    {     15,   16,   50, 16, 10,  0 }, {     15,   16,   51, 16, 10,  0 }, {     15,   16,   52, 16, 10,  0 }, {     15,   16,   53, 16, 10,  0 }, {     15,   16,   54, 16, 10,  0 },
    {     15,   16,   55, 16, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90EF28, {
    {     16,   31,    0, 24,  4,  0 }, {     16,   31,    1, 24,  4,  0 }, {     16,   30,    2, 24,  4,  0 }, {     16,   30,    3, 24,  4,  0 }, {     16,   29,    4, 24,  4,  0 },
    {     16,   29,    5, 24,  4,  0 }, {     16,   28,    6, 24,  4,  0 }, {     16,   28,    7, 24,  4,  0 }, {     16,   27,    8, 24,  4,  0 }, {     16,   27,    9, 24,  4,  0 },
    {     16,   26,   10, 24,  4,  0 }, {     16,   26,   11, 24,  4,  0 }, {     16,   25,   12, 24,  4,  0 }, {     16,   25,   13, 24,  4,  0 }, {     16,   25,   14, 24,  4,  0 },
    {     16,   24,   15, 24,  4,  0 }, {     16,   24,   16, 24,  4,  0 }, {     16,   23,   17, 24,  9,  0 }, {     16,   23,   18, 24,  9,  0 }, {     16,   23,   19, 24,  9,  0 },
    {     16,   22,   20, 24,  9,  0 }, {     16,   22,   21, 24,  9,  0 }, {     16,   22,   22, 24,  9,  0 }, {     16,   21,   23, 24,  9,  0 }, {     16,   21,   24, 24,  9,  0 },
    {     16,   21,   25, 24,  9,  0 }, {     16,   21,   26, 24,  9,  0 }, {     16,   20,   27, 24,  9,  0 }, {     16,   20,   28, 24,  9,  0 }, {     16,   20,   29, 24,  9,  0 },
    {     16,   20,   30, 24,  9,  0 }, {     16,   19,   31, 24,  9,  0 }, {     16,   19,   32, 24,  9,  0 }, {     16,   19,   33, 24,  9,  0 }, {     16,   19,   34, 24,  9,  0 },
    {     16,   18,   35, 24,  9,  0 }, {     16,   18,   36, 24,  9,  0 }, {     16,   18,   37, 24,  9,  0 }, {     16,   18,   38, 24,  9,  0 }, {     16,   17,   39, 24,  9,  0 },
    {     16,   17,   40, 24,  9,  0 }, {     16,   17,   41, 24,  9,  0 }, {     16,   17,   42, 24,  9,  0 }, {     16,   17,   43, 24, 10,  0 }, {     16,   17,   44, 24, 10,  0 },
    {     16,   17,   45, 24, 10,  0 }, {     16,   16,   46, 24, 10,  0 }, {     16,   16,   47, 24, 10,  0 }, {     16,   16,   48, 24, 10,  0 }, {     16,   16,   49, 24, 10,  0 },
    {     16,   16,   50, 24, 10,  0 }, {     16,   16,   51, 24, 10,  0 }, {     16,   16,   52, 24, 10,  0 }, {     16,   16,   53, 24, 10,  0 }, {     16,   16,   54, 24, 10,  0 },
    {     16,   16,   55, 24, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9100F2, {
    {     16,   16,   55,  0, 18,  0 }, {     16,   16,   54,  0, 18,  0 }, {     16,   16,   53,  0, 18,  0 }, {     16,   16,   52,  0, 18,  0 }, {     16,   16,   51,  0, 18,  0 },
    {     16,   16,   50,  0, 18,  0 }, {     16,   16,   49,  0, 18,  0 }, {     16,   16,   48,  0, 18,  0 }, {     15,   16,   47,  0, 18,  0 }, {     15,   16,   46,  0, 18,  0 },
    {     15,   16,   45,  0, 18,  0 }, {     15,   16,   44,  0, 18,  0 }, {     15,   16,   43,  0, 18,  0 }, {     15,   16,   42,  0, 17,  0 }, {     15,   16,   41,  0, 17,  0 },
    {     14,   16,   40,  0, 17,  0 }, {     14,   16,   39,  0, 17,  0 }, {     14,   16,   38,  0, 17,  0 }, {     14,   16,   37,  0, 17,  0 }, {     13,   16,   36,  0, 17,  0 },
    {     13,   16,   35,  0, 17,  0 }, {     13,   16,   34,  0, 17,  0 }, {     13,   16,   33,  0, 17,  0 }, {     12,   16,   32,  0, 17,  0 }, {     12,   16,   31,  0, 17,  0 },
    {     12,   16,   30,  0, 17,  0 }, {     12,   16,   29,  0, 17,  0 }, {     11,   16,   28,  0, 17,  0 }, {     11,   16,   27,  0, 17,  0 }, {     11,   16,   26,  0, 17,  0 },
    {     11,   16,   25,  0, 17,  0 }, {     10,   16,   24,  0, 17,  0 }, {     10,   16,   23,  0, 17,  0 }, {     10,   16,   22,  0, 17,  0 }, {      9,   16,   21,  0, 17,  0 },
    {      9,   16,   20,  0, 17,  0 }, {      9,   16,   19,  0, 17,  0 }, {      8,   16,   18,  0,  8,  0 }, {      8,   16,   17,  0,  8,  0 }, {      7,   16,   16,  0,  8,  0 },
    {      7,   16,   15,  0,  8,  0 }, {      7,   16,   14,  0,  8,  0 }, {      6,   16,   13,  0,  8,  0 }, {      6,   16,   12,  0,  8,  0 }, {      5,   16,   11,  0,  8,  0 },
    {      5,   16,   10,  0,  8,  0 }, {      4,   16,    9,  0,  8,  0 }, {      4,   16,    8,  0,  8,  0 }, {      3,   16,    7,  0,  8,  0 }, {      3,   16,    6,  0,  8,  0 },
    {      2,   16,    5,  0,  8,  0 }, {      2,   16,    4,  0,  8,  0 }, {      1,   16,    3,  0,  8,  0 }, {      1,   16,    2,  0,  8,  0 }, {      0,   16,    1,  0,  8,  0 },
    {      0,   16,    0,  0,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9102EC, {
    {     16,   15,   55,  8, 18,  0 }, {     16,   15,   54,  8, 18,  0 }, {     16,   15,   53,  8, 18,  0 }, {     16,   15,   52,  8, 18,  0 }, {     16,   15,   51,  8, 18,  0 },
    {     16,   15,   50,  8, 18,  0 }, {     16,   15,   49,  8, 18,  0 }, {     16,   15,   48,  8, 18,  0 }, {     16,   16,   47,  8, 18,  0 }, {     16,   16,   46,  8, 18,  0 },
    {     16,   16,   45,  8, 18,  0 }, {     16,   16,   44,  8, 18,  0 }, {     16,   16,   43,  8, 18,  0 }, {     16,   16,   42,  8, 17,  0 }, {     16,   16,   41,  8, 17,  0 },
    {     16,   17,   40,  8, 17,  0 }, {     16,   17,   39,  8, 17,  0 }, {     16,   17,   38,  8, 17,  0 }, {     16,   17,   37,  8, 17,  0 }, {     16,   18,   36,  8, 17,  0 },
    {     16,   18,   35,  8, 17,  0 }, {     16,   18,   34,  8, 17,  0 }, {     16,   18,   33,  8, 17,  0 }, {     16,   19,   32,  8, 17,  0 }, {     16,   19,   31,  8, 17,  0 },
    {     16,   19,   30,  8, 17,  0 }, {     16,   19,   29,  8, 17,  0 }, {     16,   20,   28,  8, 17,  0 }, {     16,   20,   27,  8, 17,  0 }, {     16,   20,   26,  8, 17,  0 },
    {     16,   20,   25,  8, 17,  0 }, {     16,   21,   24,  8, 17,  0 }, {     16,   21,   23,  8, 17,  0 }, {     16,   21,   22,  8, 17,  0 }, {     16,   22,   21,  8, 17,  0 },
    {     16,   22,   20,  8, 17,  0 }, {     16,   22,   19,  8, 17,  0 }, {     16,   23,   18,  8,  8,  0 }, {     16,   23,   17,  8,  8,  0 }, {     16,   24,   16,  8,  8,  0 },
    {     16,   24,   15,  8,  8,  0 }, {     16,   24,   14,  8,  8,  0 }, {     16,   25,   13,  8,  8,  0 }, {     16,   25,   12,  8,  8,  0 }, {     16,   26,   11,  8,  8,  0 },
    {     16,   26,   10,  8,  8,  0 }, {     16,   27,    9,  8,  8,  0 }, {     16,   27,    8,  8,  8,  0 }, {     16,   28,    7,  8,  8,  0 }, {     16,   28,    6,  8,  8,  0 },
    {     16,   29,    5,  8,  8,  0 }, {     16,   29,    4,  8,  8,  0 }, {     16,   30,    3,  8,  8,  0 }, {     16,   30,    2,  8,  8,  0 }, {     16,   31,    1,  8,  8,  0 },
    {     16,   31,    0,  8,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9104E6, {
    {     15,   16,   55, 16, 18,  0 }, {     15,   16,   54, 16, 18,  0 }, {     15,   16,   53, 16, 18,  0 }, {     15,   16,   52, 16, 18,  0 }, {     15,   16,   51, 16, 18,  0 },
    {     15,   16,   50, 16, 18,  0 }, {     15,   16,   49, 16, 18,  0 }, {     15,   16,   48, 16, 18,  0 }, {     16,   16,   47, 16, 18,  0 }, {     16,   16,   46, 16, 18,  0 },
    {     16,   16,   45, 16, 18,  0 }, {     16,   16,   44, 16, 18,  0 }, {     16,   16,   43, 16, 18,  0 }, {     16,   16,   42, 16, 17,  0 }, {     16,   16,   41, 16, 17,  0 },
    {     17,   16,   40, 16, 17,  0 }, {     17,   16,   39, 16, 17,  0 }, {     17,   16,   38, 16, 17,  0 }, {     17,   16,   37, 16, 17,  0 }, {     18,   16,   36, 16, 17,  0 },
    {     18,   16,   35, 16, 17,  0 }, {     18,   16,   34, 16, 17,  0 }, {     18,   16,   33, 16, 17,  0 }, {     19,   16,   32, 16, 17,  0 }, {     19,   16,   31, 16, 17,  0 },
    {     19,   16,   30, 16, 17,  0 }, {     19,   16,   29, 16, 17,  0 }, {     20,   16,   28, 16, 17,  0 }, {     20,   16,   27, 16, 17,  0 }, {     20,   16,   26, 16, 17,  0 },
    {     20,   16,   25, 16, 17,  0 }, {     21,   16,   24, 16, 17,  0 }, {     21,   16,   23, 16, 17,  0 }, {     21,   16,   22, 16, 17,  0 }, {     22,   16,   21, 16, 17,  0 },
    {     22,   16,   20, 16, 17,  0 }, {     22,   16,   19, 16, 17,  0 }, {     23,   16,   18, 16,  8,  0 }, {     23,   16,   17, 16,  8,  0 }, {     24,   16,   16, 16,  8,  0 },
    {     24,   16,   15, 16,  8,  0 }, {     24,   16,   14, 16,  8,  0 }, {     25,   16,   13, 16,  8,  0 }, {     25,   16,   12, 16,  8,  0 }, {     26,   16,   11, 16,  8,  0 },
    {     26,   16,   10, 16,  8,  0 }, {     27,   16,    9, 16,  8,  0 }, {     27,   16,    8, 16,  8,  0 }, {     28,   16,    7, 16,  8,  0 }, {     28,   16,    6, 16,  8,  0 },
    {     29,   16,    5, 16,  8,  0 }, {     29,   16,    4, 16,  8,  0 }, {     30,   16,    3, 16,  8,  0 }, {     30,   16,    2, 16,  8,  0 }, {     31,   16,    1, 16,  8,  0 },
    {     31,   16,    0, 16,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9106E0, {
    {     16,   16,   55, 24, 18,  0 }, {     16,   16,   54, 24, 18,  0 }, {     16,   16,   53, 24, 18,  0 }, {     16,   16,   52, 24, 18,  0 }, {     16,   16,   51, 24, 18,  0 },
    {     16,   16,   50, 24, 18,  0 }, {     16,   16,   49, 24, 18,  0 }, {     16,   16,   48, 24, 18,  0 }, {     16,   15,   47, 24, 18,  0 }, {     16,   15,   46, 24, 18,  0 },
    {     16,   15,   45, 24, 18,  0 }, {     16,   15,   44, 24, 18,  0 }, {     16,   15,   43, 24, 18,  0 }, {     16,   15,   42, 24, 17,  0 }, {     16,   15,   41, 24, 17,  0 },
    {     16,   14,   40, 24, 17,  0 }, {     16,   14,   39, 24, 17,  0 }, {     16,   14,   38, 24, 17,  0 }, {     16,   14,   37, 24, 17,  0 }, {     16,   13,   36, 24, 17,  0 },
    {     16,   13,   35, 24, 17,  0 }, {     16,   13,   34, 24, 17,  0 }, {     16,   13,   33, 24, 17,  0 }, {     16,   12,   32, 24, 17,  0 }, {     16,   12,   31, 24, 17,  0 },
    {     16,   12,   30, 24, 17,  0 }, {     16,   12,   29, 24, 17,  0 }, {     16,   11,   28, 24, 17,  0 }, {     16,   11,   27, 24, 17,  0 }, {     16,   11,   26, 24, 17,  0 },
    {     16,   11,   25, 24, 17,  0 }, {     16,   10,   24, 24, 17,  0 }, {     16,   10,   23, 24, 17,  0 }, {     16,   10,   22, 24, 17,  0 }, {     16,    9,   21, 24, 17,  0 },
    {     16,    9,   20, 24, 17,  0 }, {     16,    9,   19, 24, 17,  0 }, {     16,    8,   18, 24,  8,  0 }, {     16,    8,   17, 24,  8,  0 }, {     16,    7,   16, 24,  8,  0 },
    {     16,    7,   15, 24,  8,  0 }, {     16,    7,   14, 24,  8,  0 }, {     16,    6,   13, 24,  8,  0 }, {     16,    6,   12, 24,  8,  0 }, {     16,    5,   11, 24,  8,  0 },
    {     16,    5,   10, 24,  8,  0 }, {     16,    4,    9, 24,  8,  0 }, {     16,    4,    8, 24,  8,  0 }, {     16,    3,    7, 24,  8,  0 }, {     16,    3,    6, 24,  8,  0 },
    {     16,    2,    5, 24,  8,  0 }, {     16,    2,    4, 24,  8,  0 }, {     16,    1,    3, 24,  8,  0 }, {     16,    1,    2, 24,  8,  0 }, {     16,    0,    1, 24,  8,  0 },
    {     16,    0,    0, 24,  8,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90F122, {
    {     16,   16,    0,  0, 10,  0 }, {     16,   16,    1,  0, 10,  0 }, {     16,   16,    2,  0, 10,  0 }, {     16,   16,    3,  0, 10,  0 }, {     16,   16,    4,  0, 10,  0 },
    {     16,   16,    5,  0, 10,  0 }, {     16,   16,    6,  0, 10,  0 }, {     16,   16,    7,  0, 10,  0 }, {     15,   16,    8,  0, 10,  0 }, {     15,   16,    9,  0, 10,  0 },
    {     15,   16,   10,  0, 10,  0 }, {     15,   16,   11,  0, 10,  0 }, {     15,   16,   12,  0, 10,  0 }, {     15,   16,   13,  0,  9,  0 }, {     15,   16,   14,  0,  9,  0 },
    {     14,   16,   15,  0,  9,  0 }, {     14,   16,   16,  0,  9,  0 }, {     14,   16,   17,  0,  9,  0 }, {     14,   16,   18,  0,  9,  0 }, {     13,   16,   19,  0,  9,  0 },
    {     13,   16,   20,  0,  9,  0 }, {     13,   16,   21,  0,  9,  0 }, {     13,   16,   22,  0,  9,  0 }, {     12,   16,   23,  0,  9,  0 }, {     12,   16,   24,  0,  9,  0 },
    {     12,   16,   25,  0,  9,  0 }, {     12,   16,   26,  0,  9,  0 }, {     11,   16,   27,  0,  9,  0 }, {     11,   16,   28,  0,  9,  0 }, {     11,   16,   29,  0,  9,  0 },
    {     11,   16,   30,  0,  9,  0 }, {     10,   16,   31,  0,  9,  0 }, {     10,   16,   32,  0,  9,  0 }, {     10,   16,   33,  0,  9,  0 }, {      9,   16,   34,  0,  9,  0 },
    {      9,   16,   35,  0,  9,  0 }, {      9,   16,   36,  0,  9,  0 }, {      8,   16,   37,  0,  4,  0 }, {      8,   16,   38,  0,  4,  0 }, {      7,   16,   39,  0,  4,  0 },
    {      7,   16,   40,  0,  4,  0 }, {      7,   16,   41,  0,  4,  0 }, {      6,   16,   42,  0,  4,  0 }, {      6,   16,   43,  0,  4,  0 }, {      5,   16,   44,  0,  4,  0 },
    {      5,   16,   45,  0,  4,  0 }, {      4,   16,   46,  0,  4,  0 }, {      4,   16,   47,  0,  4,  0 }, {      3,   16,   48,  0,  4,  0 }, {      3,   16,   49,  0,  4,  0 },
    {      2,   16,   50,  0,  4,  0 }, {      2,   16,   51,  0,  4,  0 }, {      1,   16,   52,  0,  4,  0 }, {      1,   16,   53,  0,  4,  0 }, {      0,   16,   54,  0,  4,  0 },
    {      0,   16,   55,  0,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90F31C, {
    {     16,   15,    0,  8, 10,  0 }, {     16,   15,    1,  8, 10,  0 }, {     16,   15,    2,  8, 10,  0 }, {     16,   15,    3,  8, 10,  0 }, {     16,   15,    4,  8, 10,  0 },
    {     16,   15,    5,  8, 10,  0 }, {     16,   15,    6,  8, 10,  0 }, {     16,   15,    7,  8, 10,  0 }, {     16,   16,    8,  8, 10,  0 }, {     16,   16,    9,  8, 10,  0 },
    {     16,   16,   10,  8, 10,  0 }, {     16,   16,   11,  8, 10,  0 }, {     16,   16,   12,  8, 10,  0 }, {     16,   16,   13,  8,  9,  0 }, {     16,   16,   14,  8,  9,  0 },
    {     16,   17,   15,  8,  9,  0 }, {     16,   17,   16,  8,  9,  0 }, {     16,   17,   17,  8,  9,  0 }, {     16,   17,   18,  8,  9,  0 }, {     16,   18,   19,  8,  9,  0 },
    {     16,   18,   20,  8,  9,  0 }, {     16,   18,   21,  8,  9,  0 }, {     16,   18,   22,  8,  9,  0 }, {     16,   19,   23,  8,  9,  0 }, {     16,   19,   24,  8,  9,  0 },
    {     16,   19,   25,  8,  9,  0 }, {     16,   19,   26,  8,  9,  0 }, {     16,   20,   27,  8,  9,  0 }, {     16,   20,   28,  8,  9,  0 }, {     16,   20,   29,  8,  9,  0 },
    {     16,   20,   30,  8,  9,  0 }, {     16,   21,   31,  8,  9,  0 }, {     16,   21,   32,  8,  9,  0 }, {     16,   21,   33,  8,  9,  0 }, {     16,   22,   34,  8,  9,  0 },
    {     16,   22,   35,  8,  9,  0 }, {     16,   22,   36,  8,  9,  0 }, {     16,   23,   37,  8,  4,  0 }, {     16,   23,   38,  8,  4,  0 }, {     16,   24,   39,  8,  4,  0 },
    {     16,   24,   40,  8,  4,  0 }, {     16,   24,   41,  8,  4,  0 }, {     16,   25,   42,  8,  4,  0 }, {     16,   25,   43,  8,  4,  0 }, {     16,   26,   44,  8,  4,  0 },
    {     16,   26,   45,  8,  4,  0 }, {     16,   27,   46,  8,  4,  0 }, {     16,   27,   47,  8,  4,  0 }, {     16,   28,   48,  8,  4,  0 }, {     16,   28,   49,  8,  4,  0 },
    {     16,   29,   50,  8,  4,  0 }, {     16,   29,   51,  8,  4,  0 }, {     16,   30,   52,  8,  4,  0 }, {     16,   30,   53,  8,  4,  0 }, {     16,   31,   54,  8,  4,  0 },
    {     16,   31,   55,  8,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90F516, {
    {     15,   16,    0, 16, 10,  0 }, {     15,   16,    1, 16, 10,  0 }, {     15,   16,    2, 16, 10,  0 }, {     15,   16,    3, 16, 10,  0 }, {     15,   16,    4, 16, 10,  0 },
    {     15,   16,    5, 16, 10,  0 }, {     15,   16,    6, 16, 10,  0 }, {     15,   16,    7, 16, 10,  0 }, {     16,   16,    8, 16, 10,  0 }, {     16,   16,    9, 16, 10,  0 },
    {     16,   16,   10, 16, 10,  0 }, {     16,   16,   11, 16, 10,  0 }, {     16,   16,   12, 16, 10,  0 }, {     16,   16,   13, 16,  9,  0 }, {     16,   16,   14, 16,  9,  0 },
    {     17,   16,   15, 16,  9,  0 }, {     17,   16,   16, 16,  9,  0 }, {     17,   16,   17, 16,  9,  0 }, {     17,   16,   18, 16,  9,  0 }, {     18,   16,   19, 16,  9,  0 },
    {     18,   16,   20, 16,  9,  0 }, {     18,   16,   21, 16,  9,  0 }, {     18,   16,   22, 16,  9,  0 }, {     19,   16,   23, 16,  9,  0 }, {     19,   16,   24, 16,  9,  0 },
    {     19,   16,   25, 16,  9,  0 }, {     19,   16,   26, 16,  9,  0 }, {     20,   16,   27, 16,  9,  0 }, {     20,   16,   28, 16,  9,  0 }, {     20,   16,   29, 16,  9,  0 },
    {     20,   16,   30, 16,  9,  0 }, {     21,   16,   31, 16,  9,  0 }, {     21,   16,   32, 16,  9,  0 }, {     21,   16,   33, 16,  9,  0 }, {     22,   16,   34, 16,  9,  0 },
    {     22,   16,   35, 16,  9,  0 }, {     22,   16,   36, 16,  9,  0 }, {     23,   16,   37, 16,  4,  0 }, {     23,   16,   38, 16,  4,  0 }, {     24,   16,   39, 16,  4,  0 },
    {     24,   16,   40, 16,  4,  0 }, {     24,   16,   41, 16,  4,  0 }, {     25,   16,   42, 16,  4,  0 }, {     25,   16,   43, 16,  4,  0 }, {     26,   16,   44, 16,  4,  0 },
    {     26,   16,   45, 16,  4,  0 }, {     27,   16,   46, 16,  4,  0 }, {     27,   16,   47, 16,  4,  0 }, {     28,   16,   48, 16,  4,  0 }, {     28,   16,   49, 16,  4,  0 },
    {     29,   16,   50, 16,  4,  0 }, {     29,   16,   51, 16,  4,  0 }, {     30,   16,   52, 16,  4,  0 }, {     30,   16,   53, 16,  4,  0 }, {     31,   16,   54, 16,  4,  0 },
    {     31,   16,   55, 16,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90F710, {
    {     16,   16,    0, 24, 10,  0 }, {     16,   16,    1, 24, 10,  0 }, {     16,   16,    2, 24, 10,  0 }, {     16,   16,    3, 24, 10,  0 }, {     16,   16,    4, 24, 10,  0 },
    {     16,   16,    5, 24, 10,  0 }, {     16,   16,    6, 24, 10,  0 }, {     16,   16,    7, 24, 10,  0 }, {     16,   15,    8, 24, 10,  0 }, {     16,   15,    9, 24, 10,  0 },
    {     16,   15,   10, 24, 10,  0 }, {     16,   15,   11, 24, 10,  0 }, {     16,   15,   12, 24, 10,  0 }, {     16,   15,   13, 24,  9,  0 }, {     16,   15,   14, 24,  9,  0 },
    {     16,   14,   15, 24,  9,  0 }, {     16,   14,   16, 24,  9,  0 }, {     16,   14,   17, 24,  9,  0 }, {     16,   14,   18, 24,  9,  0 }, {     16,   13,   19, 24,  9,  0 },
    {     16,   13,   20, 24,  9,  0 }, {     16,   13,   21, 24,  9,  0 }, {     16,   13,   22, 24,  9,  0 }, {     16,   12,   23, 24,  9,  0 }, {     16,   12,   24, 24,  9,  0 },
    {     16,   12,   25, 24,  9,  0 }, {     16,   12,   26, 24,  9,  0 }, {     16,   11,   27, 24,  9,  0 }, {     16,   11,   28, 24,  9,  0 }, {     16,   11,   29, 24,  9,  0 },
    {     16,   11,   30, 24,  9,  0 }, {     16,   10,   31, 24,  9,  0 }, {     16,   10,   32, 24,  9,  0 }, {     16,   10,   33, 24,  9,  0 }, {     16,    9,   34, 24,  9,  0 },
    {     16,    9,   35, 24,  9,  0 }, {     16,    9,   36, 24,  9,  0 }, {     16,    8,   37, 24,  4,  0 }, {     16,    8,   38, 24,  4,  0 }, {     16,    7,   39, 24,  4,  0 },
    {     16,    7,   40, 24,  4,  0 }, {     16,    7,   41, 24,  4,  0 }, {     16,    6,   42, 24,  4,  0 }, {     16,    6,   43, 24,  4,  0 }, {     16,    5,   44, 24,  4,  0 },
    {     16,    5,   45, 24,  4,  0 }, {     16,    4,   46, 24,  4,  0 }, {     16,    4,   47, 24,  4,  0 }, {     16,    3,   48, 24,  4,  0 }, {     16,    3,   49, 24,  4,  0 },
    {     16,    2,   50, 24,  4,  0 }, {     16,    2,   51, 24,  4,  0 }, {     16,    1,   52, 24,  4,  0 }, {     16,    1,   53, 24,  4,  0 }, {     16,    0,   54, 24,  4,  0 },
    {     16,    0,   55, 24,  4,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90F90A, {
    {     31,   16,   55,  0,  8,  0 }, {     31,   16,   54,  0,  8,  0 }, {     30,   16,   53,  0,  8,  0 }, {     30,   16,   52,  0,  8,  0 }, {     29,   16,   51,  0,  8,  0 },
    {     29,   16,   50,  0,  8,  0 }, {     28,   16,   49,  0,  8,  0 }, {     28,   16,   48,  0,  8,  0 }, {     27,   16,   47,  0,  8,  0 }, {     27,   16,   46,  0,  8,  0 },
    {     26,   16,   45,  0,  8,  0 }, {     26,   16,   44,  0,  8,  0 }, {     25,   16,   43,  0,  8,  0 }, {     25,   16,   42,  0,  8,  0 }, {     25,   16,   41,  0,  8,  0 },
    {     24,   16,   40,  0,  8,  0 }, {     24,   16,   39,  0,  8,  0 }, {     23,   16,   38,  0, 17,  0 }, {     23,   16,   37,  0, 17,  0 }, {     23,   16,   36,  0, 17,  0 },
    {     22,   16,   35,  0, 17,  0 }, {     22,   16,   34,  0, 17,  0 }, {     22,   16,   33,  0, 17,  0 }, {     21,   16,   32,  0, 17,  0 }, {     21,   16,   31,  0, 17,  0 },
    {     21,   16,   30,  0, 17,  0 }, {     21,   16,   29,  0, 17,  0 }, {     20,   16,   28,  0, 17,  0 }, {     20,   16,   27,  0, 17,  0 }, {     20,   16,   26,  0, 17,  0 },
    {     20,   16,   25,  0, 17,  0 }, {     19,   16,   24,  0, 17,  0 }, {     19,   16,   23,  0, 17,  0 }, {     19,   16,   22,  0, 17,  0 }, {     19,   16,   21,  0, 17,  0 },
    {     18,   16,   20,  0, 17,  0 }, {     18,   16,   19,  0, 17,  0 }, {     18,   16,   18,  0, 17,  0 }, {     18,   16,   17,  0, 17,  0 }, {     17,   16,   16,  0, 17,  0 },
    {     17,   16,   15,  0, 17,  0 }, {     17,   16,   14,  0, 17,  0 }, {     17,   16,   13,  0, 17,  0 }, {     17,   16,   12,  0, 18,  0 }, {     17,   16,   11,  0, 18,  0 },
    {     17,   16,   10,  0, 18,  0 }, {     16,   16,    9,  0, 18,  0 }, {     16,   16,    8,  0, 18,  0 }, {     16,   16,    7,  0, 18,  0 }, {     16,   16,    6,  0, 18,  0 },
    {     16,   16,    5,  0, 18,  0 }, {     16,   16,    4,  0, 18,  0 }, {     16,   16,    3,  0, 18,  0 }, {     16,   16,    2,  0, 18,  0 }, {     16,   16,    1,  0, 18,  0 },
    {     16,   16,    0,  0, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90FB04, {
    {     16,    0,   55,  8,  8,  0 }, {     16,    0,   54,  8,  8,  0 }, {     16,    1,   53,  8,  8,  0 }, {     16,    1,   52,  8,  8,  0 }, {     16,    2,   51,  8,  8,  0 },
    {     16,    2,   50,  8,  8,  0 }, {     16,    3,   49,  8,  8,  0 }, {     16,    3,   48,  8,  8,  0 }, {     16,    4,   47,  8,  8,  0 }, {     16,    4,   46,  8,  8,  0 },
    {     16,    5,   45,  8,  8,  0 }, {     16,    5,   44,  8,  8,  0 }, {     16,    6,   43,  8,  8,  0 }, {     16,    6,   42,  8,  8,  0 }, {     16,    6,   41,  8,  8,  0 },
    {     16,    7,   40,  8,  8,  0 }, {     16,    7,   39,  8,  8,  0 }, {     16,    8,   38,  8, 17,  0 }, {     16,    8,   37,  8, 17,  0 }, {     16,    8,   36,  8, 17,  0 },
    {     16,    9,   35,  8, 17,  0 }, {     16,    9,   34,  8, 17,  0 }, {     16,    9,   33,  8, 17,  0 }, {     16,   10,   32,  8, 17,  0 }, {     16,   10,   31,  8, 17,  0 },
    {     16,   10,   30,  8, 17,  0 }, {     16,   10,   29,  8, 17,  0 }, {     16,   11,   28,  8, 17,  0 }, {     16,   11,   27,  8, 17,  0 }, {     16,   11,   26,  8, 17,  0 },
    {     16,   11,   25,  8, 17,  0 }, {     16,   12,   24,  8, 17,  0 }, {     16,   12,   23,  8, 17,  0 }, {     16,   12,   22,  8, 17,  0 }, {     16,   12,   21,  8, 17,  0 },
    {     16,   13,   20,  8, 17,  0 }, {     16,   13,   19,  8, 17,  0 }, {     16,   13,   18,  8, 17,  0 }, {     16,   13,   17,  8, 17,  0 }, {     16,   14,   16,  8, 17,  0 },
    {     16,   14,   15,  8, 17,  0 }, {     16,   14,   14,  8, 17,  0 }, {     16,   14,   13,  8, 17,  0 }, {     16,   14,   12,  8, 18,  0 }, {     16,   14,   11,  8, 18,  0 },
    {     16,   14,   10,  8, 18,  0 }, {     16,   15,    9,  8, 18,  0 }, {     16,   15,    8,  8, 18,  0 }, {     16,   15,    7,  8, 18,  0 }, {     16,   15,    6,  8, 18,  0 },
    {     16,   15,    5,  8, 18,  0 }, {     16,   15,    4,  8, 18,  0 }, {     16,   15,    3,  8, 18,  0 }, {     16,   15,    2,  8, 18,  0 }, {     16,   15,    1,  8, 18,  0 },
    {     16,   15,    0,  8, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90FCFE, {
    {      0,   16,   55, 16,  8,  0 }, {      0,   16,   54, 16,  8,  0 }, {      1,   16,   53, 16,  8,  0 }, {      1,   16,   52, 16,  8,  0 }, {      2,   16,   51, 16,  8,  0 },
    {      2,   16,   50, 16,  8,  0 }, {      3,   16,   49, 16,  8,  0 }, {      3,   16,   48, 16,  8,  0 }, {      4,   16,   47, 16,  8,  0 }, {      4,   16,   46, 16,  8,  0 },
    {      5,   16,   45, 16,  8,  0 }, {      5,   16,   44, 16,  8,  0 }, {      6,   16,   43, 16,  8,  0 }, {      6,   16,   42, 16,  8,  0 }, {      6,   16,   41, 16,  8,  0 },
    {      7,   16,   40, 16,  8,  0 }, {      7,   16,   39, 16,  8,  0 }, {      8,   16,   38, 16, 17,  0 }, {      8,   16,   37, 16, 17,  0 }, {      8,   16,   36, 16, 17,  0 },
    {      9,   16,   35, 16, 17,  0 }, {      9,   16,   34, 16, 17,  0 }, {      9,   16,   33, 16, 17,  0 }, {     10,   16,   32, 16, 17,  0 }, {     10,   16,   31, 16, 17,  0 },
    {     10,   16,   30, 16, 17,  0 }, {     10,   16,   29, 16, 17,  0 }, {     11,   16,   28, 16, 17,  0 }, {     11,   16,   27, 16, 17,  0 }, {     11,   16,   26, 16, 17,  0 },
    {     11,   16,   25, 16, 17,  0 }, {     12,   16,   24, 16, 17,  0 }, {     12,   16,   23, 16, 17,  0 }, {     12,   16,   22, 16, 17,  0 }, {     12,   16,   21, 16, 17,  0 },
    {     13,   16,   20, 16, 17,  0 }, {     13,   16,   19, 16, 17,  0 }, {     13,   16,   18, 16, 17,  0 }, {     13,   16,   17, 16, 17,  0 }, {     14,   16,   16, 16, 17,  0 },
    {     14,   16,   15, 16, 17,  0 }, {     14,   16,   14, 16, 17,  0 }, {     14,   16,   13, 16, 17,  0 }, {     14,   16,   12, 16, 18,  0 }, {     14,   16,   11, 16, 18,  0 },
    {     14,   16,   10, 16, 18,  0 }, {     15,   16,    9, 16, 18,  0 }, {     15,   16,    8, 16, 18,  0 }, {     15,   16,    7, 16, 18,  0 }, {     15,   16,    6, 16, 18,  0 },
    {     15,   16,    5, 16, 18,  0 }, {     15,   16,    4, 16, 18,  0 }, {     15,   16,    3, 16, 18,  0 }, {     15,   16,    2, 16, 18,  0 }, {     15,   16,    1, 16, 18,  0 },
    {     15,   16,    0, 16, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90FEF8, {
    {     16,   31,   55, 24,  8,  0 }, {     16,   31,   54, 24,  8,  0 }, {     16,   30,   53, 24,  8,  0 }, {     16,   30,   52, 24,  8,  0 }, {     16,   29,   51, 24,  8,  0 },
    {     16,   29,   50, 24,  8,  0 }, {     16,   28,   49, 24,  8,  0 }, {     16,   28,   48, 24,  8,  0 }, {     16,   27,   47, 24,  8,  0 }, {     16,   27,   46, 24,  8,  0 },
    {     16,   26,   45, 24,  8,  0 }, {     16,   26,   44, 24,  8,  0 }, {     16,   25,   43, 24,  8,  0 }, {     16,   25,   42, 24,  8,  0 }, {     16,   25,   41, 24,  8,  0 },
    {     16,   24,   40, 24,  8,  0 }, {     16,   24,   39, 24,  8,  0 }, {     16,   23,   38, 24, 17,  0 }, {     16,   23,   37, 24, 17,  0 }, {     16,   23,   36, 24, 17,  0 },
    {     16,   22,   35, 24, 17,  0 }, {     16,   22,   34, 24, 17,  0 }, {     16,   22,   33, 24, 17,  0 }, {     16,   21,   32, 24, 17,  0 }, {     16,   21,   31, 24, 17,  0 },
    {     16,   21,   30, 24, 17,  0 }, {     16,   21,   29, 24, 17,  0 }, {     16,   20,   28, 24, 17,  0 }, {     16,   20,   27, 24, 17,  0 }, {     16,   20,   26, 24, 17,  0 },
    {     16,   20,   25, 24, 17,  0 }, {     16,   19,   24, 24, 17,  0 }, {     16,   19,   23, 24, 17,  0 }, {     16,   19,   22, 24, 17,  0 }, {     16,   19,   21, 24, 17,  0 },
    {     16,   18,   20, 24, 17,  0 }, {     16,   18,   19, 24, 17,  0 }, {     16,   18,   18, 24, 17,  0 }, {     16,   18,   17, 24, 17,  0 }, {     16,   17,   16, 24, 17,  0 },
    {     16,   17,   15, 24, 17,  0 }, {     16,   17,   14, 24, 17,  0 }, {     16,   17,   13, 24, 17,  0 }, {     16,   17,   12, 24, 18,  0 }, {     16,   17,   11, 24, 18,  0 },
    {     16,   17,   10, 24, 18,  0 }, {     16,   16,    9, 24, 18,  0 }, {     16,   16,    8, 24, 18,  0 }, {     16,   16,    7, 24, 18,  0 }, {     16,   16,    6, 24, 18,  0 },
    {     16,   16,    5, 24, 18,  0 }, {     16,   16,    4, 24, 18,  0 }, {     16,   16,    3, 24, 18,  0 }, {     16,   16,    2, 24, 18,  0 }, {     16,   16,    1, 24, 18,  0 },
    {     16,   16,    0, 24, 18,  0 },
})


//LeftEighthToDiag

CREATE_VEHICLE_INFO(TrackVehicleInfo_9108DA, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     21,   16,    0, 31,  0,  0 }, {     20,   16,    0, 31,  0,  0 }, {     19,   15,    0, 31,  0,  0 }, {     18,   15,    0, 31,  0,  0 }, {     17,   15,    0, 31,  0,  0 },
    {     16,   15,    0, 31,  0,  0 }, {     15,   15,    0, 31,  0,  0 }, {     14,   14,    0, 31,  0,  0 }, {     13,   14,    0, 31,  0,  0 }, {     12,   14,    0, 31,  0,  0 },
    {     11,   14,    0, 31,  0,  0 }, {     10,   14,    0, 31,  0,  0 }, {      9,   13,    0, 31,  0,  0 }, {      8,   13,    0, 31,  0,  0 }, {      7,   13,    0, 31,  0,  0 },
    {      6,   13,    0, 31,  0,  0 }, {      5,   13,    0, 31,  0,  0 }, {      4,   12,    0, 31,  0,  0 }, {      3,   12,    0, 31,  0,  0 }, {      2,   12,    0, 31,  0,  0 },
    {      1,   12,    0, 30,  0,  0 }, {      0,   11,    0, 30,  0,  0 }, {     -1,   11,    0, 30,  0,  0 }, {     -2,   11,    0, 30,  0,  0 }, {     -3,   11,    0, 30,  0,  0 },
    {     -4,   10,    0, 30,  0,  0 }, {     -5,   10,    0, 30,  0,  0 }, {     -6,   10,    0, 30,  0,  0 }, {     -7,    9,    0, 30,  0,  0 }, {     -8,    9,    0, 30,  0,  0 },
    {     -9,    9,    0, 30,  0,  0 }, {    -10,    8,    0, 30,  0,  0 }, {    -11,    8,    0, 30,  0,  0 }, {    -12,    8,    0, 30,  0,  0 }, {    -13,    7,    0, 30,  0,  0 },
    {    -14,    7,    0, 30,  0,  0 }, {    -15,    6,    0, 30,  0,  0 }, {    -16,    6,    0, 30,  0,  0 }, {    -17,    5,    0, 30,  0,  0 }, {    -18,    5,    0, 30,  0,  0 },
    {    -19,    4,    0, 30,  0,  0 }, {    -20,    4,    0, 29,  0,  0 }, {    -21,    3,    0, 29,  0,  0 }, {    -22,    3,    0, 29,  0,  0 }, {    -23,    2,    0, 29,  0,  0 },
    {    -24,    2,    0, 29,  0,  0 }, {    -25,    1,    0, 29,  0,  0 }, {    -26,    0,    0, 29,  0,  0 }, {    -27,    0,    0, 29,  0,  0 }, {    -28,   -1,    0, 29,  0,  0 },
    {    -29,   -2,    0, 29,  0,  0 }, {    -30,   -2,    0, 29,  0,  0 }, {    -31,   -3,    0, 29,  0,  0 }, {    -32,   -4,    0, 29,  0,  0 }, {    -33,   -4,    0, 29,  0,  0 },
    {    -34,   -5,    0, 29,  0,  0 }, {    -35,   -6,    0, 29,  0,  0 }, {    -36,   -7,    0, 29,  0,  0 }, {    -37,   -7,    0, 29,  0,  0 }, {    -38,   -8,    0, 29,  0,  0 },
    {    -39,   -9,    0, 28,  0,  0 }, {    -40,  -10,    0, 28,  0,  0 }, {    -41,  -11,    0, 28,  0,  0 }, {    -42,  -12,    0, 28,  0,  0 }, {    -43,  -12,    0, 28,  0,  0 },
    {    -44,  -13,    0, 28,  0,  0 }, {    -45,  -14,    0, 28,  0,  0 }, {    -46,  -15,    0, 28,  0,  0 }, {    -47,  -16,    0, 28,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_910BA3, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  7,  0,  0 }, {     16,   12,    0,  7,  0,  0 }, {     15,   13,    0,  7,  0,  0 }, {     15,   14,    0,  7,  0,  0 },
    {     15,   15,    0,  7,  0,  0 }, {     15,   16,    0,  7,  0,  0 }, {     15,   17,    0,  7,  0,  0 }, {     14,   18,    0,  7,  0,  0 }, {     14,   19,    0,  7,  0,  0 },
    {     14,   20,    0,  7,  0,  0 }, {     14,   21,    0,  7,  0,  0 }, {     14,   22,    0,  7,  0,  0 }, {     13,   23,    0,  7,  0,  0 }, {     13,   24,    0,  7,  0,  0 },
    {     13,   25,    0,  7,  0,  0 }, {     13,   26,    0,  7,  0,  0 }, {     13,   27,    0,  7,  0,  0 }, {     12,   28,    0,  7,  0,  0 }, {     12,   29,    0,  7,  0,  0 },
    {     12,   30,    0,  7,  0,  0 }, {     12,   31,    0,  6,  0,  0 }, {     11,   32,    0,  6,  0,  0 }, {     11,   33,    0,  6,  0,  0 }, {     11,   34,    0,  6,  0,  0 },
    {     11,   35,    0,  6,  0,  0 }, {     10,   36,    0,  6,  0,  0 }, {     10,   37,    0,  6,  0,  0 }, {     10,   38,    0,  6,  0,  0 }, {      9,   39,    0,  6,  0,  0 },
    {      9,   40,    0,  6,  0,  0 }, {      9,   41,    0,  6,  0,  0 }, {      8,   42,    0,  6,  0,  0 }, {      8,   43,    0,  6,  0,  0 }, {      8,   44,    0,  6,  0,  0 },
    {      7,   45,    0,  6,  0,  0 }, {      7,   46,    0,  6,  0,  0 }, {      6,   47,    0,  6,  0,  0 }, {      6,   48,    0,  6,  0,  0 }, {      5,   49,    0,  6,  0,  0 },
    {      5,   50,    0,  6,  0,  0 }, {      4,   51,    0,  6,  0,  0 }, {      4,   52,    0,  5,  0,  0 }, {      3,   53,    0,  5,  0,  0 }, {      3,   54,    0,  5,  0,  0 },
    {      2,   55,    0,  5,  0,  0 }, {      2,   56,    0,  5,  0,  0 }, {      1,   57,    0,  5,  0,  0 }, {      0,   58,    0,  5,  0,  0 }, {      0,   59,    0,  5,  0,  0 },
    {     -1,   60,    0,  5,  0,  0 }, {     -2,   61,    0,  5,  0,  0 }, {     -2,   62,    0,  5,  0,  0 }, {     -3,   63,    0,  5,  0,  0 }, {     -4,   64,    0,  5,  0,  0 },
    {     -4,   65,    0,  5,  0,  0 }, {     -5,   66,    0,  5,  0,  0 }, {     -6,   67,    0,  5,  0,  0 }, {     -7,   68,    0,  5,  0,  0 }, {     -7,   69,    0,  5,  0,  0 },
    {     -8,   70,    0,  5,  0,  0 }, {     -9,   71,    0,  4,  0,  0 }, {    -10,   72,    0,  4,  0,  0 }, {    -11,   73,    0,  4,  0,  0 }, {    -12,   74,    0,  4,  0,  0 },
    {    -12,   75,    0,  4,  0,  0 }, {    -13,   76,    0,  4,  0,  0 }, {    -14,   77,    0,  4,  0,  0 }, {    -15,   78,    0,  4,  0,  0 }, {    -16,   79,    0,  4,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_910E75, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 }, {      9,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 15,  0,  0 }, {     12,   16,    0, 15,  0,  0 }, {     13,   16,    0, 15,  0,  0 }, {     14,   17,    0, 15,  0,  0 },
    {     15,   17,    0, 15,  0,  0 }, {     16,   17,    0, 15,  0,  0 }, {     17,   17,    0, 15,  0,  0 }, {     18,   17,    0, 15,  0,  0 }, {     19,   18,    0, 15,  0,  0 },
    {     20,   18,    0, 15,  0,  0 }, {     21,   18,    0, 15,  0,  0 }, {     22,   18,    0, 15,  0,  0 }, {     23,   18,    0, 15,  0,  0 }, {     24,   19,    0, 15,  0,  0 },
    {     25,   19,    0, 15,  0,  0 }, {     26,   19,    0, 15,  0,  0 }, {     27,   19,    0, 15,  0,  0 }, {     28,   19,    0, 15,  0,  0 }, {     29,   20,    0, 15,  0,  0 },
    {     30,   20,    0, 15,  0,  0 }, {     31,   20,    0, 14,  0,  0 }, {     32,   20,    0, 14,  0,  0 }, {     33,   21,    0, 14,  0,  0 }, {     34,   21,    0, 14,  0,  0 },
    {     35,   21,    0, 14,  0,  0 }, {     36,   21,    0, 14,  0,  0 }, {     37,   22,    0, 14,  0,  0 }, {     38,   22,    0, 14,  0,  0 }, {     39,   22,    0, 14,  0,  0 },
    {     40,   23,    0, 14,  0,  0 }, {     41,   23,    0, 14,  0,  0 }, {     42,   23,    0, 14,  0,  0 }, {     43,   24,    0, 14,  0,  0 }, {     44,   24,    0, 14,  0,  0 },
    {     45,   24,    0, 14,  0,  0 }, {     46,   25,    0, 14,  0,  0 }, {     47,   25,    0, 14,  0,  0 }, {     48,   26,    0, 14,  0,  0 }, {     49,   26,    0, 14,  0,  0 },
    {     50,   27,    0, 14,  0,  0 }, {     51,   27,    0, 14,  0,  0 }, {     52,   28,    0, 13,  0,  0 }, {     53,   28,    0, 13,  0,  0 }, {     54,   29,    0, 13,  0,  0 },
    {     55,   29,    0, 13,  0,  0 }, {     56,   30,    0, 13,  0,  0 }, {     57,   30,    0, 13,  0,  0 }, {     58,   31,    0, 13,  0,  0 }, {     59,   32,    0, 13,  0,  0 },
    {     60,   32,    0, 13,  0,  0 }, {     61,   33,    0, 13,  0,  0 }, {     62,   34,    0, 13,  0,  0 }, {     63,   34,    0, 13,  0,  0 }, {     64,   35,    0, 13,  0,  0 },
    {     65,   36,    0, 13,  0,  0 }, {     66,   36,    0, 13,  0,  0 }, {     67,   37,    0, 13,  0,  0 }, {     68,   38,    0, 13,  0,  0 }, {     69,   39,    0, 13,  0,  0 },
    {     70,   39,    0, 13,  0,  0 }, {     71,   40,    0, 12,  0,  0 }, {     72,   41,    0, 12,  0,  0 }, {     73,   42,    0, 12,  0,  0 }, {     74,   43,    0, 12,  0,  0 },
    {     75,   44,    0, 12,  0,  0 }, {     76,   44,    0, 12,  0,  0 }, {     77,   45,    0, 12,  0,  0 }, {     78,   46,    0, 12,  0,  0 }, {     79,   47,    0, 12,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_911147, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   21,    0, 23,  0,  0 }, {     16,   20,    0, 23,  0,  0 }, {     16,   19,    0, 23,  0,  0 }, {     16,   18,    0, 23,  0,  0 }, {     17,   17,    0, 23,  0,  0 },
    {     17,   16,    0, 23,  0,  0 }, {     17,   15,    0, 23,  0,  0 }, {     17,   14,    0, 23,  0,  0 }, {     17,   13,    0, 23,  0,  0 }, {     18,   12,    0, 23,  0,  0 },
    {     18,   11,    0, 23,  0,  0 }, {     18,   10,    0, 23,  0,  0 }, {     18,    9,    0, 23,  0,  0 }, {     18,    8,    0, 23,  0,  0 }, {     19,    7,    0, 23,  0,  0 },
    {     19,    6,    0, 23,  0,  0 }, {     19,    5,    0, 23,  0,  0 }, {     19,    4,    0, 23,  0,  0 }, {     19,    3,    0, 23,  0,  0 }, {     20,    2,    0, 23,  0,  0 },
    {     20,    1,    0, 22,  0,  0 }, {     20,    0,    0, 22,  0,  0 }, {     20,   -1,    0, 22,  0,  0 }, {     21,   -2,    0, 22,  0,  0 }, {     21,   -3,    0, 22,  0,  0 },
    {     21,   -4,    0, 22,  0,  0 }, {     21,   -5,    0, 22,  0,  0 }, {     22,   -6,    0, 22,  0,  0 }, {     22,   -7,    0, 22,  0,  0 }, {     22,   -8,    0, 22,  0,  0 },
    {     23,   -9,    0, 22,  0,  0 }, {     23,  -10,    0, 22,  0,  0 }, {     23,  -11,    0, 22,  0,  0 }, {     24,  -12,    0, 22,  0,  0 }, {     24,  -13,    0, 22,  0,  0 },
    {     24,  -14,    0, 22,  0,  0 }, {     25,  -15,    0, 22,  0,  0 }, {     25,  -16,    0, 22,  0,  0 }, {     26,  -17,    0, 22,  0,  0 }, {     26,  -18,    0, 22,  0,  0 },
    {     27,  -19,    0, 22,  0,  0 }, {     27,  -20,    0, 21,  0,  0 }, {     28,  -21,    0, 21,  0,  0 }, {     28,  -22,    0, 21,  0,  0 }, {     29,  -23,    0, 21,  0,  0 },
    {     29,  -24,    0, 21,  0,  0 }, {     30,  -25,    0, 21,  0,  0 }, {     30,  -26,    0, 21,  0,  0 }, {     31,  -27,    0, 21,  0,  0 }, {     32,  -28,    0, 21,  0,  0 },
    {     32,  -29,    0, 21,  0,  0 }, {     33,  -30,    0, 21,  0,  0 }, {     34,  -31,    0, 21,  0,  0 }, {     34,  -32,    0, 21,  0,  0 }, {     35,  -33,    0, 21,  0,  0 },
    {     36,  -34,    0, 21,  0,  0 }, {     36,  -35,    0, 21,  0,  0 }, {     37,  -36,    0, 21,  0,  0 }, {     38,  -37,    0, 21,  0,  0 }, {     39,  -38,    0, 21,  0,  0 },
    {     39,  -39,    0, 20,  0,  0 }, {     40,  -40,    0, 20,  0,  0 }, {     41,  -41,    0, 20,  0,  0 }, {     42,  -42,    0, 20,  0,  0 }, {     43,  -43,    0, 20,  0,  0 },
    {     44,  -44,    0, 20,  0,  0 }, {     44,  -45,    0, 20,  0,  0 }, {     45,  -46,    0, 20,  0,  0 }, {     46,  -47,    0, 20,  0,  0 }, {     47,  -48,    0, 20,  0,  0 },
})

//RightEighthToDiag

CREATE_VEHICLE_INFO(TrackVehicleInfo_911F58, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     21,   16,    0,  1,  0,  0 }, {     20,   16,    0,  1,  0,  0 }, {     19,   16,    0,  1,  0,  0 }, {     18,   16,    0,  1,  0,  0 }, {     17,   17,    0,  1,  0,  0 },
    {     16,   17,    0,  1,  0,  0 }, {     15,   17,    0,  1,  0,  0 }, {     14,   17,    0,  1,  0,  0 }, {     13,   17,    0,  1,  0,  0 }, {     12,   18,    0,  1,  0,  0 },
    {     11,   18,    0,  1,  0,  0 }, {     10,   18,    0,  1,  0,  0 }, {      9,   18,    0,  1,  0,  0 }, {      8,   18,    0,  1,  0,  0 }, {      7,   19,    0,  1,  0,  0 },
    {      6,   19,    0,  1,  0,  0 }, {      5,   19,    0,  1,  0,  0 }, {      4,   19,    0,  1,  0,  0 }, {      3,   19,    0,  1,  0,  0 }, {      2,   20,    0,  1,  0,  0 },
    {      1,   20,    0,  2,  0,  0 }, {      0,   20,    0,  2,  0,  0 }, {     -1,   20,    0,  2,  0,  0 }, {     -2,   21,    0,  2,  0,  0 }, {     -3,   21,    0,  2,  0,  0 },
    {     -4,   21,    0,  2,  0,  0 }, {     -5,   21,    0,  2,  0,  0 }, {     -6,   22,    0,  2,  0,  0 }, {     -7,   22,    0,  2,  0,  0 }, {     -8,   22,    0,  2,  0,  0 },
    {     -9,   23,    0,  2,  0,  0 }, {    -10,   23,    0,  2,  0,  0 }, {    -11,   23,    0,  2,  0,  0 }, {    -12,   24,    0,  2,  0,  0 }, {    -13,   24,    0,  2,  0,  0 },
    {    -14,   24,    0,  2,  0,  0 }, {    -15,   25,    0,  2,  0,  0 }, {    -16,   25,    0,  2,  0,  0 }, {    -17,   26,    0,  2,  0,  0 }, {    -18,   26,    0,  2,  0,  0 },
    {    -19,   27,    0,  2,  0,  0 }, {    -20,   27,    0,  3,  0,  0 }, {    -21,   28,    0,  3,  0,  0 }, {    -22,   28,    0,  3,  0,  0 }, {    -23,   29,    0,  3,  0,  0 },
    {    -24,   29,    0,  3,  0,  0 }, {    -25,   30,    0,  3,  0,  0 }, {    -26,   30,    0,  3,  0,  0 }, {    -27,   31,    0,  3,  0,  0 }, {    -28,   32,    0,  3,  0,  0 },
    {    -29,   32,    0,  3,  0,  0 }, {    -30,   33,    0,  3,  0,  0 }, {    -31,   34,    0,  3,  0,  0 }, {    -32,   34,    0,  3,  0,  0 }, {    -33,   35,    0,  3,  0,  0 },
    {    -34,   36,    0,  3,  0,  0 }, {    -35,   36,    0,  3,  0,  0 }, {    -36,   37,    0,  3,  0,  0 }, {    -37,   38,    0,  3,  0,  0 }, {    -38,   39,    0,  3,  0,  0 },
    {    -39,   39,    0,  4,  0,  0 }, {    -40,   40,    0,  4,  0,  0 }, {    -41,   41,    0,  4,  0,  0 }, {    -42,   42,    0,  4,  0,  0 }, {    -43,   43,    0,  4,  0,  0 },
    {    -44,   44,    0,  4,  0,  0 }, {    -45,   44,    0,  4,  0,  0 }, {    -46,   45,    0,  4,  0,  0 }, {    -47,   46,    0,  4,  0,  0 }, {    -48,   47,    0,  4,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91222A, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  9,  0,  0 }, {     16,   12,    0,  9,  0,  0 }, {     16,   13,    0,  9,  0,  0 }, {     17,   14,    0,  9,  0,  0 },
    {     17,   15,    0,  9,  0,  0 }, {     17,   16,    0,  9,  0,  0 }, {     17,   17,    0,  9,  0,  0 }, {     17,   18,    0,  9,  0,  0 }, {     18,   19,    0,  9,  0,  0 },
    {     18,   20,    0,  9,  0,  0 }, {     18,   21,    0,  9,  0,  0 }, {     18,   22,    0,  9,  0,  0 }, {     18,   23,    0,  9,  0,  0 }, {     19,   24,    0,  9,  0,  0 },
    {     19,   25,    0,  9,  0,  0 }, {     19,   26,    0,  9,  0,  0 }, {     19,   27,    0,  9,  0,  0 }, {     19,   28,    0,  9,  0,  0 }, {     20,   29,    0,  9,  0,  0 },
    {     20,   30,    0,  9,  0,  0 }, {     20,   31,    0, 10,  0,  0 }, {     20,   32,    0, 10,  0,  0 }, {     21,   33,    0, 10,  0,  0 }, {     21,   34,    0, 10,  0,  0 },
    {     21,   35,    0, 10,  0,  0 }, {     21,   36,    0, 10,  0,  0 }, {     22,   37,    0, 10,  0,  0 }, {     22,   38,    0, 10,  0,  0 }, {     22,   39,    0, 10,  0,  0 },
    {     23,   40,    0, 10,  0,  0 }, {     23,   41,    0, 10,  0,  0 }, {     23,   42,    0, 10,  0,  0 }, {     24,   43,    0, 10,  0,  0 }, {     24,   44,    0, 10,  0,  0 },
    {     24,   45,    0, 10,  0,  0 }, {     25,   46,    0, 10,  0,  0 }, {     25,   47,    0, 10,  0,  0 }, {     26,   48,    0, 10,  0,  0 }, {     26,   49,    0, 10,  0,  0 },
    {     27,   50,    0, 10,  0,  0 }, {     27,   51,    0, 10,  0,  0 }, {     28,   52,    0, 11,  0,  0 }, {     28,   53,    0, 11,  0,  0 }, {     29,   54,    0, 11,  0,  0 },
    {     29,   55,    0, 11,  0,  0 }, {     30,   56,    0, 11,  0,  0 }, {     30,   57,    0, 11,  0,  0 }, {     31,   58,    0, 11,  0,  0 }, {     32,   59,    0, 11,  0,  0 },
    {     32,   60,    0, 11,  0,  0 }, {     33,   61,    0, 11,  0,  0 }, {     34,   62,    0, 11,  0,  0 }, {     34,   63,    0, 11,  0,  0 }, {     35,   64,    0, 11,  0,  0 },
    {     36,   65,    0, 11,  0,  0 }, {     36,   66,    0, 11,  0,  0 }, {     37,   67,    0, 11,  0,  0 }, {     38,   68,    0, 11,  0,  0 }, {     39,   69,    0, 11,  0,  0 },
    {     39,   70,    0, 11,  0,  0 }, {     40,   71,    0, 12,  0,  0 }, {     41,   72,    0, 12,  0,  0 }, {     42,   73,    0, 12,  0,  0 }, {     43,   74,    0, 12,  0,  0 },
    {     44,   75,    0, 12,  0,  0 }, {     44,   76,    0, 12,  0,  0 }, {     45,   77,    0, 12,  0,  0 }, {     46,   78,    0, 12,  0,  0 }, {     47,   79,    0, 12,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9124FC, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 }, {      9,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 17,  0,  0 }, {     12,   16,    0, 17,  0,  0 }, {     13,   15,    0, 17,  0,  0 }, {     14,   15,    0, 17,  0,  0 },
    {     15,   15,    0, 17,  0,  0 }, {     16,   15,    0, 17,  0,  0 }, {     17,   15,    0, 17,  0,  0 }, {     18,   14,    0, 17,  0,  0 }, {     19,   14,    0, 17,  0,  0 },
    {     20,   14,    0, 17,  0,  0 }, {     21,   14,    0, 17,  0,  0 }, {     22,   14,    0, 17,  0,  0 }, {     23,   13,    0, 17,  0,  0 }, {     24,   13,    0, 17,  0,  0 },
    {     25,   13,    0, 17,  0,  0 }, {     26,   13,    0, 17,  0,  0 }, {     27,   13,    0, 17,  0,  0 }, {     28,   12,    0, 17,  0,  0 }, {     29,   12,    0, 17,  0,  0 },
    {     30,   12,    0, 17,  0,  0 }, {     31,   12,    0, 18,  0,  0 }, {     32,   11,    0, 18,  0,  0 }, {     33,   11,    0, 18,  0,  0 }, {     34,   11,    0, 18,  0,  0 },
    {     35,   11,    0, 18,  0,  0 }, {     36,   10,    0, 18,  0,  0 }, {     37,   10,    0, 18,  0,  0 }, {     38,   10,    0, 18,  0,  0 }, {     39,    9,    0, 18,  0,  0 },
    {     40,    9,    0, 18,  0,  0 }, {     41,    9,    0, 18,  0,  0 }, {     42,    8,    0, 18,  0,  0 }, {     43,    8,    0, 18,  0,  0 }, {     44,    8,    0, 18,  0,  0 },
    {     45,    7,    0, 18,  0,  0 }, {     46,    7,    0, 18,  0,  0 }, {     47,    6,    0, 18,  0,  0 }, {     48,    6,    0, 18,  0,  0 }, {     49,    5,    0, 18,  0,  0 },
    {     50,    5,    0, 18,  0,  0 }, {     51,    4,    0, 18,  0,  0 }, {     52,    4,    0, 19,  0,  0 }, {     53,    3,    0, 19,  0,  0 }, {     54,    3,    0, 19,  0,  0 },
    {     55,    2,    0, 19,  0,  0 }, {     56,    2,    0, 19,  0,  0 }, {     57,    1,    0, 19,  0,  0 }, {     58,    0,    0, 19,  0,  0 }, {     59,    0,    0, 19,  0,  0 },
    {     60,   -1,    0, 19,  0,  0 }, {     61,   -2,    0, 19,  0,  0 }, {     62,   -2,    0, 19,  0,  0 }, {     63,   -3,    0, 19,  0,  0 }, {     64,   -4,    0, 19,  0,  0 },
    {     65,   -4,    0, 19,  0,  0 }, {     66,   -5,    0, 19,  0,  0 }, {     67,   -6,    0, 19,  0,  0 }, {     68,   -7,    0, 19,  0,  0 }, {     69,   -7,    0, 19,  0,  0 },
    {     70,   -8,    0, 19,  0,  0 }, {     71,   -9,    0, 20,  0,  0 }, {     72,  -10,    0, 20,  0,  0 }, {     73,  -11,    0, 20,  0,  0 }, {     74,  -12,    0, 20,  0,  0 },
    {     75,  -12,    0, 20,  0,  0 }, {     76,  -13,    0, 20,  0,  0 }, {     77,  -14,    0, 20,  0,  0 }, {     78,  -15,    0, 20,  0,  0 }, {     79,  -16,    0, 20,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9127CE, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   21,    0, 25,  0,  0 }, {     16,   20,    0, 25,  0,  0 }, {     16,   19,    0, 25,  0,  0 }, {     15,   18,    0, 25,  0,  0 }, {     15,   17,    0, 25,  0,  0 },
    {     15,   16,    0, 25,  0,  0 }, {     15,   15,    0, 25,  0,  0 }, {     15,   14,    0, 25,  0,  0 }, {     14,   13,    0, 25,  0,  0 }, {     14,   12,    0, 25,  0,  0 },
    {     14,   11,    0, 25,  0,  0 }, {     14,   10,    0, 25,  0,  0 }, {     14,    9,    0, 25,  0,  0 }, {     13,    8,    0, 25,  0,  0 }, {     13,    7,    0, 25,  0,  0 },
    {     13,    6,    0, 25,  0,  0 }, {     13,    5,    0, 25,  0,  0 }, {     13,    4,    0, 25,  0,  0 }, {     12,    3,    0, 25,  0,  0 }, {     12,    2,    0, 25,  0,  0 },
    {     12,    1,    0, 26,  0,  0 }, {     12,    0,    0, 26,  0,  0 }, {     11,   -1,    0, 26,  0,  0 }, {     11,   -2,    0, 26,  0,  0 }, {     11,   -3,    0, 26,  0,  0 },
    {     11,   -4,    0, 26,  0,  0 }, {     10,   -5,    0, 26,  0,  0 }, {     10,   -6,    0, 26,  0,  0 }, {     10,   -7,    0, 26,  0,  0 }, {      9,   -8,    0, 26,  0,  0 },
    {      9,   -9,    0, 26,  0,  0 }, {      9,  -10,    0, 26,  0,  0 }, {      8,  -11,    0, 26,  0,  0 }, {      8,  -12,    0, 26,  0,  0 }, {      8,  -13,    0, 26,  0,  0 },
    {      7,  -14,    0, 26,  0,  0 }, {      7,  -15,    0, 26,  0,  0 }, {      6,  -16,    0, 26,  0,  0 }, {      6,  -17,    0, 26,  0,  0 }, {      5,  -18,    0, 26,  0,  0 },
    {      5,  -19,    0, 26,  0,  0 }, {      4,  -20,    0, 27,  0,  0 }, {      4,  -21,    0, 27,  0,  0 }, {      3,  -22,    0, 27,  0,  0 }, {      3,  -23,    0, 27,  0,  0 },
    {      2,  -24,    0, 27,  0,  0 }, {      2,  -25,    0, 27,  0,  0 }, {      1,  -26,    0, 27,  0,  0 }, {      0,  -27,    0, 27,  0,  0 }, {      0,  -28,    0, 27,  0,  0 },
    {     -1,  -29,    0, 27,  0,  0 }, {     -2,  -30,    0, 27,  0,  0 }, {     -2,  -31,    0, 27,  0,  0 }, {     -3,  -32,    0, 27,  0,  0 }, {     -4,  -33,    0, 27,  0,  0 },
    {     -4,  -34,    0, 27,  0,  0 }, {     -5,  -35,    0, 27,  0,  0 }, {     -6,  -36,    0, 27,  0,  0 }, {     -7,  -37,    0, 27,  0,  0 }, {     -7,  -38,    0, 27,  0,  0 },
    {     -8,  -39,    0, 28,  0,  0 }, {     -9,  -40,    0, 28,  0,  0 }, {    -10,  -41,    0, 28,  0,  0 }, {    -11,  -42,    0, 28,  0,  0 }, {    -12,  -43,    0, 28,  0,  0 },
    {    -12,  -44,    0, 28,  0,  0 }, {    -13,  -45,    0, 28,  0,  0 }, {    -14,  -46,    0, 28,  0,  0 }, {    -15,  -47,    0, 28,  0,  0 }, {    -16,  -48,    0, 28,  0,  0 },
})

//LeftEighthToOrthogonal

CREATE_VEHICLE_INFO(TrackVehicleInfo_911419, {
    {     15,   17,    0,  4,  0,  0 }, {     14,   18,    0,  4,  0,  0 }, {     13,   19,    0,  4,  0,  0 }, {     12,   20,    0,  4,  0,  0 }, {     11,   20,    0,  4,  0,  0 },
    {     10,   21,    0,  4,  0,  0 }, {      9,   22,    0,  4,  0,  0 }, {      8,   23,    0,  4,  0,  0 }, {      7,   24,    0,  3,  0,  0 }, {      6,   25,    0,  3,  0,  0 },
    {      5,   25,    0,  3,  0,  0 }, {      4,   26,    0,  3,  0,  0 }, {      3,   27,    0,  3,  0,  0 }, {      2,   28,    0,  3,  0,  0 }, {      1,   28,    0,  3,  0,  0 },
    {      0,   29,    0,  3,  0,  0 }, {     -1,   30,    0,  3,  0,  0 }, {     -2,   30,    0,  3,  0,  0 }, {     -3,   31,    0,  3,  0,  0 }, {     -4,   32,    0,  3,  0,  0 },
    {     -5,   32,    0,  3,  0,  0 }, {     -6,   33,    0,  3,  0,  0 }, {     -7,   34,    0,  3,  0,  0 }, {     -8,   34,    0,  3,  0,  0 }, {     -9,   35,    0,  3,  0,  0 },
    {    -10,   35,    0,  3,  0,  0 }, {    -11,   36,    0,  2,  0,  0 }, {    -12,   36,    0,  2,  0,  0 }, {    -13,   37,    0,  2,  0,  0 }, {    -14,   37,    0,  2,  0,  0 },
    {    -15,   38,    0,  2,  0,  0 }, {    -16,   38,    0,  2,  0,  0 }, {    -17,   39,    0,  2,  0,  0 }, {    -18,   39,    0,  2,  0,  0 }, {    -19,   40,    0,  2,  0,  0 },
    {    -20,   40,    0,  2,  0,  0 }, {    -21,   40,    0,  2,  0,  0 }, {    -22,   41,    0,  2,  0,  0 }, {    -23,   41,    0,  2,  0,  0 }, {    -24,   41,    0,  2,  0,  0 },
    {    -25,   42,    0,  2,  0,  0 }, {    -26,   42,    0,  2,  0,  0 }, {    -27,   42,    0,  2,  0,  0 }, {    -28,   43,    0,  2,  0,  0 }, {    -29,   43,    0,  2,  0,  0 },
    {    -30,   43,    0,  2,  0,  0 }, {    -31,   43,    0,  1,  0,  0 }, {    -32,   44,    0,  1,  0,  0 }, {    -33,   44,    0,  1,  0,  0 }, {    -34,   44,    0,  1,  0,  0 },
    {    -35,   44,    0,  1,  0,  0 }, {    -36,   45,    0,  1,  0,  0 }, {    -37,   45,    0,  1,  0,  0 }, {    -38,   45,    0,  1,  0,  0 }, {    -39,   45,    0,  1,  0,  0 },
    {    -40,   45,    0,  1,  0,  0 }, {    -41,   46,    0,  1,  0,  0 }, {    -42,   46,    0,  1,  0,  0 }, {    -43,   46,    0,  1,  0,  0 }, {    -44,   46,    0,  1,  0,  0 },
    {    -45,   46,    0,  1,  0,  0 }, {    -46,   47,    0,  1,  0,  0 }, {    -47,   47,    0,  1,  0,  0 }, {    -48,   47,    0,  1,  0,  0 }, {    -49,   47,    0,  1,  0,  0 },
    {    -50,   47,    0,  1,  0,  0 }, {    -51,   48,    0,  0,  0,  0 }, {    -52,   48,    0,  0,  0,  0 }, {    -53,   48,    0,  0,  0,  0 }, {    -54,   48,    0,  0,  0,  0 },
    {    -55,   48,    0,  0,  0,  0 }, {    -56,   48,    0,  0,  0,  0 }, {    -57,   48,    0,  0,  0,  0 }, {    -58,   48,    0,  0,  0,  0 }, {    -59,   48,    0,  0,  0,  0 },
    {    -60,   48,    0,  0,  0,  0 }, {    -61,   48,    0,  0,  0,  0 }, {    -62,   48,    0,  0,  0,  0 }, {    -63,   48,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9116E2, {
    {     16,   16,    0, 12,  0,  0 }, {     17,   17,    0, 12,  0,  0 }, {     18,   18,    0, 12,  0,  0 }, {     19,   19,    0, 12,  0,  0 }, {     20,   20,    0, 12,  0,  0 },
    {     20,   21,    0, 12,  0,  0 }, {     21,   22,    0, 12,  0,  0 }, {     22,   23,    0, 12,  0,  0 }, {     23,   24,    0, 12,  0,  0 }, {     24,   25,    0, 11,  0,  0 },
    {     25,   26,    0, 11,  0,  0 }, {     25,   27,    0, 11,  0,  0 }, {     26,   28,    0, 11,  0,  0 }, {     27,   29,    0, 11,  0,  0 }, {     28,   30,    0, 11,  0,  0 },
    {     28,   31,    0, 11,  0,  0 }, {     29,   32,    0, 11,  0,  0 }, {     30,   33,    0, 11,  0,  0 }, {     30,   34,    0, 11,  0,  0 }, {     31,   35,    0, 11,  0,  0 },
    {     32,   36,    0, 11,  0,  0 }, {     32,   37,    0, 11,  0,  0 }, {     33,   38,    0, 11,  0,  0 }, {     34,   39,    0, 11,  0,  0 }, {     34,   40,    0, 11,  0,  0 },
    {     35,   41,    0, 11,  0,  0 }, {     35,   42,    0, 11,  0,  0 }, {     36,   43,    0, 10,  0,  0 }, {     36,   44,    0, 10,  0,  0 }, {     37,   45,    0, 10,  0,  0 },
    {     37,   46,    0, 10,  0,  0 }, {     38,   47,    0, 10,  0,  0 }, {     38,   48,    0, 10,  0,  0 }, {     39,   49,    0, 10,  0,  0 }, {     39,   50,    0, 10,  0,  0 },
    {     40,   51,    0, 10,  0,  0 }, {     40,   52,    0, 10,  0,  0 }, {     40,   53,    0, 10,  0,  0 }, {     41,   54,    0, 10,  0,  0 }, {     41,   55,    0, 10,  0,  0 },
    {     41,   56,    0, 10,  0,  0 }, {     42,   57,    0, 10,  0,  0 }, {     42,   58,    0, 10,  0,  0 }, {     42,   59,    0, 10,  0,  0 }, {     43,   60,    0, 10,  0,  0 },
    {     43,   61,    0, 10,  0,  0 }, {     43,   62,    0, 10,  0,  0 }, {     43,   63,    0,  9,  0,  0 }, {     44,   64,    0,  9,  0,  0 }, {     44,   65,    0,  9,  0,  0 },
    {     44,   66,    0,  9,  0,  0 }, {     44,   67,    0,  9,  0,  0 }, {     45,   68,    0,  9,  0,  0 }, {     45,   69,    0,  9,  0,  0 }, {     45,   70,    0,  9,  0,  0 },
    {     45,   71,    0,  9,  0,  0 }, {     45,   72,    0,  9,  0,  0 }, {     46,   73,    0,  9,  0,  0 }, {     46,   74,    0,  9,  0,  0 }, {     46,   75,    0,  9,  0,  0 },
    {     46,   76,    0,  9,  0,  0 }, {     46,   77,    0,  9,  0,  0 }, {     47,   78,    0,  9,  0,  0 }, {     47,   79,    0,  9,  0,  0 }, {     47,   80,    0,  9,  0,  0 },
    {     47,   81,    0,  9,  0,  0 }, {     47,   82,    0,  9,  0,  0 }, {     48,   83,    0,  8,  0,  0 }, {     48,   84,    0,  8,  0,  0 }, {     48,   85,    0,  8,  0,  0 },
    {     48,   86,    0,  8,  0,  0 }, {     48,   87,    0,  8,  0,  0 }, {     48,   88,    0,  8,  0,  0 }, {     48,   89,    0,  8,  0,  0 }, {     48,   90,    0,  8,  0,  0 },
    {     48,   91,    0,  8,  0,  0 }, {     48,   92,    0,  8,  0,  0 }, {     48,   93,    0,  8,  0,  0 }, {     48,   94,    0,  8,  0,  0 }, {     48,   95,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9119B4, {
    {     16,   15,    0, 20,  0,  0 }, {     17,   14,    0, 20,  0,  0 }, {     18,   13,    0, 20,  0,  0 }, {     19,   12,    0, 20,  0,  0 }, {     20,   12,    0, 20,  0,  0 },
    {     21,   11,    0, 20,  0,  0 }, {     22,   10,    0, 20,  0,  0 }, {     23,    9,    0, 20,  0,  0 }, {     24,    8,    0, 19,  0,  0 }, {     25,    7,    0, 19,  0,  0 },
    {     26,    7,    0, 19,  0,  0 }, {     27,    6,    0, 19,  0,  0 }, {     28,    5,    0, 19,  0,  0 }, {     29,    4,    0, 19,  0,  0 }, {     30,    4,    0, 19,  0,  0 },
    {     31,    3,    0, 19,  0,  0 }, {     32,    2,    0, 19,  0,  0 }, {     33,    2,    0, 19,  0,  0 }, {     34,    1,    0, 19,  0,  0 }, {     35,    0,    0, 19,  0,  0 },
    {     36,    0,    0, 19,  0,  0 }, {     37,   -1,    0, 19,  0,  0 }, {     38,   -2,    0, 19,  0,  0 }, {     39,   -2,    0, 19,  0,  0 }, {     40,   -3,    0, 19,  0,  0 },
    {     41,   -3,    0, 19,  0,  0 }, {     42,   -4,    0, 18,  0,  0 }, {     43,   -4,    0, 18,  0,  0 }, {     44,   -5,    0, 18,  0,  0 }, {     45,   -5,    0, 18,  0,  0 },
    {     46,   -6,    0, 18,  0,  0 }, {     47,   -6,    0, 18,  0,  0 }, {     48,   -7,    0, 18,  0,  0 }, {     49,   -7,    0, 18,  0,  0 }, {     50,   -8,    0, 18,  0,  0 },
    {     51,   -8,    0, 18,  0,  0 }, {     52,   -8,    0, 18,  0,  0 }, {     53,   -9,    0, 18,  0,  0 }, {     54,   -9,    0, 18,  0,  0 }, {     55,   -9,    0, 18,  0,  0 },
    {     56,  -10,    0, 18,  0,  0 }, {     57,  -10,    0, 18,  0,  0 }, {     58,  -10,    0, 18,  0,  0 }, {     59,  -11,    0, 18,  0,  0 }, {     60,  -11,    0, 18,  0,  0 },
    {     61,  -11,    0, 18,  0,  0 }, {     62,  -11,    0, 17,  0,  0 }, {     63,  -12,    0, 17,  0,  0 }, {     64,  -12,    0, 17,  0,  0 }, {     65,  -12,    0, 17,  0,  0 },
    {     66,  -12,    0, 17,  0,  0 }, {     67,  -13,    0, 17,  0,  0 }, {     68,  -13,    0, 17,  0,  0 }, {     69,  -13,    0, 17,  0,  0 }, {     70,  -13,    0, 17,  0,  0 },
    {     71,  -13,    0, 17,  0,  0 }, {     72,  -14,    0, 17,  0,  0 }, {     73,  -14,    0, 17,  0,  0 }, {     74,  -14,    0, 17,  0,  0 }, {     75,  -14,    0, 17,  0,  0 },
    {     76,  -14,    0, 17,  0,  0 }, {     77,  -15,    0, 17,  0,  0 }, {     78,  -15,    0, 17,  0,  0 }, {     79,  -15,    0, 17,  0,  0 }, {     80,  -15,    0, 17,  0,  0 },
    {     81,  -15,    0, 17,  0,  0 }, {     82,  -16,    0, 16,  0,  0 }, {     83,  -16,    0, 16,  0,  0 }, {     84,  -16,    0, 16,  0,  0 }, {     85,  -16,    0, 16,  0,  0 },
    {     86,  -16,    0, 16,  0,  0 }, {     87,  -16,    0, 16,  0,  0 }, {     88,  -16,    0, 16,  0,  0 }, {     89,  -16,    0, 16,  0,  0 }, {     90,  -16,    0, 16,  0,  0 },
    {     91,  -16,    0, 16,  0,  0 }, {     92,  -16,    0, 16,  0,  0 }, {     93,  -16,    0, 16,  0,  0 }, {     94,  -16,    0, 16,  0,  0 }, {     95,  -16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_911C86, {
    {     15,   15,    0, 28,  0,  0 }, {     14,   14,    0, 28,  0,  0 }, {     13,   13,    0, 28,  0,  0 }, {     12,   12,    0, 28,  0,  0 }, {     12,   11,    0, 28,  0,  0 },
    {     11,   10,    0, 28,  0,  0 }, {     10,    9,    0, 28,  0,  0 }, {      9,    8,    0, 28,  0,  0 }, {      8,    7,    0, 27,  0,  0 }, {      7,    6,    0, 27,  0,  0 },
    {      7,    5,    0, 27,  0,  0 }, {      6,    4,    0, 27,  0,  0 }, {      5,    3,    0, 27,  0,  0 }, {      4,    2,    0, 27,  0,  0 }, {      4,    1,    0, 27,  0,  0 },
    {      3,    0,    0, 27,  0,  0 }, {      2,   -1,    0, 27,  0,  0 }, {      2,   -2,    0, 27,  0,  0 }, {      1,   -3,    0, 27,  0,  0 }, {      0,   -4,    0, 27,  0,  0 },
    {      0,   -5,    0, 27,  0,  0 }, {     -1,   -6,    0, 27,  0,  0 }, {     -2,   -7,    0, 27,  0,  0 }, {     -2,   -8,    0, 27,  0,  0 }, {     -3,   -9,    0, 27,  0,  0 },
    {     -3,  -10,    0, 27,  0,  0 }, {     -4,  -11,    0, 26,  0,  0 }, {     -4,  -12,    0, 26,  0,  0 }, {     -5,  -13,    0, 26,  0,  0 }, {     -5,  -14,    0, 26,  0,  0 },
    {     -6,  -15,    0, 26,  0,  0 }, {     -6,  -16,    0, 26,  0,  0 }, {     -7,  -17,    0, 26,  0,  0 }, {     -7,  -18,    0, 26,  0,  0 }, {     -8,  -19,    0, 26,  0,  0 },
    {     -8,  -20,    0, 26,  0,  0 }, {     -8,  -21,    0, 26,  0,  0 }, {     -9,  -22,    0, 26,  0,  0 }, {     -9,  -23,    0, 26,  0,  0 }, {     -9,  -24,    0, 26,  0,  0 },
    {    -10,  -25,    0, 26,  0,  0 }, {    -10,  -26,    0, 26,  0,  0 }, {    -10,  -27,    0, 26,  0,  0 }, {    -11,  -28,    0, 26,  0,  0 }, {    -11,  -29,    0, 26,  0,  0 },
    {    -11,  -30,    0, 26,  0,  0 }, {    -11,  -31,    0, 25,  0,  0 }, {    -12,  -32,    0, 25,  0,  0 }, {    -12,  -33,    0, 25,  0,  0 }, {    -12,  -34,    0, 25,  0,  0 },
    {    -12,  -35,    0, 25,  0,  0 }, {    -13,  -36,    0, 25,  0,  0 }, {    -13,  -37,    0, 25,  0,  0 }, {    -13,  -38,    0, 25,  0,  0 }, {    -13,  -39,    0, 25,  0,  0 },
    {    -13,  -40,    0, 25,  0,  0 }, {    -14,  -41,    0, 25,  0,  0 }, {    -14,  -42,    0, 25,  0,  0 }, {    -14,  -43,    0, 25,  0,  0 }, {    -14,  -44,    0, 25,  0,  0 },
    {    -14,  -45,    0, 25,  0,  0 }, {    -15,  -46,    0, 25,  0,  0 }, {    -15,  -47,    0, 25,  0,  0 }, {    -15,  -48,    0, 25,  0,  0 }, {    -15,  -49,    0, 25,  0,  0 },
    {    -15,  -50,    0, 25,  0,  0 }, {    -16,  -51,    0, 24,  0,  0 }, {    -16,  -52,    0, 24,  0,  0 }, {    -16,  -53,    0, 24,  0,  0 }, {    -16,  -54,    0, 24,  0,  0 },
    {    -16,  -55,    0, 24,  0,  0 }, {    -16,  -56,    0, 24,  0,  0 }, {    -16,  -57,    0, 24,  0,  0 }, {    -16,  -58,    0, 24,  0,  0 }, {    -16,  -59,    0, 24,  0,  0 },
    {    -16,  -60,    0, 24,  0,  0 }, {    -16,  -61,    0, 24,  0,  0 }, {    -16,  -62,    0, 24,  0,  0 }, {    -16,  -63,    0, 24,  0,  0 }, {    -16,  -64,    0, 24,  0,  0 },
})

//RightEighthToOrthogonal

CREATE_VEHICLE_INFO(TrackVehicleInfo_912AA0, {
    {     15,   17,    0,  4,  0,  0 }, {     14,   18,    0,  4,  0,  0 }, {     13,   19,    0,  4,  0,  0 }, {     12,   20,    0,  4,  0,  0 }, {     12,   21,    0,  4,  0,  0 },
    {     11,   22,    0,  4,  0,  0 }, {     10,   23,    0,  4,  0,  0 }, {      9,   24,    0,  4,  0,  0 }, {      8,   25,    0,  5,  0,  0 }, {      7,   26,    0,  5,  0,  0 },
    {      7,   27,    0,  5,  0,  0 }, {      6,   28,    0,  5,  0,  0 }, {      5,   29,    0,  5,  0,  0 }, {      4,   30,    0,  5,  0,  0 }, {      4,   31,    0,  5,  0,  0 },
    {      3,   32,    0,  5,  0,  0 }, {      2,   33,    0,  5,  0,  0 }, {      2,   34,    0,  5,  0,  0 }, {      1,   35,    0,  5,  0,  0 }, {      0,   36,    0,  5,  0,  0 },
    {      0,   37,    0,  5,  0,  0 }, {     -1,   38,    0,  5,  0,  0 }, {     -2,   39,    0,  5,  0,  0 }, {     -2,   40,    0,  5,  0,  0 }, {     -3,   41,    0,  5,  0,  0 },
    {     -3,   42,    0,  5,  0,  0 }, {     -4,   43,    0,  6,  0,  0 }, {     -4,   44,    0,  6,  0,  0 }, {     -5,   45,    0,  6,  0,  0 }, {     -5,   46,    0,  6,  0,  0 },
    {     -6,   47,    0,  6,  0,  0 }, {     -6,   48,    0,  6,  0,  0 }, {     -7,   49,    0,  6,  0,  0 }, {     -7,   50,    0,  6,  0,  0 }, {     -8,   51,    0,  6,  0,  0 },
    {     -8,   52,    0,  6,  0,  0 }, {     -8,   53,    0,  6,  0,  0 }, {     -9,   54,    0,  6,  0,  0 }, {     -9,   55,    0,  6,  0,  0 }, {     -9,   56,    0,  6,  0,  0 },
    {    -10,   57,    0,  6,  0,  0 }, {    -10,   58,    0,  6,  0,  0 }, {    -10,   59,    0,  6,  0,  0 }, {    -11,   60,    0,  6,  0,  0 }, {    -11,   61,    0,  6,  0,  0 },
    {    -11,   62,    0,  6,  0,  0 }, {    -11,   63,    0,  7,  0,  0 }, {    -12,   64,    0,  7,  0,  0 }, {    -12,   65,    0,  7,  0,  0 }, {    -12,   66,    0,  7,  0,  0 },
    {    -12,   67,    0,  7,  0,  0 }, {    -13,   68,    0,  7,  0,  0 }, {    -13,   69,    0,  7,  0,  0 }, {    -13,   70,    0,  7,  0,  0 }, {    -13,   71,    0,  7,  0,  0 },
    {    -13,   72,    0,  7,  0,  0 }, {    -14,   73,    0,  7,  0,  0 }, {    -14,   74,    0,  7,  0,  0 }, {    -14,   75,    0,  7,  0,  0 }, {    -14,   76,    0,  7,  0,  0 },
    {    -14,   77,    0,  7,  0,  0 }, {    -15,   78,    0,  7,  0,  0 }, {    -15,   79,    0,  7,  0,  0 }, {    -15,   80,    0,  7,  0,  0 }, {    -15,   81,    0,  7,  0,  0 },
    {    -15,   82,    0,  7,  0,  0 }, {    -16,   83,    0,  8,  0,  0 }, {    -16,   84,    0,  8,  0,  0 }, {    -16,   85,    0,  8,  0,  0 }, {    -16,   86,    0,  8,  0,  0 },
    {    -16,   87,    0,  8,  0,  0 }, {    -16,   88,    0,  8,  0,  0 }, {    -16,   89,    0,  8,  0,  0 }, {    -16,   90,    0,  8,  0,  0 }, {    -16,   91,    0,  8,  0,  0 },
    {    -16,   92,    0,  8,  0,  0 }, {    -16,   93,    0,  8,  0,  0 }, {    -16,   94,    0,  8,  0,  0 }, {    -16,   95,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_912D69, {
    {     16,   16,    0, 12,  0,  0 }, {     17,   17,    0, 12,  0,  0 }, {     18,   18,    0, 12,  0,  0 }, {     19,   19,    0, 12,  0,  0 }, {     20,   20,    0, 12,  0,  0 },
    {     21,   20,    0, 12,  0,  0 }, {     22,   21,    0, 12,  0,  0 }, {     23,   22,    0, 12,  0,  0 }, {     24,   23,    0, 12,  0,  0 }, {     25,   24,    0, 13,  0,  0 },
    {     26,   25,    0, 13,  0,  0 }, {     27,   25,    0, 13,  0,  0 }, {     28,   26,    0, 13,  0,  0 }, {     29,   27,    0, 13,  0,  0 }, {     30,   28,    0, 13,  0,  0 },
    {     31,   28,    0, 13,  0,  0 }, {     32,   29,    0, 13,  0,  0 }, {     33,   30,    0, 13,  0,  0 }, {     34,   30,    0, 13,  0,  0 }, {     35,   31,    0, 13,  0,  0 },
    {     36,   32,    0, 13,  0,  0 }, {     37,   32,    0, 13,  0,  0 }, {     38,   33,    0, 13,  0,  0 }, {     39,   34,    0, 13,  0,  0 }, {     40,   34,    0, 13,  0,  0 },
    {     41,   35,    0, 13,  0,  0 }, {     42,   35,    0, 13,  0,  0 }, {     43,   36,    0, 14,  0,  0 }, {     44,   36,    0, 14,  0,  0 }, {     45,   37,    0, 14,  0,  0 },
    {     46,   37,    0, 14,  0,  0 }, {     47,   38,    0, 14,  0,  0 }, {     48,   38,    0, 14,  0,  0 }, {     49,   39,    0, 14,  0,  0 }, {     50,   39,    0, 14,  0,  0 },
    {     51,   40,    0, 14,  0,  0 }, {     52,   40,    0, 14,  0,  0 }, {     53,   40,    0, 14,  0,  0 }, {     54,   41,    0, 14,  0,  0 }, {     55,   41,    0, 14,  0,  0 },
    {     56,   41,    0, 14,  0,  0 }, {     57,   42,    0, 14,  0,  0 }, {     58,   42,    0, 14,  0,  0 }, {     59,   42,    0, 14,  0,  0 }, {     60,   43,    0, 14,  0,  0 },
    {     61,   43,    0, 14,  0,  0 }, {     62,   43,    0, 14,  0,  0 }, {     63,   43,    0, 15,  0,  0 }, {     64,   44,    0, 15,  0,  0 }, {     65,   44,    0, 15,  0,  0 },
    {     66,   44,    0, 15,  0,  0 }, {     67,   44,    0, 15,  0,  0 }, {     68,   45,    0, 15,  0,  0 }, {     69,   45,    0, 15,  0,  0 }, {     70,   45,    0, 15,  0,  0 },
    {     71,   45,    0, 15,  0,  0 }, {     72,   45,    0, 15,  0,  0 }, {     73,   46,    0, 15,  0,  0 }, {     74,   46,    0, 15,  0,  0 }, {     75,   46,    0, 15,  0,  0 },
    {     76,   46,    0, 15,  0,  0 }, {     77,   46,    0, 15,  0,  0 }, {     78,   47,    0, 15,  0,  0 }, {     79,   47,    0, 15,  0,  0 }, {     80,   47,    0, 15,  0,  0 },
    {     81,   47,    0, 15,  0,  0 }, {     82,   47,    0, 15,  0,  0 }, {     83,   48,    0, 16,  0,  0 }, {     84,   48,    0, 16,  0,  0 }, {     85,   48,    0, 16,  0,  0 },
    {     86,   48,    0, 16,  0,  0 }, {     87,   48,    0, 16,  0,  0 }, {     88,   48,    0, 16,  0,  0 }, {     89,   48,    0, 16,  0,  0 }, {     90,   48,    0, 16,  0,  0 },
    {     91,   48,    0, 16,  0,  0 }, {     92,   48,    0, 16,  0,  0 }, {     93,   48,    0, 16,  0,  0 }, {     94,   48,    0, 16,  0,  0 }, {     95,   48,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91303B, {
    {     16,   15,    0, 20,  0,  0 }, {     17,   14,    0, 20,  0,  0 }, {     18,   13,    0, 20,  0,  0 }, {     19,   12,    0, 20,  0,  0 }, {     19,   11,    0, 20,  0,  0 },
    {     20,   10,    0, 20,  0,  0 }, {     21,    9,    0, 20,  0,  0 }, {     22,    8,    0, 20,  0,  0 }, {     23,    7,    0, 21,  0,  0 }, {     24,    6,    0, 21,  0,  0 },
    {     24,    5,    0, 21,  0,  0 }, {     25,    4,    0, 21,  0,  0 }, {     26,    3,    0, 21,  0,  0 }, {     27,    2,    0, 21,  0,  0 }, {     27,    1,    0, 21,  0,  0 },
    {     28,    0,    0, 21,  0,  0 }, {     29,   -1,    0, 21,  0,  0 }, {     29,   -2,    0, 21,  0,  0 }, {     30,   -3,    0, 21,  0,  0 }, {     31,   -4,    0, 21,  0,  0 },
    {     31,   -5,    0, 21,  0,  0 }, {     32,   -6,    0, 21,  0,  0 }, {     33,   -7,    0, 21,  0,  0 }, {     33,   -8,    0, 21,  0,  0 }, {     34,   -9,    0, 21,  0,  0 },
    {     34,  -10,    0, 21,  0,  0 }, {     35,  -11,    0, 22,  0,  0 }, {     35,  -12,    0, 22,  0,  0 }, {     36,  -13,    0, 22,  0,  0 }, {     36,  -14,    0, 22,  0,  0 },
    {     37,  -15,    0, 22,  0,  0 }, {     37,  -16,    0, 22,  0,  0 }, {     38,  -17,    0, 22,  0,  0 }, {     38,  -18,    0, 22,  0,  0 }, {     39,  -19,    0, 22,  0,  0 },
    {     39,  -20,    0, 22,  0,  0 }, {     39,  -21,    0, 22,  0,  0 }, {     40,  -22,    0, 22,  0,  0 }, {     40,  -23,    0, 22,  0,  0 }, {     40,  -24,    0, 22,  0,  0 },
    {     41,  -25,    0, 22,  0,  0 }, {     41,  -26,    0, 22,  0,  0 }, {     41,  -27,    0, 22,  0,  0 }, {     42,  -28,    0, 22,  0,  0 }, {     42,  -29,    0, 22,  0,  0 },
    {     42,  -30,    0, 22,  0,  0 }, {     42,  -31,    0, 23,  0,  0 }, {     43,  -32,    0, 23,  0,  0 }, {     43,  -33,    0, 23,  0,  0 }, {     43,  -34,    0, 23,  0,  0 },
    {     43,  -35,    0, 23,  0,  0 }, {     44,  -36,    0, 23,  0,  0 }, {     44,  -37,    0, 23,  0,  0 }, {     44,  -38,    0, 23,  0,  0 }, {     44,  -39,    0, 23,  0,  0 },
    {     44,  -40,    0, 23,  0,  0 }, {     45,  -41,    0, 23,  0,  0 }, {     45,  -42,    0, 23,  0,  0 }, {     45,  -43,    0, 23,  0,  0 }, {     45,  -44,    0, 23,  0,  0 },
    {     45,  -45,    0, 23,  0,  0 }, {     46,  -46,    0, 23,  0,  0 }, {     46,  -47,    0, 23,  0,  0 }, {     46,  -48,    0, 23,  0,  0 }, {     46,  -49,    0, 23,  0,  0 },
    {     46,  -50,    0, 23,  0,  0 }, {     47,  -51,    0, 24,  0,  0 }, {     47,  -52,    0, 24,  0,  0 }, {     47,  -53,    0, 24,  0,  0 }, {     47,  -54,    0, 24,  0,  0 },
    {     47,  -55,    0, 24,  0,  0 }, {     47,  -56,    0, 24,  0,  0 }, {     47,  -57,    0, 24,  0,  0 }, {     47,  -58,    0, 24,  0,  0 }, {     47,  -59,    0, 24,  0,  0 },
    {     47,  -60,    0, 24,  0,  0 }, {     47,  -61,    0, 24,  0,  0 }, {     47,  -62,    0, 24,  0,  0 }, {     47,  -63,    0, 24,  0,  0 }, {     47,  -64,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91330D, {
    {     15,   15,    0, 28,  0,  0 }, {     14,   14,    0, 28,  0,  0 }, {     13,   13,    0, 28,  0,  0 }, {     12,   12,    0, 28,  0,  0 }, {     11,   12,    0, 28,  0,  0 },
    {     10,   11,    0, 28,  0,  0 }, {      9,   10,    0, 28,  0,  0 }, {      8,    9,    0, 28,  0,  0 }, {      7,    8,    0, 29,  0,  0 }, {      6,    7,    0, 29,  0,  0 },
    {      5,    7,    0, 29,  0,  0 }, {      4,    6,    0, 29,  0,  0 }, {      3,    5,    0, 29,  0,  0 }, {      2,    4,    0, 29,  0,  0 }, {      1,    4,    0, 29,  0,  0 },
    {      0,    3,    0, 29,  0,  0 }, {     -1,    2,    0, 29,  0,  0 }, {     -2,    2,    0, 29,  0,  0 }, {     -3,    1,    0, 29,  0,  0 }, {     -4,    0,    0, 29,  0,  0 },
    {     -5,    0,    0, 29,  0,  0 }, {     -6,   -1,    0, 29,  0,  0 }, {     -7,   -2,    0, 29,  0,  0 }, {     -8,   -2,    0, 29,  0,  0 }, {     -9,   -3,    0, 29,  0,  0 },
    {    -10,   -3,    0, 29,  0,  0 }, {    -11,   -4,    0, 30,  0,  0 }, {    -12,   -4,    0, 30,  0,  0 }, {    -13,   -5,    0, 30,  0,  0 }, {    -14,   -5,    0, 30,  0,  0 },
    {    -15,   -6,    0, 30,  0,  0 }, {    -16,   -6,    0, 30,  0,  0 }, {    -17,   -7,    0, 30,  0,  0 }, {    -18,   -7,    0, 30,  0,  0 }, {    -19,   -8,    0, 30,  0,  0 },
    {    -20,   -8,    0, 30,  0,  0 }, {    -21,   -8,    0, 30,  0,  0 }, {    -22,   -9,    0, 30,  0,  0 }, {    -23,   -9,    0, 30,  0,  0 }, {    -24,   -9,    0, 30,  0,  0 },
    {    -25,  -10,    0, 30,  0,  0 }, {    -26,  -10,    0, 30,  0,  0 }, {    -27,  -10,    0, 30,  0,  0 }, {    -28,  -11,    0, 30,  0,  0 }, {    -29,  -11,    0, 30,  0,  0 },
    {    -30,  -11,    0, 30,  0,  0 }, {    -31,  -11,    0, 31,  0,  0 }, {    -32,  -12,    0, 31,  0,  0 }, {    -33,  -12,    0, 31,  0,  0 }, {    -34,  -12,    0, 31,  0,  0 },
    {    -35,  -12,    0, 31,  0,  0 }, {    -36,  -13,    0, 31,  0,  0 }, {    -37,  -13,    0, 31,  0,  0 }, {    -38,  -13,    0, 31,  0,  0 }, {    -39,  -13,    0, 31,  0,  0 },
    {    -40,  -13,    0, 31,  0,  0 }, {    -41,  -14,    0, 31,  0,  0 }, {    -42,  -14,    0, 31,  0,  0 }, {    -43,  -14,    0, 31,  0,  0 }, {    -44,  -14,    0, 31,  0,  0 },
    {    -45,  -14,    0, 31,  0,  0 }, {    -46,  -15,    0, 31,  0,  0 }, {    -47,  -15,    0, 31,  0,  0 }, {    -48,  -15,    0, 31,  0,  0 }, {    -49,  -15,    0, 31,  0,  0 },
    {    -50,  -15,    0, 31,  0,  0 }, {    -51,  -16,    0,  0,  0,  0 }, {    -52,  -16,    0,  0,  0,  0 }, {    -53,  -16,    0,  0,  0,  0 }, {    -54,  -16,    0,  0,  0,  0 },
    {    -55,  -16,    0,  0,  0,  0 }, {    -56,  -16,    0,  0,  0,  0 }, {    -57,  -16,    0,  0,  0,  0 }, {    -58,  -16,    0,  0,  0,  0 }, {    -59,  -16,    0,  0,  0,  0 },
    {    -60,  -16,    0,  0,  0,  0 }, {    -61,  -16,    0,  0,  0,  0 }, {    -62,  -16,    0,  0,  0,  0 }, {    -63,  -16,    0,  0,  0,  0 }, {    -64,  -16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9135DF, {
    {     31,   16,    0,  0,  0,  2 }, {     30,   16,    0,  0,  0,  2 }, {     29,   16,    0,  0,  0,  2 }, {     28,   16,    0,  0,  0,  2 }, {     27,   16,    0,  0,  0,  2 },
    {     26,   16,    0,  0,  0,  2 }, {     25,   16,    0,  0,  0,  2 }, {     24,   16,    0,  0,  0,  2 }, {     23,   16,    0,  0,  0,  2 }, {     22,   16,    0,  0,  0,  2 },
    {     21,   16,    0, 31,  0,  2 }, {     20,   16,    0, 31,  0,  2 }, {     19,   15,    0, 31,  0,  2 }, {     18,   15,    0, 31,  0,  2 }, {     17,   15,    0, 31,  0,  2 },
    {     16,   15,    0, 31,  0,  2 }, {     15,   15,    0, 31,  0,  2 }, {     14,   14,    0, 31,  0,  2 }, {     13,   14,    0, 31,  0,  2 }, {     12,   14,    0, 31,  0,  2 },
    {     11,   14,    0, 31,  0,  2 }, {     10,   14,    0, 31,  0,  2 }, {      9,   13,    0, 31,  0,  2 }, {      8,   13,    0, 31,  0,  2 }, {      7,   13,    0, 31,  0,  2 },
    {      6,   13,    0, 31,  0,  2 }, {      5,   13,    0, 31,  0,  2 }, {      4,   12,    0, 31,  0,  2 }, {      3,   12,    0, 31,  0,  2 }, {      2,   12,    0, 31,  0,  2 },
    {      1,   12,    0, 30,  0,  2 }, {      0,   11,    0, 30,  0,  2 }, {     -1,   11,    0, 30,  0,  2 }, {     -2,   11,    0, 30,  0,  2 }, {     -3,   11,    0, 30,  0,  2 },
    {     -4,   10,    0, 30,  0,  2 }, {     -5,   10,    0, 30,  0,  2 }, {     -6,   10,    0, 30,  0,  2 }, {     -7,    9,    0, 30,  0,  2 }, {     -8,    9,    0, 30,  0,  2 },
    {     -9,    9,    0, 30,  0,  2 }, {    -10,    8,    0, 30,  0,  2 }, {    -11,    8,    0, 30,  0,  2 }, {    -12,    8,    0, 30,  0,  2 }, {    -13,    7,    0, 30,  0,  2 },
    {    -14,    7,    0, 30,  0,  2 }, {    -15,    6,    0, 30,  0,  2 }, {    -16,    6,    0, 30,  0,  2 }, {    -17,    5,    0, 30,  0,  2 }, {    -18,    5,    0, 30,  0,  2 },
    {    -19,    4,    0, 30,  0,  2 }, {    -20,    4,    0, 29,  0,  2 }, {    -21,    3,    0, 29,  0,  2 }, {    -22,    3,    0, 29,  0,  2 }, {    -23,    2,    0, 29,  0,  2 },
    {    -24,    2,    0, 29,  0,  2 }, {    -25,    1,    0, 29,  0,  2 }, {    -26,    0,    0, 29,  0,  2 }, {    -27,    0,    0, 29,  0,  2 }, {    -28,   -1,    0, 29,  0,  2 },
    {    -29,   -2,    0, 29,  0,  2 }, {    -30,   -2,    0, 29,  0,  2 }, {    -31,   -3,    0, 29,  0,  2 }, {    -32,   -4,    0, 29,  0,  2 }, {    -33,   -4,    0, 29,  0,  2 },
    {    -34,   -5,    0, 29,  0,  2 }, {    -35,   -6,    0, 29,  0,  2 }, {    -36,   -7,    0, 29,  0,  2 }, {    -37,   -7,    0, 29,  0,  2 }, {    -38,   -8,    0, 29,  0,  2 },
    {    -39,   -9,    0, 28,  0,  2 }, {    -40,  -10,    0, 28,  0,  2 }, {    -41,  -11,    0, 28,  0,  2 }, {    -42,  -12,    0, 28,  0,  2 }, {    -43,  -12,    0, 28,  0,  2 },
    {    -44,  -13,    0, 28,  0,  2 }, {    -45,  -14,    0, 28,  0,  2 }, {    -46,  -15,    0, 28,  0,  2 }, {    -47,  -16,    0, 28,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9138A8, {
    {     16,    0,    0,  8,  0,  2 }, {     16,    1,    0,  8,  0,  2 }, {     16,    2,    0,  8,  0,  2 }, {     16,    3,    0,  8,  0,  2 }, {     16,    4,    0,  8,  0,  2 },
    {     16,    5,    0,  8,  0,  2 }, {     16,    6,    0,  8,  0,  2 }, {     16,    7,    0,  8,  0,  2 }, {     16,    8,    0,  8,  0,  2 }, {     16,    9,    0,  8,  0,  2 },
    {     16,   10,    0,  8,  0,  2 }, {     16,   11,    0,  7,  0,  2 }, {     16,   12,    0,  7,  0,  2 }, {     15,   13,    0,  7,  0,  2 }, {     15,   14,    0,  7,  0,  2 },
    {     15,   15,    0,  7,  0,  2 }, {     15,   16,    0,  7,  0,  2 }, {     15,   17,    0,  7,  0,  2 }, {     14,   18,    0,  7,  0,  2 }, {     14,   19,    0,  7,  0,  2 },
    {     14,   20,    0,  7,  0,  2 }, {     14,   21,    0,  7,  0,  2 }, {     14,   22,    0,  7,  0,  2 }, {     13,   23,    0,  7,  0,  2 }, {     13,   24,    0,  7,  0,  2 },
    {     13,   25,    0,  7,  0,  2 }, {     13,   26,    0,  7,  0,  2 }, {     13,   27,    0,  7,  0,  2 }, {     12,   28,    0,  7,  0,  2 }, {     12,   29,    0,  7,  0,  2 },
    {     12,   30,    0,  7,  0,  2 }, {     12,   31,    0,  6,  0,  2 }, {     11,   32,    0,  6,  0,  2 }, {     11,   33,    0,  6,  0,  2 }, {     11,   34,    0,  6,  0,  2 },
    {     11,   35,    0,  6,  0,  2 }, {     10,   36,    0,  6,  0,  2 }, {     10,   37,    0,  6,  0,  2 }, {     10,   38,    0,  6,  0,  2 }, {      9,   39,    0,  6,  0,  2 },
    {      9,   40,    0,  6,  0,  2 }, {      9,   41,    0,  6,  0,  2 }, {      8,   42,    0,  6,  0,  2 }, {      8,   43,    0,  6,  0,  2 }, {      8,   44,    0,  6,  0,  2 },
    {      7,   45,    0,  6,  0,  2 }, {      7,   46,    0,  6,  0,  2 }, {      6,   47,    0,  6,  0,  2 }, {      6,   48,    0,  6,  0,  2 }, {      5,   49,    0,  6,  0,  2 },
    {      5,   50,    0,  6,  0,  2 }, {      4,   51,    0,  6,  0,  2 }, {      4,   52,    0,  5,  0,  2 }, {      3,   53,    0,  5,  0,  2 }, {      3,   54,    0,  5,  0,  2 },
    {      2,   55,    0,  5,  0,  2 }, {      2,   56,    0,  5,  0,  2 }, {      1,   57,    0,  5,  0,  2 }, {      0,   58,    0,  5,  0,  2 }, {      0,   59,    0,  5,  0,  2 },
    {     -1,   60,    0,  5,  0,  2 }, {     -2,   61,    0,  5,  0,  2 }, {     -2,   62,    0,  5,  0,  2 }, {     -3,   63,    0,  5,  0,  2 }, {     -4,   64,    0,  5,  0,  2 },
    {     -4,   65,    0,  5,  0,  2 }, {     -5,   66,    0,  5,  0,  2 }, {     -6,   67,    0,  5,  0,  2 }, {     -7,   68,    0,  5,  0,  2 }, {     -7,   69,    0,  5,  0,  2 },
    {     -8,   70,    0,  5,  0,  2 }, {     -9,   71,    0,  4,  0,  2 }, {    -10,   72,    0,  4,  0,  2 }, {    -11,   73,    0,  4,  0,  2 }, {    -12,   74,    0,  4,  0,  2 },
    {    -12,   75,    0,  4,  0,  2 }, {    -13,   76,    0,  4,  0,  2 }, {    -14,   77,    0,  4,  0,  2 }, {    -15,   78,    0,  4,  0,  2 }, {    -16,   79,    0,  4,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_913B7A, {
    {      0,   16,    0, 16,  0,  2 }, {      1,   16,    0, 16,  0,  2 }, {      2,   16,    0, 16,  0,  2 }, {      3,   16,    0, 16,  0,  2 }, {      4,   16,    0, 16,  0,  2 },
    {      5,   16,    0, 16,  0,  2 }, {      6,   16,    0, 16,  0,  2 }, {      7,   16,    0, 16,  0,  2 }, {      8,   16,    0, 16,  0,  2 }, {      9,   16,    0, 16,  0,  2 },
    {     10,   16,    0, 16,  0,  2 }, {     11,   16,    0, 15,  0,  2 }, {     12,   16,    0, 15,  0,  2 }, {     13,   16,    0, 15,  0,  2 }, {     14,   17,    0, 15,  0,  2 },
    {     15,   17,    0, 15,  0,  2 }, {     16,   17,    0, 15,  0,  2 }, {     17,   17,    0, 15,  0,  2 }, {     18,   17,    0, 15,  0,  2 }, {     19,   18,    0, 15,  0,  2 },
    {     20,   18,    0, 15,  0,  2 }, {     21,   18,    0, 15,  0,  2 }, {     22,   18,    0, 15,  0,  2 }, {     23,   18,    0, 15,  0,  2 }, {     24,   19,    0, 15,  0,  2 },
    {     25,   19,    0, 15,  0,  2 }, {     26,   19,    0, 15,  0,  2 }, {     27,   19,    0, 15,  0,  2 }, {     28,   19,    0, 15,  0,  2 }, {     29,   20,    0, 15,  0,  2 },
    {     30,   20,    0, 15,  0,  2 }, {     31,   20,    0, 14,  0,  2 }, {     32,   20,    0, 14,  0,  2 }, {     33,   21,    0, 14,  0,  2 }, {     34,   21,    0, 14,  0,  2 },
    {     35,   21,    0, 14,  0,  2 }, {     36,   21,    0, 14,  0,  2 }, {     37,   22,    0, 14,  0,  2 }, {     38,   22,    0, 14,  0,  2 }, {     39,   22,    0, 14,  0,  2 },
    {     40,   23,    0, 14,  0,  2 }, {     41,   23,    0, 14,  0,  2 }, {     42,   23,    0, 14,  0,  2 }, {     43,   24,    0, 14,  0,  2 }, {     44,   24,    0, 14,  0,  2 },
    {     45,   24,    0, 14,  0,  2 }, {     46,   25,    0, 14,  0,  2 }, {     47,   25,    0, 14,  0,  2 }, {     48,   26,    0, 14,  0,  2 }, {     49,   26,    0, 14,  0,  2 },
    {     50,   27,    0, 14,  0,  2 }, {     51,   27,    0, 14,  0,  2 }, {     52,   28,    0, 13,  0,  2 }, {     53,   28,    0, 13,  0,  2 }, {     54,   29,    0, 13,  0,  2 },
    {     55,   29,    0, 13,  0,  2 }, {     56,   30,    0, 13,  0,  2 }, {     57,   30,    0, 13,  0,  2 }, {     58,   31,    0, 13,  0,  2 }, {     59,   32,    0, 13,  0,  2 },
    {     60,   32,    0, 13,  0,  2 }, {     61,   33,    0, 13,  0,  2 }, {     62,   34,    0, 13,  0,  2 }, {     63,   34,    0, 13,  0,  2 }, {     64,   35,    0, 13,  0,  2 },
    {     65,   36,    0, 13,  0,  2 }, {     66,   36,    0, 13,  0,  2 }, {     67,   37,    0, 13,  0,  2 }, {     68,   38,    0, 13,  0,  2 }, {     69,   39,    0, 13,  0,  2 },
    {     70,   39,    0, 13,  0,  2 }, {     71,   40,    0, 12,  0,  2 }, {     72,   41,    0, 12,  0,  2 }, {     73,   42,    0, 12,  0,  2 }, {     74,   43,    0, 12,  0,  2 },
    {     75,   44,    0, 12,  0,  2 }, {     76,   44,    0, 12,  0,  2 }, {     77,   45,    0, 12,  0,  2 }, {     78,   46,    0, 12,  0,  2 }, {     79,   47,    0, 12,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_913E4C, {
    {     16,   31,    0, 24,  0,  2 }, {     16,   30,    0, 24,  0,  2 }, {     16,   29,    0, 24,  0,  2 }, {     16,   28,    0, 24,  0,  2 }, {     16,   27,    0, 24,  0,  2 },
    {     16,   26,    0, 24,  0,  2 }, {     16,   25,    0, 24,  0,  2 }, {     16,   24,    0, 24,  0,  2 }, {     16,   23,    0, 24,  0,  2 }, {     16,   22,    0, 24,  0,  2 },
    {     16,   21,    0, 23,  0,  2 }, {     16,   20,    0, 23,  0,  2 }, {     16,   19,    0, 23,  0,  2 }, {     16,   18,    0, 23,  0,  2 }, {     17,   17,    0, 23,  0,  2 },
    {     17,   16,    0, 23,  0,  2 }, {     17,   15,    0, 23,  0,  2 }, {     17,   14,    0, 23,  0,  2 }, {     17,   13,    0, 23,  0,  2 }, {     18,   12,    0, 23,  0,  2 },
    {     18,   11,    0, 23,  0,  2 }, {     18,   10,    0, 23,  0,  2 }, {     18,    9,    0, 23,  0,  2 }, {     18,    8,    0, 23,  0,  2 }, {     19,    7,    0, 23,  0,  2 },
    {     19,    6,    0, 23,  0,  2 }, {     19,    5,    0, 23,  0,  2 }, {     19,    4,    0, 23,  0,  2 }, {     19,    3,    0, 23,  0,  2 }, {     20,    2,    0, 23,  0,  2 },
    {     20,    1,    0, 22,  0,  2 }, {     20,    0,    0, 22,  0,  2 }, {     20,   -1,    0, 22,  0,  2 }, {     21,   -2,    0, 22,  0,  2 }, {     21,   -3,    0, 22,  0,  2 },
    {     21,   -4,    0, 22,  0,  2 }, {     21,   -5,    0, 22,  0,  2 }, {     22,   -6,    0, 22,  0,  2 }, {     22,   -7,    0, 22,  0,  2 }, {     22,   -8,    0, 22,  0,  2 },
    {     23,   -9,    0, 22,  0,  2 }, {     23,  -10,    0, 22,  0,  2 }, {     23,  -11,    0, 22,  0,  2 }, {     24,  -12,    0, 22,  0,  2 }, {     24,  -13,    0, 22,  0,  2 },
    {     24,  -14,    0, 22,  0,  2 }, {     25,  -15,    0, 22,  0,  2 }, {     25,  -16,    0, 22,  0,  2 }, {     26,  -17,    0, 22,  0,  2 }, {     26,  -18,    0, 22,  0,  2 },
    {     27,  -19,    0, 22,  0,  2 }, {     27,  -20,    0, 21,  0,  2 }, {     28,  -21,    0, 21,  0,  2 }, {     28,  -22,    0, 21,  0,  2 }, {     29,  -23,    0, 21,  0,  2 },
    {     29,  -24,    0, 21,  0,  2 }, {     30,  -25,    0, 21,  0,  2 }, {     30,  -26,    0, 21,  0,  2 }, {     31,  -27,    0, 21,  0,  2 }, {     32,  -28,    0, 21,  0,  2 },
    {     32,  -29,    0, 21,  0,  2 }, {     33,  -30,    0, 21,  0,  2 }, {     34,  -31,    0, 21,  0,  2 }, {     34,  -32,    0, 21,  0,  2 }, {     35,  -33,    0, 21,  0,  2 },
    {     36,  -34,    0, 21,  0,  2 }, {     36,  -35,    0, 21,  0,  2 }, {     37,  -36,    0, 21,  0,  2 }, {     38,  -37,    0, 21,  0,  2 }, {     39,  -38,    0, 21,  0,  2 },
    {     39,  -39,    0, 20,  0,  2 }, {     40,  -40,    0, 20,  0,  2 }, {     41,  -41,    0, 20,  0,  2 }, {     42,  -42,    0, 20,  0,  2 }, {     43,  -43,    0, 20,  0,  2 },
    {     44,  -44,    0, 20,  0,  2 }, {     44,  -45,    0, 20,  0,  2 }, {     45,  -46,    0, 20,  0,  2 }, {     46,  -47,    0, 20,  0,  2 }, {     47,  -48,    0, 20,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_914C5D, {
    {     31,   16,    0,  0,  0,  4 }, {     30,   16,    0,  0,  0,  4 }, {     29,   16,    0,  0,  0,  4 }, {     28,   16,    0,  0,  0,  4 }, {     27,   16,    0,  0,  0,  4 },
    {     26,   16,    0,  0,  0,  4 }, {     25,   16,    0,  0,  0,  4 }, {     24,   16,    0,  0,  0,  4 }, {     23,   16,    0,  0,  0,  4 }, {     22,   16,    0,  0,  0,  4 },
    {     21,   16,    0,  1,  0,  4 }, {     20,   16,    0,  1,  0,  4 }, {     19,   16,    0,  1,  0,  4 }, {     18,   16,    0,  1,  0,  4 }, {     17,   17,    0,  1,  0,  4 },
    {     16,   17,    0,  1,  0,  4 }, {     15,   17,    0,  1,  0,  4 }, {     14,   17,    0,  1,  0,  4 }, {     13,   17,    0,  1,  0,  4 }, {     12,   18,    0,  1,  0,  4 },
    {     11,   18,    0,  1,  0,  4 }, {     10,   18,    0,  1,  0,  4 }, {      9,   18,    0,  1,  0,  4 }, {      8,   18,    0,  1,  0,  4 }, {      7,   19,    0,  1,  0,  4 },
    {      6,   19,    0,  1,  0,  4 }, {      5,   19,    0,  1,  0,  4 }, {      4,   19,    0,  1,  0,  4 }, {      3,   19,    0,  1,  0,  4 }, {      2,   20,    0,  1,  0,  4 },
    {      1,   20,    0,  2,  0,  4 }, {      0,   20,    0,  2,  0,  4 }, {     -1,   20,    0,  2,  0,  4 }, {     -2,   21,    0,  2,  0,  4 }, {     -3,   21,    0,  2,  0,  4 },
    {     -4,   21,    0,  2,  0,  4 }, {     -5,   21,    0,  2,  0,  4 }, {     -6,   22,    0,  2,  0,  4 }, {     -7,   22,    0,  2,  0,  4 }, {     -8,   22,    0,  2,  0,  4 },
    {     -9,   23,    0,  2,  0,  4 }, {    -10,   23,    0,  2,  0,  4 }, {    -11,   23,    0,  2,  0,  4 }, {    -12,   24,    0,  2,  0,  4 }, {    -13,   24,    0,  2,  0,  4 },
    {    -14,   24,    0,  2,  0,  4 }, {    -15,   25,    0,  2,  0,  4 }, {    -16,   25,    0,  2,  0,  4 }, {    -17,   26,    0,  2,  0,  4 }, {    -18,   26,    0,  2,  0,  4 },
    {    -19,   27,    0,  2,  0,  4 }, {    -20,   27,    0,  3,  0,  4 }, {    -21,   28,    0,  3,  0,  4 }, {    -22,   28,    0,  3,  0,  4 }, {    -23,   29,    0,  3,  0,  4 },
    {    -24,   29,    0,  3,  0,  4 }, {    -25,   30,    0,  3,  0,  4 }, {    -26,   30,    0,  3,  0,  4 }, {    -27,   31,    0,  3,  0,  4 }, {    -28,   32,    0,  3,  0,  4 },
    {    -29,   32,    0,  3,  0,  4 }, {    -30,   33,    0,  3,  0,  4 }, {    -31,   34,    0,  3,  0,  4 }, {    -32,   34,    0,  3,  0,  4 }, {    -33,   35,    0,  3,  0,  4 },
    {    -34,   36,    0,  3,  0,  4 }, {    -35,   36,    0,  3,  0,  4 }, {    -36,   37,    0,  3,  0,  4 }, {    -37,   38,    0,  3,  0,  4 }, {    -38,   39,    0,  3,  0,  4 },
    {    -39,   39,    0,  4,  0,  4 }, {    -40,   40,    0,  4,  0,  4 }, {    -41,   41,    0,  4,  0,  4 }, {    -42,   42,    0,  4,  0,  4 }, {    -43,   43,    0,  4,  0,  4 },
    {    -44,   44,    0,  4,  0,  4 }, {    -45,   44,    0,  4,  0,  4 }, {    -46,   45,    0,  4,  0,  4 }, {    -47,   46,    0,  4,  0,  4 }, {    -48,   47,    0,  4,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_914F2F, {
    {     16,    0,    0,  8,  0,  4 }, {     16,    1,    0,  8,  0,  4 }, {     16,    2,    0,  8,  0,  4 }, {     16,    3,    0,  8,  0,  4 }, {     16,    4,    0,  8,  0,  4 },
    {     16,    5,    0,  8,  0,  4 }, {     16,    6,    0,  8,  0,  4 }, {     16,    7,    0,  8,  0,  4 }, {     16,    8,    0,  8,  0,  4 }, {     16,    9,    0,  8,  0,  4 },
    {     16,   10,    0,  8,  0,  4 }, {     16,   11,    0,  9,  0,  4 }, {     16,   12,    0,  9,  0,  4 }, {     16,   13,    0,  9,  0,  4 }, {     17,   14,    0,  9,  0,  4 },
    {     17,   15,    0,  9,  0,  4 }, {     17,   16,    0,  9,  0,  4 }, {     17,   17,    0,  9,  0,  4 }, {     17,   18,    0,  9,  0,  4 }, {     18,   19,    0,  9,  0,  4 },
    {     18,   20,    0,  9,  0,  4 }, {     18,   21,    0,  9,  0,  4 }, {     18,   22,    0,  9,  0,  4 }, {     18,   23,    0,  9,  0,  4 }, {     19,   24,    0,  9,  0,  4 },
    {     19,   25,    0,  9,  0,  4 }, {     19,   26,    0,  9,  0,  4 }, {     19,   27,    0,  9,  0,  4 }, {     19,   28,    0,  9,  0,  4 }, {     20,   29,    0,  9,  0,  4 },
    {     20,   30,    0,  9,  0,  4 }, {     20,   31,    0, 10,  0,  4 }, {     20,   32,    0, 10,  0,  4 }, {     21,   33,    0, 10,  0,  4 }, {     21,   34,    0, 10,  0,  4 },
    {     21,   35,    0, 10,  0,  4 }, {     21,   36,    0, 10,  0,  4 }, {     22,   37,    0, 10,  0,  4 }, {     22,   38,    0, 10,  0,  4 }, {     22,   39,    0, 10,  0,  4 },
    {     23,   40,    0, 10,  0,  4 }, {     23,   41,    0, 10,  0,  4 }, {     23,   42,    0, 10,  0,  4 }, {     24,   43,    0, 10,  0,  4 }, {     24,   44,    0, 10,  0,  4 },
    {     24,   45,    0, 10,  0,  4 }, {     25,   46,    0, 10,  0,  4 }, {     25,   47,    0, 10,  0,  4 }, {     26,   48,    0, 10,  0,  4 }, {     26,   49,    0, 10,  0,  4 },
    {     27,   50,    0, 10,  0,  4 }, {     27,   51,    0, 10,  0,  4 }, {     28,   52,    0, 11,  0,  4 }, {     28,   53,    0, 11,  0,  4 }, {     29,   54,    0, 11,  0,  4 },
    {     29,   55,    0, 11,  0,  4 }, {     30,   56,    0, 11,  0,  4 }, {     30,   57,    0, 11,  0,  4 }, {     31,   58,    0, 11,  0,  4 }, {     32,   59,    0, 11,  0,  4 },
    {     32,   60,    0, 11,  0,  4 }, {     33,   61,    0, 11,  0,  4 }, {     34,   62,    0, 11,  0,  4 }, {     34,   63,    0, 11,  0,  4 }, {     35,   64,    0, 11,  0,  4 },
    {     36,   65,    0, 11,  0,  4 }, {     36,   66,    0, 11,  0,  4 }, {     37,   67,    0, 11,  0,  4 }, {     38,   68,    0, 11,  0,  4 }, {     39,   69,    0, 11,  0,  4 },
    {     39,   70,    0, 11,  0,  4 }, {     40,   71,    0, 12,  0,  4 }, {     41,   72,    0, 12,  0,  4 }, {     42,   73,    0, 12,  0,  4 }, {     43,   74,    0, 12,  0,  4 },
    {     44,   75,    0, 12,  0,  4 }, {     44,   76,    0, 12,  0,  4 }, {     45,   77,    0, 12,  0,  4 }, {     46,   78,    0, 12,  0,  4 }, {     47,   79,    0, 12,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_915201, {
    {      0,   16,    0, 16,  0,  4 }, {      1,   16,    0, 16,  0,  4 }, {      2,   16,    0, 16,  0,  4 }, {      3,   16,    0, 16,  0,  4 }, {      4,   16,    0, 16,  0,  4 },
    {      5,   16,    0, 16,  0,  4 }, {      6,   16,    0, 16,  0,  4 }, {      7,   16,    0, 16,  0,  4 }, {      8,   16,    0, 16,  0,  4 }, {      9,   16,    0, 16,  0,  4 },
    {     10,   16,    0, 16,  0,  4 }, {     11,   16,    0, 17,  0,  4 }, {     12,   16,    0, 17,  0,  4 }, {     13,   15,    0, 17,  0,  4 }, {     14,   15,    0, 17,  0,  4 },
    {     15,   15,    0, 17,  0,  4 }, {     16,   15,    0, 17,  0,  4 }, {     17,   15,    0, 17,  0,  4 }, {     18,   14,    0, 17,  0,  4 }, {     19,   14,    0, 17,  0,  4 },
    {     20,   14,    0, 17,  0,  4 }, {     21,   14,    0, 17,  0,  4 }, {     22,   14,    0, 17,  0,  4 }, {     23,   13,    0, 17,  0,  4 }, {     24,   13,    0, 17,  0,  4 },
    {     25,   13,    0, 17,  0,  4 }, {     26,   13,    0, 17,  0,  4 }, {     27,   13,    0, 17,  0,  4 }, {     28,   12,    0, 17,  0,  4 }, {     29,   12,    0, 17,  0,  4 },
    {     30,   12,    0, 17,  0,  4 }, {     31,   12,    0, 18,  0,  4 }, {     32,   11,    0, 18,  0,  4 }, {     33,   11,    0, 18,  0,  4 }, {     34,   11,    0, 18,  0,  4 },
    {     35,   11,    0, 18,  0,  4 }, {     36,   10,    0, 18,  0,  4 }, {     37,   10,    0, 18,  0,  4 }, {     38,   10,    0, 18,  0,  4 }, {     39,    9,    0, 18,  0,  4 },
    {     40,    9,    0, 18,  0,  4 }, {     41,    9,    0, 18,  0,  4 }, {     42,    8,    0, 18,  0,  4 }, {     43,    8,    0, 18,  0,  4 }, {     44,    8,    0, 18,  0,  4 },
    {     45,    7,    0, 18,  0,  4 }, {     46,    7,    0, 18,  0,  4 }, {     47,    6,    0, 18,  0,  4 }, {     48,    6,    0, 18,  0,  4 }, {     49,    5,    0, 18,  0,  4 },
    {     50,    5,    0, 18,  0,  4 }, {     51,    4,    0, 18,  0,  4 }, {     52,    4,    0, 19,  0,  4 }, {     53,    3,    0, 19,  0,  4 }, {     54,    3,    0, 19,  0,  4 },
    {     55,    2,    0, 19,  0,  4 }, {     56,    2,    0, 19,  0,  4 }, {     57,    1,    0, 19,  0,  4 }, {     58,    0,    0, 19,  0,  4 }, {     59,    0,    0, 19,  0,  4 },
    {     60,   -1,    0, 19,  0,  4 }, {     61,   -2,    0, 19,  0,  4 }, {     62,   -2,    0, 19,  0,  4 }, {     63,   -3,    0, 19,  0,  4 }, {     64,   -4,    0, 19,  0,  4 },
    {     65,   -4,    0, 19,  0,  4 }, {     66,   -5,    0, 19,  0,  4 }, {     67,   -6,    0, 19,  0,  4 }, {     68,   -7,    0, 19,  0,  4 }, {     69,   -7,    0, 19,  0,  4 },
    {     70,   -8,    0, 19,  0,  4 }, {     71,   -9,    0, 20,  0,  4 }, {     72,  -10,    0, 20,  0,  4 }, {     73,  -11,    0, 20,  0,  4 }, {     74,  -12,    0, 20,  0,  4 },
    {     75,  -12,    0, 20,  0,  4 }, {     76,  -13,    0, 20,  0,  4 }, {     77,  -14,    0, 20,  0,  4 }, {     78,  -15,    0, 20,  0,  4 }, {     79,  -16,    0, 20,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9154D3, {
    {     16,   31,    0, 24,  0,  4 }, {     16,   30,    0, 24,  0,  4 }, {     16,   29,    0, 24,  0,  4 }, {     16,   28,    0, 24,  0,  4 }, {     16,   27,    0, 24,  0,  4 },
    {     16,   26,    0, 24,  0,  4 }, {     16,   25,    0, 24,  0,  4 }, {     16,   24,    0, 24,  0,  4 }, {     16,   23,    0, 24,  0,  4 }, {     16,   22,    0, 24,  0,  4 },
    {     16,   21,    0, 25,  0,  4 }, {     16,   20,    0, 25,  0,  4 }, {     16,   19,    0, 25,  0,  4 }, {     15,   18,    0, 25,  0,  4 }, {     15,   17,    0, 25,  0,  4 },
    {     15,   16,    0, 25,  0,  4 }, {     15,   15,    0, 25,  0,  4 }, {     15,   14,    0, 25,  0,  4 }, {     14,   13,    0, 25,  0,  4 }, {     14,   12,    0, 25,  0,  4 },
    {     14,   11,    0, 25,  0,  4 }, {     14,   10,    0, 25,  0,  4 }, {     14,    9,    0, 25,  0,  4 }, {     13,    8,    0, 25,  0,  4 }, {     13,    7,    0, 25,  0,  4 },
    {     13,    6,    0, 25,  0,  4 }, {     13,    5,    0, 25,  0,  4 }, {     13,    4,    0, 25,  0,  4 }, {     12,    3,    0, 25,  0,  4 }, {     12,    2,    0, 25,  0,  4 },
    {     12,    1,    0, 26,  0,  4 }, {     12,    0,    0, 26,  0,  4 }, {     11,   -1,    0, 26,  0,  4 }, {     11,   -2,    0, 26,  0,  4 }, {     11,   -3,    0, 26,  0,  4 },
    {     11,   -4,    0, 26,  0,  4 }, {     10,   -5,    0, 26,  0,  4 }, {     10,   -6,    0, 26,  0,  4 }, {     10,   -7,    0, 26,  0,  4 }, {      9,   -8,    0, 26,  0,  4 },
    {      9,   -9,    0, 26,  0,  4 }, {      9,  -10,    0, 26,  0,  4 }, {      8,  -11,    0, 26,  0,  4 }, {      8,  -12,    0, 26,  0,  4 }, {      8,  -13,    0, 26,  0,  4 },
    {      7,  -14,    0, 26,  0,  4 }, {      7,  -15,    0, 26,  0,  4 }, {      6,  -16,    0, 26,  0,  4 }, {      6,  -17,    0, 26,  0,  4 }, {      5,  -18,    0, 26,  0,  4 },
    {      5,  -19,    0, 26,  0,  4 }, {      4,  -20,    0, 27,  0,  4 }, {      4,  -21,    0, 27,  0,  4 }, {      3,  -22,    0, 27,  0,  4 }, {      3,  -23,    0, 27,  0,  4 },
    {      2,  -24,    0, 27,  0,  4 }, {      2,  -25,    0, 27,  0,  4 }, {      1,  -26,    0, 27,  0,  4 }, {      0,  -27,    0, 27,  0,  4 }, {      0,  -28,    0, 27,  0,  4 },
    {     -1,  -29,    0, 27,  0,  4 }, {     -2,  -30,    0, 27,  0,  4 }, {     -2,  -31,    0, 27,  0,  4 }, {     -3,  -32,    0, 27,  0,  4 }, {     -4,  -33,    0, 27,  0,  4 },
    {     -4,  -34,    0, 27,  0,  4 }, {     -5,  -35,    0, 27,  0,  4 }, {     -6,  -36,    0, 27,  0,  4 }, {     -7,  -37,    0, 27,  0,  4 }, {     -7,  -38,    0, 27,  0,  4 },
    {     -8,  -39,    0, 28,  0,  4 }, {     -9,  -40,    0, 28,  0,  4 }, {    -10,  -41,    0, 28,  0,  4 }, {    -11,  -42,    0, 28,  0,  4 }, {    -12,  -43,    0, 28,  0,  4 },
    {    -12,  -44,    0, 28,  0,  4 }, {    -13,  -45,    0, 28,  0,  4 }, {    -14,  -46,    0, 28,  0,  4 }, {    -15,  -47,    0, 28,  0,  4 }, {    -16,  -48,    0, 28,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91411E, {
    {     15,   17,    0,  4,  0,  2 }, {     14,   18,    0,  4,  0,  2 }, {     13,   19,    0,  4,  0,  2 }, {     12,   20,    0,  4,  0,  2 }, {     11,   20,    0,  4,  0,  2 },
    {     10,   21,    0,  4,  0,  2 }, {      9,   22,    0,  4,  0,  2 }, {      8,   23,    0,  4,  0,  2 }, {      7,   24,    0,  3,  0,  2 }, {      6,   25,    0,  3,  0,  2 },
    {      5,   25,    0,  3,  0,  2 }, {      4,   26,    0,  3,  0,  2 }, {      3,   27,    0,  3,  0,  2 }, {      2,   28,    0,  3,  0,  2 }, {      1,   28,    0,  3,  0,  2 },
    {      0,   29,    0,  3,  0,  2 }, {     -1,   30,    0,  3,  0,  2 }, {     -2,   30,    0,  3,  0,  2 }, {     -3,   31,    0,  3,  0,  2 }, {     -4,   32,    0,  3,  0,  2 },
    {     -5,   32,    0,  3,  0,  2 }, {     -6,   33,    0,  3,  0,  2 }, {     -7,   34,    0,  3,  0,  2 }, {     -8,   34,    0,  3,  0,  2 }, {     -9,   35,    0,  3,  0,  2 },
    {    -10,   35,    0,  3,  0,  2 }, {    -11,   36,    0,  2,  0,  2 }, {    -12,   36,    0,  2,  0,  2 }, {    -13,   37,    0,  2,  0,  2 }, {    -14,   37,    0,  2,  0,  2 },
    {    -15,   38,    0,  2,  0,  2 }, {    -16,   38,    0,  2,  0,  2 }, {    -17,   39,    0,  2,  0,  2 }, {    -18,   39,    0,  2,  0,  2 }, {    -19,   40,    0,  2,  0,  2 },
    {    -20,   40,    0,  2,  0,  2 }, {    -21,   40,    0,  2,  0,  2 }, {    -22,   41,    0,  2,  0,  2 }, {    -23,   41,    0,  2,  0,  2 }, {    -24,   41,    0,  2,  0,  2 },
    {    -25,   42,    0,  2,  0,  2 }, {    -26,   42,    0,  2,  0,  2 }, {    -27,   42,    0,  2,  0,  2 }, {    -28,   43,    0,  2,  0,  2 }, {    -29,   43,    0,  2,  0,  2 },
    {    -30,   43,    0,  2,  0,  2 }, {    -31,   43,    0,  1,  0,  2 }, {    -32,   44,    0,  1,  0,  2 }, {    -33,   44,    0,  1,  0,  2 }, {    -34,   44,    0,  1,  0,  2 },
    {    -35,   44,    0,  1,  0,  2 }, {    -36,   45,    0,  1,  0,  2 }, {    -37,   45,    0,  1,  0,  2 }, {    -38,   45,    0,  1,  0,  2 }, {    -39,   45,    0,  1,  0,  2 },
    {    -40,   45,    0,  1,  0,  2 }, {    -41,   46,    0,  1,  0,  2 }, {    -42,   46,    0,  1,  0,  2 }, {    -43,   46,    0,  1,  0,  2 }, {    -44,   46,    0,  1,  0,  2 },
    {    -45,   46,    0,  1,  0,  2 }, {    -46,   47,    0,  1,  0,  2 }, {    -47,   47,    0,  1,  0,  2 }, {    -48,   47,    0,  1,  0,  2 }, {    -49,   47,    0,  1,  0,  2 },
    {    -50,   47,    0,  1,  0,  2 }, {    -51,   48,    0,  0,  0,  2 }, {    -52,   48,    0,  0,  0,  2 }, {    -53,   48,    0,  0,  0,  2 }, {    -54,   48,    0,  0,  0,  2 },
    {    -55,   48,    0,  0,  0,  2 }, {    -56,   48,    0,  0,  0,  2 }, {    -57,   48,    0,  0,  0,  2 }, {    -58,   48,    0,  0,  0,  2 }, {    -59,   48,    0,  0,  0,  2 },
    {    -60,   48,    0,  0,  0,  2 }, {    -61,   48,    0,  0,  0,  2 }, {    -62,   48,    0,  0,  0,  2 }, {    -63,   48,    0,  0,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9143E7, {
    {     16,   16,    0, 12,  0,  2 }, {     17,   17,    0, 12,  0,  2 }, {     18,   18,    0, 12,  0,  2 }, {     19,   19,    0, 12,  0,  2 }, {     20,   20,    0, 12,  0,  2 },
    {     20,   21,    0, 12,  0,  2 }, {     21,   22,    0, 12,  0,  2 }, {     22,   23,    0, 12,  0,  2 }, {     23,   24,    0, 12,  0,  2 }, {     24,   25,    0, 11,  0,  2 },
    {     25,   26,    0, 11,  0,  2 }, {     25,   27,    0, 11,  0,  2 }, {     26,   28,    0, 11,  0,  2 }, {     27,   29,    0, 11,  0,  2 }, {     28,   30,    0, 11,  0,  2 },
    {     28,   31,    0, 11,  0,  2 }, {     29,   32,    0, 11,  0,  2 }, {     30,   33,    0, 11,  0,  2 }, {     30,   34,    0, 11,  0,  2 }, {     31,   35,    0, 11,  0,  2 },
    {     32,   36,    0, 11,  0,  2 }, {     32,   37,    0, 11,  0,  2 }, {     33,   38,    0, 11,  0,  2 }, {     34,   39,    0, 11,  0,  2 }, {     34,   40,    0, 11,  0,  2 },
    {     35,   41,    0, 11,  0,  2 }, {     35,   42,    0, 11,  0,  2 }, {     36,   43,    0, 10,  0,  2 }, {     36,   44,    0, 10,  0,  2 }, {     37,   45,    0, 10,  0,  2 },
    {     37,   46,    0, 10,  0,  2 }, {     38,   47,    0, 10,  0,  2 }, {     38,   48,    0, 10,  0,  2 }, {     39,   49,    0, 10,  0,  2 }, {     39,   50,    0, 10,  0,  2 },
    {     40,   51,    0, 10,  0,  2 }, {     40,   52,    0, 10,  0,  2 }, {     40,   53,    0, 10,  0,  2 }, {     41,   54,    0, 10,  0,  2 }, {     41,   55,    0, 10,  0,  2 },
    {     41,   56,    0, 10,  0,  2 }, {     42,   57,    0, 10,  0,  2 }, {     42,   58,    0, 10,  0,  2 }, {     42,   59,    0, 10,  0,  2 }, {     43,   60,    0, 10,  0,  2 },
    {     43,   61,    0, 10,  0,  2 }, {     43,   62,    0, 10,  0,  2 }, {     43,   63,    0,  9,  0,  2 }, {     44,   64,    0,  9,  0,  2 }, {     44,   65,    0,  9,  0,  2 },
    {     44,   66,    0,  9,  0,  2 }, {     44,   67,    0,  9,  0,  2 }, {     45,   68,    0,  9,  0,  2 }, {     45,   69,    0,  9,  0,  2 }, {     45,   70,    0,  9,  0,  2 },
    {     45,   71,    0,  9,  0,  2 }, {     45,   72,    0,  9,  0,  2 }, {     46,   73,    0,  9,  0,  2 }, {     46,   74,    0,  9,  0,  2 }, {     46,   75,    0,  9,  0,  2 },
    {     46,   76,    0,  9,  0,  2 }, {     46,   77,    0,  9,  0,  2 }, {     47,   78,    0,  9,  0,  2 }, {     47,   79,    0,  9,  0,  2 }, {     47,   80,    0,  9,  0,  2 },
    {     47,   81,    0,  9,  0,  2 }, {     47,   82,    0,  9,  0,  2 }, {     48,   83,    0,  8,  0,  2 }, {     48,   84,    0,  8,  0,  2 }, {     48,   85,    0,  8,  0,  2 },
    {     48,   86,    0,  8,  0,  2 }, {     48,   87,    0,  8,  0,  2 }, {     48,   88,    0,  8,  0,  2 }, {     48,   89,    0,  8,  0,  2 }, {     48,   90,    0,  8,  0,  2 },
    {     48,   91,    0,  8,  0,  2 }, {     48,   92,    0,  8,  0,  2 }, {     48,   93,    0,  8,  0,  2 }, {     48,   94,    0,  8,  0,  2 }, {     48,   95,    0,  8,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9146B9, {
    {     16,   15,    0, 20,  0,  2 }, {     17,   14,    0, 20,  0,  2 }, {     18,   13,    0, 20,  0,  2 }, {     19,   12,    0, 20,  0,  2 }, {     20,   12,    0, 20,  0,  2 },
    {     21,   11,    0, 20,  0,  2 }, {     22,   10,    0, 20,  0,  2 }, {     23,    9,    0, 20,  0,  2 }, {     24,    8,    0, 19,  0,  2 }, {     25,    7,    0, 19,  0,  2 },
    {     26,    7,    0, 19,  0,  2 }, {     27,    6,    0, 19,  0,  2 }, {     28,    5,    0, 19,  0,  2 }, {     29,    4,    0, 19,  0,  2 }, {     30,    4,    0, 19,  0,  2 },
    {     31,    3,    0, 19,  0,  2 }, {     32,    2,    0, 19,  0,  2 }, {     33,    2,    0, 19,  0,  2 }, {     34,    1,    0, 19,  0,  2 }, {     35,    0,    0, 19,  0,  2 },
    {     36,    0,    0, 19,  0,  2 }, {     37,   -1,    0, 19,  0,  2 }, {     38,   -2,    0, 19,  0,  2 }, {     39,   -2,    0, 19,  0,  2 }, {     40,   -3,    0, 19,  0,  2 },
    {     41,   -3,    0, 19,  0,  2 }, {     42,   -4,    0, 18,  0,  2 }, {     43,   -4,    0, 18,  0,  2 }, {     44,   -5,    0, 18,  0,  2 }, {     45,   -5,    0, 18,  0,  2 },
    {     46,   -6,    0, 18,  0,  2 }, {     47,   -6,    0, 18,  0,  2 }, {     48,   -7,    0, 18,  0,  2 }, {     49,   -7,    0, 18,  0,  2 }, {     50,   -8,    0, 18,  0,  2 },
    {     51,   -8,    0, 18,  0,  2 }, {     52,   -8,    0, 18,  0,  2 }, {     53,   -9,    0, 18,  0,  2 }, {     54,   -9,    0, 18,  0,  2 }, {     55,   -9,    0, 18,  0,  2 },
    {     56,  -10,    0, 18,  0,  2 }, {     57,  -10,    0, 18,  0,  2 }, {     58,  -10,    0, 18,  0,  2 }, {     59,  -11,    0, 18,  0,  2 }, {     60,  -11,    0, 18,  0,  2 },
    {     61,  -11,    0, 18,  0,  2 }, {     62,  -11,    0, 17,  0,  2 }, {     63,  -12,    0, 17,  0,  2 }, {     64,  -12,    0, 17,  0,  2 }, {     65,  -12,    0, 17,  0,  2 },
    {     66,  -12,    0, 17,  0,  2 }, {     67,  -13,    0, 17,  0,  2 }, {     68,  -13,    0, 17,  0,  2 }, {     69,  -13,    0, 17,  0,  2 }, {     70,  -13,    0, 17,  0,  2 },
    {     71,  -13,    0, 17,  0,  2 }, {     72,  -14,    0, 17,  0,  2 }, {     73,  -14,    0, 17,  0,  2 }, {     74,  -14,    0, 17,  0,  2 }, {     75,  -14,    0, 17,  0,  2 },
    {     76,  -14,    0, 17,  0,  2 }, {     77,  -15,    0, 17,  0,  2 }, {     78,  -15,    0, 17,  0,  2 }, {     79,  -15,    0, 17,  0,  2 }, {     80,  -15,    0, 17,  0,  2 },
    {     81,  -15,    0, 17,  0,  2 }, {     82,  -16,    0, 16,  0,  2 }, {     83,  -16,    0, 16,  0,  2 }, {     84,  -16,    0, 16,  0,  2 }, {     85,  -16,    0, 16,  0,  2 },
    {     86,  -16,    0, 16,  0,  2 }, {     87,  -16,    0, 16,  0,  2 }, {     88,  -16,    0, 16,  0,  2 }, {     89,  -16,    0, 16,  0,  2 }, {     90,  -16,    0, 16,  0,  2 },
    {     91,  -16,    0, 16,  0,  2 }, {     92,  -16,    0, 16,  0,  2 }, {     93,  -16,    0, 16,  0,  2 }, {     94,  -16,    0, 16,  0,  2 }, {     95,  -16,    0, 16,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91498B, {
    {     15,   15,    0, 28,  0,  2 }, {     14,   14,    0, 28,  0,  2 }, {     13,   13,    0, 28,  0,  2 }, {     12,   12,    0, 28,  0,  2 }, {     12,   11,    0, 28,  0,  2 },
    {     11,   10,    0, 28,  0,  2 }, {     10,    9,    0, 28,  0,  2 }, {      9,    8,    0, 28,  0,  2 }, {      8,    7,    0, 27,  0,  2 }, {      7,    6,    0, 27,  0,  2 },
    {      7,    5,    0, 27,  0,  2 }, {      6,    4,    0, 27,  0,  2 }, {      5,    3,    0, 27,  0,  2 }, {      4,    2,    0, 27,  0,  2 }, {      4,    1,    0, 27,  0,  2 },
    {      3,    0,    0, 27,  0,  2 }, {      2,   -1,    0, 27,  0,  2 }, {      2,   -2,    0, 27,  0,  2 }, {      1,   -3,    0, 27,  0,  2 }, {      0,   -4,    0, 27,  0,  2 },
    {      0,   -5,    0, 27,  0,  2 }, {     -1,   -6,    0, 27,  0,  2 }, {     -2,   -7,    0, 27,  0,  2 }, {     -2,   -8,    0, 27,  0,  2 }, {     -3,   -9,    0, 27,  0,  2 },
    {     -3,  -10,    0, 27,  0,  2 }, {     -4,  -11,    0, 26,  0,  2 }, {     -4,  -12,    0, 26,  0,  2 }, {     -5,  -13,    0, 26,  0,  2 }, {     -5,  -14,    0, 26,  0,  2 },
    {     -6,  -15,    0, 26,  0,  2 }, {     -6,  -16,    0, 26,  0,  2 }, {     -7,  -17,    0, 26,  0,  2 }, {     -7,  -18,    0, 26,  0,  2 }, {     -8,  -19,    0, 26,  0,  2 },
    {     -8,  -20,    0, 26,  0,  2 }, {     -8,  -21,    0, 26,  0,  2 }, {     -9,  -22,    0, 26,  0,  2 }, {     -9,  -23,    0, 26,  0,  2 }, {     -9,  -24,    0, 26,  0,  2 },
    {    -10,  -25,    0, 26,  0,  2 }, {    -10,  -26,    0, 26,  0,  2 }, {    -10,  -27,    0, 26,  0,  2 }, {    -11,  -28,    0, 26,  0,  2 }, {    -11,  -29,    0, 26,  0,  2 },
    {    -11,  -30,    0, 26,  0,  2 }, {    -11,  -31,    0, 25,  0,  2 }, {    -12,  -32,    0, 25,  0,  2 }, {    -12,  -33,    0, 25,  0,  2 }, {    -12,  -34,    0, 25,  0,  2 },
    {    -12,  -35,    0, 25,  0,  2 }, {    -13,  -36,    0, 25,  0,  2 }, {    -13,  -37,    0, 25,  0,  2 }, {    -13,  -38,    0, 25,  0,  2 }, {    -13,  -39,    0, 25,  0,  2 },
    {    -13,  -40,    0, 25,  0,  2 }, {    -14,  -41,    0, 25,  0,  2 }, {    -14,  -42,    0, 25,  0,  2 }, {    -14,  -43,    0, 25,  0,  2 }, {    -14,  -44,    0, 25,  0,  2 },
    {    -14,  -45,    0, 25,  0,  2 }, {    -15,  -46,    0, 25,  0,  2 }, {    -15,  -47,    0, 25,  0,  2 }, {    -15,  -48,    0, 25,  0,  2 }, {    -15,  -49,    0, 25,  0,  2 },
    {    -15,  -50,    0, 25,  0,  2 }, {    -16,  -51,    0, 24,  0,  2 }, {    -16,  -52,    0, 24,  0,  2 }, {    -16,  -53,    0, 24,  0,  2 }, {    -16,  -54,    0, 24,  0,  2 },
    {    -16,  -55,    0, 24,  0,  2 }, {    -16,  -56,    0, 24,  0,  2 }, {    -16,  -57,    0, 24,  0,  2 }, {    -16,  -58,    0, 24,  0,  2 }, {    -16,  -59,    0, 24,  0,  2 },
    {    -16,  -60,    0, 24,  0,  2 }, {    -16,  -61,    0, 24,  0,  2 }, {    -16,  -62,    0, 24,  0,  2 }, {    -16,  -63,    0, 24,  0,  2 }, {    -16,  -64,    0, 24,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9157A5, {
    {     15,   17,    0,  4,  0,  4 }, {     14,   18,    0,  4,  0,  4 }, {     13,   19,    0,  4,  0,  4 }, {     12,   20,    0,  4,  0,  4 }, {     12,   21,    0,  4,  0,  4 },
    {     11,   22,    0,  4,  0,  4 }, {     10,   23,    0,  4,  0,  4 }, {      9,   24,    0,  4,  0,  4 }, {      8,   25,    0,  5,  0,  4 }, {      7,   26,    0,  5,  0,  4 },
    {      7,   27,    0,  5,  0,  4 }, {      6,   28,    0,  5,  0,  4 }, {      5,   29,    0,  5,  0,  4 }, {      4,   30,    0,  5,  0,  4 }, {      4,   31,    0,  5,  0,  4 },
    {      3,   32,    0,  5,  0,  4 }, {      2,   33,    0,  5,  0,  4 }, {      2,   34,    0,  5,  0,  4 }, {      1,   35,    0,  5,  0,  4 }, {      0,   36,    0,  5,  0,  4 },
    {      0,   37,    0,  5,  0,  4 }, {     -1,   38,    0,  5,  0,  4 }, {     -2,   39,    0,  5,  0,  4 }, {     -2,   40,    0,  5,  0,  4 }, {     -3,   41,    0,  5,  0,  4 },
    {     -3,   42,    0,  5,  0,  4 }, {     -4,   43,    0,  6,  0,  4 }, {     -4,   44,    0,  6,  0,  4 }, {     -5,   45,    0,  6,  0,  4 }, {     -5,   46,    0,  6,  0,  4 },
    {     -6,   47,    0,  6,  0,  4 }, {     -6,   48,    0,  6,  0,  4 }, {     -7,   49,    0,  6,  0,  4 }, {     -7,   50,    0,  6,  0,  4 }, {     -8,   51,    0,  6,  0,  4 },
    {     -8,   52,    0,  6,  0,  4 }, {     -8,   53,    0,  6,  0,  4 }, {     -9,   54,    0,  6,  0,  4 }, {     -9,   55,    0,  6,  0,  4 }, {     -9,   56,    0,  6,  0,  4 },
    {    -10,   57,    0,  6,  0,  4 }, {    -10,   58,    0,  6,  0,  4 }, {    -10,   59,    0,  6,  0,  4 }, {    -11,   60,    0,  6,  0,  4 }, {    -11,   61,    0,  6,  0,  4 },
    {    -11,   62,    0,  6,  0,  4 }, {    -11,   63,    0,  7,  0,  4 }, {    -12,   64,    0,  7,  0,  4 }, {    -12,   65,    0,  7,  0,  4 }, {    -12,   66,    0,  7,  0,  4 },
    {    -12,   67,    0,  7,  0,  4 }, {    -13,   68,    0,  7,  0,  4 }, {    -13,   69,    0,  7,  0,  4 }, {    -13,   70,    0,  7,  0,  4 }, {    -13,   71,    0,  7,  0,  4 },
    {    -13,   72,    0,  7,  0,  4 }, {    -14,   73,    0,  7,  0,  4 }, {    -14,   74,    0,  7,  0,  4 }, {    -14,   75,    0,  7,  0,  4 }, {    -14,   76,    0,  7,  0,  4 },
    {    -14,   77,    0,  7,  0,  4 }, {    -15,   78,    0,  7,  0,  4 }, {    -15,   79,    0,  7,  0,  4 }, {    -15,   80,    0,  7,  0,  4 }, {    -15,   81,    0,  7,  0,  4 },
    {    -15,   82,    0,  7,  0,  4 }, {    -16,   83,    0,  8,  0,  4 }, {    -16,   84,    0,  8,  0,  4 }, {    -16,   85,    0,  8,  0,  4 }, {    -16,   86,    0,  8,  0,  4 },
    {    -16,   87,    0,  8,  0,  4 }, {    -16,   88,    0,  8,  0,  4 }, {    -16,   89,    0,  8,  0,  4 }, {    -16,   90,    0,  8,  0,  4 }, {    -16,   91,    0,  8,  0,  4 },
    {    -16,   92,    0,  8,  0,  4 }, {    -16,   93,    0,  8,  0,  4 }, {    -16,   94,    0,  8,  0,  4 }, {    -16,   95,    0,  8,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_915A6E, {
    {     16,   16,    0, 12,  0,  4 }, {     17,   17,    0, 12,  0,  4 }, {     18,   18,    0, 12,  0,  4 }, {     19,   19,    0, 12,  0,  4 }, {     20,   20,    0, 12,  0,  4 },
    {     21,   20,    0, 12,  0,  4 }, {     22,   21,    0, 12,  0,  4 }, {     23,   22,    0, 12,  0,  4 }, {     24,   23,    0, 12,  0,  4 }, {     25,   24,    0, 13,  0,  4 },
    {     26,   25,    0, 13,  0,  4 }, {     27,   25,    0, 13,  0,  4 }, {     28,   26,    0, 13,  0,  4 }, {     29,   27,    0, 13,  0,  4 }, {     30,   28,    0, 13,  0,  4 },
    {     31,   28,    0, 13,  0,  4 }, {     32,   29,    0, 13,  0,  4 }, {     33,   30,    0, 13,  0,  4 }, {     34,   30,    0, 13,  0,  4 }, {     35,   31,    0, 13,  0,  4 },
    {     36,   32,    0, 13,  0,  4 }, {     37,   32,    0, 13,  0,  4 }, {     38,   33,    0, 13,  0,  4 }, {     39,   34,    0, 13,  0,  4 }, {     40,   34,    0, 13,  0,  4 },
    {     41,   35,    0, 13,  0,  4 }, {     42,   35,    0, 13,  0,  4 }, {     43,   36,    0, 14,  0,  4 }, {     44,   36,    0, 14,  0,  4 }, {     45,   37,    0, 14,  0,  4 },
    {     46,   37,    0, 14,  0,  4 }, {     47,   38,    0, 14,  0,  4 }, {     48,   38,    0, 14,  0,  4 }, {     49,   39,    0, 14,  0,  4 }, {     50,   39,    0, 14,  0,  4 },
    {     51,   40,    0, 14,  0,  4 }, {     52,   40,    0, 14,  0,  4 }, {     53,   40,    0, 14,  0,  4 }, {     54,   41,    0, 14,  0,  4 }, {     55,   41,    0, 14,  0,  4 },
    {     56,   41,    0, 14,  0,  4 }, {     57,   42,    0, 14,  0,  4 }, {     58,   42,    0, 14,  0,  4 }, {     59,   42,    0, 14,  0,  4 }, {     60,   43,    0, 14,  0,  4 },
    {     61,   43,    0, 14,  0,  4 }, {     62,   43,    0, 14,  0,  4 }, {     63,   43,    0, 15,  0,  4 }, {     64,   44,    0, 15,  0,  4 }, {     65,   44,    0, 15,  0,  4 },
    {     66,   44,    0, 15,  0,  4 }, {     67,   44,    0, 15,  0,  4 }, {     68,   45,    0, 15,  0,  4 }, {     69,   45,    0, 15,  0,  4 }, {     70,   45,    0, 15,  0,  4 },
    {     71,   45,    0, 15,  0,  4 }, {     72,   45,    0, 15,  0,  4 }, {     73,   46,    0, 15,  0,  4 }, {     74,   46,    0, 15,  0,  4 }, {     75,   46,    0, 15,  0,  4 },
    {     76,   46,    0, 15,  0,  4 }, {     77,   46,    0, 15,  0,  4 }, {     78,   47,    0, 15,  0,  4 }, {     79,   47,    0, 15,  0,  4 }, {     80,   47,    0, 15,  0,  4 },
    {     81,   47,    0, 15,  0,  4 }, {     82,   47,    0, 15,  0,  4 }, {     83,   48,    0, 16,  0,  4 }, {     84,   48,    0, 16,  0,  4 }, {     85,   48,    0, 16,  0,  4 },
    {     86,   48,    0, 16,  0,  4 }, {     87,   48,    0, 16,  0,  4 }, {     88,   48,    0, 16,  0,  4 }, {     89,   48,    0, 16,  0,  4 }, {     90,   48,    0, 16,  0,  4 },
    {     91,   48,    0, 16,  0,  4 }, {     92,   48,    0, 16,  0,  4 }, {     93,   48,    0, 16,  0,  4 }, {     94,   48,    0, 16,  0,  4 }, {     95,   48,    0, 16,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_915D40, {
    {     16,   15,    0, 20,  0,  4 }, {     17,   14,    0, 20,  0,  4 }, {     18,   13,    0, 20,  0,  4 }, {     19,   12,    0, 20,  0,  4 }, {     19,   11,    0, 20,  0,  4 },
    {     20,   10,    0, 20,  0,  4 }, {     21,    9,    0, 20,  0,  4 }, {     22,    8,    0, 20,  0,  4 }, {     23,    7,    0, 21,  0,  4 }, {     24,    6,    0, 21,  0,  4 },
    {     24,    5,    0, 21,  0,  4 }, {     25,    4,    0, 21,  0,  4 }, {     26,    3,    0, 21,  0,  4 }, {     27,    2,    0, 21,  0,  4 }, {     27,    1,    0, 21,  0,  4 },
    {     28,    0,    0, 21,  0,  4 }, {     29,   -1,    0, 21,  0,  4 }, {     29,   -2,    0, 21,  0,  4 }, {     30,   -3,    0, 21,  0,  4 }, {     31,   -4,    0, 21,  0,  4 },
    {     31,   -5,    0, 21,  0,  4 }, {     32,   -6,    0, 21,  0,  4 }, {     33,   -7,    0, 21,  0,  4 }, {     33,   -8,    0, 21,  0,  4 }, {     34,   -9,    0, 21,  0,  4 },
    {     34,  -10,    0, 21,  0,  4 }, {     35,  -11,    0, 22,  0,  4 }, {     35,  -12,    0, 22,  0,  4 }, {     36,  -13,    0, 22,  0,  4 }, {     36,  -14,    0, 22,  0,  4 },
    {     37,  -15,    0, 22,  0,  4 }, {     37,  -16,    0, 22,  0,  4 }, {     38,  -17,    0, 22,  0,  4 }, {     38,  -18,    0, 22,  0,  4 }, {     39,  -19,    0, 22,  0,  4 },
    {     39,  -20,    0, 22,  0,  4 }, {     39,  -21,    0, 22,  0,  4 }, {     40,  -22,    0, 22,  0,  4 }, {     40,  -23,    0, 22,  0,  4 }, {     40,  -24,    0, 22,  0,  4 },
    {     41,  -25,    0, 22,  0,  4 }, {     41,  -26,    0, 22,  0,  4 }, {     41,  -27,    0, 22,  0,  4 }, {     42,  -28,    0, 22,  0,  4 }, {     42,  -29,    0, 22,  0,  4 },
    {     42,  -30,    0, 22,  0,  4 }, {     42,  -31,    0, 23,  0,  4 }, {     43,  -32,    0, 23,  0,  4 }, {     43,  -33,    0, 23,  0,  4 }, {     43,  -34,    0, 23,  0,  4 },
    {     43,  -35,    0, 23,  0,  4 }, {     44,  -36,    0, 23,  0,  4 }, {     44,  -37,    0, 23,  0,  4 }, {     44,  -38,    0, 23,  0,  4 }, {     44,  -39,    0, 23,  0,  4 },
    {     44,  -40,    0, 23,  0,  4 }, {     45,  -41,    0, 23,  0,  4 }, {     45,  -42,    0, 23,  0,  4 }, {     45,  -43,    0, 23,  0,  4 }, {     45,  -44,    0, 23,  0,  4 },
    {     45,  -45,    0, 23,  0,  4 }, {     46,  -46,    0, 23,  0,  4 }, {     46,  -47,    0, 23,  0,  4 }, {     46,  -48,    0, 23,  0,  4 }, {     46,  -49,    0, 23,  0,  4 },
    {     46,  -50,    0, 23,  0,  4 }, {     47,  -51,    0, 24,  0,  4 }, {     47,  -52,    0, 24,  0,  4 }, {     47,  -53,    0, 24,  0,  4 }, {     47,  -54,    0, 24,  0,  4 },
    {     47,  -55,    0, 24,  0,  4 }, {     47,  -56,    0, 24,  0,  4 }, {     47,  -57,    0, 24,  0,  4 }, {     47,  -58,    0, 24,  0,  4 }, {     47,  -59,    0, 24,  0,  4 },
    {     47,  -60,    0, 24,  0,  4 }, {     47,  -61,    0, 24,  0,  4 }, {     47,  -62,    0, 24,  0,  4 }, {     47,  -63,    0, 24,  0,  4 }, {     47,  -64,    0, 24,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_916012, {
    {     15,   15,    0, 28,  0,  4 }, {     14,   14,    0, 28,  0,  4 }, {     13,   13,    0, 28,  0,  4 }, {     12,   12,    0, 28,  0,  4 }, {     11,   12,    0, 28,  0,  4 },
    {     10,   11,    0, 28,  0,  4 }, {      9,   10,    0, 28,  0,  4 }, {      8,    9,    0, 28,  0,  4 }, {      7,    8,    0, 29,  0,  4 }, {      6,    7,    0, 29,  0,  4 },
    {      5,    7,    0, 29,  0,  4 }, {      4,    6,    0, 29,  0,  4 }, {      3,    5,    0, 29,  0,  4 }, {      2,    4,    0, 29,  0,  4 }, {      1,    4,    0, 29,  0,  4 },
    {      0,    3,    0, 29,  0,  4 }, {     -1,    2,    0, 29,  0,  4 }, {     -2,    2,    0, 29,  0,  4 }, {     -3,    1,    0, 29,  0,  4 }, {     -4,    0,    0, 29,  0,  4 },
    {     -5,    0,    0, 29,  0,  4 }, {     -6,   -1,    0, 29,  0,  4 }, {     -7,   -2,    0, 29,  0,  4 }, {     -8,   -2,    0, 29,  0,  4 }, {     -9,   -3,    0, 29,  0,  4 },
    {    -10,   -3,    0, 29,  0,  4 }, {    -11,   -4,    0, 30,  0,  4 }, {    -12,   -4,    0, 30,  0,  4 }, {    -13,   -5,    0, 30,  0,  4 }, {    -14,   -5,    0, 30,  0,  4 },
    {    -15,   -6,    0, 30,  0,  4 }, {    -16,   -6,    0, 30,  0,  4 }, {    -17,   -7,    0, 30,  0,  4 }, {    -18,   -7,    0, 30,  0,  4 }, {    -19,   -8,    0, 30,  0,  4 },
    {    -20,   -8,    0, 30,  0,  4 }, {    -21,   -8,    0, 30,  0,  4 }, {    -22,   -9,    0, 30,  0,  4 }, {    -23,   -9,    0, 30,  0,  4 }, {    -24,   -9,    0, 30,  0,  4 },
    {    -25,  -10,    0, 30,  0,  4 }, {    -26,  -10,    0, 30,  0,  4 }, {    -27,  -10,    0, 30,  0,  4 }, {    -28,  -11,    0, 30,  0,  4 }, {    -29,  -11,    0, 30,  0,  4 },
    {    -30,  -11,    0, 30,  0,  4 }, {    -31,  -11,    0, 31,  0,  4 }, {    -32,  -12,    0, 31,  0,  4 }, {    -33,  -12,    0, 31,  0,  4 }, {    -34,  -12,    0, 31,  0,  4 },
    {    -35,  -12,    0, 31,  0,  4 }, {    -36,  -13,    0, 31,  0,  4 }, {    -37,  -13,    0, 31,  0,  4 }, {    -38,  -13,    0, 31,  0,  4 }, {    -39,  -13,    0, 31,  0,  4 },
    {    -40,  -13,    0, 31,  0,  4 }, {    -41,  -14,    0, 31,  0,  4 }, {    -42,  -14,    0, 31,  0,  4 }, {    -43,  -14,    0, 31,  0,  4 }, {    -44,  -14,    0, 31,  0,  4 },
    {    -45,  -14,    0, 31,  0,  4 }, {    -46,  -15,    0, 31,  0,  4 }, {    -47,  -15,    0, 31,  0,  4 }, {    -48,  -15,    0, 31,  0,  4 }, {    -49,  -15,    0, 31,  0,  4 },
    {    -50,  -15,    0, 31,  0,  4 }, {    -51,  -16,    0,  0,  0,  4 }, {    -52,  -16,    0,  0,  0,  4 }, {    -53,  -16,    0,  0,  0,  4 }, {    -54,  -16,    0,  0,  0,  4 },
    {    -55,  -16,    0,  0,  0,  4 }, {    -56,  -16,    0,  0,  0,  4 }, {    -57,  -16,    0,  0,  0,  4 }, {    -58,  -16,    0,  0,  0,  4 }, {    -59,  -16,    0,  0,  0,  4 },
    {    -60,  -16,    0,  0,  0,  4 }, {    -61,  -16,    0,  0,  0,  4 }, {    -62,  -16,    0,  0,  0,  4 }, {    -63,  -16,    0,  0,  0,  4 }, {    -64,  -16,    0,  0,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9162E6, {
    {     15,   16,    0,  4,  0,  0 }, {     14,   17,    0,  4,  0,  0 }, {     13,   18,    0,  4,  0,  0 }, {     12,   19,    0,  4,  0,  0 }, {     11,   20,    0,  4,  0,  0 },
    {     10,   21,    0,  4,  0,  0 }, {      9,   22,    0,  4,  0,  0 }, {      8,   23,    0,  4,  0,  0 }, {      7,   24,    0,  4,  0,  0 }, {      6,   25,    0,  4,  0,  0 },
    {      5,   26,    0,  4,  0,  0 }, {      4,   27,    0,  4,  0,  0 }, {      3,   28,    0,  4,  0,  0 }, {      2,   29,    0,  4,  0,  0 }, {      1,   30,    0,  4,  0,  0 },
    {      0,   31,    0,  4,  0,  0 }, {     -1,   32,    0,  4,  0,  0 }, {     -2,   33,    0,  4,  0,  0 }, {     -3,   34,    0,  4,  0,  0 }, {     -4,   35,    0,  4,  0,  0 },
    {     -5,   36,    0,  4,  0,  0 }, {     -6,   37,    0,  4,  0,  0 }, {     -7,   38,    0,  4,  0,  0 }, {     -8,   39,    0,  4,  0,  0 }, {     -9,   40,    0,  4,  0,  0 },
    {    -10,   41,    0,  4,  0,  0 }, {    -11,   42,    0,  4,  0,  0 }, {    -12,   43,    0,  4,  0,  0 }, {    -13,   44,    0,  4,  0,  0 }, {    -14,   45,    0,  4,  0,  0 },
    {    -15,   46,    0,  4,  0,  0 }, {    -16,   47,    0,  4,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_916408, {
    {     16,   16,    0, 12,  0,  0 }, {     17,   17,    0, 12,  0,  0 }, {     18,   18,    0, 12,  0,  0 }, {     19,   19,    0, 12,  0,  0 }, {     20,   20,    0, 12,  0,  0 },
    {     21,   21,    0, 12,  0,  0 }, {     22,   22,    0, 12,  0,  0 }, {     23,   23,    0, 12,  0,  0 }, {     24,   24,    0, 12,  0,  0 }, {     25,   25,    0, 12,  0,  0 },
    {     26,   26,    0, 12,  0,  0 }, {     27,   27,    0, 12,  0,  0 }, {     28,   28,    0, 12,  0,  0 }, {     29,   29,    0, 12,  0,  0 }, {     30,   30,    0, 12,  0,  0 },
    {     31,   31,    0, 12,  0,  0 }, {     32,   32,    0, 12,  0,  0 }, {     33,   33,    0, 12,  0,  0 }, {     34,   34,    0, 12,  0,  0 }, {     35,   35,    0, 12,  0,  0 },
    {     36,   36,    0, 12,  0,  0 }, {     37,   37,    0, 12,  0,  0 }, {     38,   38,    0, 12,  0,  0 }, {     39,   39,    0, 12,  0,  0 }, {     40,   40,    0, 12,  0,  0 },
    {     41,   41,    0, 12,  0,  0 }, {     42,   42,    0, 12,  0,  0 }, {     43,   43,    0, 12,  0,  0 }, {     44,   44,    0, 12,  0,  0 }, {     45,   45,    0, 12,  0,  0 },
    {     46,   46,    0, 12,  0,  0 }, {     47,   47,    0, 12,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91652A, {
    {     16,   15,    0, 20,  0,  0 }, {     17,   14,    0, 20,  0,  0 }, {     18,   13,    0, 20,  0,  0 }, {     19,   12,    0, 20,  0,  0 }, {     20,   11,    0, 20,  0,  0 },
    {     21,   10,    0, 20,  0,  0 }, {     22,    9,    0, 20,  0,  0 }, {     23,    8,    0, 20,  0,  0 }, {     24,    7,    0, 20,  0,  0 }, {     25,    6,    0, 20,  0,  0 },
    {     26,    5,    0, 20,  0,  0 }, {     27,    4,    0, 20,  0,  0 }, {     28,    3,    0, 20,  0,  0 }, {     29,    2,    0, 20,  0,  0 }, {     30,    1,    0, 20,  0,  0 },
    {     31,    0,    0, 20,  0,  0 }, {     32,   -1,    0, 20,  0,  0 }, {     33,   -2,    0, 20,  0,  0 }, {     34,   -3,    0, 20,  0,  0 }, {     35,   -4,    0, 20,  0,  0 },
    {     36,   -5,    0, 20,  0,  0 }, {     37,   -6,    0, 20,  0,  0 }, {     38,   -7,    0, 20,  0,  0 }, {     39,   -8,    0, 20,  0,  0 }, {     40,   -9,    0, 20,  0,  0 },
    {     41,  -10,    0, 20,  0,  0 }, {     42,  -11,    0, 20,  0,  0 }, {     43,  -12,    0, 20,  0,  0 }, {     44,  -13,    0, 20,  0,  0 }, {     45,  -14,    0, 20,  0,  0 },
    {     46,  -15,    0, 20,  0,  0 }, {     47,  -16,    0, 20,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91664C, {
    {     15,   15,    0, 28,  0,  0 }, {     14,   14,    0, 28,  0,  0 }, {     13,   13,    0, 28,  0,  0 }, {     12,   12,    0, 28,  0,  0 }, {     11,   11,    0, 28,  0,  0 },
    {     10,   10,    0, 28,  0,  0 }, {      9,    9,    0, 28,  0,  0 }, {      8,    8,    0, 28,  0,  0 }, {      7,    7,    0, 28,  0,  0 }, {      6,    6,    0, 28,  0,  0 },
    {      5,    5,    0, 28,  0,  0 }, {      4,    4,    0, 28,  0,  0 }, {      3,    3,    0, 28,  0,  0 }, {      2,    2,    0, 28,  0,  0 }, {      1,    1,    0, 28,  0,  0 },
    {      0,    0,    0, 28,  0,  0 }, {     -1,   -1,    0, 28,  0,  0 }, {     -2,   -2,    0, 28,  0,  0 }, {     -3,   -3,    0, 28,  0,  0 }, {     -4,   -4,    0, 28,  0,  0 },
    {     -5,   -5,    0, 28,  0,  0 }, {     -6,   -6,    0, 28,  0,  0 }, {     -7,   -7,    0, 28,  0,  0 }, {     -8,   -8,    0, 28,  0,  0 }, {     -9,   -9,    0, 28,  0,  0 },
    {    -10,  -10,    0, 28,  0,  0 }, {    -11,  -11,    0, 28,  0,  0 }, {    -12,  -12,    0, 28,  0,  0 }, {    -13,  -13,    0, 28,  0,  0 }, {    -14,  -14,    0, 28,  0,  0 },
    {    -15,  -15,    0, 28,  0,  0 }, {    -16,  -16,    0, 28,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91676E, {
    {     15,   16,    0,  4, 51,  0 }, {     14,   17,    1,  4, 51,  0 }, {     13,   18,    1,  4, 51,  0 }, {     12,   19,    2,  4, 51,  0 }, {     11,   20,    2,  4, 51,  0 },
    {     10,   21,    3,  4, 51,  0 }, {      9,   22,    3,  4, 51,  0 }, {      8,   23,    4,  4, 51,  0 }, {      7,   24,    4,  4, 51,  0 }, {      6,   25,    5,  4, 51,  0 },
    {      5,   26,    5,  4, 51,  0 }, {      4,   27,    6,  4, 51,  0 }, {      3,   28,    6,  4, 51,  0 }, {      2,   29,    7,  4, 51,  0 }, {      1,   30,    7,  4, 51,  0 },
    {      0,   31,    8,  4, 51,  0 }, {     -1,   32,    8,  4, 51,  0 }, {     -2,   33,    9,  4, 51,  0 }, {     -3,   34,    9,  4, 51,  0 }, {     -4,   35,   10,  4, 51,  0 },
    {     -5,   36,   10,  4, 51,  0 }, {     -6,   37,   11,  4, 51,  0 }, {     -7,   38,   11,  4, 51,  0 }, {     -8,   39,   12,  4, 51,  0 }, {     -9,   40,   12,  4, 51,  0 },
    {    -10,   41,   13,  4, 51,  0 }, {    -11,   42,   13,  4, 51,  0 }, {    -12,   43,   14,  4, 51,  0 }, {    -13,   44,   14,  4, 51,  0 }, {    -14,   45,   15,  4, 51,  0 },
    {    -15,   46,   15,  4, 51,  0 }, {    -16,   47,   16,  4, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_916890, {
    {     16,   16,    0, 12, 51,  0 }, {     17,   17,    0, 12, 51,  0 }, {     18,   18,    1, 12, 51,  0 }, {     19,   19,    1, 12, 51,  0 }, {     20,   20,    2, 12, 51,  0 },
    {     21,   21,    2, 12, 51,  0 }, {     22,   22,    3, 12, 51,  0 }, {     23,   23,    3, 12, 51,  0 }, {     24,   24,    4, 12, 51,  0 }, {     25,   25,    4, 12, 51,  0 },
    {     26,   26,    5, 12, 51,  0 }, {     27,   27,    5, 12, 51,  0 }, {     28,   28,    6, 12, 51,  0 }, {     29,   29,    6, 12, 51,  0 }, {     30,   30,    7, 12, 51,  0 },
    {     31,   31,    7, 12, 51,  0 }, {     32,   32,    8, 12, 51,  0 }, {     33,   33,    8, 12, 51,  0 }, {     34,   34,    9, 12, 51,  0 }, {     35,   35,    9, 12, 51,  0 },
    {     36,   36,   10, 12, 51,  0 }, {     37,   37,   10, 12, 51,  0 }, {     38,   38,   11, 12, 51,  0 }, {     39,   39,   11, 12, 51,  0 }, {     40,   40,   12, 12, 51,  0 },
    {     41,   41,   12, 12, 51,  0 }, {     42,   42,   13, 12, 51,  0 }, {     43,   43,   13, 12, 51,  0 }, {     44,   44,   14, 12, 51,  0 }, {     45,   45,   14, 12, 51,  0 },
    {     46,   46,   15, 12, 51,  0 }, {     47,   47,   15, 12, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9169B2, {
    {     16,   15,    0, 20, 51,  0 }, {     17,   14,    0, 20, 51,  0 }, {     18,   13,    1, 20, 51,  0 }, {     19,   12,    1, 20, 51,  0 }, {     20,   11,    2, 20, 51,  0 },
    {     21,   10,    2, 20, 51,  0 }, {     22,    9,    3, 20, 51,  0 }, {     23,    8,    3, 20, 51,  0 }, {     24,    7,    4, 20, 51,  0 }, {     25,    6,    4, 20, 51,  0 },
    {     26,    5,    5, 20, 51,  0 }, {     27,    4,    5, 20, 51,  0 }, {     28,    3,    6, 20, 51,  0 }, {     29,    2,    6, 20, 51,  0 }, {     30,    1,    7, 20, 51,  0 },
    {     31,    0,    7, 20, 51,  0 }, {     32,   -1,    8, 20, 51,  0 }, {     33,   -2,    8, 20, 51,  0 }, {     34,   -3,    9, 20, 51,  0 }, {     35,   -4,    9, 20, 51,  0 },
    {     36,   -5,   10, 20, 51,  0 }, {     37,   -6,   10, 20, 51,  0 }, {     38,   -7,   11, 20, 51,  0 }, {     39,   -8,   11, 20, 51,  0 }, {     40,   -9,   12, 20, 51,  0 },
    {     41,  -10,   12, 20, 51,  0 }, {     42,  -11,   13, 20, 51,  0 }, {     43,  -12,   13, 20, 51,  0 }, {     44,  -13,   14, 20, 51,  0 }, {     45,  -14,   14, 20, 51,  0 },
    {     46,  -15,   15, 20, 51,  0 }, {     47,  -16,   15, 20, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_916AD4, {
    {     15,   15,    0, 28, 51,  0 }, {     14,   14,    1, 28, 51,  0 }, {     13,   13,    1, 28, 51,  0 }, {     12,   12,    2, 28, 51,  0 }, {     11,   11,    2, 28, 51,  0 },
    {     10,   10,    3, 28, 51,  0 }, {      9,    9,    3, 28, 51,  0 }, {      8,    8,    4, 28, 51,  0 }, {      7,    7,    4, 28, 51,  0 }, {      6,    6,    5, 28, 51,  0 },
    {      5,    5,    5, 28, 51,  0 }, {      4,    4,    6, 28, 51,  0 }, {      3,    3,    6, 28, 51,  0 }, {      2,    2,    7, 28, 51,  0 }, {      1,    1,    7, 28, 51,  0 },
    {      0,    0,    8, 28, 51,  0 }, {     -1,   -1,    8, 28, 51,  0 }, {     -2,   -2,    9, 28, 51,  0 }, {     -3,   -3,    9, 28, 51,  0 }, {     -4,   -4,   10, 28, 51,  0 },
    {     -5,   -5,   10, 28, 51,  0 }, {     -6,   -6,   11, 28, 51,  0 }, {     -7,   -7,   11, 28, 51,  0 }, {     -8,   -8,   12, 28, 51,  0 }, {     -9,   -9,   12, 28, 51,  0 },
    {    -10,  -10,   13, 28, 51,  0 }, {    -11,  -11,   13, 28, 51,  0 }, {    -12,  -12,   14, 28, 51,  0 }, {    -13,  -13,   14, 28, 51,  0 }, {    -14,  -14,   15, 28, 51,  0 },
    {    -15,  -15,   15, 28, 51,  0 }, {    -16,  -16,   16, 28, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91707E, {
    {     15,   16,    0,  4, 52,  0 }, {     15,   16,    1,  4, 52,  0 }, {     14,   17,    2,  4, 52,  0 }, {     14,   17,    3,  4, 52,  0 }, {     13,   18,    4,  4, 52,  0 },
    {     13,   18,    5,  4, 52,  0 }, {     12,   19,    6,  4, 52,  0 }, {     12,   19,    7,  4, 52,  0 }, {     11,   20,    8,  4, 52,  0 }, {     11,   20,    9,  4, 52,  0 },
    {     10,   21,   10,  4, 52,  0 }, {     10,   21,   11,  4, 52,  0 }, {      9,   22,   12,  4, 52,  0 }, {      9,   22,   13,  4, 52,  0 }, {      8,   23,   14,  4, 52,  0 },
    {      8,   23,   15,  4, 52,  0 }, {      7,   24,   16,  4, 52,  0 }, {      7,   24,   17,  4, 52,  0 }, {      6,   25,   18,  4, 52,  0 }, {      6,   25,   19,  4, 52,  0 },
    {      5,   26,   20,  4, 52,  0 }, {      5,   26,   21,  4, 52,  0 }, {      4,   27,   22,  4, 52,  0 }, {      4,   27,   23,  4, 52,  0 }, {      3,   28,   24,  4, 52,  0 },
    {      3,   28,   25,  4, 52,  0 }, {      2,   29,   26,  4, 52,  0 }, {      2,   29,   27,  4, 52,  0 }, {      1,   30,   28,  4, 52,  0 }, {      1,   30,   29,  4, 52,  0 },
    {      0,   31,   30,  4, 52,  0 }, {      0,   31,   31,  4, 52,  0 }, {     -1,   32,   32,  4, 52,  0 }, {     -1,   32,   33,  4, 52,  0 }, {     -2,   33,   34,  4, 52,  0 },
    {     -2,   33,   35,  4, 52,  0 }, {     -3,   34,   36,  4, 52,  0 }, {     -3,   34,   37,  4, 52,  0 }, {     -4,   35,   38,  4, 52,  0 }, {     -4,   35,   39,  4, 52,  0 },
    {     -5,   36,   40,  4, 52,  0 }, {     -5,   36,   41,  4, 52,  0 }, {     -6,   37,   42,  4, 52,  0 }, {     -6,   37,   43,  4, 52,  0 }, {     -7,   38,   44,  4, 52,  0 },
    {     -7,   38,   45,  4, 52,  0 }, {     -8,   39,   46,  4, 52,  0 }, {     -8,   39,   47,  4, 52,  0 }, {     -9,   40,   48,  4, 52,  0 }, {     -9,   40,   49,  4, 52,  0 },
    {    -10,   41,   50,  4, 52,  0 }, {    -10,   41,   51,  4, 52,  0 }, {    -11,   42,   52,  4, 52,  0 }, {    -11,   42,   53,  4, 52,  0 }, {    -12,   43,   54,  4, 52,  0 },
    {    -12,   43,   55,  4, 52,  0 }, {    -13,   44,   56,  4, 52,  0 }, {    -13,   44,   57,  4, 52,  0 }, {    -14,   45,   58,  4, 52,  0 }, {    -14,   45,   59,  4, 52,  0 },
    {    -15,   46,   60,  4, 52,  0 }, {    -15,   46,   61,  4, 52,  0 }, {    -16,   47,   62,  4, 52,  0 }, {    -16,   47,   63,  4, 52,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9172C0, {
    {     16,   16,    0, 12, 52,  0 }, {     16,   16,    1, 12, 52,  0 }, {     17,   17,    2, 12, 52,  0 }, {     17,   17,    3, 12, 52,  0 }, {     18,   18,    4, 12, 52,  0 },
    {     18,   18,    5, 12, 52,  0 }, {     19,   19,    6, 12, 52,  0 }, {     19,   19,    7, 12, 52,  0 }, {     20,   20,    8, 12, 52,  0 }, {     20,   20,    9, 12, 52,  0 },
    {     21,   21,   10, 12, 52,  0 }, {     21,   21,   11, 12, 52,  0 }, {     22,   22,   12, 12, 52,  0 }, {     22,   22,   13, 12, 52,  0 }, {     23,   23,   14, 12, 52,  0 },
    {     23,   23,   15, 12, 52,  0 }, {     24,   24,   16, 12, 52,  0 }, {     24,   24,   17, 12, 52,  0 }, {     25,   25,   18, 12, 52,  0 }, {     25,   25,   19, 12, 52,  0 },
    {     26,   26,   20, 12, 52,  0 }, {     26,   26,   21, 12, 52,  0 }, {     27,   27,   22, 12, 52,  0 }, {     27,   27,   23, 12, 52,  0 }, {     28,   28,   24, 12, 52,  0 },
    {     28,   28,   25, 12, 52,  0 }, {     29,   29,   26, 12, 52,  0 }, {     29,   29,   27, 12, 52,  0 }, {     30,   30,   28, 12, 52,  0 }, {     30,   30,   29, 12, 52,  0 },
    {     31,   31,   30, 12, 52,  0 }, {     31,   31,   31, 12, 52,  0 }, {     32,   32,   32, 12, 52,  0 }, {     32,   32,   33, 12, 52,  0 }, {     33,   33,   34, 12, 52,  0 },
    {     33,   33,   35, 12, 52,  0 }, {     34,   34,   36, 12, 52,  0 }, {     34,   34,   37, 12, 52,  0 }, {     35,   35,   38, 12, 52,  0 }, {     35,   35,   39, 12, 52,  0 },
    {     36,   36,   40, 12, 52,  0 }, {     36,   36,   41, 12, 52,  0 }, {     37,   37,   42, 12, 52,  0 }, {     37,   37,   43, 12, 52,  0 }, {     38,   38,   44, 12, 52,  0 },
    {     38,   38,   45, 12, 52,  0 }, {     39,   39,   46, 12, 52,  0 }, {     39,   39,   47, 12, 52,  0 }, {     40,   40,   48, 12, 52,  0 }, {     40,   40,   49, 12, 52,  0 },
    {     41,   41,   50, 12, 52,  0 }, {     41,   41,   51, 12, 52,  0 }, {     42,   42,   52, 12, 52,  0 }, {     42,   42,   53, 12, 52,  0 }, {     43,   43,   54, 12, 52,  0 },
    {     43,   43,   55, 12, 52,  0 }, {     44,   44,   56, 12, 52,  0 }, {     44,   44,   57, 12, 52,  0 }, {     45,   45,   58, 12, 52,  0 }, {     45,   45,   59, 12, 52,  0 },
    {     46,   46,   60, 12, 52,  0 }, {     46,   46,   61, 12, 52,  0 }, {     47,   47,   62, 12, 52,  0 }, {     47,   47,   63, 12, 52,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_917502, {
    {     16,   15,    0, 20, 52,  0 }, {     16,   15,    1, 20, 52,  0 }, {     17,   14,    2, 20, 52,  0 }, {     17,   14,    3, 20, 52,  0 }, {     18,   13,    4, 20, 52,  0 },
    {     18,   13,    5, 20, 52,  0 }, {     19,   12,    6, 20, 52,  0 }, {     19,   12,    7, 20, 52,  0 }, {     20,   11,    8, 20, 52,  0 }, {     20,   11,    9, 20, 52,  0 },
    {     21,   10,   10, 20, 52,  0 }, {     21,   10,   11, 20, 52,  0 }, {     22,    9,   12, 20, 52,  0 }, {     22,    9,   13, 20, 52,  0 }, {     23,    8,   14, 20, 52,  0 },
    {     23,    8,   15, 20, 52,  0 }, {     24,    7,   16, 20, 52,  0 }, {     24,    7,   17, 20, 52,  0 }, {     25,    6,   18, 20, 52,  0 }, {     25,    6,   19, 20, 52,  0 },
    {     26,    5,   20, 20, 52,  0 }, {     26,    5,   21, 20, 52,  0 }, {     27,    4,   22, 20, 52,  0 }, {     27,    4,   23, 20, 52,  0 }, {     28,    3,   24, 20, 52,  0 },
    {     28,    3,   25, 20, 52,  0 }, {     29,    2,   26, 20, 52,  0 }, {     29,    2,   27, 20, 52,  0 }, {     30,    1,   28, 20, 52,  0 }, {     30,    1,   29, 20, 52,  0 },
    {     31,    0,   30, 20, 52,  0 }, {     31,    0,   31, 20, 52,  0 }, {     32,   -1,   32, 20, 52,  0 }, {     32,   -1,   33, 20, 52,  0 }, {     33,   -2,   34, 20, 52,  0 },
    {     33,   -2,   35, 20, 52,  0 }, {     34,   -3,   36, 20, 52,  0 }, {     34,   -3,   37, 20, 52,  0 }, {     35,   -4,   38, 20, 52,  0 }, {     35,   -4,   39, 20, 52,  0 },
    {     36,   -5,   40, 20, 52,  0 }, {     36,   -5,   41, 20, 52,  0 }, {     37,   -6,   42, 20, 52,  0 }, {     37,   -6,   43, 20, 52,  0 }, {     38,   -7,   44, 20, 52,  0 },
    {     38,   -7,   45, 20, 52,  0 }, {     39,   -8,   46, 20, 52,  0 }, {     39,   -8,   47, 20, 52,  0 }, {     40,   -9,   48, 20, 52,  0 }, {     40,   -9,   49, 20, 52,  0 },
    {     41,  -10,   50, 20, 52,  0 }, {     41,  -10,   51, 20, 52,  0 }, {     42,  -11,   52, 20, 52,  0 }, {     42,  -11,   53, 20, 52,  0 }, {     43,  -12,   54, 20, 52,  0 },
    {     43,  -12,   55, 20, 52,  0 }, {     44,  -13,   56, 20, 52,  0 }, {     44,  -13,   57, 20, 52,  0 }, {     45,  -14,   58, 20, 52,  0 }, {     45,  -14,   59, 20, 52,  0 },
    {     46,  -15,   60, 20, 52,  0 }, {     46,  -15,   61, 20, 52,  0 }, {     47,  -16,   62, 20, 52,  0 }, {     47,  -16,   63, 20, 52,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_917744, {
    {     15,   15,    0, 28, 52,  0 }, {     15,   15,    1, 28, 52,  0 }, {     14,   14,    2, 28, 52,  0 }, {     14,   14,    3, 28, 52,  0 }, {     13,   13,    4, 28, 52,  0 },
    {     13,   13,    5, 28, 52,  0 }, {     12,   12,    6, 28, 52,  0 }, {     12,   12,    7, 28, 52,  0 }, {     11,   11,    8, 28, 52,  0 }, {     11,   11,    9, 28, 52,  0 },
    {     10,   10,   10, 28, 52,  0 }, {     10,   10,   11, 28, 52,  0 }, {      9,    9,   12, 28, 52,  0 }, {      9,    9,   13, 28, 52,  0 }, {      8,    8,   14, 28, 52,  0 },
    {      8,    8,   15, 28, 52,  0 }, {      7,    7,   16, 28, 52,  0 }, {      7,    7,   17, 28, 52,  0 }, {      6,    6,   18, 28, 52,  0 }, {      6,    6,   19, 28, 52,  0 },
    {      5,    5,   20, 28, 52,  0 }, {      5,    5,   21, 28, 52,  0 }, {      4,    4,   22, 28, 52,  0 }, {      4,    4,   23, 28, 52,  0 }, {      3,    3,   24, 28, 52,  0 },
    {      3,    3,   25, 28, 52,  0 }, {      2,    2,   26, 28, 52,  0 }, {      2,    2,   27, 28, 52,  0 }, {      1,    1,   28, 28, 52,  0 }, {      1,    1,   29, 28, 52,  0 },
    {      0,    0,   30, 28, 52,  0 }, {      0,    0,   31, 28, 52,  0 }, {     -1,   -1,   32, 28, 52,  0 }, {     -1,   -1,   33, 28, 52,  0 }, {     -2,   -2,   34, 28, 52,  0 },
    {     -2,   -2,   35, 28, 52,  0 }, {     -3,   -3,   36, 28, 52,  0 }, {     -3,   -3,   37, 28, 52,  0 }, {     -4,   -4,   38, 28, 52,  0 }, {     -4,   -4,   39, 28, 52,  0 },
    {     -5,   -5,   40, 28, 52,  0 }, {     -5,   -5,   41, 28, 52,  0 }, {     -6,   -6,   42, 28, 52,  0 }, {     -6,   -6,   43, 28, 52,  0 }, {     -7,   -7,   44, 28, 52,  0 },
    {     -7,   -7,   45, 28, 52,  0 }, {     -8,   -8,   46, 28, 52,  0 }, {     -8,   -8,   47, 28, 52,  0 }, {     -9,   -9,   48, 28, 52,  0 }, {     -9,   -9,   49, 28, 52,  0 },
    {    -10,  -10,   50, 28, 52,  0 }, {    -10,  -10,   51, 28, 52,  0 }, {    -11,  -11,   52, 28, 52,  0 }, {    -11,  -11,   53, 28, 52,  0 }, {    -12,  -12,   54, 28, 52,  0 },
    {    -12,  -12,   55, 28, 52,  0 }, {    -13,  -13,   56, 28, 52,  0 }, {    -13,  -13,   57, 28, 52,  0 }, {    -14,  -14,   58, 28, 52,  0 }, {    -14,  -14,   59, 28, 52,  0 },
    {    -15,  -15,   60, 28, 52,  0 }, {    -15,  -15,   61, 28, 52,  0 }, {    -16,  -16,   62, 28, 52,  0 }, {    -16,  -16,   63, 28, 52,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91828E, {
    {     15,   16,    0,  4,  0,  0 }, {     14,   17,    0,  4,  0,  0 }, {     13,   18,    0,  4,  0,  0 }, {     12,   19,    0,  4,  0,  0 }, {     11,   20,    0,  4,  0,  0 },
    {     10,   21,    0,  4,  0,  0 }, {      9,   22,    0,  4,  0,  0 }, {      8,   23,    0,  4,  0,  0 }, {      7,   24,    0,  4, 50,  0 }, {      6,   25,    0,  4, 50,  0 },
    {      5,   26,    1,  4, 50,  0 }, {      4,   27,    1,  4, 50,  0 }, {      3,   28,    1,  4, 50,  0 }, {      2,   29,    1,  4, 50,  0 }, {      1,   30,    1,  4, 50,  0 },
    {      0,   31,    1,  4, 50,  0 }, {     -1,   32,    2,  4, 50,  0 }, {     -2,   33,    2,  4, 50,  0 }, {     -3,   34,    2,  4, 50,  0 }, {     -4,   35,    2,  4, 50,  0 },
    {     -5,   36,    3,  4, 50,  0 }, {     -6,   37,    3,  4, 50,  0 }, {     -7,   38,    3,  4, 50,  0 }, {     -8,   39,    4,  4, 50,  0 }, {     -9,   40,    4,  4, 51,  0 },
    {    -10,   41,    5,  4, 51,  0 }, {    -11,   42,    5,  4, 51,  0 }, {    -12,   43,    6,  4, 51,  0 }, {    -13,   44,    6,  4, 51,  0 }, {    -14,   45,    7,  4, 51,  0 },
    {    -15,   46,    7,  4, 51,  0 }, {    -16,   47,    8,  4, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9183B0, {
    {     16,   16,    0, 12,  0,  0 }, {     17,   17,    0, 12,  0,  0 }, {     18,   18,    0, 12,  0,  0 }, {     19,   19,    0, 12,  0,  0 }, {     20,   20,    0, 12,  0,  0 },
    {     21,   21,    0, 12,  0,  0 }, {     22,   22,    0, 12,  0,  0 }, {     23,   23,    0, 12,  0,  0 }, {     24,   24,    0, 12, 50,  0 }, {     25,   25,    0, 12, 50,  0 },
    {     26,   26,    1, 12, 50,  0 }, {     27,   27,    1, 12, 50,  0 }, {     28,   28,    1, 12, 50,  0 }, {     29,   29,    1, 12, 50,  0 }, {     30,   30,    1, 12, 50,  0 },
    {     31,   31,    1, 12, 50,  0 }, {     32,   32,    2, 12, 50,  0 }, {     33,   33,    2, 12, 50,  0 }, {     34,   34,    2, 12, 50,  0 }, {     35,   35,    2, 12, 50,  0 },
    {     36,   36,    3, 12, 50,  0 }, {     37,   37,    3, 12, 50,  0 }, {     38,   38,    3, 12, 50,  0 }, {     39,   39,    4, 12, 50,  0 }, {     40,   40,    4, 12, 51,  0 },
    {     41,   41,    4, 12, 51,  0 }, {     42,   42,    5, 12, 51,  0 }, {     43,   43,    5, 12, 51,  0 }, {     44,   44,    6, 12, 51,  0 }, {     45,   45,    6, 12, 51,  0 },
    {     46,   46,    7, 12, 51,  0 }, {     47,   47,    7, 12, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9184D2, {
    {     16,   15,    0, 20,  0,  0 }, {     17,   14,    0, 20,  0,  0 }, {     18,   13,    0, 20,  0,  0 }, {     19,   12,    0, 20,  0,  0 }, {     20,   11,    0, 20,  0,  0 },
    {     21,   10,    0, 20,  0,  0 }, {     22,    9,    0, 20,  0,  0 }, {     23,    8,    0, 20,  0,  0 }, {     24,    7,    0, 20, 50,  0 }, {     25,    6,    0, 20, 50,  0 },
    {     26,    5,    1, 20, 50,  0 }, {     27,    4,    1, 20, 50,  0 }, {     28,    3,    1, 20, 50,  0 }, {     29,    2,    1, 20, 50,  0 }, {     30,    1,    1, 20, 50,  0 },
    {     31,    0,    1, 20, 50,  0 }, {     32,   -1,    2, 20, 50,  0 }, {     33,   -2,    2, 20, 50,  0 }, {     34,   -3,    2, 20, 50,  0 }, {     35,   -4,    2, 20, 50,  0 },
    {     36,   -5,    3, 20, 50,  0 }, {     37,   -6,    3, 20, 50,  0 }, {     38,   -7,    3, 20, 50,  0 }, {     39,   -8,    4, 20, 50,  0 }, {     40,   -9,    4, 20, 51,  0 },
    {     41,  -10,    4, 20, 51,  0 }, {     42,  -11,    5, 20, 51,  0 }, {     43,  -12,    5, 20, 51,  0 }, {     44,  -13,    6, 20, 51,  0 }, {     45,  -14,    6, 20, 51,  0 },
    {     46,  -15,    7, 20, 51,  0 }, {     47,  -16,    7, 20, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9185F4, {
    {     15,   15,    0, 28,  0,  0 }, {     14,   14,    0, 28,  0,  0 }, {     13,   13,    0, 28,  0,  0 }, {     12,   12,    0, 28,  0,  0 }, {     11,   11,    0, 28,  0,  0 },
    {     10,   10,    0, 28,  0,  0 }, {      9,    9,    0, 28,  0,  0 }, {      8,    8,    0, 28,  0,  0 }, {      7,    7,    0, 28, 50,  0 }, {      6,    6,    0, 28, 50,  0 },
    {      5,    5,    1, 28, 50,  0 }, {      4,    4,    1, 28, 50,  0 }, {      3,    3,    1, 28, 50,  0 }, {      2,    2,    1, 28, 50,  0 }, {      1,    1,    1, 28, 50,  0 },
    {      0,    0,    1, 28, 50,  0 }, {     -1,   -1,    2, 28, 50,  0 }, {     -2,   -2,    2, 28, 50,  0 }, {     -3,   -3,    2, 28, 50,  0 }, {     -4,   -4,    2, 28, 50,  0 },
    {     -5,   -5,    3, 28, 50,  0 }, {     -6,   -6,    3, 28, 50,  0 }, {     -7,   -7,    3, 28, 50,  0 }, {     -8,   -8,    4, 28, 50,  0 }, {     -9,   -9,    4, 28, 51,  0 },
    {    -10,  -10,    5, 28, 51,  0 }, {    -11,  -11,    5, 28, 51,  0 }, {    -12,  -12,    6, 28, 51,  0 }, {    -13,  -13,    6, 28, 51,  0 }, {    -14,  -14,    7, 28, 51,  0 },
    {    -15,  -15,    7, 28, 51,  0 }, {    -16,  -16,    8, 28, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9194F6, {
    {     15,   16,    0,  4, 51,  0 }, {     14,   17,    0,  4, 51,  0 }, {     13,   18,    1,  4, 51,  0 }, {     12,   19,    1,  4, 51,  0 }, {     11,   20,    2,  4,  2,  0 },
    {     10,   21,    3,  4,  2,  0 }, {      9,   22,    3,  4,  2,  0 }, {      8,   23,    4,  4,  2,  0 }, {      7,   24,    5,  4,  2,  0 }, {      6,   25,    5,  4,  2,  0 },
    {      5,   26,    6,  4,  2,  0 }, {      4,   27,    7,  4,  2,  0 }, {      3,   28,    8,  4,  2,  0 }, {      2,   29,    8,  4,  2,  0 }, {      1,   30,    9,  4,  2,  0 },
    {      0,   31,   10,  4,  2,  0 }, {     -1,   32,   11,  4,  2,  0 }, {     -2,   33,   12,  4,  2,  0 }, {     -3,   34,   13,  4,  3,  0 }, {     -4,   35,   14,  4,  3,  0 },
    {     -5,   36,   15,  4,  3,  0 }, {     -6,   37,   16,  4,  3,  0 }, {     -7,   38,   17,  4,  3,  0 }, {     -8,   39,   18,  4,  3,  0 }, {     -8,   39,   19,  4,  3,  0 },
    {     -9,   40,   20,  4,  3,  0 }, {    -10,   41,   21,  4,  3,  0 }, {    -11,   42,   22,  4,  3,  0 }, {    -11,   42,   23,  4,  3,  0 }, {    -12,   43,   24,  4,  3,  0 },
    {    -13,   44,   25,  4,  3,  0 }, {    -13,   44,   26,  4,  3,  0 }, {    -14,   45,   27,  4,  3,  0 }, {    -15,   46,   28,  4, 52,  0 }, {    -15,   46,   29,  4, 52,  0 },
    {    -16,   47,   30,  4, 52,  0 }, {    -16,   47,   31,  4, 52,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_919645, {
    {     16,   16,    0, 12, 51,  0 }, {     17,   17,    0, 12, 51,  0 }, {     18,   18,    1, 12, 51,  0 }, {     19,   19,    1, 12, 51,  0 }, {     20,   20,    2, 12,  2,  0 },
    {     21,   21,    3, 12,  2,  0 }, {     22,   22,    3, 12,  2,  0 }, {     23,   23,    4, 12,  2,  0 }, {     24,   24,    5, 12,  2,  0 }, {     25,   25,    5, 12,  2,  0 },
    {     26,   26,    6, 12,  2,  0 }, {     27,   27,    7, 12,  2,  0 }, {     28,   28,    8, 12,  2,  0 }, {     29,   29,    8, 12,  2,  0 }, {     30,   30,    9, 12,  2,  0 },
    {     31,   31,   10, 12,  2,  0 }, {     32,   32,   11, 12,  2,  0 }, {     33,   33,   12, 12,  2,  0 }, {     34,   34,   13, 12,  3,  0 }, {     35,   35,   14, 12,  3,  0 },
    {     36,   36,   15, 12,  3,  0 }, {     37,   37,   16, 12,  3,  0 }, {     38,   38,   17, 12,  3,  0 }, {     39,   39,   18, 12,  3,  0 }, {     39,   39,   19, 12,  3,  0 },
    {     40,   40,   20, 12,  3,  0 }, {     41,   41,   21, 12,  3,  0 }, {     42,   42,   22, 12,  3,  0 }, {     42,   42,   23, 12,  3,  0 }, {     43,   43,   24, 12,  3,  0 },
    {     44,   44,   25, 12,  3,  0 }, {     44,   44,   26, 12,  3,  0 }, {     45,   45,   27, 12,  3,  0 }, {     46,   46,   28, 12, 52,  0 }, {     46,   46,   29, 12, 52,  0 },
    {     47,   47,   30, 12, 52,  0 }, {     47,   47,   31, 12, 52,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_919794, {
    {     16,   15,    0, 20, 51,  0 }, {     17,   14,    0, 20, 51,  0 }, {     18,   13,    1, 20, 51,  0 }, {     19,   12,    1, 20, 51,  0 }, {     20,   11,    2, 20,  2,  0 },
    {     21,   10,    3, 20,  2,  0 }, {     22,    9,    3, 20,  2,  0 }, {     23,    8,    4, 20,  2,  0 }, {     24,    7,    5, 20,  2,  0 }, {     25,    6,    5, 20,  2,  0 },
    {     26,    5,    6, 20,  2,  0 }, {     27,    4,    7, 20,  2,  0 }, {     28,    3,    8, 20,  2,  0 }, {     29,    2,    8, 20,  2,  0 }, {     30,    1,    9, 20,  2,  0 },
    {     31,    0,   10, 20,  2,  0 }, {     32,   -1,   11, 20,  2,  0 }, {     33,   -2,   12, 20,  2,  0 }, {     34,   -3,   13, 20,  3,  0 }, {     35,   -4,   14, 20,  3,  0 },
    {     36,   -5,   15, 20,  3,  0 }, {     37,   -6,   16, 20,  3,  0 }, {     38,   -7,   17, 20,  3,  0 }, {     39,   -8,   18, 20,  3,  0 }, {     39,   -8,   19, 20,  3,  0 },
    {     40,   -9,   20, 20,  3,  0 }, {     41,  -10,   21, 20,  3,  0 }, {     42,  -11,   22, 20,  3,  0 }, {     42,  -11,   23, 20,  3,  0 }, {     43,  -12,   24, 20,  3,  0 },
    {     44,  -13,   25, 20,  3,  0 }, {     44,  -13,   26, 20,  3,  0 }, {     45,  -14,   27, 20,  3,  0 }, {     46,  -15,   28, 20, 52,  0 }, {     46,  -15,   29, 20, 52,  0 },
    {     47,  -16,   30, 20, 52,  0 }, {     47,  -16,   31, 20, 52,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9198E3, {
    {     15,   15,    0, 28, 51,  0 }, {     14,   14,    0, 28, 51,  0 }, {     13,   13,    1, 28, 51,  0 }, {     12,   12,    1, 28, 51,  0 }, {     11,   11,    2, 28,  2,  0 },
    {     10,   10,    3, 28,  2,  0 }, {      9,    9,    3, 28,  2,  0 }, {      8,    8,    4, 28,  2,  0 }, {      7,    7,    5, 28,  2,  0 }, {      6,    6,    5, 28,  2,  0 },
    {      5,    5,    6, 28,  2,  0 }, {      4,    4,    7, 28,  2,  0 }, {      3,    3,    8, 28,  2,  0 }, {      2,    2,    8, 28,  2,  0 }, {      1,    1,    9, 28,  2,  0 },
    {      0,    0,   10, 28,  2,  0 }, {     -1,   -1,   11, 28,  2,  0 }, {     -2,   -2,   12, 28,  2,  0 }, {     -3,   -3,   13, 28,  3,  0 }, {     -4,   -4,   14, 28,  3,  0 },
    {     -5,   -5,   15, 28,  3,  0 }, {     -6,   -6,   16, 28,  3,  0 }, {     -7,   -7,   17, 28,  3,  0 }, {     -8,   -8,   18, 28,  3,  0 }, {     -8,   -8,   19, 28,  3,  0 },
    {     -9,   -9,   20, 28,  3,  0 }, {    -10,  -10,   21, 28,  3,  0 }, {    -11,  -11,   22, 28,  3,  0 }, {    -11,  -11,   23, 28,  3,  0 }, {    -12,  -12,   24, 28,  3,  0 },
    {    -13,  -13,   25, 28,  3,  0 }, {    -13,  -13,   26, 28,  3,  0 }, {    -14,  -14,   27, 28,  3,  0 }, {    -15,  -15,   28, 28, 52,  0 }, {    -15,  -15,   29, 28, 52,  0 },
    {    -16,  -16,   30, 28, 52,  0 }, {    -16,  -16,   31, 28, 52,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_919A32, {
    {     15,   16,    0,  4, 52,  0 }, {     15,   16,    1,  4,  3,  0 }, {     14,   17,    2,  4,  3,  0 }, {     14,   17,    3,  4,  3,  0 }, {     13,   18,    4,  4,  3,  0 },
    {     12,   19,    5,  4,  3,  0 }, {     12,   19,    6,  4,  3,  0 }, {     11,   20,    7,  4,  3,  0 }, {     10,   21,    8,  4,  3,  0 }, {     10,   21,    9,  4,  3,  0 },
    {      9,   22,   10,  4,  3,  0 }, {      8,   23,   11,  4,  3,  0 }, {      7,   24,   12,  4,  3,  0 }, {      7,   24,   13,  4,  3,  0 }, {      6,   25,   14,  4,  3,  0 },
    {      5,   26,   15,  4,  3,  0 }, {      4,   27,   16,  4,  2,  0 }, {      3,   28,   17,  4,  2,  0 }, {      2,   29,   18,  4,  2,  0 }, {      1,   30,   19,  4,  2,  0 },
    {      0,   31,   20,  4,  2,  0 }, {     -1,   32,   21,  4,  2,  0 }, {     -2,   33,   22,  4,  2,  0 }, {     -3,   34,   23,  4,  2,  0 }, {     -4,   35,   23,  4,  2,  0 },
    {     -5,   36,   24,  4,  2,  0 }, {     -6,   37,   25,  4,  2,  0 }, {     -7,   38,   26,  4,  2,  0 }, {     -8,   39,   26,  4,  2,  0 }, {     -9,   40,   27,  4,  2,  0 },
    {    -10,   41,   28,  4,  2,  0 }, {    -11,   42,   28,  4,  2,  0 }, {    -12,   43,   29,  4,  2,  0 }, {    -13,   44,   30,  4, 51,  0 }, {    -14,   45,   30,  4, 51,  0 },
    {    -15,   46,   31,  4, 51,  0 }, {    -16,   47,   31,  4, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_919B81, {
    {     16,   16,    0, 12, 52,  0 }, {     16,   16,    1, 12,  3,  0 }, {     17,   17,    2, 12,  3,  0 }, {     17,   17,    3, 12,  3,  0 }, {     18,   18,    4, 12,  3,  0 },
    {     19,   19,    5, 12,  3,  0 }, {     19,   19,    6, 12,  3,  0 }, {     20,   20,    7, 12,  3,  0 }, {     21,   21,    8, 12,  3,  0 }, {     21,   21,    9, 12,  3,  0 },
    {     22,   22,   10, 12,  3,  0 }, {     23,   23,   11, 12,  3,  0 }, {     24,   24,   12, 12,  3,  0 }, {     24,   24,   13, 12,  3,  0 }, {     25,   25,   14, 12,  3,  0 },
    {     26,   26,   15, 12,  3,  0 }, {     27,   27,   16, 12,  2,  0 }, {     28,   28,   17, 12,  2,  0 }, {     29,   29,   18, 12,  2,  0 }, {     30,   30,   19, 12,  2,  0 },
    {     31,   31,   20, 12,  2,  0 }, {     32,   32,   21, 12,  2,  0 }, {     33,   33,   22, 12,  2,  0 }, {     34,   34,   23, 12,  2,  0 }, {     35,   35,   23, 12,  2,  0 },
    {     36,   36,   24, 12,  2,  0 }, {     37,   37,   25, 12,  2,  0 }, {     38,   38,   26, 12,  2,  0 }, {     39,   39,   26, 12,  2,  0 }, {     40,   40,   27, 12,  2,  0 },
    {     41,   41,   28, 12,  2,  0 }, {     42,   42,   28, 12,  2,  0 }, {     43,   43,   29, 12,  2,  0 }, {     44,   44,   30, 12, 51,  0 }, {     45,   45,   30, 12, 51,  0 },
    {     46,   46,   31, 12, 51,  0 }, {     47,   47,   31, 12, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_919CD0, {
    {     16,   15,    0, 20, 52,  0 }, {     16,   15,    1, 20,  3,  0 }, {     17,   14,    2, 20,  3,  0 }, {     17,   14,    3, 20,  3,  0 }, {     18,   13,    4, 20,  3,  0 },
    {     19,   12,    5, 20,  3,  0 }, {     19,   12,    6, 20,  3,  0 }, {     20,   11,    7, 20,  3,  0 }, {     21,   10,    8, 20,  3,  0 }, {     21,   10,    9, 20,  3,  0 },
    {     22,    9,   10, 20,  3,  0 }, {     23,    8,   11, 20,  3,  0 }, {     24,    7,   12, 20,  3,  0 }, {     24,    7,   13, 20,  3,  0 }, {     25,    6,   14, 20,  3,  0 },
    {     26,    5,   15, 20,  3,  0 }, {     27,    4,   16, 20,  2,  0 }, {     28,    3,   17, 20,  2,  0 }, {     29,    2,   18, 20,  2,  0 }, {     30,    1,   19, 20,  2,  0 },
    {     31,    0,   20, 20,  2,  0 }, {     32,   -1,   21, 20,  2,  0 }, {     33,   -2,   22, 20,  2,  0 }, {     34,   -3,   23, 20,  2,  0 }, {     35,   -4,   23, 20,  2,  0 },
    {     36,   -5,   24, 20,  2,  0 }, {     37,   -6,   25, 20,  2,  0 }, {     38,   -7,   26, 20,  2,  0 }, {     39,   -8,   26, 20,  2,  0 }, {     40,   -9,   27, 20,  2,  0 },
    {     41,  -10,   28, 20,  2,  0 }, {     42,  -11,   28, 20,  2,  0 }, {     43,  -12,   29, 20,  2,  0 }, {     44,  -13,   30, 20, 51,  0 }, {     45,  -14,   30, 20, 51,  0 },
    {     46,  -15,   31, 20, 51,  0 }, {     47,  -16,   31, 20, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_919E1F, {
    {     15,   15,    0, 28, 52,  0 }, {     15,   15,    1, 28,  3,  0 }, {     14,   14,    2, 28,  3,  0 }, {     14,   14,    3, 28,  3,  0 }, {     13,   13,    4, 28,  3,  0 },
    {     12,   12,    5, 28,  3,  0 }, {     12,   12,    6, 28,  3,  0 }, {     11,   11,    7, 28,  3,  0 }, {     10,   10,    8, 28,  3,  0 }, {     10,   10,    9, 28,  3,  0 },
    {      9,    9,   10, 28,  3,  0 }, {      8,    8,   11, 28,  3,  0 }, {      7,    7,   12, 28,  3,  0 }, {      7,    7,   13, 28,  3,  0 }, {      6,    6,   14, 28,  3,  0 },
    {      5,    5,   15, 28,  3,  0 }, {      4,    4,   16, 28,  2,  0 }, {      3,    3,   17, 28,  2,  0 }, {      2,    2,   18, 28,  2,  0 }, {      1,    1,   19, 28,  2,  0 },
    {      0,    0,   20, 28,  2,  0 }, {     -1,   -1,   21, 28,  2,  0 }, {     -2,   -2,   22, 28,  2,  0 }, {     -3,   -3,   23, 28,  2,  0 }, {     -4,   -4,   23, 28,  2,  0 },
    {     -5,   -5,   24, 28,  2,  0 }, {     -6,   -6,   25, 28,  2,  0 }, {     -7,   -7,   26, 28,  2,  0 }, {     -8,   -8,   26, 28,  2,  0 }, {     -9,   -9,   27, 28,  2,  0 },
    {    -10,  -10,   28, 28,  2,  0 }, {    -11,  -11,   28, 28,  2,  0 }, {    -12,  -12,   29, 28,  2,  0 }, {    -13,  -13,   30, 28, 51,  0 }, {    -14,  -14,   30, 28, 51,  0 },
    {    -15,  -15,   31, 28, 51,  0 }, {    -16,  -16,   31, 28, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_918716, {
    {     15,   16,    0,  4, 51,  0 }, {     14,   17,    1,  4, 51,  0 }, {     13,   18,    1,  4, 51,  0 }, {     12,   19,    2,  4, 51,  0 }, {     11,   20,    2,  4, 51,  0 },
    {     10,   21,    3,  4, 51,  0 }, {      9,   22,    3,  4, 51,  0 }, {      8,   23,    3,  4, 51,  0 }, {      7,   24,    4,  4, 50,  0 }, {      6,   25,    4,  4, 50,  0 },
    {      5,   26,    4,  4, 50,  0 }, {      4,   27,    5,  4, 50,  0 }, {      3,   28,    5,  4, 50,  0 }, {      2,   29,    5,  4, 50,  0 }, {      1,   30,    6,  4, 50,  0 },
    {      0,   31,    6,  4, 50,  0 }, {     -1,   32,    6,  4, 50,  0 }, {     -2,   33,    6,  4, 50,  0 }, {     -3,   34,    7,  4, 50,  0 }, {     -4,   35,    7,  4, 50,  0 },
    {     -5,   36,    7,  4, 50,  0 }, {     -6,   37,    7,  4, 50,  0 }, {     -7,   38,    7,  4,  0,  0 }, {     -8,   39,    7,  4,  0,  0 }, {     -9,   40,    8,  4,  0,  0 },
    {    -10,   41,    8,  4,  0,  0 }, {    -11,   42,    8,  4,  0,  0 }, {    -12,   43,    8,  4,  0,  0 }, {    -13,   44,    8,  4,  0,  0 }, {    -14,   45,    8,  4,  0,  0 },
    {    -15,   46,    8,  4,  0,  0 }, {    -16,   47,    8,  4,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91884A, {
    {     16,   16,    0, 12, 51,  0 }, {     17,   17,    0, 12, 51,  0 }, {     18,   18,    1, 12, 51,  0 }, {     19,   19,    1, 12, 51,  0 }, {     20,   20,    2, 12, 51,  0 },
    {     21,   21,    2, 12, 51,  0 }, {     22,   22,    3, 12, 51,  0 }, {     23,   23,    3, 12, 51,  0 }, {     24,   24,    4, 12, 50,  0 }, {     25,   25,    4, 12, 50,  0 },
    {     26,   26,    4, 12, 50,  0 }, {     27,   27,    5, 12, 50,  0 }, {     28,   28,    5, 12, 50,  0 }, {     29,   29,    5, 12, 50,  0 }, {     30,   30,    6, 12, 50,  0 },
    {     31,   31,    6, 12, 50,  0 }, {     32,   32,    6, 12, 50,  0 }, {     33,   33,    6, 12, 50,  0 }, {     34,   34,    7, 12, 50,  0 }, {     35,   35,    7, 12, 50,  0 },
    {     36,   36,    7, 12, 50,  0 }, {     37,   37,    7, 12, 50,  0 }, {     38,   38,    7, 12,  0,  0 }, {     39,   39,    7, 12,  0,  0 }, {     40,   40,    8, 12,  0,  0 },
    {     41,   41,    8, 12,  0,  0 }, {     42,   42,    8, 12,  0,  0 }, {     43,   43,    8, 12,  0,  0 }, {     44,   44,    8, 12,  0,  0 }, {     45,   45,    8, 12,  0,  0 },
    {     46,   46,    8, 12,  0,  0 }, {     47,   47,    8, 12,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91897E, {
    {     16,   15,    0, 20, 51,  0 }, {     17,   14,    0, 20, 51,  0 }, {     18,   13,    1, 20, 51,  0 }, {     19,   12,    1, 20, 51,  0 }, {     20,   11,    2, 20, 51,  0 },
    {     21,   10,    2, 20, 51,  0 }, {     22,    9,    3, 20, 51,  0 }, {     23,    8,    3, 20, 51,  0 }, {     24,    7,    4, 20, 50,  0 }, {     25,    6,    4, 20, 50,  0 },
    {     26,    5,    4, 20, 50,  0 }, {     27,    4,    5, 20, 50,  0 }, {     28,    3,    5, 20, 50,  0 }, {     29,    2,    5, 20, 50,  0 }, {     30,    1,    6, 20, 50,  0 },
    {     31,    0,    6, 20, 50,  0 }, {     32,   -1,    6, 20, 50,  0 }, {     33,   -2,    6, 20, 50,  0 }, {     34,   -3,    7, 20, 50,  0 }, {     35,   -4,    7, 20, 50,  0 },
    {     36,   -5,    7, 20, 50,  0 }, {     37,   -6,    7, 20, 50,  0 }, {     38,   -7,    7, 20,  0,  0 }, {     39,   -8,    7, 20,  0,  0 }, {     40,   -9,    8, 20,  0,  0 },
    {     41,  -10,    8, 20,  0,  0 }, {     42,  -11,    8, 20,  0,  0 }, {     43,  -12,    8, 20,  0,  0 }, {     44,  -13,    8, 20,  0,  0 }, {     45,  -14,    8, 20,  0,  0 },
    {     46,  -15,    8, 20,  0,  0 }, {     47,  -16,    8, 20,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_918AB2, {
    {     15,   15,    0, 28, 51,  0 }, {     14,   14,    1, 28, 51,  0 }, {     13,   13,    1, 28, 51,  0 }, {     12,   12,    2, 28, 51,  0 }, {     11,   11,    2, 28, 51,  0 },
    {     10,   10,    3, 28, 51,  0 }, {      9,    9,    3, 28, 51,  0 }, {      8,    8,    3, 28, 51,  0 }, {      7,    7,    4, 28, 50,  0 }, {      6,    6,    4, 28, 50,  0 },
    {      5,    5,    4, 28, 50,  0 }, {      4,    4,    5, 28, 50,  0 }, {      3,    3,    5, 28, 50,  0 }, {      2,    2,    5, 28, 50,  0 }, {      1,    1,    6, 28, 50,  0 },
    {      0,    0,    6, 28, 50,  0 }, {     -1,   -1,    6, 28, 50,  0 }, {     -2,   -2,    6, 28, 50,  0 }, {     -3,   -3,    7, 28, 50,  0 }, {     -4,   -4,    7, 28, 50,  0 },
    {     -5,   -5,    7, 28, 50,  0 }, {     -6,   -6,    7, 28, 50,  0 }, {     -7,   -7,    7, 28,  0,  0 }, {     -8,   -8,    7, 28,  0,  0 }, {     -9,   -9,    8, 28,  0,  0 },
    {    -10,  -10,    8, 28,  0,  0 }, {    -11,  -11,    8, 28,  0,  0 }, {    -12,  -12,    8, 28,  0,  0 }, {    -13,  -13,    8, 28,  0,  0 }, {    -14,  -14,    8, 28,  0,  0 },
    {    -15,  -15,    8, 28,  0,  0 }, {    -16,  -16,    8, 28,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_916BF6, {
    {     15,   16,   15,  4, 54,  0 }, {     14,   17,   15,  4, 54,  0 }, {     13,   18,   14,  4, 54,  0 }, {     12,   19,   14,  4, 54,  0 }, {     11,   20,   13,  4, 54,  0 },
    {     10,   21,   13,  4, 54,  0 }, {      9,   22,   12,  4, 54,  0 }, {      8,   23,   12,  4, 54,  0 }, {      7,   24,   11,  4, 54,  0 }, {      6,   25,   11,  4, 54,  0 },
    {      5,   26,   10,  4, 54,  0 }, {      4,   27,   10,  4, 54,  0 }, {      3,   28,    9,  4, 54,  0 }, {      2,   29,    9,  4, 54,  0 }, {      1,   30,    8,  4, 54,  0 },
    {      0,   31,    8,  4, 54,  0 }, {     -1,   32,    7,  4, 54,  0 }, {     -2,   33,    7,  4, 54,  0 }, {     -3,   34,    6,  4, 54,  0 }, {     -4,   35,    6,  4, 54,  0 },
    {     -5,   36,    5,  4, 54,  0 }, {     -6,   37,    5,  4, 54,  0 }, {     -7,   38,    4,  4, 54,  0 }, {     -8,   39,    4,  4, 54,  0 }, {     -9,   40,    3,  4, 54,  0 },
    {    -10,   41,    3,  4, 54,  0 }, {    -11,   42,    2,  4, 54,  0 }, {    -12,   43,    2,  4, 54,  0 }, {    -13,   44,    1,  4, 54,  0 }, {    -14,   45,    1,  4, 54,  0 },
    {    -15,   46,    0,  4, 54,  0 }, {    -16,   47,    0,  4, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_916D18, {
    {     16,   16,   15, 12, 54,  0 }, {     17,   17,   14, 12, 54,  0 }, {     18,   18,   14, 12, 54,  0 }, {     19,   19,   13, 12, 54,  0 }, {     20,   20,   13, 12, 54,  0 },
    {     21,   21,   12, 12, 54,  0 }, {     22,   22,   12, 12, 54,  0 }, {     23,   23,   11, 12, 54,  0 }, {     24,   24,   11, 12, 54,  0 }, {     25,   25,   10, 12, 54,  0 },
    {     26,   26,   10, 12, 54,  0 }, {     27,   27,    9, 12, 54,  0 }, {     28,   28,    9, 12, 54,  0 }, {     29,   29,    8, 12, 54,  0 }, {     30,   30,    8, 12, 54,  0 },
    {     31,   31,    7, 12, 54,  0 }, {     32,   32,    7, 12, 54,  0 }, {     33,   33,    6, 12, 54,  0 }, {     34,   34,    6, 12, 54,  0 }, {     35,   35,    5, 12, 54,  0 },
    {     36,   36,    5, 12, 54,  0 }, {     37,   37,    4, 12, 54,  0 }, {     38,   38,    4, 12, 54,  0 }, {     39,   39,    3, 12, 54,  0 }, {     40,   40,    3, 12, 54,  0 },
    {     41,   41,    2, 12, 54,  0 }, {     42,   42,    2, 12, 54,  0 }, {     43,   43,    1, 12, 54,  0 }, {     44,   44,    1, 12, 54,  0 }, {     45,   45,    0, 12, 54,  0 },
    {     46,   46,    0, 12, 54,  0 }, {     47,   47,   -1, 12, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_916E3A, {
    {     16,   15,   15, 20, 54,  0 }, {     17,   14,   14, 20, 54,  0 }, {     18,   13,   14, 20, 54,  0 }, {     19,   12,   13, 20, 54,  0 }, {     20,   11,   13, 20, 54,  0 },
    {     21,   10,   12, 20, 54,  0 }, {     22,    9,   12, 20, 54,  0 }, {     23,    8,   11, 20, 54,  0 }, {     24,    7,   11, 20, 54,  0 }, {     25,    6,   10, 20, 54,  0 },
    {     26,    5,   10, 20, 54,  0 }, {     27,    4,    9, 20, 54,  0 }, {     28,    3,    9, 20, 54,  0 }, {     29,    2,    8, 20, 54,  0 }, {     30,    1,    8, 20, 54,  0 },
    {     31,    0,    7, 20, 54,  0 }, {     32,   -1,    7, 20, 54,  0 }, {     33,   -2,    6, 20, 54,  0 }, {     34,   -3,    6, 20, 54,  0 }, {     35,   -4,    5, 20, 54,  0 },
    {     36,   -5,    5, 20, 54,  0 }, {     37,   -6,    4, 20, 54,  0 }, {     38,   -7,    4, 20, 54,  0 }, {     39,   -8,    3, 20, 54,  0 }, {     40,   -9,    3, 20, 54,  0 },
    {     41,  -10,    2, 20, 54,  0 }, {     42,  -11,    2, 20, 54,  0 }, {     43,  -12,    1, 20, 54,  0 }, {     44,  -13,    1, 20, 54,  0 }, {     45,  -14,    0, 20, 54,  0 },
    {     46,  -15,    0, 20, 54,  0 }, {     47,  -16,   -1, 20, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_916F5C, {
    {     15,   15,   15, 28, 54,  0 }, {     14,   14,   15, 28, 54,  0 }, {     13,   13,   14, 28, 54,  0 }, {     12,   12,   14, 28, 54,  0 }, {     11,   11,   13, 28, 54,  0 },
    {     10,   10,   13, 28, 54,  0 }, {      9,    9,   12, 28, 54,  0 }, {      8,    8,   12, 28, 54,  0 }, {      7,    7,   11, 28, 54,  0 }, {      6,    6,   11, 28, 54,  0 },
    {      5,    5,   10, 28, 54,  0 }, {      4,    4,   10, 28, 54,  0 }, {      3,    3,    9, 28, 54,  0 }, {      2,    2,    9, 28, 54,  0 }, {      1,    1,    8, 28, 54,  0 },
    {      0,    0,    8, 28, 54,  0 }, {     -1,   -1,    7, 28, 54,  0 }, {     -2,   -2,    7, 28, 54,  0 }, {     -3,   -3,    6, 28, 54,  0 }, {     -4,   -4,    6, 28, 54,  0 },
    {     -5,   -5,    5, 28, 54,  0 }, {     -6,   -6,    5, 28, 54,  0 }, {     -7,   -7,    4, 28, 54,  0 }, {     -8,   -8,    4, 28, 54,  0 }, {     -9,   -9,    3, 28, 54,  0 },
    {    -10,  -10,    3, 28, 54,  0 }, {    -11,  -11,    2, 28, 54,  0 }, {    -12,  -12,    2, 28, 54,  0 }, {    -13,  -13,    1, 28, 54,  0 }, {    -14,  -14,    1, 28, 54,  0 },
    {    -15,  -15,    0, 28, 54,  0 }, {    -16,  -16,    0, 28, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_917986, {
    {     15,   16,   63,  4, 55,  0 }, {     15,   16,   62,  4, 55,  0 }, {     14,   17,   61,  4, 55,  0 }, {     14,   17,   60,  4, 55,  0 }, {     13,   18,   59,  4, 55,  0 },
    {     13,   18,   58,  4, 55,  0 }, {     12,   19,   57,  4, 55,  0 }, {     12,   19,   56,  4, 55,  0 }, {     11,   20,   55,  4, 55,  0 }, {     11,   20,   54,  4, 55,  0 },
    {     10,   21,   53,  4, 55,  0 }, {     10,   21,   52,  4, 55,  0 }, {      9,   22,   51,  4, 55,  0 }, {      9,   22,   50,  4, 55,  0 }, {      8,   23,   49,  4, 55,  0 },
    {      8,   23,   48,  4, 55,  0 }, {      7,   24,   47,  4, 55,  0 }, {      7,   24,   46,  4, 55,  0 }, {      6,   25,   45,  4, 55,  0 }, {      6,   25,   44,  4, 55,  0 },
    {      5,   26,   43,  4, 55,  0 }, {      5,   26,   42,  4, 55,  0 }, {      4,   27,   41,  4, 55,  0 }, {      4,   27,   40,  4, 55,  0 }, {      3,   28,   39,  4, 55,  0 },
    {      3,   28,   38,  4, 55,  0 }, {      2,   29,   37,  4, 55,  0 }, {      2,   29,   36,  4, 55,  0 }, {      1,   30,   35,  4, 55,  0 }, {      1,   30,   34,  4, 55,  0 },
    {      0,   31,   33,  4, 55,  0 }, {      0,   31,   32,  4, 55,  0 }, {     -1,   32,   31,  4, 55,  0 }, {     -1,   32,   30,  4, 55,  0 }, {     -2,   33,   29,  4, 55,  0 },
    {     -2,   33,   28,  4, 55,  0 }, {     -3,   34,   27,  4, 55,  0 }, {     -3,   34,   26,  4, 55,  0 }, {     -4,   35,   25,  4, 55,  0 }, {     -4,   35,   24,  4, 55,  0 },
    {     -5,   36,   23,  4, 55,  0 }, {     -5,   36,   22,  4, 55,  0 }, {     -6,   37,   21,  4, 55,  0 }, {     -6,   37,   20,  4, 55,  0 }, {     -7,   38,   19,  4, 55,  0 },
    {     -7,   38,   18,  4, 55,  0 }, {     -8,   39,   17,  4, 55,  0 }, {     -8,   39,   16,  4, 55,  0 }, {     -9,   40,   15,  4, 55,  0 }, {     -9,   40,   14,  4, 55,  0 },
    {    -10,   41,   13,  4, 55,  0 }, {    -10,   41,   12,  4, 55,  0 }, {    -11,   42,   11,  4, 55,  0 }, {    -11,   42,   10,  4, 55,  0 }, {    -12,   43,    9,  4, 55,  0 },
    {    -12,   43,    8,  4, 55,  0 }, {    -13,   44,    7,  4, 55,  0 }, {    -13,   44,    6,  4, 55,  0 }, {    -14,   45,    5,  4, 55,  0 }, {    -14,   45,    4,  4, 55,  0 },
    {    -15,   46,    3,  4, 55,  0 }, {    -15,   46,    2,  4, 55,  0 }, {    -16,   47,    1,  4, 55,  0 }, {    -16,   47,    0,  4, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_917BC8, {
    {     16,   16,   63, 12, 55,  0 }, {     16,   16,   62, 12, 55,  0 }, {     17,   17,   61, 12, 55,  0 }, {     17,   17,   60, 12, 55,  0 }, {     18,   18,   59, 12, 55,  0 },
    {     18,   18,   58, 12, 55,  0 }, {     19,   19,   57, 12, 55,  0 }, {     19,   19,   56, 12, 55,  0 }, {     20,   20,   55, 12, 55,  0 }, {     20,   20,   54, 12, 55,  0 },
    {     21,   21,   53, 12, 55,  0 }, {     21,   21,   52, 12, 55,  0 }, {     22,   22,   51, 12, 55,  0 }, {     22,   22,   50, 12, 55,  0 }, {     23,   23,   49, 12, 55,  0 },
    {     23,   23,   48, 12, 55,  0 }, {     24,   24,   47, 12, 55,  0 }, {     24,   24,   46, 12, 55,  0 }, {     25,   25,   45, 12, 55,  0 }, {     25,   25,   44, 12, 55,  0 },
    {     26,   26,   43, 12, 55,  0 }, {     26,   26,   42, 12, 55,  0 }, {     27,   27,   41, 12, 55,  0 }, {     27,   27,   40, 12, 55,  0 }, {     28,   28,   39, 12, 55,  0 },
    {     28,   28,   38, 12, 55,  0 }, {     29,   29,   37, 12, 55,  0 }, {     29,   29,   36, 12, 55,  0 }, {     30,   30,   35, 12, 55,  0 }, {     30,   30,   34, 12, 55,  0 },
    {     31,   31,   33, 12, 55,  0 }, {     31,   31,   32, 12, 55,  0 }, {     32,   32,   31, 12, 55,  0 }, {     32,   32,   30, 12, 55,  0 }, {     33,   33,   29, 12, 55,  0 },
    {     33,   33,   28, 12, 55,  0 }, {     34,   34,   27, 12, 55,  0 }, {     34,   34,   26, 12, 55,  0 }, {     35,   35,   25, 12, 55,  0 }, {     35,   35,   24, 12, 55,  0 },
    {     36,   36,   23, 12, 55,  0 }, {     36,   36,   22, 12, 55,  0 }, {     37,   37,   21, 12, 55,  0 }, {     37,   37,   20, 12, 55,  0 }, {     38,   38,   19, 12, 55,  0 },
    {     38,   38,   18, 12, 55,  0 }, {     39,   39,   17, 12, 55,  0 }, {     39,   39,   16, 12, 55,  0 }, {     40,   40,   15, 12, 55,  0 }, {     40,   40,   14, 12, 55,  0 },
    {     41,   41,   13, 12, 55,  0 }, {     41,   41,   12, 12, 55,  0 }, {     42,   42,   11, 12, 55,  0 }, {     42,   42,   10, 12, 55,  0 }, {     43,   43,    9, 12, 55,  0 },
    {     43,   43,    8, 12, 55,  0 }, {     44,   44,    7, 12, 55,  0 }, {     44,   44,    6, 12, 55,  0 }, {     45,   45,    5, 12, 55,  0 }, {     45,   45,    4, 12, 55,  0 },
    {     46,   46,    3, 12, 55,  0 }, {     46,   46,    2, 12, 55,  0 }, {     47,   47,    1, 12, 55,  0 }, {     47,   47,    0, 12, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_917E0A, {
    {     16,   15,   63, 20, 55,  0 }, {     16,   15,   62, 20, 55,  0 }, {     17,   14,   61, 20, 55,  0 }, {     17,   14,   60, 20, 55,  0 }, {     18,   13,   59, 20, 55,  0 },
    {     18,   13,   58, 20, 55,  0 }, {     19,   12,   57, 20, 55,  0 }, {     19,   12,   56, 20, 55,  0 }, {     20,   11,   55, 20, 55,  0 }, {     20,   11,   54, 20, 55,  0 },
    {     21,   10,   53, 20, 55,  0 }, {     21,   10,   52, 20, 55,  0 }, {     22,    9,   51, 20, 55,  0 }, {     22,    9,   50, 20, 55,  0 }, {     23,    8,   49, 20, 55,  0 },
    {     23,    8,   48, 20, 55,  0 }, {     24,    7,   47, 20, 55,  0 }, {     24,    7,   46, 20, 55,  0 }, {     25,    6,   45, 20, 55,  0 }, {     25,    6,   44, 20, 55,  0 },
    {     26,    5,   43, 20, 55,  0 }, {     26,    5,   42, 20, 55,  0 }, {     27,    4,   41, 20, 55,  0 }, {     27,    4,   40, 20, 55,  0 }, {     28,    3,   39, 20, 55,  0 },
    {     28,    3,   38, 20, 55,  0 }, {     29,    2,   37, 20, 55,  0 }, {     29,    2,   36, 20, 55,  0 }, {     30,    1,   35, 20, 55,  0 }, {     30,    1,   34, 20, 55,  0 },
    {     31,    0,   33, 20, 55,  0 }, {     31,    0,   32, 20, 55,  0 }, {     32,   -1,   31, 20, 55,  0 }, {     32,   -1,   30, 20, 55,  0 }, {     33,   -2,   29, 20, 55,  0 },
    {     33,   -2,   28, 20, 55,  0 }, {     34,   -3,   27, 20, 55,  0 }, {     34,   -3,   26, 20, 55,  0 }, {     35,   -4,   25, 20, 55,  0 }, {     35,   -4,   24, 20, 55,  0 },
    {     36,   -5,   23, 20, 55,  0 }, {     36,   -5,   22, 20, 55,  0 }, {     37,   -6,   21, 20, 55,  0 }, {     37,   -6,   20, 20, 55,  0 }, {     38,   -7,   19, 20, 55,  0 },
    {     38,   -7,   18, 20, 55,  0 }, {     39,   -8,   17, 20, 55,  0 }, {     39,   -8,   16, 20, 55,  0 }, {     40,   -9,   15, 20, 55,  0 }, {     40,   -9,   14, 20, 55,  0 },
    {     41,  -10,   13, 20, 55,  0 }, {     41,  -10,   12, 20, 55,  0 }, {     42,  -11,   11, 20, 55,  0 }, {     42,  -11,   10, 20, 55,  0 }, {     43,  -12,    9, 20, 55,  0 },
    {     43,  -12,    8, 20, 55,  0 }, {     44,  -13,    7, 20, 55,  0 }, {     44,  -13,    6, 20, 55,  0 }, {     45,  -14,    5, 20, 55,  0 }, {     45,  -14,    4, 20, 55,  0 },
    {     46,  -15,    3, 20, 55,  0 }, {     46,  -15,    2, 20, 55,  0 }, {     47,  -16,    1, 20, 55,  0 }, {     47,  -16,    0, 20, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91804C, {
    {     15,   15,   63, 28, 55,  0 }, {     15,   15,   62, 28, 55,  0 }, {     14,   14,   61, 28, 55,  0 }, {     14,   14,   60, 28, 55,  0 }, {     13,   13,   59, 28, 55,  0 },
    {     13,   13,   58, 28, 55,  0 }, {     12,   12,   57, 28, 55,  0 }, {     12,   12,   56, 28, 55,  0 }, {     11,   11,   55, 28, 55,  0 }, {     11,   11,   54, 28, 55,  0 },
    {     10,   10,   53, 28, 55,  0 }, {     10,   10,   52, 28, 55,  0 }, {      9,    9,   51, 28, 55,  0 }, {      9,    9,   50, 28, 55,  0 }, {      8,    8,   49, 28, 55,  0 },
    {      8,    8,   48, 28, 55,  0 }, {      7,    7,   47, 28, 55,  0 }, {      7,    7,   46, 28, 55,  0 }, {      6,    6,   45, 28, 55,  0 }, {      6,    6,   44, 28, 55,  0 },
    {      5,    5,   43, 28, 55,  0 }, {      5,    5,   42, 28, 55,  0 }, {      4,    4,   41, 28, 55,  0 }, {      4,    4,   40, 28, 55,  0 }, {      3,    3,   39, 28, 55,  0 },
    {      3,    3,   38, 28, 55,  0 }, {      2,    2,   37, 28, 55,  0 }, {      2,    2,   36, 28, 55,  0 }, {      1,    1,   35, 28, 55,  0 }, {      1,    1,   34, 28, 55,  0 },
    {      0,    0,   33, 28, 55,  0 }, {      0,    0,   32, 28, 55,  0 }, {     -1,   -1,   31, 28, 55,  0 }, {     -1,   -1,   30, 28, 55,  0 }, {     -2,   -2,   29, 28, 55,  0 },
    {     -2,   -2,   28, 28, 55,  0 }, {     -3,   -3,   27, 28, 55,  0 }, {     -3,   -3,   26, 28, 55,  0 }, {     -4,   -4,   25, 28, 55,  0 }, {     -4,   -4,   24, 28, 55,  0 },
    {     -5,   -5,   23, 28, 55,  0 }, {     -5,   -5,   22, 28, 55,  0 }, {     -6,   -6,   21, 28, 55,  0 }, {     -6,   -6,   20, 28, 55,  0 }, {     -7,   -7,   19, 28, 55,  0 },
    {     -7,   -7,   18, 28, 55,  0 }, {     -8,   -8,   17, 28, 55,  0 }, {     -8,   -8,   16, 28, 55,  0 }, {     -9,   -9,   15, 28, 55,  0 }, {     -9,   -9,   14, 28, 55,  0 },
    {    -10,  -10,   13, 28, 55,  0 }, {    -10,  -10,   12, 28, 55,  0 }, {    -11,  -11,   11, 28, 55,  0 }, {    -11,  -11,   10, 28, 55,  0 }, {    -12,  -12,    9, 28, 55,  0 },
    {    -12,  -12,    8, 28, 55,  0 }, {    -13,  -13,    7, 28, 55,  0 }, {    -13,  -13,    6, 28, 55,  0 }, {    -14,  -14,    5, 28, 55,  0 }, {    -14,  -14,    4, 28, 55,  0 },
    {    -15,  -15,    3, 28, 55,  0 }, {    -15,  -15,    2, 28, 55,  0 }, {    -16,  -16,    1, 28, 55,  0 }, {    -16,  -16,    0, 28, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91906E, {
    {     15,   16,    8,  4,  0,  0 }, {     14,   17,    8,  4,  0,  0 }, {     13,   18,    8,  4,  0,  0 }, {     12,   19,    8,  4,  0,  0 }, {     11,   20,    8,  4,  0,  0 },
    {     10,   21,    8,  4,  0,  0 }, {      9,   22,    8,  4,  0,  0 }, {      8,   23,    8,  4,  0,  0 }, {      7,   24,    7,  4, 53,  0 }, {      6,   25,    7,  4, 53,  0 },
    {      5,   26,    7,  4, 53,  0 }, {      4,   27,    7,  4, 53,  0 }, {      3,   28,    7,  4, 53,  0 }, {      2,   29,    7,  4, 53,  0 }, {      1,   30,    6,  4, 53,  0 },
    {      0,   31,    6,  4, 53,  0 }, {     -1,   32,    6,  4, 53,  0 }, {     -2,   33,    6,  4, 53,  0 }, {     -3,   34,    5,  4, 53,  0 }, {     -4,   35,    5,  4, 53,  0 },
    {     -5,   36,    5,  4, 53,  0 }, {     -6,   37,    4,  4, 53,  0 }, {     -7,   38,    4,  4, 53,  0 }, {     -8,   39,    4,  4, 53,  0 }, {     -9,   40,    3,  4, 54,  0 },
    {    -10,   41,    3,  4, 54,  0 }, {    -11,   42,    2,  4, 54,  0 }, {    -12,   43,    2,  4, 54,  0 }, {    -13,   44,    1,  4, 54,  0 }, {    -14,   45,    1,  4, 54,  0 },
    {    -15,   46,    0,  4, 54,  0 }, {    -16,   47,    0,  4, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_919190, {
    {     16,   16,    8, 12,  0,  0 }, {     17,   17,    8, 12,  0,  0 }, {     18,   18,    8, 12,  0,  0 }, {     19,   19,    8, 12,  0,  0 }, {     20,   20,    8, 12,  0,  0 },
    {     21,   21,    8, 12,  0,  0 }, {     22,   22,    8, 12,  0,  0 }, {     23,   23,    8, 12,  0,  0 }, {     24,   24,    7, 12, 53,  0 }, {     25,   25,    7, 12, 53,  0 },
    {     26,   26,    7, 12, 53,  0 }, {     27,   27,    7, 12, 53,  0 }, {     28,   28,    7, 12, 53,  0 }, {     29,   29,    7, 12, 53,  0 }, {     30,   30,    6, 12, 53,  0 },
    {     31,   31,    6, 12, 53,  0 }, {     32,   32,    6, 12, 53,  0 }, {     33,   33,    6, 12, 53,  0 }, {     34,   34,    5, 12, 53,  0 }, {     35,   35,    5, 12, 53,  0 },
    {     36,   36,    5, 12, 53,  0 }, {     37,   37,    4, 12, 53,  0 }, {     38,   38,    4, 12, 53,  0 }, {     39,   39,    4, 12, 53,  0 }, {     40,   40,    3, 12, 54,  0 },
    {     41,   41,    3, 12, 54,  0 }, {     42,   42,    3, 12, 54,  0 }, {     43,   43,    2, 12, 54,  0 }, {     44,   44,    2, 12, 54,  0 }, {     45,   45,    1, 12, 54,  0 },
    {     46,   46,    1, 12, 54,  0 }, {     47,   47,    0, 12, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9192B2, {
    {     16,   15,    8, 20,  0,  0 }, {     17,   14,    8, 20,  0,  0 }, {     18,   13,    8, 20,  0,  0 }, {     19,   12,    8, 20,  0,  0 }, {     20,   11,    8, 20,  0,  0 },
    {     21,   10,    8, 20,  0,  0 }, {     22,    9,    8, 20,  0,  0 }, {     23,    8,    8, 20,  0,  0 }, {     24,    7,    7, 20, 53,  0 }, {     25,    6,    7, 20, 53,  0 },
    {     26,    5,    7, 20, 53,  0 }, {     27,    4,    7, 20, 53,  0 }, {     28,    3,    7, 20, 53,  0 }, {     29,    2,    7, 20, 53,  0 }, {     30,    1,    6, 20, 53,  0 },
    {     31,    0,    6, 20, 53,  0 }, {     32,   -1,    6, 20, 53,  0 }, {     33,   -2,    6, 20, 53,  0 }, {     34,   -3,    5, 20, 53,  0 }, {     35,   -4,    5, 20, 53,  0 },
    {     36,   -5,    5, 20, 53,  0 }, {     37,   -6,    4, 20, 53,  0 }, {     38,   -7,    4, 20, 53,  0 }, {     39,   -8,    4, 20, 53,  0 }, {     40,   -9,    3, 20, 54,  0 },
    {     41,  -10,    3, 20, 54,  0 }, {     42,  -11,    3, 20, 54,  0 }, {     43,  -12,    2, 20, 54,  0 }, {     44,  -13,    2, 20, 54,  0 }, {     45,  -14,    1, 20, 54,  0 },
    {     46,  -15,    1, 20, 54,  0 }, {     47,  -16,    0, 20, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9193D4, {
    {     15,   15,    8, 28,  0,  0 }, {     14,   14,    8, 28,  0,  0 }, {     13,   13,    8, 28,  0,  0 }, {     12,   12,    8, 28,  0,  0 }, {     11,   11,    8, 28,  0,  0 },
    {     10,   10,    8, 28,  0,  0 }, {      9,    9,    8, 28,  0,  0 }, {      8,    8,    8, 28,  0,  0 }, {      7,    7,    7, 28, 53,  0 }, {      6,    6,    7, 28, 53,  0 },
    {      5,    5,    7, 28, 53,  0 }, {      4,    4,    7, 28, 53,  0 }, {      3,    3,    7, 28, 53,  0 }, {      2,    2,    7, 28, 53,  0 }, {      1,    1,    6, 28, 53,  0 },
    {      0,    0,    6, 28, 53,  0 }, {     -1,   -1,    6, 28, 53,  0 }, {     -2,   -2,    6, 28, 53,  0 }, {     -3,   -3,    5, 28, 53,  0 }, {     -4,   -4,    5, 28, 53,  0 },
    {     -5,   -5,    5, 28, 53,  0 }, {     -6,   -6,    4, 28, 53,  0 }, {     -7,   -7,    4, 28, 53,  0 }, {     -8,   -8,    4, 28, 53,  0 }, {     -9,   -9,    3, 28, 54,  0 },
    {    -10,  -10,    3, 28, 54,  0 }, {    -11,  -11,    2, 28, 54,  0 }, {    -12,  -12,    2, 28, 54,  0 }, {    -13,  -13,    1, 28, 54,  0 }, {    -14,  -14,    1, 28, 54,  0 },
    {    -15,  -15,    0, 28, 54,  0 }, {    -16,  -16,    0, 28, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91A4AA, {
    {     15,   16,   31,  4, 54,  0 }, {     14,   17,   31,  4, 54,  0 }, {     13,   18,   30,  4, 54,  0 }, {     12,   19,   30,  4, 54,  0 }, {     11,   20,   29,  4,  6,  0 },
    {     10,   21,   28,  4,  6,  0 }, {      9,   22,   28,  4,  6,  0 }, {      8,   23,   27,  4,  6,  0 }, {      7,   24,   26,  4,  6,  0 }, {      6,   25,   26,  4,  6,  0 },
    {      5,   26,   25,  4,  6,  0 }, {      4,   27,   24,  4,  6,  0 }, {      3,   28,   23,  4,  6,  0 }, {      2,   29,   23,  4,  6,  0 }, {      1,   30,   22,  4,  6,  0 },
    {      0,   31,   21,  4,  6,  0 }, {     -1,   32,   20,  4,  6,  0 }, {     -2,   33,   19,  4,  6,  0 }, {     -3,   34,   18,  4,  6,  0 }, {     -4,   35,   16,  4,  6,  0 },
    {     -5,   36,   15,  4,  6,  0 }, {     -6,   37,   14,  4,  7,  0 }, {     -7,   38,   13,  4,  7,  0 }, {     -8,   39,   12,  4,  7,  0 }, {     -8,   39,   11,  4,  7,  0 },
    {     -9,   40,   10,  4,  7,  0 }, {    -10,   41,    9,  4,  7,  0 }, {    -11,   42,    8,  4,  7,  0 }, {    -11,   42,    7,  4,  7,  0 }, {    -12,   43,    6,  4,  7,  0 },
    {    -13,   44,    5,  4,  7,  0 }, {    -13,   44,    4,  4,  7,  0 }, {    -14,   45,    3,  4,  7,  0 }, {    -15,   46,    2,  4,  7,  0 }, {    -15,   46,    1,  4,  7,  0 },
    {    -16,   47,    0,  4,  7,  0 }, {    -16,   47,   -1,  4, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91A5F9, {
    {     16,   16,   31, 12, 54,  0 }, {     17,   17,   31, 12, 54,  0 }, {     18,   18,   30, 12, 54,  0 }, {     19,   19,   30, 12, 54,  0 }, {     20,   20,   29, 12,  6,  0 },
    {     21,   21,   28, 12,  6,  0 }, {     22,   22,   28, 12,  6,  0 }, {     23,   23,   27, 12,  6,  0 }, {     24,   24,   26, 12,  6,  0 }, {     25,   25,   26, 12,  6,  0 },
    {     26,   26,   25, 12,  6,  0 }, {     27,   27,   24, 12,  6,  0 }, {     28,   28,   23, 12,  6,  0 }, {     29,   29,   23, 12,  6,  0 }, {     30,   30,   22, 12,  6,  0 },
    {     31,   31,   21, 12,  6,  0 }, {     32,   32,   20, 12,  6,  0 }, {     33,   33,   19, 12,  6,  0 }, {     34,   34,   18, 12,  6,  0 }, {     35,   35,   16, 12,  6,  0 },
    {     36,   36,   15, 12,  6,  0 }, {     37,   37,   14, 12,  7,  0 }, {     38,   38,   13, 12,  7,  0 }, {     39,   39,   12, 12,  7,  0 }, {     39,   39,   11, 12,  7,  0 },
    {     40,   40,   10, 12,  7,  0 }, {     41,   41,    9, 12,  7,  0 }, {     42,   42,    8, 12,  7,  0 }, {     42,   42,    7, 12,  7,  0 }, {     43,   43,    6, 12,  7,  0 },
    {     44,   44,    5, 12,  7,  0 }, {     44,   44,    4, 12,  7,  0 }, {     45,   45,    3, 12,  7,  0 }, {     46,   46,    2, 12,  7,  0 }, {     46,   46,    1, 12,  7,  0 },
    {     47,   47,    0, 12,  7,  0 }, {     47,   47,   -1, 12, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91A748, {
    {     16,   15,   31, 20, 54,  0 }, {     17,   14,   31, 20, 54,  0 }, {     18,   13,   30, 20, 54,  0 }, {     19,   12,   30, 20, 54,  0 }, {     20,   11,   29, 20,  6,  0 },
    {     21,   10,   28, 20,  6,  0 }, {     22,    9,   28, 20,  6,  0 }, {     23,    8,   27, 20,  6,  0 }, {     24,    7,   26, 20,  6,  0 }, {     25,    6,   26, 20,  6,  0 },
    {     26,    5,   25, 20,  6,  0 }, {     27,    4,   24, 20,  6,  0 }, {     28,    3,   23, 20,  6,  0 }, {     29,    2,   23, 20,  6,  0 }, {     30,    1,   22, 20,  6,  0 },
    {     31,    0,   21, 20,  6,  0 }, {     32,   -1,   20, 20,  6,  0 }, {     33,   -2,   19, 20,  6,  0 }, {     34,   -3,   18, 20,  6,  0 }, {     35,   -4,   16, 20,  6,  0 },
    {     36,   -5,   15, 20,  6,  0 }, {     37,   -6,   14, 20,  7,  0 }, {     38,   -7,   13, 20,  7,  0 }, {     39,   -8,   12, 20,  7,  0 }, {     39,   -8,   11, 20,  7,  0 },
    {     40,   -9,   10, 20,  7,  0 }, {     41,  -10,    9, 20,  7,  0 }, {     42,  -11,    8, 20,  7,  0 }, {     42,  -11,    7, 20,  7,  0 }, {     43,  -12,    6, 20,  7,  0 },
    {     44,  -13,    5, 20,  7,  0 }, {     44,  -13,    4, 20,  7,  0 }, {     45,  -14,    3, 20,  7,  0 }, {     46,  -15,    2, 20,  7,  0 }, {     46,  -15,    1, 20,  7,  0 },
    {     47,  -16,    0, 20,  7,  0 }, {     47,  -16,   -1, 20, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91A897, {
    {     15,   15,   31, 28, 54,  0 }, {     14,   14,   31, 28, 54,  0 }, {     13,   13,   30, 28, 54,  0 }, {     12,   12,   30, 28, 54,  0 }, {     11,   11,   29, 28,  6,  0 },
    {     10,   10,   28, 28,  6,  0 }, {      9,    9,   28, 28,  6,  0 }, {      8,    8,   27, 28,  6,  0 }, {      7,    7,   26, 28,  6,  0 }, {      6,    6,   26, 28,  6,  0 },
    {      5,    5,   25, 28,  6,  0 }, {      4,    4,   24, 28,  6,  0 }, {      3,    3,   23, 28,  6,  0 }, {      2,    2,   23, 28,  6,  0 }, {      1,    1,   22, 28,  6,  0 },
    {      0,    0,   21, 28,  6,  0 }, {     -1,   -1,   20, 28,  6,  0 }, {     -2,   -2,   19, 28,  6,  0 }, {     -3,   -3,   18, 28,  6,  0 }, {     -4,   -4,   16, 28,  6,  0 },
    {     -5,   -5,   15, 28,  6,  0 }, {     -6,   -6,   14, 28,  7,  0 }, {     -7,   -7,   13, 28,  7,  0 }, {     -8,   -8,   12, 28,  7,  0 }, {     -8,   -8,   11, 28,  7,  0 },
    {     -9,   -9,   10, 28,  7,  0 }, {    -10,  -10,    9, 28,  7,  0 }, {    -11,  -11,    8, 28,  7,  0 }, {    -11,  -11,    7, 28,  7,  0 }, {    -12,  -12,    6, 28,  7,  0 },
    {    -13,  -13,    5, 28,  7,  0 }, {    -13,  -13,    4, 28,  7,  0 }, {    -14,  -14,    3, 28,  7,  0 }, {    -15,  -15,    2, 28,  7,  0 }, {    -15,  -15,    1, 28,  7,  0 },
    {    -16,  -16,    0, 28,  7,  0 }, {    -16,  -16,   -1, 28, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_919F6E, {
    {     15,   16,   31,  4, 55,  0 }, {     15,   16,   30,  4, 55,  0 }, {     14,   17,   29,  4, 55,  0 }, {     14,   17,   28,  4, 55,  0 }, {     13,   18,   27,  4,  7,  0 },
    {     12,   19,   26,  4,  7,  0 }, {     12,   19,   25,  4,  7,  0 }, {     11,   20,   24,  4,  7,  0 }, {     10,   21,   23,  4,  7,  0 }, {     10,   21,   22,  4,  7,  0 },
    {      9,   22,   21,  4,  7,  0 }, {      8,   23,   20,  4,  7,  0 }, {      7,   24,   19,  4,  7,  0 }, {      7,   24,   18,  4,  7,  0 }, {      6,   25,   17,  4,  7,  0 },
    {      5,   26,   16,  4,  7,  0 }, {      4,   27,   15,  4,  7,  0 }, {      3,   28,   14,  4,  7,  0 }, {      2,   29,   13,  4,  7,  0 }, {      0,   31,   12,  4,  6,  0 },
    {     -1,   32,   11,  4,  6,  0 }, {     -2,   33,   10,  4,  6,  0 }, {     -3,   34,    9,  4,  6,  0 }, {     -4,   35,    8,  4,  6,  0 }, {     -5,   36,    8,  4,  6,  0 },
    {     -6,   37,    7,  4,  6,  0 }, {     -7,   38,    6,  4,  6,  0 }, {     -8,   39,    5,  4,  6,  0 }, {     -9,   40,    5,  4,  6,  0 }, {    -10,   41,    4,  4,  6,  0 },
    {    -11,   42,    3,  4,  6,  0 }, {    -12,   43,    3,  4,  6,  0 }, {    -13,   44,    2,  4,  6,  0 }, {    -14,   45,    1,  4, 54,  0 }, {    -15,   46,    1,  4, 54,  0 },
    {    -16,   47,    0,  4, 54,  0 }, {    -17,   48,    0,  4, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91A0BD, {
    {     16,   16,   31, 12, 55,  0 }, {     16,   16,   30, 12, 55,  0 }, {     17,   17,   29, 12, 55,  0 }, {     17,   17,   28, 12, 55,  0 }, {     18,   18,   27, 12,  7,  0 },
    {     19,   19,   26, 12,  7,  0 }, {     19,   19,   25, 12,  7,  0 }, {     20,   20,   24, 12,  7,  0 }, {     21,   21,   23, 12,  7,  0 }, {     21,   21,   22, 12,  7,  0 },
    {     22,   22,   21, 12,  7,  0 }, {     23,   23,   20, 12,  7,  0 }, {     24,   24,   19, 12,  7,  0 }, {     24,   24,   18, 12,  7,  0 }, {     25,   25,   17, 12,  7,  0 },
    {     26,   26,   16, 12,  7,  0 }, {     27,   27,   15, 12,  7,  0 }, {     28,   28,   14, 12,  7,  0 }, {     29,   29,   13, 12,  7,  0 }, {     31,   31,   12, 12,  6,  0 },
    {     32,   32,   11, 12,  6,  0 }, {     33,   33,   10, 12,  6,  0 }, {     34,   34,    9, 12,  6,  0 }, {     35,   35,    8, 12,  6,  0 }, {     36,   36,    8, 12,  6,  0 },
    {     37,   37,    7, 12,  6,  0 }, {     38,   38,    6, 12,  6,  0 }, {     39,   39,    5, 12,  6,  0 }, {     40,   40,    5, 12,  6,  0 }, {     41,   41,    4, 12,  6,  0 },
    {     42,   42,    3, 12,  6,  0 }, {     43,   43,    3, 12,  6,  0 }, {     44,   44,    2, 12,  6,  0 }, {     45,   45,    1, 12, 54,  0 }, {     46,   46,    1, 12, 54,  0 },
    {     47,   47,    0, 12, 54,  0 }, {     48,   48,    0, 12, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91A20C, {
    {     16,   15,   31, 20, 55,  0 }, {     16,   15,   30, 20, 55,  0 }, {     17,   14,   29, 20, 55,  0 }, {     17,   14,   28, 20, 55,  0 }, {     18,   13,   27, 20,  7,  0 },
    {     19,   12,   26, 20,  7,  0 }, {     19,   12,   25, 20,  7,  0 }, {     20,   11,   24, 20,  7,  0 }, {     21,   10,   23, 20,  7,  0 }, {     21,   10,   22, 20,  7,  0 },
    {     22,    9,   21, 20,  7,  0 }, {     23,    8,   20, 20,  7,  0 }, {     24,    7,   19, 20,  7,  0 }, {     24,    7,   18, 20,  7,  0 }, {     25,    6,   17, 20,  7,  0 },
    {     26,    5,   16, 20,  7,  0 }, {     27,    4,   15, 20,  7,  0 }, {     28,    3,   14, 20,  7,  0 }, {     29,    2,   13, 20,  7,  0 }, {     31,    0,   12, 20,  6,  0 },
    {     32,   -1,   11, 20,  6,  0 }, {     33,   -2,   10, 20,  6,  0 }, {     34,   -3,    9, 20,  6,  0 }, {     35,   -4,    8, 20,  6,  0 }, {     36,   -5,    8, 20,  6,  0 },
    {     37,   -6,    7, 20,  6,  0 }, {     38,   -7,    6, 20,  6,  0 }, {     39,   -8,    5, 20,  6,  0 }, {     40,   -9,    5, 20,  6,  0 }, {     41,  -10,    4, 20,  6,  0 },
    {     42,  -11,    3, 20,  6,  0 }, {     43,  -12,    3, 20,  6,  0 }, {     44,  -13,    2, 20,  6,  0 }, {     45,  -14,    1, 20, 54,  0 }, {     46,  -15,    1, 20, 54,  0 },
    {     47,  -16,    0, 20, 54,  0 }, {     48,  -17,    0, 20, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91A35B, {
    {     15,   15,   31, 28, 55,  0 }, {     15,   15,   30, 28, 55,  0 }, {     14,   14,   29, 28, 55,  0 }, {     14,   14,   28, 28, 55,  0 }, {     13,   13,   27, 28,  7,  0 },
    {     12,   12,   26, 28,  7,  0 }, {     12,   12,   25, 28,  7,  0 }, {     11,   11,   24, 28,  7,  0 }, {     10,   10,   23, 28,  7,  0 }, {     10,   10,   22, 28,  7,  0 },
    {      9,    9,   21, 28,  7,  0 }, {      8,    8,   20, 28,  7,  0 }, {      7,    7,   19, 28,  7,  0 }, {      7,    7,   18, 28,  7,  0 }, {      6,    6,   17, 28,  7,  0 },
    {      5,    5,   16, 28,  7,  0 }, {      4,    4,   15, 28,  7,  0 }, {      3,    3,   14, 28,  7,  0 }, {      2,    2,   13, 28,  7,  0 }, {      0,    0,   12, 28,  6,  0 },
    {     -1,   -1,   11, 28,  6,  0 }, {     -2,   -2,   10, 28,  6,  0 }, {     -3,   -3,    9, 28,  6,  0 }, {     -4,   -4,    8, 28,  6,  0 }, {     -5,   -5,    8, 28,  6,  0 },
    {     -6,   -6,    7, 28,  6,  0 }, {     -7,   -7,    6, 28,  6,  0 }, {     -8,   -8,    5, 28,  6,  0 }, {     -9,   -9,    5, 28,  6,  0 }, {    -10,  -10,    4, 28,  6,  0 },
    {    -11,  -11,    3, 28,  6,  0 }, {    -12,  -12,    3, 28,  6,  0 }, {    -13,  -13,    2, 28,  6,  0 }, {    -14,  -14,    1, 28, 54,  0 }, {    -15,  -15,    1, 28, 54,  0 },
    {    -16,  -16,    0, 28, 54,  0 }, {    -17,  -17,    0, 28, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_918BE6, {
    {     15,   16,    7,  4, 54,  0 }, {     14,   17,    7,  4, 54,  0 }, {     13,   18,    6,  4, 54,  0 }, {     12,   19,    6,  4, 54,  0 }, {     11,   20,    5,  4, 54,  0 },
    {     10,   21,    5,  4, 54,  0 }, {      9,   22,    4,  4, 54,  0 }, {      8,   23,    4,  4, 54,  0 }, {      7,   24,    4,  4, 53,  0 }, {      6,   25,    3,  4, 53,  0 },
    {      5,   26,    3,  4, 53,  0 }, {      4,   27,    3,  4, 53,  0 }, {      3,   28,    2,  4, 53,  0 }, {      2,   29,    2,  4, 53,  0 }, {      1,   30,    2,  4, 53,  0 },
    {      0,   31,    2,  4, 53,  0 }, {     -1,   32,    1,  4, 53,  0 }, {     -2,   33,    1,  4, 53,  0 }, {     -3,   34,    1,  4, 53,  0 }, {     -4,   35,    1,  4, 53,  0 },
    {     -5,   36,    1,  4, 53,  0 }, {     -6,   37,    1,  4, 53,  0 }, {     -7,   38,    0,  4,  0,  0 }, {     -8,   39,    0,  4,  0,  0 }, {     -9,   40,    0,  4,  0,  0 },
    {    -10,   41,    0,  4,  0,  0 }, {    -11,   42,    0,  4,  0,  0 }, {    -12,   43,    0,  4,  0,  0 }, {    -13,   44,    0,  4,  0,  0 }, {    -14,   45,    0,  4,  0,  0 },
    {    -15,   46,    0,  4,  0,  0 }, {    -16,   47,    0,  4,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_918D08, {
    {     16,   16,    8, 12, 54,  0 }, {     17,   17,    7, 12, 54,  0 }, {     18,   18,    7, 12, 54,  0 }, {     19,   19,    6, 12, 54,  0 }, {     20,   20,    6, 12, 54,  0 },
    {     21,   21,    5, 12, 54,  0 }, {     22,   22,    5, 12, 54,  0 }, {     23,   23,    4, 12, 54,  0 }, {     24,   24,    4, 12, 53,  0 }, {     25,   25,    3, 12, 53,  0 },
    {     26,   26,    3, 12, 53,  0 }, {     27,   27,    3, 12, 53,  0 }, {     28,   28,    2, 12, 53,  0 }, {     29,   29,    2, 12, 53,  0 }, {     30,   30,    2, 12, 53,  0 },
    {     31,   31,    2, 12, 53,  0 }, {     32,   32,    1, 12, 53,  0 }, {     33,   33,    1, 12, 53,  0 }, {     34,   34,    1, 12, 53,  0 }, {     35,   35,    1, 12, 53,  0 },
    {     36,   36,    1, 12, 53,  0 }, {     37,   37,    1, 12, 53,  0 }, {     38,   38,    0, 12,  0,  0 }, {     39,   39,    0, 12,  0,  0 }, {     40,   40,    0, 12,  0,  0 },
    {     41,   41,    0, 12,  0,  0 }, {     42,   42,    0, 12,  0,  0 }, {     43,   43,    0, 12,  0,  0 }, {     44,   44,    0, 12,  0,  0 }, {     45,   45,    0, 12,  0,  0 },
    {     46,   46,    0, 12,  0,  0 }, {     47,   47,    0, 12,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_918E2A, {
    {     16,   15,    8, 20, 54,  0 }, {     17,   14,    7, 20, 54,  0 }, {     18,   13,    7, 20, 54,  0 }, {     19,   12,    6, 20, 54,  0 }, {     20,   11,    6, 20, 54,  0 },
    {     21,   10,    5, 20, 54,  0 }, {     22,    9,    5, 20, 54,  0 }, {     23,    8,    4, 20, 54,  0 }, {     24,    7,    4, 20, 53,  0 }, {     25,    6,    3, 20, 53,  0 },
    {     26,    5,    3, 20, 53,  0 }, {     27,    4,    3, 20, 53,  0 }, {     28,    3,    2, 20, 53,  0 }, {     29,    2,    2, 20, 53,  0 }, {     30,    1,    2, 20, 53,  0 },
    {     31,    0,    2, 20, 53,  0 }, {     32,   -1,    1, 20, 53,  0 }, {     33,   -2,    1, 20, 53,  0 }, {     34,   -3,    1, 20, 53,  0 }, {     35,   -4,    1, 20, 53,  0 },
    {     36,   -5,    1, 20, 53,  0 }, {     37,   -6,    1, 20, 53,  0 }, {     38,   -7,    0, 20,  0,  0 }, {     39,   -8,    0, 20,  0,  0 }, {     40,   -9,    0, 20,  0,  0 },
    {     41,  -10,    0, 20,  0,  0 }, {     42,  -11,    0, 20,  0,  0 }, {     43,  -12,    0, 20,  0,  0 }, {     44,  -13,    0, 20,  0,  0 }, {     45,  -14,    0, 20,  0,  0 },
    {     46,  -15,    0, 20,  0,  0 }, {     47,  -16,    0, 20,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_918F4C, {
    {     15,   15,    7, 28, 54,  0 }, {     14,   14,    7, 28, 54,  0 }, {     13,   13,    6, 28, 54,  0 }, {     12,   12,    6, 28, 54,  0 }, {     11,   11,    5, 28, 54,  0 },
    {     10,   10,    5, 28, 54,  0 }, {      9,    9,    4, 28, 54,  0 }, {      8,    8,    4, 28, 54,  0 }, {      7,    7,    4, 28, 53,  0 }, {      6,    6,    3, 28, 53,  0 },
    {      5,    5,    3, 28, 53,  0 }, {      4,    4,    3, 28, 53,  0 }, {      3,    3,    2, 28, 53,  0 }, {      2,    2,    2, 28, 53,  0 }, {      1,    1,    2, 28, 53,  0 },
    {      0,    0,    2, 28, 53,  0 }, {     -1,   -1,    1, 28, 53,  0 }, {     -2,   -2,    1, 28, 53,  0 }, {     -3,   -3,    1, 28, 53,  0 }, {     -4,   -4,    1, 28, 53,  0 },
    {     -5,   -5,    1, 28, 53,  0 }, {     -6,   -6,    1, 28, 53,  0 }, {     -7,   -7,    0, 28,  0,  0 }, {     -8,   -8,    0, 28,  0,  0 }, {     -9,   -9,    0, 28,  0,  0 },
    {    -10,  -10,    0, 28,  0,  0 }, {    -11,  -11,    0, 28,  0,  0 }, {    -12,  -12,    0, 28,  0,  0 }, {    -13,  -13,    0, 28,  0,  0 }, {    -14,  -14,    0, 28,  0,  0 },
    {    -15,  -15,    0, 28,  0,  0 }, {    -16,  -16,    0, 28,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91A9E6, {
    {     15,   16,    0,  4,  0,  0 }, {     14,   17,    0,  4,  0,  0 }, {     13,   18,    0,  4,  0,  0 }, {     12,   19,    0,  4,  0,  0 }, {     11,   20,    1,  4,  0,  0 },
    {     10,   21,    1,  4, 50,  0 }, {      9,   22,    1,  4, 50,  0 }, {      8,   23,    2,  4, 50,  0 }, {      7,   24,    2,  4, 50,  0 }, {      6,   25,    2,  4, 50,  0 },
    {      5,   26,    3,  4, 50,  0 }, {      4,   27,    3,  4, 50,  0 }, {      3,   28,    4,  4, 50,  0 }, {      2,   29,    4,  4, 51,  0 }, {      1,   30,    5,  4, 51,  0 },
    {      0,   31,    5,  4, 51,  0 }, {     -1,   32,    6,  4, 51,  0 }, {     -2,   33,    6,  4, 51,  0 }, {     -3,   34,    7,  4, 51,  0 }, {     -4,   35,    8,  4, 51,  0 },
    {     -5,   36,    8,  4, 51,  0 }, {     -6,   37,    9,  4, 51,  0 }, {     -7,   38,   10,  4,  3,  0 }, {     -8,   39,   11,  4,  3,  0 }, {     -9,   40,   12,  4,  3,  0 },
    {    -10,   41,   13,  4,  3,  0 }, {    -11,   42,   14,  4,  3,  0 }, {    -12,   43,   15,  4,  3,  0 }, {    -12,   43,   16,  4,  3,  0 }, {    -13,   44,   17,  4, 52,  0 },
    {    -14,   45,   18,  4, 52,  0 }, {    -14,   45,   19,  4, 52,  0 }, {    -15,   46,   20,  4, 52,  0 }, {    -15,   46,   21,  4, 52,  0 }, {    -16,   47,   22,  4, 52,  0 },
    {    -16,   47,   23,  4, 52,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91AB2C, {
    {     16,   16,    0, 12,  0,  0 }, {     17,   17,    0, 12,  0,  0 }, {     18,   18,    0, 12,  0,  0 }, {     19,   19,    0, 12,  0,  0 }, {     20,   20,    1, 12,  0,  0 },
    {     21,   21,    1, 12, 50,  0 }, {     22,   22,    1, 12, 50,  0 }, {     23,   23,    2, 12, 50,  0 }, {     24,   24,    2, 12, 50,  0 }, {     25,   25,    2, 12, 50,  0 },
    {     26,   26,    3, 12, 50,  0 }, {     27,   27,    3, 12, 50,  0 }, {     28,   28,    4, 12, 50,  0 }, {     29,   29,    4, 12, 51,  0 }, {     30,   30,    5, 12, 51,  0 },
    {     31,   31,    5, 12, 51,  0 }, {     32,   32,    6, 12, 51,  0 }, {     33,   33,    6, 12, 51,  0 }, {     34,   34,    7, 12, 51,  0 }, {     35,   35,    8, 12, 51,  0 },
    {     36,   36,    8, 12, 51,  0 }, {     37,   37,    9, 12, 51,  0 }, {     38,   38,   10, 12,  3,  0 }, {     39,   39,   11, 12,  3,  0 }, {     40,   40,   12, 12,  3,  0 },
    {     41,   41,   13, 12,  3,  0 }, {     42,   42,   14, 12,  3,  0 }, {     43,   43,   15, 12,  3,  0 }, {     43,   43,   16, 12,  3,  0 }, {     44,   44,   17, 12, 52,  0 },
    {     45,   45,   18, 12, 52,  0 }, {     45,   45,   19, 12, 52,  0 }, {     46,   46,   20, 12, 52,  0 }, {     46,   46,   21, 12, 52,  0 }, {     47,   47,   22, 12, 52,  0 },
    {     47,   47,   23, 12, 52,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91AC72, {
    {     16,   15,    0, 20,  0,  0 }, {     17,   14,    0, 20,  0,  0 }, {     18,   13,    0, 20,  0,  0 }, {     19,   12,    0, 20,  0,  0 }, {     20,   11,    1, 20,  0,  0 },
    {     21,   10,    1, 20, 50,  0 }, {     22,    9,    1, 20, 50,  0 }, {     23,    8,    2, 20, 50,  0 }, {     24,    7,    2, 20, 50,  0 }, {     25,    6,    2, 20, 50,  0 },
    {     26,    5,    3, 20, 50,  0 }, {     27,    4,    3, 20, 50,  0 }, {     28,    3,    4, 20, 50,  0 }, {     29,    2,    4, 20, 51,  0 }, {     30,    1,    5, 20, 51,  0 },
    {     31,    0,    5, 20, 51,  0 }, {     32,   -1,    6, 20, 51,  0 }, {     33,   -2,    6, 20, 51,  0 }, {     34,   -3,    7, 20, 51,  0 }, {     35,   -4,    8, 20, 51,  0 },
    {     36,   -5,    8, 20, 51,  0 }, {     37,   -6,    9, 20, 51,  0 }, {     38,   -7,   10, 20,  3,  0 }, {     39,   -8,   11, 20,  3,  0 }, {     40,   -9,   12, 20,  3,  0 },
    {     41,  -10,   13, 20,  3,  0 }, {     42,  -11,   14, 20,  3,  0 }, {     43,  -12,   15, 20,  3,  0 }, {     43,  -12,   16, 20,  3,  0 }, {     44,  -13,   17, 20, 52,  0 },
    {     45,  -14,   18, 20, 52,  0 }, {     45,  -14,   19, 20, 52,  0 }, {     46,  -15,   20, 20, 52,  0 }, {     46,  -15,   21, 20, 52,  0 }, {     47,  -16,   22, 20, 52,  0 },
    {     47,  -16,   23, 20, 52,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91ADB8, {
    {     15,   15,    0, 28,  0,  0 }, {     14,   14,    0, 28,  0,  0 }, {     13,   13,    0, 28,  0,  0 }, {     12,   12,    0, 28,  0,  0 }, {     11,   11,    1, 28,  0,  0 },
    {     10,   10,    1, 28, 50,  0 }, {      9,    9,    1, 28, 50,  0 }, {      8,    8,    2, 28, 50,  0 }, {      7,    7,    2, 28, 50,  0 }, {      6,    6,    2, 28, 50,  0 },
    {      5,    5,    3, 28, 50,  0 }, {      4,    4,    3, 28, 50,  0 }, {      3,    3,    4, 28, 50,  0 }, {      2,    2,    4, 28, 51,  0 }, {      1,    1,    5, 28, 51,  0 },
    {      0,    0,    5, 28, 51,  0 }, {     -1,   -1,    6, 28, 51,  0 }, {     -2,   -2,    6, 28, 51,  0 }, {     -3,   -3,    7, 28, 51,  0 }, {     -4,   -4,    8, 28, 51,  0 },
    {     -5,   -5,    8, 28, 51,  0 }, {     -6,   -6,    9, 28, 51,  0 }, {     -7,   -7,   10, 28,  3,  0 }, {     -8,   -8,   11, 28,  3,  0 }, {     -9,   -9,   12, 28,  3,  0 },
    {    -10,  -10,   13, 28,  3,  0 }, {    -11,  -11,   14, 28,  3,  0 }, {    -12,  -12,   15, 28,  3,  0 }, {    -12,  -12,   16, 28,  3,  0 }, {    -13,  -13,   17, 28, 52,  0 },
    {    -14,  -14,   18, 28, 52,  0 }, {    -14,  -14,   19, 28, 52,  0 }, {    -15,  -15,   20, 28, 52,  0 }, {    -15,  -15,   21, 28, 52,  0 }, {    -16,  -16,   22, 28, 52,  0 },
    {    -16,  -16,   23, 28, 52,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91AEFE, {
    {     15,   16,    0,  4, 52,  0 }, {     15,   16,    1,  4, 52,  0 }, {     14,   17,    2,  4, 52,  0 }, {     14,   17,    3,  4, 52,  0 }, {     13,   18,    4,  4, 52,  0 },
    {     13,   18,    5,  4, 52,  0 }, {     12,   19,    6,  4, 52,  0 }, {     11,   20,    7,  4,  3,  0 }, {     11,   20,    8,  4,  3,  0 }, {     10,   21,    9,  4,  3,  0 },
    {      9,   22,   10,  4,  3,  0 }, {      8,   23,   11,  4,  3,  0 }, {      7,   24,   12,  4,  3,  0 }, {      6,   25,   13,  4,  3,  0 }, {      5,   26,   14,  4, 51,  0 },
    {      4,   27,   15,  4, 51,  0 }, {      3,   28,   15,  4, 51,  0 }, {      2,   29,   16,  4, 51,  0 }, {      1,   30,   17,  4, 51,  0 }, {      0,   31,   17,  4, 51,  0 },
    {     -1,   32,   18,  4, 51,  0 }, {     -2,   33,   18,  4, 51,  0 }, {     -3,   34,   19,  4, 51,  0 }, {     -4,   35,   19,  4, 50,  0 }, {     -5,   36,   20,  4, 50,  0 },
    {     -6,   37,   20,  4, 50,  0 }, {     -7,   38,   21,  4, 50,  0 }, {     -8,   39,   21,  4, 50,  0 }, {     -9,   40,   21,  4, 50,  0 }, {    -10,   41,   22,  4, 50,  0 },
    {    -11,   42,   22,  4, 50,  0 }, {    -12,   43,   22,  4,  0,  0 }, {    -13,   44,   23,  4,  0,  0 }, {    -14,   45,   23,  4,  0,  0 }, {    -15,   46,   23,  4,  0,  0 },
    {    -16,   47,   23,  4,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91B044, {
    {     16,   16,    0, 12, 52,  0 }, {     16,   16,    1, 12, 52,  0 }, {     17,   17,    2, 12, 52,  0 }, {     17,   17,    3, 12, 52,  0 }, {     18,   18,    4, 12, 52,  0 },
    {     18,   18,    5, 12, 52,  0 }, {     19,   19,    6, 12, 52,  0 }, {     20,   20,    7, 12,  3,  0 }, {     20,   20,    8, 12,  3,  0 }, {     21,   21,    9, 12,  3,  0 },
    {     22,   22,   10, 12,  3,  0 }, {     23,   23,   11, 12,  3,  0 }, {     24,   24,   12, 12,  3,  0 }, {     25,   25,   13, 12,  3,  0 }, {     26,   26,   14, 12, 51,  0 },
    {     27,   27,   15, 12, 51,  0 }, {     28,   28,   15, 12, 51,  0 }, {     29,   29,   16, 12, 51,  0 }, {     30,   30,   17, 12, 51,  0 }, {     31,   31,   17, 12, 51,  0 },
    {     32,   32,   18, 12, 51,  0 }, {     33,   33,   18, 12, 51,  0 }, {     34,   34,   19, 12, 51,  0 }, {     35,   35,   19, 12, 50,  0 }, {     36,   36,   20, 12, 50,  0 },
    {     37,   37,   20, 12, 50,  0 }, {     38,   38,   21, 12, 50,  0 }, {     39,   39,   21, 12, 50,  0 }, {     40,   40,   21, 12, 50,  0 }, {     41,   41,   22, 12, 50,  0 },
    {     42,   42,   22, 12, 50,  0 }, {     43,   43,   22, 12,  0,  0 }, {     44,   44,   23, 12,  0,  0 }, {     45,   45,   23, 12,  0,  0 }, {     46,   46,   23, 12,  0,  0 },
    {     47,   47,   23, 12,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91B18A, {
    {     16,   15,    0, 20, 52,  0 }, {     16,   15,    1, 20, 52,  0 }, {     17,   14,    2, 20, 52,  0 }, {     17,   14,    3, 20, 52,  0 }, {     18,   13,    4, 20, 52,  0 },
    {     18,   13,    5, 20, 52,  0 }, {     19,   12,    6, 20, 52,  0 }, {     20,   11,    7, 20,  3,  0 }, {     20,   11,    8, 20,  3,  0 }, {     21,   10,    9, 20,  3,  0 },
    {     22,    9,   10, 20,  3,  0 }, {     23,    8,   11, 20,  3,  0 }, {     24,    7,   12, 20,  3,  0 }, {     25,    6,   13, 20,  3,  0 }, {     26,    5,   14, 20, 51,  0 },
    {     27,    4,   15, 20, 51,  0 }, {     28,    3,   15, 20, 51,  0 }, {     29,    2,   16, 20, 51,  0 }, {     30,    1,   17, 20, 51,  0 }, {     31,    0,   17, 20, 51,  0 },
    {     32,   -1,   18, 20, 51,  0 }, {     33,   -2,   18, 20, 51,  0 }, {     34,   -3,   19, 20, 51,  0 }, {     35,   -4,   19, 20, 50,  0 }, {     36,   -5,   20, 20, 50,  0 },
    {     37,   -6,   20, 20, 50,  0 }, {     38,   -7,   21, 20, 50,  0 }, {     39,   -8,   21, 20, 50,  0 }, {     40,   -9,   21, 20, 50,  0 }, {     41,  -10,   22, 20, 50,  0 },
    {     42,  -11,   22, 20, 50,  0 }, {     43,  -12,   22, 20,  0,  0 }, {     44,  -13,   23, 20,  0,  0 }, {     45,  -14,   23, 20,  0,  0 }, {     46,  -15,   23, 20,  0,  0 },
    {     47,  -16,   23, 20,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91B2D0, {
    {     15,   15,    0, 28, 52,  0 }, {     15,   15,    1, 28, 52,  0 }, {     14,   14,    2, 28, 52,  0 }, {     14,   14,    3, 28, 52,  0 }, {     13,   13,    4, 28, 52,  0 },
    {     13,   13,    5, 28, 52,  0 }, {     12,   12,    6, 28, 52,  0 }, {     11,   11,    7, 28,  3,  0 }, {     11,   11,    8, 28,  3,  0 }, {     10,   10,    9, 28,  3,  0 },
    {      9,    9,   10, 28,  3,  0 }, {      8,    8,   11, 28,  3,  0 }, {      7,    7,   12, 28,  3,  0 }, {      6,    6,   13, 28,  3,  0 }, {      5,    5,   14, 28, 51,  0 },
    {      4,    4,   15, 28, 51,  0 }, {      3,    3,   15, 28, 51,  0 }, {      2,    2,   16, 28, 51,  0 }, {      1,    1,   17, 28, 51,  0 }, {      0,    0,   17, 28, 51,  0 },
    {     -1,   -1,   18, 28, 51,  0 }, {     -2,   -2,   18, 28, 51,  0 }, {     -3,   -3,   19, 28, 51,  0 }, {     -4,   -4,   19, 28, 50,  0 }, {     -5,   -5,   20, 28, 50,  0 },
    {     -6,   -6,   20, 28, 50,  0 }, {     -7,   -7,   21, 28, 50,  0 }, {     -8,   -8,   21, 28, 50,  0 }, {     -9,   -9,   21, 28, 50,  0 }, {    -10,  -10,   22, 28, 50,  0 },
    {    -11,  -11,   22, 28, 50,  0 }, {    -12,  -12,   22, 28,  0,  0 }, {    -13,  -13,   23, 28,  0,  0 }, {    -14,  -14,   23, 28,  0,  0 }, {    -15,  -15,   23, 28,  0,  0 },
    {    -16,  -16,   23, 28,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91B416, {
    {     15,   16,   23,  4,  0,  0 }, {     14,   17,   23,  4,  0,  0 }, {     13,   18,   23,  4,  0,  0 }, {     12,   19,   23,  4,  0,  0 }, {     11,   20,   22,  4,  0,  0 },
    {     10,   21,   22,  4, 53,  0 }, {      9,   22,   22,  4, 53,  0 }, {      8,   23,   21,  4, 53,  0 }, {      7,   24,   21,  4, 53,  0 }, {      6,   25,   21,  4, 53,  0 },
    {      5,   26,   20,  4, 53,  0 }, {      4,   27,   20,  4, 53,  0 }, {      3,   28,   19,  4, 53,  0 }, {      2,   29,   19,  4, 54,  0 }, {      1,   30,   18,  4, 54,  0 },
    {      0,   31,   18,  4, 54,  0 }, {     -1,   32,   17,  4, 54,  0 }, {     -2,   33,   17,  4, 54,  0 }, {     -3,   34,   16,  4, 54,  0 }, {     -4,   35,   15,  4, 54,  0 },
    {     -5,   36,   15,  4, 54,  0 }, {     -6,   37,   14,  4, 54,  0 }, {     -7,   38,   13,  4,  7,  0 }, {     -8,   39,   12,  4,  7,  0 }, {     -9,   40,   11,  4,  7,  0 },
    {    -10,   41,   10,  4,  7,  0 }, {    -11,   42,    9,  4,  7,  0 }, {    -12,   43,    8,  4,  7,  0 }, {    -12,   43,    7,  4,  7,  0 }, {    -13,   44,    6,  4, 55,  0 },
    {    -14,   45,    5,  4, 55,  0 }, {    -14,   45,    4,  4, 55,  0 }, {    -15,   46,    3,  4, 55,  0 }, {    -15,   46,    2,  4, 55,  0 }, {    -16,   47,    1,  4, 55,  0 },
    {    -16,   47,    0,  4, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91B55C, {
    {     16,   16,   23, 12,  0,  0 }, {     17,   17,   23, 12,  0,  0 }, {     18,   18,   23, 12,  0,  0 }, {     19,   19,   23, 12,  0,  0 }, {     20,   20,   22, 12,  0,  0 },
    {     21,   21,   22, 12, 53,  0 }, {     22,   22,   22, 12, 53,  0 }, {     23,   23,   21, 12, 53,  0 }, {     24,   24,   21, 12, 53,  0 }, {     25,   25,   21, 12, 53,  0 },
    {     26,   26,   20, 12, 53,  0 }, {     27,   27,   20, 12, 53,  0 }, {     28,   28,   19, 12, 53,  0 }, {     29,   29,   19, 12, 54,  0 }, {     30,   30,   18, 12, 54,  0 },
    {     31,   31,   18, 12, 54,  0 }, {     32,   32,   17, 12, 54,  0 }, {     33,   33,   17, 12, 54,  0 }, {     34,   34,   16, 12, 54,  0 }, {     35,   35,   15, 12, 54,  0 },
    {     36,   36,   15, 12, 54,  0 }, {     37,   37,   14, 12, 54,  0 }, {     38,   38,   13, 12,  7,  0 }, {     39,   39,   12, 12,  7,  0 }, {     40,   40,   11, 12,  7,  0 },
    {     41,   41,   10, 12,  7,  0 }, {     42,   42,    9, 12,  7,  0 }, {     43,   43,    8, 12,  7,  0 }, {     43,   43,    7, 12,  7,  0 }, {     44,   44,    6, 12, 55,  0 },
    {     45,   45,    5, 12, 55,  0 }, {     45,   45,    4, 12, 55,  0 }, {     46,   46,    3, 12, 55,  0 }, {     46,   46,    2, 12, 55,  0 }, {     47,   47,    1, 12, 55,  0 },
    {     47,   47,    0, 12, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91B6A2, {
    {     16,   15,   23, 20,  0,  0 }, {     17,   14,   23, 20,  0,  0 }, {     18,   13,   23, 20,  0,  0 }, {     19,   12,   23, 20,  0,  0 }, {     20,   11,   22, 20,  0,  0 },
    {     21,   10,   22, 20, 53,  0 }, {     22,    9,   22, 20, 53,  0 }, {     23,    8,   21, 20, 53,  0 }, {     24,    7,   21, 20, 53,  0 }, {     25,    6,   21, 20, 53,  0 },
    {     26,    5,   20, 20, 53,  0 }, {     27,    4,   20, 20, 53,  0 }, {     28,    3,   19, 20, 53,  0 }, {     29,    2,   19, 20, 54,  0 }, {     30,    1,   18, 20, 54,  0 },
    {     31,    0,   18, 20, 54,  0 }, {     32,   -1,   17, 20, 54,  0 }, {     33,   -2,   17, 20, 54,  0 }, {     34,   -3,   16, 20, 54,  0 }, {     35,   -4,   15, 20, 54,  0 },
    {     36,   -5,   15, 20, 54,  0 }, {     37,   -6,   14, 20, 54,  0 }, {     38,   -7,   13, 20,  7,  0 }, {     39,   -8,   12, 20,  7,  0 }, {     40,   -9,   11, 20,  7,  0 },
    {     41,  -10,   10, 20,  7,  0 }, {     42,  -11,    9, 20,  7,  0 }, {     43,  -12,    8, 20,  7,  0 }, {     43,  -12,    7, 20,  7,  0 }, {     44,  -13,    6, 20, 55,  0 },
    {     45,  -14,    5, 20, 55,  0 }, {     45,  -14,    4, 20, 55,  0 }, {     46,  -15,    3, 20, 55,  0 }, {     46,  -15,    2, 20, 55,  0 }, {     47,  -16,    1, 20, 55,  0 },
    {     47,  -16,    0, 20, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91B7E8, {
    {     15,   15,   23, 28,  0,  0 }, {     14,   14,   23, 28,  0,  0 }, {     13,   13,   23, 28,  0,  0 }, {     12,   12,   23, 28,  0,  0 }, {     11,   11,   22, 28,  0,  0 },
    {     10,   10,   22, 28, 53,  0 }, {      9,    9,   22, 28, 53,  0 }, {      8,    8,   21, 28, 53,  0 }, {      7,    7,   21, 28, 53,  0 }, {      6,    6,   21, 28, 53,  0 },
    {      5,    5,   20, 28, 53,  0 }, {      4,    4,   20, 28, 53,  0 }, {      3,    3,   19, 28, 53,  0 }, {      2,    2,   19, 28, 54,  0 }, {      1,    1,   18, 28, 54,  0 },
    {      0,    0,   18, 28, 54,  0 }, {     -1,   -1,   17, 28, 54,  0 }, {     -2,   -2,   17, 28, 54,  0 }, {     -3,   -3,   16, 28, 54,  0 }, {     -4,   -4,   15, 28, 54,  0 },
    {     -5,   -5,   15, 28, 54,  0 }, {     -6,   -6,   14, 28, 54,  0 }, {     -7,   -7,   13, 28,  7,  0 }, {     -8,   -8,   12, 28,  7,  0 }, {     -9,   -9,   11, 28,  7,  0 },
    {    -10,  -10,   10, 28,  7,  0 }, {    -11,  -11,    9, 28,  7,  0 }, {    -12,  -12,    8, 28,  7,  0 }, {    -12,  -12,    7, 28,  7,  0 }, {    -13,  -13,    6, 28, 55,  0 },
    {    -14,  -14,    5, 28, 55,  0 }, {    -14,  -14,    4, 28, 55,  0 }, {    -15,  -15,    3, 28, 55,  0 }, {    -15,  -15,    2, 28, 55,  0 }, {    -16,  -16,    1, 28, 55,  0 },
    {    -16,  -16,    0, 28, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91B92E, {
    {     15,   16,   23,  4, 55,  0 }, {     15,   16,   22,  4, 55,  0 }, {     14,   17,   21,  4, 55,  0 }, {     14,   17,   20,  4, 55,  0 }, {     13,   18,   19,  4, 55,  0 },
    {     13,   18,   18,  4, 55,  0 }, {     12,   19,   17,  4, 55,  0 }, {     11,   20,   16,  4,  7,  0 }, {     11,   20,   15,  4,  7,  0 }, {     10,   21,   14,  4,  7,  0 },
    {      9,   22,   13,  4,  7,  0 }, {      8,   23,   12,  4,  7,  0 }, {      7,   24,   11,  4,  7,  0 }, {      6,   25,   10,  4,  7,  0 }, {      5,   26,    9,  4, 54,  0 },
    {      4,   27,    8,  4, 54,  0 }, {      3,   28,    8,  4, 54,  0 }, {      2,   29,    7,  4, 54,  0 }, {      1,   30,    6,  4, 54,  0 }, {      0,   31,    6,  4, 54,  0 },
    {     -1,   32,    5,  4, 54,  0 }, {     -2,   33,    5,  4, 54,  0 }, {     -3,   34,    4,  4, 54,  0 }, {     -4,   35,    4,  4, 53,  0 }, {     -5,   36,    3,  4, 53,  0 },
    {     -6,   37,    3,  4, 53,  0 }, {     -7,   38,    2,  4, 53,  0 }, {     -8,   39,    2,  4, 53,  0 }, {     -9,   40,    2,  4, 53,  0 }, {    -10,   41,    1,  4, 53,  0 },
    {    -11,   42,    1,  4, 53,  0 }, {    -12,   43,    1,  4,  0,  0 }, {    -13,   44,    0,  4,  0,  0 }, {    -14,   45,    0,  4,  0,  0 }, {    -15,   46,    0,  4,  0,  0 },
    {    -16,   47,    0,  4,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91BA74, {
    {     16,   16,   23, 12, 55,  0 }, {     16,   16,   22, 12, 55,  0 }, {     17,   17,   21, 12, 55,  0 }, {     17,   17,   20, 12, 55,  0 }, {     18,   18,   19, 12, 55,  0 },
    {     18,   18,   18, 12, 55,  0 }, {     19,   19,   17, 12, 55,  0 }, {     20,   20,   16, 12,  7,  0 }, {     20,   20,   15, 12,  7,  0 }, {     21,   21,   14, 12,  7,  0 },
    {     22,   22,   13, 12,  7,  0 }, {     23,   23,   12, 12,  7,  0 }, {     24,   24,   11, 12,  7,  0 }, {     25,   25,   10, 12,  7,  0 }, {     26,   26,    9, 12, 54,  0 },
    {     27,   27,    8, 12, 54,  0 }, {     28,   28,    8, 12, 54,  0 }, {     29,   29,    7, 12, 54,  0 }, {     30,   30,    6, 12, 54,  0 }, {     31,   31,    6, 12, 54,  0 },
    {     32,   32,    5, 12, 54,  0 }, {     33,   33,    5, 12, 54,  0 }, {     34,   34,    4, 12, 54,  0 }, {     35,   35,    4, 12, 53,  0 }, {     36,   36,    3, 12, 53,  0 },
    {     37,   37,    3, 12, 53,  0 }, {     38,   38,    2, 12, 53,  0 }, {     39,   39,    2, 12, 53,  0 }, {     40,   40,    2, 12, 53,  0 }, {     41,   41,    1, 12, 53,  0 },
    {     42,   42,    1, 12, 53,  0 }, {     43,   43,    1, 12,  0,  0 }, {     44,   44,    0, 12,  0,  0 }, {     45,   45,    0, 12,  0,  0 }, {     46,   46,    0, 12,  0,  0 },
    {     47,   47,    0, 12,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91BBBA, {
    {     16,   15,   23, 20, 55,  0 }, {     16,   15,   22, 20, 55,  0 }, {     17,   14,   21, 20, 55,  0 }, {     17,   14,   20, 20, 55,  0 }, {     18,   13,   19, 20, 55,  0 },
    {     18,   13,   18, 20, 55,  0 }, {     19,   12,   17, 20, 55,  0 }, {     20,   11,   16, 20,  7,  0 }, {     20,   11,   15, 20,  7,  0 }, {     21,   10,   14, 20,  7,  0 },
    {     22,    9,   13, 20,  7,  0 }, {     23,    8,   12, 20,  7,  0 }, {     24,    7,   11, 20,  7,  0 }, {     25,    6,   10, 20,  7,  0 }, {     26,    5,    9, 20, 54,  0 },
    {     27,    4,    8, 20, 54,  0 }, {     28,    3,    8, 20, 54,  0 }, {     29,    2,    7, 20, 54,  0 }, {     30,    1,    6, 20, 54,  0 }, {     31,    0,    6, 20, 54,  0 },
    {     32,   -1,    5, 20, 54,  0 }, {     33,   -2,    5, 20, 54,  0 }, {     34,   -3,    4, 20, 54,  0 }, {     35,   -4,    4, 20, 53,  0 }, {     36,   -5,    3, 20, 53,  0 },
    {     37,   -6,    3, 20, 53,  0 }, {     38,   -7,    2, 20, 53,  0 }, {     39,   -8,    2, 20, 53,  0 }, {     40,   -9,    2, 20, 53,  0 }, {     41,  -10,    1, 20, 53,  0 },
    {     42,  -11,    1, 20, 53,  0 }, {     43,  -12,    1, 20,  0,  0 }, {     44,  -13,    0, 20,  0,  0 }, {     45,  -14,    0, 20,  0,  0 }, {     46,  -15,    0, 20,  0,  0 },
    {     47,  -16,    0, 20,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91BD00, {
    {     15,   15,   23, 28, 55,  0 }, {     15,   15,   22, 28, 55,  0 }, {     14,   14,   21, 28, 55,  0 }, {     14,   14,   20, 28, 55,  0 }, {     13,   13,   19, 28, 55,  0 },
    {     13,   13,   18, 28, 55,  0 }, {     12,   12,   17, 28, 55,  0 }, {     11,   11,   16, 28,  7,  0 }, {     11,   11,   15, 28,  7,  0 }, {     10,   10,   14, 28,  7,  0 },
    {      9,    9,   13, 28,  7,  0 }, {      8,    8,   12, 28,  7,  0 }, {      7,    7,   11, 28,  7,  0 }, {      6,    6,   10, 28,  7,  0 }, {      5,    5,    9, 28, 54,  0 },
    {      4,    4,    8, 28, 54,  0 }, {      3,    3,    8, 28, 54,  0 }, {      2,    2,    7, 28, 54,  0 }, {      1,    1,    6, 28, 54,  0 }, {      0,    0,    6, 28, 54,  0 },
    {     -1,   -1,    5, 28, 54,  0 }, {     -2,   -2,    5, 28, 54,  0 }, {     -3,   -3,    4, 28, 54,  0 }, {     -4,   -4,    4, 28, 53,  0 }, {     -5,   -5,    3, 28, 53,  0 },
    {     -6,   -6,    3, 28, 53,  0 }, {     -7,   -7,    2, 28, 53,  0 }, {     -8,   -8,    2, 28, 53,  0 }, {     -9,   -9,    2, 28, 53,  0 }, {    -10,  -10,    1, 28, 53,  0 },
    {    -11,  -11,    1, 28, 53,  0 }, {    -12,  -12,    1, 28,  0,  0 }, {    -13,  -13,    0, 28,  0,  0 }, {    -14,  -14,    0, 28,  0,  0 }, {    -15,  -15,    0, 28,  0,  0 },
    {    -16,  -16,    0, 28,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95787E, {
    {     15,   16,    0,  4,  0,  0 }, {     14,   17,    0,  4,  0,  0 }, {     13,   18,    0,  4,  0,  0 }, {     12,   19,    0,  4,  0,  0 }, {     11,   20,    0,  4,  0,  0 },
    {     10,   21,    0,  4,  0,  0 }, {      9,   22,    0,  4,  0,  0 }, {      8,   23,    0,  4,  0,  0 }, {      7,   24,    0,  4,  0,  1 }, {      6,   25,    0,  4,  0,  1 },
    {      5,   26,    0,  4,  0,  1 }, {      4,   27,    0,  4,  0,  1 }, {      3,   28,    0,  4,  0,  1 }, {      2,   29,    0,  4,  0,  1 }, {      1,   30,    0,  4,  0,  1 },
    {      0,   31,    0,  4,  0,  1 }, {     -1,   32,    0,  4,  0,  1 }, {     -2,   33,    0,  4,  0,  1 }, {     -3,   34,    0,  4,  0,  1 }, {     -4,   35,    0,  4,  0,  1 },
    {     -5,   36,    0,  4,  0,  1 }, {     -6,   37,    0,  4,  0,  1 }, {     -7,   38,    0,  4,  0,  1 }, {     -8,   39,    0,  4,  0,  1 }, {     -9,   40,    0,  4,  0,  2 },
    {    -10,   41,    0,  4,  0,  2 }, {    -11,   42,    0,  4,  0,  2 }, {    -12,   43,    0,  4,  0,  2 }, {    -13,   44,    0,  4,  0,  2 }, {    -14,   45,    0,  4,  0,  2 },
    {    -15,   46,    0,  4,  0,  2 }, {    -16,   47,    0,  4,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9579A0, {
    {     16,   16,    0, 12,  0,  0 }, {     17,   17,    0, 12,  0,  0 }, {     18,   18,    0, 12,  0,  0 }, {     19,   19,    0, 12,  0,  0 }, {     20,   20,    0, 12,  0,  0 },
    {     21,   21,    0, 12,  0,  0 }, {     22,   22,    0, 12,  0,  0 }, {     23,   23,    0, 12,  0,  0 }, {     24,   24,    0, 12,  0,  1 }, {     25,   25,    0, 12,  0,  1 },
    {     26,   26,    0, 12,  0,  1 }, {     27,   27,    0, 12,  0,  1 }, {     28,   28,    0, 12,  0,  1 }, {     29,   29,    0, 12,  0,  1 }, {     30,   30,    0, 12,  0,  1 },
    {     31,   31,    0, 12,  0,  1 }, {     32,   32,    0, 12,  0,  1 }, {     33,   33,    0, 12,  0,  1 }, {     34,   34,    0, 12,  0,  1 }, {     35,   35,    0, 12,  0,  1 },
    {     36,   36,    0, 12,  0,  1 }, {     37,   37,    0, 12,  0,  1 }, {     38,   38,    0, 12,  0,  1 }, {     39,   39,    0, 12,  0,  1 }, {     40,   40,    0, 12,  0,  2 },
    {     41,   41,    0, 12,  0,  2 }, {     42,   42,    0, 12,  0,  2 }, {     43,   43,    0, 12,  0,  2 }, {     44,   44,    0, 12,  0,  2 }, {     45,   45,    0, 12,  0,  2 },
    {     46,   46,    0, 12,  0,  2 }, {     47,   47,    0, 12,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_957AC2, {
    {     16,   15,    0, 20,  0,  0 }, {     17,   14,    0, 20,  0,  0 }, {     18,   13,    0, 20,  0,  0 }, {     19,   12,    0, 20,  0,  0 }, {     20,   11,    0, 20,  0,  0 },
    {     21,   10,    0, 20,  0,  0 }, {     22,    9,    0, 20,  0,  0 }, {     23,    8,    0, 20,  0,  0 }, {     24,    7,    0, 20,  0,  1 }, {     25,    6,    0, 20,  0,  1 },
    {     26,    5,    0, 20,  0,  1 }, {     27,    4,    0, 20,  0,  1 }, {     28,    3,    0, 20,  0,  1 }, {     29,    2,    0, 20,  0,  1 }, {     30,    1,    0, 20,  0,  1 },
    {     31,    0,    0, 20,  0,  1 }, {     32,   -1,    0, 20,  0,  1 }, {     33,   -2,    0, 20,  0,  1 }, {     34,   -3,    0, 20,  0,  1 }, {     35,   -4,    0, 20,  0,  1 },
    {     36,   -5,    0, 20,  0,  1 }, {     37,   -6,    0, 20,  0,  1 }, {     38,   -7,    0, 20,  0,  1 }, {     39,   -8,    0, 20,  0,  1 }, {     40,   -9,    0, 20,  0,  2 },
    {     41,  -10,    0, 20,  0,  2 }, {     42,  -11,    0, 20,  0,  2 }, {     43,  -12,    0, 20,  0,  2 }, {     44,  -13,    0, 20,  0,  2 }, {     45,  -14,    0, 20,  0,  2 },
    {     46,  -15,    0, 20,  0,  2 }, {     47,  -16,    0, 20,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_957BE4, {
    {     15,   15,    0, 28,  0,  0 }, {     14,   14,    0, 28,  0,  0 }, {     13,   13,    0, 28,  0,  0 }, {     12,   12,    0, 28,  0,  0 }, {     11,   11,    0, 28,  0,  0 },
    {     10,   10,    0, 28,  0,  0 }, {      9,    9,    0, 28,  0,  0 }, {      8,    8,    0, 28,  0,  0 }, {      7,    7,    0, 28,  0,  1 }, {      6,    6,    0, 28,  0,  1 },
    {      5,    5,    0, 28,  0,  1 }, {      4,    4,    0, 28,  0,  1 }, {      3,    3,    0, 28,  0,  1 }, {      2,    2,    0, 28,  0,  1 }, {      1,    1,    0, 28,  0,  1 },
    {      0,    0,    0, 28,  0,  1 }, {     -1,   -1,    0, 28,  0,  1 }, {     -2,   -2,    0, 28,  0,  1 }, {     -3,   -3,    0, 28,  0,  1 }, {     -4,   -4,    0, 28,  0,  1 },
    {     -5,   -5,    0, 28,  0,  1 }, {     -6,   -6,    0, 28,  0,  1 }, {     -7,   -7,    0, 28,  0,  1 }, {     -8,   -8,    0, 28,  0,  1 }, {     -9,   -9,    0, 28,  0,  2 },
    {    -10,  -10,    0, 28,  0,  2 }, {    -11,  -11,    0, 28,  0,  2 }, {    -12,  -12,    0, 28,  0,  2 }, {    -13,  -13,    0, 28,  0,  2 }, {    -14,  -14,    0, 28,  0,  2 },
    {    -15,  -15,    0, 28,  0,  2 }, {    -16,  -16,    0, 28,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_957D06, {
    {     15,   16,    0,  4,  0,  0 }, {     14,   17,    0,  4,  0,  0 }, {     13,   18,    0,  4,  0,  0 }, {     12,   19,    0,  4,  0,  0 }, {     11,   20,    0,  4,  0,  0 },
    {     10,   21,    0,  4,  0,  0 }, {      9,   22,    0,  4,  0,  0 }, {      8,   23,    0,  4,  0,  0 }, {      7,   24,    0,  4,  0,  3 }, {      6,   25,    0,  4,  0,  3 },
    {      5,   26,    0,  4,  0,  3 }, {      4,   27,    0,  4,  0,  3 }, {      3,   28,    0,  4,  0,  3 }, {      2,   29,    0,  4,  0,  3 }, {      1,   30,    0,  4,  0,  3 },
    {      0,   31,    0,  4,  0,  3 }, {     -1,   32,    0,  4,  0,  3 }, {     -2,   33,    0,  4,  0,  3 }, {     -3,   34,    0,  4,  0,  3 }, {     -4,   35,    0,  4,  0,  3 },
    {     -5,   36,    0,  4,  0,  3 }, {     -6,   37,    0,  4,  0,  3 }, {     -7,   38,    0,  4,  0,  3 }, {     -8,   39,    0,  4,  0,  3 }, {     -9,   40,    0,  4,  0,  4 },
    {    -10,   41,    0,  4,  0,  4 }, {    -11,   42,    0,  4,  0,  4 }, {    -12,   43,    0,  4,  0,  4 }, {    -13,   44,    0,  4,  0,  4 }, {    -14,   45,    0,  4,  0,  4 },
    {    -15,   46,    0,  4,  0,  4 }, {    -16,   47,    0,  4,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_957E28, {
    {     16,   16,    0, 12,  0,  0 }, {     17,   17,    0, 12,  0,  0 }, {     18,   18,    0, 12,  0,  0 }, {     19,   19,    0, 12,  0,  0 }, {     20,   20,    0, 12,  0,  0 },
    {     21,   21,    0, 12,  0,  0 }, {     22,   22,    0, 12,  0,  0 }, {     23,   23,    0, 12,  0,  0 }, {     24,   24,    0, 12,  0,  3 }, {     25,   25,    0, 12,  0,  3 },
    {     26,   26,    0, 12,  0,  3 }, {     27,   27,    0, 12,  0,  3 }, {     28,   28,    0, 12,  0,  3 }, {     29,   29,    0, 12,  0,  3 }, {     30,   30,    0, 12,  0,  3 },
    {     31,   31,    0, 12,  0,  3 }, {     32,   32,    0, 12,  0,  3 }, {     33,   33,    0, 12,  0,  3 }, {     34,   34,    0, 12,  0,  3 }, {     35,   35,    0, 12,  0,  3 },
    {     36,   36,    0, 12,  0,  3 }, {     37,   37,    0, 12,  0,  3 }, {     38,   38,    0, 12,  0,  3 }, {     39,   39,    0, 12,  0,  3 }, {     40,   40,    0, 12,  0,  4 },
    {     41,   41,    0, 12,  0,  4 }, {     42,   42,    0, 12,  0,  4 }, {     43,   43,    0, 12,  0,  4 }, {     44,   44,    0, 12,  0,  4 }, {     45,   45,    0, 12,  0,  4 },
    {     46,   46,    0, 12,  0,  4 }, {     47,   47,    0, 12,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_957F4A, {
    {     16,   15,    0, 20,  0,  0 }, {     17,   14,    0, 20,  0,  0 }, {     18,   13,    0, 20,  0,  0 }, {     19,   12,    0, 20,  0,  0 }, {     20,   11,    0, 20,  0,  0 },
    {     21,   10,    0, 20,  0,  0 }, {     22,    9,    0, 20,  0,  0 }, {     23,    8,    0, 20,  0,  0 }, {     24,    7,    0, 20,  0,  3 }, {     25,    6,    0, 20,  0,  3 },
    {     26,    5,    0, 20,  0,  3 }, {     27,    4,    0, 20,  0,  3 }, {     28,    3,    0, 20,  0,  3 }, {     29,    2,    0, 20,  0,  3 }, {     30,    1,    0, 20,  0,  3 },
    {     31,    0,    0, 20,  0,  3 }, {     32,   -1,    0, 20,  0,  3 }, {     33,   -2,    0, 20,  0,  3 }, {     34,   -3,    0, 20,  0,  3 }, {     35,   -4,    0, 20,  0,  3 },
    {     36,   -5,    0, 20,  0,  3 }, {     37,   -6,    0, 20,  0,  3 }, {     38,   -7,    0, 20,  0,  3 }, {     39,   -8,    0, 20,  0,  3 }, {     40,   -9,    0, 20,  0,  4 },
    {     41,  -10,    0, 20,  0,  4 }, {     42,  -11,    0, 20,  0,  4 }, {     43,  -12,    0, 20,  0,  4 }, {     44,  -13,    0, 20,  0,  4 }, {     45,  -14,    0, 20,  0,  4 },
    {     46,  -15,    0, 20,  0,  4 }, {     47,  -16,    0, 20,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95806C, {
    {     15,   15,    0, 28,  0,  0 }, {     14,   14,    0, 28,  0,  0 }, {     13,   13,    0, 28,  0,  0 }, {     12,   12,    0, 28,  0,  0 }, {     11,   11,    0, 28,  0,  0 },
    {     10,   10,    0, 28,  0,  0 }, {      9,    9,    0, 28,  0,  0 }, {      8,    8,    0, 28,  0,  0 }, {      7,    7,    0, 28,  0,  3 }, {      6,    6,    0, 28,  0,  3 },
    {      5,    5,    0, 28,  0,  3 }, {      4,    4,    0, 28,  0,  3 }, {      3,    3,    0, 28,  0,  3 }, {      2,    2,    0, 28,  0,  3 }, {      1,    1,    0, 28,  0,  3 },
    {      0,    0,    0, 28,  0,  3 }, {     -1,   -1,    0, 28,  0,  3 }, {     -2,   -2,    0, 28,  0,  3 }, {     -3,   -3,    0, 28,  0,  3 }, {     -4,   -4,    0, 28,  0,  3 },
    {     -5,   -5,    0, 28,  0,  3 }, {     -6,   -6,    0, 28,  0,  3 }, {     -7,   -7,    0, 28,  0,  3 }, {     -8,   -8,    0, 28,  0,  3 }, {     -9,   -9,    0, 28,  0,  4 },
    {    -10,  -10,    0, 28,  0,  4 }, {    -11,  -11,    0, 28,  0,  4 }, {    -12,  -12,    0, 28,  0,  4 }, {    -13,  -13,    0, 28,  0,  4 }, {    -14,  -14,    0, 28,  0,  4 },
    {    -15,  -15,    0, 28,  0,  4 }, {    -16,  -16,    0, 28,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95818E, {
    {     15,   16,    0,  4,  0,  2 }, {     14,   17,    0,  4,  0,  2 }, {     13,   18,    0,  4,  0,  2 }, {     12,   19,    0,  4,  0,  2 }, {     11,   20,    0,  4,  0,  2 },
    {     10,   21,    0,  4,  0,  2 }, {      9,   22,    0,  4,  0,  2 }, {      8,   23,    0,  4,  0,  2 }, {      7,   24,    0,  4,  0,  1 }, {      6,   25,    0,  4,  0,  1 },
    {      5,   26,    0,  4,  0,  1 }, {      4,   27,    0,  4,  0,  1 }, {      3,   28,    0,  4,  0,  1 }, {      2,   29,    0,  4,  0,  1 }, {      1,   30,    0,  4,  0,  1 },
    {      0,   31,    0,  4,  0,  1 }, {     -1,   32,    0,  4,  0,  1 }, {     -2,   33,    0,  4,  0,  1 }, {     -3,   34,    0,  4,  0,  1 }, {     -4,   35,    0,  4,  0,  1 },
    {     -5,   36,    0,  4,  0,  1 }, {     -6,   37,    0,  4,  0,  1 }, {     -7,   38,    0,  4,  0,  1 }, {     -8,   39,    0,  4,  0,  1 }, {     -9,   40,    0,  4,  0,  0 },
    {    -10,   41,    0,  4,  0,  0 }, {    -11,   42,    0,  4,  0,  0 }, {    -12,   43,    0,  4,  0,  0 }, {    -13,   44,    0,  4,  0,  0 }, {    -14,   45,    0,  4,  0,  0 },
    {    -15,   46,    0,  4,  0,  0 }, {    -16,   47,    0,  4,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9582B0, {
    {     16,   16,    0, 12,  0,  2 }, {     17,   17,    0, 12,  0,  2 }, {     18,   18,    0, 12,  0,  2 }, {     19,   19,    0, 12,  0,  2 }, {     20,   20,    0, 12,  0,  2 },
    {     21,   21,    0, 12,  0,  2 }, {     22,   22,    0, 12,  0,  2 }, {     23,   23,    0, 12,  0,  2 }, {     24,   24,    0, 12,  0,  1 }, {     25,   25,    0, 12,  0,  1 },
    {     26,   26,    0, 12,  0,  1 }, {     27,   27,    0, 12,  0,  1 }, {     28,   28,    0, 12,  0,  1 }, {     29,   29,    0, 12,  0,  1 }, {     30,   30,    0, 12,  0,  1 },
    {     31,   31,    0, 12,  0,  1 }, {     32,   32,    0, 12,  0,  1 }, {     33,   33,    0, 12,  0,  1 }, {     34,   34,    0, 12,  0,  1 }, {     35,   35,    0, 12,  0,  1 },
    {     36,   36,    0, 12,  0,  1 }, {     37,   37,    0, 12,  0,  1 }, {     38,   38,    0, 12,  0,  1 }, {     39,   39,    0, 12,  0,  1 }, {     40,   40,    0, 12,  0,  0 },
    {     41,   41,    0, 12,  0,  0 }, {     42,   42,    0, 12,  0,  0 }, {     43,   43,    0, 12,  0,  0 }, {     44,   44,    0, 12,  0,  0 }, {     45,   45,    0, 12,  0,  0 },
    {     46,   46,    0, 12,  0,  0 }, {     47,   47,    0, 12,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9583D2, {
    {     16,   15,    0, 20,  0,  2 }, {     17,   14,    0, 20,  0,  2 }, {     18,   13,    0, 20,  0,  2 }, {     19,   12,    0, 20,  0,  2 }, {     20,   11,    0, 20,  0,  2 },
    {     21,   10,    0, 20,  0,  2 }, {     22,    9,    0, 20,  0,  2 }, {     23,    8,    0, 20,  0,  2 }, {     24,    7,    0, 20,  0,  1 }, {     25,    6,    0, 20,  0,  1 },
    {     26,    5,    0, 20,  0,  1 }, {     27,    4,    0, 20,  0,  1 }, {     28,    3,    0, 20,  0,  1 }, {     29,    2,    0, 20,  0,  1 }, {     30,    1,    0, 20,  0,  1 },
    {     31,    0,    0, 20,  0,  1 }, {     32,   -1,    0, 20,  0,  1 }, {     33,   -2,    0, 20,  0,  1 }, {     34,   -3,    0, 20,  0,  1 }, {     35,   -4,    0, 20,  0,  1 },
    {     36,   -5,    0, 20,  0,  1 }, {     37,   -6,    0, 20,  0,  1 }, {     38,   -7,    0, 20,  0,  1 }, {     39,   -8,    0, 20,  0,  1 }, {     40,   -9,    0, 20,  0,  0 },
    {     41,  -10,    0, 20,  0,  0 }, {     42,  -11,    0, 20,  0,  0 }, {     43,  -12,    0, 20,  0,  0 }, {     44,  -13,    0, 20,  0,  0 }, {     45,  -14,    0, 20,  0,  0 },
    {     46,  -15,    0, 20,  0,  0 }, {     47,  -16,    0, 20,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9584F4, {
    {     15,   15,    0, 28,  0,  2 }, {     14,   14,    0, 28,  0,  2 }, {     13,   13,    0, 28,  0,  2 }, {     12,   12,    0, 28,  0,  2 }, {     11,   11,    0, 28,  0,  2 },
    {     10,   10,    0, 28,  0,  2 }, {      9,    9,    0, 28,  0,  2 }, {      8,    8,    0, 28,  0,  2 }, {      7,    7,    0, 28,  0,  1 }, {      6,    6,    0, 28,  0,  1 },
    {      5,    5,    0, 28,  0,  1 }, {      4,    4,    0, 28,  0,  1 }, {      3,    3,    0, 28,  0,  1 }, {      2,    2,    0, 28,  0,  1 }, {      1,    1,    0, 28,  0,  1 },
    {      0,    0,    0, 28,  0,  1 }, {     -1,   -1,    0, 28,  0,  1 }, {     -2,   -2,    0, 28,  0,  1 }, {     -3,   -3,    0, 28,  0,  1 }, {     -4,   -4,    0, 28,  0,  1 },
    {     -5,   -5,    0, 28,  0,  1 }, {     -6,   -6,    0, 28,  0,  1 }, {     -7,   -7,    0, 28,  0,  1 }, {     -8,   -8,    0, 28,  0,  1 }, {     -9,   -9,    0, 28,  0,  0 },
    {    -10,  -10,    0, 28,  0,  0 }, {    -11,  -11,    0, 28,  0,  0 }, {    -12,  -12,    0, 28,  0,  0 }, {    -13,  -13,    0, 28,  0,  0 }, {    -14,  -14,    0, 28,  0,  0 },
    {    -15,  -15,    0, 28,  0,  0 }, {    -16,  -16,    0, 28,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_958616, {
    {     15,   16,    0,  4,  0,  4 }, {     14,   17,    0,  4,  0,  4 }, {     13,   18,    0,  4,  0,  4 }, {     12,   19,    0,  4,  0,  4 }, {     11,   20,    0,  4,  0,  4 },
    {     10,   21,    0,  4,  0,  4 }, {      9,   22,    0,  4,  0,  4 }, {      8,   23,    0,  4,  0,  4 }, {      7,   24,    0,  4,  0,  3 }, {      6,   25,    0,  4,  0,  3 },
    {      5,   26,    0,  4,  0,  3 }, {      4,   27,    0,  4,  0,  3 }, {      3,   28,    0,  4,  0,  3 }, {      2,   29,    0,  4,  0,  3 }, {      1,   30,    0,  4,  0,  3 },
    {      0,   31,    0,  4,  0,  3 }, {     -1,   32,    0,  4,  0,  3 }, {     -2,   33,    0,  4,  0,  3 }, {     -3,   34,    0,  4,  0,  3 }, {     -4,   35,    0,  4,  0,  3 },
    {     -5,   36,    0,  4,  0,  3 }, {     -6,   37,    0,  4,  0,  3 }, {     -7,   38,    0,  4,  0,  3 }, {     -8,   39,    0,  4,  0,  3 }, {     -9,   40,    0,  4,  0,  0 },
    {    -10,   41,    0,  4,  0,  0 }, {    -11,   42,    0,  4,  0,  0 }, {    -12,   43,    0,  4,  0,  0 }, {    -13,   44,    0,  4,  0,  0 }, {    -14,   45,    0,  4,  0,  0 },
    {    -15,   46,    0,  4,  0,  0 }, {    -16,   47,    0,  4,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_958738, {
    {     16,   16,    0, 12,  0,  4 }, {     17,   17,    0, 12,  0,  4 }, {     18,   18,    0, 12,  0,  4 }, {     19,   19,    0, 12,  0,  4 }, {     20,   20,    0, 12,  0,  4 },
    {     21,   21,    0, 12,  0,  4 }, {     22,   22,    0, 12,  0,  4 }, {     23,   23,    0, 12,  0,  4 }, {     24,   24,    0, 12,  0,  3 }, {     25,   25,    0, 12,  0,  3 },
    {     26,   26,    0, 12,  0,  3 }, {     27,   27,    0, 12,  0,  3 }, {     28,   28,    0, 12,  0,  3 }, {     29,   29,    0, 12,  0,  3 }, {     30,   30,    0, 12,  0,  3 },
    {     31,   31,    0, 12,  0,  3 }, {     32,   32,    0, 12,  0,  3 }, {     33,   33,    0, 12,  0,  3 }, {     34,   34,    0, 12,  0,  3 }, {     35,   35,    0, 12,  0,  3 },
    {     36,   36,    0, 12,  0,  3 }, {     37,   37,    0, 12,  0,  3 }, {     38,   38,    0, 12,  0,  3 }, {     39,   39,    0, 12,  0,  3 }, {     40,   40,    0, 12,  0,  0 },
    {     41,   41,    0, 12,  0,  0 }, {     42,   42,    0, 12,  0,  0 }, {     43,   43,    0, 12,  0,  0 }, {     44,   44,    0, 12,  0,  0 }, {     45,   45,    0, 12,  0,  0 },
    {     46,   46,    0, 12,  0,  0 }, {     47,   47,    0, 12,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95885A, {
    {     16,   15,    0, 20,  0,  4 }, {     17,   14,    0, 20,  0,  4 }, {     18,   13,    0, 20,  0,  4 }, {     19,   12,    0, 20,  0,  4 }, {     20,   11,    0, 20,  0,  4 },
    {     21,   10,    0, 20,  0,  4 }, {     22,    9,    0, 20,  0,  4 }, {     23,    8,    0, 20,  0,  4 }, {     24,    7,    0, 20,  0,  3 }, {     25,    6,    0, 20,  0,  3 },
    {     26,    5,    0, 20,  0,  3 }, {     27,    4,    0, 20,  0,  3 }, {     28,    3,    0, 20,  0,  3 }, {     29,    2,    0, 20,  0,  3 }, {     30,    1,    0, 20,  0,  3 },
    {     31,    0,    0, 20,  0,  3 }, {     32,   -1,    0, 20,  0,  3 }, {     33,   -2,    0, 20,  0,  3 }, {     34,   -3,    0, 20,  0,  3 }, {     35,   -4,    0, 20,  0,  3 },
    {     36,   -5,    0, 20,  0,  3 }, {     37,   -6,    0, 20,  0,  3 }, {     38,   -7,    0, 20,  0,  3 }, {     39,   -8,    0, 20,  0,  3 }, {     40,   -9,    0, 20,  0,  0 },
    {     41,  -10,    0, 20,  0,  0 }, {     42,  -11,    0, 20,  0,  0 }, {     43,  -12,    0, 20,  0,  0 }, {     44,  -13,    0, 20,  0,  0 }, {     45,  -14,    0, 20,  0,  0 },
    {     46,  -15,    0, 20,  0,  0 }, {     47,  -16,    0, 20,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95897C, {
    {     15,   15,    0, 28,  0,  4 }, {     14,   14,    0, 28,  0,  4 }, {     13,   13,    0, 28,  0,  4 }, {     12,   12,    0, 28,  0,  4 }, {     11,   11,    0, 28,  0,  4 },
    {     10,   10,    0, 28,  0,  4 }, {      9,    9,    0, 28,  0,  4 }, {      8,    8,    0, 28,  0,  4 }, {      7,    7,    0, 28,  0,  3 }, {      6,    6,    0, 28,  0,  3 },
    {      5,    5,    0, 28,  0,  3 }, {      4,    4,    0, 28,  0,  3 }, {      3,    3,    0, 28,  0,  3 }, {      2,    2,    0, 28,  0,  3 }, {      1,    1,    0, 28,  0,  3 },
    {      0,    0,    0, 28,  0,  3 }, {     -1,   -1,    0, 28,  0,  3 }, {     -2,   -2,    0, 28,  0,  3 }, {     -3,   -3,    0, 28,  0,  3 }, {     -4,   -4,    0, 28,  0,  3 },
    {     -5,   -5,    0, 28,  0,  3 }, {     -6,   -6,    0, 28,  0,  3 }, {     -7,   -7,    0, 28,  0,  3 }, {     -8,   -8,    0, 28,  0,  3 }, {     -9,   -9,    0, 28,  0,  0 },
    {    -10,  -10,    0, 28,  0,  0 }, {    -11,  -11,    0, 28,  0,  0 }, {    -12,  -12,    0, 28,  0,  0 }, {    -13,  -13,    0, 28,  0,  0 }, {    -14,  -14,    0, 28,  0,  0 },
    {    -15,  -15,    0, 28,  0,  0 }, {    -16,  -16,    0, 28,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_958A9E, {
    {     15,   16,    0,  4,  0,  2 }, {     14,   17,    0,  4,  0,  2 }, {     13,   18,    0,  4,  0,  2 }, {     12,   19,    0,  4,  0,  2 }, {     11,   20,    0,  4,  0,  2 },
    {     10,   21,    0,  4,  0,  2 }, {      9,   22,    0,  4,  0,  2 }, {      8,   23,    0,  4,  0,  2 }, {      7,   24,    0,  4, 50,  1 }, {      6,   25,    0,  4, 50,  1 },
    {      5,   26,    1,  4, 50,  1 }, {      4,   27,    1,  4, 50,  1 }, {      3,   28,    1,  4, 50,  1 }, {      2,   29,    1,  4, 50,  1 }, {      1,   30,    1,  4, 50,  1 },
    {      0,   31,    1,  4, 50,  1 }, {     -1,   32,    2,  4, 50,  1 }, {     -2,   33,    2,  4, 50,  1 }, {     -3,   34,    2,  4, 50,  1 }, {     -4,   35,    2,  4, 50,  1 },
    {     -5,   36,    3,  4, 50,  1 }, {     -6,   37,    3,  4, 50,  1 }, {     -7,   38,    3,  4, 50,  1 }, {     -8,   39,    4,  4, 50,  1 }, {     -9,   40,    4,  4, 51,  0 },
    {    -10,   41,    4,  4, 51,  0 }, {    -11,   42,    5,  4, 51,  0 }, {    -12,   43,    5,  4, 51,  0 }, {    -13,   44,    6,  4, 51,  0 }, {    -14,   45,    6,  4, 51,  0 },
    {    -15,   46,    7,  4, 51,  0 }, {    -16,   47,    7,  4, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_958BC0, {
    {     16,   16,    0, 12,  0,  2 }, {     17,   17,    0, 12,  0,  2 }, {     18,   18,    0, 12,  0,  2 }, {     19,   19,    0, 12,  0,  2 }, {     20,   20,    0, 12,  0,  2 },
    {     21,   21,    0, 12,  0,  2 }, {     22,   22,    0, 12,  0,  2 }, {     23,   23,    0, 12,  0,  2 }, {     24,   24,    0, 12, 50,  1 }, {     25,   25,    0, 12, 50,  1 },
    {     26,   26,    1, 12, 50,  1 }, {     27,   27,    1, 12, 50,  1 }, {     28,   28,    1, 12, 50,  1 }, {     29,   29,    1, 12, 50,  1 }, {     30,   30,    1, 12, 50,  1 },
    {     31,   31,    1, 12, 50,  1 }, {     32,   32,    2, 12, 50,  1 }, {     33,   33,    2, 12, 50,  1 }, {     34,   34,    2, 12, 50,  1 }, {     35,   35,    2, 12, 50,  1 },
    {     36,   36,    3, 12, 50,  1 }, {     37,   37,    3, 12, 50,  1 }, {     38,   38,    3, 12, 50,  1 }, {     39,   39,    4, 12, 50,  1 }, {     40,   40,    4, 12, 51,  0 },
    {     41,   41,    4, 12, 51,  0 }, {     42,   42,    5, 12, 51,  0 }, {     43,   43,    5, 12, 51,  0 }, {     44,   44,    6, 12, 51,  0 }, {     45,   45,    6, 12, 51,  0 },
    {     46,   46,    7, 12, 51,  0 }, {     47,   47,    7, 12, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_958CE2, {
    {     16,   15,    0, 20,  0,  2 }, {     17,   14,    0, 20,  0,  2 }, {     18,   13,    0, 20,  0,  2 }, {     19,   12,    0, 20,  0,  2 }, {     20,   11,    0, 20,  0,  2 },
    {     21,   10,    0, 20,  0,  2 }, {     22,    9,    0, 20,  0,  2 }, {     23,    8,    0, 20,  0,  2 }, {     24,    7,    0, 20, 50,  1 }, {     25,    6,    0, 20, 50,  1 },
    {     26,    5,    1, 20, 50,  1 }, {     27,    4,    1, 20, 50,  1 }, {     28,    3,    1, 20, 50,  1 }, {     29,    2,    1, 20, 50,  1 }, {     30,    1,    1, 20, 50,  1 },
    {     31,    0,    1, 20, 50,  1 }, {     32,   -1,    2, 20, 50,  1 }, {     33,   -2,    2, 20, 50,  1 }, {     34,   -3,    2, 20, 50,  1 }, {     35,   -4,    2, 20, 50,  1 },
    {     36,   -5,    3, 20, 50,  1 }, {     37,   -6,    3, 20, 50,  1 }, {     38,   -7,    3, 20, 50,  1 }, {     39,   -8,    4, 20, 50,  1 }, {     40,   -9,    4, 20, 51,  0 },
    {     41,  -10,    4, 20, 51,  0 }, {     42,  -11,    5, 20, 51,  0 }, {     43,  -12,    5, 20, 51,  0 }, {     44,  -13,    6, 20, 51,  0 }, {     45,  -14,    6, 20, 51,  0 },
    {     46,  -15,    7, 20, 51,  0 }, {     47,  -16,    7, 20, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_958E04, {
    {     15,   15,    0, 28,  0,  2 }, {     14,   14,    0, 28,  0,  2 }, {     13,   13,    0, 28,  0,  2 }, {     12,   12,    0, 28,  0,  2 }, {     11,   11,    0, 28,  0,  2 },
    {     10,   10,    0, 28,  0,  2 }, {      9,    9,    0, 28,  0,  2 }, {      8,    8,    0, 28,  0,  2 }, {      7,    7,    0, 28, 50,  1 }, {      6,    6,    0, 28, 50,  1 },
    {      5,    5,    1, 28, 50,  1 }, {      4,    4,    1, 28, 50,  1 }, {      3,    3,    1, 28, 50,  1 }, {      2,    2,    1, 28, 50,  1 }, {      1,    1,    1, 28, 50,  1 },
    {      0,    0,    1, 28, 50,  1 }, {     -1,   -1,    2, 28, 50,  1 }, {     -2,   -2,    2, 28, 50,  1 }, {     -3,   -3,    2, 28, 50,  1 }, {     -4,   -4,    2, 28, 50,  1 },
    {     -5,   -5,    3, 28, 50,  1 }, {     -6,   -6,    3, 28, 50,  1 }, {     -7,   -7,    3, 28, 50,  1 }, {     -8,   -8,    4, 28, 50,  1 }, {     -9,   -9,    4, 28, 51,  0 },
    {    -10,  -10,    4, 28, 51,  0 }, {    -11,  -11,    5, 28, 51,  0 }, {    -12,  -12,    5, 28, 51,  0 }, {    -13,  -13,    6, 28, 51,  0 }, {    -14,  -14,    6, 28, 51,  0 },
    {    -15,  -15,    7, 28, 51,  0 }, {    -16,  -16,    7, 28, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_958F26, {
    {     15,   16,    0,  4,  0,  4 }, {     14,   17,    0,  4,  0,  4 }, {     13,   18,    0,  4,  0,  4 }, {     12,   19,    0,  4,  0,  4 }, {     11,   20,    0,  4,  0,  4 },
    {     10,   21,    0,  4,  0,  4 }, {      9,   22,    0,  4,  0,  4 }, {      8,   23,    0,  4,  0,  4 }, {      7,   24,    0,  4, 50,  3 }, {      6,   25,    0,  4, 50,  3 },
    {      5,   26,    1,  4, 50,  3 }, {      4,   27,    1,  4, 50,  3 }, {      3,   28,    1,  4, 50,  3 }, {      2,   29,    1,  4, 50,  3 }, {      1,   30,    1,  4, 50,  3 },
    {      0,   31,    1,  4, 50,  3 }, {     -1,   32,    2,  4, 50,  3 }, {     -2,   33,    2,  4, 50,  3 }, {     -3,   34,    2,  4, 50,  3 }, {     -4,   35,    2,  4, 50,  3 },
    {     -5,   36,    3,  4, 50,  3 }, {     -6,   37,    3,  4, 50,  3 }, {     -7,   38,    3,  4, 50,  3 }, {     -8,   39,    4,  4, 50,  3 }, {     -9,   40,    4,  4, 51,  0 },
    {    -10,   41,    4,  4, 51,  0 }, {    -11,   42,    5,  4, 51,  0 }, {    -12,   43,    5,  4, 51,  0 }, {    -13,   44,    6,  4, 51,  0 }, {    -14,   45,    6,  4, 51,  0 },
    {    -15,   46,    7,  4, 51,  0 }, {    -16,   47,    7,  4, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_959048, {
    {     16,   16,    0, 12,  0,  4 }, {     17,   17,    0, 12,  0,  4 }, {     18,   18,    0, 12,  0,  4 }, {     19,   19,    0, 12,  0,  4 }, {     20,   20,    0, 12,  0,  4 },
    {     21,   21,    0, 12,  0,  4 }, {     22,   22,    0, 12,  0,  4 }, {     23,   23,    0, 12,  0,  4 }, {     24,   24,    0, 12, 50,  3 }, {     25,   25,    0, 12, 50,  3 },
    {     26,   26,    1, 12, 50,  3 }, {     27,   27,    1, 12, 50,  3 }, {     28,   28,    1, 12, 50,  3 }, {     29,   29,    1, 12, 50,  3 }, {     30,   30,    1, 12, 50,  3 },
    {     31,   31,    1, 12, 50,  3 }, {     32,   32,    2, 12, 50,  3 }, {     33,   33,    2, 12, 50,  3 }, {     34,   34,    2, 12, 50,  3 }, {     35,   35,    2, 12, 50,  3 },
    {     36,   36,    3, 12, 50,  3 }, {     37,   37,    3, 12, 50,  3 }, {     38,   38,    3, 12, 50,  3 }, {     39,   39,    4, 12, 50,  3 }, {     40,   40,    4, 12, 51,  0 },
    {     41,   41,    4, 12, 51,  0 }, {     42,   42,    5, 12, 51,  0 }, {     43,   43,    5, 12, 51,  0 }, {     44,   44,    6, 12, 51,  0 }, {     45,   45,    6, 12, 51,  0 },
    {     46,   46,    7, 12, 51,  0 }, {     47,   47,    7, 12, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95916A, {
    {     16,   15,    0, 20,  0,  4 }, {     17,   14,    0, 20,  0,  4 }, {     18,   13,    0, 20,  0,  4 }, {     19,   12,    0, 20,  0,  4 }, {     20,   11,    0, 20,  0,  4 },
    {     21,   10,    0, 20,  0,  4 }, {     22,    9,    0, 20,  0,  4 }, {     23,    8,    0, 20,  0,  4 }, {     24,    7,    0, 20, 50,  3 }, {     25,    6,    0, 20, 50,  3 },
    {     26,    5,    1, 20, 50,  3 }, {     27,    4,    1, 20, 50,  3 }, {     28,    3,    1, 20, 50,  3 }, {     29,    2,    1, 20, 50,  3 }, {     30,    1,    1, 20, 50,  3 },
    {     31,    0,    1, 20, 50,  3 }, {     32,   -1,    2, 20, 50,  3 }, {     33,   -2,    2, 20, 50,  3 }, {     34,   -3,    2, 20, 50,  3 }, {     35,   -4,    2, 20, 50,  3 },
    {     36,   -5,    3, 20, 50,  3 }, {     37,   -6,    3, 20, 50,  3 }, {     38,   -7,    3, 20, 50,  3 }, {     39,   -8,    4, 20, 50,  3 }, {     40,   -9,    4, 20, 51,  0 },
    {     41,  -10,    4, 20, 51,  0 }, {     42,  -11,    5, 20, 51,  0 }, {     43,  -12,    5, 20, 51,  0 }, {     44,  -13,    6, 20, 51,  0 }, {     45,  -14,    6, 20, 51,  0 },
    {     46,  -15,    7, 20, 51,  0 }, {     47,  -16,    7, 20, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95928C, {
    {     15,   15,    0, 28,  0,  4 }, {     14,   14,    0, 28,  0,  4 }, {     13,   13,    0, 28,  0,  4 }, {     12,   12,    0, 28,  0,  4 }, {     11,   11,    0, 28,  0,  4 },
    {     10,   10,    0, 28,  0,  4 }, {      9,    9,    0, 28,  0,  4 }, {      8,    8,    0, 28,  0,  4 }, {      7,    7,    0, 28, 50,  3 }, {      6,    6,    0, 28, 50,  3 },
    {      5,    5,    1, 28, 50,  3 }, {      4,    4,    1, 28, 50,  3 }, {      3,    3,    1, 28, 50,  3 }, {      2,    2,    1, 28, 50,  3 }, {      1,    1,    1, 28, 50,  3 },
    {      0,    0,    1, 28, 50,  3 }, {     -1,   -1,    2, 28, 50,  3 }, {     -2,   -2,    2, 28, 50,  3 }, {     -3,   -3,    2, 28, 50,  3 }, {     -4,   -4,    2, 28, 50,  3 },
    {     -5,   -5,    3, 28, 50,  3 }, {     -6,   -6,    3, 28, 50,  3 }, {     -7,   -7,    3, 28, 50,  3 }, {     -8,   -8,    4, 28, 50,  3 }, {     -9,   -9,    4, 28, 51,  0 },
    {    -10,  -10,    4, 28, 51,  0 }, {    -11,  -11,    5, 28, 51,  0 }, {    -12,  -12,    5, 28, 51,  0 }, {    -13,  -13,    6, 28, 51,  0 }, {    -14,  -14,    6, 28, 51,  0 },
    {    -15,  -15,    7, 28, 51,  0 }, {    -16,  -16,    7, 28, 51,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9593AE, {
    {     15,   16,    0,  4, 51,  0 }, {     14,   17,    0,  4, 51,  0 }, {     13,   18,    1,  4, 51,  0 }, {     12,   19,    1,  4, 51,  0 }, {     11,   20,    2,  4, 51,  0 },
    {     10,   21,    2,  4, 51,  0 }, {      9,   22,    3,  4, 51,  0 }, {      8,   23,    3,  4, 51,  0 }, {      7,   24,    4,  4, 50,  1 }, {      6,   25,    4,  4, 50,  1 },
    {      5,   26,    4,  4, 50,  1 }, {      4,   27,    5,  4, 50,  1 }, {      3,   28,    5,  4, 50,  1 }, {      2,   29,    5,  4, 50,  1 }, {      1,   30,    6,  4, 50,  1 },
    {      0,   31,    6,  4, 50,  1 }, {     -1,   32,    6,  4, 50,  1 }, {     -2,   33,    6,  4, 50,  1 }, {     -3,   34,    7,  4, 50,  1 }, {     -4,   35,    7,  4, 50,  1 },
    {     -5,   36,    7,  4, 50,  1 }, {     -6,   37,    7,  4, 50,  1 }, {     -7,   38,    7,  4,  0,  2 }, {     -8,   39,    7,  4,  0,  2 }, {     -9,   40,    8,  4,  0,  2 },
    {    -10,   41,    8,  4,  0,  2 }, {    -11,   42,    8,  4,  0,  2 }, {    -12,   43,    8,  4,  0,  2 }, {    -13,   44,    8,  4,  0,  2 }, {    -14,   45,    8,  4,  0,  2 },
    {    -15,   46,    8,  4,  0,  2 }, {    -16,   47,    8,  4,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9594E2, {
    {     16,   16,    0, 12, 51,  0 }, {     17,   17,    0, 12, 51,  0 }, {     18,   18,    1, 12, 51,  0 }, {     19,   19,    1, 12, 51,  0 }, {     20,   20,    2, 12, 51,  0 },
    {     21,   21,    2, 12, 51,  0 }, {     22,   22,    3, 12, 51,  0 }, {     23,   23,    3, 12, 51,  0 }, {     24,   24,    4, 12, 50,  1 }, {     25,   25,    4, 12, 50,  1 },
    {     26,   26,    4, 12, 50,  1 }, {     27,   27,    5, 12, 50,  1 }, {     28,   28,    5, 12, 50,  1 }, {     29,   29,    5, 12, 50,  1 }, {     30,   30,    6, 12, 50,  1 },
    {     31,   31,    6, 12, 50,  1 }, {     32,   32,    6, 12, 50,  1 }, {     33,   33,    6, 12, 50,  1 }, {     34,   34,    7, 12, 50,  1 }, {     35,   35,    7, 12, 50,  1 },
    {     36,   36,    7, 12, 50,  1 }, {     37,   37,    7, 12, 50,  1 }, {     38,   38,    7, 12,  0,  2 }, {     39,   39,    7, 12,  0,  2 }, {     40,   40,    8, 12,  0,  2 },
    {     41,   41,    8, 12,  0,  2 }, {     42,   42,    8, 12,  0,  2 }, {     43,   43,    8, 12,  0,  2 }, {     44,   44,    8, 12,  0,  2 }, {     45,   45,    8, 12,  0,  2 },
    {     46,   46,    8, 12,  0,  2 }, {     47,   47,    8, 12,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_959616, {
    {     16,   15,    0, 20, 51,  0 }, {     17,   14,    0, 20, 51,  0 }, {     18,   13,    1, 20, 51,  0 }, {     19,   12,    1, 20, 51,  0 }, {     20,   11,    2, 20, 51,  0 },
    {     21,   10,    2, 20, 51,  0 }, {     22,    9,    3, 20, 51,  0 }, {     23,    8,    3, 20, 51,  0 }, {     24,    7,    4, 20, 50,  1 }, {     25,    6,    4, 20, 50,  1 },
    {     26,    5,    4, 20, 50,  1 }, {     27,    4,    5, 20, 50,  1 }, {     28,    3,    5, 20, 50,  1 }, {     29,    2,    5, 20, 50,  1 }, {     30,    1,    6, 20, 50,  1 },
    {     31,    0,    6, 20, 50,  1 }, {     32,   -1,    6, 20, 50,  1 }, {     33,   -2,    6, 20, 50,  1 }, {     34,   -3,    7, 20, 50,  1 }, {     35,   -4,    7, 20, 50,  1 },
    {     36,   -5,    7, 20, 50,  1 }, {     37,   -6,    7, 20, 50,  1 }, {     38,   -7,    7, 20,  0,  2 }, {     39,   -8,    7, 20,  0,  2 }, {     40,   -9,    8, 20,  0,  2 },
    {     41,  -10,    8, 20,  0,  2 }, {     42,  -11,    8, 20,  0,  2 }, {     43,  -12,    8, 20,  0,  2 }, {     44,  -13,    8, 20,  0,  2 }, {     45,  -14,    8, 20,  0,  2 },
    {     46,  -15,    8, 20,  0,  2 }, {     47,  -16,    8, 20,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95974A, {
    {     15,   15,    0, 28, 51,  0 }, {     14,   14,    0, 28, 51,  0 }, {     13,   13,    1, 28, 51,  0 }, {     12,   12,    1, 28, 51,  0 }, {     11,   11,    2, 28, 51,  0 },
    {     10,   10,    2, 28, 51,  0 }, {      9,    9,    3, 28, 51,  0 }, {      8,    8,    3, 28, 51,  0 }, {      7,    7,    4, 28, 50,  1 }, {      6,    6,    4, 28, 50,  1 },
    {      5,    5,    4, 28, 50,  1 }, {      4,    4,    5, 28, 50,  1 }, {      3,    3,    5, 28, 50,  1 }, {      2,    2,    5, 28, 50,  1 }, {      1,    1,    6, 28, 50,  1 },
    {      0,    0,    6, 28, 50,  1 }, {     -1,   -1,    6, 28, 50,  1 }, {     -2,   -2,    6, 28, 50,  1 }, {     -3,   -3,    7, 28, 50,  1 }, {     -4,   -4,    7, 28, 50,  1 },
    {     -5,   -5,    7, 28, 50,  1 }, {     -6,   -6,    7, 28, 50,  1 }, {     -7,   -7,    7, 28,  0,  2 }, {     -8,   -8,    7, 28,  0,  2 }, {     -9,   -9,    8, 28,  0,  2 },
    {    -10,  -10,    8, 28,  0,  2 }, {    -11,  -11,    8, 28,  0,  2 }, {    -12,  -12,    8, 28,  0,  2 }, {    -13,  -13,    8, 28,  0,  2 }, {    -14,  -14,    8, 28,  0,  2 },
    {    -15,  -15,    8, 28,  0,  2 }, {    -16,  -16,    8, 28,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95987E, {
    {     15,   16,    0,  4, 51,  0 }, {     14,   17,    0,  4, 51,  0 }, {     13,   18,    1,  4, 51,  0 }, {     12,   19,    1,  4, 51,  0 }, {     11,   20,    2,  4, 51,  0 },
    {     10,   21,    2,  4, 51,  0 }, {      9,   22,    3,  4, 51,  0 }, {      8,   23,    3,  4, 51,  0 }, {      7,   24,    4,  4, 50,  3 }, {      6,   25,    4,  4, 50,  3 },
    {      5,   26,    4,  4, 50,  3 }, {      4,   27,    5,  4, 50,  3 }, {      3,   28,    5,  4, 50,  3 }, {      2,   29,    5,  4, 50,  3 }, {      1,   30,    6,  4, 50,  3 },
    {      0,   31,    6,  4, 50,  3 }, {     -1,   32,    6,  4, 50,  3 }, {     -2,   33,    6,  4, 50,  3 }, {     -3,   34,    7,  4, 50,  3 }, {     -4,   35,    7,  4, 50,  3 },
    {     -5,   36,    7,  4, 50,  3 }, {     -6,   37,    7,  4, 50,  3 }, {     -7,   38,    7,  4,  0,  4 }, {     -8,   39,    7,  4,  0,  4 }, {     -9,   40,    8,  4,  0,  4 },
    {    -10,   41,    8,  4,  0,  4 }, {    -11,   42,    8,  4,  0,  4 }, {    -12,   43,    8,  4,  0,  4 }, {    -13,   44,    8,  4,  0,  4 }, {    -14,   45,    8,  4,  0,  4 },
    {    -15,   46,    8,  4,  0,  4 }, {    -16,   47,    8,  4,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9599B2, {
    {     16,   16,    0, 12, 51,  0 }, {     17,   17,    0, 12, 51,  0 }, {     18,   18,    1, 12, 51,  0 }, {     19,   19,    1, 12, 51,  0 }, {     20,   20,    2, 12, 51,  0 },
    {     21,   21,    2, 12, 51,  0 }, {     22,   22,    3, 12, 51,  0 }, {     23,   23,    3, 12, 51,  0 }, {     24,   24,    4, 12, 50,  3 }, {     25,   25,    4, 12, 50,  3 },
    {     26,   26,    4, 12, 50,  3 }, {     27,   27,    5, 12, 50,  3 }, {     28,   28,    5, 12, 50,  3 }, {     29,   29,    5, 12, 50,  3 }, {     30,   30,    6, 12, 50,  3 },
    {     31,   31,    6, 12, 50,  3 }, {     32,   32,    6, 12, 50,  3 }, {     33,   33,    6, 12, 50,  3 }, {     34,   34,    7, 12, 50,  3 }, {     35,   35,    7, 12, 50,  3 },
    {     36,   36,    7, 12, 50,  3 }, {     37,   37,    7, 12, 50,  3 }, {     38,   38,    7, 12,  0,  4 }, {     39,   39,    7, 12,  0,  4 }, {     40,   40,    8, 12,  0,  4 },
    {     41,   41,    8, 12,  0,  4 }, {     42,   42,    8, 12,  0,  4 }, {     43,   43,    8, 12,  0,  4 }, {     44,   44,    8, 12,  0,  4 }, {     45,   45,    8, 12,  0,  4 },
    {     46,   46,    8, 12,  0,  4 }, {     47,   47,    8, 12,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_959AE6, {
    {     16,   15,    0, 20, 51,  0 }, {     17,   14,    0, 20, 51,  0 }, {     18,   13,    1, 20, 51,  0 }, {     19,   12,    1, 20, 51,  0 }, {     20,   11,    2, 20, 51,  0 },
    {     21,   10,    2, 20, 51,  0 }, {     22,    9,    3, 20, 51,  0 }, {     23,    8,    3, 20, 51,  0 }, {     24,    7,    4, 20, 50,  3 }, {     25,    6,    4, 20, 50,  3 },
    {     26,    5,    4, 20, 50,  3 }, {     27,    4,    5, 20, 50,  3 }, {     28,    3,    5, 20, 50,  3 }, {     29,    2,    5, 20, 50,  3 }, {     30,    1,    6, 20, 50,  3 },
    {     31,    0,    6, 20, 50,  3 }, {     32,   -1,    6, 20, 50,  3 }, {     33,   -2,    6, 20, 50,  3 }, {     34,   -3,    7, 20, 50,  3 }, {     35,   -4,    7, 20, 50,  3 },
    {     36,   -5,    7, 20, 50,  3 }, {     37,   -6,    7, 20, 50,  3 }, {     38,   -7,    7, 20,  0,  4 }, {     39,   -8,    7, 20,  0,  4 }, {     40,   -9,    8, 20,  0,  4 },
    {     41,  -10,    8, 20,  0,  4 }, {     42,  -11,    8, 20,  0,  4 }, {     43,  -12,    8, 20,  0,  4 }, {     44,  -13,    8, 20,  0,  4 }, {     45,  -14,    8, 20,  0,  4 },
    {     46,  -15,    8, 20,  0,  4 }, {     47,  -16,    8, 20,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_959C1A, {
    {     15,   15,    0, 28, 51,  0 }, {     14,   14,    0, 28, 51,  0 }, {     13,   13,    1, 28, 51,  0 }, {     12,   12,    1, 28, 51,  0 }, {     11,   11,    2, 28, 51,  0 },
    {     10,   10,    2, 28, 51,  0 }, {      9,    9,    3, 28, 51,  0 }, {      8,    8,    3, 28, 51,  0 }, {      7,    7,    4, 28, 50,  3 }, {      6,    6,    4, 28, 50,  3 },
    {      5,    5,    4, 28, 50,  3 }, {      4,    4,    5, 28, 50,  3 }, {      3,    3,    5, 28, 50,  3 }, {      2,    2,    5, 28, 50,  3 }, {      1,    1,    6, 28, 50,  3 },
    {      0,    0,    6, 28, 50,  3 }, {     -1,   -1,    6, 28, 50,  3 }, {     -2,   -2,    6, 28, 50,  3 }, {     -3,   -3,    7, 28, 50,  3 }, {     -4,   -4,    7, 28, 50,  3 },
    {     -5,   -5,    7, 28, 50,  3 }, {     -6,   -6,    7, 28, 50,  3 }, {     -7,   -7,    7, 28,  0,  4 }, {     -8,   -8,    7, 28,  0,  4 }, {     -9,   -9,    8, 28,  0,  4 },
    {    -10,  -10,    8, 28,  0,  4 }, {    -11,  -11,    8, 28,  0,  4 }, {    -12,  -12,    8, 28,  0,  4 }, {    -13,  -13,    8, 28,  0,  4 }, {    -14,  -14,    8, 28,  0,  4 },
    {    -15,  -15,    8, 28,  0,  4 }, {    -16,  -16,    8, 28,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95A65E, {
    {     15,   16,    8,  4,  0,  2 }, {     14,   17,    8,  4,  0,  2 }, {     13,   18,    8,  4,  0,  2 }, {     12,   19,    8,  4,  0,  2 }, {     11,   20,    8,  4,  0,  2 },
    {     10,   21,    8,  4,  0,  2 }, {      9,   22,    8,  4,  0,  2 }, {      8,   23,    8,  4,  0,  2 }, {      7,   24,    7,  4, 53,  1 }, {      6,   25,    7,  4, 53,  1 },
    {      5,   26,    7,  4, 53,  1 }, {      4,   27,    7,  4, 53,  1 }, {      3,   28,    7,  4, 53,  1 }, {      2,   29,    7,  4, 53,  1 }, {      1,   30,    6,  4, 53,  1 },
    {      0,   31,    6,  4, 53,  1 }, {     -1,   32,    6,  4, 53,  1 }, {     -2,   33,    6,  4, 53,  1 }, {     -3,   34,    5,  4, 53,  1 }, {     -4,   35,    5,  4, 53,  1 },
    {     -5,   36,    5,  4, 53,  1 }, {     -6,   37,    4,  4, 53,  1 }, {     -7,   38,    4,  4, 53,  1 }, {     -8,   39,    4,  4, 53,  1 }, {     -9,   40,    3,  4, 54,  0 },
    {    -10,   41,    3,  4, 54,  0 }, {    -11,   42,    2,  4, 54,  0 }, {    -12,   43,    2,  4, 54,  0 }, {    -13,   44,    1,  4, 54,  0 }, {    -14,   45,    1,  4, 54,  0 },
    {    -15,   46,    0,  4, 54,  0 }, {    -16,   47,    0,  4, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95A780, {
    {     16,   16,    8, 12,  0,  2 }, {     17,   17,    8, 12,  0,  2 }, {     18,   18,    8, 12,  0,  2 }, {     19,   19,    8, 12,  0,  2 }, {     20,   20,    8, 12,  0,  2 },
    {     21,   21,    8, 12,  0,  2 }, {     22,   22,    8, 12,  0,  2 }, {     23,   23,    8, 12,  0,  2 }, {     24,   24,    7, 12, 53,  1 }, {     25,   25,    7, 12, 53,  1 },
    {     26,   26,    7, 12, 53,  1 }, {     27,   27,    7, 12, 53,  1 }, {     28,   28,    7, 12, 53,  1 }, {     29,   29,    7, 12, 53,  1 }, {     30,   30,    6, 12, 53,  1 },
    {     31,   31,    6, 12, 53,  1 }, {     32,   32,    6, 12, 53,  1 }, {     33,   33,    6, 12, 53,  1 }, {     34,   34,    5, 12, 53,  1 }, {     35,   35,    5, 12, 53,  1 },
    {     36,   36,    5, 12, 53,  1 }, {     37,   37,    4, 12, 53,  1 }, {     38,   38,    4, 12, 53,  1 }, {     39,   39,    4, 12, 53,  1 }, {     40,   40,    3, 12, 54,  0 },
    {     41,   41,    3, 12, 54,  0 }, {     42,   42,    2, 12, 54,  0 }, {     43,   43,    2, 12, 54,  0 }, {     44,   44,    1, 12, 54,  0 }, {     45,   45,    1, 12, 54,  0 },
    {     46,   46,    0, 12, 54,  0 }, {     47,   47,    0, 12, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95A8A2, {
    {     16,   15,    8, 20,  0,  2 }, {     17,   14,    8, 20,  0,  2 }, {     18,   13,    8, 20,  0,  2 }, {     19,   12,    8, 20,  0,  2 }, {     20,   11,    8, 20,  0,  2 },
    {     21,   10,    8, 20,  0,  2 }, {     22,    9,    8, 20,  0,  2 }, {     23,    8,    8, 20,  0,  2 }, {     24,    7,    7, 20, 53,  1 }, {     25,    6,    7, 20, 53,  1 },
    {     26,    5,    7, 20, 53,  1 }, {     27,    4,    7, 20, 53,  1 }, {     28,    3,    7, 20, 53,  1 }, {     29,    2,    7, 20, 53,  1 }, {     30,    1,    6, 20, 53,  1 },
    {     31,    0,    6, 20, 53,  1 }, {     32,   -1,    6, 20, 53,  1 }, {     33,   -2,    6, 20, 53,  1 }, {     34,   -3,    5, 20, 53,  1 }, {     35,   -4,    5, 20, 53,  1 },
    {     36,   -5,    5, 20, 53,  1 }, {     37,   -6,    4, 20, 53,  1 }, {     38,   -7,    4, 20, 53,  1 }, {     39,   -8,    4, 20, 53,  1 }, {     40,   -9,    3, 20, 54,  0 },
    {     41,  -10,    3, 20, 54,  0 }, {     42,  -11,    2, 20, 54,  0 }, {     43,  -12,    2, 20, 54,  0 }, {     44,  -13,    1, 20, 54,  0 }, {     45,  -14,    1, 20, 54,  0 },
    {     46,  -15,    0, 20, 54,  0 }, {     47,  -16,    0, 20, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95A9C4, {
    {     15,   15,    8, 28,  0,  2 }, {     14,   14,    8, 28,  0,  2 }, {     13,   13,    8, 28,  0,  2 }, {     12,   12,    8, 28,  0,  2 }, {     11,   11,    8, 28,  0,  2 },
    {     10,   10,    8, 28,  0,  2 }, {      9,    9,    8, 28,  0,  2 }, {      8,    8,    8, 28,  0,  2 }, {      7,    7,    7, 28, 53,  1 }, {      6,    6,    7, 28, 53,  1 },
    {      5,    5,    7, 28, 53,  1 }, {      4,    4,    7, 28, 53,  1 }, {      3,    3,    7, 28, 53,  1 }, {      2,    2,    7, 28, 53,  1 }, {      1,    1,    6, 28, 53,  1 },
    {      0,    0,    6, 28, 53,  1 }, {     -1,   -1,    6, 28, 53,  1 }, {     -2,   -2,    6, 28, 53,  1 }, {     -3,   -3,    5, 28, 53,  1 }, {     -4,   -4,    5, 28, 53,  1 },
    {     -5,   -5,    5, 28, 53,  1 }, {     -6,   -6,    4, 28, 53,  1 }, {     -7,   -7,    4, 28, 53,  1 }, {     -8,   -8,    4, 28, 53,  1 }, {     -9,   -9,    3, 28, 54,  0 },
    {    -10,  -10,    3, 28, 54,  0 }, {    -11,  -11,    2, 28, 54,  0 }, {    -12,  -12,    2, 28, 54,  0 }, {    -13,  -13,    1, 28, 54,  0 }, {    -14,  -14,    1, 28, 54,  0 },
    {    -15,  -15,    0, 28, 54,  0 }, {    -16,  -16,    0, 28, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95AAE6, {
    {     15,   16,    8,  4,  0,  4 }, {     14,   17,    8,  4,  0,  4 }, {     13,   18,    8,  4,  0,  4 }, {     12,   19,    8,  4,  0,  4 }, {     11,   20,    8,  4,  0,  4 },
    {     10,   21,    8,  4,  0,  4 }, {      9,   22,    8,  4,  0,  4 }, {      8,   23,    8,  4,  0,  4 }, {      7,   24,    7,  4, 53,  3 }, {      6,   25,    7,  4, 53,  3 },
    {      5,   26,    7,  4, 53,  3 }, {      4,   27,    7,  4, 53,  3 }, {      3,   28,    7,  4, 53,  3 }, {      2,   29,    7,  4, 53,  3 }, {      1,   30,    6,  4, 53,  3 },
    {      0,   31,    6,  4, 53,  3 }, {     -1,   32,    6,  4, 53,  3 }, {     -2,   33,    6,  4, 53,  3 }, {     -3,   34,    5,  4, 53,  3 }, {     -4,   35,    5,  4, 53,  3 },
    {     -5,   36,    5,  4, 53,  3 }, {     -6,   37,    4,  4, 53,  3 }, {     -7,   38,    4,  4, 53,  3 }, {     -8,   39,    4,  4, 53,  3 }, {     -9,   40,    3,  4, 54,  0 },
    {    -10,   41,    3,  4, 54,  0 }, {    -11,   42,    2,  4, 54,  0 }, {    -12,   43,    2,  4, 54,  0 }, {    -13,   44,    1,  4, 54,  0 }, {    -14,   45,    1,  4, 54,  0 },
    {    -15,   46,    0,  4, 54,  0 }, {    -16,   47,    0,  4, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95AC08, {
    {     16,   16,    8, 12,  0,  4 }, {     17,   17,    8, 12,  0,  4 }, {     18,   18,    8, 12,  0,  4 }, {     19,   19,    8, 12,  0,  4 }, {     20,   20,    8, 12,  0,  4 },
    {     21,   21,    8, 12,  0,  4 }, {     22,   22,    8, 12,  0,  4 }, {     23,   23,    8, 12,  0,  4 }, {     24,   24,    7, 12, 53,  3 }, {     25,   25,    7, 12, 53,  3 },
    {     26,   26,    7, 12, 53,  3 }, {     27,   27,    7, 12, 53,  3 }, {     28,   28,    7, 12, 53,  3 }, {     29,   29,    7, 12, 53,  3 }, {     30,   30,    6, 12, 53,  3 },
    {     31,   31,    6, 12, 53,  3 }, {     32,   32,    6, 12, 53,  3 }, {     33,   33,    6, 12, 53,  3 }, {     34,   34,    5, 12, 53,  3 }, {     35,   35,    5, 12, 53,  3 },
    {     36,   36,    5, 12, 53,  3 }, {     37,   37,    4, 12, 53,  3 }, {     38,   38,    4, 12, 53,  3 }, {     39,   39,    4, 12, 53,  3 }, {     40,   40,    3, 12, 54,  0 },
    {     41,   41,    3, 12, 54,  0 }, {     42,   42,    2, 12, 54,  0 }, {     43,   43,    2, 12, 54,  0 }, {     44,   44,    1, 12, 54,  0 }, {     45,   45,    1, 12, 54,  0 },
    {     46,   46,    0, 12, 54,  0 }, {     47,   47,    0, 12, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95AD2A, {
    {     16,   15,    8, 20,  0,  4 }, {     17,   14,    8, 20,  0,  4 }, {     18,   13,    8, 20,  0,  4 }, {     19,   12,    8, 20,  0,  4 }, {     20,   11,    8, 20,  0,  4 },
    {     21,   10,    8, 20,  0,  4 }, {     22,    9,    8, 20,  0,  4 }, {     23,    8,    8, 20,  0,  4 }, {     24,    7,    7, 20, 53,  3 }, {     25,    6,    7, 20, 53,  3 },
    {     26,    5,    7, 20, 53,  3 }, {     27,    4,    7, 20, 53,  3 }, {     28,    3,    7, 20, 53,  3 }, {     29,    2,    7, 20, 53,  3 }, {     30,    1,    6, 20, 53,  3 },
    {     31,    0,    6, 20, 53,  3 }, {     32,   -1,    6, 20, 53,  3 }, {     33,   -2,    6, 20, 53,  3 }, {     34,   -3,    5, 20, 53,  3 }, {     35,   -4,    5, 20, 53,  3 },
    {     36,   -5,    5, 20, 53,  3 }, {     37,   -6,    4, 20, 53,  3 }, {     38,   -7,    4, 20, 53,  3 }, {     39,   -8,    4, 20, 53,  3 }, {     40,   -9,    3, 20, 54,  0 },
    {     41,  -10,    3, 20, 54,  0 }, {     42,  -11,    2, 20, 54,  0 }, {     43,  -12,    2, 20, 54,  0 }, {     44,  -13,    1, 20, 54,  0 }, {     45,  -14,    1, 20, 54,  0 },
    {     46,  -15,    0, 20, 54,  0 }, {     47,  -16,    0, 20, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95AE4C, {
    {     15,   15,    8, 28,  0,  4 }, {     14,   14,    8, 28,  0,  4 }, {     13,   13,    8, 28,  0,  4 }, {     12,   12,    8, 28,  0,  4 }, {     11,   11,    8, 28,  0,  4 },
    {     10,   10,    8, 28,  0,  4 }, {      9,    9,    8, 28,  0,  4 }, {      8,    8,    8, 28,  0,  4 }, {      7,    7,    7, 28, 53,  3 }, {      6,    6,    7, 28, 53,  3 },
    {      5,    5,    7, 28, 53,  3 }, {      4,    4,    7, 28, 53,  3 }, {      3,    3,    7, 28, 53,  3 }, {      2,    2,    7, 28, 53,  3 }, {      1,    1,    6, 28, 53,  3 },
    {      0,    0,    6, 28, 53,  3 }, {     -1,   -1,    6, 28, 53,  3 }, {     -2,   -2,    6, 28, 53,  3 }, {     -3,   -3,    5, 28, 53,  3 }, {     -4,   -4,    5, 28, 53,  3 },
    {     -5,   -5,    5, 28, 53,  3 }, {     -6,   -6,    4, 28, 53,  3 }, {     -7,   -7,    4, 28, 53,  3 }, {     -8,   -8,    4, 28, 53,  3 }, {     -9,   -9,    3, 28, 54,  0 },
    {    -10,  -10,    3, 28, 54,  0 }, {    -11,  -11,    2, 28, 54,  0 }, {    -12,  -12,    2, 28, 54,  0 }, {    -13,  -13,    1, 28, 54,  0 }, {    -14,  -14,    1, 28, 54,  0 },
    {    -15,  -15,    0, 28, 54,  0 }, {    -16,  -16,    0, 28, 54,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_959D4E, {
    {     15,   16,    7,  4, 54,  0 }, {     14,   17,    7,  4, 54,  0 }, {     13,   18,    6,  4, 54,  0 }, {     12,   19,    6,  4, 54,  0 }, {     11,   20,    5,  4, 54,  0 },
    {     10,   21,    5,  4, 54,  0 }, {      9,   22,    4,  4, 54,  0 }, {      8,   23,    4,  4, 54,  0 }, {      7,   24,    4,  4, 53,  1 }, {      6,   25,    3,  4, 53,  1 },
    {      5,   26,    3,  4, 53,  1 }, {      4,   27,    3,  4, 53,  1 }, {      3,   28,    2,  4, 53,  1 }, {      2,   29,    2,  4, 53,  1 }, {      1,   30,    2,  4, 53,  1 },
    {      0,   31,    2,  4, 53,  1 }, {     -1,   32,    1,  4, 53,  1 }, {     -2,   33,    1,  4, 53,  1 }, {     -3,   34,    1,  4, 53,  1 }, {     -4,   35,    1,  4, 53,  1 },
    {     -5,   36,    1,  4, 53,  1 }, {     -6,   37,    1,  4, 53,  1 }, {     -7,   38,    0,  4,  0,  2 }, {     -8,   39,    0,  4,  0,  2 }, {     -9,   40,    0,  4,  0,  2 },
    {    -10,   41,    0,  4,  0,  2 }, {    -11,   42,    0,  4,  0,  2 }, {    -12,   43,    0,  4,  0,  2 }, {    -13,   44,    0,  4,  0,  2 }, {    -14,   45,    0,  4,  0,  2 },
    {    -15,   46,    0,  4,  0,  2 }, {    -16,   47,    0,  4,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_959E70, {
    {     16,   16,    7, 12, 54,  0 }, {     17,   17,    7, 12, 54,  0 }, {     18,   18,    6, 12, 54,  0 }, {     19,   19,    6, 12, 54,  0 }, {     20,   20,    5, 12, 54,  0 },
    {     21,   21,    5, 12, 54,  0 }, {     22,   22,    4, 12, 54,  0 }, {     23,   23,    4, 12, 54,  0 }, {     24,   24,    4, 12, 53,  1 }, {     25,   25,    3, 12, 53,  1 },
    {     26,   26,    3, 12, 53,  1 }, {     27,   27,    3, 12, 53,  1 }, {     28,   28,    2, 12, 53,  1 }, {     29,   29,    2, 12, 53,  1 }, {     30,   30,    2, 12, 53,  1 },
    {     31,   31,    2, 12, 53,  1 }, {     32,   32,    1, 12, 53,  1 }, {     33,   33,    1, 12, 53,  1 }, {     34,   34,    1, 12, 53,  1 }, {     35,   35,    1, 12, 53,  1 },
    {     36,   36,    1, 12, 53,  1 }, {     37,   37,    1, 12, 53,  1 }, {     38,   38,    0, 12,  0,  2 }, {     39,   39,    0, 12,  0,  2 }, {     40,   40,    0, 12,  0,  2 },
    {     41,   41,    0, 12,  0,  2 }, {     42,   42,    0, 12,  0,  2 }, {     43,   43,    0, 12,  0,  2 }, {     44,   44,    0, 12,  0,  2 }, {     45,   45,    0, 12,  0,  2 },
    {     46,   46,    0, 12,  0,  2 }, {     47,   47,    0, 12,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_959F92, {
    {     16,   15,    7, 20, 54,  0 }, {     17,   14,    7, 20, 54,  0 }, {     18,   13,    6, 20, 54,  0 }, {     19,   12,    6, 20, 54,  0 }, {     20,   11,    5, 20, 54,  0 },
    {     21,   10,    5, 20, 54,  0 }, {     22,    9,    4, 20, 54,  0 }, {     23,    8,    4, 20, 54,  0 }, {     24,    7,    4, 20, 53,  1 }, {     25,    6,    3, 20, 53,  1 },
    {     26,    5,    3, 20, 53,  1 }, {     27,    4,    3, 20, 53,  1 }, {     28,    3,    2, 20, 53,  1 }, {     29,    2,    2, 20, 53,  1 }, {     30,    1,    2, 20, 53,  1 },
    {     31,    0,    2, 20, 53,  1 }, {     32,   -1,    1, 20, 53,  1 }, {     33,   -2,    1, 20, 53,  1 }, {     34,   -3,    1, 20, 53,  1 }, {     35,   -4,    1, 20, 53,  1 },
    {     36,   -5,    1, 20, 53,  1 }, {     37,   -6,    1, 20, 53,  1 }, {     38,   -7,    0, 20,  0,  2 }, {     39,   -8,    0, 20,  0,  2 }, {     40,   -9,    0, 20,  0,  2 },
    {     41,  -10,    0, 20,  0,  2 }, {     42,  -11,    0, 20,  0,  2 }, {     43,  -12,    0, 20,  0,  2 }, {     44,  -13,    0, 20,  0,  2 }, {     45,  -14,    0, 20,  0,  2 },
    {     46,  -15,    0, 20,  0,  2 }, {     47,  -16,    0, 20,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95A0B4, {
    {     15,   15,    7, 28, 54,  0 }, {     14,   14,    7, 28, 54,  0 }, {     13,   13,    6, 28, 54,  0 }, {     12,   12,    6, 28, 54,  0 }, {     11,   11,    5, 28, 54,  0 },
    {     10,   10,    5, 28, 54,  0 }, {      9,    9,    4, 28, 54,  0 }, {      8,    8,    4, 28, 54,  0 }, {      7,    7,    4, 28, 53,  1 }, {      6,    6,    3, 28, 53,  1 },
    {      5,    5,    3, 28, 53,  1 }, {      4,    4,    3, 28, 53,  1 }, {      3,    3,    2, 28, 53,  1 }, {      2,    2,    2, 28, 53,  1 }, {      1,    1,    2, 28, 53,  1 },
    {      0,    0,    2, 28, 53,  1 }, {     -1,   -1,    1, 28, 53,  1 }, {     -2,   -2,    1, 28, 53,  1 }, {     -3,   -3,    1, 28, 53,  1 }, {     -4,   -4,    1, 28, 53,  1 },
    {     -5,   -5,    1, 28, 53,  1 }, {     -6,   -6,    1, 28, 53,  1 }, {     -7,   -7,    0, 28,  0,  2 }, {     -8,   -8,    0, 28,  0,  2 }, {     -9,   -9,    0, 28,  0,  2 },
    {    -10,  -10,    0, 28,  0,  2 }, {    -11,  -11,    0, 28,  0,  2 }, {    -12,  -12,    0, 28,  0,  2 }, {    -13,  -13,    0, 28,  0,  2 }, {    -14,  -14,    0, 28,  0,  2 },
    {    -15,  -15,    0, 28,  0,  2 }, {    -16,  -16,    0, 28,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95A1D6, {
    {     15,   16,    7,  4, 54,  0 }, {     14,   17,    7,  4, 54,  0 }, {     13,   18,    6,  4, 54,  0 }, {     12,   19,    6,  4, 54,  0 }, {     11,   20,    5,  4, 54,  0 },
    {     10,   21,    5,  4, 54,  0 }, {      9,   22,    4,  4, 54,  0 }, {      8,   23,    4,  4, 54,  0 }, {      7,   24,    4,  4, 53,  3 }, {      6,   25,    3,  4, 53,  3 },
    {      5,   26,    3,  4, 53,  3 }, {      4,   27,    3,  4, 53,  3 }, {      3,   28,    2,  4, 53,  3 }, {      2,   29,    2,  4, 53,  3 }, {      1,   30,    2,  4, 53,  3 },
    {      0,   31,    2,  4, 53,  3 }, {     -1,   32,    1,  4, 53,  3 }, {     -2,   33,    1,  4, 53,  3 }, {     -3,   34,    1,  4, 53,  3 }, {     -4,   35,    1,  4, 53,  3 },
    {     -5,   36,    1,  4, 53,  3 }, {     -6,   37,    1,  4, 53,  3 }, {     -7,   38,    0,  4,  0,  4 }, {     -8,   39,    0,  4,  0,  4 }, {     -9,   40,    0,  4,  0,  4 },
    {    -10,   41,    0,  4,  0,  4 }, {    -11,   42,    0,  4,  0,  4 }, {    -12,   43,    0,  4,  0,  4 }, {    -13,   44,    0,  4,  0,  4 }, {    -14,   45,    0,  4,  0,  4 },
    {    -15,   46,    0,  4,  0,  4 }, {    -16,   47,    0,  4,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95A2F8, {
    {     16,   16,    7, 12, 54,  0 }, {     17,   17,    7, 12, 54,  0 }, {     18,   18,    6, 12, 54,  0 }, {     19,   19,    6, 12, 54,  0 }, {     20,   20,    5, 12, 54,  0 },
    {     21,   21,    5, 12, 54,  0 }, {     22,   22,    4, 12, 54,  0 }, {     23,   23,    4, 12, 54,  0 }, {     24,   24,    4, 12, 53,  3 }, {     25,   25,    3, 12, 53,  3 },
    {     26,   26,    3, 12, 53,  3 }, {     27,   27,    3, 12, 53,  3 }, {     28,   28,    2, 12, 53,  3 }, {     29,   29,    2, 12, 53,  3 }, {     30,   30,    2, 12, 53,  3 },
    {     31,   31,    2, 12, 53,  3 }, {     32,   32,    1, 12, 53,  3 }, {     33,   33,    1, 12, 53,  3 }, {     34,   34,    1, 12, 53,  3 }, {     35,   35,    1, 12, 53,  3 },
    {     36,   36,    1, 12, 53,  3 }, {     37,   37,    1, 12, 53,  3 }, {     38,   38,    0, 12,  0,  4 }, {     39,   39,    0, 12,  0,  4 }, {     40,   40,    0, 12,  0,  4 },
    {     41,   41,    0, 12,  0,  4 }, {     42,   42,    0, 12,  0,  4 }, {     43,   43,    0, 12,  0,  4 }, {     44,   44,    0, 12,  0,  4 }, {     45,   45,    0, 12,  0,  4 },
    {     46,   46,    0, 12,  0,  4 }, {     47,   47,    0, 12,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95A41A, {
    {     16,   15,    7, 20, 54,  0 }, {     17,   14,    7, 20, 54,  0 }, {     18,   13,    6, 20, 54,  0 }, {     19,   12,    6, 20, 54,  0 }, {     20,   11,    5, 20, 54,  0 },
    {     21,   10,    5, 20, 54,  0 }, {     22,    9,    4, 20, 54,  0 }, {     23,    8,    4, 20, 54,  0 }, {     24,    7,    4, 20, 53,  3 }, {     25,    6,    3, 20, 53,  3 },
    {     26,    5,    3, 20, 53,  3 }, {     27,    4,    3, 20, 53,  3 }, {     28,    3,    2, 20, 53,  3 }, {     29,    2,    2, 20, 53,  3 }, {     30,    1,    2, 20, 53,  3 },
    {     31,    0,    2, 20, 53,  3 }, {     32,   -1,    1, 20, 53,  3 }, {     33,   -2,    1, 20, 53,  3 }, {     34,   -3,    1, 20, 53,  3 }, {     35,   -4,    1, 20, 53,  3 },
    {     36,   -5,    1, 20, 53,  3 }, {     37,   -6,    1, 20, 53,  3 }, {     38,   -7,    0, 20,  0,  4 }, {     39,   -8,    0, 20,  0,  4 }, {     40,   -9,    0, 20,  0,  4 },
    {     41,  -10,    0, 20,  0,  4 }, {     42,  -11,    0, 20,  0,  4 }, {     43,  -12,    0, 20,  0,  4 }, {     44,  -13,    0, 20,  0,  4 }, {     45,  -14,    0, 20,  0,  4 },
    {     46,  -15,    0, 20,  0,  4 }, {     47,  -16,    0, 20,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95A53C, {
    {     15,   15,    7, 28, 54,  0 }, {     14,   14,    7, 28, 54,  0 }, {     13,   13,    6, 28, 54,  0 }, {     12,   12,    6, 28, 54,  0 }, {     11,   11,    5, 28, 54,  0 },
    {     10,   10,    5, 28, 54,  0 }, {      9,    9,    4, 28, 54,  0 }, {      8,    8,    4, 28, 54,  0 }, {      7,    7,    4, 28, 53,  3 }, {      6,    6,    3, 28, 53,  3 },
    {      5,    5,    3, 28, 53,  3 }, {      4,    4,    3, 28, 53,  3 }, {      3,    3,    2, 28, 53,  3 }, {      2,    2,    2, 28, 53,  3 }, {      1,    1,    2, 28, 53,  3 },
    {      0,    0,    2, 28, 53,  3 }, {     -1,   -1,    1, 28, 53,  3 }, {     -2,   -2,    1, 28, 53,  3 }, {     -3,   -3,    1, 28, 53,  3 }, {     -4,   -4,    1, 28, 53,  3 },
    {     -5,   -5,    1, 28, 53,  3 }, {     -6,   -6,    1, 28, 53,  3 }, {     -7,   -7,    0, 28,  0,  4 }, {     -8,   -8,    0, 28,  0,  4 }, {     -9,   -9,    0, 28,  0,  4 },
    {    -10,  -10,    0, 28,  0,  4 }, {    -11,  -11,    0, 28,  0,  4 }, {    -12,  -12,    0, 28,  0,  4 }, {    -13,  -13,    0, 28,  0,  4 }, {    -14,  -14,    0, 28,  0,  4 },
    {    -15,  -15,    0, 28,  0,  4 }, {    -16,  -16,    0, 28,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95AF6E, {
    {     15,   16,    0,  4,  0,  2 }, {     14,   17,    0,  4,  0,  2 }, {     13,   18,    0,  4,  0,  2 }, {     12,   19,    0,  4,  0,  2 }, {     11,   20,    0,  4,  0,  2 },
    {     10,   21,    0,  4,  0,  2 }, {      9,   22,    0,  4,  0,  2 }, {      8,   23,    0,  4,  0,  2 }, {      7,   24,    0,  4,  0,  2 }, {      6,   25,    0,  4,  0,  2 },
    {      5,   26,    0,  4,  0,  2 }, {      4,   27,    0,  4,  0,  2 }, {      3,   28,    0,  4,  0,  2 }, {      2,   29,    0,  4,  0,  2 }, {      1,   30,    0,  4,  0,  2 },
    {      0,   31,    0,  4,  0,  2 }, {     -1,   32,    0,  4,  0,  2 }, {     -2,   33,    0,  4,  0,  2 }, {     -3,   34,    0,  4,  0,  2 }, {     -4,   35,    0,  4,  0,  2 },
    {     -5,   36,    0,  4,  0,  2 }, {     -6,   37,    0,  4,  0,  2 }, {     -7,   38,    0,  4,  0,  2 }, {     -8,   39,    0,  4,  0,  2 }, {     -9,   40,    0,  4,  0,  2 },
    {    -10,   41,    0,  4,  0,  2 }, {    -11,   42,    0,  4,  0,  2 }, {    -12,   43,    0,  4,  0,  2 }, {    -13,   44,    0,  4,  0,  2 }, {    -14,   45,    0,  4,  0,  2 },
    {    -15,   46,    0,  4,  0,  2 }, {    -16,   47,    0,  4,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95B090, {
    {     16,   16,    0, 12,  0,  2 }, {     17,   17,    0, 12,  0,  2 }, {     18,   18,    0, 12,  0,  2 }, {     19,   19,    0, 12,  0,  2 }, {     20,   20,    0, 12,  0,  2 },
    {     21,   21,    0, 12,  0,  2 }, {     22,   22,    0, 12,  0,  2 }, {     23,   23,    0, 12,  0,  2 }, {     24,   24,    0, 12,  0,  2 }, {     25,   25,    0, 12,  0,  2 },
    {     26,   26,    0, 12,  0,  2 }, {     27,   27,    0, 12,  0,  2 }, {     28,   28,    0, 12,  0,  2 }, {     29,   29,    0, 12,  0,  2 }, {     30,   30,    0, 12,  0,  2 },
    {     31,   31,    0, 12,  0,  2 }, {     32,   32,    0, 12,  0,  2 }, {     33,   33,    0, 12,  0,  2 }, {     34,   34,    0, 12,  0,  2 }, {     35,   35,    0, 12,  0,  2 },
    {     36,   36,    0, 12,  0,  2 }, {     37,   37,    0, 12,  0,  2 }, {     38,   38,    0, 12,  0,  2 }, {     39,   39,    0, 12,  0,  2 }, {     40,   40,    0, 12,  0,  2 },
    {     41,   41,    0, 12,  0,  2 }, {     42,   42,    0, 12,  0,  2 }, {     43,   43,    0, 12,  0,  2 }, {     44,   44,    0, 12,  0,  2 }, {     45,   45,    0, 12,  0,  2 },
    {     46,   46,    0, 12,  0,  2 }, {     47,   47,    0, 12,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95B1B2, {
    {     16,   15,    0, 20,  0,  2 }, {     17,   14,    0, 20,  0,  2 }, {     18,   13,    0, 20,  0,  2 }, {     19,   12,    0, 20,  0,  2 }, {     20,   11,    0, 20,  0,  2 },
    {     21,   10,    0, 20,  0,  2 }, {     22,    9,    0, 20,  0,  2 }, {     23,    8,    0, 20,  0,  2 }, {     24,    7,    0, 20,  0,  2 }, {     25,    6,    0, 20,  0,  2 },
    {     26,    5,    0, 20,  0,  2 }, {     27,    4,    0, 20,  0,  2 }, {     28,    3,    0, 20,  0,  2 }, {     29,    2,    0, 20,  0,  2 }, {     30,    1,    0, 20,  0,  2 },
    {     31,    0,    0, 20,  0,  2 }, {     32,   -1,    0, 20,  0,  2 }, {     33,   -2,    0, 20,  0,  2 }, {     34,   -3,    0, 20,  0,  2 }, {     35,   -4,    0, 20,  0,  2 },
    {     36,   -5,    0, 20,  0,  2 }, {     37,   -6,    0, 20,  0,  2 }, {     38,   -7,    0, 20,  0,  2 }, {     39,   -8,    0, 20,  0,  2 }, {     40,   -9,    0, 20,  0,  2 },
    {     41,  -10,    0, 20,  0,  2 }, {     42,  -11,    0, 20,  0,  2 }, {     43,  -12,    0, 20,  0,  2 }, {     44,  -13,    0, 20,  0,  2 }, {     45,  -14,    0, 20,  0,  2 },
    {     46,  -15,    0, 20,  0,  2 }, {     47,  -16,    0, 20,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95B2D4, {
    {     15,   15,    0, 28,  0,  2 }, {     14,   14,    0, 28,  0,  2 }, {     13,   13,    0, 28,  0,  2 }, {     12,   12,    0, 28,  0,  2 }, {     11,   11,    0, 28,  0,  2 },
    {     10,   10,    0, 28,  0,  2 }, {      9,    9,    0, 28,  0,  2 }, {      8,    8,    0, 28,  0,  2 }, {      7,    7,    0, 28,  0,  2 }, {      6,    6,    0, 28,  0,  2 },
    {      5,    5,    0, 28,  0,  2 }, {      4,    4,    0, 28,  0,  2 }, {      3,    3,    0, 28,  0,  2 }, {      2,    2,    0, 28,  0,  2 }, {      1,    1,    0, 28,  0,  2 },
    {      0,    0,    0, 28,  0,  2 }, {     -1,   -1,    0, 28,  0,  2 }, {     -2,   -2,    0, 28,  0,  2 }, {     -3,   -3,    0, 28,  0,  2 }, {     -4,   -4,    0, 28,  0,  2 },
    {     -5,   -5,    0, 28,  0,  2 }, {     -6,   -6,    0, 28,  0,  2 }, {     -7,   -7,    0, 28,  0,  2 }, {     -8,   -8,    0, 28,  0,  2 }, {     -9,   -9,    0, 28,  0,  2 },
    {    -10,  -10,    0, 28,  0,  2 }, {    -11,  -11,    0, 28,  0,  2 }, {    -12,  -12,    0, 28,  0,  2 }, {    -13,  -13,    0, 28,  0,  2 }, {    -14,  -14,    0, 28,  0,  2 },
    {    -15,  -15,    0, 28,  0,  2 }, {    -16,  -16,    0, 28,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95B3F6, {
    {     15,   16,    0,  4,  0,  4 }, {     14,   17,    0,  4,  0,  4 }, {     13,   18,    0,  4,  0,  4 }, {     12,   19,    0,  4,  0,  4 }, {     11,   20,    0,  4,  0,  4 },
    {     10,   21,    0,  4,  0,  4 }, {      9,   22,    0,  4,  0,  4 }, {      8,   23,    0,  4,  0,  4 }, {      7,   24,    0,  4,  0,  4 }, {      6,   25,    0,  4,  0,  4 },
    {      5,   26,    0,  4,  0,  4 }, {      4,   27,    0,  4,  0,  4 }, {      3,   28,    0,  4,  0,  4 }, {      2,   29,    0,  4,  0,  4 }, {      1,   30,    0,  4,  0,  4 },
    {      0,   31,    0,  4,  0,  4 }, {     -1,   32,    0,  4,  0,  4 }, {     -2,   33,    0,  4,  0,  4 }, {     -3,   34,    0,  4,  0,  4 }, {     -4,   35,    0,  4,  0,  4 },
    {     -5,   36,    0,  4,  0,  4 }, {     -6,   37,    0,  4,  0,  4 }, {     -7,   38,    0,  4,  0,  4 }, {     -8,   39,    0,  4,  0,  4 }, {     -9,   40,    0,  4,  0,  4 },
    {    -10,   41,    0,  4,  0,  4 }, {    -11,   42,    0,  4,  0,  4 }, {    -12,   43,    0,  4,  0,  4 }, {    -13,   44,    0,  4,  0,  4 }, {    -14,   45,    0,  4,  0,  4 },
    {    -15,   46,    0,  4,  0,  4 }, {    -16,   47,    0,  4,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95B518, {
    {     16,   16,    0, 12,  0,  4 }, {     17,   17,    0, 12,  0,  4 }, {     18,   18,    0, 12,  0,  4 }, {     19,   19,    0, 12,  0,  4 }, {     20,   20,    0, 12,  0,  4 },
    {     21,   21,    0, 12,  0,  4 }, {     22,   22,    0, 12,  0,  4 }, {     23,   23,    0, 12,  0,  4 }, {     24,   24,    0, 12,  0,  4 }, {     25,   25,    0, 12,  0,  4 },
    {     26,   26,    0, 12,  0,  4 }, {     27,   27,    0, 12,  0,  4 }, {     28,   28,    0, 12,  0,  4 }, {     29,   29,    0, 12,  0,  4 }, {     30,   30,    0, 12,  0,  4 },
    {     31,   31,    0, 12,  0,  4 }, {     32,   32,    0, 12,  0,  4 }, {     33,   33,    0, 12,  0,  4 }, {     34,   34,    0, 12,  0,  4 }, {     35,   35,    0, 12,  0,  4 },
    {     36,   36,    0, 12,  0,  4 }, {     37,   37,    0, 12,  0,  4 }, {     38,   38,    0, 12,  0,  4 }, {     39,   39,    0, 12,  0,  4 }, {     40,   40,    0, 12,  0,  4 },
    {     41,   41,    0, 12,  0,  4 }, {     42,   42,    0, 12,  0,  4 }, {     43,   43,    0, 12,  0,  4 }, {     44,   44,    0, 12,  0,  4 }, {     45,   45,    0, 12,  0,  4 },
    {     46,   46,    0, 12,  0,  4 }, {     47,   47,    0, 12,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95B63A, {
    {     16,   15,    0, 20,  0,  4 }, {     17,   14,    0, 20,  0,  4 }, {     18,   13,    0, 20,  0,  4 }, {     19,   12,    0, 20,  0,  4 }, {     20,   11,    0, 20,  0,  4 },
    {     21,   10,    0, 20,  0,  4 }, {     22,    9,    0, 20,  0,  4 }, {     23,    8,    0, 20,  0,  4 }, {     24,    7,    0, 20,  0,  4 }, {     25,    6,    0, 20,  0,  4 },
    {     26,    5,    0, 20,  0,  4 }, {     27,    4,    0, 20,  0,  4 }, {     28,    3,    0, 20,  0,  4 }, {     29,    2,    0, 20,  0,  4 }, {     30,    1,    0, 20,  0,  4 },
    {     31,    0,    0, 20,  0,  4 }, {     32,   -1,    0, 20,  0,  4 }, {     33,   -2,    0, 20,  0,  4 }, {     34,   -3,    0, 20,  0,  4 }, {     35,   -4,    0, 20,  0,  4 },
    {     36,   -5,    0, 20,  0,  4 }, {     37,   -6,    0, 20,  0,  4 }, {     38,   -7,    0, 20,  0,  4 }, {     39,   -8,    0, 20,  0,  4 }, {     40,   -9,    0, 20,  0,  4 },
    {     41,  -10,    0, 20,  0,  4 }, {     42,  -11,    0, 20,  0,  4 }, {     43,  -12,    0, 20,  0,  4 }, {     44,  -13,    0, 20,  0,  4 }, {     45,  -14,    0, 20,  0,  4 },
    {     46,  -15,    0, 20,  0,  4 }, {     47,  -16,    0, 20,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95B75C, {
    {     15,   15,    0, 28,  0,  4 }, {     14,   14,    0, 28,  0,  4 }, {     13,   13,    0, 28,  0,  4 }, {     12,   12,    0, 28,  0,  4 }, {     11,   11,    0, 28,  0,  4 },
    {     10,   10,    0, 28,  0,  4 }, {      9,    9,    0, 28,  0,  4 }, {      8,    8,    0, 28,  0,  4 }, {      7,    7,    0, 28,  0,  4 }, {      6,    6,    0, 28,  0,  4 },
    {      5,    5,    0, 28,  0,  4 }, {      4,    4,    0, 28,  0,  4 }, {      3,    3,    0, 28,  0,  4 }, {      2,    2,    0, 28,  0,  4 }, {      1,    1,    0, 28,  0,  4 },
    {      0,    0,    0, 28,  0,  4 }, {     -1,   -1,    0, 28,  0,  4 }, {     -2,   -2,    0, 28,  0,  4 }, {     -3,   -3,    0, 28,  0,  4 }, {     -4,   -4,    0, 28,  0,  4 },
    {     -5,   -5,    0, 28,  0,  4 }, {     -6,   -6,    0, 28,  0,  4 }, {     -7,   -7,    0, 28,  0,  4 }, {     -8,   -8,    0, 28,  0,  4 }, {     -9,   -9,    0, 28,  0,  4 },
    {    -10,  -10,    0, 28,  0,  4 }, {    -11,  -11,    0, 28,  0,  4 }, {    -12,  -12,    0, 28,  0,  4 }, {    -13,  -13,    0, 28,  0,  4 }, {    -14,  -14,    0, 28,  0,  4 },
    {    -15,  -15,    0, 28,  0,  4 }, {    -16,  -16,    0, 28,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91BE46, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     21,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     15,   17,    0,  1,  0,  0 }, {     15,   16,    0,  2,  0,  0 }, {     15,   17,    0,  3,  0,  0 },
    {     15,   16,    0,  4,  0,  0 }, {     15,   17,    0,  5,  0,  0 }, {     15,   16,    0,  6,  0,  0 }, {     15,   17,    0,  7,  0,  0 }, {     15,   16,    0,  8,  0,  0 },
    {     15,   17,    0,  9,  0,  0 }, {     15,   16,    0, 10,  0,  0 }, {     15,   17,    0, 11,  0,  0 }, {     15,   16,    0, 12,  0,  0 }, {     15,   17,    0, 13,  0,  0 },
    {     15,   16,    0, 14,  0,  0 }, {     15,   17,    0, 15,  0,  0 }, {     15,   16,    0, 16,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     14,   16,    0,  0,  0,  0 },
    {     13,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {     10,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 },
    {      8,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 }, {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 },
    {      3,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91C001, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   15,    0,  8,  0,  0 }, {     15,   16,    0,  8,  0,  0 }, {     15,   17,    0,  9,  0,  0 }, {     15,   16,    0, 10,  0,  0 }, {     15,   17,    0, 11,  0,  0 },
    {     15,   16,    0, 12,  0,  0 }, {     15,   17,    0, 13,  0,  0 }, {     15,   16,    0, 14,  0,  0 }, {     15,   17,    0, 15,  0,  0 }, {     15,   16,    0, 16,  0,  0 },
    {     15,   17,    0, 17,  0,  0 }, {     15,   16,    0, 18,  0,  0 }, {     15,   17,    0, 19,  0,  0 }, {     15,   16,    0, 20,  0,  0 }, {     15,   17,    0, 21,  0,  0 },
    {     15,   16,    0, 22,  0,  0 }, {     15,   17,    0, 23,  0,  0 }, {     15,   16,    0, 24,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   17,    0,  8,  0,  0 },
    {     16,   18,    0,  8,  0,  0 }, {     16,   19,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   21,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 },
    {     16,   23,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 }, {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 },
    {     16,   28,    0,  8,  0,  0 }, {     16,   29,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91C1BC, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 }, {      9,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     13,   16,    0, 16,  0,  0 }, {     14,   16,    0, 16,  0,  0 },
    {     15,   16,    0, 16,  0,  0 }, {     15,   16,    0, 16,  0,  0 }, {     15,   17,    0, 17,  0,  0 }, {     15,   16,    0, 18,  0,  0 }, {     15,   17,    0, 19,  0,  0 },
    {     15,   16,    0, 20,  0,  0 }, {     15,   17,    0, 21,  0,  0 }, {     15,   16,    0, 22,  0,  0 }, {     15,   17,    0, 23,  0,  0 }, {     15,   16,    0, 24,  0,  0 },
    {     15,   17,    0, 25,  0,  0 }, {     15,   16,    0, 26,  0,  0 }, {     15,   17,    0, 27,  0,  0 }, {     15,   16,    0, 28,  0,  0 }, {     15,   17,    0, 29,  0,  0 },
    {     15,   16,    0, 30,  0,  0 }, {     15,   17,    0, 31,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     17,   16,    0, 16,  0,  0 },
    {     18,   16,    0, 16,  0,  0 }, {     19,   16,    0, 16,  0,  0 }, {     20,   16,    0, 16,  0,  0 }, {     21,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 },
    {     23,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 }, {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 },
    {     28,   16,    0, 16,  0,  0 }, {     29,   16,    0, 16,  0,  0 }, {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91C377, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   21,    0, 24,  0,  0 }, {     16,   20,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 }, {     16,   17,    0, 24,  0,  0 },
    {     16,   16,    0, 24,  0,  0 }, {     15,   16,    0, 24,  0,  0 }, {     15,   17,    0, 25,  0,  0 }, {     15,   16,    0, 26,  0,  0 }, {     15,   17,    0, 27,  0,  0 },
    {     15,   16,    0, 28,  0,  0 }, {     15,   17,    0, 29,  0,  0 }, {     15,   16,    0, 30,  0,  0 }, {     15,   17,    0, 31,  0,  0 }, {     15,   16,    0,  0,  0,  0 },
    {     15,   17,    0,  1,  0,  0 }, {     15,   16,    0,  2,  0,  0 }, {     15,   17,    0,  3,  0,  0 }, {     15,   16,    0,  4,  0,  0 }, {     15,   17,    0,  5,  0,  0 },
    {     15,   16,    0,  6,  0,  0 }, {     15,   17,    0,  7,  0,  0 }, {     15,   16,    0,  8,  0,  0 }, {     16,   15,    0, 24,  0,  0 }, {     16,   14,    0, 24,  0,  0 },
    {     16,   13,    0, 24,  0,  0 }, {     16,   12,    0, 24,  0,  0 }, {     16,   11,    0, 24,  0,  0 }, {     16,   10,    0, 24,  0,  0 }, {     16,    9,    0, 24,  0,  0 },
    {     16,    8,    0, 24,  0,  0 }, {     16,    7,    0, 24,  0,  0 }, {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 },
    {     16,    3,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 }, {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91C532, {
    {     31,   16,    1,  0, 45,  0 }, {     30,   16,    1,  0, 45,  0 }, {     29,   16,    1,  0, 45,  0 }, {     28,   17,    1,  0, 45,  0 }, {     27,   17,    1,  0, 45,  0 },
    {     26,   17,    1,  0, 45,  0 }, {     25,   17,    1,  0, 45,  1 }, {     24,   18,    1,  0, 45,  1 }, {     23,   18,    1,  0, 45,  1 }, {     22,   18,    1,  0, 45,  1 },
    {     21,   18,    1,  0, 45,  1 }, {     20,   18,    2,  0, 45,  1 }, {     19,   19,    2,  0, 45,  1 }, {     18,   19,    2,  0, 45,  1 }, {     17,   19,    2,  0, 45,  1 },
    {     16,   19,    2,  0, 45,  1 }, {     15,   19,    2,  0, 45,  1 }, {     14,   20,    2,  0, 45,  1 }, {     13,   20,    2,  0, 45,  2 }, {     12,   20,    2,  0, 45,  2 },
    {     11,   20,    3,  0, 45,  2 }, {     10,   20,    3,  0, 45,  2 }, {      9,   21,    3,  0, 45,  2 }, {      8,   21,    3,  0, 45,  2 }, {      7,   21,    3,  0, 45,  2 },
    {      6,   21,    4,  0, 45,  2 }, {      5,   21,    4,  0, 45,  2 }, {      4,   21,    4,  0, 45,  2 }, {      3,   22,    4,  0, 45,  2 }, {      2,   22,    4,  0, 45,  2 },
    {      1,   22,    5,  0, 45,  5 }, {      0,   22,    5,  0, 45,  5 }, {     -1,   22,    5,  0, 45,  5 }, {     -2,   22,    5,  0, 45,  5 }, {     -3,   22,    5,  0, 45,  5 },
    {     -4,   22,    6,  0, 45,  5 }, {     -5,   22,    6,  0, 45,  5 }, {     -6,   23,    6,  0, 45,  5 }, {     -7,   23,    6,  0, 45,  5 }, {     -8,   23,    7,  0, 45,  5 },
    {     -9,   23,    7,  0, 45,  5 }, {    -10,   23,    7,  0, 45,  5 }, {    -11,   23,    7,  0, 45,  6 }, {    -12,   23,    8,  0, 45,  6 }, {    -13,   23,    8,  0, 45,  6 },
    {    -14,   23,    8,  0, 45,  6 }, {    -15,   23,    8,  0, 45,  6 }, {    -16,   23,    8,  0, 45,  6 }, {    -17,   23,    8,  0, 45,  6 }, {    -18,   23,    8,  0, 45,  6 },
    {    -19,   23,    9,  0, 45,  6 }, {    -20,   23,    9,  0, 45,  6 }, {    -21,   23,    9,  0, 45,  6 }, {    -22,   23,    9,  0, 45,  6 }, {    -23,   23,   10,  0, 45,  7 },
    {    -24,   23,   10,  0, 45,  7 }, {    -25,   23,   10,  0, 45,  7 }, {    -26,   23,   10,  0, 45,  7 }, {    -27,   23,   11,  0, 45,  7 }, {    -28,   23,   11,  0, 45,  7 },
    {    -29,   22,   11,  0, 45,  7 }, {    -30,   22,   11,  0, 45,  7 }, {    -31,   22,   12,  0, 45,  7 }, {    -32,   22,   12,  0, 45,  7 }, {    -33,   22,   12,  0, 45,  7 },
    {    -34,   22,   12,  0, 45,  7 }, {    -35,   22,   12,  0, 45,  8 }, {    -36,   22,   13,  0, 45,  8 }, {    -37,   22,   13,  0, 45,  8 }, {    -38,   21,   13,  0, 45,  8 },
    {    -39,   21,   13,  0, 45,  8 }, {    -40,   21,   13,  0, 45,  8 }, {    -41,   21,   14,  0, 45,  8 }, {    -42,   21,   14,  0, 45,  8 }, {    -43,   21,   14,  0, 45,  8 },
    {    -44,   20,   14,  0, 45,  8 }, {    -45,   20,   14,  0, 45,  8 }, {    -46,   20,   15,  0, 45,  8 }, {    -47,   20,   15,  0, 45,  9 }, {    -48,   20,   15,  0, 45,  9 },
    {    -49,   19,   15,  0, 45,  9 }, {    -50,   19,   15,  0, 45,  9 }, {    -51,   19,   15,  0, 45,  9 }, {    -52,   19,   15,  0, 45,  9 }, {    -53,   19,   15,  0, 45,  9 },
    {    -54,   18,   15,  0, 45,  9 }, {    -55,   18,   16,  0, 45,  9 }, {    -56,   18,   16,  0, 45,  9 }, {    -57,   18,   16,  0, 45,  9 }, {    -58,   18,   16,  0, 45,  9 },
    {    -59,   17,   16, 16, 16,  0 }, {    -60,   17,   16, 16, 16,  0 }, {    -61,   17,   16, 16, 16,  0 }, {    -62,   17,   16, 16, 16,  0 }, {    -63,   16,   16, 16, 16,  0 },
    {    -64,   16,   16, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91C894, {
    {     16,    0,    1,  8, 45,  0 }, {     16,    1,    1,  8, 45,  0 }, {     16,    2,    1,  8, 45,  0 }, {     17,    3,    1,  8, 45,  0 }, {     17,    4,    1,  8, 45,  0 },
    {     17,    5,    1,  8, 45,  0 }, {     17,    6,    1,  8, 45,  1 }, {     18,    7,    1,  8, 45,  1 }, {     18,    8,    1,  8, 45,  1 }, {     18,    9,    1,  8, 45,  1 },
    {     18,   10,    1,  8, 45,  1 }, {     18,   11,    2,  8, 45,  1 }, {     19,   12,    2,  8, 45,  1 }, {     19,   13,    2,  8, 45,  1 }, {     19,   14,    2,  8, 45,  1 },
    {     19,   15,    2,  8, 45,  1 }, {     19,   16,    2,  8, 45,  1 }, {     20,   17,    2,  8, 45,  1 }, {     20,   18,    2,  8, 45,  2 }, {     20,   19,    2,  8, 45,  2 },
    {     20,   20,    3,  8, 45,  2 }, {     20,   21,    3,  8, 45,  2 }, {     21,   22,    3,  8, 45,  2 }, {     21,   23,    3,  8, 45,  2 }, {     21,   24,    3,  8, 45,  2 },
    {     21,   25,    4,  8, 45,  2 }, {     21,   26,    4,  8, 45,  2 }, {     21,   27,    4,  8, 45,  2 }, {     22,   28,    4,  8, 45,  2 }, {     22,   29,    4,  8, 45,  2 },
    {     22,   30,    5,  8, 45,  5 }, {     22,   31,    5,  8, 45,  5 }, {     22,   32,    5,  8, 45,  5 }, {     22,   33,    5,  8, 45,  5 }, {     22,   34,    5,  8, 45,  5 },
    {     22,   35,    6,  8, 45,  5 }, {     22,   36,    6,  8, 45,  5 }, {     23,   37,    6,  8, 45,  5 }, {     23,   38,    6,  8, 45,  5 }, {     23,   39,    7,  8, 45,  5 },
    {     23,   40,    7,  8, 45,  5 }, {     23,   41,    7,  8, 45,  5 }, {     23,   42,    7,  8, 45,  6 }, {     23,   43,    8,  8, 45,  6 }, {     23,   44,    8,  8, 45,  6 },
    {     23,   45,    8,  8, 45,  6 }, {     23,   46,    8,  8, 45,  6 }, {     23,   47,    8,  8, 45,  6 }, {     23,   48,    8,  8, 45,  6 }, {     23,   49,    8,  8, 45,  6 },
    {     23,   50,    9,  8, 45,  6 }, {     23,   51,    9,  8, 45,  6 }, {     23,   52,    9,  8, 45,  6 }, {     23,   53,    9,  8, 45,  6 }, {     23,   54,   10,  8, 45,  7 },
    {     23,   55,   10,  8, 45,  7 }, {     23,   56,   10,  8, 45,  7 }, {     23,   57,   10,  8, 45,  7 }, {     23,   58,   11,  8, 45,  7 }, {     23,   59,   11,  8, 45,  7 },
    {     22,   60,   11,  8, 45,  7 }, {     22,   61,   11,  8, 45,  7 }, {     22,   62,   12,  8, 45,  7 }, {     22,   63,   12,  8, 45,  7 }, {     22,   64,   12,  8, 45,  7 },
    {     22,   65,   12,  8, 45,  7 }, {     22,   66,   12,  8, 45,  8 }, {     22,   67,   13,  8, 45,  8 }, {     22,   68,   13,  8, 45,  8 }, {     21,   69,   13,  8, 45,  8 },
    {     21,   70,   13,  8, 45,  8 }, {     21,   71,   13,  8, 45,  8 }, {     21,   72,   14,  8, 45,  8 }, {     21,   73,   14,  8, 45,  8 }, {     21,   74,   14,  8, 45,  8 },
    {     20,   75,   14,  8, 45,  8 }, {     20,   76,   14,  8, 45,  8 }, {     20,   77,   15,  8, 45,  8 }, {     20,   78,   15,  8, 45,  9 }, {     20,   79,   15,  8, 45,  9 },
    {     19,   80,   15,  8, 45,  9 }, {     19,   81,   15,  8, 45,  9 }, {     19,   82,   15,  8, 45,  9 }, {     19,   83,   15,  8, 45,  9 }, {     19,   84,   15,  8, 45,  9 },
    {     18,   85,   15,  8, 45,  9 }, {     18,   86,   16,  8, 45,  9 }, {     18,   87,   16,  8, 45,  9 }, {     18,   88,   16,  8, 45,  9 }, {     18,   89,   16,  8, 45,  9 },
    {     17,   90,   16, 24, 16,  0 }, {     17,   91,   16, 24, 16,  0 }, {     17,   92,   16, 24, 16,  0 }, {     17,   93,   16, 24, 16,  0 }, {     16,   94,   16, 24, 16,  0 },
    {     16,   95,   16, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91CBF6, {
    {      0,   16,    1, 16, 45,  0 }, {      1,   16,    1, 16, 45,  0 }, {      2,   16,    1, 16, 45,  0 }, {      3,   15,    1, 16, 45,  0 }, {      4,   15,    1, 16, 45,  0 },
    {      5,   15,    1, 16, 45,  0 }, {      6,   15,    1, 16, 45,  1 }, {      7,   14,    1, 16, 45,  1 }, {      8,   14,    1, 16, 45,  1 }, {      9,   14,    1, 16, 45,  1 },
    {     10,   14,    1, 16, 45,  1 }, {     11,   14,    2, 16, 45,  1 }, {     12,   13,    2, 16, 45,  1 }, {     13,   13,    2, 16, 45,  1 }, {     14,   13,    2, 16, 45,  1 },
    {     15,   13,    2, 16, 45,  1 }, {     16,   13,    2, 16, 45,  1 }, {     17,   12,    2, 16, 45,  1 }, {     18,   12,    2, 16, 45,  2 }, {     19,   12,    2, 16, 45,  2 },
    {     20,   12,    3, 16, 45,  2 }, {     21,   12,    3, 16, 45,  2 }, {     22,   11,    3, 16, 45,  2 }, {     23,   11,    3, 16, 45,  2 }, {     24,   11,    3, 16, 45,  2 },
    {     25,   11,    4, 16, 45,  2 }, {     26,   11,    4, 16, 45,  2 }, {     27,   11,    4, 16, 45,  2 }, {     28,   10,    4, 16, 45,  2 }, {     29,   10,    4, 16, 45,  2 },
    {     30,   10,    5, 16, 45,  5 }, {     31,   10,    5, 16, 45,  5 }, {     32,   10,    5, 16, 45,  5 }, {     33,   10,    5, 16, 45,  5 }, {     34,   10,    5, 16, 45,  5 },
    {     35,   10,    6, 16, 45,  5 }, {     36,   10,    6, 16, 45,  5 }, {     37,    9,    6, 16, 45,  5 }, {     38,    9,    6, 16, 45,  5 }, {     39,    9,    7, 16, 45,  5 },
    {     40,    9,    7, 16, 45,  5 }, {     41,    9,    7, 16, 45,  5 }, {     42,    9,    7, 16, 45,  6 }, {     43,    9,    8, 16, 45,  6 }, {     44,    9,    8, 16, 45,  6 },
    {     45,    9,    8, 16, 45,  6 }, {     46,    9,    8, 16, 45,  6 }, {     47,    9,    8, 16, 45,  6 }, {     48,    9,    8, 16, 45,  6 }, {     49,    9,    8, 16, 45,  6 },
    {     50,    9,    9, 16, 45,  6 }, {     51,    9,    9, 16, 45,  6 }, {     52,    9,    9, 16, 45,  6 }, {     53,    9,    9, 16, 45,  6 }, {     54,    9,   10, 16, 45,  7 },
    {     55,    9,   10, 16, 45,  7 }, {     56,    9,   10, 16, 45,  7 }, {     57,    9,   10, 16, 45,  7 }, {     58,    9,   11, 16, 45,  7 }, {     59,    9,   11, 16, 45,  7 },
    {     60,   10,   11, 16, 45,  7 }, {     61,   10,   11, 16, 45,  7 }, {     62,   10,   12, 16, 45,  7 }, {     63,   10,   12, 16, 45,  7 }, {     64,   10,   12, 16, 45,  7 },
    {     65,   10,   12, 16, 45,  7 }, {     66,   10,   12, 16, 45,  8 }, {     67,   10,   13, 16, 45,  8 }, {     68,   10,   13, 16, 45,  8 }, {     69,   11,   13, 16, 45,  8 },
    {     70,   11,   13, 16, 45,  8 }, {     71,   11,   13, 16, 45,  8 }, {     72,   11,   14, 16, 45,  8 }, {     73,   11,   14, 16, 45,  8 }, {     74,   11,   14, 16, 45,  8 },
    {     75,   12,   14, 16, 45,  8 }, {     76,   12,   14, 16, 45,  8 }, {     77,   12,   15, 16, 45,  8 }, {     78,   12,   15, 16, 45,  9 }, {     79,   12,   15, 16, 45,  9 },
    {     80,   13,   15, 16, 45,  9 }, {     81,   13,   15, 16, 45,  9 }, {     82,   13,   15, 16, 45,  9 }, {     83,   13,   15, 16, 45,  9 }, {     84,   13,   15, 16, 45,  9 },
    {     85,   14,   15, 16, 45,  9 }, {     86,   14,   16, 16, 45,  9 }, {     87,   14,   16, 16, 45,  9 }, {     88,   14,   16, 16, 45,  9 }, {     89,   14,   16, 16, 45,  9 },
    {     90,   15,   16,  0, 16,  0 }, {     91,   15,   16,  0, 16,  0 }, {     92,   15,   16,  0, 16,  0 }, {     93,   15,   16,  0, 16,  0 }, {     94,   16,   16,  0, 16,  0 },
    {     95,   16,   16,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91CF58, {
    {     16,   31,    1, 24, 45,  0 }, {     16,   30,    1, 24, 45,  0 }, {     16,   29,    1, 24, 45,  0 }, {     15,   28,    1, 24, 45,  0 }, {     15,   27,    1, 24, 45,  0 },
    {     15,   26,    1, 24, 45,  0 }, {     15,   25,    1, 24, 45,  1 }, {     14,   24,    1, 24, 45,  1 }, {     14,   23,    1, 24, 45,  1 }, {     14,   22,    1, 24, 45,  1 },
    {     14,   21,    1, 24, 45,  1 }, {     14,   20,    2, 24, 45,  1 }, {     13,   19,    2, 24, 45,  1 }, {     13,   18,    2, 24, 45,  1 }, {     13,   17,    2, 24, 45,  1 },
    {     13,   16,    2, 24, 45,  1 }, {     13,   15,    2, 24, 45,  1 }, {     12,   14,    2, 24, 45,  1 }, {     12,   13,    2, 24, 45,  2 }, {     12,   12,    2, 24, 45,  2 },
    {     12,   11,    3, 24, 45,  2 }, {     12,   10,    3, 24, 45,  2 }, {     11,    9,    3, 24, 45,  2 }, {     11,    8,    3, 24, 45,  2 }, {     11,    7,    3, 24, 45,  2 },
    {     11,    6,    4, 24, 45,  2 }, {     11,    5,    4, 24, 45,  2 }, {     11,    4,    4, 24, 45,  2 }, {     10,    3,    4, 24, 45,  2 }, {     10,    2,    4, 24, 45,  2 },
    {     10,    1,    5, 24, 45,  5 }, {     10,    0,    5, 24, 45,  5 }, {     10,   -1,    5, 24, 45,  5 }, {     10,   -2,    5, 24, 45,  5 }, {     10,   -3,    5, 24, 45,  5 },
    {     10,   -4,    6, 24, 45,  5 }, {     10,   -5,    6, 24, 45,  5 }, {      9,   -6,    6, 24, 45,  5 }, {      9,   -7,    6, 24, 45,  5 }, {      9,   -8,    7, 24, 45,  5 },
    {      9,   -9,    7, 24, 45,  5 }, {      9,  -10,    7, 24, 45,  5 }, {      9,  -11,    7, 24, 45,  6 }, {      9,  -12,    8, 24, 45,  6 }, {      9,  -13,    8, 24, 45,  6 },
    {      9,  -14,    8, 24, 45,  6 }, {      9,  -15,    8, 24, 45,  6 }, {      9,  -16,    8, 24, 45,  6 }, {      9,  -17,    8, 24, 45,  6 }, {      9,  -18,    8, 24, 45,  6 },
    {      9,  -19,    9, 24, 45,  6 }, {      9,  -20,    9, 24, 45,  6 }, {      9,  -21,    9, 24, 45,  6 }, {      9,  -22,    9, 24, 45,  6 }, {      9,  -23,   10, 24, 45,  7 },
    {      9,  -24,   10, 24, 45,  7 }, {      9,  -25,   10, 24, 45,  7 }, {      9,  -26,   10, 24, 45,  7 }, {      9,  -27,   11, 24, 45,  7 }, {      9,  -28,   11, 24, 45,  7 },
    {     10,  -29,   11, 24, 45,  7 }, {     10,  -30,   11, 24, 45,  7 }, {     10,  -31,   12, 24, 45,  7 }, {     10,  -32,   12, 24, 45,  7 }, {     10,  -33,   12, 24, 45,  7 },
    {     10,  -34,   12, 24, 45,  7 }, {     10,  -35,   12, 24, 45,  8 }, {     10,  -36,   13, 24, 45,  8 }, {     10,  -37,   13, 24, 45,  8 }, {     11,  -38,   13, 24, 45,  8 },
    {     11,  -39,   13, 24, 45,  8 }, {     11,  -40,   13, 24, 45,  8 }, {     11,  -41,   14, 24, 45,  8 }, {     11,  -42,   14, 24, 45,  8 }, {     11,  -43,   14, 24, 45,  8 },
    {     12,  -44,   14, 24, 45,  8 }, {     12,  -45,   14, 24, 45,  8 }, {     12,  -46,   15, 24, 45,  8 }, {     12,  -47,   15, 24, 45,  9 }, {     12,  -48,   15, 24, 45,  9 },
    {     13,  -49,   15, 24, 45,  9 }, {     13,  -50,   15, 24, 45,  9 }, {     13,  -51,   15, 24, 45,  9 }, {     13,  -52,   15, 24, 45,  9 }, {     13,  -53,   15, 24, 45,  9 },
    {     14,  -54,   15, 24, 45,  9 }, {     14,  -55,   16, 24, 45,  9 }, {     14,  -56,   16, 24, 45,  9 }, {     14,  -57,   16, 24, 45,  9 }, {     14,  -58,   16, 24, 45,  9 },
    {     15,  -59,   16,  8, 16,  0 }, {     15,  -60,   16,  8, 16,  0 }, {     15,  -61,   16,  8, 16,  0 }, {     15,  -62,   16,  8, 16,  0 }, {     16,  -63,   16,  8, 16,  0 },
    {     16,  -64,   16,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91D2BA, {
    {     31,   16,    1,  0, 45,  0 }, {     30,   16,    1,  0, 45,  0 }, {     29,   16,    1,  0, 45,  0 }, {     28,   15,    1,  0, 45,  0 }, {     27,   15,    1,  0, 45,  0 },
    {     26,   15,    1,  0, 45,  0 }, {     25,   15,    1,  0, 45,  3 }, {     24,   14,    1,  0, 45,  3 }, {     23,   14,    1,  0, 45,  3 }, {     22,   14,    1,  0, 45,  3 },
    {     21,   14,    1,  0, 45,  3 }, {     20,   14,    2,  0, 45,  3 }, {     19,   13,    2,  0, 45,  3 }, {     18,   13,    2,  0, 45,  3 }, {     17,   13,    2,  0, 45,  3 },
    {     16,   13,    2,  0, 45,  3 }, {     15,   13,    2,  0, 45,  3 }, {     14,   12,    2,  0, 45,  3 }, {     13,   12,    2,  0, 45,  4 }, {     12,   12,    2,  0, 45,  4 },
    {     11,   12,    3,  0, 45,  4 }, {     10,   12,    3,  0, 45,  4 }, {      9,   11,    3,  0, 45,  4 }, {      8,   11,    3,  0, 45,  4 }, {      7,   11,    3,  0, 45,  4 },
    {      6,   11,    4,  0, 45,  4 }, {      5,   11,    4,  0, 45,  4 }, {      4,   11,    4,  0, 45,  4 }, {      3,   10,    4,  0, 45,  4 }, {      2,   10,    4,  0, 45,  4 },
    {      1,   10,    5,  0, 45, 10 }, {      0,   10,    5,  0, 45, 10 }, {     -1,   10,    5,  0, 45, 10 }, {     -2,   10,    5,  0, 45, 10 }, {     -3,   10,    5,  0, 45, 10 },
    {     -4,   10,    6,  0, 45, 10 }, {     -5,   10,    6,  0, 45, 10 }, {     -6,    9,    6,  0, 45, 10 }, {     -7,    9,    6,  0, 45, 10 }, {     -8,    9,    7,  0, 45, 10 },
    {     -9,    9,    7,  0, 45, 10 }, {    -10,    9,    7,  0, 45, 10 }, {    -11,    9,    7,  0, 45, 11 }, {    -12,    9,    8,  0, 45, 11 }, {    -13,    9,    8,  0, 45, 11 },
    {    -14,    9,    8,  0, 45, 11 }, {    -15,    9,    8,  0, 45, 11 }, {    -16,    9,    8,  0, 45, 11 }, {    -17,    9,    8,  0, 45, 11 }, {    -18,    9,    8,  0, 45, 11 },
    {    -19,    9,    9,  0, 45, 11 }, {    -20,    9,    9,  0, 45, 11 }, {    -21,    9,    9,  0, 45, 11 }, {    -22,    9,    9,  0, 45, 11 }, {    -23,    9,   10,  0, 45, 12 },
    {    -24,    9,   10,  0, 45, 12 }, {    -25,    9,   10,  0, 45, 12 }, {    -26,    9,   10,  0, 45, 12 }, {    -27,    9,   11,  0, 45, 12 }, {    -28,    9,   11,  0, 45, 12 },
    {    -29,   10,   11,  0, 45, 12 }, {    -30,   10,   11,  0, 45, 12 }, {    -31,   10,   12,  0, 45, 12 }, {    -32,   10,   12,  0, 45, 12 }, {    -33,   10,   12,  0, 45, 12 },
    {    -34,   10,   12,  0, 45, 12 }, {    -35,   10,   12,  0, 45, 13 }, {    -36,   10,   13,  0, 45, 13 }, {    -37,   10,   13,  0, 45, 13 }, {    -38,   11,   13,  0, 45, 13 },
    {    -39,   11,   13,  0, 45, 13 }, {    -40,   11,   13,  0, 45, 13 }, {    -41,   11,   14,  0, 45, 13 }, {    -42,   11,   14,  0, 45, 13 }, {    -43,   11,   14,  0, 45, 13 },
    {    -44,   12,   14,  0, 45, 13 }, {    -45,   12,   14,  0, 45, 13 }, {    -46,   12,   15,  0, 45, 13 }, {    -47,   12,   15,  0, 45, 14 }, {    -48,   12,   15,  0, 45, 14 },
    {    -49,   13,   15,  0, 45, 14 }, {    -50,   13,   15,  0, 45, 14 }, {    -51,   13,   15,  0, 45, 14 }, {    -52,   13,   15,  0, 45, 14 }, {    -53,   13,   15,  0, 45, 14 },
    {    -54,   14,   15,  0, 45, 14 }, {    -55,   14,   16,  0, 45, 14 }, {    -56,   14,   16,  0, 45, 14 }, {    -57,   14,   16,  0, 45, 14 }, {    -58,   14,   16,  0, 45, 14 },
    {    -59,   15,   16, 16, 16,  0 }, {    -60,   15,   16, 16, 16,  0 }, {    -61,   15,   16, 16, 16,  0 }, {    -62,   15,   16, 16, 16,  0 }, {    -63,   16,   16, 16, 16,  0 },
    {    -64,   16,   16, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91D61C, {
    {     16,    0,    1,  8, 45,  0 }, {     16,    1,    1,  8, 45,  0 }, {     16,    2,    1,  8, 45,  0 }, {     15,    3,    1,  8, 45,  0 }, {     15,    4,    1,  8, 45,  0 },
    {     15,    5,    1,  8, 45,  0 }, {     15,    6,    1,  8, 45,  3 }, {     14,    7,    1,  8, 45,  3 }, {     14,    8,    1,  8, 45,  3 }, {     14,    9,    1,  8, 45,  3 },
    {     14,   10,    1,  8, 45,  3 }, {     14,   11,    2,  8, 45,  3 }, {     13,   12,    2,  8, 45,  3 }, {     13,   13,    2,  8, 45,  3 }, {     13,   14,    2,  8, 45,  3 },
    {     13,   15,    2,  8, 45,  3 }, {     13,   16,    2,  8, 45,  3 }, {     12,   17,    2,  8, 45,  3 }, {     12,   18,    2,  8, 45,  4 }, {     12,   19,    2,  8, 45,  4 },
    {     12,   20,    3,  8, 45,  4 }, {     12,   21,    3,  8, 45,  4 }, {     11,   22,    3,  8, 45,  4 }, {     11,   23,    3,  8, 45,  4 }, {     11,   24,    3,  8, 45,  4 },
    {     11,   25,    4,  8, 45,  4 }, {     11,   26,    4,  8, 45,  4 }, {     11,   27,    4,  8, 45,  4 }, {     10,   28,    4,  8, 45,  4 }, {     10,   29,    4,  8, 45,  4 },
    {     10,   30,    5,  8, 45, 10 }, {     10,   31,    5,  8, 45, 10 }, {     10,   32,    5,  8, 45, 10 }, {     10,   33,    5,  8, 45, 10 }, {     10,   34,    5,  8, 45, 10 },
    {     10,   35,    6,  8, 45, 10 }, {     10,   36,    6,  8, 45, 10 }, {      9,   37,    6,  8, 45, 10 }, {      9,   38,    6,  8, 45, 10 }, {      9,   39,    7,  8, 45, 10 },
    {      9,   40,    7,  8, 45, 10 }, {      9,   41,    7,  8, 45, 10 }, {      9,   42,    7,  8, 45, 11 }, {      9,   43,    8,  8, 45, 11 }, {      9,   44,    8,  8, 45, 11 },
    {      9,   45,    8,  8, 45, 11 }, {      9,   46,    8,  8, 45, 11 }, {      9,   47,    8,  8, 45, 11 }, {      9,   48,    8,  8, 45, 11 }, {      9,   49,    8,  8, 45, 11 },
    {      9,   50,    9,  8, 45, 11 }, {      9,   51,    9,  8, 45, 11 }, {      9,   52,    9,  8, 45, 11 }, {      9,   53,    9,  8, 45, 11 }, {      9,   54,   10,  8, 45, 12 },
    {      9,   55,   10,  8, 45, 12 }, {      9,   56,   10,  8, 45, 12 }, {      9,   57,   10,  8, 45, 12 }, {      9,   58,   11,  8, 45, 12 }, {      9,   59,   11,  8, 45, 12 },
    {     10,   60,   11,  8, 45, 12 }, {     10,   61,   11,  8, 45, 12 }, {     10,   62,   12,  8, 45, 12 }, {     10,   63,   12,  8, 45, 12 }, {     10,   64,   12,  8, 45, 12 },
    {     10,   65,   12,  8, 45, 12 }, {     10,   66,   12,  8, 45, 13 }, {     10,   67,   13,  8, 45, 13 }, {     10,   68,   13,  8, 45, 13 }, {     11,   69,   13,  8, 45, 13 },
    {     11,   70,   13,  8, 45, 13 }, {     11,   71,   13,  8, 45, 13 }, {     11,   72,   14,  8, 45, 13 }, {     11,   73,   14,  8, 45, 13 }, {     11,   74,   14,  8, 45, 13 },
    {     12,   75,   14,  8, 45, 13 }, {     12,   76,   14,  8, 45, 13 }, {     12,   77,   15,  8, 45, 13 }, {     12,   78,   15,  8, 45, 14 }, {     12,   79,   15,  8, 45, 14 },
    {     13,   80,   15,  8, 45, 14 }, {     13,   81,   15,  8, 45, 14 }, {     13,   82,   15,  8, 45, 14 }, {     13,   83,   15,  8, 45, 14 }, {     13,   84,   15,  8, 45, 14 },
    {     14,   85,   15,  8, 45, 14 }, {     14,   86,   16,  8, 45, 14 }, {     14,   87,   16,  8, 45, 14 }, {     14,   88,   16,  8, 45, 14 }, {     14,   89,   16,  8, 45, 14 },
    {     15,   90,   16, 24, 16,  0 }, {     15,   91,   16, 24, 16,  0 }, {     15,   92,   16, 24, 16,  0 }, {     15,   93,   16, 24, 16,  0 }, {     16,   94,   16, 24, 16,  0 },
    {     16,   95,   16, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91D97E, {
    {      0,   16,    1, 16, 45,  0 }, {      1,   16,    1, 16, 45,  0 }, {      2,   16,    1, 16, 45,  0 }, {      3,   17,    1, 16, 45,  0 }, {      4,   17,    1, 16, 45,  0 },
    {      5,   17,    1, 16, 45,  0 }, {      6,   17,    1, 16, 45,  3 }, {      7,   18,    1, 16, 45,  3 }, {      8,   18,    1, 16, 45,  3 }, {      9,   18,    1, 16, 45,  3 },
    {     10,   18,    1, 16, 45,  3 }, {     11,   18,    2, 16, 45,  3 }, {     12,   19,    2, 16, 45,  3 }, {     13,   19,    2, 16, 45,  3 }, {     14,   19,    2, 16, 45,  3 },
    {     15,   19,    2, 16, 45,  3 }, {     16,   19,    2, 16, 45,  3 }, {     17,   20,    2, 16, 45,  3 }, {     18,   20,    2, 16, 45,  4 }, {     19,   20,    2, 16, 45,  4 },
    {     20,   20,    3, 16, 45,  4 }, {     21,   20,    3, 16, 45,  4 }, {     22,   21,    3, 16, 45,  4 }, {     23,   21,    3, 16, 45,  4 }, {     24,   21,    3, 16, 45,  4 },
    {     25,   21,    4, 16, 45,  4 }, {     26,   21,    4, 16, 45,  4 }, {     27,   21,    4, 16, 45,  4 }, {     28,   22,    4, 16, 45,  4 }, {     29,   22,    4, 16, 45,  4 },
    {     30,   22,    5, 16, 45, 10 }, {     31,   22,    5, 16, 45, 10 }, {     32,   22,    5, 16, 45, 10 }, {     33,   22,    5, 16, 45, 10 }, {     34,   22,    5, 16, 45, 10 },
    {     35,   22,    6, 16, 45, 10 }, {     36,   22,    6, 16, 45, 10 }, {     37,   23,    6, 16, 45, 10 }, {     38,   23,    6, 16, 45, 10 }, {     39,   23,    7, 16, 45, 10 },
    {     40,   23,    7, 16, 45, 10 }, {     41,   23,    7, 16, 45, 10 }, {     42,   23,    7, 16, 45, 11 }, {     43,   23,    8, 16, 45, 11 }, {     44,   23,    8, 16, 45, 11 },
    {     45,   23,    8, 16, 45, 11 }, {     46,   23,    8, 16, 45, 11 }, {     47,   23,    8, 16, 45, 11 }, {     48,   23,    8, 16, 45, 11 }, {     49,   23,    8, 16, 45, 11 },
    {     50,   23,    9, 16, 45, 11 }, {     51,   23,    9, 16, 45, 11 }, {     52,   23,    9, 16, 45, 11 }, {     53,   23,    9, 16, 45, 11 }, {     54,   23,   10, 16, 45, 12 },
    {     55,   23,   10, 16, 45, 12 }, {     56,   23,   10, 16, 45, 12 }, {     57,   23,   10, 16, 45, 12 }, {     58,   23,   11, 16, 45, 12 }, {     59,   23,   11, 16, 45, 12 },
    {     60,   22,   11, 16, 45, 12 }, {     61,   22,   11, 16, 45, 12 }, {     62,   22,   12, 16, 45, 12 }, {     63,   22,   12, 16, 45, 12 }, {     64,   22,   12, 16, 45, 12 },
    {     65,   22,   12, 16, 45, 12 }, {     66,   22,   12, 16, 45, 13 }, {     67,   22,   13, 16, 45, 13 }, {     68,   22,   13, 16, 45, 13 }, {     69,   21,   13, 16, 45, 13 },
    {     70,   21,   13, 16, 45, 13 }, {     71,   21,   13, 16, 45, 13 }, {     72,   21,   14, 16, 45, 13 }, {     73,   21,   14, 16, 45, 13 }, {     74,   21,   14, 16, 45, 13 },
    {     75,   20,   14, 16, 45, 13 }, {     76,   20,   14, 16, 45, 13 }, {     77,   20,   15, 16, 45, 13 }, {     78,   20,   15, 16, 45, 14 }, {     79,   20,   15, 16, 45, 14 },
    {     80,   19,   15, 16, 45, 14 }, {     81,   19,   15, 16, 45, 14 }, {     82,   19,   15, 16, 45, 14 }, {     83,   19,   15, 16, 45, 14 }, {     84,   19,   15, 16, 45, 14 },
    {     85,   18,   15, 16, 45, 14 }, {     86,   18,   16, 16, 45, 14 }, {     87,   18,   16, 16, 45, 14 }, {     88,   18,   16, 16, 45, 14 }, {     89,   18,   16, 16, 45, 14 },
    {     90,   17,   16,  0, 16,  0 }, {     91,   17,   16,  0, 16,  0 }, {     92,   17,   16,  0, 16,  0 }, {     93,   17,   16,  0, 16,  0 }, {     94,   16,   16,  0, 16,  0 },
    {     95,   16,   16,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91DCE0, {
    {     16,   31,    1, 24, 45,  0 }, {     16,   30,    1, 24, 45,  0 }, {     16,   29,    1, 24, 45,  0 }, {     17,   28,    1, 24, 45,  0 }, {     17,   27,    1, 24, 45,  0 },
    {     17,   26,    1, 24, 45,  0 }, {     17,   25,    1, 24, 45,  3 }, {     18,   24,    1, 24, 45,  3 }, {     18,   23,    1, 24, 45,  3 }, {     18,   22,    1, 24, 45,  3 },
    {     18,   21,    1, 24, 45,  3 }, {     18,   20,    2, 24, 45,  3 }, {     19,   19,    2, 24, 45,  3 }, {     19,   18,    2, 24, 45,  3 }, {     19,   17,    2, 24, 45,  3 },
    {     19,   16,    2, 24, 45,  3 }, {     19,   15,    2, 24, 45,  3 }, {     20,   14,    2, 24, 45,  3 }, {     20,   13,    2, 24, 45,  4 }, {     20,   12,    2, 24, 45,  4 },
    {     20,   11,    3, 24, 45,  4 }, {     20,   10,    3, 24, 45,  4 }, {     21,    9,    3, 24, 45,  4 }, {     21,    8,    3, 24, 45,  4 }, {     21,    7,    3, 24, 45,  4 },
    {     21,    6,    4, 24, 45,  4 }, {     21,    5,    4, 24, 45,  4 }, {     21,    4,    4, 24, 45,  4 }, {     22,    3,    4, 24, 45,  4 }, {     22,    2,    4, 24, 45,  4 },
    {     22,    1,    5, 24, 45, 10 }, {     22,    0,    5, 24, 45, 10 }, {     22,   -1,    5, 24, 45, 10 }, {     22,   -2,    5, 24, 45, 10 }, {     22,   -3,    5, 24, 45, 10 },
    {     22,   -4,    6, 24, 45, 10 }, {     22,   -5,    6, 24, 45, 10 }, {     23,   -6,    6, 24, 45, 10 }, {     23,   -7,    6, 24, 45, 10 }, {     23,   -8,    7, 24, 45, 10 },
    {     23,   -9,    7, 24, 45, 10 }, {     23,  -10,    7, 24, 45, 10 }, {     23,  -11,    7, 24, 45, 11 }, {     23,  -12,    8, 24, 45, 11 }, {     23,  -13,    8, 24, 45, 11 },
    {     23,  -14,    8, 24, 45, 11 }, {     23,  -15,    8, 24, 45, 11 }, {     23,  -16,    8, 24, 45, 11 }, {     23,  -17,    8, 24, 45, 11 }, {     23,  -18,    8, 24, 45, 11 },
    {     23,  -19,    9, 24, 45, 11 }, {     23,  -20,    9, 24, 45, 11 }, {     23,  -21,    9, 24, 45, 11 }, {     23,  -22,    9, 24, 45, 11 }, {     23,  -23,   10, 24, 45, 12 },
    {     23,  -24,   10, 24, 45, 12 }, {     23,  -25,   10, 24, 45, 12 }, {     23,  -26,   10, 24, 45, 12 }, {     23,  -27,   11, 24, 45, 12 }, {     23,  -28,   11, 24, 45, 12 },
    {     22,  -29,   11, 24, 45, 12 }, {     22,  -30,   11, 24, 45, 12 }, {     22,  -31,   12, 24, 45, 12 }, {     22,  -32,   12, 24, 45, 12 }, {     22,  -33,   12, 24, 45, 12 },
    {     22,  -34,   12, 24, 45, 12 }, {     22,  -35,   12, 24, 45, 13 }, {     22,  -36,   13, 24, 45, 13 }, {     22,  -37,   13, 24, 45, 13 }, {     21,  -38,   13, 24, 45, 13 },
    {     21,  -39,   13, 24, 45, 13 }, {     21,  -40,   13, 24, 45, 13 }, {     21,  -41,   14, 24, 45, 13 }, {     21,  -42,   14, 24, 45, 13 }, {     21,  -43,   14, 24, 45, 13 },
    {     20,  -44,   14, 24, 45, 13 }, {     20,  -45,   14, 24, 45, 13 }, {     20,  -46,   15, 24, 45, 13 }, {     20,  -47,   15, 24, 45, 14 }, {     20,  -48,   15, 24, 45, 14 },
    {     19,  -49,   15, 24, 45, 14 }, {     19,  -50,   15, 24, 45, 14 }, {     19,  -51,   15, 24, 45, 14 }, {     19,  -52,   15, 24, 45, 14 }, {     19,  -53,   15, 24, 45, 14 },
    {     18,  -54,   15, 24, 45, 14 }, {     18,  -55,   16, 24, 45, 14 }, {     18,  -56,   16, 24, 45, 14 }, {     18,  -57,   16, 24, 45, 14 }, {     18,  -58,   16, 24, 45, 14 },
    {     17,  -59,   16,  8, 16,  0 }, {     17,  -60,   16,  8, 16,  0 }, {     17,  -61,   16,  8, 16,  0 }, {     17,  -62,   16,  8, 16,  0 }, {     16,  -63,   16,  8, 16,  0 },
    {     16,  -64,   16,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91E042, {
    {     31,   16,   15, 16, 16,  0 }, {     30,   16,   15, 16, 16,  0 }, {     29,   16,   15, 16, 16,  0 }, {     28,   15,   15, 16, 16,  0 }, {     27,   15,   15, 16, 16,  0 },
    {     26,   15,   15, 16, 16,  0 }, {     25,   15,   15,  0, 47, 14 }, {     24,   14,   15,  0, 47, 14 }, {     23,   14,   15,  0, 47, 14 }, {     22,   14,   15,  0, 47, 14 },
    {     21,   14,   15,  0, 47, 14 }, {     20,   14,   14,  0, 47, 14 }, {     19,   13,   14,  0, 47, 14 }, {     18,   13,   14,  0, 47, 14 }, {     17,   13,   14,  0, 47, 14 },
    {     16,   13,   14,  0, 47, 14 }, {     15,   13,   14,  0, 47, 14 }, {     14,   12,   14,  0, 47, 14 }, {     13,   12,   14,  0, 47, 13 }, {     12,   12,   14,  0, 47, 13 },
    {     11,   12,   13,  0, 47, 13 }, {     10,   12,   13,  0, 47, 13 }, {      9,   11,   13,  0, 47, 13 }, {      8,   11,   13,  0, 47, 13 }, {      7,   11,   13,  0, 47, 13 },
    {      6,   11,   12,  0, 47, 13 }, {      5,   11,   12,  0, 47, 13 }, {      4,   11,   12,  0, 47, 13 }, {      3,   10,   12,  0, 47, 13 }, {      2,   10,   12,  0, 47, 13 },
    {      1,   10,   11,  0, 47, 12 }, {      0,   10,   11,  0, 47, 12 }, {     -1,   10,   11,  0, 47, 12 }, {     -2,   10,   11,  0, 47, 12 }, {     -3,   10,   11,  0, 47, 12 },
    {     -4,   10,   10,  0, 47, 12 }, {     -5,   10,   10,  0, 47, 12 }, {     -6,    9,   10,  0, 47, 12 }, {     -7,    9,   10,  0, 47, 12 }, {     -8,    9,    9,  0, 47, 12 },
    {     -9,    9,    9,  0, 47, 12 }, {    -10,    9,    9,  0, 47, 12 }, {    -11,    9,    9,  0, 47, 11 }, {    -12,    9,    8,  0, 47, 11 }, {    -13,    9,    8,  0, 47, 11 },
    {    -14,    9,    8,  0, 47, 11 }, {    -15,    9,    8,  0, 47, 11 }, {    -16,    9,    8,  0, 47, 11 }, {    -17,    9,    8,  0, 47, 11 }, {    -18,    9,    8,  0, 47, 11 },
    {    -19,    9,    7,  0, 47, 11 }, {    -20,    9,    7,  0, 47, 11 }, {    -21,    9,    7,  0, 47, 11 }, {    -22,    9,    7,  0, 47, 11 }, {    -23,    9,    6,  0, 47, 10 },
    {    -24,    9,    6,  0, 47, 10 }, {    -25,    9,    6,  0, 47, 10 }, {    -26,    9,    6,  0, 47, 10 }, {    -27,    9,    5,  0, 47, 10 }, {    -28,    9,    5,  0, 47, 10 },
    {    -29,   10,    5,  0, 47, 10 }, {    -30,   10,    5,  0, 47, 10 }, {    -31,   10,    4,  0, 47, 10 }, {    -32,   10,    4,  0, 47, 10 }, {    -33,   10,    4,  0, 47, 10 },
    {    -34,   10,    4,  0, 47, 10 }, {    -35,   10,    4,  0, 47,  4 }, {    -36,   10,    3,  0, 47,  4 }, {    -37,   10,    3,  0, 47,  4 }, {    -38,   11,    3,  0, 47,  4 },
    {    -39,   11,    3,  0, 47,  4 }, {    -40,   11,    3,  0, 47,  4 }, {    -41,   11,    2,  0, 47,  4 }, {    -42,   11,    2,  0, 47,  4 }, {    -43,   11,    2,  0, 47,  4 },
    {    -44,   12,    2,  0, 47,  4 }, {    -45,   12,    2,  0, 47,  4 }, {    -46,   12,    1,  0, 47,  4 }, {    -47,   12,    1,  0, 47,  3 }, {    -48,   12,    1,  0, 47,  3 },
    {    -49,   13,    1,  0, 47,  3 }, {    -50,   13,    1,  0, 47,  3 }, {    -51,   13,    1,  0, 47,  3 }, {    -52,   13,    1,  0, 47,  3 }, {    -53,   13,    1,  0, 47,  3 },
    {    -54,   14,    1,  0, 47,  3 }, {    -55,   14,    0,  0, 47,  3 }, {    -56,   14,    0,  0, 47,  3 }, {    -57,   14,    0,  0, 47,  3 }, {    -58,   14,    0,  0, 47,  3 },
    {    -59,   15,    0,  0, 47,  0 }, {    -60,   15,    0,  0, 47,  0 }, {    -61,   15,    0,  0, 47,  0 }, {    -62,   15,    0,  0, 47,  0 }, {    -63,   16,    0,  0, 47,  0 },
    {    -64,   16,    0,  0, 47,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91E3A4, {
    {     16,    0,   15, 24, 16,  0 }, {     16,    1,   15, 24, 16,  0 }, {     16,    2,   15, 24, 16,  0 }, {     15,    3,   15, 24, 16,  0 }, {     15,    4,   15, 24, 16,  0 },
    {     15,    5,   15, 24, 16,  0 }, {     15,    6,   15,  8, 47, 14 }, {     14,    7,   15,  8, 47, 14 }, {     14,    8,   15,  8, 47, 14 }, {     14,    9,   15,  8, 47, 14 },
    {     14,   10,   15,  8, 47, 14 }, {     14,   11,   14,  8, 47, 14 }, {     13,   12,   14,  8, 47, 14 }, {     13,   13,   14,  8, 47, 14 }, {     13,   14,   14,  8, 47, 14 },
    {     13,   15,   14,  8, 47, 14 }, {     13,   16,   14,  8, 47, 14 }, {     12,   17,   14,  8, 47, 14 }, {     12,   18,   14,  8, 47, 13 }, {     12,   19,   14,  8, 47, 13 },
    {     12,   20,   13,  8, 47, 13 }, {     12,   21,   13,  8, 47, 13 }, {     11,   22,   13,  8, 47, 13 }, {     11,   23,   13,  8, 47, 13 }, {     11,   24,   13,  8, 47, 13 },
    {     11,   25,   12,  8, 47, 13 }, {     11,   26,   12,  8, 47, 13 }, {     11,   27,   12,  8, 47, 13 }, {     10,   28,   12,  8, 47, 13 }, {     10,   29,   12,  8, 47, 13 },
    {     10,   30,   11,  8, 47, 12 }, {     10,   31,   11,  8, 47, 12 }, {     10,   32,   11,  8, 47, 12 }, {     10,   33,   11,  8, 47, 12 }, {     10,   34,   11,  8, 47, 12 },
    {     10,   35,   10,  8, 47, 12 }, {     10,   36,   10,  8, 47, 12 }, {      9,   37,   10,  8, 47, 12 }, {      9,   38,   10,  8, 47, 12 }, {      9,   39,    9,  8, 47, 12 },
    {      9,   40,    9,  8, 47, 12 }, {      9,   41,    9,  8, 47, 12 }, {      9,   42,    9,  8, 47, 11 }, {      9,   43,    8,  8, 47, 11 }, {      9,   44,    8,  8, 47, 11 },
    {      9,   45,    8,  8, 47, 11 }, {      9,   46,    8,  8, 47, 11 }, {      9,   47,    8,  8, 47, 11 }, {      9,   48,    8,  8, 47, 11 }, {      9,   49,    8,  8, 47, 11 },
    {      9,   50,    7,  8, 47, 11 }, {      9,   51,    7,  8, 47, 11 }, {      9,   52,    7,  8, 47, 11 }, {      9,   53,    7,  8, 47, 11 }, {      9,   54,    6,  8, 47, 10 },
    {      9,   55,    6,  8, 47, 10 }, {      9,   56,    6,  8, 47, 10 }, {      9,   57,    6,  8, 47, 10 }, {      9,   58,    5,  8, 47, 10 }, {      9,   59,    5,  8, 47, 10 },
    {     10,   60,    5,  8, 47, 10 }, {     10,   61,    5,  8, 47, 10 }, {     10,   62,    4,  8, 47, 10 }, {     10,   63,    4,  8, 47, 10 }, {     10,   64,    4,  8, 47, 10 },
    {     10,   65,    4,  8, 47, 10 }, {     10,   66,    4,  8, 47,  4 }, {     10,   67,    3,  8, 47,  4 }, {     10,   68,    3,  8, 47,  4 }, {     11,   69,    3,  8, 47,  4 },
    {     11,   70,    3,  8, 47,  4 }, {     11,   71,    3,  8, 47,  4 }, {     11,   72,    2,  8, 47,  4 }, {     11,   73,    2,  8, 47,  4 }, {     11,   74,    2,  8, 47,  4 },
    {     12,   75,    2,  8, 47,  4 }, {     12,   76,    2,  8, 47,  4 }, {     12,   77,    1,  8, 47,  4 }, {     12,   78,    1,  8, 47,  3 }, {     12,   79,    1,  8, 47,  3 },
    {     13,   80,    1,  8, 47,  3 }, {     13,   81,    1,  8, 47,  3 }, {     13,   82,    1,  8, 47,  3 }, {     13,   83,    1,  8, 47,  3 }, {     13,   84,    1,  8, 47,  3 },
    {     14,   85,    1,  8, 47,  3 }, {     14,   86,    0,  8, 47,  3 }, {     14,   87,    0,  8, 47,  3 }, {     14,   88,    0,  8, 47,  3 }, {     14,   89,    0,  8, 47,  3 },
    {     15,   90,    0,  8, 47,  0 }, {     15,   91,    0,  8, 47,  0 }, {     15,   92,    0,  8, 47,  0 }, {     15,   93,    0,  8, 47,  0 }, {     16,   94,    0,  8, 47,  0 },
    {     16,   95,    0,  8, 47,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91E706, {
    {      0,   16,   15,  0, 16,  0 }, {      1,   16,   15,  0, 16,  0 }, {      2,   16,   15,  0, 16,  0 }, {      3,   17,   15,  0, 16,  0 }, {      4,   17,   15,  0, 16,  0 },
    {      5,   17,   15,  0, 16,  0 }, {      6,   17,   15, 16, 47, 14 }, {      7,   18,   15, 16, 47, 14 }, {      8,   18,   15, 16, 47, 14 }, {      9,   18,   15, 16, 47, 14 },
    {     10,   18,   15, 16, 47, 14 }, {     11,   18,   14, 16, 47, 14 }, {     12,   19,   14, 16, 47, 14 }, {     13,   19,   14, 16, 47, 14 }, {     14,   19,   14, 16, 47, 14 },
    {     15,   19,   14, 16, 47, 14 }, {     16,   19,   14, 16, 47, 14 }, {     17,   20,   14, 16, 47, 14 }, {     18,   20,   14, 16, 47, 13 }, {     19,   20,   14, 16, 47, 13 },
    {     20,   20,   13, 16, 47, 13 }, {     21,   20,   13, 16, 47, 13 }, {     22,   21,   13, 16, 47, 13 }, {     23,   21,   13, 16, 47, 13 }, {     24,   21,   13, 16, 47, 13 },
    {     25,   21,   12, 16, 47, 13 }, {     26,   21,   12, 16, 47, 13 }, {     27,   21,   12, 16, 47, 13 }, {     28,   22,   12, 16, 47, 13 }, {     29,   22,   12, 16, 47, 13 },
    {     30,   22,   11, 16, 47, 12 }, {     31,   22,   11, 16, 47, 12 }, {     32,   22,   11, 16, 47, 12 }, {     33,   22,   11, 16, 47, 12 }, {     34,   22,   11, 16, 47, 12 },
    {     35,   22,   10, 16, 47, 12 }, {     36,   22,   10, 16, 47, 12 }, {     37,   23,   10, 16, 47, 12 }, {     38,   23,   10, 16, 47, 12 }, {     39,   23,    9, 16, 47, 12 },
    {     40,   23,    9, 16, 47, 12 }, {     41,   23,    9, 16, 47, 12 }, {     42,   23,    9, 16, 47, 11 }, {     43,   23,    8, 16, 47, 11 }, {     44,   23,    8, 16, 47, 11 },
    {     45,   23,    8, 16, 47, 11 }, {     46,   23,    8, 16, 47, 11 }, {     47,   23,    8, 16, 47, 11 }, {     48,   23,    8, 16, 47, 11 }, {     49,   23,    8, 16, 47, 11 },
    {     50,   23,    7, 16, 47, 11 }, {     51,   23,    7, 16, 47, 11 }, {     52,   23,    7, 16, 47, 11 }, {     53,   23,    7, 16, 47, 11 }, {     54,   23,    6, 16, 47, 10 },
    {     55,   23,    6, 16, 47, 10 }, {     56,   23,    6, 16, 47, 10 }, {     57,   23,    6, 16, 47, 10 }, {     58,   23,    5, 16, 47, 10 }, {     59,   23,    5, 16, 47, 10 },
    {     60,   22,    5, 16, 47, 10 }, {     61,   22,    5, 16, 47, 10 }, {     62,   22,    4, 16, 47, 10 }, {     63,   22,    4, 16, 47, 10 }, {     64,   22,    4, 16, 47, 10 },
    {     65,   22,    4, 16, 47, 10 }, {     66,   22,    4, 16, 47,  4 }, {     67,   22,    3, 16, 47,  4 }, {     68,   22,    3, 16, 47,  4 }, {     69,   21,    3, 16, 47,  4 },
    {     70,   21,    3, 16, 47,  4 }, {     71,   21,    3, 16, 47,  4 }, {     72,   21,    2, 16, 47,  4 }, {     73,   21,    2, 16, 47,  4 }, {     74,   21,    2, 16, 47,  4 },
    {     75,   20,    2, 16, 47,  4 }, {     76,   20,    2, 16, 47,  4 }, {     77,   20,    1, 16, 47,  4 }, {     78,   20,    1, 16, 47,  3 }, {     79,   20,    1, 16, 47,  3 },
    {     80,   19,    1, 16, 47,  3 }, {     81,   19,    1, 16, 47,  3 }, {     82,   19,    1, 16, 47,  3 }, {     83,   19,    1, 16, 47,  3 }, {     84,   19,    1, 16, 47,  3 },
    {     85,   18,    1, 16, 47,  3 }, {     86,   18,    0, 16, 47,  3 }, {     87,   18,    0, 16, 47,  3 }, {     88,   18,    0, 16, 47,  3 }, {     89,   18,    0, 16, 47,  3 },
    {     90,   17,    0, 16, 47,  0 }, {     91,   17,    0, 16, 47,  0 }, {     92,   17,    0, 16, 47,  0 }, {     93,   17,    0, 16, 47,  0 }, {     94,   16,    0, 16, 47,  0 },
    {     95,   16,    0, 16, 47,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91EA68, {
    {     16,   31,   15,  8, 16,  0 }, {     16,   30,   15,  8, 16,  0 }, {     16,   29,   15,  8, 16,  0 }, {     17,   28,   15,  8, 16,  0 }, {     17,   27,   15,  8, 16,  0 },
    {     17,   26,   15,  8, 16,  0 }, {     17,   25,   15, 24, 47, 14 }, {     18,   24,   15, 24, 47, 14 }, {     18,   23,   15, 24, 47, 14 }, {     18,   22,   15, 24, 47, 14 },
    {     18,   21,   15, 24, 47, 14 }, {     18,   20,   14, 24, 47, 14 }, {     19,   19,   14, 24, 47, 14 }, {     19,   18,   14, 24, 47, 14 }, {     19,   17,   14, 24, 47, 14 },
    {     19,   16,   14, 24, 47, 14 }, {     19,   15,   14, 24, 47, 14 }, {     20,   14,   14, 24, 47, 14 }, {     20,   13,   14, 24, 47, 13 }, {     20,   12,   14, 24, 47, 13 },
    {     20,   11,   13, 24, 47, 13 }, {     20,   10,   13, 24, 47, 13 }, {     21,    9,   13, 24, 47, 13 }, {     21,    8,   13, 24, 47, 13 }, {     21,    7,   13, 24, 47, 13 },
    {     21,    6,   12, 24, 47, 13 }, {     21,    5,   12, 24, 47, 13 }, {     21,    4,   12, 24, 47, 13 }, {     22,    3,   12, 24, 47, 13 }, {     22,    2,   12, 24, 47, 13 },
    {     22,    1,   11, 24, 47, 12 }, {     22,    0,   11, 24, 47, 12 }, {     22,   -1,   11, 24, 47, 12 }, {     22,   -2,   11, 24, 47, 12 }, {     22,   -3,   11, 24, 47, 12 },
    {     22,   -4,   10, 24, 47, 12 }, {     22,   -5,   10, 24, 47, 12 }, {     23,   -6,   10, 24, 47, 12 }, {     23,   -7,   10, 24, 47, 12 }, {     23,   -8,    9, 24, 47, 12 },
    {     23,   -9,    9, 24, 47, 12 }, {     23,  -10,    9, 24, 47, 12 }, {     23,  -11,    9, 24, 47, 11 }, {     23,  -12,    8, 24, 47, 11 }, {     23,  -13,    8, 24, 47, 11 },
    {     23,  -14,    8, 24, 47, 11 }, {     23,  -15,    8, 24, 47, 11 }, {     23,  -16,    8, 24, 47, 11 }, {     23,  -17,    8, 24, 47, 11 }, {     23,  -18,    8, 24, 47, 11 },
    {     23,  -19,    7, 24, 47, 11 }, {     23,  -20,    7, 24, 47, 11 }, {     23,  -21,    7, 24, 47, 11 }, {     23,  -22,    7, 24, 47, 11 }, {     23,  -23,    6, 24, 47, 10 },
    {     23,  -24,    6, 24, 47, 10 }, {     23,  -25,    6, 24, 47, 10 }, {     23,  -26,    6, 24, 47, 10 }, {     23,  -27,    5, 24, 47, 10 }, {     23,  -28,    5, 24, 47, 10 },
    {     22,  -29,    5, 24, 47, 10 }, {     22,  -30,    5, 24, 47, 10 }, {     22,  -31,    4, 24, 47, 10 }, {     22,  -32,    4, 24, 47, 10 }, {     22,  -33,    4, 24, 47, 10 },
    {     22,  -34,    4, 24, 47, 10 }, {     22,  -35,    4, 24, 47,  4 }, {     22,  -36,    3, 24, 47,  4 }, {     22,  -37,    3, 24, 47,  4 }, {     21,  -38,    3, 24, 47,  4 },
    {     21,  -39,    3, 24, 47,  4 }, {     21,  -40,    3, 24, 47,  4 }, {     21,  -41,    2, 24, 47,  4 }, {     21,  -42,    2, 24, 47,  4 }, {     21,  -43,    2, 24, 47,  4 },
    {     20,  -44,    2, 24, 47,  4 }, {     20,  -45,    2, 24, 47,  4 }, {     20,  -46,    1, 24, 47,  4 }, {     20,  -47,    1, 24, 47,  3 }, {     20,  -48,    1, 24, 47,  3 },
    {     19,  -49,    1, 24, 47,  3 }, {     19,  -50,    1, 24, 47,  3 }, {     19,  -51,    1, 24, 47,  3 }, {     19,  -52,    1, 24, 47,  3 }, {     19,  -53,    1, 24, 47,  3 },
    {     18,  -54,    1, 24, 47,  3 }, {     18,  -55,    0, 24, 47,  3 }, {     18,  -56,    0, 24, 47,  3 }, {     18,  -57,    0, 24, 47,  3 }, {     18,  -58,    0, 24, 47,  3 },
    {     17,  -59,    0, 24, 47,  0 }, {     17,  -60,    0, 24, 47,  0 }, {     17,  -61,    0, 24, 47,  0 }, {     17,  -62,    0, 24, 47,  0 }, {     16,  -63,    0, 24, 47,  0 },
    {     16,  -64,    0, 24, 47,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91EDCA, {
    {     31,   16,   15, 16, 16,  0 }, {     30,   16,   15, 16, 16,  0 }, {     29,   16,   15, 16, 16,  0 }, {     28,   17,   15, 16, 16,  0 }, {     27,   17,   15, 16, 16,  0 },
    {     26,   17,   15, 16, 16,  0 }, {     25,   17,   15,  0, 47,  9 }, {     24,   18,   15,  0, 47,  9 }, {     23,   18,   15,  0, 47,  9 }, {     22,   18,   15,  0, 47,  9 },
    {     21,   18,   15,  0, 47,  9 }, {     20,   18,   14,  0, 47,  9 }, {     19,   19,   14,  0, 47,  9 }, {     18,   19,   14,  0, 47,  9 }, {     17,   19,   14,  0, 47,  9 },
    {     16,   19,   14,  0, 47,  9 }, {     15,   19,   14,  0, 47,  9 }, {     14,   20,   14,  0, 47,  9 }, {     13,   20,   14,  0, 47,  8 }, {     12,   20,   14,  0, 47,  8 },
    {     11,   20,   13,  0, 47,  8 }, {     10,   20,   13,  0, 47,  8 }, {      9,   21,   13,  0, 47,  8 }, {      8,   21,   13,  0, 47,  8 }, {      7,   21,   13,  0, 47,  8 },
    {      6,   21,   12,  0, 47,  8 }, {      5,   21,   12,  0, 47,  8 }, {      4,   21,   12,  0, 47,  8 }, {      3,   22,   12,  0, 47,  8 }, {      2,   22,   12,  0, 47,  8 },
    {      1,   22,   11,  0, 47,  7 }, {      0,   22,   11,  0, 47,  7 }, {     -1,   22,   11,  0, 47,  7 }, {     -2,   22,   11,  0, 47,  7 }, {     -3,   22,   11,  0, 47,  7 },
    {     -4,   22,   10,  0, 47,  7 }, {     -5,   22,   10,  0, 47,  7 }, {     -6,   23,   10,  0, 47,  7 }, {     -7,   23,   10,  0, 47,  7 }, {     -8,   23,    9,  0, 47,  7 },
    {     -9,   23,    9,  0, 47,  7 }, {    -10,   23,    9,  0, 47,  7 }, {    -11,   23,    9,  0, 47,  6 }, {    -12,   23,    8,  0, 47,  6 }, {    -13,   23,    8,  0, 47,  6 },
    {    -14,   23,    8,  0, 47,  6 }, {    -15,   23,    8,  0, 47,  6 }, {    -16,   23,    8,  0, 47,  6 }, {    -17,   23,    8,  0, 47,  6 }, {    -18,   23,    8,  0, 47,  6 },
    {    -19,   23,    7,  0, 47,  6 }, {    -20,   23,    7,  0, 47,  6 }, {    -21,   23,    7,  0, 47,  6 }, {    -22,   23,    7,  0, 47,  6 }, {    -23,   23,    6,  0, 47,  5 },
    {    -24,   23,    6,  0, 47,  5 }, {    -25,   23,    6,  0, 47,  5 }, {    -26,   23,    6,  0, 47,  5 }, {    -27,   23,    5,  0, 47,  5 }, {    -28,   23,    5,  0, 47,  5 },
    {    -29,   22,    5,  0, 47,  5 }, {    -30,   22,    5,  0, 47,  5 }, {    -31,   22,    4,  0, 47,  5 }, {    -32,   22,    4,  0, 47,  5 }, {    -33,   22,    4,  0, 47,  5 },
    {    -34,   22,    4,  0, 47,  5 }, {    -35,   22,    4,  0, 47,  2 }, {    -36,   22,    3,  0, 47,  2 }, {    -37,   22,    3,  0, 47,  2 }, {    -38,   21,    3,  0, 47,  2 },
    {    -39,   21,    3,  0, 47,  2 }, {    -40,   21,    3,  0, 47,  2 }, {    -41,   21,    2,  0, 47,  2 }, {    -42,   21,    2,  0, 47,  2 }, {    -43,   21,    2,  0, 47,  2 },
    {    -44,   20,    2,  0, 47,  2 }, {    -45,   20,    2,  0, 47,  2 }, {    -46,   20,    1,  0, 47,  2 }, {    -47,   20,    1,  0, 47,  1 }, {    -48,   20,    1,  0, 47,  1 },
    {    -49,   19,    1,  0, 47,  1 }, {    -50,   19,    1,  0, 47,  1 }, {    -51,   19,    1,  0, 47,  1 }, {    -52,   19,    1,  0, 47,  1 }, {    -53,   19,    1,  0, 47,  1 },
    {    -54,   18,    1,  0, 47,  1 }, {    -55,   18,    0,  0, 47,  1 }, {    -56,   18,    0,  0, 47,  1 }, {    -57,   18,    0,  0, 47,  1 }, {    -58,   18,    0,  0, 47,  1 },
    {    -59,   17,    0,  0, 47,  0 }, {    -60,   17,    0,  0, 47,  0 }, {    -61,   17,    0,  0, 47,  0 }, {    -62,   17,    0,  0, 47,  0 }, {    -63,   16,    0,  0, 47,  0 },
    {    -64,   16,    0,  0, 47,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91F12C, {
    {     16,    0,   15, 24, 16,  0 }, {     16,    1,   15, 24, 16,  0 }, {     16,    2,   15, 24, 16,  0 }, {     17,    3,   15, 24, 16,  0 }, {     17,    4,   15, 24, 16,  0 },
    {     17,    5,   15, 24, 16,  0 }, {     17,    6,   15,  8, 47,  9 }, {     18,    7,   15,  8, 47,  9 }, {     18,    8,   15,  8, 47,  9 }, {     18,    9,   15,  8, 47,  9 },
    {     18,   10,   15,  8, 47,  9 }, {     18,   11,   14,  8, 47,  9 }, {     19,   12,   14,  8, 47,  9 }, {     19,   13,   14,  8, 47,  9 }, {     19,   14,   14,  8, 47,  9 },
    {     19,   15,   14,  8, 47,  9 }, {     19,   16,   14,  8, 47,  9 }, {     20,   17,   14,  8, 47,  9 }, {     20,   18,   14,  8, 47,  8 }, {     20,   19,   14,  8, 47,  8 },
    {     20,   20,   13,  8, 47,  8 }, {     20,   21,   13,  8, 47,  8 }, {     21,   22,   13,  8, 47,  8 }, {     21,   23,   13,  8, 47,  8 }, {     21,   24,   13,  8, 47,  8 },
    {     21,   25,   12,  8, 47,  8 }, {     21,   26,   12,  8, 47,  8 }, {     21,   27,   12,  8, 47,  8 }, {     22,   28,   12,  8, 47,  8 }, {     22,   29,   12,  8, 47,  8 },
    {     22,   30,   11,  8, 47,  7 }, {     22,   31,   11,  8, 47,  7 }, {     22,   32,   11,  8, 47,  7 }, {     22,   33,   11,  8, 47,  7 }, {     22,   34,   11,  8, 47,  7 },
    {     22,   35,   10,  8, 47,  7 }, {     22,   36,   10,  8, 47,  7 }, {     23,   37,   10,  8, 47,  7 }, {     23,   38,   10,  8, 47,  7 }, {     23,   39,    9,  8, 47,  7 },
    {     23,   40,    9,  8, 47,  7 }, {     23,   41,    9,  8, 47,  7 }, {     23,   42,    9,  8, 47,  6 }, {     23,   43,    8,  8, 47,  6 }, {     23,   44,    8,  8, 47,  6 },
    {     23,   45,    8,  8, 47,  6 }, {     23,   46,    8,  8, 47,  6 }, {     23,   47,    8,  8, 47,  6 }, {     23,   48,    8,  8, 47,  6 }, {     23,   49,    8,  8, 47,  6 },
    {     23,   50,    7,  8, 47,  6 }, {     23,   51,    7,  8, 47,  6 }, {     23,   52,    7,  8, 47,  6 }, {     23,   53,    7,  8, 47,  6 }, {     23,   54,    6,  8, 47,  5 },
    {     23,   55,    6,  8, 47,  5 }, {     23,   56,    6,  8, 47,  5 }, {     23,   57,    6,  8, 47,  5 }, {     23,   58,    5,  8, 47,  5 }, {     23,   59,    5,  8, 47,  5 },
    {     22,   60,    5,  8, 47,  5 }, {     22,   61,    5,  8, 47,  5 }, {     22,   62,    4,  8, 47,  5 }, {     22,   63,    4,  8, 47,  5 }, {     22,   64,    4,  8, 47,  5 },
    {     22,   65,    4,  8, 47,  5 }, {     22,   66,    4,  8, 47,  2 }, {     22,   67,    3,  8, 47,  2 }, {     22,   68,    3,  8, 47,  2 }, {     21,   69,    3,  8, 47,  2 },
    {     21,   70,    3,  8, 47,  2 }, {     21,   71,    3,  8, 47,  2 }, {     21,   72,    2,  8, 47,  2 }, {     21,   73,    2,  8, 47,  2 }, {     21,   74,    2,  8, 47,  2 },
    {     20,   75,    2,  8, 47,  2 }, {     20,   76,    2,  8, 47,  2 }, {     20,   77,    1,  8, 47,  2 }, {     20,   78,    1,  8, 47,  1 }, {     20,   79,    1,  8, 47,  1 },
    {     19,   80,    1,  8, 47,  1 }, {     19,   81,    1,  8, 47,  1 }, {     19,   82,    1,  8, 47,  1 }, {     19,   83,    1,  8, 47,  1 }, {     19,   84,    1,  8, 47,  1 },
    {     18,   85,    1,  8, 47,  1 }, {     18,   86,    0,  8, 47,  1 }, {     18,   87,    0,  8, 47,  1 }, {     18,   88,    0,  8, 47,  1 }, {     18,   89,    0,  8, 47,  1 },
    {     17,   90,    0,  8, 47,  0 }, {     17,   91,    0,  8, 47,  0 }, {     17,   92,    0,  8, 47,  0 }, {     17,   93,    0,  8, 47,  0 }, {     16,   94,    0,  8, 47,  0 },
    {     16,   95,    0,  8, 47,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91F48E, {
    {      0,   16,   15,  0, 16,  0 }, {      1,   16,   15,  0, 16,  0 }, {      2,   16,   15,  0, 16,  0 }, {      3,   15,   15,  0, 16,  0 }, {      4,   15,   15,  0, 16,  0 },
    {      5,   15,   15,  0, 16,  0 }, {      6,   15,   15, 16, 47,  9 }, {      7,   14,   15, 16, 47,  9 }, {      8,   14,   15, 16, 47,  9 }, {      9,   14,   15, 16, 47,  9 },
    {     10,   14,   15, 16, 47,  9 }, {     11,   14,   14, 16, 47,  9 }, {     12,   13,   14, 16, 47,  9 }, {     13,   13,   14, 16, 47,  9 }, {     14,   13,   14, 16, 47,  9 },
    {     15,   13,   14, 16, 47,  9 }, {     16,   13,   14, 16, 47,  9 }, {     17,   12,   14, 16, 47,  9 }, {     18,   12,   14, 16, 47,  8 }, {     19,   12,   14, 16, 47,  8 },
    {     20,   12,   13, 16, 47,  8 }, {     21,   12,   13, 16, 47,  8 }, {     22,   11,   13, 16, 47,  8 }, {     23,   11,   13, 16, 47,  8 }, {     24,   11,   13, 16, 47,  8 },
    {     25,   11,   12, 16, 47,  8 }, {     26,   11,   12, 16, 47,  8 }, {     27,   11,   12, 16, 47,  8 }, {     28,   10,   12, 16, 47,  8 }, {     29,   10,   12, 16, 47,  8 },
    {     30,   10,   11, 16, 47,  7 }, {     31,   10,   11, 16, 47,  7 }, {     32,   10,   11, 16, 47,  7 }, {     33,   10,   11, 16, 47,  7 }, {     34,   10,   11, 16, 47,  7 },
    {     35,   10,   10, 16, 47,  7 }, {     36,   10,   10, 16, 47,  7 }, {     37,    9,   10, 16, 47,  7 }, {     38,    9,   10, 16, 47,  7 }, {     39,    9,    9, 16, 47,  7 },
    {     40,    9,    9, 16, 47,  7 }, {     41,    9,    9, 16, 47,  7 }, {     42,    9,    9, 16, 47,  6 }, {     43,    9,    8, 16, 47,  6 }, {     44,    9,    8, 16, 47,  6 },
    {     45,    9,    8, 16, 47,  6 }, {     46,    9,    8, 16, 47,  6 }, {     47,    9,    8, 16, 47,  6 }, {     48,    9,    8, 16, 47,  6 }, {     49,    9,    8, 16, 47,  6 },
    {     50,    9,    7, 16, 47,  6 }, {     51,    9,    7, 16, 47,  6 }, {     52,    9,    7, 16, 47,  6 }, {     53,    9,    7, 16, 47,  6 }, {     54,    9,    6, 16, 47,  5 },
    {     55,    9,    6, 16, 47,  5 }, {     56,    9,    6, 16, 47,  5 }, {     57,    9,    6, 16, 47,  5 }, {     58,    9,    5, 16, 47,  5 }, {     59,    9,    5, 16, 47,  5 },
    {     60,   10,    5, 16, 47,  5 }, {     61,   10,    5, 16, 47,  5 }, {     62,   10,    4, 16, 47,  5 }, {     63,   10,    4, 16, 47,  5 }, {     64,   10,    4, 16, 47,  5 },
    {     65,   10,    4, 16, 47,  5 }, {     66,   10,    4, 16, 47,  2 }, {     67,   10,    3, 16, 47,  2 }, {     68,   10,    3, 16, 47,  2 }, {     69,   11,    3, 16, 47,  2 },
    {     70,   11,    3, 16, 47,  2 }, {     71,   11,    3, 16, 47,  2 }, {     72,   11,    2, 16, 47,  2 }, {     73,   11,    2, 16, 47,  2 }, {     74,   11,    2, 16, 47,  2 },
    {     75,   12,    2, 16, 47,  2 }, {     76,   12,    2, 16, 47,  2 }, {     77,   12,    1, 16, 47,  2 }, {     78,   12,    1, 16, 47,  1 }, {     79,   12,    1, 16, 47,  1 },
    {     80,   13,    1, 16, 47,  1 }, {     81,   13,    1, 16, 47,  1 }, {     82,   13,    1, 16, 47,  1 }, {     83,   13,    1, 16, 47,  1 }, {     84,   13,    1, 16, 47,  1 },
    {     85,   14,    1, 16, 47,  1 }, {     86,   14,    0, 16, 47,  1 }, {     87,   14,    0, 16, 47,  1 }, {     88,   14,    0, 16, 47,  1 }, {     89,   14,    0, 16, 47,  1 },
    {     90,   15,    0, 16, 47,  0 }, {     91,   15,    0, 16, 47,  0 }, {     92,   15,    0, 16, 47,  0 }, {     93,   15,    0, 16, 47,  0 }, {     94,   16,    0, 16, 47,  0 },
    {     95,   16,    0, 16, 47,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91F7F0, {
    {     16,   31,   15,  8, 16,  0 }, {     16,   30,   15,  8, 16,  0 }, {     16,   29,   15,  8, 16,  0 }, {     15,   28,   15,  8, 16,  0 }, {     15,   27,   15,  8, 16,  0 },
    {     15,   26,   15,  8, 16,  0 }, {     15,   25,   15, 24, 47,  9 }, {     14,   24,   15, 24, 47,  9 }, {     14,   23,   15, 24, 47,  9 }, {     14,   22,   15, 24, 47,  9 },
    {     14,   21,   15, 24, 47,  9 }, {     14,   20,   14, 24, 47,  9 }, {     13,   19,   14, 24, 47,  9 }, {     13,   18,   14, 24, 47,  9 }, {     13,   17,   14, 24, 47,  9 },
    {     13,   16,   14, 24, 47,  9 }, {     13,   15,   14, 24, 47,  9 }, {     12,   14,   14, 24, 47,  9 }, {     12,   13,   14, 24, 47,  8 }, {     12,   12,   14, 24, 47,  8 },
    {     12,   11,   13, 24, 47,  8 }, {     12,   10,   13, 24, 47,  8 }, {     11,    9,   13, 24, 47,  8 }, {     11,    8,   13, 24, 47,  8 }, {     11,    7,   13, 24, 47,  8 },
    {     11,    6,   12, 24, 47,  8 }, {     11,    5,   12, 24, 47,  8 }, {     11,    4,   12, 24, 47,  8 }, {     10,    3,   12, 24, 47,  8 }, {     10,    2,   12, 24, 47,  8 },
    {     10,    1,   11, 24, 47,  7 }, {     10,    0,   11, 24, 47,  7 }, {     10,   -1,   11, 24, 47,  7 }, {     10,   -2,   11, 24, 47,  7 }, {     10,   -3,   11, 24, 47,  7 },
    {     10,   -4,   10, 24, 47,  7 }, {     10,   -5,   10, 24, 47,  7 }, {      9,   -6,   10, 24, 47,  7 }, {      9,   -7,   10, 24, 47,  7 }, {      9,   -8,    9, 24, 47,  7 },
    {      9,   -9,    9, 24, 47,  7 }, {      9,  -10,    9, 24, 47,  7 }, {      9,  -11,    9, 24, 47,  6 }, {      9,  -12,    8, 24, 47,  6 }, {      9,  -13,    8, 24, 47,  6 },
    {      9,  -14,    8, 24, 47,  6 }, {      9,  -15,    8, 24, 47,  6 }, {      9,  -16,    8, 24, 47,  6 }, {      9,  -17,    8, 24, 47,  6 }, {      9,  -18,    8, 24, 47,  6 },
    {      9,  -19,    7, 24, 47,  6 }, {      9,  -20,    7, 24, 47,  6 }, {      9,  -21,    7, 24, 47,  6 }, {      9,  -22,    7, 24, 47,  6 }, {      9,  -23,    6, 24, 47,  5 },
    {      9,  -24,    6, 24, 47,  5 }, {      9,  -25,    6, 24, 47,  5 }, {      9,  -26,    6, 24, 47,  5 }, {      9,  -27,    5, 24, 47,  5 }, {      9,  -28,    5, 24, 47,  5 },
    {     10,  -29,    5, 24, 47,  5 }, {     10,  -30,    5, 24, 47,  5 }, {     10,  -31,    4, 24, 47,  5 }, {     10,  -32,    4, 24, 47,  5 }, {     10,  -33,    4, 24, 47,  5 },
    {     10,  -34,    4, 24, 47,  5 }, {     10,  -35,    4, 24, 47,  2 }, {     10,  -36,    3, 24, 47,  2 }, {     10,  -37,    3, 24, 47,  2 }, {     11,  -38,    3, 24, 47,  2 },
    {     11,  -39,    3, 24, 47,  2 }, {     11,  -40,    3, 24, 47,  2 }, {     11,  -41,    2, 24, 47,  2 }, {     11,  -42,    2, 24, 47,  2 }, {     11,  -43,    2, 24, 47,  2 },
    {     12,  -44,    2, 24, 47,  2 }, {     12,  -45,    2, 24, 47,  2 }, {     12,  -46,    1, 24, 47,  2 }, {     12,  -47,    1, 24, 47,  1 }, {     12,  -48,    1, 24, 47,  1 },
    {     13,  -49,    1, 24, 47,  1 }, {     13,  -50,    1, 24, 47,  1 }, {     13,  -51,    1, 24, 47,  1 }, {     13,  -52,    1, 24, 47,  1 }, {     13,  -53,    1, 24, 47,  1 },
    {     14,  -54,    1, 24, 47,  1 }, {     14,  -55,    0, 24, 47,  1 }, {     14,  -56,    0, 24, 47,  1 }, {     14,  -57,    0, 24, 47,  1 }, {     14,  -58,    0, 24, 47,  1 },
    {     15,  -59,    0, 24, 47,  0 }, {     15,  -60,    0, 24, 47,  0 }, {     15,  -61,    0, 24, 47,  0 }, {     15,  -62,    0, 24, 47,  0 }, {     16,  -63,    0, 24, 47,  0 },
    {     16,  -64,    0, 24, 47,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_920E82, {
    {     31,   16,    0,  0,  0,  2 }, {     30,   16,    0,  0,  0,  2 }, {     29,   16,    0,  0,  0,  2 }, {     28,   16,    0,  0,  0,  2 }, {     27,   16,    0, 31,  0,  2 },
    {     26,   16,    0, 31,  0,  2 }, {     25,   15,    0, 31,  0,  2 }, {     24,   15,    1, 31,  0,  2 }, {     23,   15,    1, 31,  0,  2 }, {     22,   15,    1, 31,  0,  2 },
    {     21,   15,    1, 31,  0,  2 }, {     20,   15,    1, 31,  0,  2 }, {     19,   14,    1, 31,  0,  2 }, {     18,   14,    2, 30,  0,  2 }, {     17,   14,    2, 30,  0,  2 },
    {     16,   13,    2, 30,  0,  2 }, {     15,   13,    2, 30,  1,  1 }, {     14,   13,    2, 30,  1,  1 }, {     13,   12,    3, 30,  1,  1 }, {     12,   12,    3, 30,  1,  1 },
    {     11,   11,    3, 30,  1,  1 }, {     10,   11,    3, 30,  1,  1 }, {      9,   10,    3, 30,  1,  1 }, {      8,   10,    4, 29,  1,  1 }, {      7,    9,    4, 29,  1,  1 },
    {      6,    9,    4, 29,  1,  1 }, {      5,    8,    5, 29,  1,  1 }, {      4,    7,    5, 29,  1,  1 }, {      3,    7,    5, 29,  1,  1 }, {      2,    6,    6, 29,  1,  1 },
    {      1,    5,    6, 29,  1,  1 }, {      0,    4,    6, 29,  1,  1 }, {     -1,    3,    7, 28,  1,  1 }, {     -3,    3,    7, 28,  2,  0 }, {     -4,    2,    8, 28,  2,  0 },
    {     -5,    1,    8, 28,  2,  0 }, {     -6,    0,    8, 28,  2,  0 }, {     -7,   -1,    9, 27,  2,  0 }, {     -7,   -2,    9, 27,  2,  0 }, {     -8,   -3,    9, 27,  2,  0 },
    {     -9,   -4,   10, 27,  2,  0 }, {     -9,   -5,   10, 27,  2,  0 }, {    -10,   -6,   11, 27,  2,  0 }, {    -10,   -7,   11, 27,  2,  0 }, {    -11,   -8,   12, 27,  2,  0 },
    {    -11,   -9,   12, 27,  2,  0 }, {    -12,  -10,   13, 26,  2,  0 }, {    -12,  -11,   13, 26,  2,  0 }, {    -13,  -12,   14, 26,  2,  0 }, {    -13,  -13,   14, 26,  2,  0 },
    {    -13,  -14,   15, 26,  2,  0 }, {    -14,  -15,   15, 26,  2,  0 }, {    -14,  -16,   16, 26,  2,  0 }, {    -14,  -17,   16, 26,  2,  0 }, {    -15,  -18,   17, 26,  2,  0 },
    {    -15,  -19,   17, 26,  2,  0 }, {    -15,  -20,   18, 25,  2,  0 }, {    -15,  -21,   18, 25,  2,  0 }, {    -15,  -22,   19, 25,  2,  0 }, {    -15,  -23,   19, 25,  2,  0 },
    {    -16,  -24,   20, 25,  2,  0 }, {    -16,  -25,   20, 25,  2,  0 }, {    -16,  -26,   21, 25,  2,  0 }, {    -16,  -27,   21, 25,  2,  0 }, {    -16,  -28,   22, 24,  2,  0 },
    {    -16,  -29,   22, 24,  2,  0 }, {    -16,  -30,   23, 24,  2,  0 }, {    -16,  -31,   23, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9210E8, {
    {     16,    0,    0,  8,  0,  2 }, {     16,    1,    0,  8,  0,  2 }, {     16,    2,    0,  8,  0,  2 }, {     16,    3,    0,  8,  0,  2 }, {     16,    4,    0,  8,  0,  2 },
    {     16,    5,    0,  7,  0,  2 }, {     16,    6,    0,  7,  0,  2 }, {     15,    7,    0,  7,  0,  2 }, {     15,    8,    1,  7,  0,  2 }, {     15,    9,    1,  7,  0,  2 },
    {     15,   10,    1,  7,  0,  2 }, {     15,   11,    1,  7,  0,  2 }, {     15,   12,    1,  7,  0,  2 }, {     14,   13,    1,  7,  0,  2 }, {     14,   14,    2,  6,  0,  2 },
    {     14,   15,    2,  6,  0,  2 }, {     13,   16,    2,  6,  0,  2 }, {     13,   17,    2,  6,  1,  1 }, {     13,   18,    2,  6,  1,  1 }, {     12,   19,    3,  6,  1,  1 },
    {     12,   20,    3,  6,  1,  1 }, {     11,   21,    3,  6,  1,  1 }, {     11,   22,    3,  6,  1,  1 }, {     10,   23,    3,  6,  1,  1 }, {     10,   24,    4,  5,  1,  1 },
    {      9,   25,    4,  5,  1,  1 }, {      9,   26,    4,  5,  1,  1 }, {      8,   27,    5,  5,  1,  1 }, {      7,   28,    5,  5,  1,  1 }, {      7,   29,    5,  5,  1,  1 },
    {      6,   30,    6,  5,  1,  1 }, {      5,   31,    6,  5,  1,  1 }, {      4,   32,    6,  5,  1,  1 }, {      3,   33,    7,  4,  1,  1 }, {      3,   35,    7,  4,  2,  0 },
    {      2,   36,    8,  4,  2,  0 }, {      1,   37,    8,  4,  2,  0 }, {      0,   38,    8,  4,  2,  0 }, {     -1,   39,    9,  3,  2,  0 }, {     -2,   39,    9,  3,  2,  0 },
    {     -3,   40,    9,  3,  2,  0 }, {     -4,   41,   10,  3,  2,  0 }, {     -5,   41,   10,  3,  2,  0 }, {     -6,   42,   11,  3,  2,  0 }, {     -7,   42,   11,  3,  2,  0 },
    {     -8,   43,   12,  3,  2,  0 }, {     -9,   43,   12,  3,  2,  0 }, {    -10,   44,   13,  2,  2,  0 }, {    -11,   44,   13,  2,  2,  0 }, {    -12,   45,   14,  2,  2,  0 },
    {    -13,   45,   14,  2,  2,  0 }, {    -14,   45,   15,  2,  2,  0 }, {    -15,   46,   15,  2,  2,  0 }, {    -16,   46,   16,  2,  2,  0 }, {    -17,   46,   16,  2,  2,  0 },
    {    -18,   47,   17,  2,  2,  0 }, {    -19,   47,   17,  2,  2,  0 }, {    -20,   47,   18,  1,  2,  0 }, {    -21,   47,   18,  1,  2,  0 }, {    -22,   47,   19,  1,  2,  0 },
    {    -23,   47,   19,  1,  2,  0 }, {    -24,   48,   20,  1,  2,  0 }, {    -25,   48,   20,  1,  2,  0 }, {    -26,   48,   21,  1,  2,  0 }, {    -27,   48,   21,  1,  2,  0 },
    {    -28,   48,   22,  0,  2,  0 }, {    -29,   48,   22,  0,  2,  0 }, {    -30,   48,   23,  0,  2,  0 }, {    -31,   48,   23,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_921357, {
    {      0,   16,    0, 16,  0,  2 }, {      1,   16,    0, 16,  0,  2 }, {      2,   16,    0, 16,  0,  2 }, {      3,   16,    0, 16,  0,  2 }, {      4,   16,    0, 16,  0,  2 },
    {      5,   16,    0, 15,  0,  2 }, {      6,   16,    0, 15,  0,  2 }, {      7,   17,    1, 15,  0,  2 }, {      8,   17,    1, 15,  0,  2 }, {      9,   17,    1, 15,  0,  2 },
    {     10,   17,    1, 15,  0,  2 }, {     11,   17,    1, 15,  0,  2 }, {     12,   17,    1, 15,  0,  2 }, {     13,   18,    2, 15,  0,  2 }, {     14,   18,    2, 14,  0,  2 },
    {     15,   18,    2, 14,  0,  2 }, {     16,   19,    2, 14,  1,  1 }, {     17,   19,    2, 14,  1,  1 }, {     18,   19,    3, 14,  1,  1 }, {     19,   20,    3, 14,  1,  1 },
    {     20,   20,    3, 14,  1,  1 }, {     21,   21,    3, 14,  1,  1 }, {     22,   21,    3, 14,  1,  1 }, {     23,   22,    4, 14,  1,  1 }, {     24,   22,    4, 13,  1,  1 },
    {     25,   23,    4, 13,  1,  1 }, {     26,   23,    5, 13,  1,  1 }, {     27,   24,    5, 13,  1,  1 }, {     28,   25,    5, 13,  1,  1 }, {     29,   25,    6, 13,  1,  1 },
    {     30,   26,    6, 13,  1,  1 }, {     31,   27,    6, 13,  1,  1 }, {     32,   28,    7, 13,  1,  1 }, {     33,   29,    7, 12,  2,  0 }, {     35,   29,    8, 12,  2,  0 },
    {     36,   30,    8, 12,  2,  0 }, {     37,   31,    8, 12,  2,  0 }, {     38,   32,    9, 12,  2,  0 }, {     39,   33,    9, 11,  2,  0 }, {     39,   34,    9, 11,  2,  0 },
    {     40,   35,   10, 11,  2,  0 }, {     41,   36,   10, 11,  2,  0 }, {     41,   37,   11, 11,  2,  0 }, {     42,   38,   11, 11,  2,  0 }, {     42,   39,   12, 11,  2,  0 },
    {     43,   40,   12, 11,  2,  0 }, {     43,   41,   13, 11,  2,  0 }, {     44,   42,   13, 10,  2,  0 }, {     44,   43,   14, 10,  2,  0 }, {     45,   44,   14, 10,  2,  0 },
    {     45,   45,   15, 10,  2,  0 }, {     45,   46,   15, 10,  2,  0 }, {     46,   47,   16, 10,  2,  0 }, {     46,   48,   16, 10,  2,  0 }, {     46,   49,   17, 10,  2,  0 },
    {     47,   50,   17, 10,  2,  0 }, {     47,   51,   18, 10,  2,  0 }, {     47,   52,   18,  9,  2,  0 }, {     47,   53,   19,  9,  2,  0 }, {     47,   54,   19,  9,  2,  0 },
    {     47,   55,   20,  9,  2,  0 }, {     48,   56,   20,  9,  2,  0 }, {     48,   57,   21,  9,  2,  0 }, {     48,   58,   21,  9,  2,  0 }, {     48,   59,   22,  9,  2,  0 },
    {     48,   60,   22,  8,  2,  0 }, {     48,   61,   23,  8,  2,  0 }, {     48,   62,   23,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9215BD, {
    {     16,   31,    0, 24,  0,  2 }, {     16,   30,    0, 24,  0,  2 }, {     16,   29,    0, 24,  0,  2 }, {     16,   28,    0, 24,  0,  2 }, {     16,   27,    0, 23,  0,  2 },
    {     16,   26,    0, 23,  0,  2 }, {     17,   25,    1, 23,  0,  2 }, {     17,   24,    1, 23,  0,  2 }, {     17,   23,    1, 23,  0,  2 }, {     17,   22,    1, 23,  0,  2 },
    {     17,   21,    1, 23,  0,  2 }, {     17,   20,    1, 23,  0,  2 }, {     18,   19,    2, 23,  0,  2 }, {     18,   18,    2, 22,  0,  2 }, {     18,   17,    2, 22,  0,  2 },
    {     19,   16,    2, 22,  1,  1 }, {     19,   15,    2, 22,  1,  1 }, {     19,   14,    3, 22,  1,  1 }, {     20,   13,    3, 22,  1,  1 }, {     20,   12,    3, 22,  1,  1 },
    {     21,   11,    3, 22,  1,  1 }, {     21,   10,    3, 22,  1,  1 }, {     22,    9,    4, 22,  1,  1 }, {     22,    8,    4, 21,  1,  1 }, {     23,    7,    4, 21,  1,  1 },
    {     23,    6,    5, 21,  1,  1 }, {     24,    5,    5, 21,  1,  1 }, {     25,    4,    5, 21,  1,  1 }, {     25,    3,    6, 21,  1,  1 }, {     26,    2,    6, 21,  1,  1 },
    {     27,    1,    6, 21,  1,  1 }, {     28,    0,    7, 21,  1,  1 }, {     29,   -1,    7, 20,  2,  0 }, {     29,   -3,    8, 20,  2,  0 }, {     30,   -4,    8, 20,  2,  0 },
    {     31,   -5,    8, 20,  2,  0 }, {     32,   -6,    9, 20,  2,  0 }, {     33,   -7,    9, 19,  2,  0 }, {     34,   -7,    9, 19,  2,  0 }, {     35,   -8,   10, 19,  2,  0 },
    {     36,   -9,   10, 19,  2,  0 }, {     37,   -9,   11, 19,  2,  0 }, {     38,  -10,   11, 19,  2,  0 }, {     39,  -10,   12, 19,  2,  0 }, {     40,  -11,   12, 19,  2,  0 },
    {     41,  -11,   13, 19,  2,  0 }, {     42,  -12,   13, 18,  2,  0 }, {     43,  -12,   14, 18,  2,  0 }, {     44,  -13,   14, 18,  2,  0 }, {     45,  -13,   15, 18,  2,  0 },
    {     46,  -13,   15, 18,  2,  0 }, {     47,  -14,   16, 18,  2,  0 }, {     48,  -14,   16, 18,  2,  0 }, {     49,  -14,   17, 18,  2,  0 }, {     50,  -15,   17, 18,  2,  0 },
    {     51,  -15,   18, 18,  2,  0 }, {     52,  -15,   18, 17,  2,  0 }, {     53,  -15,   19, 17,  2,  0 }, {     54,  -15,   19, 17,  2,  0 }, {     55,  -15,   20, 17,  2,  0 },
    {     56,  -16,   20, 17,  2,  0 }, {     57,  -16,   21, 17,  2,  0 }, {     58,  -16,   21, 17,  2,  0 }, {     59,  -16,   22, 17,  2,  0 }, {     60,  -16,   22, 16,  2,  0 },
    {     61,  -16,   23, 16,  2,  0 }, {     62,  -16,   23, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92181A, {
    {     31,   16,    0,  0,  0,  4 }, {     30,   16,    0,  0,  0,  4 }, {     29,   16,    0,  0,  0,  4 }, {     28,   16,    0,  0,  0,  4 }, {     27,   16,    0,  1,  0,  4 },
    {     26,   16,    0,  1,  0,  4 }, {     25,   17,    1,  1,  0,  4 }, {     24,   17,    1,  1,  0,  4 }, {     23,   17,    1,  1,  0,  4 }, {     22,   17,    1,  1,  0,  4 },
    {     21,   17,    1,  1,  0,  4 }, {     20,   17,    1,  1,  0,  4 }, {     19,   18,    2,  1,  0,  4 }, {     18,   18,    2,  2,  0,  4 }, {     17,   18,    2,  2,  0,  4 },
    {     16,   19,    2,  2,  1,  3 }, {     15,   19,    2,  2,  1,  3 }, {     14,   19,    3,  2,  1,  3 }, {     13,   20,    3,  2,  1,  3 }, {     12,   20,    3,  2,  1,  3 },
    {     11,   21,    3,  2,  1,  3 }, {     10,   21,    3,  2,  1,  3 }, {      9,   22,    4,  2,  1,  3 }, {      8,   22,    4,  3,  1,  3 }, {      7,   23,    4,  3,  1,  3 },
    {      6,   23,    5,  3,  1,  3 }, {      5,   24,    5,  3,  1,  3 }, {      4,   25,    5,  3,  1,  3 }, {      3,   25,    6,  3,  1,  3 }, {      2,   26,    6,  3,  1,  3 },
    {      1,   27,    6,  3,  1,  3 }, {      0,   28,    7,  3,  1,  3 }, {     -1,   29,    7,  4,  2,  0 }, {     -3,   29,    8,  4,  2,  0 }, {     -4,   30,    8,  4,  2,  0 },
    {     -5,   31,    8,  4,  2,  0 }, {     -6,   32,    9,  4,  2,  0 }, {     -7,   33,    9,  5,  2,  0 }, {     -7,   34,    9,  5,  2,  0 }, {     -8,   35,   10,  5,  2,  0 },
    {     -9,   36,   10,  5,  2,  0 }, {     -9,   37,   11,  5,  2,  0 }, {    -10,   38,   11,  5,  2,  0 }, {    -10,   39,   12,  5,  2,  0 }, {    -11,   40,   12,  5,  2,  0 },
    {    -11,   41,   13,  5,  2,  0 }, {    -12,   42,   13,  6,  2,  0 }, {    -12,   43,   14,  6,  2,  0 }, {    -13,   44,   14,  6,  2,  0 }, {    -13,   45,   15,  6,  2,  0 },
    {    -13,   46,   15,  6,  2,  0 }, {    -14,   47,   16,  6,  2,  0 }, {    -14,   48,   16,  6,  2,  0 }, {    -14,   49,   17,  6,  2,  0 }, {    -15,   50,   17,  6,  2,  0 },
    {    -15,   51,   18,  6,  2,  0 }, {    -15,   52,   18,  7,  2,  0 }, {    -15,   53,   19,  7,  2,  0 }, {    -15,   54,   19,  7,  2,  0 }, {    -15,   55,   20,  7,  2,  0 },
    {    -16,   56,   20,  7,  2,  0 }, {    -16,   57,   21,  7,  2,  0 }, {    -16,   58,   21,  7,  2,  0 }, {    -16,   59,   22,  7,  2,  0 }, {    -16,   60,   22,  8,  2,  0 },
    {    -16,   61,   23,  8,  2,  0 }, {    -16,   62,   23,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_921A77, {
    {     16,    0,    0,  8,  0,  4 }, {     16,    1,    0,  8,  0,  4 }, {     16,    2,    0,  8,  0,  4 }, {     16,    3,    0,  8,  0,  4 }, {     16,    4,    0,  8,  0,  4 },
    {     16,    5,    0,  9,  0,  4 }, {     16,    6,    0,  9,  0,  4 }, {     17,    7,    1,  9,  0,  4 }, {     17,    8,    1,  9,  0,  4 }, {     17,    9,    1,  9,  0,  4 },
    {     17,   10,    1,  9,  0,  4 }, {     17,   11,    1,  9,  0,  4 }, {     17,   12,    1,  9,  0,  4 }, {     18,   13,    2,  9,  0,  4 }, {     18,   14,    2, 10,  0,  4 },
    {     18,   15,    2, 10,  0,  4 }, {     19,   16,    2, 10,  1,  3 }, {     19,   17,    2, 10,  1,  3 }, {     19,   18,    3, 10,  1,  3 }, {     20,   19,    3, 10,  1,  3 },
    {     20,   20,    3, 10,  1,  3 }, {     21,   21,    3, 10,  1,  3 }, {     21,   22,    3, 10,  1,  3 }, {     22,   23,    4, 10,  1,  3 }, {     22,   24,    4, 11,  1,  3 },
    {     23,   25,    4, 11,  1,  3 }, {     23,   26,    5, 11,  1,  3 }, {     24,   27,    5, 11,  1,  3 }, {     25,   28,    5, 11,  1,  3 }, {     25,   29,    6, 11,  1,  3 },
    {     26,   30,    6, 11,  1,  3 }, {     27,   31,    6, 11,  1,  3 }, {     28,   32,    7, 11,  1,  3 }, {     29,   33,    7, 12,  2,  0 }, {     29,   35,    8, 12,  2,  0 },
    {     30,   36,    8, 12,  2,  0 }, {     31,   37,    8, 12,  2,  0 }, {     32,   38,    9, 12,  2,  0 }, {     33,   39,    9, 13,  2,  0 }, {     34,   39,    9, 13,  2,  0 },
    {     35,   40,   10, 13,  2,  0 }, {     36,   41,   10, 13,  2,  0 }, {     37,   41,   11, 13,  2,  0 }, {     38,   42,   11, 13,  2,  0 }, {     39,   42,   12, 13,  2,  0 },
    {     40,   43,   12, 13,  2,  0 }, {     41,   43,   13, 13,  2,  0 }, {     42,   44,   13, 14,  2,  0 }, {     43,   44,   14, 14,  2,  0 }, {     44,   45,   14, 14,  2,  0 },
    {     45,   45,   15, 14,  2,  0 }, {     46,   45,   15, 14,  2,  0 }, {     47,   46,   16, 14,  2,  0 }, {     48,   46,   16, 14,  2,  0 }, {     49,   46,   17, 14,  2,  0 },
    {     50,   47,   17, 14,  2,  0 }, {     51,   47,   18, 14,  2,  0 }, {     52,   47,   18, 15,  2,  0 }, {     53,   47,   19, 15,  2,  0 }, {     54,   47,   19, 15,  2,  0 },
    {     55,   47,   20, 15,  2,  0 }, {     56,   48,   20, 15,  2,  0 }, {     57,   48,   21, 15,  2,  0 }, {     58,   48,   21, 15,  2,  0 }, {     59,   48,   22, 15,  2,  0 },
    {     60,   48,   22, 16,  2,  0 }, {     61,   48,   23, 16,  2,  0 }, {     62,   48,   23, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_921CDD, {
    {      0,   16,    0, 16,  0,  4 }, {      1,   16,    0, 16,  0,  4 }, {      2,   16,    0, 16,  0,  4 }, {      3,   16,    0, 16,  0,  4 }, {      4,   16,    0, 16,  0,  4 },
    {      5,   16,    0, 17,  0,  4 }, {      6,   16,    0, 17,  0,  4 }, {      7,   15,    0, 17,  0,  4 }, {      8,   15,    1, 17,  0,  4 }, {      9,   15,    1, 17,  0,  4 },
    {     10,   15,    1, 17,  0,  4 }, {     11,   15,    1, 17,  0,  4 }, {     12,   15,    1, 17,  0,  4 }, {     13,   14,    1, 17,  0,  4 }, {     14,   14,    2, 18,  0,  4 },
    {     15,   14,    2, 18,  0,  4 }, {     16,   13,    2, 18,  0,  4 }, {     17,   13,    2, 18,  1,  3 }, {     18,   13,    2, 18,  1,  3 }, {     19,   12,    3, 18,  1,  3 },
    {     20,   12,    3, 18,  1,  3 }, {     21,   11,    3, 18,  1,  3 }, {     22,   11,    3, 18,  1,  3 }, {     23,   10,    3, 18,  1,  3 }, {     24,   10,    4, 19,  1,  3 },
    {     25,    9,    4, 19,  1,  3 }, {     26,    9,    4, 19,  1,  3 }, {     27,    8,    5, 19,  1,  3 }, {     28,    7,    5, 19,  1,  3 }, {     29,    7,    5, 19,  1,  3 },
    {     30,    6,    6, 19,  1,  3 }, {     31,    5,    6, 19,  1,  3 }, {     32,    4,    6, 19,  1,  3 }, {     33,    3,    7, 20,  1,  3 }, {     35,    3,    7, 20,  2,  0 },
    {     36,    2,    8, 20,  2,  0 }, {     37,    1,    8, 20,  2,  0 }, {     38,    0,    8, 20,  2,  0 }, {     39,   -1,    9, 21,  2,  0 }, {     39,   -2,    9, 21,  2,  0 },
    {     40,   -3,    9, 21,  2,  0 }, {     41,   -4,   10, 21,  2,  0 }, {     41,   -5,   10, 21,  2,  0 }, {     42,   -6,   11, 21,  2,  0 }, {     42,   -7,   11, 21,  2,  0 },
    {     43,   -8,   12, 21,  2,  0 }, {     43,   -9,   12, 21,  2,  0 }, {     44,  -10,   13, 22,  2,  0 }, {     44,  -11,   13, 22,  2,  0 }, {     45,  -12,   14, 22,  2,  0 },
    {     45,  -13,   14, 22,  2,  0 }, {     45,  -14,   15, 22,  2,  0 }, {     46,  -15,   15, 22,  2,  0 }, {     46,  -16,   16, 22,  2,  0 }, {     46,  -17,   16, 22,  2,  0 },
    {     47,  -18,   17, 22,  2,  0 }, {     47,  -19,   17, 22,  2,  0 }, {     47,  -20,   18, 23,  2,  0 }, {     47,  -21,   18, 23,  2,  0 }, {     47,  -22,   19, 23,  2,  0 },
    {     47,  -23,   19, 23,  2,  0 }, {     48,  -24,   20, 23,  2,  0 }, {     48,  -25,   20, 23,  2,  0 }, {     48,  -26,   21, 23,  2,  0 }, {     48,  -27,   21, 23,  2,  0 },
    {     48,  -28,   22, 24,  2,  0 }, {     48,  -29,   22, 24,  2,  0 }, {     48,  -30,   23, 24,  2,  0 }, {     48,  -31,   23, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_921F4C, {
    {     16,   31,    0, 24,  0,  4 }, {     16,   30,    0, 24,  0,  4 }, {     16,   29,    0, 24,  0,  4 }, {     16,   28,    0, 24,  0,  4 }, {     16,   27,    0, 25,  0,  4 },
    {     16,   26,    0, 25,  0,  4 }, {     15,   25,    0, 25,  0,  4 }, {     15,   24,    1, 25,  0,  4 }, {     15,   23,    1, 25,  0,  4 }, {     15,   22,    1, 25,  0,  4 },
    {     15,   21,    1, 25,  0,  4 }, {     15,   20,    1, 25,  0,  4 }, {     14,   19,    1, 25,  0,  4 }, {     14,   18,    2, 26,  0,  4 }, {     14,   17,    2, 26,  0,  4 },
    {     13,   16,    2, 26,  0,  4 }, {     13,   15,    2, 26,  1,  3 }, {     13,   14,    2, 26,  1,  3 }, {     12,   13,    3, 26,  1,  3 }, {     12,   12,    3, 26,  1,  3 },
    {     11,   11,    3, 26,  1,  3 }, {     11,   10,    3, 26,  1,  3 }, {     10,    9,    3, 26,  1,  3 }, {     10,    8,    4, 27,  1,  3 }, {      9,    7,    4, 27,  1,  3 },
    {      9,    6,    4, 27,  1,  3 }, {      8,    5,    5, 27,  1,  3 }, {      7,    4,    5, 27,  1,  3 }, {      7,    3,    5, 27,  1,  3 }, {      6,    2,    6, 27,  1,  3 },
    {      5,    1,    6, 27,  1,  3 }, {      4,    0,    6, 27,  1,  3 }, {      3,   -1,    7, 28,  1,  3 }, {      3,   -3,    7, 28,  2,  0 }, {      2,   -4,    8, 28,  2,  0 },
    {      1,   -5,    8, 28,  2,  0 }, {      0,   -6,    8, 28,  2,  0 }, {     -1,   -7,    9, 29,  2,  0 }, {     -2,   -7,    9, 29,  2,  0 }, {     -3,   -8,    9, 29,  2,  0 },
    {     -4,   -9,   10, 29,  2,  0 }, {     -5,   -9,   10, 29,  2,  0 }, {     -6,  -10,   11, 29,  2,  0 }, {     -7,  -10,   11, 29,  2,  0 }, {     -8,  -11,   12, 29,  2,  0 },
    {     -9,  -11,   12, 29,  2,  0 }, {    -10,  -12,   13, 30,  2,  0 }, {    -11,  -12,   13, 30,  2,  0 }, {    -12,  -13,   14, 30,  2,  0 }, {    -13,  -13,   14, 30,  2,  0 },
    {    -14,  -13,   15, 30,  2,  0 }, {    -15,  -14,   15, 30,  2,  0 }, {    -16,  -14,   16, 30,  2,  0 }, {    -17,  -14,   16, 30,  2,  0 }, {    -18,  -15,   17, 30,  2,  0 },
    {    -19,  -15,   17, 30,  2,  0 }, {    -20,  -15,   18, 31,  2,  0 }, {    -21,  -15,   18, 31,  2,  0 }, {    -22,  -15,   19, 31,  2,  0 }, {    -23,  -15,   19, 31,  2,  0 },
    {    -24,  -16,   20, 31,  2,  0 }, {    -25,  -16,   20, 31,  2,  0 }, {    -26,  -16,   21, 31,  2,  0 }, {    -27,  -16,   21, 31,  2,  0 }, {    -28,  -16,   22,  0,  2,  0 },
    {    -29,  -16,   22,  0,  2,  0 }, {    -30,  -16,   23,  0,  2,  0 }, {    -31,  -16,   23,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91FB52, {
    {     31,   16,    7,  0,  6,  0 }, {     30,   16,    7,  0,  6,  0 }, {     29,   16,    6,  0,  6,  0 }, {     28,   16,    6,  0,  6,  0 }, {     27,   16,    5, 31,  6,  0 },
    {     26,   16,    5, 31,  6,  0 }, {     25,   15,    4, 31,  6,  0 }, {     24,   15,    4, 31,  6,  0 }, {     23,   15,    3, 31,  6,  0 }, {     22,   15,    3, 31,  6,  0 },
    {     21,   15,    2, 31,  6,  0 }, {     20,   15,    2, 31,  6,  0 }, {     19,   14,    1, 31,  6,  0 }, {     18,   14,    1, 30,  6,  0 }, {     17,   14,    0, 30,  6,  0 },
    {     16,   13,    0, 30,  6,  0 }, {     15,   13,   -1, 30,  6,  0 }, {     14,   13,   -1, 30,  6,  0 }, {     13,   12,   -2, 30,  6,  0 }, {     12,   12,   -2, 30,  6,  0 },
    {     11,   11,   -3, 30,  6,  0 }, {     10,   11,   -3, 30,  6,  0 }, {      9,   10,   -4, 30,  6,  0 }, {      8,   10,   -4, 29,  6,  0 }, {      7,    9,   -5, 29,  6,  0 },
    {      6,    9,   -5, 29,  6,  0 }, {      5,    8,   -6, 29,  6,  0 }, {      4,    7,   -6, 29,  6,  0 }, {      3,    7,   -7, 29,  6,  0 }, {      2,    6,   -7, 29,  6,  0 },
    {      1,    5,   -7, 29,  6,  0 }, {      0,    4,   -8, 29,  6,  0 }, {     -1,    3,   -8, 28,  6,  0 }, {     -3,    3,   -8, 28,  6,  0 }, {     -4,    2,   -9, 28,  6,  0 },
    {     -5,    1,   -9, 28,  5,  1 }, {     -6,    0,  -10, 28,  5,  1 }, {     -7,   -1,  -10, 27,  5,  1 }, {     -7,   -2,  -10, 27,  5,  1 }, {     -8,   -3,  -11, 27,  5,  1 },
    {     -9,   -4,  -11, 27,  5,  1 }, {     -9,   -5,  -11, 27,  5,  1 }, {    -10,   -6,  -12, 27,  5,  1 }, {    -10,   -7,  -12, 27,  5,  1 }, {    -11,   -8,  -12, 27,  5,  1 },
    {    -11,   -9,  -13, 27,  5,  1 }, {    -12,  -10,  -13, 26,  5,  1 }, {    -12,  -11,  -13, 26,  5,  1 }, {    -13,  -12,  -13, 26,  5,  1 }, {    -13,  -13,  -13, 26,  5,  1 },
    {    -13,  -14,  -14, 26,  5,  1 }, {    -14,  -15,  -14, 26,  5,  1 }, {    -14,  -16,  -14, 26,  0,  2 }, {    -14,  -17,  -14, 26,  0,  2 }, {    -15,  -18,  -14, 26,  0,  2 },
    {    -15,  -19,  -15, 26,  0,  2 }, {    -15,  -20,  -15, 25,  0,  2 }, {    -15,  -21,  -15, 25,  0,  2 }, {    -15,  -22,  -15, 25,  0,  2 }, {    -15,  -23,  -15, 25,  0,  2 },
    {    -16,  -24,  -15, 25,  0,  2 }, {    -16,  -25,  -16, 25,  0,  2 }, {    -16,  -26,  -16, 25,  0,  2 }, {    -16,  -27,  -16, 25,  0,  2 }, {    -16,  -28,  -16, 24,  0,  2 },
    {    -16,  -29,  -16, 24,  0,  2 }, {    -16,  -30,  -16, 24,  0,  2 }, {    -16,  -31,  -16, 24,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_91FDB8, {
    {     16,    0,    7,  8,  6,  0 }, {     16,    1,    7,  8,  6,  0 }, {     16,    2,    6,  8,  6,  0 }, {     16,    3,    6,  8,  6,  0 }, {     16,    4,    5,  8,  6,  0 },
    {     16,    5,    5,  7,  6,  0 }, {     16,    6,    4,  7,  6,  0 }, {     15,    7,    4,  7,  6,  0 }, {     15,    8,    3,  7,  6,  0 }, {     15,    9,    3,  7,  6,  0 },
    {     15,   10,    2,  7,  6,  0 }, {     15,   11,    2,  7,  6,  0 }, {     15,   12,    1,  7,  6,  0 }, {     14,   13,    1,  7,  6,  0 }, {     14,   14,    0,  6,  6,  0 },
    {     14,   15,    0,  6,  6,  0 }, {     13,   16,   -1,  6,  6,  0 }, {     13,   17,   -1,  6,  6,  0 }, {     13,   18,   -2,  6,  6,  0 }, {     12,   19,   -2,  6,  6,  0 },
    {     12,   20,   -3,  6,  6,  0 }, {     11,   21,   -3,  6,  6,  0 }, {     11,   22,   -4,  6,  6,  0 }, {     10,   23,   -4,  6,  6,  0 }, {     10,   24,   -5,  5,  6,  0 },
    {      9,   25,   -5,  5,  6,  0 }, {      9,   26,   -6,  5,  6,  0 }, {      8,   27,   -6,  5,  6,  0 }, {      7,   28,   -7,  5,  6,  0 }, {      7,   29,   -7,  5,  6,  0 },
    {      6,   30,   -7,  5,  6,  0 }, {      5,   31,   -8,  5,  6,  0 }, {      4,   32,   -8,  5,  6,  0 }, {      3,   33,   -8,  4,  6,  0 }, {      3,   35,   -9,  4,  6,  0 },
    {      2,   36,   -9,  4,  5,  1 }, {      1,   37,  -10,  4,  5,  1 }, {      0,   38,  -10,  4,  5,  1 }, {     -1,   39,  -10,  3,  5,  1 }, {     -2,   39,  -11,  3,  5,  1 },
    {     -3,   40,  -11,  3,  5,  1 }, {     -4,   41,  -11,  3,  5,  1 }, {     -5,   41,  -12,  3,  5,  1 }, {     -6,   42,  -12,  3,  5,  1 }, {     -7,   42,  -12,  3,  5,  1 },
    {     -8,   43,  -13,  3,  5,  1 }, {     -9,   43,  -13,  3,  5,  1 }, {    -10,   44,  -13,  2,  5,  1 }, {    -11,   44,  -13,  2,  5,  1 }, {    -12,   45,  -13,  2,  5,  1 },
    {    -13,   45,  -14,  2,  5,  1 }, {    -14,   45,  -14,  2,  5,  1 }, {    -15,   46,  -14,  2,  0,  2 }, {    -16,   46,  -14,  2,  0,  2 }, {    -17,   46,  -14,  2,  0,  2 },
    {    -18,   47,  -15,  2,  0,  2 }, {    -19,   47,  -15,  2,  0,  2 }, {    -20,   47,  -15,  1,  0,  2 }, {    -21,   47,  -15,  1,  0,  2 }, {    -22,   47,  -15,  1,  0,  2 },
    {    -23,   47,  -15,  1,  0,  2 }, {    -24,   48,  -16,  1,  0,  2 }, {    -25,   48,  -16,  1,  0,  2 }, {    -26,   48,  -16,  1,  0,  2 }, {    -27,   48,  -16,  1,  0,  2 },
    {    -28,   48,  -16,  0,  0,  2 }, {    -29,   48,  -16,  0,  0,  2 }, {    -30,   48,  -16,  0,  0,  2 }, {    -31,   48,  -16,  0,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_920027, {
    {      0,   16,    7, 16,  6,  0 }, {      1,   16,    7, 16,  6,  0 }, {      2,   16,    6, 16,  6,  0 }, {      3,   16,    6, 16,  6,  0 }, {      4,   16,    5, 16,  6,  0 },
    {      5,   16,    5, 15,  6,  0 }, {      6,   16,    4, 15,  6,  0 }, {      7,   17,    4, 15,  6,  0 }, {      8,   17,    3, 15,  6,  0 }, {      9,   17,    3, 15,  6,  0 },
    {     10,   17,    2, 15,  6,  0 }, {     11,   17,    2, 15,  6,  0 }, {     12,   17,    1, 15,  6,  0 }, {     13,   18,    1, 15,  6,  0 }, {     14,   18,    0, 14,  6,  0 },
    {     15,   18,    0, 14,  6,  0 }, {     16,   19,   -1, 14,  6,  0 }, {     17,   19,   -1, 14,  6,  0 }, {     18,   19,   -2, 14,  6,  0 }, {     19,   20,   -2, 14,  6,  0 },
    {     20,   20,   -3, 14,  6,  0 }, {     21,   21,   -3, 14,  6,  0 }, {     22,   21,   -4, 14,  6,  0 }, {     23,   22,   -4, 14,  6,  0 }, {     24,   22,   -5, 13,  6,  0 },
    {     25,   23,   -5, 13,  6,  0 }, {     26,   23,   -6, 13,  6,  0 }, {     27,   24,   -6, 13,  6,  0 }, {     28,   25,   -7, 13,  6,  0 }, {     29,   25,   -7, 13,  6,  0 },
    {     30,   26,   -7, 13,  6,  0 }, {     31,   27,   -8, 13,  6,  0 }, {     32,   28,   -8, 13,  6,  0 }, {     33,   29,   -8, 12,  6,  0 }, {     35,   29,   -9, 12,  6,  0 },
    {     36,   30,   -9, 12,  5,  1 }, {     37,   31,  -10, 12,  5,  1 }, {     38,   32,  -10, 12,  5,  1 }, {     39,   33,  -10, 11,  5,  1 }, {     39,   34,  -11, 11,  5,  1 },
    {     40,   35,  -11, 11,  5,  1 }, {     41,   36,  -11, 11,  5,  1 }, {     41,   37,  -12, 11,  5,  1 }, {     42,   38,  -12, 11,  5,  1 }, {     42,   39,  -12, 11,  5,  1 },
    {     43,   40,  -13, 11,  5,  1 }, {     43,   41,  -13, 11,  5,  1 }, {     44,   42,  -13, 10,  5,  1 }, {     44,   43,  -13, 10,  5,  1 }, {     45,   44,  -13, 10,  5,  1 },
    {     45,   45,  -14, 10,  5,  1 }, {     45,   46,  -14, 10,  5,  1 }, {     46,   47,  -14, 10,  0,  2 }, {     46,   48,  -14, 10,  0,  2 }, {     46,   49,  -14, 10,  0,  2 },
    {     47,   50,  -15, 10,  0,  2 }, {     47,   51,  -15, 10,  0,  2 }, {     47,   52,  -15,  9,  0,  2 }, {     47,   53,  -15,  9,  0,  2 }, {     47,   54,  -15,  9,  0,  2 },
    {     47,   55,  -15,  9,  0,  2 }, {     48,   56,  -16,  9,  0,  2 }, {     48,   57,  -16,  9,  0,  2 }, {     48,   58,  -16,  9,  0,  2 }, {     48,   59,  -16,  9,  0,  2 },
    {     48,   60,  -16,  8,  0,  2 }, {     48,   61,  -16,  8,  0,  2 }, {     48,   62,  -16,  8,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92028D, {
    {     16,   31,    7, 24,  6,  0 }, {     16,   30,    7, 24,  6,  0 }, {     16,   29,    6, 24,  6,  0 }, {     16,   28,    6, 24,  6,  0 }, {     16,   27,    5, 23,  6,  0 },
    {     16,   26,    5, 23,  6,  0 }, {     17,   25,    4, 23,  6,  0 }, {     17,   24,    4, 23,  6,  0 }, {     17,   23,    3, 23,  6,  0 }, {     17,   22,    3, 23,  6,  0 },
    {     17,   21,    2, 23,  6,  0 }, {     17,   20,    2, 23,  6,  0 }, {     18,   19,    1, 23,  6,  0 }, {     18,   18,    1, 22,  6,  0 }, {     18,   17,    0, 22,  6,  0 },
    {     19,   16,    0, 22,  6,  0 }, {     19,   15,   -1, 22,  6,  0 }, {     19,   14,   -1, 22,  6,  0 }, {     20,   13,   -2, 22,  6,  0 }, {     20,   12,   -2, 22,  6,  0 },
    {     21,   11,   -3, 22,  6,  0 }, {     21,   10,   -3, 22,  6,  0 }, {     22,    9,   -4, 22,  6,  0 }, {     22,    8,   -4, 21,  6,  0 }, {     23,    7,   -5, 21,  6,  0 },
    {     23,    6,   -5, 21,  6,  0 }, {     24,    5,   -6, 21,  6,  0 }, {     25,    4,   -6, 21,  6,  0 }, {     25,    3,   -7, 21,  6,  0 }, {     26,    2,   -7, 21,  6,  0 },
    {     27,    1,   -7, 21,  6,  0 }, {     28,    0,   -8, 21,  6,  0 }, {     29,   -1,   -8, 20,  6,  0 }, {     29,   -3,   -8, 20,  6,  0 }, {     30,   -4,   -9, 20,  6,  0 },
    {     31,   -5,   -9, 20,  5,  1 }, {     32,   -6,  -10, 20,  5,  1 }, {     33,   -7,  -10, 19,  5,  1 }, {     34,   -7,  -10, 19,  5,  1 }, {     35,   -8,  -11, 19,  5,  1 },
    {     36,   -9,  -11, 19,  5,  1 }, {     37,   -9,  -11, 19,  5,  1 }, {     38,  -10,  -12, 19,  5,  1 }, {     39,  -10,  -12, 19,  5,  1 }, {     40,  -11,  -12, 19,  5,  1 },
    {     41,  -11,  -13, 19,  5,  1 }, {     42,  -12,  -13, 18,  5,  1 }, {     43,  -12,  -13, 18,  5,  1 }, {     44,  -13,  -13, 18,  5,  1 }, {     45,  -13,  -13, 18,  5,  1 },
    {     46,  -13,  -14, 18,  5,  1 }, {     47,  -14,  -14, 18,  5,  1 }, {     48,  -14,  -14, 18,  0,  2 }, {     49,  -14,  -14, 18,  0,  2 }, {     50,  -15,  -14, 18,  0,  2 },
    {     51,  -15,  -15, 18,  0,  2 }, {     52,  -15,  -15, 17,  0,  2 }, {     53,  -15,  -15, 17,  0,  2 }, {     54,  -15,  -15, 17,  0,  2 }, {     55,  -15,  -15, 17,  0,  2 },
    {     56,  -16,  -15, 17,  0,  2 }, {     57,  -16,  -16, 17,  0,  2 }, {     58,  -16,  -16, 17,  0,  2 }, {     59,  -16,  -16, 17,  0,  2 }, {     60,  -16,  -16, 16,  0,  2 },
    {     61,  -16,  -16, 16,  0,  2 }, {     62,  -16,  -16, 16,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9204EA, {
    {     31,   16,    7,  0,  6,  0 }, {     30,   16,    7,  0,  6,  0 }, {     29,   16,    6,  0,  6,  0 }, {     28,   16,    6,  0,  6,  0 }, {     27,   16,    5,  1,  6,  0 },
    {     26,   16,    5,  1,  6,  0 }, {     25,   17,    4,  1,  6,  0 }, {     24,   17,    4,  1,  6,  0 }, {     23,   17,    3,  1,  6,  0 }, {     22,   17,    3,  1,  6,  0 },
    {     21,   17,    2,  1,  6,  0 }, {     20,   17,    2,  1,  6,  0 }, {     19,   18,    1,  1,  6,  0 }, {     18,   18,    1,  2,  6,  0 }, {     17,   18,    0,  2,  6,  0 },
    {     16,   19,    0,  2,  6,  0 }, {     15,   19,   -1,  2,  6,  0 }, {     14,   19,   -1,  2,  6,  0 }, {     13,   20,   -2,  2,  6,  0 }, {     12,   20,   -2,  2,  6,  0 },
    {     11,   21,   -3,  2,  6,  0 }, {     10,   21,   -3,  2,  6,  0 }, {      9,   22,   -4,  2,  6,  0 }, {      8,   22,   -4,  3,  6,  0 }, {      7,   23,   -5,  3,  6,  0 },
    {      6,   23,   -5,  3,  6,  0 }, {      5,   24,   -6,  3,  6,  0 }, {      4,   25,   -6,  3,  6,  0 }, {      3,   25,   -7,  3,  6,  0 }, {      2,   26,   -7,  3,  6,  0 },
    {      1,   27,   -7,  3,  6,  0 }, {      0,   28,   -8,  3,  6,  0 }, {     -1,   29,   -8,  4,  6,  0 }, {     -3,   29,   -8,  4,  6,  0 }, {     -4,   30,   -9,  4,  6,  0 },
    {     -5,   31,   -9,  4,  5,  3 }, {     -6,   32,  -10,  4,  5,  3 }, {     -7,   33,  -10,  5,  5,  3 }, {     -7,   34,  -10,  5,  5,  3 }, {     -8,   35,  -11,  5,  5,  3 },
    {     -9,   36,  -11,  5,  5,  3 }, {     -9,   37,  -11,  5,  5,  3 }, {    -10,   38,  -12,  5,  5,  3 }, {    -10,   39,  -12,  5,  5,  3 }, {    -11,   40,  -12,  5,  5,  3 },
    {    -11,   41,  -13,  5,  5,  3 }, {    -12,   42,  -13,  6,  5,  3 }, {    -12,   43,  -13,  6,  5,  3 }, {    -13,   44,  -13,  6,  5,  3 }, {    -13,   45,  -13,  6,  5,  3 },
    {    -13,   46,  -14,  6,  5,  3 }, {    -14,   47,  -14,  6,  5,  3 }, {    -14,   48,  -14,  6,  0,  4 }, {    -14,   49,  -14,  6,  0,  4 }, {    -15,   50,  -14,  6,  0,  4 },
    {    -15,   51,  -15,  6,  0,  4 }, {    -15,   52,  -15,  7,  0,  4 }, {    -15,   53,  -15,  7,  0,  4 }, {    -15,   54,  -15,  7,  0,  4 }, {    -15,   55,  -15,  7,  0,  4 },
    {    -16,   56,  -15,  7,  0,  4 }, {    -16,   57,  -16,  7,  0,  4 }, {    -16,   58,  -16,  7,  0,  4 }, {    -16,   59,  -16,  7,  0,  4 }, {    -16,   60,  -16,  8,  0,  4 },
    {    -16,   61,  -16,  8,  0,  4 }, {    -16,   62,  -16,  8,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_920747, {
    {     16,    0,    7,  8,  6,  0 }, {     16,    1,    7,  8,  6,  0 }, {     16,    2,    6,  8,  6,  0 }, {     16,    3,    6,  8,  6,  0 }, {     16,    4,    5,  8,  6,  0 },
    {     16,    5,    5,  9,  6,  0 }, {     16,    6,    4,  9,  6,  0 }, {     17,    7,    4,  9,  6,  0 }, {     17,    8,    3,  9,  6,  0 }, {     17,    9,    3,  9,  6,  0 },
    {     17,   10,    2,  9,  6,  0 }, {     17,   11,    2,  9,  6,  0 }, {     17,   12,    1,  9,  6,  0 }, {     18,   13,    1,  9,  6,  0 }, {     18,   14,    0, 10,  6,  0 },
    {     18,   15,    0, 10,  6,  0 }, {     19,   16,   -1, 10,  6,  0 }, {     19,   17,   -1, 10,  6,  0 }, {     19,   18,   -2, 10,  6,  0 }, {     20,   19,   -2, 10,  6,  0 },
    {     20,   20,   -3, 10,  6,  0 }, {     21,   21,   -3, 10,  6,  0 }, {     21,   22,   -4, 10,  6,  0 }, {     22,   23,   -4, 10,  6,  0 }, {     22,   24,   -5, 11,  6,  0 },
    {     23,   25,   -5, 11,  6,  0 }, {     23,   26,   -6, 11,  6,  0 }, {     24,   27,   -6, 11,  6,  0 }, {     25,   28,   -7, 11,  6,  0 }, {     25,   29,   -7, 11,  6,  0 },
    {     26,   30,   -7, 11,  6,  0 }, {     27,   31,   -8, 11,  6,  0 }, {     28,   32,   -8, 11,  6,  0 }, {     29,   33,   -8, 12,  6,  0 }, {     29,   35,   -9, 12,  6,  0 },
    {     30,   36,   -9, 12,  5,  3 }, {     31,   37,  -10, 12,  5,  3 }, {     32,   38,  -10, 12,  5,  3 }, {     33,   39,  -10, 13,  5,  3 }, {     34,   39,  -11, 13,  5,  3 },
    {     35,   40,  -11, 13,  5,  3 }, {     36,   41,  -11, 13,  5,  3 }, {     37,   41,  -12, 13,  5,  3 }, {     38,   42,  -12, 13,  5,  3 }, {     39,   42,  -12, 13,  5,  3 },
    {     40,   43,  -13, 13,  5,  3 }, {     41,   43,  -13, 13,  5,  3 }, {     42,   44,  -13, 14,  5,  3 }, {     43,   44,  -13, 14,  5,  3 }, {     44,   45,  -13, 14,  5,  3 },
    {     45,   45,  -14, 14,  5,  3 }, {     46,   45,  -14, 14,  5,  3 }, {     47,   46,  -14, 14,  0,  4 }, {     48,   46,  -14, 14,  0,  4 }, {     49,   46,  -14, 14,  0,  4 },
    {     50,   47,  -15, 14,  0,  4 }, {     51,   47,  -15, 14,  0,  4 }, {     52,   47,  -15, 15,  0,  4 }, {     53,   47,  -15, 15,  0,  4 }, {     54,   47,  -15, 15,  0,  4 },
    {     55,   47,  -15, 15,  0,  4 }, {     56,   48,  -16, 15,  0,  4 }, {     57,   48,  -16, 15,  0,  4 }, {     58,   48,  -16, 15,  0,  4 }, {     59,   48,  -16, 15,  0,  4 },
    {     60,   48,  -16, 16,  0,  4 }, {     61,   48,  -16, 16,  0,  4 }, {     62,   48,  -16, 16,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9209AD, {
    {      0,   16,    7, 16,  6,  0 }, {      1,   16,    7, 16,  6,  0 }, {      2,   16,    6, 16,  6,  0 }, {      3,   16,    6, 16,  6,  0 }, {      4,   16,    5, 16,  6,  0 },
    {      5,   16,    5, 17,  6,  0 }, {      6,   16,    4, 17,  6,  0 }, {      7,   15,    4, 17,  6,  0 }, {      8,   15,    3, 17,  6,  0 }, {      9,   15,    3, 17,  6,  0 },
    {     10,   15,    2, 17,  6,  0 }, {     11,   15,    2, 17,  6,  0 }, {     12,   15,    1, 17,  6,  0 }, {     13,   14,    1, 17,  6,  0 }, {     14,   14,    0, 18,  6,  0 },
    {     15,   14,    0, 18,  6,  0 }, {     16,   13,   -1, 18,  6,  0 }, {     17,   13,   -1, 18,  6,  0 }, {     18,   13,   -2, 18,  6,  0 }, {     19,   12,   -2, 18,  6,  0 },
    {     20,   12,   -3, 18,  6,  0 }, {     21,   11,   -3, 18,  6,  0 }, {     22,   11,   -4, 18,  6,  0 }, {     23,   10,   -4, 18,  6,  0 }, {     24,   10,   -5, 19,  6,  0 },
    {     25,    9,   -5, 19,  6,  0 }, {     26,    9,   -6, 19,  6,  0 }, {     27,    8,   -6, 19,  6,  0 }, {     28,    7,   -7, 19,  6,  0 }, {     29,    7,   -7, 19,  6,  0 },
    {     30,    6,   -7, 19,  6,  0 }, {     31,    5,   -8, 19,  6,  0 }, {     32,    4,   -8, 19,  6,  0 }, {     33,    3,   -8, 20,  6,  0 }, {     35,    3,   -9, 20,  6,  0 },
    {     36,    2,   -9, 20,  5,  3 }, {     37,    1,  -10, 20,  5,  3 }, {     38,    0,  -10, 20,  5,  3 }, {     39,   -1,  -10, 21,  5,  3 }, {     39,   -2,  -11, 21,  5,  3 },
    {     40,   -3,  -11, 21,  5,  3 }, {     41,   -4,  -11, 21,  5,  3 }, {     41,   -5,  -12, 21,  5,  3 }, {     42,   -6,  -12, 21,  5,  3 }, {     42,   -7,  -12, 21,  5,  3 },
    {     43,   -8,  -13, 21,  5,  3 }, {     43,   -9,  -13, 21,  5,  3 }, {     44,  -10,  -13, 22,  5,  3 }, {     44,  -11,  -13, 22,  5,  3 }, {     45,  -12,  -13, 22,  5,  3 },
    {     45,  -13,  -14, 22,  5,  3 }, {     45,  -14,  -14, 22,  5,  3 }, {     46,  -15,  -14, 22,  0,  4 }, {     46,  -16,  -14, 22,  0,  4 }, {     46,  -17,  -14, 22,  0,  4 },
    {     47,  -18,  -15, 22,  0,  4 }, {     47,  -19,  -15, 22,  0,  4 }, {     47,  -20,  -15, 23,  0,  4 }, {     47,  -21,  -15, 23,  0,  4 }, {     47,  -22,  -15, 23,  0,  4 },
    {     47,  -23,  -15, 23,  0,  4 }, {     48,  -24,  -16, 23,  0,  4 }, {     48,  -25,  -16, 23,  0,  4 }, {     48,  -26,  -16, 23,  0,  4 }, {     48,  -27,  -16, 23,  0,  4 },
    {     48,  -28,  -16, 24,  0,  4 }, {     48,  -29,  -16, 24,  0,  4 }, {     48,  -30,  -16, 24,  0,  4 }, {     48,  -31,  -16, 24,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_920C1C, {
    {     16,   31,    7, 24,  6,  0 }, {     16,   30,    7, 24,  6,  0 }, {     16,   29,    6, 24,  6,  0 }, {     16,   28,    6, 24,  6,  0 }, {     16,   27,    5, 25,  6,  0 },
    {     16,   26,    5, 25,  6,  0 }, {     15,   25,    4, 25,  6,  0 }, {     15,   24,    4, 25,  6,  0 }, {     15,   23,    3, 25,  6,  0 }, {     15,   22,    3, 25,  6,  0 },
    {     15,   21,    2, 25,  6,  0 }, {     15,   20,    2, 25,  6,  0 }, {     14,   19,    1, 25,  6,  0 }, {     14,   18,    1, 26,  6,  0 }, {     14,   17,    0, 26,  6,  0 },
    {     13,   16,    0, 26,  6,  0 }, {     13,   15,   -1, 26,  6,  0 }, {     13,   14,   -1, 26,  6,  0 }, {     12,   13,   -2, 26,  6,  0 }, {     12,   12,   -2, 26,  6,  0 },
    {     11,   11,   -3, 26,  6,  0 }, {     11,   10,   -3, 26,  6,  0 }, {     10,    9,   -4, 26,  6,  0 }, {     10,    8,   -4, 27,  6,  0 }, {      9,    7,   -5, 27,  6,  0 },
    {      9,    6,   -5, 27,  6,  0 }, {      8,    5,   -6, 27,  6,  0 }, {      7,    4,   -6, 27,  6,  0 }, {      7,    3,   -7, 27,  6,  0 }, {      6,    2,   -7, 27,  6,  0 },
    {      5,    1,   -7, 27,  6,  0 }, {      4,    0,   -8, 27,  6,  0 }, {      3,   -1,   -8, 28,  6,  0 }, {      3,   -3,   -8, 28,  6,  0 }, {      2,   -4,   -9, 28,  6,  0 },
    {      1,   -5,   -9, 28,  5,  3 }, {      0,   -6,  -10, 28,  5,  3 }, {     -1,   -7,  -10, 29,  5,  3 }, {     -2,   -7,  -10, 29,  5,  3 }, {     -3,   -8,  -11, 29,  5,  3 },
    {     -4,   -9,  -11, 29,  5,  3 }, {     -5,   -9,  -11, 29,  5,  3 }, {     -6,  -10,  -12, 29,  5,  3 }, {     -7,  -10,  -12, 29,  5,  3 }, {     -8,  -11,  -12, 29,  5,  3 },
    {     -9,  -11,  -13, 29,  5,  3 }, {    -10,  -12,  -13, 30,  5,  3 }, {    -11,  -12,  -13, 30,  5,  3 }, {    -12,  -13,  -13, 30,  5,  3 }, {    -13,  -13,  -13, 30,  5,  3 },
    {    -14,  -13,  -14, 30,  5,  3 }, {    -15,  -14,  -14, 30,  5,  3 }, {    -16,  -14,  -14, 30,  0,  4 }, {    -17,  -14,  -14, 30,  0,  4 }, {    -18,  -15,  -14, 30,  0,  4 },
    {    -19,  -15,  -15, 30,  0,  4 }, {    -20,  -15,  -15, 31,  0,  4 }, {    -21,  -15,  -15, 31,  0,  4 }, {    -22,  -15,  -15, 31,  0,  4 }, {    -23,  -15,  -15, 31,  0,  4 },
    {    -24,  -16,  -15, 31,  0,  4 }, {    -25,  -16,  -16, 31,  0,  4 }, {    -26,  -16,  -16, 31,  0,  4 }, {    -27,  -16,  -16, 31,  0,  4 }, {    -28,  -16,  -16,  0,  0,  4 },
    {    -29,  -16,  -16,  0,  0,  4 }, {    -30,  -16,  -16,  0,  0,  4 }, {    -31,  -16,  -16,  0,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9221B2, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    0,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    1,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    2,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    3,  0,  2,  0 }, {     23,   16,    4,  0,  2,  0 }, {     22,   16,    4,  0,  2,  0 },
    {     21,   15,    5,  0,  2,  0 }, {     20,   15,    5,  0,  2,  0 }, {     19,   15,    6,  0,  2,  0 }, {     18,   15,    6,  0,  2,  0 }, {     17,   15,    7,  0,  2,  0 },
    {     16,   15,    7,  0,  2,  0 }, {     15,   15,    8,  0,  2,  0 }, {     14,   15,    8,  0,  2,  0 }, {     13,   15,    9,  0,  2,  0 }, {     12,   15,    9,  0,  2,  0 },
    {     11,   14,   10,  0,  2,  0 }, {     10,   14,   10,  0,  2,  0 }, {      9,   14,   11,  0,  2,  0 }, {      8,   14,   11,  0,  2,  0 }, {      7,   14,   12,  0,  2,  0 },
    {      6,   14,   12,  0,  2,  0 }, {      5,   14,   13,  0,  2,  0 }, {      4,   14,   13,  0,  2,  0 }, {      3,   14,   14,  0,  2,  0 }, {      2,   14,   14,  0,  2,  0 },
    {      1,   13,   15,  0,  2,  0 }, {      0,   13,   15,  0,  2,  0 }, {     -1,   13,   16,  0,  2,  0 }, {     -2,   13,   16,  0,  2,  0 }, {     -3,   13,   17,  0,  2,  0 },
    {     -4,   13,   17,  0,  2,  0 }, {     -5,   13,   18,  0,  2,  0 }, {     -6,   13,   18,  0,  2,  0 }, {     -7,   13,   19,  0,  2,  0 }, {     -8,   12,   19,  0,  2,  0 },
    {     -9,   12,   20,  0,  2,  0 }, {    -10,   12,   21,  0,  2,  0 }, {    -11,   12,   21,  0,  2,  0 }, {    -12,   12,   22,  0,  2,  0 }, {    -13,   12,   22,  0,  2,  0 },
    {    -14,   12,   23,  0,  2,  0 }, {    -15,   12,   24,  0,  2,  0 }, {    -16,   12,   24,  0,  2,  0 }, {    -17,   12,   25,  0,  2,  0 }, {    -18,   11,   25,  0,  2,  0 },
    {    -19,   11,   26,  0,  2,  0 }, {    -20,   11,   27,  0,  2,  0 }, {    -21,   11,   27,  0,  2,  0 }, {    -22,   11,   28,  0,  2,  0 }, {    -23,   11,   29,  0,  2,  0 },
    {    -24,   11,   30,  0,  2,  0 }, {    -25,   11,   30,  0,  2,  0 }, {    -26,   11,   31,  0,  2,  0 }, {    -27,   11,   32,  0,  2,  0 }, {    -28,   10,   33,  0,  2,  0 },
    {    -29,   10,   33,  0,  2,  0 }, {    -30,   10,   34,  0,  2,  0 }, {    -31,   10,   35,  0,  3,  0 }, {    -32,   10,   36,  0,  3,  0 }, {    -33,   10,   36,  0,  3,  0 },
    {    -34,   10,   37,  0,  3,  0 }, {    -35,   10,   38,  0,  3,  0 }, {    -36,   10,   39,  0,  3,  0 }, {    -37,   10,   40,  0,  3,  0 }, {    -38,    9,   41,  0,  3,  0 },
    {    -39,    9,   42,  0,  3,  0 }, {    -40,    9,   42,  0,  3,  0 }, {    -41,    9,   43,  0,  3,  0 }, {    -42,    9,   44,  0,  3,  0 }, {    -43,    9,   45,  0,  3,  0 },
    {    -44,    9,   46,  0,  3,  0 }, {    -45,    9,   47,  0,  3,  0 }, {    -46,    9,   48,  0,  3,  0 }, {    -47,    8,   49,  0,  3,  0 }, {    -48,    8,   50,  0,  3,  0 },
    {    -49,    8,   51,  0,  3,  0 }, {    -50,    8,   52,  0,  3,  0 }, {    -50,    8,   53,  0,  3,  0 }, {    -51,    8,   54,  0,  3,  0 }, {    -52,    8,   55,  0,  3,  0 },
    {    -53,    8,   56,  0,  3,  0 }, {    -54,    8,   57,  0,  3,  0 }, {    -55,    8,   58,  0,  3,  0 }, {    -56,    7,   59,  0,  3,  0 }, {    -57,    7,   60,  0,  3,  0 },
    {    -57,    7,   61,  0,  3,  0 }, {    -58,    7,   62,  0,  3,  0 }, {    -59,    7,   63,  0,  3,  0 }, {    -59,    7,   64,  0,  3,  0 }, {    -60,    7,   65,  0,  3,  0 },
    {    -61,    7,   66,  0,  3,  0 }, {    -61,    7,   67,  0,  3,  0 }, {    -62,    7,   68,  0,  3,  0 }, {    -63,    6,   69,  0,  3,  0 }, {    -64,    6,   70,  0,  3,  0 },
    {    -64,    6,   71,  0,  3,  0 }, {    -65,    6,   72,  0,  3,  0 }, {    -66,    6,   73,  0,  3,  0 }, {    -66,    6,   74,  0,  3,  0 }, {    -67,    6,   75,  0,  3,  0 },
    {    -68,    6,   76,  0,  3,  0 }, {    -68,    6,   77,  0,  3,  0 }, {    -69,    5,   78,  0,  3,  0 }, {    -69,    5,   79,  0,  3,  0 }, {    -70,    5,   80,  0,  4,  0 },
    {    -71,    5,   81,  0,  4,  0 }, {    -71,    5,   82,  0,  4,  0 }, {    -72,    5,   83,  0,  4,  0 }, {    -72,    5,   84,  0,  4,  0 }, {    -73,    5,   85,  0,  4,  0 },
    {    -74,    5,   86,  0,  4,  0 }, {    -74,    5,   87,  0,  4,  0 }, {    -75,    4,   88,  0,  4,  0 }, {    -75,    4,   89,  0,  4,  0 }, {    -76,    4,   90,  0,  4,  0 },
    {    -76,    4,   91,  0,  4,  0 }, {    -77,    4,   92,  0,  4,  0 }, {    -77,    4,   93,  0,  4,  0 }, {    -78,    4,   94,  0,  4,  0 }, {    -78,    4,   95,  0,  4,  0 },
    {    -78,    4,   96,  0,  4,  0 }, {    -79,    4,   97,  0,  4,  0 }, {    -79,    3,   98,  0,  4,  0 }, {    -80,    3,   99,  0,  4,  0 }, {    -80,    3,  100,  0,  4,  0 },
    {    -81,    3,  101,  0,  4,  0 }, {    -81,    3,  102,  0,  4,  0 }, {    -81,    3,  103,  0,  4,  0 }, {    -82,    3,  104,  0,  4,  0 }, {    -82,    3,  105,  0,  4,  0 },
    {    -83,    3,  106,  0,  4,  0 }, {    -83,    3,  107,  0,  4,  0 }, {    -83,    2,  108,  0,  4,  0 }, {    -84,    2,  109,  0,  4,  0 }, {    -84,    2,  110,  0,  4,  0 },
    {    -85,    2,  111,  0,  4,  0 }, {    -85,    2,  112,  0,  4,  0 }, {    -86,    2,  113,  0,  4,  0 }, {    -86,    2,  114,  0,  4,  0 }, {    -86,    2,  115,  0,  4,  0 },
    {    -87,    2,  116,  0,  9,  0 }, {    -87,    1,  117,  0,  9,  0 }, {    -87,    1,  118,  0,  9,  0 }, {    -87,    1,  119,  0,  9,  0 }, {    -88,    1,  120,  0,  9,  0 },
    {    -88,    1,  121,  0,  9,  0 }, {    -88,    1,  122,  0,  9,  0 }, {    -89,    1,  123,  0,  9,  0 }, {    -89,    1,  124,  0,  9,  0 }, {    -89,    1,  125,  0,  9,  0 },
    {    -90,    1,  126,  0,  9,  0 }, {    -90,    0,  127,  0,  9,  0 }, {    -90,    0,  128,  0,  9,  0 }, {    -90,    0,  129,  0,  9,  0 }, {    -91,    0,  130,  0,  9,  0 },
    {    -91,    0,  131,  0,  9,  0 }, {    -91,    0,  132,  0,  9,  0 }, {    -91,    0,  133,  0,  9,  0 }, {    -91,    0,  134,  0,  9,  0 }, {    -92,    0,  135,  0,  9,  0 },
    {    -92,    0,  136,  0,  9,  0 }, {    -92,   -1,  137,  0,  9,  0 }, {    -92,   -1,  138,  0,  9,  0 }, {    -92,   -1,  139,  0,  9,  0 }, {    -92,   -1,  140,  0,  9,  0 },
    {    -93,   -1,  141,  0,  9,  0 }, {    -93,   -1,  142,  0,  9,  0 }, {    -93,   -1,  143,  0,  9,  0 }, {    -93,   -1,  144,  0,  9,  0 }, {    -93,   -1,  145,  0,  9,  0 },
    {    -93,   -2,  146,  0,  9,  0 }, {    -94,   -2,  147,  0,  9,  0 }, {    -94,   -2,  148,  0,  9,  0 }, {    -94,   -2,  149,  0, 10,  0 }, {    -94,   -2,  150,  0, 10,  0 },
    {    -94,   -2,  151,  0, 10,  0 }, {    -94,   -2,  152,  0, 10,  0 }, {    -94,   -2,  153,  0, 10,  0 }, {    -94,   -2,  154,  0, 10,  0 }, {    -94,   -2,  155,  0, 10,  0 },
    {    -94,   -3,  156,  0, 10,  0 }, {    -94,   -3,  157,  0, 10,  0 }, {    -94,   -3,  158,  0, 10,  0 }, {    -94,   -3,  159,  0, 10,  0 }, {    -94,   -3,  160,  0, 10,  0 },
    {    -94,   -3,  161,  0, 10,  0 }, {    -94,   -3,  162,  0, 10,  0 }, {    -94,   -3,  163,  0, 10,  0 }, {    -94,   -3,  164,  0, 10,  0 }, {    -94,   -3,  165,  0, 10,  0 },
    {    -94,   -4,  166,  0, 10,  0 }, {    -94,   -4,  167,  0, 10,  0 }, {    -94,   -4,  168,  0, 10,  0 }, {    -94,   -4,  169,  0, 10,  0 }, {    -94,   -4,  170,  0, 10,  0 },
    {    -94,   -4,  171,  0, 10,  0 }, {    -94,   -4,  172,  0, 10,  0 }, {    -94,   -4,  173,  0, 10,  0 }, {    -94,   -4,  174,  0, 10,  0 }, {    -94,   -4,  175,  0, 10,  0 },
    {    -94,   -5,  176,  0, 10,  0 }, {    -94,   -5,  177,  0, 10,  0 }, {    -94,   -5,  178,  0, 10,  0 }, {    -94,   -5,  179,  0, 10,  0 }, {    -94,   -5,  180,  0, 10,  0 },
    {    -94,   -5,  181,  0, 10,  0 }, {    -94,   -5,  182,  0, 10,  0 }, {    -94,   -5,  183,  0, 10,  0 }, {    -94,   -5,  184,  0, 10,  0 }, {    -94,   -6,  185,  0, 10,  0 },
    {    -94,   -6,  186,  0, 11,  0 }, {    -94,   -6,  187,  0, 11,  0 }, {    -93,   -6,  188,  0, 11,  0 }, {    -93,   -6,  189,  0, 11,  0 }, {    -93,   -6,  190,  0, 11,  0 },
    {    -93,   -6,  191,  0, 11,  0 }, {    -93,   -6,  192,  0, 11,  0 }, {    -93,   -6,  193,  0, 11,  0 }, {    -93,   -6,  194,  0, 11,  0 }, {    -93,   -7,  195,  0, 11,  0 },
    {    -92,   -7,  196,  0, 11,  0 }, {    -92,   -7,  197,  0, 11,  0 }, {    -92,   -7,  198,  0, 11,  0 }, {    -92,   -7,  199,  0, 11,  0 }, {    -92,   -7,  200,  0, 11,  0 },
    {    -92,   -7,  201,  0, 11,  0 }, {    -91,   -7,  202,  0, 11,  0 }, {    -91,   -7,  203,  0, 11,  0 }, {    -91,   -7,  204,  0, 11,  0 }, {    -91,   -8,  205,  0, 11,  0 },
    {    -90,   -8,  206,  0, 11,  0 }, {    -90,   -8,  207,  0, 11,  0 }, {    -90,   -8,  208,  0, 11,  0 }, {    -90,   -8,  209,  0, 11,  0 }, {    -89,   -8,  210,  0, 12,  0 },
    {    -89,   -8,  211,  0, 12,  0 }, {    -89,   -8,  212,  0, 12,  0 }, {    -88,   -8,  213,  0, 12,  0 }, {    -88,   -9,  214,  0, 12,  0 }, {    -87,   -9,  215,  0, 12,  0 },
    {    -87,   -9,  216,  0, 12,  0 }, {    -87,   -9,  217,  0, 12,  0 }, {    -86,   -9,  218,  0, 12,  0 }, {    -86,   -9,  219,  0, 12,  0 }, {    -86,   -9,  220,  0, 12,  0 },
    {    -85,   -9,  221,  0, 12,  0 }, {    -85,   -9,  222,  0, 12,  0 }, {    -84,   -9,  223,  0, 12,  0 }, {    -84,  -10,  224,  0, 12,  0 }, {    -83,  -10,  225,  0, 13,  0 },
    {    -83,  -10,  226,  0, 13,  0 }, {    -82,  -10,  227,  0, 13,  0 }, {    -82,  -10,  228,  0, 13,  0 }, {    -81,  -10,  229,  0, 13,  0 }, {    -81,  -10,  230,  0, 13,  0 },
    {    -80,  -10,  231,  0, 13,  0 }, {    -80,  -10,  232,  0, 13,  0 }, {    -79,  -10,  233,  0, 13,  0 }, {    -78,  -11,  234,  0, 13,  0 }, {    -78,  -11,  235,  0, 13,  0 },
    {    -77,  -11,  236,  0, 13,  0 }, {    -76,  -11,  237,  0, 13,  0 }, {    -76,  -11,  238,  0, 13,  0 }, {    -75,  -11,  239,  0, 13,  0 }, {    -74,  -11,  240,  0, 14,  0 },
    {    -73,  -11,  241,  0, 14,  0 }, {    -73,  -11,  242,  0, 14,  0 }, {    -72,  -11,  243,  0, 14,  0 }, {    -71,  -12,  244,  0, 14,  0 }, {    -70,  -12,  245,  0, 14,  0 },
    {    -69,  -12,  246,  0, 14,  0 }, {    -68,  -12,  247,  0, 14,  0 }, {    -67,  -12,  248,  0, 14,  0 }, {    -66,  -12,  249,  0, 14,  0 }, {    -65,  -12,  250,  0, 14,  0 },
    {    -64,  -12,  251,  0, 14,  0 }, {    -63,  -12,  252,  0, 14,  0 }, {    -62,  -13,  253,  0, 15,  0 }, {    -61,  -13,  253,  0, 15,  0 }, {    -60,  -13,  254,  0, 15,  0 },
    {    -59,  -13,  255,  0, 15,  0 }, {    -58,  -13,  256,  0, 15,  0 }, {    -57,  -13,  256,  0, 15,  0 }, {    -56,  -13,  257,  0, 15,  0 }, {    -55,  -13,  258,  0, 15,  0 },
    {    -54,  -13,  258,  0, 15,  0 }, {    -53,  -13,  259,  0, 15,  0 }, {    -52,  -14,  259,  0, 15,  0 }, {    -51,  -14,  260,  0, 15,  0 }, {    -50,  -14,  260,  0, 15,  0 },
    {    -49,  -14,  261,  0, 15,  0 }, {    -48,  -14,  261,  0, 15,  0 }, {    -47,  -14,  262,  0, 16,  0 }, {    -46,  -14,  262,  0, 16,  0 }, {    -45,  -14,  262,  0, 16,  0 },
    {    -44,  -14,  263,  0, 16,  0 }, {    -43,  -14,  263,  0, 16,  0 }, {    -42,  -15,  263,  0, 16,  0 }, {    -41,  -15,  263,  0, 16,  0 }, {    -40,  -15,  264,  0, 16,  0 },
    {    -39,  -15,  264,  0, 16,  0 }, {    -38,  -15,  264,  0, 16,  0 }, {    -37,  -15,  264,  0, 16,  0 }, {    -36,  -15,  264,  0, 16,  0 }, {    -35,  -15,  264,  0, 16,  0 },
    {    -34,  -15,  264,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9237A6, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    2,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    3,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    4,  8,  2,  0 }, {     16,    9,    4,  8,  2,  0 },
    {     15,   10,    5,  8,  2,  0 }, {     15,   11,    5,  8,  2,  0 }, {     15,   12,    6,  8,  2,  0 }, {     15,   13,    6,  8,  2,  0 }, {     15,   14,    7,  8,  2,  0 },
    {     15,   15,    7,  8,  2,  0 }, {     15,   16,    8,  8,  2,  0 }, {     15,   17,    8,  8,  2,  0 }, {     15,   18,    9,  8,  2,  0 }, {     15,   19,    9,  8,  2,  0 },
    {     14,   20,   10,  8,  2,  0 }, {     14,   21,   10,  8,  2,  0 }, {     14,   22,   11,  8,  2,  0 }, {     14,   23,   11,  8,  2,  0 }, {     14,   24,   12,  8,  2,  0 },
    {     14,   25,   12,  8,  2,  0 }, {     14,   26,   13,  8,  2,  0 }, {     14,   27,   13,  8,  2,  0 }, {     14,   28,   14,  8,  2,  0 }, {     14,   29,   14,  8,  2,  0 },
    {     13,   30,   15,  8,  2,  0 }, {     13,   31,   15,  8,  2,  0 }, {     13,   32,   16,  8,  2,  0 }, {     13,   33,   16,  8,  2,  0 }, {     13,   34,   17,  8,  2,  0 },
    {     13,   35,   17,  8,  2,  0 }, {     13,   36,   18,  8,  2,  0 }, {     13,   37,   18,  8,  2,  0 }, {     13,   38,   19,  8,  2,  0 }, {     12,   39,   19,  8,  2,  0 },
    {     12,   40,   20,  8,  2,  0 }, {     12,   41,   21,  8,  2,  0 }, {     12,   42,   21,  8,  2,  0 }, {     12,   43,   22,  8,  2,  0 }, {     12,   44,   22,  8,  2,  0 },
    {     12,   45,   23,  8,  2,  0 }, {     12,   46,   24,  8,  2,  0 }, {     12,   47,   24,  8,  2,  0 }, {     12,   48,   25,  8,  2,  0 }, {     11,   49,   25,  8,  2,  0 },
    {     11,   50,   26,  8,  2,  0 }, {     11,   51,   27,  8,  2,  0 }, {     11,   52,   27,  8,  2,  0 }, {     11,   53,   28,  8,  2,  0 }, {     11,   54,   29,  8,  2,  0 },
    {     11,   55,   30,  8,  2,  0 }, {     11,   56,   30,  8,  2,  0 }, {     11,   57,   31,  8,  2,  0 }, {     11,   58,   32,  8,  2,  0 }, {     10,   59,   33,  8,  2,  0 },
    {     10,   60,   33,  8,  2,  0 }, {     10,   61,   34,  8,  2,  0 }, {     10,   62,   35,  8,  3,  0 }, {     10,   63,   36,  8,  3,  0 }, {     10,   64,   36,  8,  3,  0 },
    {     10,   65,   37,  8,  3,  0 }, {     10,   66,   38,  8,  3,  0 }, {     10,   67,   39,  8,  3,  0 }, {     10,   68,   40,  8,  3,  0 }, {      9,   69,   41,  8,  3,  0 },
    {      9,   70,   42,  8,  3,  0 }, {      9,   71,   42,  8,  3,  0 }, {      9,   72,   43,  8,  3,  0 }, {      9,   73,   44,  8,  3,  0 }, {      9,   74,   45,  8,  3,  0 },
    {      9,   75,   46,  8,  3,  0 }, {      9,   76,   47,  8,  3,  0 }, {      9,   77,   48,  8,  3,  0 }, {      8,   78,   49,  8,  3,  0 }, {      8,   79,   50,  8,  3,  0 },
    {      8,   80,   51,  8,  3,  0 }, {      8,   81,   52,  8,  3,  0 }, {      8,   81,   53,  8,  3,  0 }, {      8,   82,   54,  8,  3,  0 }, {      8,   83,   55,  8,  3,  0 },
    {      8,   84,   56,  8,  3,  0 }, {      8,   85,   57,  8,  3,  0 }, {      8,   86,   58,  8,  3,  0 }, {      7,   87,   59,  8,  3,  0 }, {      7,   88,   60,  8,  3,  0 },
    {      7,   88,   61,  8,  3,  0 }, {      7,   89,   62,  8,  3,  0 }, {      7,   90,   63,  8,  3,  0 }, {      7,   90,   64,  8,  3,  0 }, {      7,   91,   65,  8,  3,  0 },
    {      7,   92,   66,  8,  3,  0 }, {      7,   92,   67,  8,  3,  0 }, {      7,   93,   68,  8,  3,  0 }, {      6,   94,   69,  8,  3,  0 }, {      6,   95,   70,  8,  3,  0 },
    {      6,   95,   71,  8,  3,  0 }, {      6,   96,   72,  8,  3,  0 }, {      6,   97,   73,  8,  3,  0 }, {      6,   97,   74,  8,  3,  0 }, {      6,   98,   75,  8,  3,  0 },
    {      6,   99,   76,  8,  3,  0 }, {      6,   99,   77,  8,  3,  0 }, {      5,  100,   78,  8,  3,  0 }, {      5,  100,   79,  8,  3,  0 }, {      5,  101,   80,  8,  4,  0 },
    {      5,  102,   81,  8,  4,  0 }, {      5,  102,   82,  8,  4,  0 }, {      5,  103,   83,  8,  4,  0 }, {      5,  103,   84,  8,  4,  0 }, {      5,  104,   85,  8,  4,  0 },
    {      5,  105,   86,  8,  4,  0 }, {      5,  105,   87,  8,  4,  0 }, {      4,  106,   88,  8,  4,  0 }, {      4,  106,   89,  8,  4,  0 }, {      4,  107,   90,  8,  4,  0 },
    {      4,  107,   91,  8,  4,  0 }, {      4,  108,   92,  8,  4,  0 }, {      4,  108,   93,  8,  4,  0 }, {      4,  109,   94,  8,  4,  0 }, {      4,  109,   95,  8,  4,  0 },
    {      4,  109,   96,  8,  4,  0 }, {      4,  110,   97,  8,  4,  0 }, {      3,  110,   98,  8,  4,  0 }, {      3,  111,   99,  8,  4,  0 }, {      3,  111,  100,  8,  4,  0 },
    {      3,  112,  101,  8,  4,  0 }, {      3,  112,  102,  8,  4,  0 }, {      3,  112,  103,  8,  4,  0 }, {      3,  113,  104,  8,  4,  0 }, {      3,  113,  105,  8,  4,  0 },
    {      3,  114,  106,  8,  4,  0 }, {      3,  114,  107,  8,  4,  0 }, {      2,  114,  108,  8,  4,  0 }, {      2,  115,  109,  8,  4,  0 }, {      2,  115,  110,  8,  4,  0 },
    {      2,  116,  111,  8,  4,  0 }, {      2,  116,  112,  8,  4,  0 }, {      2,  117,  113,  8,  4,  0 }, {      2,  117,  114,  8,  4,  0 }, {      2,  117,  115,  8,  4,  0 },
    {      2,  118,  116,  8,  9,  0 }, {      1,  118,  117,  8,  9,  0 }, {      1,  118,  118,  8,  9,  0 }, {      1,  118,  119,  8,  9,  0 }, {      1,  119,  120,  8,  9,  0 },
    {      1,  119,  121,  8,  9,  0 }, {      1,  119,  122,  8,  9,  0 }, {      1,  120,  123,  8,  9,  0 }, {      1,  120,  124,  8,  9,  0 }, {      1,  120,  125,  8,  9,  0 },
    {      1,  121,  126,  8,  9,  0 }, {      0,  121,  127,  8,  9,  0 }, {      0,  121,  128,  8,  9,  0 }, {      0,  121,  129,  8,  9,  0 }, {      0,  122,  130,  8,  9,  0 },
    {      0,  122,  131,  8,  9,  0 }, {      0,  122,  132,  8,  9,  0 }, {      0,  122,  133,  8,  9,  0 }, {      0,  122,  134,  8,  9,  0 }, {      0,  123,  135,  8,  9,  0 },
    {      0,  123,  136,  8,  9,  0 }, {     -1,  123,  137,  8,  9,  0 }, {     -1,  123,  138,  8,  9,  0 }, {     -1,  123,  139,  8,  9,  0 }, {     -1,  123,  140,  8,  9,  0 },
    {     -1,  124,  141,  8,  9,  0 }, {     -1,  124,  142,  8,  9,  0 }, {     -1,  124,  143,  8,  9,  0 }, {     -1,  124,  144,  8,  9,  0 }, {     -1,  124,  145,  8,  9,  0 },
    {     -2,  124,  146,  8,  9,  0 }, {     -2,  125,  147,  8,  9,  0 }, {     -2,  125,  148,  8,  9,  0 }, {     -2,  125,  149,  8, 10,  0 }, {     -2,  125,  150,  8, 10,  0 },
    {     -2,  125,  151,  8, 10,  0 }, {     -2,  125,  152,  8, 10,  0 }, {     -2,  125,  153,  8, 10,  0 }, {     -2,  125,  154,  8, 10,  0 }, {     -2,  125,  155,  8, 10,  0 },
    {     -3,  125,  156,  8, 10,  0 }, {     -3,  125,  157,  8, 10,  0 }, {     -3,  125,  158,  8, 10,  0 }, {     -3,  125,  159,  8, 10,  0 }, {     -3,  125,  160,  8, 10,  0 },
    {     -3,  125,  161,  8, 10,  0 }, {     -3,  125,  162,  8, 10,  0 }, {     -3,  125,  163,  8, 10,  0 }, {     -3,  125,  164,  8, 10,  0 }, {     -3,  125,  165,  8, 10,  0 },
    {     -4,  125,  166,  8, 10,  0 }, {     -4,  125,  167,  8, 10,  0 }, {     -4,  125,  168,  8, 10,  0 }, {     -4,  125,  169,  8, 10,  0 }, {     -4,  125,  170,  8, 10,  0 },
    {     -4,  125,  171,  8, 10,  0 }, {     -4,  125,  172,  8, 10,  0 }, {     -4,  125,  173,  8, 10,  0 }, {     -4,  125,  174,  8, 10,  0 }, {     -4,  125,  175,  8, 10,  0 },
    {     -5,  125,  176,  8, 10,  0 }, {     -5,  125,  177,  8, 10,  0 }, {     -5,  125,  178,  8, 10,  0 }, {     -5,  125,  179,  8, 10,  0 }, {     -5,  125,  180,  8, 10,  0 },
    {     -5,  125,  181,  8, 10,  0 }, {     -5,  125,  182,  8, 10,  0 }, {     -5,  125,  183,  8, 10,  0 }, {     -5,  125,  184,  8, 10,  0 }, {     -6,  125,  185,  8, 10,  0 },
    {     -6,  125,  186,  8, 11,  0 }, {     -6,  125,  187,  8, 11,  0 }, {     -6,  124,  188,  8, 11,  0 }, {     -6,  124,  189,  8, 11,  0 }, {     -6,  124,  190,  8, 11,  0 },
    {     -6,  124,  191,  8, 11,  0 }, {     -6,  124,  192,  8, 11,  0 }, {     -6,  124,  193,  8, 11,  0 }, {     -6,  124,  194,  8, 11,  0 }, {     -7,  124,  195,  8, 11,  0 },
    {     -7,  123,  196,  8, 11,  0 }, {     -7,  123,  197,  8, 11,  0 }, {     -7,  123,  198,  8, 11,  0 }, {     -7,  123,  199,  8, 11,  0 }, {     -7,  123,  200,  8, 11,  0 },
    {     -7,  123,  201,  8, 11,  0 }, {     -7,  122,  202,  8, 11,  0 }, {     -7,  122,  203,  8, 11,  0 }, {     -7,  122,  204,  8, 11,  0 }, {     -8,  122,  205,  8, 11,  0 },
    {     -8,  121,  206,  8, 11,  0 }, {     -8,  121,  207,  8, 11,  0 }, {     -8,  121,  208,  8, 11,  0 }, {     -8,  121,  209,  8, 11,  0 }, {     -8,  120,  210,  8, 12,  0 },
    {     -8,  120,  211,  8, 12,  0 }, {     -8,  120,  212,  8, 12,  0 }, {     -8,  119,  213,  8, 12,  0 }, {     -9,  119,  214,  8, 12,  0 }, {     -9,  118,  215,  8, 12,  0 },
    {     -9,  118,  216,  8, 12,  0 }, {     -9,  118,  217,  8, 12,  0 }, {     -9,  117,  218,  8, 12,  0 }, {     -9,  117,  219,  8, 12,  0 }, {     -9,  117,  220,  8, 12,  0 },
    {     -9,  116,  221,  8, 12,  0 }, {     -9,  116,  222,  8, 12,  0 }, {     -9,  115,  223,  8, 12,  0 }, {    -10,  115,  224,  8, 12,  0 }, {    -10,  114,  225,  8, 13,  0 },
    {    -10,  114,  226,  8, 13,  0 }, {    -10,  113,  227,  8, 13,  0 }, {    -10,  113,  228,  8, 13,  0 }, {    -10,  112,  229,  8, 13,  0 }, {    -10,  112,  230,  8, 13,  0 },
    {    -10,  111,  231,  8, 13,  0 }, {    -10,  111,  232,  8, 13,  0 }, {    -10,  110,  233,  8, 13,  0 }, {    -11,  109,  234,  8, 13,  0 }, {    -11,  109,  235,  8, 13,  0 },
    {    -11,  108,  236,  8, 13,  0 }, {    -11,  107,  237,  8, 13,  0 }, {    -11,  107,  238,  8, 13,  0 }, {    -11,  106,  239,  8, 13,  0 }, {    -11,  105,  240,  8, 14,  0 },
    {    -11,  104,  241,  8, 14,  0 }, {    -11,  104,  242,  8, 14,  0 }, {    -11,  103,  243,  8, 14,  0 }, {    -12,  102,  244,  8, 14,  0 }, {    -12,  101,  245,  8, 14,  0 },
    {    -12,  100,  246,  8, 14,  0 }, {    -12,   99,  247,  8, 14,  0 }, {    -12,   98,  248,  8, 14,  0 }, {    -12,   97,  249,  8, 14,  0 }, {    -12,   96,  250,  8, 14,  0 },
    {    -12,   95,  251,  8, 14,  0 }, {    -12,   94,  252,  8, 14,  0 }, {    -13,   93,  253,  8, 15,  0 }, {    -13,   92,  253,  8, 15,  0 }, {    -13,   91,  254,  8, 15,  0 },
    {    -13,   90,  255,  8, 15,  0 }, {    -13,   89,  256,  8, 15,  0 }, {    -13,   88,  256,  8, 15,  0 }, {    -13,   87,  257,  8, 15,  0 }, {    -13,   86,  258,  8, 15,  0 },
    {    -13,   85,  258,  8, 15,  0 }, {    -13,   84,  259,  8, 15,  0 }, {    -14,   83,  259,  8, 15,  0 }, {    -14,   82,  260,  8, 15,  0 }, {    -14,   81,  260,  8, 15,  0 },
    {    -14,   80,  261,  8, 15,  0 }, {    -14,   79,  261,  8, 15,  0 }, {    -14,   78,  262,  8, 16,  0 }, {    -14,   77,  262,  8, 16,  0 }, {    -14,   76,  262,  8, 16,  0 },
    {    -14,   75,  263,  8, 16,  0 }, {    -14,   74,  263,  8, 16,  0 }, {    -15,   73,  263,  8, 16,  0 }, {    -15,   72,  263,  8, 16,  0 }, {    -15,   71,  264,  8, 16,  0 },
    {    -15,   70,  264,  8, 16,  0 }, {    -15,   69,  264,  8, 16,  0 }, {    -15,   68,  264,  8, 16,  0 }, {    -15,   67,  264,  8, 16,  0 }, {    -15,   66,  264,  8, 16,  0 },
    {    -15,   65,  264,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_924D9A, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    2, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    3, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    4, 16,  2,  0 }, {      9,   16,    4, 16,  2,  0 },
    {     10,   17,    5, 16,  2,  0 }, {     11,   17,    5, 16,  2,  0 }, {     12,   17,    6, 16,  2,  0 }, {     13,   17,    6, 16,  2,  0 }, {     14,   17,    7, 16,  2,  0 },
    {     15,   17,    7, 16,  2,  0 }, {     16,   17,    8, 16,  2,  0 }, {     17,   17,    8, 16,  2,  0 }, {     18,   17,    9, 16,  2,  0 }, {     19,   17,    9, 16,  2,  0 },
    {     20,   18,   10, 16,  2,  0 }, {     21,   18,   10, 16,  2,  0 }, {     22,   18,   11, 16,  2,  0 }, {     23,   18,   11, 16,  2,  0 }, {     24,   18,   12, 16,  2,  0 },
    {     25,   18,   12, 16,  2,  0 }, {     26,   18,   13, 16,  2,  0 }, {     27,   18,   13, 16,  2,  0 }, {     28,   18,   14, 16,  2,  0 }, {     29,   18,   14, 16,  2,  0 },
    {     30,   19,   15, 16,  2,  0 }, {     31,   19,   15, 16,  2,  0 }, {     32,   19,   16, 16,  2,  0 }, {     33,   19,   16, 16,  2,  0 }, {     34,   19,   17, 16,  2,  0 },
    {     35,   19,   17, 16,  2,  0 }, {     36,   19,   18, 16,  2,  0 }, {     37,   19,   18, 16,  2,  0 }, {     38,   19,   19, 16,  2,  0 }, {     39,   20,   19, 16,  2,  0 },
    {     40,   20,   20, 16,  2,  0 }, {     41,   20,   21, 16,  2,  0 }, {     42,   20,   21, 16,  2,  0 }, {     43,   20,   22, 16,  2,  0 }, {     44,   20,   22, 16,  2,  0 },
    {     45,   20,   23, 16,  2,  0 }, {     46,   20,   24, 16,  2,  0 }, {     47,   20,   24, 16,  2,  0 }, {     48,   20,   25, 16,  2,  0 }, {     49,   21,   25, 16,  2,  0 },
    {     50,   21,   26, 16,  2,  0 }, {     51,   21,   27, 16,  2,  0 }, {     52,   21,   27, 16,  2,  0 }, {     53,   21,   28, 16,  2,  0 }, {     54,   21,   29, 16,  2,  0 },
    {     55,   21,   30, 16,  2,  0 }, {     56,   21,   30, 16,  2,  0 }, {     57,   21,   31, 16,  2,  0 }, {     58,   21,   32, 16,  2,  0 }, {     59,   22,   33, 16,  2,  0 },
    {     60,   22,   33, 16,  2,  0 }, {     61,   22,   34, 16,  2,  0 }, {     62,   22,   35, 16,  3,  0 }, {     63,   22,   36, 16,  3,  0 }, {     64,   22,   36, 16,  3,  0 },
    {     65,   22,   37, 16,  3,  0 }, {     66,   22,   38, 16,  3,  0 }, {     67,   22,   39, 16,  3,  0 }, {     68,   22,   40, 16,  3,  0 }, {     69,   23,   41, 16,  3,  0 },
    {     70,   23,   42, 16,  3,  0 }, {     71,   23,   42, 16,  3,  0 }, {     72,   23,   43, 16,  3,  0 }, {     73,   23,   44, 16,  3,  0 }, {     74,   23,   45, 16,  3,  0 },
    {     75,   23,   46, 16,  3,  0 }, {     76,   23,   47, 16,  3,  0 }, {     77,   23,   48, 16,  3,  0 }, {     78,   24,   49, 16,  3,  0 }, {     79,   24,   50, 16,  3,  0 },
    {     80,   24,   51, 16,  3,  0 }, {     81,   24,   52, 16,  3,  0 }, {     81,   24,   53, 16,  3,  0 }, {     82,   24,   54, 16,  3,  0 }, {     83,   24,   55, 16,  3,  0 },
    {     84,   24,   56, 16,  3,  0 }, {     85,   24,   57, 16,  3,  0 }, {     86,   24,   58, 16,  3,  0 }, {     87,   25,   59, 16,  3,  0 }, {     88,   25,   60, 16,  3,  0 },
    {     88,   25,   61, 16,  3,  0 }, {     89,   25,   62, 16,  3,  0 }, {     90,   25,   63, 16,  3,  0 }, {     90,   25,   64, 16,  3,  0 }, {     91,   25,   65, 16,  3,  0 },
    {     92,   25,   66, 16,  3,  0 }, {     92,   25,   67, 16,  3,  0 }, {     93,   25,   68, 16,  3,  0 }, {     94,   26,   69, 16,  3,  0 }, {     95,   26,   70, 16,  3,  0 },
    {     95,   26,   71, 16,  3,  0 }, {     96,   26,   72, 16,  3,  0 }, {     97,   26,   73, 16,  3,  0 }, {     97,   26,   74, 16,  3,  0 }, {     98,   26,   75, 16,  3,  0 },
    {     99,   26,   76, 16,  3,  0 }, {     99,   26,   77, 16,  3,  0 }, {    100,   27,   78, 16,  3,  0 }, {    100,   27,   79, 16,  3,  0 }, {    101,   27,   80, 16,  4,  0 },
    {    102,   27,   81, 16,  4,  0 }, {    102,   27,   82, 16,  4,  0 }, {    103,   27,   83, 16,  4,  0 }, {    103,   27,   84, 16,  4,  0 }, {    104,   27,   85, 16,  4,  0 },
    {    105,   27,   86, 16,  4,  0 }, {    105,   27,   87, 16,  4,  0 }, {    106,   28,   88, 16,  4,  0 }, {    106,   28,   89, 16,  4,  0 }, {    107,   28,   90, 16,  4,  0 },
    {    107,   28,   91, 16,  4,  0 }, {    108,   28,   92, 16,  4,  0 }, {    108,   28,   93, 16,  4,  0 }, {    109,   28,   94, 16,  4,  0 }, {    109,   28,   95, 16,  4,  0 },
    {    109,   28,   96, 16,  4,  0 }, {    110,   28,   97, 16,  4,  0 }, {    110,   29,   98, 16,  4,  0 }, {    111,   29,   99, 16,  4,  0 }, {    111,   29,  100, 16,  4,  0 },
    {    112,   29,  101, 16,  4,  0 }, {    112,   29,  102, 16,  4,  0 }, {    112,   29,  103, 16,  4,  0 }, {    113,   29,  104, 16,  4,  0 }, {    113,   29,  105, 16,  4,  0 },
    {    114,   29,  106, 16,  4,  0 }, {    114,   29,  107, 16,  4,  0 }, {    114,   30,  108, 16,  4,  0 }, {    115,   30,  109, 16,  4,  0 }, {    115,   30,  110, 16,  4,  0 },
    {    116,   30,  111, 16,  4,  0 }, {    116,   30,  112, 16,  4,  0 }, {    117,   30,  113, 16,  4,  0 }, {    117,   30,  114, 16,  4,  0 }, {    117,   30,  115, 16,  4,  0 },
    {    118,   30,  116, 16,  9,  0 }, {    118,   31,  117, 16,  9,  0 }, {    118,   31,  118, 16,  9,  0 }, {    118,   31,  119, 16,  9,  0 }, {    119,   31,  120, 16,  9,  0 },
    {    119,   31,  121, 16,  9,  0 }, {    119,   31,  122, 16,  9,  0 }, {    120,   31,  123, 16,  9,  0 }, {    120,   31,  124, 16,  9,  0 }, {    120,   31,  125, 16,  9,  0 },
    {    121,   31,  126, 16,  9,  0 }, {    121,   32,  127, 16,  9,  0 }, {    121,   32,  128, 16,  9,  0 }, {    121,   32,  129, 16,  9,  0 }, {    122,   32,  130, 16,  9,  0 },
    {    122,   32,  131, 16,  9,  0 }, {    122,   32,  132, 16,  9,  0 }, {    122,   32,  133, 16,  9,  0 }, {    122,   32,  134, 16,  9,  0 }, {    123,   32,  135, 16,  9,  0 },
    {    123,   32,  136, 16,  9,  0 }, {    123,   33,  137, 16,  9,  0 }, {    123,   33,  138, 16,  9,  0 }, {    123,   33,  139, 16,  9,  0 }, {    123,   33,  140, 16,  9,  0 },
    {    124,   33,  141, 16,  9,  0 }, {    124,   33,  142, 16,  9,  0 }, {    124,   33,  143, 16,  9,  0 }, {    124,   33,  144, 16,  9,  0 }, {    124,   33,  145, 16,  9,  0 },
    {    124,   34,  146, 16,  9,  0 }, {    125,   34,  147, 16,  9,  0 }, {    125,   34,  148, 16,  9,  0 }, {    125,   34,  149, 16, 10,  0 }, {    125,   34,  150, 16, 10,  0 },
    {    125,   34,  151, 16, 10,  0 }, {    125,   34,  152, 16, 10,  0 }, {    125,   34,  153, 16, 10,  0 }, {    125,   34,  154, 16, 10,  0 }, {    125,   34,  155, 16, 10,  0 },
    {    125,   35,  156, 16, 10,  0 }, {    125,   35,  157, 16, 10,  0 }, {    125,   35,  158, 16, 10,  0 }, {    125,   35,  159, 16, 10,  0 }, {    125,   35,  160, 16, 10,  0 },
    {    125,   35,  161, 16, 10,  0 }, {    125,   35,  162, 16, 10,  0 }, {    125,   35,  163, 16, 10,  0 }, {    125,   35,  164, 16, 10,  0 }, {    125,   35,  165, 16, 10,  0 },
    {    125,   36,  166, 16, 10,  0 }, {    125,   36,  167, 16, 10,  0 }, {    125,   36,  168, 16, 10,  0 }, {    125,   36,  169, 16, 10,  0 }, {    125,   36,  170, 16, 10,  0 },
    {    125,   36,  171, 16, 10,  0 }, {    125,   36,  172, 16, 10,  0 }, {    125,   36,  173, 16, 10,  0 }, {    125,   36,  174, 16, 10,  0 }, {    125,   36,  175, 16, 10,  0 },
    {    125,   37,  176, 16, 10,  0 }, {    125,   37,  177, 16, 10,  0 }, {    125,   37,  178, 16, 10,  0 }, {    125,   37,  179, 16, 10,  0 }, {    125,   37,  180, 16, 10,  0 },
    {    125,   37,  181, 16, 10,  0 }, {    125,   37,  182, 16, 10,  0 }, {    125,   37,  183, 16, 10,  0 }, {    125,   37,  184, 16, 10,  0 }, {    125,   38,  185, 16, 10,  0 },
    {    125,   38,  186, 16, 11,  0 }, {    125,   38,  187, 16, 11,  0 }, {    124,   38,  188, 16, 11,  0 }, {    124,   38,  189, 16, 11,  0 }, {    124,   38,  190, 16, 11,  0 },
    {    124,   38,  191, 16, 11,  0 }, {    124,   38,  192, 16, 11,  0 }, {    124,   38,  193, 16, 11,  0 }, {    124,   38,  194, 16, 11,  0 }, {    124,   39,  195, 16, 11,  0 },
    {    123,   39,  196, 16, 11,  0 }, {    123,   39,  197, 16, 11,  0 }, {    123,   39,  198, 16, 11,  0 }, {    123,   39,  199, 16, 11,  0 }, {    123,   39,  200, 16, 11,  0 },
    {    123,   39,  201, 16, 11,  0 }, {    122,   39,  202, 16, 11,  0 }, {    122,   39,  203, 16, 11,  0 }, {    122,   39,  204, 16, 11,  0 }, {    122,   40,  205, 16, 11,  0 },
    {    121,   40,  206, 16, 11,  0 }, {    121,   40,  207, 16, 11,  0 }, {    121,   40,  208, 16, 11,  0 }, {    121,   40,  209, 16, 11,  0 }, {    120,   40,  210, 16, 12,  0 },
    {    120,   40,  211, 16, 12,  0 }, {    120,   40,  212, 16, 12,  0 }, {    119,   40,  213, 16, 12,  0 }, {    119,   41,  214, 16, 12,  0 }, {    118,   41,  215, 16, 12,  0 },
    {    118,   41,  216, 16, 12,  0 }, {    118,   41,  217, 16, 12,  0 }, {    117,   41,  218, 16, 12,  0 }, {    117,   41,  219, 16, 12,  0 }, {    117,   41,  220, 16, 12,  0 },
    {    116,   41,  221, 16, 12,  0 }, {    116,   41,  222, 16, 12,  0 }, {    115,   41,  223, 16, 12,  0 }, {    115,   42,  224, 16, 12,  0 }, {    114,   42,  225, 16, 13,  0 },
    {    114,   42,  226, 16, 13,  0 }, {    113,   42,  227, 16, 13,  0 }, {    113,   42,  228, 16, 13,  0 }, {    112,   42,  229, 16, 13,  0 }, {    112,   42,  230, 16, 13,  0 },
    {    111,   42,  231, 16, 13,  0 }, {    111,   42,  232, 16, 13,  0 }, {    110,   42,  233, 16, 13,  0 }, {    109,   43,  234, 16, 13,  0 }, {    109,   43,  235, 16, 13,  0 },
    {    108,   43,  236, 16, 13,  0 }, {    107,   43,  237, 16, 13,  0 }, {    107,   43,  238, 16, 13,  0 }, {    106,   43,  239, 16, 13,  0 }, {    105,   43,  240, 16, 14,  0 },
    {    104,   43,  241, 16, 14,  0 }, {    104,   43,  242, 16, 14,  0 }, {    103,   43,  243, 16, 14,  0 }, {    102,   44,  244, 16, 14,  0 }, {    101,   44,  245, 16, 14,  0 },
    {    100,   44,  246, 16, 14,  0 }, {     99,   44,  247, 16, 14,  0 }, {     98,   44,  248, 16, 14,  0 }, {     97,   44,  249, 16, 14,  0 }, {     96,   44,  250, 16, 14,  0 },
    {     95,   44,  251, 16, 14,  0 }, {     94,   44,  252, 16, 14,  0 }, {     93,   45,  253, 16, 15,  0 }, {     92,   45,  253, 16, 15,  0 }, {     91,   45,  254, 16, 15,  0 },
    {     90,   45,  255, 16, 15,  0 }, {     89,   45,  256, 16, 15,  0 }, {     88,   45,  256, 16, 15,  0 }, {     87,   45,  257, 16, 15,  0 }, {     86,   45,  258, 16, 15,  0 },
    {     85,   45,  258, 16, 15,  0 }, {     84,   45,  259, 16, 15,  0 }, {     83,   46,  259, 16, 15,  0 }, {     82,   46,  260, 16, 15,  0 }, {     81,   46,  260, 16, 15,  0 },
    {     80,   46,  261, 16, 15,  0 }, {     79,   46,  261, 16, 15,  0 }, {     78,   46,  262, 16, 16,  0 }, {     77,   46,  262, 16, 16,  0 }, {     76,   46,  262, 16, 16,  0 },
    {     75,   46,  263, 16, 16,  0 }, {     74,   46,  263, 16, 16,  0 }, {     73,   47,  263, 16, 16,  0 }, {     72,   47,  263, 16, 16,  0 }, {     71,   47,  264, 16, 16,  0 },
    {     70,   47,  264, 16, 16,  0 }, {     69,   47,  264, 16, 16,  0 }, {     68,   47,  264, 16, 16,  0 }, {     67,   47,  264, 16, 16,  0 }, {     66,   47,  264, 16, 16,  0 },
    {     65,   47,  264, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92638E, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    0, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    1, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    2, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    3, 24,  2,  0 }, {     16,   23,    4, 24,  2,  0 }, {     16,   22,    4, 24,  2,  0 },
    {     17,   21,    5, 24,  2,  0 }, {     17,   20,    5, 24,  2,  0 }, {     17,   19,    6, 24,  2,  0 }, {     17,   18,    6, 24,  2,  0 }, {     17,   17,    7, 24,  2,  0 },
    {     17,   16,    7, 24,  2,  0 }, {     17,   15,    8, 24,  2,  0 }, {     17,   14,    8, 24,  2,  0 }, {     17,   13,    9, 24,  2,  0 }, {     17,   12,    9, 24,  2,  0 },
    {     18,   11,   10, 24,  2,  0 }, {     18,   10,   10, 24,  2,  0 }, {     18,    9,   11, 24,  2,  0 }, {     18,    8,   11, 24,  2,  0 }, {     18,    7,   12, 24,  2,  0 },
    {     18,    6,   12, 24,  2,  0 }, {     18,    5,   13, 24,  2,  0 }, {     18,    4,   13, 24,  2,  0 }, {     18,    3,   14, 24,  2,  0 }, {     18,    2,   14, 24,  2,  0 },
    {     19,    1,   15, 24,  2,  0 }, {     19,    0,   15, 24,  2,  0 }, {     19,   -1,   16, 24,  2,  0 }, {     19,   -2,   16, 24,  2,  0 }, {     19,   -3,   17, 24,  2,  0 },
    {     19,   -4,   17, 24,  2,  0 }, {     19,   -5,   18, 24,  2,  0 }, {     19,   -6,   18, 24,  2,  0 }, {     19,   -7,   19, 24,  2,  0 }, {     20,   -8,   19, 24,  2,  0 },
    {     20,   -9,   20, 24,  2,  0 }, {     20,  -10,   21, 24,  2,  0 }, {     20,  -11,   21, 24,  2,  0 }, {     20,  -12,   22, 24,  2,  0 }, {     20,  -13,   22, 24,  2,  0 },
    {     20,  -14,   23, 24,  2,  0 }, {     20,  -15,   24, 24,  2,  0 }, {     20,  -16,   24, 24,  2,  0 }, {     20,  -17,   25, 24,  2,  0 }, {     21,  -18,   25, 24,  2,  0 },
    {     21,  -19,   26, 24,  2,  0 }, {     21,  -20,   27, 24,  2,  0 }, {     21,  -21,   27, 24,  2,  0 }, {     21,  -22,   28, 24,  2,  0 }, {     21,  -23,   29, 24,  2,  0 },
    {     21,  -24,   30, 24,  2,  0 }, {     21,  -25,   30, 24,  2,  0 }, {     21,  -26,   31, 24,  2,  0 }, {     21,  -27,   32, 24,  2,  0 }, {     22,  -28,   33, 24,  2,  0 },
    {     22,  -29,   33, 24,  2,  0 }, {     22,  -30,   34, 24,  2,  0 }, {     22,  -31,   35, 24,  3,  0 }, {     22,  -32,   36, 24,  3,  0 }, {     22,  -33,   36, 24,  3,  0 },
    {     22,  -34,   37, 24,  3,  0 }, {     22,  -35,   38, 24,  3,  0 }, {     22,  -36,   39, 24,  3,  0 }, {     22,  -37,   40, 24,  3,  0 }, {     23,  -38,   41, 24,  3,  0 },
    {     23,  -39,   42, 24,  3,  0 }, {     23,  -40,   42, 24,  3,  0 }, {     23,  -41,   43, 24,  3,  0 }, {     23,  -42,   44, 24,  3,  0 }, {     23,  -43,   45, 24,  3,  0 },
    {     23,  -44,   46, 24,  3,  0 }, {     23,  -45,   47, 24,  3,  0 }, {     23,  -46,   48, 24,  3,  0 }, {     24,  -47,   49, 24,  3,  0 }, {     24,  -48,   50, 24,  3,  0 },
    {     24,  -49,   51, 24,  3,  0 }, {     24,  -50,   52, 24,  3,  0 }, {     24,  -50,   53, 24,  3,  0 }, {     24,  -51,   54, 24,  3,  0 }, {     24,  -52,   55, 24,  3,  0 },
    {     24,  -53,   56, 24,  3,  0 }, {     24,  -54,   57, 24,  3,  0 }, {     24,  -55,   58, 24,  3,  0 }, {     25,  -56,   59, 24,  3,  0 }, {     25,  -57,   60, 24,  3,  0 },
    {     25,  -57,   61, 24,  3,  0 }, {     25,  -58,   62, 24,  3,  0 }, {     25,  -59,   63, 24,  3,  0 }, {     25,  -59,   64, 24,  3,  0 }, {     25,  -60,   65, 24,  3,  0 },
    {     25,  -61,   66, 24,  3,  0 }, {     25,  -61,   67, 24,  3,  0 }, {     25,  -62,   68, 24,  3,  0 }, {     26,  -63,   69, 24,  3,  0 }, {     26,  -64,   70, 24,  3,  0 },
    {     26,  -64,   71, 24,  3,  0 }, {     26,  -65,   72, 24,  3,  0 }, {     26,  -66,   73, 24,  3,  0 }, {     26,  -66,   74, 24,  3,  0 }, {     26,  -67,   75, 24,  3,  0 },
    {     26,  -68,   76, 24,  3,  0 }, {     26,  -68,   77, 24,  3,  0 }, {     27,  -69,   78, 24,  3,  0 }, {     27,  -69,   79, 24,  3,  0 }, {     27,  -70,   80, 24,  4,  0 },
    {     27,  -71,   81, 24,  4,  0 }, {     27,  -71,   82, 24,  4,  0 }, {     27,  -72,   83, 24,  4,  0 }, {     27,  -72,   84, 24,  4,  0 }, {     27,  -73,   85, 24,  4,  0 },
    {     27,  -74,   86, 24,  4,  0 }, {     27,  -74,   87, 24,  4,  0 }, {     28,  -75,   88, 24,  4,  0 }, {     28,  -75,   89, 24,  4,  0 }, {     28,  -76,   90, 24,  4,  0 },
    {     28,  -76,   91, 24,  4,  0 }, {     28,  -77,   92, 24,  4,  0 }, {     28,  -77,   93, 24,  4,  0 }, {     28,  -78,   94, 24,  4,  0 }, {     28,  -78,   95, 24,  4,  0 },
    {     28,  -78,   96, 24,  4,  0 }, {     28,  -79,   97, 24,  4,  0 }, {     29,  -79,   98, 24,  4,  0 }, {     29,  -80,   99, 24,  4,  0 }, {     29,  -80,  100, 24,  4,  0 },
    {     29,  -81,  101, 24,  4,  0 }, {     29,  -81,  102, 24,  4,  0 }, {     29,  -81,  103, 24,  4,  0 }, {     29,  -82,  104, 24,  4,  0 }, {     29,  -82,  105, 24,  4,  0 },
    {     29,  -83,  106, 24,  4,  0 }, {     29,  -83,  107, 24,  4,  0 }, {     30,  -83,  108, 24,  4,  0 }, {     30,  -84,  109, 24,  4,  0 }, {     30,  -84,  110, 24,  4,  0 },
    {     30,  -85,  111, 24,  4,  0 }, {     30,  -85,  112, 24,  4,  0 }, {     30,  -86,  113, 24,  4,  0 }, {     30,  -86,  114, 24,  4,  0 }, {     30,  -86,  115, 24,  4,  0 },
    {     30,  -87,  116, 24,  9,  0 }, {     31,  -87,  117, 24,  9,  0 }, {     31,  -87,  118, 24,  9,  0 }, {     31,  -87,  119, 24,  9,  0 }, {     31,  -88,  120, 24,  9,  0 },
    {     31,  -88,  121, 24,  9,  0 }, {     31,  -88,  122, 24,  9,  0 }, {     31,  -89,  123, 24,  9,  0 }, {     31,  -89,  124, 24,  9,  0 }, {     31,  -89,  125, 24,  9,  0 },
    {     31,  -90,  126, 24,  9,  0 }, {     32,  -90,  127, 24,  9,  0 }, {     32,  -90,  128, 24,  9,  0 }, {     32,  -90,  129, 24,  9,  0 }, {     32,  -91,  130, 24,  9,  0 },
    {     32,  -91,  131, 24,  9,  0 }, {     32,  -91,  132, 24,  9,  0 }, {     32,  -91,  133, 24,  9,  0 }, {     32,  -91,  134, 24,  9,  0 }, {     32,  -92,  135, 24,  9,  0 },
    {     32,  -92,  136, 24,  9,  0 }, {     33,  -92,  137, 24,  9,  0 }, {     33,  -92,  138, 24,  9,  0 }, {     33,  -92,  139, 24,  9,  0 }, {     33,  -92,  140, 24,  9,  0 },
    {     33,  -93,  141, 24,  9,  0 }, {     33,  -93,  142, 24,  9,  0 }, {     33,  -93,  143, 24,  9,  0 }, {     33,  -93,  144, 24,  9,  0 }, {     33,  -93,  145, 24,  9,  0 },
    {     34,  -93,  146, 24,  9,  0 }, {     34,  -94,  147, 24,  9,  0 }, {     34,  -94,  148, 24,  9,  0 }, {     34,  -94,  149, 24, 10,  0 }, {     34,  -94,  150, 24, 10,  0 },
    {     34,  -94,  151, 24, 10,  0 }, {     34,  -94,  152, 24, 10,  0 }, {     34,  -94,  153, 24, 10,  0 }, {     34,  -94,  154, 24, 10,  0 }, {     34,  -94,  155, 24, 10,  0 },
    {     35,  -94,  156, 24, 10,  0 }, {     35,  -94,  157, 24, 10,  0 }, {     35,  -94,  158, 24, 10,  0 }, {     35,  -94,  159, 24, 10,  0 }, {     35,  -94,  160, 24, 10,  0 },
    {     35,  -94,  161, 24, 10,  0 }, {     35,  -94,  162, 24, 10,  0 }, {     35,  -94,  163, 24, 10,  0 }, {     35,  -94,  164, 24, 10,  0 }, {     35,  -94,  165, 24, 10,  0 },
    {     36,  -94,  166, 24, 10,  0 }, {     36,  -94,  167, 24, 10,  0 }, {     36,  -94,  168, 24, 10,  0 }, {     36,  -94,  169, 24, 10,  0 }, {     36,  -94,  170, 24, 10,  0 },
    {     36,  -94,  171, 24, 10,  0 }, {     36,  -94,  172, 24, 10,  0 }, {     36,  -94,  173, 24, 10,  0 }, {     36,  -94,  174, 24, 10,  0 }, {     36,  -94,  175, 24, 10,  0 },
    {     37,  -94,  176, 24, 10,  0 }, {     37,  -94,  177, 24, 10,  0 }, {     37,  -94,  178, 24, 10,  0 }, {     37,  -94,  179, 24, 10,  0 }, {     37,  -94,  180, 24, 10,  0 },
    {     37,  -94,  181, 24, 10,  0 }, {     37,  -94,  182, 24, 10,  0 }, {     37,  -94,  183, 24, 10,  0 }, {     37,  -94,  184, 24, 10,  0 }, {     38,  -94,  185, 24, 10,  0 },
    {     38,  -94,  186, 24, 11,  0 }, {     38,  -94,  187, 24, 11,  0 }, {     38,  -93,  188, 24, 11,  0 }, {     38,  -93,  189, 24, 11,  0 }, {     38,  -93,  190, 24, 11,  0 },
    {     38,  -93,  191, 24, 11,  0 }, {     38,  -93,  192, 24, 11,  0 }, {     38,  -93,  193, 24, 11,  0 }, {     38,  -93,  194, 24, 11,  0 }, {     39,  -93,  195, 24, 11,  0 },
    {     39,  -92,  196, 24, 11,  0 }, {     39,  -92,  197, 24, 11,  0 }, {     39,  -92,  198, 24, 11,  0 }, {     39,  -92,  199, 24, 11,  0 }, {     39,  -92,  200, 24, 11,  0 },
    {     39,  -92,  201, 24, 11,  0 }, {     39,  -91,  202, 24, 11,  0 }, {     39,  -91,  203, 24, 11,  0 }, {     39,  -91,  204, 24, 11,  0 }, {     40,  -91,  205, 24, 11,  0 },
    {     40,  -90,  206, 24, 11,  0 }, {     40,  -90,  207, 24, 11,  0 }, {     40,  -90,  208, 24, 11,  0 }, {     40,  -90,  209, 24, 11,  0 }, {     40,  -89,  210, 24, 12,  0 },
    {     40,  -89,  211, 24, 12,  0 }, {     40,  -89,  212, 24, 12,  0 }, {     40,  -88,  213, 24, 12,  0 }, {     41,  -88,  214, 24, 12,  0 }, {     41,  -87,  215, 24, 12,  0 },
    {     41,  -87,  216, 24, 12,  0 }, {     41,  -87,  217, 24, 12,  0 }, {     41,  -86,  218, 24, 12,  0 }, {     41,  -86,  219, 24, 12,  0 }, {     41,  -86,  220, 24, 12,  0 },
    {     41,  -85,  221, 24, 12,  0 }, {     41,  -85,  222, 24, 12,  0 }, {     41,  -84,  223, 24, 12,  0 }, {     42,  -84,  224, 24, 12,  0 }, {     42,  -83,  225, 24, 13,  0 },
    {     42,  -83,  226, 24, 13,  0 }, {     42,  -82,  227, 24, 13,  0 }, {     42,  -82,  228, 24, 13,  0 }, {     42,  -81,  229, 24, 13,  0 }, {     42,  -81,  230, 24, 13,  0 },
    {     42,  -80,  231, 24, 13,  0 }, {     42,  -80,  232, 24, 13,  0 }, {     42,  -79,  233, 24, 13,  0 }, {     43,  -78,  234, 24, 13,  0 }, {     43,  -78,  235, 24, 13,  0 },
    {     43,  -77,  236, 24, 13,  0 }, {     43,  -76,  237, 24, 13,  0 }, {     43,  -76,  238, 24, 13,  0 }, {     43,  -75,  239, 24, 13,  0 }, {     43,  -74,  240, 24, 14,  0 },
    {     43,  -73,  241, 24, 14,  0 }, {     43,  -73,  242, 24, 14,  0 }, {     43,  -72,  243, 24, 14,  0 }, {     44,  -71,  244, 24, 14,  0 }, {     44,  -70,  245, 24, 14,  0 },
    {     44,  -69,  246, 24, 14,  0 }, {     44,  -68,  247, 24, 14,  0 }, {     44,  -67,  248, 24, 14,  0 }, {     44,  -66,  249, 24, 14,  0 }, {     44,  -65,  250, 24, 14,  0 },
    {     44,  -64,  251, 24, 14,  0 }, {     44,  -63,  252, 24, 14,  0 }, {     45,  -62,  253, 24, 15,  0 }, {     45,  -61,  253, 24, 15,  0 }, {     45,  -60,  254, 24, 15,  0 },
    {     45,  -59,  255, 24, 15,  0 }, {     45,  -58,  256, 24, 15,  0 }, {     45,  -57,  256, 24, 15,  0 }, {     45,  -56,  257, 24, 15,  0 }, {     45,  -55,  258, 24, 15,  0 },
    {     45,  -54,  258, 24, 15,  0 }, {     45,  -53,  259, 24, 15,  0 }, {     46,  -52,  259, 24, 15,  0 }, {     46,  -51,  260, 24, 15,  0 }, {     46,  -50,  260, 24, 15,  0 },
    {     46,  -49,  261, 24, 15,  0 }, {     46,  -48,  261, 24, 15,  0 }, {     46,  -47,  262, 24, 16,  0 }, {     46,  -46,  262, 24, 16,  0 }, {     46,  -45,  262, 24, 16,  0 },
    {     46,  -44,  263, 24, 16,  0 }, {     46,  -43,  263, 24, 16,  0 }, {     47,  -42,  263, 24, 16,  0 }, {     47,  -41,  263, 24, 16,  0 }, {     47,  -40,  264, 24, 16,  0 },
    {     47,  -39,  264, 24, 16,  0 }, {     47,  -38,  264, 24, 16,  0 }, {     47,  -37,  264, 24, 16,  0 }, {     47,  -36,  264, 24, 16,  0 }, {     47,  -35,  264, 24, 16,  0 },
    {     47,  -34,  264, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_922CAC, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    0,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    1,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    2,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    3,  0,  2,  0 }, {     23,   16,    4,  0,  2,  0 }, {     22,   16,    4,  0,  2,  0 },
    {     21,   17,    5,  0,  2,  0 }, {     20,   17,    5,  0,  2,  0 }, {     19,   17,    6,  0,  2,  0 }, {     18,   17,    6,  0,  2,  0 }, {     17,   17,    7,  0,  2,  0 },
    {     16,   17,    7,  0,  2,  0 }, {     15,   17,    8,  0,  2,  0 }, {     14,   17,    8,  0,  2,  0 }, {     13,   17,    9,  0,  2,  0 }, {     12,   17,    9,  0,  2,  0 },
    {     11,   18,   10,  0,  2,  0 }, {     10,   18,   10,  0,  2,  0 }, {      9,   18,   11,  0,  2,  0 }, {      8,   18,   11,  0,  2,  0 }, {      7,   18,   12,  0,  2,  0 },
    {      6,   18,   12,  0,  2,  0 }, {      5,   18,   13,  0,  2,  0 }, {      4,   18,   13,  0,  2,  0 }, {      3,   18,   14,  0,  2,  0 }, {      2,   18,   14,  0,  2,  0 },
    {      1,   19,   15,  0,  2,  0 }, {      0,   19,   15,  0,  2,  0 }, {     -1,   19,   16,  0,  2,  0 }, {     -2,   19,   16,  0,  2,  0 }, {     -3,   19,   17,  0,  2,  0 },
    {     -4,   19,   17,  0,  2,  0 }, {     -5,   19,   18,  0,  2,  0 }, {     -6,   19,   18,  0,  2,  0 }, {     -7,   19,   19,  0,  2,  0 }, {     -8,   20,   19,  0,  2,  0 },
    {     -9,   20,   20,  0,  2,  0 }, {    -10,   20,   21,  0,  2,  0 }, {    -11,   20,   21,  0,  2,  0 }, {    -12,   20,   22,  0,  2,  0 }, {    -13,   20,   22,  0,  2,  0 },
    {    -14,   20,   23,  0,  2,  0 }, {    -15,   20,   24,  0,  2,  0 }, {    -16,   20,   24,  0,  2,  0 }, {    -17,   20,   25,  0,  2,  0 }, {    -18,   21,   25,  0,  2,  0 },
    {    -19,   21,   26,  0,  2,  0 }, {    -20,   21,   27,  0,  2,  0 }, {    -21,   21,   27,  0,  2,  0 }, {    -22,   21,   28,  0,  2,  0 }, {    -23,   21,   29,  0,  2,  0 },
    {    -24,   21,   30,  0,  2,  0 }, {    -25,   21,   30,  0,  2,  0 }, {    -26,   21,   31,  0,  2,  0 }, {    -27,   21,   32,  0,  2,  0 }, {    -28,   22,   33,  0,  2,  0 },
    {    -29,   22,   33,  0,  2,  0 }, {    -30,   22,   34,  0,  2,  0 }, {    -31,   22,   35,  0,  3,  0 }, {    -32,   22,   36,  0,  3,  0 }, {    -33,   22,   36,  0,  3,  0 },
    {    -34,   22,   37,  0,  3,  0 }, {    -35,   22,   38,  0,  3,  0 }, {    -36,   22,   39,  0,  3,  0 }, {    -37,   22,   40,  0,  3,  0 }, {    -38,   23,   41,  0,  3,  0 },
    {    -39,   23,   42,  0,  3,  0 }, {    -40,   23,   42,  0,  3,  0 }, {    -41,   23,   43,  0,  3,  0 }, {    -42,   23,   44,  0,  3,  0 }, {    -43,   23,   45,  0,  3,  0 },
    {    -44,   23,   46,  0,  3,  0 }, {    -45,   23,   47,  0,  3,  0 }, {    -46,   23,   48,  0,  3,  0 }, {    -47,   24,   49,  0,  3,  0 }, {    -48,   24,   50,  0,  3,  0 },
    {    -49,   24,   51,  0,  3,  0 }, {    -50,   24,   52,  0,  3,  0 }, {    -50,   24,   53,  0,  3,  0 }, {    -51,   24,   54,  0,  3,  0 }, {    -52,   24,   55,  0,  3,  0 },
    {    -53,   24,   56,  0,  3,  0 }, {    -54,   24,   57,  0,  3,  0 }, {    -55,   24,   58,  0,  3,  0 }, {    -56,   25,   59,  0,  3,  0 }, {    -57,   25,   60,  0,  3,  0 },
    {    -57,   25,   61,  0,  3,  0 }, {    -58,   25,   62,  0,  3,  0 }, {    -59,   25,   63,  0,  3,  0 }, {    -59,   25,   64,  0,  3,  0 }, {    -60,   25,   65,  0,  3,  0 },
    {    -61,   25,   66,  0,  3,  0 }, {    -61,   25,   67,  0,  3,  0 }, {    -62,   25,   68,  0,  3,  0 }, {    -63,   26,   69,  0,  3,  0 }, {    -64,   26,   70,  0,  3,  0 },
    {    -64,   26,   71,  0,  3,  0 }, {    -65,   26,   72,  0,  3,  0 }, {    -66,   26,   73,  0,  3,  0 }, {    -66,   26,   74,  0,  3,  0 }, {    -67,   26,   75,  0,  3,  0 },
    {    -68,   26,   76,  0,  3,  0 }, {    -68,   26,   77,  0,  3,  0 }, {    -69,   27,   78,  0,  3,  0 }, {    -69,   27,   79,  0,  3,  0 }, {    -70,   27,   80,  0,  4,  0 },
    {    -71,   27,   81,  0,  4,  0 }, {    -71,   27,   82,  0,  4,  0 }, {    -72,   27,   83,  0,  4,  0 }, {    -72,   27,   84,  0,  4,  0 }, {    -73,   27,   85,  0,  4,  0 },
    {    -74,   27,   86,  0,  4,  0 }, {    -74,   27,   87,  0,  4,  0 }, {    -75,   28,   88,  0,  4,  0 }, {    -75,   28,   89,  0,  4,  0 }, {    -76,   28,   90,  0,  4,  0 },
    {    -76,   28,   91,  0,  4,  0 }, {    -77,   28,   92,  0,  4,  0 }, {    -77,   28,   93,  0,  4,  0 }, {    -78,   28,   94,  0,  4,  0 }, {    -78,   28,   95,  0,  4,  0 },
    {    -78,   28,   96,  0,  4,  0 }, {    -79,   28,   97,  0,  4,  0 }, {    -79,   29,   98,  0,  4,  0 }, {    -80,   29,   99,  0,  4,  0 }, {    -80,   29,  100,  0,  4,  0 },
    {    -81,   29,  101,  0,  4,  0 }, {    -81,   29,  102,  0,  4,  0 }, {    -81,   29,  103,  0,  4,  0 }, {    -82,   29,  104,  0,  4,  0 }, {    -82,   29,  105,  0,  4,  0 },
    {    -83,   29,  106,  0,  4,  0 }, {    -83,   29,  107,  0,  4,  0 }, {    -83,   30,  108,  0,  4,  0 }, {    -84,   30,  109,  0,  4,  0 }, {    -84,   30,  110,  0,  4,  0 },
    {    -85,   30,  111,  0,  4,  0 }, {    -85,   30,  112,  0,  4,  0 }, {    -86,   30,  113,  0,  4,  0 }, {    -86,   30,  114,  0,  4,  0 }, {    -86,   30,  115,  0,  4,  0 },
    {    -87,   30,  116,  0,  9,  0 }, {    -87,   31,  117,  0,  9,  0 }, {    -87,   31,  118,  0,  9,  0 }, {    -87,   31,  119,  0,  9,  0 }, {    -88,   31,  120,  0,  9,  0 },
    {    -88,   31,  121,  0,  9,  0 }, {    -88,   31,  122,  0,  9,  0 }, {    -89,   31,  123,  0,  9,  0 }, {    -89,   31,  124,  0,  9,  0 }, {    -89,   31,  125,  0,  9,  0 },
    {    -90,   31,  126,  0,  9,  0 }, {    -90,   32,  127,  0,  9,  0 }, {    -90,   32,  128,  0,  9,  0 }, {    -90,   32,  129,  0,  9,  0 }, {    -91,   32,  130,  0,  9,  0 },
    {    -91,   32,  131,  0,  9,  0 }, {    -91,   32,  132,  0,  9,  0 }, {    -91,   32,  133,  0,  9,  0 }, {    -91,   32,  134,  0,  9,  0 }, {    -92,   32,  135,  0,  9,  0 },
    {    -92,   32,  136,  0,  9,  0 }, {    -92,   33,  137,  0,  9,  0 }, {    -92,   33,  138,  0,  9,  0 }, {    -92,   33,  139,  0,  9,  0 }, {    -92,   33,  140,  0,  9,  0 },
    {    -93,   33,  141,  0,  9,  0 }, {    -93,   33,  142,  0,  9,  0 }, {    -93,   33,  143,  0,  9,  0 }, {    -93,   33,  144,  0,  9,  0 }, {    -93,   33,  145,  0,  9,  0 },
    {    -93,   34,  146,  0,  9,  0 }, {    -94,   34,  147,  0,  9,  0 }, {    -94,   34,  148,  0,  9,  0 }, {    -94,   34,  149,  0, 10,  0 }, {    -94,   34,  150,  0, 10,  0 },
    {    -94,   34,  151,  0, 10,  0 }, {    -94,   34,  152,  0, 10,  0 }, {    -94,   34,  153,  0, 10,  0 }, {    -94,   34,  154,  0, 10,  0 }, {    -94,   34,  155,  0, 10,  0 },
    {    -94,   35,  156,  0, 10,  0 }, {    -94,   35,  157,  0, 10,  0 }, {    -94,   35,  158,  0, 10,  0 }, {    -94,   35,  159,  0, 10,  0 }, {    -94,   35,  160,  0, 10,  0 },
    {    -94,   35,  161,  0, 10,  0 }, {    -94,   35,  162,  0, 10,  0 }, {    -94,   35,  163,  0, 10,  0 }, {    -94,   35,  164,  0, 10,  0 }, {    -94,   35,  165,  0, 10,  0 },
    {    -94,   36,  166,  0, 10,  0 }, {    -94,   36,  167,  0, 10,  0 }, {    -94,   36,  168,  0, 10,  0 }, {    -94,   36,  169,  0, 10,  0 }, {    -94,   36,  170,  0, 10,  0 },
    {    -94,   36,  171,  0, 10,  0 }, {    -94,   36,  172,  0, 10,  0 }, {    -94,   36,  173,  0, 10,  0 }, {    -94,   36,  174,  0, 10,  0 }, {    -94,   36,  175,  0, 10,  0 },
    {    -94,   37,  176,  0, 10,  0 }, {    -94,   37,  177,  0, 10,  0 }, {    -94,   37,  178,  0, 10,  0 }, {    -94,   37,  179,  0, 10,  0 }, {    -94,   37,  180,  0, 10,  0 },
    {    -94,   37,  181,  0, 10,  0 }, {    -94,   37,  182,  0, 10,  0 }, {    -94,   37,  183,  0, 10,  0 }, {    -94,   37,  184,  0, 10,  0 }, {    -94,   38,  185,  0, 10,  0 },
    {    -94,   38,  186,  0, 11,  0 }, {    -94,   38,  187,  0, 11,  0 }, {    -93,   38,  188,  0, 11,  0 }, {    -93,   38,  189,  0, 11,  0 }, {    -93,   38,  190,  0, 11,  0 },
    {    -93,   38,  191,  0, 11,  0 }, {    -93,   38,  192,  0, 11,  0 }, {    -93,   38,  193,  0, 11,  0 }, {    -93,   38,  194,  0, 11,  0 }, {    -93,   39,  195,  0, 11,  0 },
    {    -92,   39,  196,  0, 11,  0 }, {    -92,   39,  197,  0, 11,  0 }, {    -92,   39,  198,  0, 11,  0 }, {    -92,   39,  199,  0, 11,  0 }, {    -92,   39,  200,  0, 11,  0 },
    {    -92,   39,  201,  0, 11,  0 }, {    -91,   39,  202,  0, 11,  0 }, {    -91,   39,  203,  0, 11,  0 }, {    -91,   39,  204,  0, 11,  0 }, {    -91,   40,  205,  0, 11,  0 },
    {    -90,   40,  206,  0, 11,  0 }, {    -90,   40,  207,  0, 11,  0 }, {    -90,   40,  208,  0, 11,  0 }, {    -90,   40,  209,  0, 11,  0 }, {    -89,   40,  210,  0, 12,  0 },
    {    -89,   40,  211,  0, 12,  0 }, {    -89,   40,  212,  0, 12,  0 }, {    -88,   40,  213,  0, 12,  0 }, {    -88,   41,  214,  0, 12,  0 }, {    -87,   41,  215,  0, 12,  0 },
    {    -87,   41,  216,  0, 12,  0 }, {    -87,   41,  217,  0, 12,  0 }, {    -86,   41,  218,  0, 12,  0 }, {    -86,   41,  219,  0, 12,  0 }, {    -86,   41,  220,  0, 12,  0 },
    {    -85,   41,  221,  0, 12,  0 }, {    -85,   41,  222,  0, 12,  0 }, {    -84,   41,  223,  0, 12,  0 }, {    -84,   42,  224,  0, 12,  0 }, {    -83,   42,  225,  0, 13,  0 },
    {    -83,   42,  226,  0, 13,  0 }, {    -82,   42,  227,  0, 13,  0 }, {    -82,   42,  228,  0, 13,  0 }, {    -81,   42,  229,  0, 13,  0 }, {    -81,   42,  230,  0, 13,  0 },
    {    -80,   42,  231,  0, 13,  0 }, {    -80,   42,  232,  0, 13,  0 }, {    -79,   42,  233,  0, 13,  0 }, {    -78,   43,  234,  0, 13,  0 }, {    -78,   43,  235,  0, 13,  0 },
    {    -77,   43,  236,  0, 13,  0 }, {    -76,   43,  237,  0, 13,  0 }, {    -76,   43,  238,  0, 13,  0 }, {    -75,   43,  239,  0, 13,  0 }, {    -74,   43,  240,  0, 14,  0 },
    {    -73,   43,  241,  0, 14,  0 }, {    -73,   43,  242,  0, 14,  0 }, {    -72,   43,  243,  0, 14,  0 }, {    -71,   44,  244,  0, 14,  0 }, {    -70,   44,  245,  0, 14,  0 },
    {    -69,   44,  246,  0, 14,  0 }, {    -68,   44,  247,  0, 14,  0 }, {    -67,   44,  248,  0, 14,  0 }, {    -66,   44,  249,  0, 14,  0 }, {    -65,   44,  250,  0, 14,  0 },
    {    -64,   44,  251,  0, 14,  0 }, {    -63,   44,  252,  0, 14,  0 }, {    -62,   45,  253,  0, 15,  0 }, {    -61,   45,  253,  0, 15,  0 }, {    -60,   45,  254,  0, 15,  0 },
    {    -59,   45,  255,  0, 15,  0 }, {    -58,   45,  256,  0, 15,  0 }, {    -57,   45,  256,  0, 15,  0 }, {    -56,   45,  257,  0, 15,  0 }, {    -55,   45,  258,  0, 15,  0 },
    {    -54,   45,  258,  0, 15,  0 }, {    -53,   45,  259,  0, 15,  0 }, {    -52,   46,  259,  0, 15,  0 }, {    -51,   46,  260,  0, 15,  0 }, {    -50,   46,  260,  0, 15,  0 },
    {    -49,   46,  261,  0, 15,  0 }, {    -48,   46,  261,  0, 15,  0 }, {    -47,   46,  262,  0, 16,  0 }, {    -46,   46,  262,  0, 16,  0 }, {    -45,   46,  262,  0, 16,  0 },
    {    -44,   46,  263,  0, 16,  0 }, {    -43,   46,  263,  0, 16,  0 }, {    -42,   47,  263,  0, 16,  0 }, {    -41,   47,  263,  0, 16,  0 }, {    -40,   47,  264,  0, 16,  0 },
    {    -39,   47,  264,  0, 16,  0 }, {    -38,   47,  264,  0, 16,  0 }, {    -37,   47,  264,  0, 16,  0 }, {    -36,   47,  264,  0, 16,  0 }, {    -35,   47,  264,  0, 16,  0 },
    {    -34,   47,  264,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9242A0, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    2,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    3,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    4,  8,  2,  0 }, {     16,    9,    4,  8,  2,  0 },
    {     17,   10,    5,  8,  2,  0 }, {     17,   11,    5,  8,  2,  0 }, {     17,   12,    6,  8,  2,  0 }, {     17,   13,    6,  8,  2,  0 }, {     17,   14,    7,  8,  2,  0 },
    {     17,   15,    7,  8,  2,  0 }, {     17,   16,    8,  8,  2,  0 }, {     17,   17,    8,  8,  2,  0 }, {     17,   18,    9,  8,  2,  0 }, {     17,   19,    9,  8,  2,  0 },
    {     18,   20,   10,  8,  2,  0 }, {     18,   21,   10,  8,  2,  0 }, {     18,   22,   11,  8,  2,  0 }, {     18,   23,   11,  8,  2,  0 }, {     18,   24,   12,  8,  2,  0 },
    {     18,   25,   12,  8,  2,  0 }, {     18,   26,   13,  8,  2,  0 }, {     18,   27,   13,  8,  2,  0 }, {     18,   28,   14,  8,  2,  0 }, {     18,   29,   14,  8,  2,  0 },
    {     19,   30,   15,  8,  2,  0 }, {     19,   31,   15,  8,  2,  0 }, {     19,   32,   16,  8,  2,  0 }, {     19,   33,   16,  8,  2,  0 }, {     19,   34,   17,  8,  2,  0 },
    {     19,   35,   17,  8,  2,  0 }, {     19,   36,   18,  8,  2,  0 }, {     19,   37,   18,  8,  2,  0 }, {     19,   38,   19,  8,  2,  0 }, {     20,   39,   19,  8,  2,  0 },
    {     20,   40,   20,  8,  2,  0 }, {     20,   41,   21,  8,  2,  0 }, {     20,   42,   21,  8,  2,  0 }, {     20,   43,   22,  8,  2,  0 }, {     20,   44,   22,  8,  2,  0 },
    {     20,   45,   23,  8,  2,  0 }, {     20,   46,   24,  8,  2,  0 }, {     20,   47,   24,  8,  2,  0 }, {     20,   48,   25,  8,  2,  0 }, {     21,   49,   25,  8,  2,  0 },
    {     21,   50,   26,  8,  2,  0 }, {     21,   51,   27,  8,  2,  0 }, {     21,   52,   27,  8,  2,  0 }, {     21,   53,   28,  8,  2,  0 }, {     21,   54,   29,  8,  2,  0 },
    {     21,   55,   30,  8,  2,  0 }, {     21,   56,   30,  8,  2,  0 }, {     21,   57,   31,  8,  2,  0 }, {     21,   58,   32,  8,  2,  0 }, {     22,   59,   33,  8,  2,  0 },
    {     22,   60,   33,  8,  2,  0 }, {     22,   61,   34,  8,  2,  0 }, {     22,   62,   35,  8,  3,  0 }, {     22,   63,   36,  8,  3,  0 }, {     22,   64,   36,  8,  3,  0 },
    {     22,   65,   37,  8,  3,  0 }, {     22,   66,   38,  8,  3,  0 }, {     22,   67,   39,  8,  3,  0 }, {     22,   68,   40,  8,  3,  0 }, {     23,   69,   41,  8,  3,  0 },
    {     23,   70,   42,  8,  3,  0 }, {     23,   71,   42,  8,  3,  0 }, {     23,   72,   43,  8,  3,  0 }, {     23,   73,   44,  8,  3,  0 }, {     23,   74,   45,  8,  3,  0 },
    {     23,   75,   46,  8,  3,  0 }, {     23,   76,   47,  8,  3,  0 }, {     23,   77,   48,  8,  3,  0 }, {     24,   78,   49,  8,  3,  0 }, {     24,   79,   50,  8,  3,  0 },
    {     24,   80,   51,  8,  3,  0 }, {     24,   81,   52,  8,  3,  0 }, {     24,   81,   53,  8,  3,  0 }, {     24,   82,   54,  8,  3,  0 }, {     24,   83,   55,  8,  3,  0 },
    {     24,   84,   56,  8,  3,  0 }, {     24,   85,   57,  8,  3,  0 }, {     24,   86,   58,  8,  3,  0 }, {     25,   87,   59,  8,  3,  0 }, {     25,   88,   60,  8,  3,  0 },
    {     25,   88,   61,  8,  3,  0 }, {     25,   89,   62,  8,  3,  0 }, {     25,   90,   63,  8,  3,  0 }, {     25,   90,   64,  8,  3,  0 }, {     25,   91,   65,  8,  3,  0 },
    {     25,   92,   66,  8,  3,  0 }, {     25,   92,   67,  8,  3,  0 }, {     25,   93,   68,  8,  3,  0 }, {     26,   94,   69,  8,  3,  0 }, {     26,   95,   70,  8,  3,  0 },
    {     26,   95,   71,  8,  3,  0 }, {     26,   96,   72,  8,  3,  0 }, {     26,   97,   73,  8,  3,  0 }, {     26,   97,   74,  8,  3,  0 }, {     26,   98,   75,  8,  3,  0 },
    {     26,   99,   76,  8,  3,  0 }, {     26,   99,   77,  8,  3,  0 }, {     27,  100,   78,  8,  3,  0 }, {     27,  100,   79,  8,  3,  0 }, {     27,  101,   80,  8,  4,  0 },
    {     27,  102,   81,  8,  4,  0 }, {     27,  102,   82,  8,  4,  0 }, {     27,  103,   83,  8,  4,  0 }, {     27,  103,   84,  8,  4,  0 }, {     27,  104,   85,  8,  4,  0 },
    {     27,  105,   86,  8,  4,  0 }, {     27,  105,   87,  8,  4,  0 }, {     28,  106,   88,  8,  4,  0 }, {     28,  106,   89,  8,  4,  0 }, {     28,  107,   90,  8,  4,  0 },
    {     28,  107,   91,  8,  4,  0 }, {     28,  108,   92,  8,  4,  0 }, {     28,  108,   93,  8,  4,  0 }, {     28,  109,   94,  8,  4,  0 }, {     28,  109,   95,  8,  4,  0 },
    {     28,  109,   96,  8,  4,  0 }, {     28,  110,   97,  8,  4,  0 }, {     29,  110,   98,  8,  4,  0 }, {     29,  111,   99,  8,  4,  0 }, {     29,  111,  100,  8,  4,  0 },
    {     29,  112,  101,  8,  4,  0 }, {     29,  112,  102,  8,  4,  0 }, {     29,  112,  103,  8,  4,  0 }, {     29,  113,  104,  8,  4,  0 }, {     29,  113,  105,  8,  4,  0 },
    {     29,  114,  106,  8,  4,  0 }, {     29,  114,  107,  8,  4,  0 }, {     30,  114,  108,  8,  4,  0 }, {     30,  115,  109,  8,  4,  0 }, {     30,  115,  110,  8,  4,  0 },
    {     30,  116,  111,  8,  4,  0 }, {     30,  116,  112,  8,  4,  0 }, {     30,  117,  113,  8,  4,  0 }, {     30,  117,  114,  8,  4,  0 }, {     30,  117,  115,  8,  4,  0 },
    {     30,  118,  116,  8,  9,  0 }, {     31,  118,  117,  8,  9,  0 }, {     31,  118,  118,  8,  9,  0 }, {     31,  118,  119,  8,  9,  0 }, {     31,  119,  120,  8,  9,  0 },
    {     31,  119,  121,  8,  9,  0 }, {     31,  119,  122,  8,  9,  0 }, {     31,  120,  123,  8,  9,  0 }, {     31,  120,  124,  8,  9,  0 }, {     31,  120,  125,  8,  9,  0 },
    {     31,  121,  126,  8,  9,  0 }, {     32,  121,  127,  8,  9,  0 }, {     32,  121,  128,  8,  9,  0 }, {     32,  121,  129,  8,  9,  0 }, {     32,  122,  130,  8,  9,  0 },
    {     32,  122,  131,  8,  9,  0 }, {     32,  122,  132,  8,  9,  0 }, {     32,  122,  133,  8,  9,  0 }, {     32,  122,  134,  8,  9,  0 }, {     32,  123,  135,  8,  9,  0 },
    {     32,  123,  136,  8,  9,  0 }, {     33,  123,  137,  8,  9,  0 }, {     33,  123,  138,  8,  9,  0 }, {     33,  123,  139,  8,  9,  0 }, {     33,  123,  140,  8,  9,  0 },
    {     33,  124,  141,  8,  9,  0 }, {     33,  124,  142,  8,  9,  0 }, {     33,  124,  143,  8,  9,  0 }, {     33,  124,  144,  8,  9,  0 }, {     33,  124,  145,  8,  9,  0 },
    {     34,  124,  146,  8,  9,  0 }, {     34,  125,  147,  8,  9,  0 }, {     34,  125,  148,  8,  9,  0 }, {     34,  125,  149,  8, 10,  0 }, {     34,  125,  150,  8, 10,  0 },
    {     34,  125,  151,  8, 10,  0 }, {     34,  125,  152,  8, 10,  0 }, {     34,  125,  153,  8, 10,  0 }, {     34,  125,  154,  8, 10,  0 }, {     34,  125,  155,  8, 10,  0 },
    {     35,  125,  156,  8, 10,  0 }, {     35,  125,  157,  8, 10,  0 }, {     35,  125,  158,  8, 10,  0 }, {     35,  125,  159,  8, 10,  0 }, {     35,  125,  160,  8, 10,  0 },
    {     35,  125,  161,  8, 10,  0 }, {     35,  125,  162,  8, 10,  0 }, {     35,  125,  163,  8, 10,  0 }, {     35,  125,  164,  8, 10,  0 }, {     35,  125,  165,  8, 10,  0 },
    {     36,  125,  166,  8, 10,  0 }, {     36,  125,  167,  8, 10,  0 }, {     36,  125,  168,  8, 10,  0 }, {     36,  125,  169,  8, 10,  0 }, {     36,  125,  170,  8, 10,  0 },
    {     36,  125,  171,  8, 10,  0 }, {     36,  125,  172,  8, 10,  0 }, {     36,  125,  173,  8, 10,  0 }, {     36,  125,  174,  8, 10,  0 }, {     36,  125,  175,  8, 10,  0 },
    {     37,  125,  176,  8, 10,  0 }, {     37,  125,  177,  8, 10,  0 }, {     37,  125,  178,  8, 10,  0 }, {     37,  125,  179,  8, 10,  0 }, {     37,  125,  180,  8, 10,  0 },
    {     37,  125,  181,  8, 10,  0 }, {     37,  125,  182,  8, 10,  0 }, {     37,  125,  183,  8, 10,  0 }, {     37,  125,  184,  8, 10,  0 }, {     38,  125,  185,  8, 10,  0 },
    {     38,  125,  186,  8, 11,  0 }, {     38,  125,  187,  8, 11,  0 }, {     38,  124,  188,  8, 11,  0 }, {     38,  124,  189,  8, 11,  0 }, {     38,  124,  190,  8, 11,  0 },
    {     38,  124,  191,  8, 11,  0 }, {     38,  124,  192,  8, 11,  0 }, {     38,  124,  193,  8, 11,  0 }, {     38,  124,  194,  8, 11,  0 }, {     39,  124,  195,  8, 11,  0 },
    {     39,  123,  196,  8, 11,  0 }, {     39,  123,  197,  8, 11,  0 }, {     39,  123,  198,  8, 11,  0 }, {     39,  123,  199,  8, 11,  0 }, {     39,  123,  200,  8, 11,  0 },
    {     39,  123,  201,  8, 11,  0 }, {     39,  122,  202,  8, 11,  0 }, {     39,  122,  203,  8, 11,  0 }, {     39,  122,  204,  8, 11,  0 }, {     40,  122,  205,  8, 11,  0 },
    {     40,  121,  206,  8, 11,  0 }, {     40,  121,  207,  8, 11,  0 }, {     40,  121,  208,  8, 11,  0 }, {     40,  121,  209,  8, 11,  0 }, {     40,  120,  210,  8, 12,  0 },
    {     40,  120,  211,  8, 12,  0 }, {     40,  120,  212,  8, 12,  0 }, {     40,  119,  213,  8, 12,  0 }, {     41,  119,  214,  8, 12,  0 }, {     41,  118,  215,  8, 12,  0 },
    {     41,  118,  216,  8, 12,  0 }, {     41,  118,  217,  8, 12,  0 }, {     41,  117,  218,  8, 12,  0 }, {     41,  117,  219,  8, 12,  0 }, {     41,  117,  220,  8, 12,  0 },
    {     41,  116,  221,  8, 12,  0 }, {     41,  116,  222,  8, 12,  0 }, {     41,  115,  223,  8, 12,  0 }, {     42,  115,  224,  8, 12,  0 }, {     42,  114,  225,  8, 13,  0 },
    {     42,  114,  226,  8, 13,  0 }, {     42,  113,  227,  8, 13,  0 }, {     42,  113,  228,  8, 13,  0 }, {     42,  112,  229,  8, 13,  0 }, {     42,  112,  230,  8, 13,  0 },
    {     42,  111,  231,  8, 13,  0 }, {     42,  111,  232,  8, 13,  0 }, {     42,  110,  233,  8, 13,  0 }, {     43,  109,  234,  8, 13,  0 }, {     43,  109,  235,  8, 13,  0 },
    {     43,  108,  236,  8, 13,  0 }, {     43,  107,  237,  8, 13,  0 }, {     43,  107,  238,  8, 13,  0 }, {     43,  106,  239,  8, 13,  0 }, {     43,  105,  240,  8, 14,  0 },
    {     43,  104,  241,  8, 14,  0 }, {     43,  104,  242,  8, 14,  0 }, {     43,  103,  243,  8, 14,  0 }, {     44,  102,  244,  8, 14,  0 }, {     44,  101,  245,  8, 14,  0 },
    {     44,  100,  246,  8, 14,  0 }, {     44,   99,  247,  8, 14,  0 }, {     44,   98,  248,  8, 14,  0 }, {     44,   97,  249,  8, 14,  0 }, {     44,   96,  250,  8, 14,  0 },
    {     44,   95,  251,  8, 14,  0 }, {     44,   94,  252,  8, 14,  0 }, {     45,   93,  253,  8, 15,  0 }, {     45,   92,  253,  8, 15,  0 }, {     45,   91,  254,  8, 15,  0 },
    {     45,   90,  255,  8, 15,  0 }, {     45,   89,  256,  8, 15,  0 }, {     45,   88,  256,  8, 15,  0 }, {     45,   87,  257,  8, 15,  0 }, {     45,   86,  258,  8, 15,  0 },
    {     45,   85,  258,  8, 15,  0 }, {     45,   84,  259,  8, 15,  0 }, {     46,   83,  259,  8, 15,  0 }, {     46,   82,  260,  8, 15,  0 }, {     46,   81,  260,  8, 15,  0 },
    {     46,   80,  261,  8, 15,  0 }, {     46,   79,  261,  8, 15,  0 }, {     46,   78,  262,  8, 16,  0 }, {     46,   77,  262,  8, 16,  0 }, {     46,   76,  262,  8, 16,  0 },
    {     46,   75,  263,  8, 16,  0 }, {     46,   74,  263,  8, 16,  0 }, {     47,   73,  263,  8, 16,  0 }, {     47,   72,  263,  8, 16,  0 }, {     47,   71,  264,  8, 16,  0 },
    {     47,   70,  264,  8, 16,  0 }, {     47,   69,  264,  8, 16,  0 }, {     47,   68,  264,  8, 16,  0 }, {     47,   67,  264,  8, 16,  0 }, {     47,   66,  264,  8, 16,  0 },
    {     47,   65,  264,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_925894, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    2, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    3, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    4, 16,  2,  0 }, {      9,   16,    4, 16,  2,  0 },
    {     10,   15,    5, 16,  2,  0 }, {     11,   15,    5, 16,  2,  0 }, {     12,   15,    6, 16,  2,  0 }, {     13,   15,    6, 16,  2,  0 }, {     14,   15,    7, 16,  2,  0 },
    {     15,   15,    7, 16,  2,  0 }, {     16,   15,    8, 16,  2,  0 }, {     17,   15,    8, 16,  2,  0 }, {     18,   15,    9, 16,  2,  0 }, {     19,   15,    9, 16,  2,  0 },
    {     20,   14,   10, 16,  2,  0 }, {     21,   14,   10, 16,  2,  0 }, {     22,   14,   11, 16,  2,  0 }, {     23,   14,   11, 16,  2,  0 }, {     24,   14,   12, 16,  2,  0 },
    {     25,   14,   12, 16,  2,  0 }, {     26,   14,   13, 16,  2,  0 }, {     27,   14,   13, 16,  2,  0 }, {     28,   14,   14, 16,  2,  0 }, {     29,   14,   14, 16,  2,  0 },
    {     30,   13,   15, 16,  2,  0 }, {     31,   13,   15, 16,  2,  0 }, {     32,   13,   16, 16,  2,  0 }, {     33,   13,   16, 16,  2,  0 }, {     34,   13,   17, 16,  2,  0 },
    {     35,   13,   17, 16,  2,  0 }, {     36,   13,   18, 16,  2,  0 }, {     37,   13,   18, 16,  2,  0 }, {     38,   13,   19, 16,  2,  0 }, {     39,   12,   19, 16,  2,  0 },
    {     40,   12,   20, 16,  2,  0 }, {     41,   12,   21, 16,  2,  0 }, {     42,   12,   21, 16,  2,  0 }, {     43,   12,   22, 16,  2,  0 }, {     44,   12,   22, 16,  2,  0 },
    {     45,   12,   23, 16,  2,  0 }, {     46,   12,   24, 16,  2,  0 }, {     47,   12,   24, 16,  2,  0 }, {     48,   12,   25, 16,  2,  0 }, {     49,   11,   25, 16,  2,  0 },
    {     50,   11,   26, 16,  2,  0 }, {     51,   11,   27, 16,  2,  0 }, {     52,   11,   27, 16,  2,  0 }, {     53,   11,   28, 16,  2,  0 }, {     54,   11,   29, 16,  2,  0 },
    {     55,   11,   30, 16,  2,  0 }, {     56,   11,   30, 16,  2,  0 }, {     57,   11,   31, 16,  2,  0 }, {     58,   11,   32, 16,  2,  0 }, {     59,   10,   33, 16,  2,  0 },
    {     60,   10,   33, 16,  2,  0 }, {     61,   10,   34, 16,  2,  0 }, {     62,   10,   35, 16,  3,  0 }, {     63,   10,   36, 16,  3,  0 }, {     64,   10,   36, 16,  3,  0 },
    {     65,   10,   37, 16,  3,  0 }, {     66,   10,   38, 16,  3,  0 }, {     67,   10,   39, 16,  3,  0 }, {     68,   10,   40, 16,  3,  0 }, {     69,    9,   41, 16,  3,  0 },
    {     70,    9,   42, 16,  3,  0 }, {     71,    9,   42, 16,  3,  0 }, {     72,    9,   43, 16,  3,  0 }, {     73,    9,   44, 16,  3,  0 }, {     74,    9,   45, 16,  3,  0 },
    {     75,    9,   46, 16,  3,  0 }, {     76,    9,   47, 16,  3,  0 }, {     77,    9,   48, 16,  3,  0 }, {     78,    8,   49, 16,  3,  0 }, {     79,    8,   50, 16,  3,  0 },
    {     80,    8,   51, 16,  3,  0 }, {     81,    8,   52, 16,  3,  0 }, {     81,    8,   53, 16,  3,  0 }, {     82,    8,   54, 16,  3,  0 }, {     83,    8,   55, 16,  3,  0 },
    {     84,    8,   56, 16,  3,  0 }, {     85,    8,   57, 16,  3,  0 }, {     86,    8,   58, 16,  3,  0 }, {     87,    7,   59, 16,  3,  0 }, {     88,    7,   60, 16,  3,  0 },
    {     88,    7,   61, 16,  3,  0 }, {     89,    7,   62, 16,  3,  0 }, {     90,    7,   63, 16,  3,  0 }, {     90,    7,   64, 16,  3,  0 }, {     91,    7,   65, 16,  3,  0 },
    {     92,    7,   66, 16,  3,  0 }, {     92,    7,   67, 16,  3,  0 }, {     93,    7,   68, 16,  3,  0 }, {     94,    6,   69, 16,  3,  0 }, {     95,    6,   70, 16,  3,  0 },
    {     95,    6,   71, 16,  3,  0 }, {     96,    6,   72, 16,  3,  0 }, {     97,    6,   73, 16,  3,  0 }, {     97,    6,   74, 16,  3,  0 }, {     98,    6,   75, 16,  3,  0 },
    {     99,    6,   76, 16,  3,  0 }, {     99,    6,   77, 16,  3,  0 }, {    100,    5,   78, 16,  3,  0 }, {    100,    5,   79, 16,  3,  0 }, {    101,    5,   80, 16,  4,  0 },
    {    102,    5,   81, 16,  4,  0 }, {    102,    5,   82, 16,  4,  0 }, {    103,    5,   83, 16,  4,  0 }, {    103,    5,   84, 16,  4,  0 }, {    104,    5,   85, 16,  4,  0 },
    {    105,    5,   86, 16,  4,  0 }, {    105,    5,   87, 16,  4,  0 }, {    106,    4,   88, 16,  4,  0 }, {    106,    4,   89, 16,  4,  0 }, {    107,    4,   90, 16,  4,  0 },
    {    107,    4,   91, 16,  4,  0 }, {    108,    4,   92, 16,  4,  0 }, {    108,    4,   93, 16,  4,  0 }, {    109,    4,   94, 16,  4,  0 }, {    109,    4,   95, 16,  4,  0 },
    {    109,    4,   96, 16,  4,  0 }, {    110,    4,   97, 16,  4,  0 }, {    110,    3,   98, 16,  4,  0 }, {    111,    3,   99, 16,  4,  0 }, {    111,    3,  100, 16,  4,  0 },
    {    112,    3,  101, 16,  4,  0 }, {    112,    3,  102, 16,  4,  0 }, {    112,    3,  103, 16,  4,  0 }, {    113,    3,  104, 16,  4,  0 }, {    113,    3,  105, 16,  4,  0 },
    {    114,    3,  106, 16,  4,  0 }, {    114,    3,  107, 16,  4,  0 }, {    114,    2,  108, 16,  4,  0 }, {    115,    2,  109, 16,  4,  0 }, {    115,    2,  110, 16,  4,  0 },
    {    116,    2,  111, 16,  4,  0 }, {    116,    2,  112, 16,  4,  0 }, {    117,    2,  113, 16,  4,  0 }, {    117,    2,  114, 16,  4,  0 }, {    117,    2,  115, 16,  4,  0 },
    {    118,    2,  116, 16,  9,  0 }, {    118,    1,  117, 16,  9,  0 }, {    118,    1,  118, 16,  9,  0 }, {    118,    1,  119, 16,  9,  0 }, {    119,    1,  120, 16,  9,  0 },
    {    119,    1,  121, 16,  9,  0 }, {    119,    1,  122, 16,  9,  0 }, {    120,    1,  123, 16,  9,  0 }, {    120,    1,  124, 16,  9,  0 }, {    120,    1,  125, 16,  9,  0 },
    {    121,    1,  126, 16,  9,  0 }, {    121,    0,  127, 16,  9,  0 }, {    121,    0,  128, 16,  9,  0 }, {    121,    0,  129, 16,  9,  0 }, {    122,    0,  130, 16,  9,  0 },
    {    122,    0,  131, 16,  9,  0 }, {    122,    0,  132, 16,  9,  0 }, {    122,    0,  133, 16,  9,  0 }, {    122,    0,  134, 16,  9,  0 }, {    123,    0,  135, 16,  9,  0 },
    {    123,    0,  136, 16,  9,  0 }, {    123,   -1,  137, 16,  9,  0 }, {    123,   -1,  138, 16,  9,  0 }, {    123,   -1,  139, 16,  9,  0 }, {    123,   -1,  140, 16,  9,  0 },
    {    124,   -1,  141, 16,  9,  0 }, {    124,   -1,  142, 16,  9,  0 }, {    124,   -1,  143, 16,  9,  0 }, {    124,   -1,  144, 16,  9,  0 }, {    124,   -1,  145, 16,  9,  0 },
    {    124,   -2,  146, 16,  9,  0 }, {    125,   -2,  147, 16,  9,  0 }, {    125,   -2,  148, 16,  9,  0 }, {    125,   -2,  149, 16, 10,  0 }, {    125,   -2,  150, 16, 10,  0 },
    {    125,   -2,  151, 16, 10,  0 }, {    125,   -2,  152, 16, 10,  0 }, {    125,   -2,  153, 16, 10,  0 }, {    125,   -2,  154, 16, 10,  0 }, {    125,   -2,  155, 16, 10,  0 },
    {    125,   -3,  156, 16, 10,  0 }, {    125,   -3,  157, 16, 10,  0 }, {    125,   -3,  158, 16, 10,  0 }, {    125,   -3,  159, 16, 10,  0 }, {    125,   -3,  160, 16, 10,  0 },
    {    125,   -3,  161, 16, 10,  0 }, {    125,   -3,  162, 16, 10,  0 }, {    125,   -3,  163, 16, 10,  0 }, {    125,   -3,  164, 16, 10,  0 }, {    125,   -3,  165, 16, 10,  0 },
    {    125,   -4,  166, 16, 10,  0 }, {    125,   -4,  167, 16, 10,  0 }, {    125,   -4,  168, 16, 10,  0 }, {    125,   -4,  169, 16, 10,  0 }, {    125,   -4,  170, 16, 10,  0 },
    {    125,   -4,  171, 16, 10,  0 }, {    125,   -4,  172, 16, 10,  0 }, {    125,   -4,  173, 16, 10,  0 }, {    125,   -4,  174, 16, 10,  0 }, {    125,   -4,  175, 16, 10,  0 },
    {    125,   -5,  176, 16, 10,  0 }, {    125,   -5,  177, 16, 10,  0 }, {    125,   -5,  178, 16, 10,  0 }, {    125,   -5,  179, 16, 10,  0 }, {    125,   -5,  180, 16, 10,  0 },
    {    125,   -5,  181, 16, 10,  0 }, {    125,   -5,  182, 16, 10,  0 }, {    125,   -5,  183, 16, 10,  0 }, {    125,   -5,  184, 16, 10,  0 }, {    125,   -6,  185, 16, 10,  0 },
    {    125,   -6,  186, 16, 11,  0 }, {    125,   -6,  187, 16, 11,  0 }, {    124,   -6,  188, 16, 11,  0 }, {    124,   -6,  189, 16, 11,  0 }, {    124,   -6,  190, 16, 11,  0 },
    {    124,   -6,  191, 16, 11,  0 }, {    124,   -6,  192, 16, 11,  0 }, {    124,   -6,  193, 16, 11,  0 }, {    124,   -6,  194, 16, 11,  0 }, {    124,   -7,  195, 16, 11,  0 },
    {    123,   -7,  196, 16, 11,  0 }, {    123,   -7,  197, 16, 11,  0 }, {    123,   -7,  198, 16, 11,  0 }, {    123,   -7,  199, 16, 11,  0 }, {    123,   -7,  200, 16, 11,  0 },
    {    123,   -7,  201, 16, 11,  0 }, {    122,   -7,  202, 16, 11,  0 }, {    122,   -7,  203, 16, 11,  0 }, {    122,   -7,  204, 16, 11,  0 }, {    122,   -8,  205, 16, 11,  0 },
    {    121,   -8,  206, 16, 11,  0 }, {    121,   -8,  207, 16, 11,  0 }, {    121,   -8,  208, 16, 11,  0 }, {    121,   -8,  209, 16, 11,  0 }, {    120,   -8,  210, 16, 12,  0 },
    {    120,   -8,  211, 16, 12,  0 }, {    120,   -8,  212, 16, 12,  0 }, {    119,   -8,  213, 16, 12,  0 }, {    119,   -9,  214, 16, 12,  0 }, {    118,   -9,  215, 16, 12,  0 },
    {    118,   -9,  216, 16, 12,  0 }, {    118,   -9,  217, 16, 12,  0 }, {    117,   -9,  218, 16, 12,  0 }, {    117,   -9,  219, 16, 12,  0 }, {    117,   -9,  220, 16, 12,  0 },
    {    116,   -9,  221, 16, 12,  0 }, {    116,   -9,  222, 16, 12,  0 }, {    115,   -9,  223, 16, 12,  0 }, {    115,  -10,  224, 16, 12,  0 }, {    114,  -10,  225, 16, 13,  0 },
    {    114,  -10,  226, 16, 13,  0 }, {    113,  -10,  227, 16, 13,  0 }, {    113,  -10,  228, 16, 13,  0 }, {    112,  -10,  229, 16, 13,  0 }, {    112,  -10,  230, 16, 13,  0 },
    {    111,  -10,  231, 16, 13,  0 }, {    111,  -10,  232, 16, 13,  0 }, {    110,  -10,  233, 16, 13,  0 }, {    109,  -11,  234, 16, 13,  0 }, {    109,  -11,  235, 16, 13,  0 },
    {    108,  -11,  236, 16, 13,  0 }, {    107,  -11,  237, 16, 13,  0 }, {    107,  -11,  238, 16, 13,  0 }, {    106,  -11,  239, 16, 13,  0 }, {    105,  -11,  240, 16, 14,  0 },
    {    104,  -11,  241, 16, 14,  0 }, {    104,  -11,  242, 16, 14,  0 }, {    103,  -11,  243, 16, 14,  0 }, {    102,  -12,  244, 16, 14,  0 }, {    101,  -12,  245, 16, 14,  0 },
    {    100,  -12,  246, 16, 14,  0 }, {     99,  -12,  247, 16, 14,  0 }, {     98,  -12,  248, 16, 14,  0 }, {     97,  -12,  249, 16, 14,  0 }, {     96,  -12,  250, 16, 14,  0 },
    {     95,  -12,  251, 16, 14,  0 }, {     94,  -12,  252, 16, 14,  0 }, {     93,  -13,  253, 16, 15,  0 }, {     92,  -13,  253, 16, 15,  0 }, {     91,  -13,  254, 16, 15,  0 },
    {     90,  -13,  255, 16, 15,  0 }, {     89,  -13,  256, 16, 15,  0 }, {     88,  -13,  256, 16, 15,  0 }, {     87,  -13,  257, 16, 15,  0 }, {     86,  -13,  258, 16, 15,  0 },
    {     85,  -13,  258, 16, 15,  0 }, {     84,  -13,  259, 16, 15,  0 }, {     83,  -14,  259, 16, 15,  0 }, {     82,  -14,  260, 16, 15,  0 }, {     81,  -14,  260, 16, 15,  0 },
    {     80,  -14,  261, 16, 15,  0 }, {     79,  -14,  261, 16, 15,  0 }, {     78,  -14,  262, 16, 16,  0 }, {     77,  -14,  262, 16, 16,  0 }, {     76,  -14,  262, 16, 16,  0 },
    {     75,  -14,  263, 16, 16,  0 }, {     74,  -14,  263, 16, 16,  0 }, {     73,  -15,  263, 16, 16,  0 }, {     72,  -15,  263, 16, 16,  0 }, {     71,  -15,  264, 16, 16,  0 },
    {     70,  -15,  264, 16, 16,  0 }, {     69,  -15,  264, 16, 16,  0 }, {     68,  -15,  264, 16, 16,  0 }, {     67,  -15,  264, 16, 16,  0 }, {     66,  -15,  264, 16, 16,  0 },
    {     65,  -15,  264, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_926E88, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    0, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    1, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    2, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    3, 24,  2,  0 }, {     16,   23,    4, 24,  2,  0 }, {     16,   22,    4, 24,  2,  0 },
    {     15,   21,    5, 24,  2,  0 }, {     15,   20,    5, 24,  2,  0 }, {     15,   19,    6, 24,  2,  0 }, {     15,   18,    6, 24,  2,  0 }, {     15,   17,    7, 24,  2,  0 },
    {     15,   16,    7, 24,  2,  0 }, {     15,   15,    8, 24,  2,  0 }, {     15,   14,    8, 24,  2,  0 }, {     15,   13,    9, 24,  2,  0 }, {     15,   12,    9, 24,  2,  0 },
    {     14,   11,   10, 24,  2,  0 }, {     14,   10,   10, 24,  2,  0 }, {     14,    9,   11, 24,  2,  0 }, {     14,    8,   11, 24,  2,  0 }, {     14,    7,   12, 24,  2,  0 },
    {     14,    6,   12, 24,  2,  0 }, {     14,    5,   13, 24,  2,  0 }, {     14,    4,   13, 24,  2,  0 }, {     14,    3,   14, 24,  2,  0 }, {     14,    2,   14, 24,  2,  0 },
    {     13,    1,   15, 24,  2,  0 }, {     13,    0,   15, 24,  2,  0 }, {     13,   -1,   16, 24,  2,  0 }, {     13,   -2,   16, 24,  2,  0 }, {     13,   -3,   17, 24,  2,  0 },
    {     13,   -4,   17, 24,  2,  0 }, {     13,   -5,   18, 24,  2,  0 }, {     13,   -6,   18, 24,  2,  0 }, {     13,   -7,   19, 24,  2,  0 }, {     12,   -8,   19, 24,  2,  0 },
    {     12,   -9,   20, 24,  2,  0 }, {     12,  -10,   21, 24,  2,  0 }, {     12,  -11,   21, 24,  2,  0 }, {     12,  -12,   22, 24,  2,  0 }, {     12,  -13,   22, 24,  2,  0 },
    {     12,  -14,   23, 24,  2,  0 }, {     12,  -15,   24, 24,  2,  0 }, {     12,  -16,   24, 24,  2,  0 }, {     12,  -17,   25, 24,  2,  0 }, {     11,  -18,   25, 24,  2,  0 },
    {     11,  -19,   26, 24,  2,  0 }, {     11,  -20,   27, 24,  2,  0 }, {     11,  -21,   27, 24,  2,  0 }, {     11,  -22,   28, 24,  2,  0 }, {     11,  -23,   29, 24,  2,  0 },
    {     11,  -24,   30, 24,  2,  0 }, {     11,  -25,   30, 24,  2,  0 }, {     11,  -26,   31, 24,  2,  0 }, {     11,  -27,   32, 24,  2,  0 }, {     10,  -28,   33, 24,  2,  0 },
    {     10,  -29,   33, 24,  2,  0 }, {     10,  -30,   34, 24,  2,  0 }, {     10,  -31,   35, 24,  3,  0 }, {     10,  -32,   36, 24,  3,  0 }, {     10,  -33,   36, 24,  3,  0 },
    {     10,  -34,   37, 24,  3,  0 }, {     10,  -35,   38, 24,  3,  0 }, {     10,  -36,   39, 24,  3,  0 }, {     10,  -37,   40, 24,  3,  0 }, {      9,  -38,   41, 24,  3,  0 },
    {      9,  -39,   42, 24,  3,  0 }, {      9,  -40,   42, 24,  3,  0 }, {      9,  -41,   43, 24,  3,  0 }, {      9,  -42,   44, 24,  3,  0 }, {      9,  -43,   45, 24,  3,  0 },
    {      9,  -44,   46, 24,  3,  0 }, {      9,  -45,   47, 24,  3,  0 }, {      9,  -46,   48, 24,  3,  0 }, {      8,  -47,   49, 24,  3,  0 }, {      8,  -48,   50, 24,  3,  0 },
    {      8,  -49,   51, 24,  3,  0 }, {      8,  -50,   52, 24,  3,  0 }, {      8,  -50,   53, 24,  3,  0 }, {      8,  -51,   54, 24,  3,  0 }, {      8,  -52,   55, 24,  3,  0 },
    {      8,  -53,   56, 24,  3,  0 }, {      8,  -54,   57, 24,  3,  0 }, {      8,  -55,   58, 24,  3,  0 }, {      7,  -56,   59, 24,  3,  0 }, {      7,  -57,   60, 24,  3,  0 },
    {      7,  -57,   61, 24,  3,  0 }, {      7,  -58,   62, 24,  3,  0 }, {      7,  -59,   63, 24,  3,  0 }, {      7,  -59,   64, 24,  3,  0 }, {      7,  -60,   65, 24,  3,  0 },
    {      7,  -61,   66, 24,  3,  0 }, {      7,  -61,   67, 24,  3,  0 }, {      7,  -62,   68, 24,  3,  0 }, {      6,  -63,   69, 24,  3,  0 }, {      6,  -64,   70, 24,  3,  0 },
    {      6,  -64,   71, 24,  3,  0 }, {      6,  -65,   72, 24,  3,  0 }, {      6,  -66,   73, 24,  3,  0 }, {      6,  -66,   74, 24,  3,  0 }, {      6,  -67,   75, 24,  3,  0 },
    {      6,  -68,   76, 24,  3,  0 }, {      6,  -68,   77, 24,  3,  0 }, {      5,  -69,   78, 24,  3,  0 }, {      5,  -69,   79, 24,  3,  0 }, {      5,  -70,   80, 24,  4,  0 },
    {      5,  -71,   81, 24,  4,  0 }, {      5,  -71,   82, 24,  4,  0 }, {      5,  -72,   83, 24,  4,  0 }, {      5,  -72,   84, 24,  4,  0 }, {      5,  -73,   85, 24,  4,  0 },
    {      5,  -74,   86, 24,  4,  0 }, {      5,  -74,   87, 24,  4,  0 }, {      4,  -75,   88, 24,  4,  0 }, {      4,  -75,   89, 24,  4,  0 }, {      4,  -76,   90, 24,  4,  0 },
    {      4,  -76,   91, 24,  4,  0 }, {      4,  -77,   92, 24,  4,  0 }, {      4,  -77,   93, 24,  4,  0 }, {      4,  -78,   94, 24,  4,  0 }, {      4,  -78,   95, 24,  4,  0 },
    {      4,  -78,   96, 24,  4,  0 }, {      4,  -79,   97, 24,  4,  0 }, {      3,  -79,   98, 24,  4,  0 }, {      3,  -80,   99, 24,  4,  0 }, {      3,  -80,  100, 24,  4,  0 },
    {      3,  -81,  101, 24,  4,  0 }, {      3,  -81,  102, 24,  4,  0 }, {      3,  -81,  103, 24,  4,  0 }, {      3,  -82,  104, 24,  4,  0 }, {      3,  -82,  105, 24,  4,  0 },
    {      3,  -83,  106, 24,  4,  0 }, {      3,  -83,  107, 24,  4,  0 }, {      2,  -83,  108, 24,  4,  0 }, {      2,  -84,  109, 24,  4,  0 }, {      2,  -84,  110, 24,  4,  0 },
    {      2,  -85,  111, 24,  4,  0 }, {      2,  -85,  112, 24,  4,  0 }, {      2,  -86,  113, 24,  4,  0 }, {      2,  -86,  114, 24,  4,  0 }, {      2,  -86,  115, 24,  4,  0 },
    {      2,  -87,  116, 24,  9,  0 }, {      1,  -87,  117, 24,  9,  0 }, {      1,  -87,  118, 24,  9,  0 }, {      1,  -87,  119, 24,  9,  0 }, {      1,  -88,  120, 24,  9,  0 },
    {      1,  -88,  121, 24,  9,  0 }, {      1,  -88,  122, 24,  9,  0 }, {      1,  -89,  123, 24,  9,  0 }, {      1,  -89,  124, 24,  9,  0 }, {      1,  -89,  125, 24,  9,  0 },
    {      1,  -90,  126, 24,  9,  0 }, {      0,  -90,  127, 24,  9,  0 }, {      0,  -90,  128, 24,  9,  0 }, {      0,  -90,  129, 24,  9,  0 }, {      0,  -91,  130, 24,  9,  0 },
    {      0,  -91,  131, 24,  9,  0 }, {      0,  -91,  132, 24,  9,  0 }, {      0,  -91,  133, 24,  9,  0 }, {      0,  -91,  134, 24,  9,  0 }, {      0,  -92,  135, 24,  9,  0 },
    {      0,  -92,  136, 24,  9,  0 }, {     -1,  -92,  137, 24,  9,  0 }, {     -1,  -92,  138, 24,  9,  0 }, {     -1,  -92,  139, 24,  9,  0 }, {     -1,  -92,  140, 24,  9,  0 },
    {     -1,  -93,  141, 24,  9,  0 }, {     -1,  -93,  142, 24,  9,  0 }, {     -1,  -93,  143, 24,  9,  0 }, {     -1,  -93,  144, 24,  9,  0 }, {     -1,  -93,  145, 24,  9,  0 },
    {     -2,  -93,  146, 24,  9,  0 }, {     -2,  -94,  147, 24,  9,  0 }, {     -2,  -94,  148, 24,  9,  0 }, {     -2,  -94,  149, 24, 10,  0 }, {     -2,  -94,  150, 24, 10,  0 },
    {     -2,  -94,  151, 24, 10,  0 }, {     -2,  -94,  152, 24, 10,  0 }, {     -2,  -94,  153, 24, 10,  0 }, {     -2,  -94,  154, 24, 10,  0 }, {     -2,  -94,  155, 24, 10,  0 },
    {     -3,  -94,  156, 24, 10,  0 }, {     -3,  -94,  157, 24, 10,  0 }, {     -3,  -94,  158, 24, 10,  0 }, {     -3,  -94,  159, 24, 10,  0 }, {     -3,  -94,  160, 24, 10,  0 },
    {     -3,  -94,  161, 24, 10,  0 }, {     -3,  -94,  162, 24, 10,  0 }, {     -3,  -94,  163, 24, 10,  0 }, {     -3,  -94,  164, 24, 10,  0 }, {     -3,  -94,  165, 24, 10,  0 },
    {     -4,  -94,  166, 24, 10,  0 }, {     -4,  -94,  167, 24, 10,  0 }, {     -4,  -94,  168, 24, 10,  0 }, {     -4,  -94,  169, 24, 10,  0 }, {     -4,  -94,  170, 24, 10,  0 },
    {     -4,  -94,  171, 24, 10,  0 }, {     -4,  -94,  172, 24, 10,  0 }, {     -4,  -94,  173, 24, 10,  0 }, {     -4,  -94,  174, 24, 10,  0 }, {     -4,  -94,  175, 24, 10,  0 },
    {     -5,  -94,  176, 24, 10,  0 }, {     -5,  -94,  177, 24, 10,  0 }, {     -5,  -94,  178, 24, 10,  0 }, {     -5,  -94,  179, 24, 10,  0 }, {     -5,  -94,  180, 24, 10,  0 },
    {     -5,  -94,  181, 24, 10,  0 }, {     -5,  -94,  182, 24, 10,  0 }, {     -5,  -94,  183, 24, 10,  0 }, {     -5,  -94,  184, 24, 10,  0 }, {     -6,  -94,  185, 24, 10,  0 },
    {     -6,  -94,  186, 24, 11,  0 }, {     -6,  -94,  187, 24, 11,  0 }, {     -6,  -93,  188, 24, 11,  0 }, {     -6,  -93,  189, 24, 11,  0 }, {     -6,  -93,  190, 24, 11,  0 },
    {     -6,  -93,  191, 24, 11,  0 }, {     -6,  -93,  192, 24, 11,  0 }, {     -6,  -93,  193, 24, 11,  0 }, {     -6,  -93,  194, 24, 11,  0 }, {     -7,  -93,  195, 24, 11,  0 },
    {     -7,  -92,  196, 24, 11,  0 }, {     -7,  -92,  197, 24, 11,  0 }, {     -7,  -92,  198, 24, 11,  0 }, {     -7,  -92,  199, 24, 11,  0 }, {     -7,  -92,  200, 24, 11,  0 },
    {     -7,  -92,  201, 24, 11,  0 }, {     -7,  -91,  202, 24, 11,  0 }, {     -7,  -91,  203, 24, 11,  0 }, {     -7,  -91,  204, 24, 11,  0 }, {     -8,  -91,  205, 24, 11,  0 },
    {     -8,  -90,  206, 24, 11,  0 }, {     -8,  -90,  207, 24, 11,  0 }, {     -8,  -90,  208, 24, 11,  0 }, {     -8,  -90,  209, 24, 11,  0 }, {     -8,  -89,  210, 24, 12,  0 },
    {     -8,  -89,  211, 24, 12,  0 }, {     -8,  -89,  212, 24, 12,  0 }, {     -8,  -88,  213, 24, 12,  0 }, {     -9,  -88,  214, 24, 12,  0 }, {     -9,  -87,  215, 24, 12,  0 },
    {     -9,  -87,  216, 24, 12,  0 }, {     -9,  -87,  217, 24, 12,  0 }, {     -9,  -86,  218, 24, 12,  0 }, {     -9,  -86,  219, 24, 12,  0 }, {     -9,  -86,  220, 24, 12,  0 },
    {     -9,  -85,  221, 24, 12,  0 }, {     -9,  -85,  222, 24, 12,  0 }, {     -9,  -84,  223, 24, 12,  0 }, {    -10,  -84,  224, 24, 12,  0 }, {    -10,  -83,  225, 24, 13,  0 },
    {    -10,  -83,  226, 24, 13,  0 }, {    -10,  -82,  227, 24, 13,  0 }, {    -10,  -82,  228, 24, 13,  0 }, {    -10,  -81,  229, 24, 13,  0 }, {    -10,  -81,  230, 24, 13,  0 },
    {    -10,  -80,  231, 24, 13,  0 }, {    -10,  -80,  232, 24, 13,  0 }, {    -10,  -79,  233, 24, 13,  0 }, {    -11,  -78,  234, 24, 13,  0 }, {    -11,  -78,  235, 24, 13,  0 },
    {    -11,  -77,  236, 24, 13,  0 }, {    -11,  -76,  237, 24, 13,  0 }, {    -11,  -76,  238, 24, 13,  0 }, {    -11,  -75,  239, 24, 13,  0 }, {    -11,  -74,  240, 24, 14,  0 },
    {    -11,  -73,  241, 24, 14,  0 }, {    -11,  -73,  242, 24, 14,  0 }, {    -11,  -72,  243, 24, 14,  0 }, {    -12,  -71,  244, 24, 14,  0 }, {    -12,  -70,  245, 24, 14,  0 },
    {    -12,  -69,  246, 24, 14,  0 }, {    -12,  -68,  247, 24, 14,  0 }, {    -12,  -67,  248, 24, 14,  0 }, {    -12,  -66,  249, 24, 14,  0 }, {    -12,  -65,  250, 24, 14,  0 },
    {    -12,  -64,  251, 24, 14,  0 }, {    -12,  -63,  252, 24, 14,  0 }, {    -13,  -62,  253, 24, 15,  0 }, {    -13,  -61,  253, 24, 15,  0 }, {    -13,  -60,  254, 24, 15,  0 },
    {    -13,  -59,  255, 24, 15,  0 }, {    -13,  -58,  256, 24, 15,  0 }, {    -13,  -57,  256, 24, 15,  0 }, {    -13,  -56,  257, 24, 15,  0 }, {    -13,  -55,  258, 24, 15,  0 },
    {    -13,  -54,  258, 24, 15,  0 }, {    -13,  -53,  259, 24, 15,  0 }, {    -14,  -52,  259, 24, 15,  0 }, {    -14,  -51,  260, 24, 15,  0 }, {    -14,  -50,  260, 24, 15,  0 },
    {    -14,  -49,  261, 24, 15,  0 }, {    -14,  -48,  261, 24, 15,  0 }, {    -14,  -47,  262, 24, 16,  0 }, {    -14,  -46,  262, 24, 16,  0 }, {    -14,  -45,  262, 24, 16,  0 },
    {    -14,  -44,  263, 24, 16,  0 }, {    -14,  -43,  263, 24, 16,  0 }, {    -15,  -42,  263, 24, 16,  0 }, {    -15,  -41,  263, 24, 16,  0 }, {    -15,  -40,  264, 24, 16,  0 },
    {    -15,  -39,  264, 24, 16,  0 }, {    -15,  -38,  264, 24, 16,  0 }, {    -15,  -37,  264, 24, 16,  0 }, {    -15,  -36,  264, 24, 16,  0 }, {    -15,  -35,  264, 24, 16,  0 },
    {    -15,  -34,  264, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_927982, {
    {     31,   16,   16, 16, 16,  0 }, {     30,   16,   16, 16, 16,  0 }, {     29,   16,   16, 16, 16,  0 }, {     28,   16,   16, 16, 16,  0 }, {     27,   16,   16, 16, 16,  0 },
    {     26,   16,   16, 16, 16,  0 }, {     25,   16,   16, 16, 16,  0 }, {     24,   16,   16, 16, 16,  0 }, {     23,   16,   15, 16, 16,  0 }, {     22,   16,   15, 16, 16,  0 },
    {     21,   15,   15, 16, 16,  0 }, {     20,   15,   15, 16, 16,  0 }, {     19,   15,   14, 16, 16,  0 }, {     18,   15,   14, 16, 16,  0 }, {     17,   15,   14, 16, 16,  0 },
    {     16,   15,   13, 16, 23,  0 }, {     15,   15,   13, 16, 23,  0 }, {     14,   15,   12, 16, 23,  0 }, {     13,   15,   12, 16, 23,  0 }, {     12,   15,   11, 16, 23,  0 },
    {     11,   14,   11, 16, 23,  0 }, {     10,   14,   10, 16, 23,  0 }, {      9,   14,   10, 16, 23,  0 }, {      8,   14,    9, 16, 23,  0 }, {      7,   14,    8, 16, 23,  0 },
    {      6,   14,    8, 16, 23,  0 }, {      5,   14,    7, 16, 23,  0 }, {      4,   14,    6, 16, 23,  0 }, {      3,   14,    5, 16, 23,  0 }, {      2,   14,    5, 16, 23,  0 },
    {      1,   13,    4, 16, 22,  0 }, {      0,   13,    3, 16, 22,  0 }, {     -1,   13,    2, 16, 22,  0 }, {     -2,   13,    1, 16, 22,  0 }, {     -3,   13,    0, 16, 22,  0 },
    {     -4,   13,   -1, 16, 22,  0 }, {     -5,   13,   -2, 16, 22,  0 }, {     -6,   13,   -3, 16, 22,  0 }, {     -7,   13,   -4, 16, 22,  0 }, {     -8,   12,   -5, 16, 22,  0 },
    {     -9,   12,   -6, 16, 22,  0 }, {     -9,   12,   -7, 16, 22,  0 }, {    -10,   12,   -8, 16, 22,  0 }, {    -11,   12,   -9, 16, 21,  0 }, {    -12,   12,  -10, 16, 21,  0 },
    {    -12,   12,  -11, 16, 21,  0 }, {    -13,   12,  -12, 16, 21,  0 }, {    -14,   12,  -13, 16, 21,  0 }, {    -14,   12,  -14, 16, 21,  0 }, {    -15,   11,  -15, 16, 21,  0 },
    {    -16,   11,  -16, 16, 21,  0 }, {    -16,   11,  -17, 16, 21,  0 }, {    -17,   11,  -18, 16, 21,  0 }, {    -17,   11,  -19, 16, 21,  0 }, {    -18,   11,  -20, 16, 21,  0 },
    {    -18,   11,  -21, 16, 21,  0 }, {    -19,   11,  -22, 16, 21,  0 }, {    -19,   11,  -23, 16, 21,  0 }, {    -20,   11,  -24, 16, 20,  0 }, {    -20,   10,  -25, 16, 20,  0 },
    {    -21,   10,  -26, 16, 20,  0 }, {    -21,   10,  -27, 16, 20,  0 }, {    -22,   10,  -28, 16, 20,  0 }, {    -22,   10,  -29, 16, 20,  0 }, {    -22,   10,  -30, 16, 20,  0 },
    {    -23,   10,  -31, 16, 20,  0 }, {    -23,   10,  -32, 16, 20,  0 }, {    -23,   10,  -33, 16, 20,  0 }, {    -24,   10,  -34, 16, 20,  0 }, {    -24,    9,  -35, 16, 20,  0 },
    {    -25,    9,  -36, 16, 20,  0 }, {    -25,    9,  -37, 16, 20,  0 }, {    -25,    9,  -38, 16, 20,  0 }, {    -26,    9,  -39, 16, 19,  0 }, {    -26,    9,  -40, 16, 19,  0 },
    {    -26,    9,  -41, 16, 19,  0 }, {    -26,    9,  -42, 16, 19,  0 }, {    -27,    9,  -43, 16, 19,  0 }, {    -27,    8,  -44, 16, 19,  0 }, {    -27,    8,  -45, 16, 19,  0 },
    {    -27,    8,  -46, 16, 19,  0 }, {    -28,    8,  -47, 16, 19,  0 }, {    -28,    8,  -48, 16, 19,  0 }, {    -28,    8,  -49, 16, 19,  0 }, {    -28,    8,  -50, 16, 19,  0 },
    {    -28,    8,  -51, 16, 19,  0 }, {    -28,    8,  -52, 16, 19,  0 }, {    -29,    8,  -53, 16, 19,  0 }, {    -29,    7,  -54, 16, 19,  0 }, {    -29,    7,  -55, 16, 19,  0 },
    {    -29,    7,  -56, 16, 19,  0 }, {    -29,    7,  -57, 16, 19,  0 }, {    -29,    7,  -58, 16, 19,  0 }, {    -29,    7,  -59, 16, 19,  0 }, {    -29,    7,  -60, 16, 19,  0 },
    {    -30,    7,  -61, 16, 19,  0 }, {    -30,    7,  -62, 16, 19,  0 }, {    -30,    7,  -63, 16, 18,  0 }, {    -30,    6,  -64, 16, 18,  0 }, {    -30,    6,  -65, 16, 18,  0 },
    {    -30,    6,  -66, 16, 18,  0 }, {    -30,    6,  -67, 16, 18,  0 }, {    -30,    6,  -68, 16, 18,  0 }, {    -30,    6,  -69, 16, 18,  0 }, {    -30,    6,  -70, 16, 18,  0 },
    {    -30,    6,  -71, 16, 18,  0 }, {    -30,    6,  -72, 16, 18,  0 }, {    -30,    5,  -73, 16, 18,  0 }, {    -30,    5,  -74, 16, 18,  0 }, {    -30,    5,  -75, 16, 18,  0 },
    {    -30,    5,  -76, 16, 18,  0 }, {    -30,    5,  -77, 16, 18,  0 }, {    -30,    5,  -78, 16, 18,  0 }, {    -30,    5,  -79, 16, 18,  0 }, {    -30,    5,  -80, 16, 18,  0 },
    {    -30,    5,  -81, 16, 18,  0 }, {    -30,    5,  -82, 16, 18,  0 }, {    -30,    4,  -83, 16, 18,  0 }, {    -30,    4,  -84, 16, 18,  0 }, {    -30,    4,  -85, 16, 18,  0 },
    {    -30,    4,  -86, 16, 18,  0 }, {    -30,    4,  -87, 16, 18,  0 }, {    -30,    4,  -88, 16, 18,  0 }, {    -30,    4,  -89, 16, 18,  0 }, {    -30,    4,  -90, 16, 18,  0 },
    {    -30,    4,  -91, 16, 18,  0 }, {    -30,    4,  -92, 16, 18,  0 }, {    -30,    3,  -93, 16, 18,  0 }, {    -30,    3,  -94, 16, 18,  0 }, {    -30,    3,  -95, 16, 18,  0 },
    {    -30,    3,  -96, 16, 18,  0 }, {    -30,    3,  -97, 16, 18,  0 }, {    -30,    3,  -98, 16, 18,  0 }, {    -30,    3,  -99, 16, 18,  0 }, {    -30,    3, -100, 16, 17,  0 },
    {    -30,    3, -101, 16, 17,  0 }, {    -29,    3, -102, 16, 17,  0 }, {    -29,    2, -103, 16, 17,  0 }, {    -29,    2, -104, 16, 17,  0 }, {    -29,    2, -105, 16, 17,  0 },
    {    -29,    2, -106, 16, 17,  0 }, {    -29,    2, -107, 16, 17,  0 }, {    -28,    2, -108, 16, 17,  0 }, {    -28,    2, -109, 16, 17,  0 }, {    -28,    2, -110, 16, 17,  0 },
    {    -28,    2, -111, 16, 17,  0 }, {    -28,    1, -112, 16, 17,  0 }, {    -28,    1, -113, 16, 17,  0 }, {    -27,    1, -114, 16, 17,  0 }, {    -27,    1, -115, 16, 17,  0 },
    {    -27,    1, -116, 16, 17,  0 }, {    -27,    1, -117, 16, 17,  0 }, {    -27,    1, -118, 16, 17,  0 }, {    -26,    1, -119, 16, 17,  0 }, {    -26,    1, -120, 16, 17,  0 },
    {    -26,    1, -121, 16, 17,  0 }, {    -26,    0, -122, 16, 17,  0 }, {    -25,    0, -123, 16, 17,  0 }, {    -25,    0, -124, 16, 17,  0 }, {    -25,    0, -125, 16, 17,  0 },
    {    -24,    0, -126, 16, 17,  0 }, {    -24,    0, -127, 16, 17,  0 }, {    -24,    0, -128, 16, 17,  0 }, {    -23,    0, -129, 16, 17,  0 }, {    -23,    0, -130, 16, 17,  0 },
    {    -23,    0, -131, 16, 17,  0 }, {    -23,   -1, -132, 16, 17,  0 }, {    -22,   -1, -133, 16,  8,  0 }, {    -22,   -1, -134, 16,  8,  0 }, {    -22,   -1, -135, 16,  8,  0 },
    {    -21,   -1, -136, 16,  8,  0 }, {    -21,   -1, -137, 16,  8,  0 }, {    -20,   -1, -138, 16,  8,  0 }, {    -20,   -1, -139, 16,  8,  0 }, {    -19,   -1, -140, 16,  8,  0 },
    {    -19,   -2, -141, 16,  8,  0 }, {    -19,   -2, -142, 16,  8,  0 }, {    -18,   -2, -143, 16,  8,  0 }, {    -18,   -2, -144, 16,  8,  0 }, {    -17,   -2, -145, 16,  8,  0 },
    {    -17,   -2, -146, 16,  8,  0 }, {    -17,   -2, -147, 16,  8,  0 }, {    -16,   -2, -148, 16,  8,  0 }, {    -16,   -2, -149, 16,  8,  0 }, {    -15,   -2, -150, 16,  8,  0 },
    {    -15,   -3, -151, 16,  8,  0 }, {    -14,   -3, -152, 16,  8,  0 }, {    -14,   -3, -153, 16,  8,  0 }, {    -14,   -3, -154, 16,  8,  0 }, {    -13,   -3, -155, 16,  8,  0 },
    {    -13,   -3, -156, 16,  8,  0 }, {    -12,   -3, -157, 16,  8,  0 }, {    -12,   -3, -158, 16,  8,  0 }, {    -11,   -3, -159, 16,  8,  0 }, {    -11,   -3, -160, 16,  8,  0 },
    {    -10,   -4, -161, 16,  8,  0 }, {    -10,   -4, -162, 16,  8,  0 }, {     -9,   -4, -163, 16,  8,  0 }, {     -8,   -4, -164, 16,  8,  0 }, {     -8,   -4, -165, 16,  8,  0 },
    {     -7,   -4, -166, 16,  8,  0 }, {     -7,   -4, -167, 16,  8,  0 }, {     -6,   -4, -168, 16,  8,  0 }, {     -5,   -4, -169, 16,  7,  0 }, {     -5,   -4, -170, 16,  7,  0 },
    {     -4,   -5, -171, 16,  7,  0 }, {     -4,   -5, -172, 16,  7,  0 }, {     -3,   -5, -173, 16,  7,  0 }, {     -2,   -5, -174, 16,  7,  0 }, {     -2,   -5, -175, 16,  7,  0 },
    {     -1,   -5, -176, 16,  7,  0 }, {      0,   -5, -177, 16,  7,  0 }, {      0,   -5, -178, 16,  7,  0 }, {      1,   -5, -179, 16,  7,  0 }, {      2,   -6, -180, 16,  7,  0 },
    {      3,   -6, -181, 16,  7,  0 }, {      3,   -6, -182, 16,  7,  0 }, {      4,   -6, -183, 16,  7,  0 }, {      5,   -6, -184, 16,  7,  0 }, {      5,   -6, -185, 16,  7,  0 },
    {      6,   -6, -186, 16,  7,  0 }, {      7,   -6, -187, 16,  7,  0 }, {      7,   -6, -188, 16,  7,  0 }, {      8,   -6, -189, 16,  7,  0 }, {      9,   -7, -190, 16,  7,  0 },
    {     10,   -7, -191, 16,  7,  0 }, {     11,   -7, -192, 16,  7,  0 }, {     12,   -7, -193, 16,  7,  0 }, {     13,   -7, -194, 16,  7,  0 }, {     14,   -7, -195, 16,  7,  0 },
    {     14,   -7, -196, 16,  7,  0 }, {     15,   -7, -197, 16,  7,  0 }, {     16,   -7, -198, 16,  7,  0 }, {     17,   -7, -199, 16,  7,  0 }, {     18,   -8, -200, 16,  7,  0 },
    {     19,   -8, -201, 16,  7,  0 }, {     20,   -8, -202, 16,  7,  0 }, {     21,   -8, -203, 16,  7,  0 }, {     22,   -8, -204, 16,  7,  0 }, {     23,   -8, -205, 16,  7,  0 },
    {     24,   -8, -206, 16,  7,  0 }, {     25,   -8, -206, 16,  7,  0 }, {     26,   -8, -207, 16,  7,  0 }, {     27,   -9, -208, 16,  7,  0 }, {     28,   -9, -209, 16,  7,  0 },
    {     29,   -9, -210, 16,  7,  0 }, {     30,   -9, -211, 16,  7,  0 }, {     31,   -9, -212, 16,  7,  0 }, {     32,   -9, -212, 16,  7,  0 }, {     33,   -9, -213, 16,  7,  0 },
    {     34,   -9, -214, 16,  6,  0 }, {     35,   -9, -215, 16,  6,  0 }, {     36,   -9, -215, 16,  6,  0 }, {     37,  -10, -216, 16,  6,  0 }, {     38,  -10, -217, 16,  6,  0 },
    {     39,  -10, -218, 16,  6,  0 }, {     40,  -10, -218, 16,  6,  0 }, {     41,  -10, -219, 16,  6,  0 }, {     42,  -10, -220, 16,  6,  0 }, {     43,  -10, -221, 16,  6,  0 },
    {     44,  -10, -221, 16,  6,  0 }, {     45,  -10, -222, 16,  6,  0 }, {     46,  -10, -223, 16,  6,  0 }, {     47,  -11, -223, 16,  6,  0 }, {     48,  -11, -224, 16,  6,  0 },
    {     49,  -11, -224, 16,  6,  0 }, {     50,  -11, -225, 16,  6,  0 }, {     51,  -11, -226, 16,  6,  0 }, {     52,  -11, -226, 16,  6,  0 }, {     53,  -11, -227, 16,  6,  0 },
    {     54,  -11, -227, 16,  6,  0 }, {     55,  -11, -228, 16,  6,  0 }, {     56,  -11, -229, 16,  6,  0 }, {     57,  -12, -229, 16,  6,  0 }, {     58,  -12, -230, 16,  6,  0 },
    {     59,  -12, -230, 16,  6,  0 }, {     60,  -12, -231, 16,  6,  0 }, {     61,  -12, -231, 16,  6,  0 }, {     62,  -12, -232, 16,  6,  0 }, {     63,  -12, -232, 16,  6,  0 },
    {     64,  -12, -233, 16,  6,  0 }, {     65,  -12, -233, 16,  6,  0 }, {     66,  -13, -234, 16,  6,  0 }, {     67,  -13, -234, 16,  6,  0 }, {     68,  -13, -235, 16,  6,  0 },
    {     69,  -13, -235, 16,  6,  0 }, {     70,  -13, -236, 16,  6,  0 }, {     71,  -13, -236, 16,  6,  0 }, {     72,  -13, -237, 16,  6,  0 }, {     73,  -13, -237, 16,  6,  0 },
    {     74,  -13, -238, 16,  6,  0 }, {     75,  -13, -238, 16,  6,  0 }, {     76,  -14, -239, 16,  6,  0 }, {     77,  -14, -239, 16,  6,  0 }, {     78,  -14, -240, 16,  6,  0 },
    {     79,  -14, -240, 16,  6,  0 }, {     80,  -14, -241, 16,  6,  0 }, {     81,  -14, -241, 16,  6,  0 }, {     82,  -14, -242, 16,  6,  0 }, {     83,  -14, -242, 16,  6,  0 },
    {     84,  -14, -243, 16,  6,  0 }, {     85,  -14, -243, 16,  6,  0 }, {     86,  -15, -244, 16,  6,  0 }, {     87,  -15, -244, 16,  6,  0 }, {     88,  -15, -245, 16,  6,  0 },
    {     89,  -15, -245, 16,  6,  0 }, {     90,  -15, -246, 16,  6,  0 }, {     91,  -15, -246, 16,  6,  0 }, {     92,  -15, -247, 16,  6,  0 }, {     93,  -15, -247, 16,  6,  0 },
    {     94,  -15, -248, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_928F76, {
    {     16,    0,   16, 24, 16,  0 }, {     16,    1,   16, 24, 16,  0 }, {     16,    2,   16, 24, 16,  0 }, {     16,    3,   16, 24, 16,  0 }, {     16,    4,   16, 24, 16,  0 },
    {     16,    5,   16, 24, 16,  0 }, {     16,    6,   16, 24, 16,  0 }, {     16,    7,   16, 24, 16,  0 }, {     16,    8,   15, 24, 16,  0 }, {     16,    9,   15, 24, 16,  0 },
    {     15,   10,   15, 24, 16,  0 }, {     15,   11,   15, 24, 16,  0 }, {     15,   12,   14, 24, 16,  0 }, {     15,   13,   14, 24, 16,  0 }, {     15,   14,   14, 24, 16,  0 },
    {     15,   15,   13, 24, 23,  0 }, {     15,   16,   13, 24, 23,  0 }, {     15,   17,   12, 24, 23,  0 }, {     15,   18,   12, 24, 23,  0 }, {     15,   19,   11, 24, 23,  0 },
    {     14,   20,   11, 24, 23,  0 }, {     14,   21,   10, 24, 23,  0 }, {     14,   22,   10, 24, 23,  0 }, {     14,   23,    9, 24, 23,  0 }, {     14,   24,    8, 24, 23,  0 },
    {     14,   25,    8, 24, 23,  0 }, {     14,   26,    7, 24, 23,  0 }, {     14,   27,    6, 24, 23,  0 }, {     14,   28,    5, 24, 23,  0 }, {     14,   29,    5, 24, 23,  0 },
    {     13,   30,    4, 24, 22,  0 }, {     13,   31,    3, 24, 22,  0 }, {     13,   32,    2, 24, 22,  0 }, {     13,   33,    1, 24, 22,  0 }, {     13,   34,    0, 24, 22,  0 },
    {     13,   35,   -1, 24, 22,  0 }, {     13,   36,   -2, 24, 22,  0 }, {     13,   37,   -3, 24, 22,  0 }, {     13,   38,   -4, 24, 22,  0 }, {     12,   39,   -5, 24, 22,  0 },
    {     12,   40,   -6, 24, 22,  0 }, {     12,   40,   -7, 24, 22,  0 }, {     12,   41,   -8, 24, 22,  0 }, {     12,   42,   -9, 24, 21,  0 }, {     12,   43,  -10, 24, 21,  0 },
    {     12,   43,  -11, 24, 21,  0 }, {     12,   44,  -12, 24, 21,  0 }, {     12,   45,  -13, 24, 21,  0 }, {     12,   45,  -14, 24, 21,  0 }, {     11,   46,  -15, 24, 21,  0 },
    {     11,   47,  -16, 24, 21,  0 }, {     11,   47,  -17, 24, 21,  0 }, {     11,   48,  -18, 24, 21,  0 }, {     11,   48,  -19, 24, 21,  0 }, {     11,   49,  -20, 24, 21,  0 },
    {     11,   49,  -21, 24, 21,  0 }, {     11,   50,  -22, 24, 21,  0 }, {     11,   50,  -23, 24, 21,  0 }, {     11,   51,  -24, 24, 20,  0 }, {     10,   51,  -25, 24, 20,  0 },
    {     10,   52,  -26, 24, 20,  0 }, {     10,   52,  -27, 24, 20,  0 }, {     10,   53,  -28, 24, 20,  0 }, {     10,   53,  -29, 24, 20,  0 }, {     10,   53,  -30, 24, 20,  0 },
    {     10,   54,  -31, 24, 20,  0 }, {     10,   54,  -32, 24, 20,  0 }, {     10,   54,  -33, 24, 20,  0 }, {     10,   55,  -34, 24, 20,  0 }, {      9,   55,  -35, 24, 20,  0 },
    {      9,   56,  -36, 24, 20,  0 }, {      9,   56,  -37, 24, 20,  0 }, {      9,   56,  -38, 24, 20,  0 }, {      9,   57,  -39, 24, 19,  0 }, {      9,   57,  -40, 24, 19,  0 },
    {      9,   57,  -41, 24, 19,  0 }, {      9,   57,  -42, 24, 19,  0 }, {      9,   58,  -43, 24, 19,  0 }, {      8,   58,  -44, 24, 19,  0 }, {      8,   58,  -45, 24, 19,  0 },
    {      8,   58,  -46, 24, 19,  0 }, {      8,   59,  -47, 24, 19,  0 }, {      8,   59,  -48, 24, 19,  0 }, {      8,   59,  -49, 24, 19,  0 }, {      8,   59,  -50, 24, 19,  0 },
    {      8,   59,  -51, 24, 19,  0 }, {      8,   59,  -52, 24, 19,  0 }, {      8,   60,  -53, 24, 19,  0 }, {      7,   60,  -54, 24, 19,  0 }, {      7,   60,  -55, 24, 19,  0 },
    {      7,   60,  -56, 24, 19,  0 }, {      7,   60,  -57, 24, 19,  0 }, {      7,   60,  -58, 24, 19,  0 }, {      7,   60,  -59, 24, 19,  0 }, {      7,   60,  -60, 24, 19,  0 },
    {      7,   61,  -61, 24, 19,  0 }, {      7,   61,  -62, 24, 19,  0 }, {      7,   61,  -63, 24, 18,  0 }, {      6,   61,  -64, 24, 18,  0 }, {      6,   61,  -65, 24, 18,  0 },
    {      6,   61,  -66, 24, 18,  0 }, {      6,   61,  -67, 24, 18,  0 }, {      6,   61,  -68, 24, 18,  0 }, {      6,   61,  -69, 24, 18,  0 }, {      6,   61,  -70, 24, 18,  0 },
    {      6,   61,  -71, 24, 18,  0 }, {      6,   61,  -72, 24, 18,  0 }, {      5,   61,  -73, 24, 18,  0 }, {      5,   61,  -74, 24, 18,  0 }, {      5,   61,  -75, 24, 18,  0 },
    {      5,   61,  -76, 24, 18,  0 }, {      5,   61,  -77, 24, 18,  0 }, {      5,   61,  -78, 24, 18,  0 }, {      5,   61,  -79, 24, 18,  0 }, {      5,   61,  -80, 24, 18,  0 },
    {      5,   61,  -81, 24, 18,  0 }, {      5,   61,  -82, 24, 18,  0 }, {      4,   61,  -83, 24, 18,  0 }, {      4,   61,  -84, 24, 18,  0 }, {      4,   61,  -85, 24, 18,  0 },
    {      4,   61,  -86, 24, 18,  0 }, {      4,   61,  -87, 24, 18,  0 }, {      4,   61,  -88, 24, 18,  0 }, {      4,   61,  -89, 24, 18,  0 }, {      4,   61,  -90, 24, 18,  0 },
    {      4,   61,  -91, 24, 18,  0 }, {      4,   61,  -92, 24, 18,  0 }, {      3,   61,  -93, 24, 18,  0 }, {      3,   61,  -94, 24, 18,  0 }, {      3,   61,  -95, 24, 18,  0 },
    {      3,   61,  -96, 24, 18,  0 }, {      3,   61,  -97, 24, 18,  0 }, {      3,   61,  -98, 24, 18,  0 }, {      3,   61,  -99, 24, 18,  0 }, {      3,   61, -100, 24, 17,  0 },
    {      3,   61, -101, 24, 17,  0 }, {      3,   60, -102, 24, 17,  0 }, {      2,   60, -103, 24, 17,  0 }, {      2,   60, -104, 24, 17,  0 }, {      2,   60, -105, 24, 17,  0 },
    {      2,   60, -106, 24, 17,  0 }, {      2,   60, -107, 24, 17,  0 }, {      2,   59, -108, 24, 17,  0 }, {      2,   59, -109, 24, 17,  0 }, {      2,   59, -110, 24, 17,  0 },
    {      2,   59, -111, 24, 17,  0 }, {      1,   59, -112, 24, 17,  0 }, {      1,   59, -113, 24, 17,  0 }, {      1,   58, -114, 24, 17,  0 }, {      1,   58, -115, 24, 17,  0 },
    {      1,   58, -116, 24, 17,  0 }, {      1,   58, -117, 24, 17,  0 }, {      1,   58, -118, 24, 17,  0 }, {      1,   57, -119, 24, 17,  0 }, {      1,   57, -120, 24, 17,  0 },
    {      1,   57, -121, 24, 17,  0 }, {      0,   57, -122, 24, 17,  0 }, {      0,   56, -123, 24, 17,  0 }, {      0,   56, -124, 24, 17,  0 }, {      0,   56, -125, 24, 17,  0 },
    {      0,   55, -126, 24, 17,  0 }, {      0,   55, -127, 24, 17,  0 }, {      0,   55, -128, 24, 17,  0 }, {      0,   54, -129, 24, 17,  0 }, {      0,   54, -130, 24, 17,  0 },
    {      0,   54, -131, 24, 17,  0 }, {     -1,   54, -132, 24, 17,  0 }, {     -1,   53, -133, 24,  8,  0 }, {     -1,   53, -134, 24,  8,  0 }, {     -1,   53, -135, 24,  8,  0 },
    {     -1,   52, -136, 24,  8,  0 }, {     -1,   52, -137, 24,  8,  0 }, {     -1,   51, -138, 24,  8,  0 }, {     -1,   51, -139, 24,  8,  0 }, {     -1,   50, -140, 24,  8,  0 },
    {     -2,   50, -141, 24,  8,  0 }, {     -2,   50, -142, 24,  8,  0 }, {     -2,   49, -143, 24,  8,  0 }, {     -2,   49, -144, 24,  8,  0 }, {     -2,   48, -145, 24,  8,  0 },
    {     -2,   48, -146, 24,  8,  0 }, {     -2,   48, -147, 24,  8,  0 }, {     -2,   47, -148, 24,  8,  0 }, {     -2,   47, -149, 24,  8,  0 }, {     -2,   46, -150, 24,  8,  0 },
    {     -3,   46, -151, 24,  8,  0 }, {     -3,   45, -152, 24,  8,  0 }, {     -3,   45, -153, 24,  8,  0 }, {     -3,   45, -154, 24,  8,  0 }, {     -3,   44, -155, 24,  8,  0 },
    {     -3,   44, -156, 24,  8,  0 }, {     -3,   43, -157, 24,  8,  0 }, {     -3,   43, -158, 24,  8,  0 }, {     -3,   42, -159, 24,  8,  0 }, {     -3,   42, -160, 24,  8,  0 },
    {     -4,   41, -161, 24,  8,  0 }, {     -4,   41, -162, 24,  8,  0 }, {     -4,   40, -163, 24,  8,  0 }, {     -4,   39, -164, 24,  8,  0 }, {     -4,   39, -165, 24,  8,  0 },
    {     -4,   38, -166, 24,  8,  0 }, {     -4,   38, -167, 24,  8,  0 }, {     -4,   37, -168, 24,  8,  0 }, {     -4,   36, -169, 24,  7,  0 }, {     -4,   36, -170, 24,  7,  0 },
    {     -5,   35, -171, 24,  7,  0 }, {     -5,   35, -172, 24,  7,  0 }, {     -5,   34, -173, 24,  7,  0 }, {     -5,   33, -174, 24,  7,  0 }, {     -5,   33, -175, 24,  7,  0 },
    {     -5,   32, -176, 24,  7,  0 }, {     -5,   31, -177, 24,  7,  0 }, {     -5,   31, -178, 24,  7,  0 }, {     -5,   30, -179, 24,  7,  0 }, {     -6,   29, -180, 24,  7,  0 },
    {     -6,   28, -181, 24,  7,  0 }, {     -6,   28, -182, 24,  7,  0 }, {     -6,   27, -183, 24,  7,  0 }, {     -6,   26, -184, 24,  7,  0 }, {     -6,   26, -185, 24,  7,  0 },
    {     -6,   25, -186, 24,  7,  0 }, {     -6,   24, -187, 24,  7,  0 }, {     -6,   24, -188, 24,  7,  0 }, {     -6,   23, -189, 24,  7,  0 }, {     -7,   22, -190, 24,  7,  0 },
    {     -7,   21, -191, 24,  7,  0 }, {     -7,   20, -192, 24,  7,  0 }, {     -7,   19, -193, 24,  7,  0 }, {     -7,   18, -194, 24,  7,  0 }, {     -7,   17, -195, 24,  7,  0 },
    {     -7,   17, -196, 24,  7,  0 }, {     -7,   16, -197, 24,  7,  0 }, {     -7,   15, -198, 24,  7,  0 }, {     -7,   14, -199, 24,  7,  0 }, {     -8,   13, -200, 24,  7,  0 },
    {     -8,   12, -201, 24,  7,  0 }, {     -8,   11, -202, 24,  7,  0 }, {     -8,   10, -203, 24,  7,  0 }, {     -8,    9, -204, 24,  7,  0 }, {     -8,    8, -205, 24,  7,  0 },
    {     -8,    7, -206, 24,  7,  0 }, {     -8,    6, -206, 24,  7,  0 }, {     -8,    5, -207, 24,  7,  0 }, {     -9,    4, -208, 24,  7,  0 }, {     -9,    3, -209, 24,  7,  0 },
    {     -9,    2, -210, 24,  7,  0 }, {     -9,    1, -211, 24,  7,  0 }, {     -9,    0, -212, 24,  7,  0 }, {     -9,   -1, -212, 24,  7,  0 }, {     -9,   -2, -213, 24,  7,  0 },
    {     -9,   -3, -214, 24,  6,  0 }, {     -9,   -4, -215, 24,  6,  0 }, {     -9,   -5, -215, 24,  6,  0 }, {    -10,   -6, -216, 24,  6,  0 }, {    -10,   -7, -217, 24,  6,  0 },
    {    -10,   -8, -218, 24,  6,  0 }, {    -10,   -9, -218, 24,  6,  0 }, {    -10,  -10, -219, 24,  6,  0 }, {    -10,  -11, -220, 24,  6,  0 }, {    -10,  -12, -221, 24,  6,  0 },
    {    -10,  -13, -221, 24,  6,  0 }, {    -10,  -14, -222, 24,  6,  0 }, {    -10,  -15, -223, 24,  6,  0 }, {    -11,  -16, -223, 24,  6,  0 }, {    -11,  -17, -224, 24,  6,  0 },
    {    -11,  -18, -224, 24,  6,  0 }, {    -11,  -19, -225, 24,  6,  0 }, {    -11,  -20, -226, 24,  6,  0 }, {    -11,  -21, -226, 24,  6,  0 }, {    -11,  -22, -227, 24,  6,  0 },
    {    -11,  -23, -227, 24,  6,  0 }, {    -11,  -24, -228, 24,  6,  0 }, {    -11,  -25, -229, 24,  6,  0 }, {    -12,  -26, -229, 24,  6,  0 }, {    -12,  -27, -230, 24,  6,  0 },
    {    -12,  -28, -230, 24,  6,  0 }, {    -12,  -29, -231, 24,  6,  0 }, {    -12,  -30, -231, 24,  6,  0 }, {    -12,  -31, -232, 24,  6,  0 }, {    -12,  -32, -232, 24,  6,  0 },
    {    -12,  -33, -233, 24,  6,  0 }, {    -12,  -34, -233, 24,  6,  0 }, {    -13,  -35, -234, 24,  6,  0 }, {    -13,  -36, -234, 24,  6,  0 }, {    -13,  -37, -235, 24,  6,  0 },
    {    -13,  -38, -235, 24,  6,  0 }, {    -13,  -39, -236, 24,  6,  0 }, {    -13,  -40, -236, 24,  6,  0 }, {    -13,  -41, -237, 24,  6,  0 }, {    -13,  -42, -237, 24,  6,  0 },
    {    -13,  -43, -238, 24,  6,  0 }, {    -13,  -44, -238, 24,  6,  0 }, {    -14,  -45, -239, 24,  6,  0 }, {    -14,  -46, -239, 24,  6,  0 }, {    -14,  -47, -240, 24,  6,  0 },
    {    -14,  -48, -240, 24,  6,  0 }, {    -14,  -49, -241, 24,  6,  0 }, {    -14,  -50, -241, 24,  6,  0 }, {    -14,  -51, -242, 24,  6,  0 }, {    -14,  -52, -242, 24,  6,  0 },
    {    -14,  -53, -243, 24,  6,  0 }, {    -14,  -54, -243, 24,  6,  0 }, {    -15,  -55, -244, 24,  6,  0 }, {    -15,  -56, -244, 24,  6,  0 }, {    -15,  -57, -245, 24,  6,  0 },
    {    -15,  -58, -245, 24,  6,  0 }, {    -15,  -59, -246, 24,  6,  0 }, {    -15,  -60, -246, 24,  6,  0 }, {    -15,  -61, -247, 24,  6,  0 }, {    -15,  -62, -247, 24,  6,  0 },
    {    -15,  -63, -248, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92A56A, {
    {      0,   16,   16,  0, 16,  0 }, {      1,   16,   16,  0, 16,  0 }, {      2,   16,   16,  0, 16,  0 }, {      3,   16,   16,  0, 16,  0 }, {      4,   16,   16,  0, 16,  0 },
    {      5,   16,   16,  0, 16,  0 }, {      6,   16,   16,  0, 16,  0 }, {      7,   16,   16,  0, 16,  0 }, {      8,   16,   15,  0, 16,  0 }, {      9,   16,   15,  0, 16,  0 },
    {     10,   17,   15,  0, 16,  0 }, {     11,   17,   15,  0, 16,  0 }, {     12,   17,   14,  0, 16,  0 }, {     13,   17,   14,  0, 16,  0 }, {     14,   17,   14,  0, 16,  0 },
    {     15,   17,   13,  0, 23,  0 }, {     16,   17,   13,  0, 23,  0 }, {     17,   17,   12,  0, 23,  0 }, {     18,   17,   12,  0, 23,  0 }, {     19,   17,   11,  0, 23,  0 },
    {     20,   18,   11,  0, 23,  0 }, {     21,   18,   10,  0, 23,  0 }, {     22,   18,   10,  0, 23,  0 }, {     23,   18,    9,  0, 23,  0 }, {     24,   18,    8,  0, 23,  0 },
    {     25,   18,    8,  0, 23,  0 }, {     26,   18,    7,  0, 23,  0 }, {     27,   18,    6,  0, 23,  0 }, {     28,   18,    5,  0, 23,  0 }, {     29,   18,    5,  0, 23,  0 },
    {     30,   19,    4,  0, 22,  0 }, {     31,   19,    3,  0, 22,  0 }, {     32,   19,    2,  0, 22,  0 }, {     33,   19,    1,  0, 22,  0 }, {     34,   19,    0,  0, 22,  0 },
    {     35,   19,   -1,  0, 22,  0 }, {     36,   19,   -2,  0, 22,  0 }, {     37,   19,   -3,  0, 22,  0 }, {     38,   19,   -4,  0, 22,  0 }, {     39,   20,   -5,  0, 22,  0 },
    {     40,   20,   -6,  0, 22,  0 }, {     40,   20,   -7,  0, 22,  0 }, {     41,   20,   -8,  0, 22,  0 }, {     42,   20,   -9,  0, 21,  0 }, {     43,   20,  -10,  0, 21,  0 },
    {     43,   20,  -11,  0, 21,  0 }, {     44,   20,  -12,  0, 21,  0 }, {     45,   20,  -13,  0, 21,  0 }, {     45,   20,  -14,  0, 21,  0 }, {     46,   21,  -15,  0, 21,  0 },
    {     47,   21,  -16,  0, 21,  0 }, {     47,   21,  -17,  0, 21,  0 }, {     48,   21,  -18,  0, 21,  0 }, {     48,   21,  -19,  0, 21,  0 }, {     49,   21,  -20,  0, 21,  0 },
    {     49,   21,  -21,  0, 21,  0 }, {     50,   21,  -22,  0, 21,  0 }, {     50,   21,  -23,  0, 21,  0 }, {     51,   21,  -24,  0, 20,  0 }, {     51,   22,  -25,  0, 20,  0 },
    {     52,   22,  -26,  0, 20,  0 }, {     52,   22,  -27,  0, 20,  0 }, {     53,   22,  -28,  0, 20,  0 }, {     53,   22,  -29,  0, 20,  0 }, {     53,   22,  -30,  0, 20,  0 },
    {     54,   22,  -31,  0, 20,  0 }, {     54,   22,  -32,  0, 20,  0 }, {     54,   22,  -33,  0, 20,  0 }, {     55,   22,  -34,  0, 20,  0 }, {     55,   23,  -35,  0, 20,  0 },
    {     56,   23,  -36,  0, 20,  0 }, {     56,   23,  -37,  0, 20,  0 }, {     56,   23,  -38,  0, 20,  0 }, {     57,   23,  -39,  0, 19,  0 }, {     57,   23,  -40,  0, 19,  0 },
    {     57,   23,  -41,  0, 19,  0 }, {     57,   23,  -42,  0, 19,  0 }, {     58,   23,  -43,  0, 19,  0 }, {     58,   24,  -44,  0, 19,  0 }, {     58,   24,  -45,  0, 19,  0 },
    {     58,   24,  -46,  0, 19,  0 }, {     59,   24,  -47,  0, 19,  0 }, {     59,   24,  -48,  0, 19,  0 }, {     59,   24,  -49,  0, 19,  0 }, {     59,   24,  -50,  0, 19,  0 },
    {     59,   24,  -51,  0, 19,  0 }, {     59,   24,  -52,  0, 19,  0 }, {     60,   24,  -53,  0, 19,  0 }, {     60,   25,  -54,  0, 19,  0 }, {     60,   25,  -55,  0, 19,  0 },
    {     60,   25,  -56,  0, 19,  0 }, {     60,   25,  -57,  0, 19,  0 }, {     60,   25,  -58,  0, 19,  0 }, {     60,   25,  -59,  0, 19,  0 }, {     60,   25,  -60,  0, 19,  0 },
    {     61,   25,  -61,  0, 19,  0 }, {     61,   25,  -62,  0, 19,  0 }, {     61,   25,  -63,  0, 18,  0 }, {     61,   26,  -64,  0, 18,  0 }, {     61,   26,  -65,  0, 18,  0 },
    {     61,   26,  -66,  0, 18,  0 }, {     61,   26,  -67,  0, 18,  0 }, {     61,   26,  -68,  0, 18,  0 }, {     61,   26,  -69,  0, 18,  0 }, {     61,   26,  -70,  0, 18,  0 },
    {     61,   26,  -71,  0, 18,  0 }, {     61,   26,  -72,  0, 18,  0 }, {     61,   27,  -73,  0, 18,  0 }, {     61,   27,  -74,  0, 18,  0 }, {     61,   27,  -75,  0, 18,  0 },
    {     61,   27,  -76,  0, 18,  0 }, {     61,   27,  -77,  0, 18,  0 }, {     61,   27,  -78,  0, 18,  0 }, {     61,   27,  -79,  0, 18,  0 }, {     61,   27,  -80,  0, 18,  0 },
    {     61,   27,  -81,  0, 18,  0 }, {     61,   27,  -82,  0, 18,  0 }, {     61,   28,  -83,  0, 18,  0 }, {     61,   28,  -84,  0, 18,  0 }, {     61,   28,  -85,  0, 18,  0 },
    {     61,   28,  -86,  0, 18,  0 }, {     61,   28,  -87,  0, 18,  0 }, {     61,   28,  -88,  0, 18,  0 }, {     61,   28,  -89,  0, 18,  0 }, {     61,   28,  -90,  0, 18,  0 },
    {     61,   28,  -91,  0, 18,  0 }, {     61,   28,  -92,  0, 18,  0 }, {     61,   29,  -93,  0, 18,  0 }, {     61,   29,  -94,  0, 18,  0 }, {     61,   29,  -95,  0, 18,  0 },
    {     61,   29,  -96,  0, 18,  0 }, {     61,   29,  -97,  0, 18,  0 }, {     61,   29,  -98,  0, 18,  0 }, {     61,   29,  -99,  0, 18,  0 }, {     61,   29, -100,  0, 17,  0 },
    {     61,   29, -101,  0, 17,  0 }, {     60,   29, -102,  0, 17,  0 }, {     60,   30, -103,  0, 17,  0 }, {     60,   30, -104,  0, 17,  0 }, {     60,   30, -105,  0, 17,  0 },
    {     60,   30, -106,  0, 17,  0 }, {     60,   30, -107,  0, 17,  0 }, {     59,   30, -108,  0, 17,  0 }, {     59,   30, -109,  0, 17,  0 }, {     59,   30, -110,  0, 17,  0 },
    {     59,   30, -111,  0, 17,  0 }, {     59,   31, -112,  0, 17,  0 }, {     59,   31, -113,  0, 17,  0 }, {     58,   31, -114,  0, 17,  0 }, {     58,   31, -115,  0, 17,  0 },
    {     58,   31, -116,  0, 17,  0 }, {     58,   31, -117,  0, 17,  0 }, {     58,   31, -118,  0, 17,  0 }, {     57,   31, -119,  0, 17,  0 }, {     57,   31, -120,  0, 17,  0 },
    {     57,   31, -121,  0, 17,  0 }, {     57,   32, -122,  0, 17,  0 }, {     56,   32, -123,  0, 17,  0 }, {     56,   32, -124,  0, 17,  0 }, {     56,   32, -125,  0, 17,  0 },
    {     55,   32, -126,  0, 17,  0 }, {     55,   32, -127,  0, 17,  0 }, {     55,   32, -128,  0, 17,  0 }, {     54,   32, -129,  0, 17,  0 }, {     54,   32, -130,  0, 17,  0 },
    {     54,   32, -131,  0, 17,  0 }, {     54,   33, -132,  0, 17,  0 }, {     53,   33, -133,  0,  8,  0 }, {     53,   33, -134,  0,  8,  0 }, {     53,   33, -135,  0,  8,  0 },
    {     52,   33, -136,  0,  8,  0 }, {     52,   33, -137,  0,  8,  0 }, {     51,   33, -138,  0,  8,  0 }, {     51,   33, -139,  0,  8,  0 }, {     50,   33, -140,  0,  8,  0 },
    {     50,   34, -141,  0,  8,  0 }, {     50,   34, -142,  0,  8,  0 }, {     49,   34, -143,  0,  8,  0 }, {     49,   34, -144,  0,  8,  0 }, {     48,   34, -145,  0,  8,  0 },
    {     48,   34, -146,  0,  8,  0 }, {     48,   34, -147,  0,  8,  0 }, {     47,   34, -148,  0,  8,  0 }, {     47,   34, -149,  0,  8,  0 }, {     46,   34, -150,  0,  8,  0 },
    {     46,   35, -151,  0,  8,  0 }, {     45,   35, -152,  0,  8,  0 }, {     45,   35, -153,  0,  8,  0 }, {     45,   35, -154,  0,  8,  0 }, {     44,   35, -155,  0,  8,  0 },
    {     44,   35, -156,  0,  8,  0 }, {     43,   35, -157,  0,  8,  0 }, {     43,   35, -158,  0,  8,  0 }, {     42,   35, -159,  0,  8,  0 }, {     42,   35, -160,  0,  8,  0 },
    {     41,   36, -161,  0,  8,  0 }, {     41,   36, -162,  0,  8,  0 }, {     40,   36, -163,  0,  8,  0 }, {     39,   36, -164,  0,  8,  0 }, {     39,   36, -165,  0,  8,  0 },
    {     38,   36, -166,  0,  8,  0 }, {     38,   36, -167,  0,  8,  0 }, {     37,   36, -168,  0,  8,  0 }, {     36,   36, -169,  0,  7,  0 }, {     36,   36, -170,  0,  7,  0 },
    {     35,   37, -171,  0,  7,  0 }, {     35,   37, -172,  0,  7,  0 }, {     34,   37, -173,  0,  7,  0 }, {     33,   37, -174,  0,  7,  0 }, {     33,   37, -175,  0,  7,  0 },
    {     32,   37, -176,  0,  7,  0 }, {     31,   37, -177,  0,  7,  0 }, {     31,   37, -178,  0,  7,  0 }, {     30,   37, -179,  0,  7,  0 }, {     29,   38, -180,  0,  7,  0 },
    {     28,   38, -181,  0,  7,  0 }, {     28,   38, -182,  0,  7,  0 }, {     27,   38, -183,  0,  7,  0 }, {     26,   38, -184,  0,  7,  0 }, {     26,   38, -185,  0,  7,  0 },
    {     25,   38, -186,  0,  7,  0 }, {     24,   38, -187,  0,  7,  0 }, {     24,   38, -188,  0,  7,  0 }, {     23,   38, -189,  0,  7,  0 }, {     22,   39, -190,  0,  7,  0 },
    {     21,   39, -191,  0,  7,  0 }, {     20,   39, -192,  0,  7,  0 }, {     19,   39, -193,  0,  7,  0 }, {     18,   39, -194,  0,  7,  0 }, {     17,   39, -195,  0,  7,  0 },
    {     17,   39, -196,  0,  7,  0 }, {     16,   39, -197,  0,  7,  0 }, {     15,   39, -198,  0,  7,  0 }, {     14,   39, -199,  0,  7,  0 }, {     13,   40, -200,  0,  7,  0 },
    {     12,   40, -201,  0,  7,  0 }, {     11,   40, -202,  0,  7,  0 }, {     10,   40, -203,  0,  7,  0 }, {      9,   40, -204,  0,  7,  0 }, {      8,   40, -205,  0,  7,  0 },
    {      7,   40, -206,  0,  7,  0 }, {      6,   40, -206,  0,  7,  0 }, {      5,   40, -207,  0,  7,  0 }, {      4,   41, -208,  0,  7,  0 }, {      3,   41, -209,  0,  7,  0 },
    {      2,   41, -210,  0,  7,  0 }, {      1,   41, -211,  0,  7,  0 }, {      0,   41, -212,  0,  7,  0 }, {     -1,   41, -212,  0,  7,  0 }, {     -2,   41, -213,  0,  7,  0 },
    {     -3,   41, -214,  0,  6,  0 }, {     -4,   41, -215,  0,  6,  0 }, {     -5,   41, -215,  0,  6,  0 }, {     -6,   42, -216,  0,  6,  0 }, {     -7,   42, -217,  0,  6,  0 },
    {     -8,   42, -218,  0,  6,  0 }, {     -9,   42, -218,  0,  6,  0 }, {    -10,   42, -219,  0,  6,  0 }, {    -11,   42, -220,  0,  6,  0 }, {    -12,   42, -221,  0,  6,  0 },
    {    -13,   42, -221,  0,  6,  0 }, {    -14,   42, -222,  0,  6,  0 }, {    -15,   42, -223,  0,  6,  0 }, {    -16,   43, -223,  0,  6,  0 }, {    -17,   43, -224,  0,  6,  0 },
    {    -18,   43, -224,  0,  6,  0 }, {    -19,   43, -225,  0,  6,  0 }, {    -20,   43, -226,  0,  6,  0 }, {    -21,   43, -226,  0,  6,  0 }, {    -22,   43, -227,  0,  6,  0 },
    {    -23,   43, -227,  0,  6,  0 }, {    -24,   43, -228,  0,  6,  0 }, {    -25,   43, -229,  0,  6,  0 }, {    -26,   44, -229,  0,  6,  0 }, {    -27,   44, -230,  0,  6,  0 },
    {    -28,   44, -230,  0,  6,  0 }, {    -29,   44, -231,  0,  6,  0 }, {    -30,   44, -231,  0,  6,  0 }, {    -31,   44, -232,  0,  6,  0 }, {    -32,   44, -232,  0,  6,  0 },
    {    -33,   44, -233,  0,  6,  0 }, {    -34,   44, -233,  0,  6,  0 }, {    -35,   45, -234,  0,  6,  0 }, {    -36,   45, -234,  0,  6,  0 }, {    -37,   45, -235,  0,  6,  0 },
    {    -38,   45, -235,  0,  6,  0 }, {    -39,   45, -236,  0,  6,  0 }, {    -40,   45, -236,  0,  6,  0 }, {    -41,   45, -237,  0,  6,  0 }, {    -42,   45, -237,  0,  6,  0 },
    {    -43,   45, -238,  0,  6,  0 }, {    -44,   45, -238,  0,  6,  0 }, {    -45,   46, -239,  0,  6,  0 }, {    -46,   46, -239,  0,  6,  0 }, {    -47,   46, -240,  0,  6,  0 },
    {    -48,   46, -240,  0,  6,  0 }, {    -49,   46, -241,  0,  6,  0 }, {    -50,   46, -241,  0,  6,  0 }, {    -51,   46, -242,  0,  6,  0 }, {    -52,   46, -242,  0,  6,  0 },
    {    -53,   46, -243,  0,  6,  0 }, {    -54,   46, -243,  0,  6,  0 }, {    -55,   47, -244,  0,  6,  0 }, {    -56,   47, -244,  0,  6,  0 }, {    -57,   47, -245,  0,  6,  0 },
    {    -58,   47, -245,  0,  6,  0 }, {    -59,   47, -246,  0,  6,  0 }, {    -60,   47, -246,  0,  6,  0 }, {    -61,   47, -247,  0,  6,  0 }, {    -62,   47, -247,  0,  6,  0 },
    {    -63,   47, -248,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92BB5E, {
    {     16,   31,   16,  8, 16,  0 }, {     16,   30,   16,  8, 16,  0 }, {     16,   29,   16,  8, 16,  0 }, {     16,   28,   16,  8, 16,  0 }, {     16,   27,   16,  8, 16,  0 },
    {     16,   26,   16,  8, 16,  0 }, {     16,   25,   16,  8, 16,  0 }, {     16,   24,   16,  8, 16,  0 }, {     16,   23,   15,  8, 16,  0 }, {     16,   22,   15,  8, 16,  0 },
    {     17,   21,   15,  8, 16,  0 }, {     17,   20,   15,  8, 16,  0 }, {     17,   19,   14,  8, 16,  0 }, {     17,   18,   14,  8, 16,  0 }, {     17,   17,   14,  8, 16,  0 },
    {     17,   16,   13,  8, 23,  0 }, {     17,   15,   13,  8, 23,  0 }, {     17,   14,   12,  8, 23,  0 }, {     17,   13,   12,  8, 23,  0 }, {     17,   12,   11,  8, 23,  0 },
    {     18,   11,   11,  8, 23,  0 }, {     18,   10,   10,  8, 23,  0 }, {     18,    9,   10,  8, 23,  0 }, {     18,    8,    9,  8, 23,  0 }, {     18,    7,    8,  8, 23,  0 },
    {     18,    6,    8,  8, 23,  0 }, {     18,    5,    7,  8, 23,  0 }, {     18,    4,    6,  8, 23,  0 }, {     18,    3,    5,  8, 23,  0 }, {     18,    2,    5,  8, 23,  0 },
    {     19,    1,    4,  8, 22,  0 }, {     19,    0,    3,  8, 22,  0 }, {     19,   -1,    2,  8, 22,  0 }, {     19,   -2,    1,  8, 22,  0 }, {     19,   -3,    0,  8, 22,  0 },
    {     19,   -4,   -1,  8, 22,  0 }, {     19,   -5,   -2,  8, 22,  0 }, {     19,   -6,   -3,  8, 22,  0 }, {     19,   -7,   -4,  8, 22,  0 }, {     20,   -8,   -5,  8, 22,  0 },
    {     20,   -9,   -6,  8, 22,  0 }, {     20,   -9,   -7,  8, 22,  0 }, {     20,  -10,   -8,  8, 22,  0 }, {     20,  -11,   -9,  8, 21,  0 }, {     20,  -12,  -10,  8, 21,  0 },
    {     20,  -12,  -11,  8, 21,  0 }, {     20,  -13,  -12,  8, 21,  0 }, {     20,  -14,  -13,  8, 21,  0 }, {     20,  -14,  -14,  8, 21,  0 }, {     21,  -15,  -15,  8, 21,  0 },
    {     21,  -16,  -16,  8, 21,  0 }, {     21,  -16,  -17,  8, 21,  0 }, {     21,  -17,  -18,  8, 21,  0 }, {     21,  -17,  -19,  8, 21,  0 }, {     21,  -18,  -20,  8, 21,  0 },
    {     21,  -18,  -21,  8, 21,  0 }, {     21,  -19,  -22,  8, 21,  0 }, {     21,  -19,  -23,  8, 21,  0 }, {     21,  -20,  -24,  8, 20,  0 }, {     22,  -20,  -25,  8, 20,  0 },
    {     22,  -21,  -26,  8, 20,  0 }, {     22,  -21,  -27,  8, 20,  0 }, {     22,  -22,  -28,  8, 20,  0 }, {     22,  -22,  -29,  8, 20,  0 }, {     22,  -22,  -30,  8, 20,  0 },
    {     22,  -23,  -31,  8, 20,  0 }, {     22,  -23,  -32,  8, 20,  0 }, {     22,  -23,  -33,  8, 20,  0 }, {     22,  -24,  -34,  8, 20,  0 }, {     23,  -24,  -35,  8, 20,  0 },
    {     23,  -25,  -36,  8, 20,  0 }, {     23,  -25,  -37,  8, 20,  0 }, {     23,  -25,  -38,  8, 20,  0 }, {     23,  -26,  -39,  8, 19,  0 }, {     23,  -26,  -40,  8, 19,  0 },
    {     23,  -26,  -41,  8, 19,  0 }, {     23,  -26,  -42,  8, 19,  0 }, {     23,  -27,  -43,  8, 19,  0 }, {     24,  -27,  -44,  8, 19,  0 }, {     24,  -27,  -45,  8, 19,  0 },
    {     24,  -27,  -46,  8, 19,  0 }, {     24,  -28,  -47,  8, 19,  0 }, {     24,  -28,  -48,  8, 19,  0 }, {     24,  -28,  -49,  8, 19,  0 }, {     24,  -28,  -50,  8, 19,  0 },
    {     24,  -28,  -51,  8, 19,  0 }, {     24,  -28,  -52,  8, 19,  0 }, {     24,  -29,  -53,  8, 19,  0 }, {     25,  -29,  -54,  8, 19,  0 }, {     25,  -29,  -55,  8, 19,  0 },
    {     25,  -29,  -56,  8, 19,  0 }, {     25,  -29,  -57,  8, 19,  0 }, {     25,  -29,  -58,  8, 19,  0 }, {     25,  -29,  -59,  8, 19,  0 }, {     25,  -29,  -60,  8, 19,  0 },
    {     25,  -30,  -61,  8, 19,  0 }, {     25,  -30,  -62,  8, 19,  0 }, {     25,  -30,  -63,  8, 18,  0 }, {     26,  -30,  -64,  8, 18,  0 }, {     26,  -30,  -65,  8, 18,  0 },
    {     26,  -30,  -66,  8, 18,  0 }, {     26,  -30,  -67,  8, 18,  0 }, {     26,  -30,  -68,  8, 18,  0 }, {     26,  -30,  -69,  8, 18,  0 }, {     26,  -30,  -70,  8, 18,  0 },
    {     26,  -30,  -71,  8, 18,  0 }, {     26,  -30,  -72,  8, 18,  0 }, {     27,  -30,  -73,  8, 18,  0 }, {     27,  -30,  -74,  8, 18,  0 }, {     27,  -30,  -75,  8, 18,  0 },
    {     27,  -30,  -76,  8, 18,  0 }, {     27,  -30,  -77,  8, 18,  0 }, {     27,  -30,  -78,  8, 18,  0 }, {     27,  -30,  -79,  8, 18,  0 }, {     27,  -30,  -80,  8, 18,  0 },
    {     27,  -30,  -81,  8, 18,  0 }, {     27,  -30,  -82,  8, 18,  0 }, {     28,  -30,  -83,  8, 18,  0 }, {     28,  -30,  -84,  8, 18,  0 }, {     28,  -30,  -85,  8, 18,  0 },
    {     28,  -30,  -86,  8, 18,  0 }, {     28,  -30,  -87,  8, 18,  0 }, {     28,  -30,  -88,  8, 18,  0 }, {     28,  -30,  -89,  8, 18,  0 }, {     28,  -30,  -90,  8, 18,  0 },
    {     28,  -30,  -91,  8, 18,  0 }, {     28,  -30,  -92,  8, 18,  0 }, {     29,  -30,  -93,  8, 18,  0 }, {     29,  -30,  -94,  8, 18,  0 }, {     29,  -30,  -95,  8, 18,  0 },
    {     29,  -30,  -96,  8, 18,  0 }, {     29,  -30,  -97,  8, 18,  0 }, {     29,  -30,  -98,  8, 18,  0 }, {     29,  -30,  -99,  8, 18,  0 }, {     29,  -30, -100,  8, 17,  0 },
    {     29,  -30, -101,  8, 17,  0 }, {     29,  -29, -102,  8, 17,  0 }, {     30,  -29, -103,  8, 17,  0 }, {     30,  -29, -104,  8, 17,  0 }, {     30,  -29, -105,  8, 17,  0 },
    {     30,  -29, -106,  8, 17,  0 }, {     30,  -29, -107,  8, 17,  0 }, {     30,  -28, -108,  8, 17,  0 }, {     30,  -28, -109,  8, 17,  0 }, {     30,  -28, -110,  8, 17,  0 },
    {     30,  -28, -111,  8, 17,  0 }, {     31,  -28, -112,  8, 17,  0 }, {     31,  -28, -113,  8, 17,  0 }, {     31,  -27, -114,  8, 17,  0 }, {     31,  -27, -115,  8, 17,  0 },
    {     31,  -27, -116,  8, 17,  0 }, {     31,  -27, -117,  8, 17,  0 }, {     31,  -27, -118,  8, 17,  0 }, {     31,  -26, -119,  8, 17,  0 }, {     31,  -26, -120,  8, 17,  0 },
    {     31,  -26, -121,  8, 17,  0 }, {     32,  -26, -122,  8, 17,  0 }, {     32,  -25, -123,  8, 17,  0 }, {     32,  -25, -124,  8, 17,  0 }, {     32,  -25, -125,  8, 17,  0 },
    {     32,  -24, -126,  8, 17,  0 }, {     32,  -24, -127,  8, 17,  0 }, {     32,  -24, -128,  8, 17,  0 }, {     32,  -23, -129,  8, 17,  0 }, {     32,  -23, -130,  8, 17,  0 },
    {     32,  -23, -131,  8, 17,  0 }, {     33,  -23, -132,  8, 17,  0 }, {     33,  -22, -133,  8,  8,  0 }, {     33,  -22, -134,  8,  8,  0 }, {     33,  -22, -135,  8,  8,  0 },
    {     33,  -21, -136,  8,  8,  0 }, {     33,  -21, -137,  8,  8,  0 }, {     33,  -20, -138,  8,  8,  0 }, {     33,  -20, -139,  8,  8,  0 }, {     33,  -19, -140,  8,  8,  0 },
    {     34,  -19, -141,  8,  8,  0 }, {     34,  -19, -142,  8,  8,  0 }, {     34,  -18, -143,  8,  8,  0 }, {     34,  -18, -144,  8,  8,  0 }, {     34,  -17, -145,  8,  8,  0 },
    {     34,  -17, -146,  8,  8,  0 }, {     34,  -17, -147,  8,  8,  0 }, {     34,  -16, -148,  8,  8,  0 }, {     34,  -16, -149,  8,  8,  0 }, {     34,  -15, -150,  8,  8,  0 },
    {     35,  -15, -151,  8,  8,  0 }, {     35,  -14, -152,  8,  8,  0 }, {     35,  -14, -153,  8,  8,  0 }, {     35,  -14, -154,  8,  8,  0 }, {     35,  -13, -155,  8,  8,  0 },
    {     35,  -13, -156,  8,  8,  0 }, {     35,  -12, -157,  8,  8,  0 }, {     35,  -12, -158,  8,  8,  0 }, {     35,  -11, -159,  8,  8,  0 }, {     35,  -11, -160,  8,  8,  0 },
    {     36,  -10, -161,  8,  8,  0 }, {     36,  -10, -162,  8,  8,  0 }, {     36,   -9, -163,  8,  8,  0 }, {     36,   -8, -164,  8,  8,  0 }, {     36,   -8, -165,  8,  8,  0 },
    {     36,   -7, -166,  8,  8,  0 }, {     36,   -7, -167,  8,  8,  0 }, {     36,   -6, -168,  8,  8,  0 }, {     36,   -5, -169,  8,  7,  0 }, {     36,   -5, -170,  8,  7,  0 },
    {     37,   -4, -171,  8,  7,  0 }, {     37,   -4, -172,  8,  7,  0 }, {     37,   -3, -173,  8,  7,  0 }, {     37,   -2, -174,  8,  7,  0 }, {     37,   -2, -175,  8,  7,  0 },
    {     37,   -1, -176,  8,  7,  0 }, {     37,    0, -177,  8,  7,  0 }, {     37,    0, -178,  8,  7,  0 }, {     37,    1, -179,  8,  7,  0 }, {     38,    2, -180,  8,  7,  0 },
    {     38,    3, -181,  8,  7,  0 }, {     38,    3, -182,  8,  7,  0 }, {     38,    4, -183,  8,  7,  0 }, {     38,    5, -184,  8,  7,  0 }, {     38,    5, -185,  8,  7,  0 },
    {     38,    6, -186,  8,  7,  0 }, {     38,    7, -187,  8,  7,  0 }, {     38,    7, -188,  8,  7,  0 }, {     38,    8, -189,  8,  7,  0 }, {     39,    9, -190,  8,  7,  0 },
    {     39,   10, -191,  8,  7,  0 }, {     39,   11, -192,  8,  7,  0 }, {     39,   12, -193,  8,  7,  0 }, {     39,   13, -194,  8,  7,  0 }, {     39,   14, -195,  8,  7,  0 },
    {     39,   14, -196,  8,  7,  0 }, {     39,   15, -197,  8,  7,  0 }, {     39,   16, -198,  8,  7,  0 }, {     39,   17, -199,  8,  7,  0 }, {     40,   18, -200,  8,  7,  0 },
    {     40,   19, -201,  8,  7,  0 }, {     40,   20, -202,  8,  7,  0 }, {     40,   21, -203,  8,  7,  0 }, {     40,   22, -204,  8,  7,  0 }, {     40,   23, -205,  8,  7,  0 },
    {     40,   24, -206,  8,  7,  0 }, {     40,   25, -206,  8,  7,  0 }, {     40,   26, -207,  8,  7,  0 }, {     41,   27, -208,  8,  7,  0 }, {     41,   28, -209,  8,  7,  0 },
    {     41,   29, -210,  8,  7,  0 }, {     41,   30, -211,  8,  7,  0 }, {     41,   31, -212,  8,  7,  0 }, {     41,   32, -212,  8,  7,  0 }, {     41,   33, -213,  8,  7,  0 },
    {     41,   34, -214,  8,  6,  0 }, {     41,   35, -215,  8,  6,  0 }, {     41,   36, -215,  8,  6,  0 }, {     42,   37, -216,  8,  6,  0 }, {     42,   38, -217,  8,  6,  0 },
    {     42,   39, -218,  8,  6,  0 }, {     42,   40, -218,  8,  6,  0 }, {     42,   41, -219,  8,  6,  0 }, {     42,   42, -220,  8,  6,  0 }, {     42,   43, -221,  8,  6,  0 },
    {     42,   44, -221,  8,  6,  0 }, {     42,   45, -222,  8,  6,  0 }, {     42,   46, -223,  8,  6,  0 }, {     43,   47, -223,  8,  6,  0 }, {     43,   48, -224,  8,  6,  0 },
    {     43,   49, -224,  8,  6,  0 }, {     43,   50, -225,  8,  6,  0 }, {     43,   51, -226,  8,  6,  0 }, {     43,   52, -226,  8,  6,  0 }, {     43,   53, -227,  8,  6,  0 },
    {     43,   54, -227,  8,  6,  0 }, {     43,   55, -228,  8,  6,  0 }, {     43,   56, -229,  8,  6,  0 }, {     44,   57, -229,  8,  6,  0 }, {     44,   58, -230,  8,  6,  0 },
    {     44,   59, -230,  8,  6,  0 }, {     44,   60, -231,  8,  6,  0 }, {     44,   61, -231,  8,  6,  0 }, {     44,   62, -232,  8,  6,  0 }, {     44,   63, -232,  8,  6,  0 },
    {     44,   64, -233,  8,  6,  0 }, {     44,   65, -233,  8,  6,  0 }, {     45,   66, -234,  8,  6,  0 }, {     45,   67, -234,  8,  6,  0 }, {     45,   68, -235,  8,  6,  0 },
    {     45,   69, -235,  8,  6,  0 }, {     45,   70, -236,  8,  6,  0 }, {     45,   71, -236,  8,  6,  0 }, {     45,   72, -237,  8,  6,  0 }, {     45,   73, -237,  8,  6,  0 },
    {     45,   74, -238,  8,  6,  0 }, {     45,   75, -238,  8,  6,  0 }, {     46,   76, -239,  8,  6,  0 }, {     46,   77, -239,  8,  6,  0 }, {     46,   78, -240,  8,  6,  0 },
    {     46,   79, -240,  8,  6,  0 }, {     46,   80, -241,  8,  6,  0 }, {     46,   81, -241,  8,  6,  0 }, {     46,   82, -242,  8,  6,  0 }, {     46,   83, -242,  8,  6,  0 },
    {     46,   84, -243,  8,  6,  0 }, {     46,   85, -243,  8,  6,  0 }, {     47,   86, -244,  8,  6,  0 }, {     47,   87, -244,  8,  6,  0 }, {     47,   88, -245,  8,  6,  0 },
    {     47,   89, -245,  8,  6,  0 }, {     47,   90, -246,  8,  6,  0 }, {     47,   91, -246,  8,  6,  0 }, {     47,   92, -247,  8,  6,  0 }, {     47,   93, -247,  8,  6,  0 },
    {     47,   94, -248,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92847C, {
    {     31,   16,   16, 16, 16,  0 }, {     30,   16,   16, 16, 16,  0 }, {     29,   16,   16, 16, 16,  0 }, {     28,   16,   16, 16, 16,  0 }, {     27,   16,   16, 16, 16,  0 },
    {     26,   16,   16, 16, 16,  0 }, {     25,   16,   16, 16, 16,  0 }, {     24,   16,   16, 16, 16,  0 }, {     23,   16,   15, 16, 16,  0 }, {     22,   16,   15, 16, 16,  0 },
    {     21,   17,   15, 16, 16,  0 }, {     20,   17,   15, 16, 16,  0 }, {     19,   17,   14, 16, 16,  0 }, {     18,   17,   14, 16, 16,  0 }, {     17,   17,   14, 16, 16,  0 },
    {     16,   17,   13, 16, 23,  0 }, {     15,   17,   13, 16, 23,  0 }, {     14,   17,   12, 16, 23,  0 }, {     13,   17,   12, 16, 23,  0 }, {     12,   17,   11, 16, 23,  0 },
    {     11,   18,   11, 16, 23,  0 }, {     10,   18,   10, 16, 23,  0 }, {      9,   18,   10, 16, 23,  0 }, {      8,   18,    9, 16, 23,  0 }, {      7,   18,    8, 16, 23,  0 },
    {      6,   18,    8, 16, 23,  0 }, {      5,   18,    7, 16, 23,  0 }, {      4,   18,    6, 16, 23,  0 }, {      3,   18,    5, 16, 23,  0 }, {      2,   18,    5, 16, 23,  0 },
    {      1,   19,    4, 16, 22,  0 }, {      0,   19,    3, 16, 22,  0 }, {     -1,   19,    2, 16, 22,  0 }, {     -2,   19,    1, 16, 22,  0 }, {     -3,   19,    0, 16, 22,  0 },
    {     -4,   19,   -1, 16, 22,  0 }, {     -5,   19,   -2, 16, 22,  0 }, {     -6,   19,   -3, 16, 22,  0 }, {     -7,   19,   -4, 16, 22,  0 }, {     -8,   20,   -5, 16, 22,  0 },
    {     -9,   20,   -6, 16, 22,  0 }, {     -9,   20,   -7, 16, 22,  0 }, {    -10,   20,   -8, 16, 22,  0 }, {    -11,   20,   -9, 16, 21,  0 }, {    -12,   20,  -10, 16, 21,  0 },
    {    -12,   20,  -11, 16, 21,  0 }, {    -13,   20,  -12, 16, 21,  0 }, {    -14,   20,  -13, 16, 21,  0 }, {    -14,   20,  -14, 16, 21,  0 }, {    -15,   21,  -15, 16, 21,  0 },
    {    -16,   21,  -16, 16, 21,  0 }, {    -16,   21,  -17, 16, 21,  0 }, {    -17,   21,  -18, 16, 21,  0 }, {    -17,   21,  -19, 16, 21,  0 }, {    -18,   21,  -20, 16, 21,  0 },
    {    -18,   21,  -21, 16, 21,  0 }, {    -19,   21,  -22, 16, 21,  0 }, {    -19,   21,  -23, 16, 21,  0 }, {    -20,   21,  -24, 16, 20,  0 }, {    -20,   22,  -25, 16, 20,  0 },
    {    -21,   22,  -26, 16, 20,  0 }, {    -21,   22,  -27, 16, 20,  0 }, {    -22,   22,  -28, 16, 20,  0 }, {    -22,   22,  -29, 16, 20,  0 }, {    -22,   22,  -30, 16, 20,  0 },
    {    -23,   22,  -31, 16, 20,  0 }, {    -23,   22,  -32, 16, 20,  0 }, {    -23,   22,  -33, 16, 20,  0 }, {    -24,   22,  -34, 16, 20,  0 }, {    -24,   23,  -35, 16, 20,  0 },
    {    -25,   23,  -36, 16, 20,  0 }, {    -25,   23,  -37, 16, 20,  0 }, {    -25,   23,  -38, 16, 20,  0 }, {    -26,   23,  -39, 16, 19,  0 }, {    -26,   23,  -40, 16, 19,  0 },
    {    -26,   23,  -41, 16, 19,  0 }, {    -26,   23,  -42, 16, 19,  0 }, {    -27,   23,  -43, 16, 19,  0 }, {    -27,   24,  -44, 16, 19,  0 }, {    -27,   24,  -45, 16, 19,  0 },
    {    -27,   24,  -46, 16, 19,  0 }, {    -28,   24,  -47, 16, 19,  0 }, {    -28,   24,  -48, 16, 19,  0 }, {    -28,   24,  -49, 16, 19,  0 }, {    -28,   24,  -50, 16, 19,  0 },
    {    -28,   24,  -51, 16, 19,  0 }, {    -28,   24,  -52, 16, 19,  0 }, {    -29,   24,  -53, 16, 19,  0 }, {    -29,   25,  -54, 16, 19,  0 }, {    -29,   25,  -55, 16, 19,  0 },
    {    -29,   25,  -56, 16, 19,  0 }, {    -29,   25,  -57, 16, 19,  0 }, {    -29,   25,  -58, 16, 19,  0 }, {    -29,   25,  -59, 16, 19,  0 }, {    -29,   25,  -60, 16, 19,  0 },
    {    -30,   25,  -61, 16, 19,  0 }, {    -30,   25,  -62, 16, 19,  0 }, {    -30,   25,  -63, 16, 18,  0 }, {    -30,   26,  -64, 16, 18,  0 }, {    -30,   26,  -65, 16, 18,  0 },
    {    -30,   26,  -66, 16, 18,  0 }, {    -30,   26,  -67, 16, 18,  0 }, {    -30,   26,  -68, 16, 18,  0 }, {    -30,   26,  -69, 16, 18,  0 }, {    -30,   26,  -70, 16, 18,  0 },
    {    -30,   26,  -71, 16, 18,  0 }, {    -30,   26,  -72, 16, 18,  0 }, {    -30,   27,  -73, 16, 18,  0 }, {    -30,   27,  -74, 16, 18,  0 }, {    -30,   27,  -75, 16, 18,  0 },
    {    -30,   27,  -76, 16, 18,  0 }, {    -30,   27,  -77, 16, 18,  0 }, {    -30,   27,  -78, 16, 18,  0 }, {    -30,   27,  -79, 16, 18,  0 }, {    -30,   27,  -80, 16, 18,  0 },
    {    -30,   27,  -81, 16, 18,  0 }, {    -30,   27,  -82, 16, 18,  0 }, {    -30,   28,  -83, 16, 18,  0 }, {    -30,   28,  -84, 16, 18,  0 }, {    -30,   28,  -85, 16, 18,  0 },
    {    -30,   28,  -86, 16, 18,  0 }, {    -30,   28,  -87, 16, 18,  0 }, {    -30,   28,  -88, 16, 18,  0 }, {    -30,   28,  -89, 16, 18,  0 }, {    -30,   28,  -90, 16, 18,  0 },
    {    -30,   28,  -91, 16, 18,  0 }, {    -30,   28,  -92, 16, 18,  0 }, {    -30,   29,  -93, 16, 18,  0 }, {    -30,   29,  -94, 16, 18,  0 }, {    -30,   29,  -95, 16, 18,  0 },
    {    -30,   29,  -96, 16, 18,  0 }, {    -30,   29,  -97, 16, 18,  0 }, {    -30,   29,  -98, 16, 18,  0 }, {    -30,   29,  -99, 16, 18,  0 }, {    -30,   29, -100, 16, 17,  0 },
    {    -30,   29, -101, 16, 17,  0 }, {    -29,   29, -102, 16, 17,  0 }, {    -29,   30, -103, 16, 17,  0 }, {    -29,   30, -104, 16, 17,  0 }, {    -29,   30, -105, 16, 17,  0 },
    {    -29,   30, -106, 16, 17,  0 }, {    -29,   30, -107, 16, 17,  0 }, {    -28,   30, -108, 16, 17,  0 }, {    -28,   30, -109, 16, 17,  0 }, {    -28,   30, -110, 16, 17,  0 },
    {    -28,   30, -111, 16, 17,  0 }, {    -28,   31, -112, 16, 17,  0 }, {    -28,   31, -113, 16, 17,  0 }, {    -27,   31, -114, 16, 17,  0 }, {    -27,   31, -115, 16, 17,  0 },
    {    -27,   31, -116, 16, 17,  0 }, {    -27,   31, -117, 16, 17,  0 }, {    -27,   31, -118, 16, 17,  0 }, {    -26,   31, -119, 16, 17,  0 }, {    -26,   31, -120, 16, 17,  0 },
    {    -26,   31, -121, 16, 17,  0 }, {    -26,   32, -122, 16, 17,  0 }, {    -25,   32, -123, 16, 17,  0 }, {    -25,   32, -124, 16, 17,  0 }, {    -25,   32, -125, 16, 17,  0 },
    {    -24,   32, -126, 16, 17,  0 }, {    -24,   32, -127, 16, 17,  0 }, {    -24,   32, -128, 16, 17,  0 }, {    -23,   32, -129, 16, 17,  0 }, {    -23,   32, -130, 16, 17,  0 },
    {    -23,   32, -131, 16, 17,  0 }, {    -23,   33, -132, 16, 17,  0 }, {    -22,   33, -133, 16,  8,  0 }, {    -22,   33, -134, 16,  8,  0 }, {    -22,   33, -135, 16,  8,  0 },
    {    -21,   33, -136, 16,  8,  0 }, {    -21,   33, -137, 16,  8,  0 }, {    -20,   33, -138, 16,  8,  0 }, {    -20,   33, -139, 16,  8,  0 }, {    -19,   33, -140, 16,  8,  0 },
    {    -19,   34, -141, 16,  8,  0 }, {    -19,   34, -142, 16,  8,  0 }, {    -18,   34, -143, 16,  8,  0 }, {    -18,   34, -144, 16,  8,  0 }, {    -17,   34, -145, 16,  8,  0 },
    {    -17,   34, -146, 16,  8,  0 }, {    -17,   34, -147, 16,  8,  0 }, {    -16,   34, -148, 16,  8,  0 }, {    -16,   34, -149, 16,  8,  0 }, {    -15,   34, -150, 16,  8,  0 },
    {    -15,   35, -151, 16,  8,  0 }, {    -14,   35, -152, 16,  8,  0 }, {    -14,   35, -153, 16,  8,  0 }, {    -14,   35, -154, 16,  8,  0 }, {    -13,   35, -155, 16,  8,  0 },
    {    -13,   35, -156, 16,  8,  0 }, {    -12,   35, -157, 16,  8,  0 }, {    -12,   35, -158, 16,  8,  0 }, {    -11,   35, -159, 16,  8,  0 }, {    -11,   35, -160, 16,  8,  0 },
    {    -10,   36, -161, 16,  8,  0 }, {    -10,   36, -162, 16,  8,  0 }, {     -9,   36, -163, 16,  8,  0 }, {     -8,   36, -164, 16,  8,  0 }, {     -8,   36, -165, 16,  8,  0 },
    {     -7,   36, -166, 16,  8,  0 }, {     -7,   36, -167, 16,  8,  0 }, {     -6,   36, -168, 16,  8,  0 }, {     -5,   36, -169, 16,  7,  0 }, {     -5,   36, -170, 16,  7,  0 },
    {     -4,   37, -171, 16,  7,  0 }, {     -4,   37, -172, 16,  7,  0 }, {     -3,   37, -173, 16,  7,  0 }, {     -2,   37, -174, 16,  7,  0 }, {     -2,   37, -175, 16,  7,  0 },
    {     -1,   37, -176, 16,  7,  0 }, {      0,   37, -177, 16,  7,  0 }, {      0,   37, -178, 16,  7,  0 }, {      1,   37, -179, 16,  7,  0 }, {      2,   38, -180, 16,  7,  0 },
    {      3,   38, -181, 16,  7,  0 }, {      3,   38, -182, 16,  7,  0 }, {      4,   38, -183, 16,  7,  0 }, {      5,   38, -184, 16,  7,  0 }, {      5,   38, -185, 16,  7,  0 },
    {      6,   38, -186, 16,  7,  0 }, {      7,   38, -187, 16,  7,  0 }, {      7,   38, -188, 16,  7,  0 }, {      8,   38, -189, 16,  7,  0 }, {      9,   39, -190, 16,  7,  0 },
    {     10,   39, -191, 16,  7,  0 }, {     11,   39, -192, 16,  7,  0 }, {     12,   39, -193, 16,  7,  0 }, {     13,   39, -194, 16,  7,  0 }, {     14,   39, -195, 16,  7,  0 },
    {     14,   39, -196, 16,  7,  0 }, {     15,   39, -197, 16,  7,  0 }, {     16,   39, -198, 16,  7,  0 }, {     17,   39, -199, 16,  7,  0 }, {     18,   40, -200, 16,  7,  0 },
    {     19,   40, -201, 16,  7,  0 }, {     20,   40, -202, 16,  7,  0 }, {     21,   40, -203, 16,  7,  0 }, {     22,   40, -204, 16,  7,  0 }, {     23,   40, -205, 16,  7,  0 },
    {     24,   40, -206, 16,  7,  0 }, {     25,   40, -206, 16,  7,  0 }, {     26,   40, -207, 16,  7,  0 }, {     27,   41, -208, 16,  7,  0 }, {     28,   41, -209, 16,  7,  0 },
    {     29,   41, -210, 16,  7,  0 }, {     30,   41, -211, 16,  7,  0 }, {     31,   41, -212, 16,  7,  0 }, {     32,   41, -212, 16,  7,  0 }, {     33,   41, -213, 16,  7,  0 },
    {     34,   41, -214, 16,  6,  0 }, {     35,   41, -215, 16,  6,  0 }, {     36,   41, -215, 16,  6,  0 }, {     37,   42, -216, 16,  6,  0 }, {     38,   42, -217, 16,  6,  0 },
    {     39,   42, -218, 16,  6,  0 }, {     40,   42, -218, 16,  6,  0 }, {     41,   42, -219, 16,  6,  0 }, {     42,   42, -220, 16,  6,  0 }, {     43,   42, -221, 16,  6,  0 },
    {     44,   42, -221, 16,  6,  0 }, {     45,   42, -222, 16,  6,  0 }, {     46,   42, -223, 16,  6,  0 }, {     47,   43, -223, 16,  6,  0 }, {     48,   43, -224, 16,  6,  0 },
    {     49,   43, -224, 16,  6,  0 }, {     50,   43, -225, 16,  6,  0 }, {     51,   43, -226, 16,  6,  0 }, {     52,   43, -226, 16,  6,  0 }, {     53,   43, -227, 16,  6,  0 },
    {     54,   43, -227, 16,  6,  0 }, {     55,   43, -228, 16,  6,  0 }, {     56,   43, -229, 16,  6,  0 }, {     57,   44, -229, 16,  6,  0 }, {     58,   44, -230, 16,  6,  0 },
    {     59,   44, -230, 16,  6,  0 }, {     60,   44, -231, 16,  6,  0 }, {     61,   44, -231, 16,  6,  0 }, {     62,   44, -232, 16,  6,  0 }, {     63,   44, -232, 16,  6,  0 },
    {     64,   44, -233, 16,  6,  0 }, {     65,   44, -233, 16,  6,  0 }, {     66,   45, -234, 16,  6,  0 }, {     67,   45, -234, 16,  6,  0 }, {     68,   45, -235, 16,  6,  0 },
    {     69,   45, -235, 16,  6,  0 }, {     70,   45, -236, 16,  6,  0 }, {     71,   45, -236, 16,  6,  0 }, {     72,   45, -237, 16,  6,  0 }, {     73,   45, -237, 16,  6,  0 },
    {     74,   45, -238, 16,  6,  0 }, {     75,   45, -238, 16,  6,  0 }, {     76,   46, -239, 16,  6,  0 }, {     77,   46, -239, 16,  6,  0 }, {     78,   46, -240, 16,  6,  0 },
    {     79,   46, -240, 16,  6,  0 }, {     80,   46, -241, 16,  6,  0 }, {     81,   46, -241, 16,  6,  0 }, {     82,   46, -242, 16,  6,  0 }, {     83,   46, -242, 16,  6,  0 },
    {     84,   46, -243, 16,  6,  0 }, {     85,   46, -243, 16,  6,  0 }, {     86,   47, -244, 16,  6,  0 }, {     87,   47, -244, 16,  6,  0 }, {     88,   47, -245, 16,  6,  0 },
    {     89,   47, -245, 16,  6,  0 }, {     90,   47, -246, 16,  6,  0 }, {     91,   47, -246, 16,  6,  0 }, {     92,   47, -247, 16,  6,  0 }, {     93,   47, -247, 16,  6,  0 },
    {     94,   47, -248, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_929A70, {
    {     16,    0,   16, 24, 16,  0 }, {     16,    1,   16, 24, 16,  0 }, {     16,    2,   16, 24, 16,  0 }, {     16,    3,   16, 24, 16,  0 }, {     16,    4,   16, 24, 16,  0 },
    {     16,    5,   16, 24, 16,  0 }, {     16,    6,   16, 24, 16,  0 }, {     16,    7,   16, 24, 16,  0 }, {     16,    8,   15, 24, 16,  0 }, {     16,    9,   15, 24, 16,  0 },
    {     17,   10,   15, 24, 16,  0 }, {     17,   11,   15, 24, 16,  0 }, {     17,   12,   14, 24, 16,  0 }, {     17,   13,   14, 24, 16,  0 }, {     17,   14,   14, 24, 16,  0 },
    {     17,   15,   13, 24, 23,  0 }, {     17,   16,   13, 24, 23,  0 }, {     17,   17,   12, 24, 23,  0 }, {     17,   18,   12, 24, 23,  0 }, {     17,   19,   11, 24, 23,  0 },
    {     18,   20,   11, 24, 23,  0 }, {     18,   21,   10, 24, 23,  0 }, {     18,   22,   10, 24, 23,  0 }, {     18,   23,    9, 24, 23,  0 }, {     18,   24,    8, 24, 23,  0 },
    {     18,   25,    8, 24, 23,  0 }, {     18,   26,    7, 24, 23,  0 }, {     18,   27,    6, 24, 23,  0 }, {     18,   28,    5, 24, 23,  0 }, {     18,   29,    5, 24, 23,  0 },
    {     19,   30,    4, 24, 22,  0 }, {     19,   31,    3, 24, 22,  0 }, {     19,   32,    2, 24, 22,  0 }, {     19,   33,    1, 24, 22,  0 }, {     19,   34,    0, 24, 22,  0 },
    {     19,   35,   -1, 24, 22,  0 }, {     19,   36,   -2, 24, 22,  0 }, {     19,   37,   -3, 24, 22,  0 }, {     19,   38,   -4, 24, 22,  0 }, {     20,   39,   -5, 24, 22,  0 },
    {     20,   40,   -6, 24, 22,  0 }, {     20,   40,   -7, 24, 22,  0 }, {     20,   41,   -8, 24, 22,  0 }, {     20,   42,   -9, 24, 21,  0 }, {     20,   43,  -10, 24, 21,  0 },
    {     20,   43,  -11, 24, 21,  0 }, {     20,   44,  -12, 24, 21,  0 }, {     20,   45,  -13, 24, 21,  0 }, {     20,   45,  -14, 24, 21,  0 }, {     21,   46,  -15, 24, 21,  0 },
    {     21,   47,  -16, 24, 21,  0 }, {     21,   47,  -17, 24, 21,  0 }, {     21,   48,  -18, 24, 21,  0 }, {     21,   48,  -19, 24, 21,  0 }, {     21,   49,  -20, 24, 21,  0 },
    {     21,   49,  -21, 24, 21,  0 }, {     21,   50,  -22, 24, 21,  0 }, {     21,   50,  -23, 24, 21,  0 }, {     21,   51,  -24, 24, 20,  0 }, {     22,   51,  -25, 24, 20,  0 },
    {     22,   52,  -26, 24, 20,  0 }, {     22,   52,  -27, 24, 20,  0 }, {     22,   53,  -28, 24, 20,  0 }, {     22,   53,  -29, 24, 20,  0 }, {     22,   53,  -30, 24, 20,  0 },
    {     22,   54,  -31, 24, 20,  0 }, {     22,   54,  -32, 24, 20,  0 }, {     22,   54,  -33, 24, 20,  0 }, {     22,   55,  -34, 24, 20,  0 }, {     23,   55,  -35, 24, 20,  0 },
    {     23,   56,  -36, 24, 20,  0 }, {     23,   56,  -37, 24, 20,  0 }, {     23,   56,  -38, 24, 20,  0 }, {     23,   57,  -39, 24, 19,  0 }, {     23,   57,  -40, 24, 19,  0 },
    {     23,   57,  -41, 24, 19,  0 }, {     23,   57,  -42, 24, 19,  0 }, {     23,   58,  -43, 24, 19,  0 }, {     24,   58,  -44, 24, 19,  0 }, {     24,   58,  -45, 24, 19,  0 },
    {     24,   58,  -46, 24, 19,  0 }, {     24,   59,  -47, 24, 19,  0 }, {     24,   59,  -48, 24, 19,  0 }, {     24,   59,  -49, 24, 19,  0 }, {     24,   59,  -50, 24, 19,  0 },
    {     24,   59,  -51, 24, 19,  0 }, {     24,   59,  -52, 24, 19,  0 }, {     24,   60,  -53, 24, 19,  0 }, {     25,   60,  -54, 24, 19,  0 }, {     25,   60,  -55, 24, 19,  0 },
    {     25,   60,  -56, 24, 19,  0 }, {     25,   60,  -57, 24, 19,  0 }, {     25,   60,  -58, 24, 19,  0 }, {     25,   60,  -59, 24, 19,  0 }, {     25,   60,  -60, 24, 19,  0 },
    {     25,   61,  -61, 24, 19,  0 }, {     25,   61,  -62, 24, 19,  0 }, {     25,   61,  -63, 24, 18,  0 }, {     26,   61,  -64, 24, 18,  0 }, {     26,   61,  -65, 24, 18,  0 },
    {     26,   61,  -66, 24, 18,  0 }, {     26,   61,  -67, 24, 18,  0 }, {     26,   61,  -68, 24, 18,  0 }, {     26,   61,  -69, 24, 18,  0 }, {     26,   61,  -70, 24, 18,  0 },
    {     26,   61,  -71, 24, 18,  0 }, {     26,   61,  -72, 24, 18,  0 }, {     27,   61,  -73, 24, 18,  0 }, {     27,   61,  -74, 24, 18,  0 }, {     27,   61,  -75, 24, 18,  0 },
    {     27,   61,  -76, 24, 18,  0 }, {     27,   61,  -77, 24, 18,  0 }, {     27,   61,  -78, 24, 18,  0 }, {     27,   61,  -79, 24, 18,  0 }, {     27,   61,  -80, 24, 18,  0 },
    {     27,   61,  -81, 24, 18,  0 }, {     27,   61,  -82, 24, 18,  0 }, {     28,   61,  -83, 24, 18,  0 }, {     28,   61,  -84, 24, 18,  0 }, {     28,   61,  -85, 24, 18,  0 },
    {     28,   61,  -86, 24, 18,  0 }, {     28,   61,  -87, 24, 18,  0 }, {     28,   61,  -88, 24, 18,  0 }, {     28,   61,  -89, 24, 18,  0 }, {     28,   61,  -90, 24, 18,  0 },
    {     28,   61,  -91, 24, 18,  0 }, {     28,   61,  -92, 24, 18,  0 }, {     29,   61,  -93, 24, 18,  0 }, {     29,   61,  -94, 24, 18,  0 }, {     29,   61,  -95, 24, 18,  0 },
    {     29,   61,  -96, 24, 18,  0 }, {     29,   61,  -97, 24, 18,  0 }, {     29,   61,  -98, 24, 18,  0 }, {     29,   61,  -99, 24, 18,  0 }, {     29,   61, -100, 24, 17,  0 },
    {     29,   61, -101, 24, 17,  0 }, {     29,   60, -102, 24, 17,  0 }, {     30,   60, -103, 24, 17,  0 }, {     30,   60, -104, 24, 17,  0 }, {     30,   60, -105, 24, 17,  0 },
    {     30,   60, -106, 24, 17,  0 }, {     30,   60, -107, 24, 17,  0 }, {     30,   59, -108, 24, 17,  0 }, {     30,   59, -109, 24, 17,  0 }, {     30,   59, -110, 24, 17,  0 },
    {     30,   59, -111, 24, 17,  0 }, {     31,   59, -112, 24, 17,  0 }, {     31,   59, -113, 24, 17,  0 }, {     31,   58, -114, 24, 17,  0 }, {     31,   58, -115, 24, 17,  0 },
    {     31,   58, -116, 24, 17,  0 }, {     31,   58, -117, 24, 17,  0 }, {     31,   58, -118, 24, 17,  0 }, {     31,   57, -119, 24, 17,  0 }, {     31,   57, -120, 24, 17,  0 },
    {     31,   57, -121, 24, 17,  0 }, {     32,   57, -122, 24, 17,  0 }, {     32,   56, -123, 24, 17,  0 }, {     32,   56, -124, 24, 17,  0 }, {     32,   56, -125, 24, 17,  0 },
    {     32,   55, -126, 24, 17,  0 }, {     32,   55, -127, 24, 17,  0 }, {     32,   55, -128, 24, 17,  0 }, {     32,   54, -129, 24, 17,  0 }, {     32,   54, -130, 24, 17,  0 },
    {     32,   54, -131, 24, 17,  0 }, {     33,   54, -132, 24, 17,  0 }, {     33,   53, -133, 24,  8,  0 }, {     33,   53, -134, 24,  8,  0 }, {     33,   53, -135, 24,  8,  0 },
    {     33,   52, -136, 24,  8,  0 }, {     33,   52, -137, 24,  8,  0 }, {     33,   51, -138, 24,  8,  0 }, {     33,   51, -139, 24,  8,  0 }, {     33,   50, -140, 24,  8,  0 },
    {     34,   50, -141, 24,  8,  0 }, {     34,   50, -142, 24,  8,  0 }, {     34,   49, -143, 24,  8,  0 }, {     34,   49, -144, 24,  8,  0 }, {     34,   48, -145, 24,  8,  0 },
    {     34,   48, -146, 24,  8,  0 }, {     34,   48, -147, 24,  8,  0 }, {     34,   47, -148, 24,  8,  0 }, {     34,   47, -149, 24,  8,  0 }, {     34,   46, -150, 24,  8,  0 },
    {     35,   46, -151, 24,  8,  0 }, {     35,   45, -152, 24,  8,  0 }, {     35,   45, -153, 24,  8,  0 }, {     35,   45, -154, 24,  8,  0 }, {     35,   44, -155, 24,  8,  0 },
    {     35,   44, -156, 24,  8,  0 }, {     35,   43, -157, 24,  8,  0 }, {     35,   43, -158, 24,  8,  0 }, {     35,   42, -159, 24,  8,  0 }, {     35,   42, -160, 24,  8,  0 },
    {     36,   41, -161, 24,  8,  0 }, {     36,   41, -162, 24,  8,  0 }, {     36,   40, -163, 24,  8,  0 }, {     36,   39, -164, 24,  8,  0 }, {     36,   39, -165, 24,  8,  0 },
    {     36,   38, -166, 24,  8,  0 }, {     36,   38, -167, 24,  8,  0 }, {     36,   37, -168, 24,  8,  0 }, {     36,   36, -169, 24,  7,  0 }, {     36,   36, -170, 24,  7,  0 },
    {     37,   35, -171, 24,  7,  0 }, {     37,   35, -172, 24,  7,  0 }, {     37,   34, -173, 24,  7,  0 }, {     37,   33, -174, 24,  7,  0 }, {     37,   33, -175, 24,  7,  0 },
    {     37,   32, -176, 24,  7,  0 }, {     37,   31, -177, 24,  7,  0 }, {     37,   31, -178, 24,  7,  0 }, {     37,   30, -179, 24,  7,  0 }, {     38,   29, -180, 24,  7,  0 },
    {     38,   28, -181, 24,  7,  0 }, {     38,   28, -182, 24,  7,  0 }, {     38,   27, -183, 24,  7,  0 }, {     38,   26, -184, 24,  7,  0 }, {     38,   26, -185, 24,  7,  0 },
    {     38,   25, -186, 24,  7,  0 }, {     38,   24, -187, 24,  7,  0 }, {     38,   24, -188, 24,  7,  0 }, {     38,   23, -189, 24,  7,  0 }, {     39,   22, -190, 24,  7,  0 },
    {     39,   21, -191, 24,  7,  0 }, {     39,   20, -192, 24,  7,  0 }, {     39,   19, -193, 24,  7,  0 }, {     39,   18, -194, 24,  7,  0 }, {     39,   17, -195, 24,  7,  0 },
    {     39,   17, -196, 24,  7,  0 }, {     39,   16, -197, 24,  7,  0 }, {     39,   15, -198, 24,  7,  0 }, {     39,   14, -199, 24,  7,  0 }, {     40,   13, -200, 24,  7,  0 },
    {     40,   12, -201, 24,  7,  0 }, {     40,   11, -202, 24,  7,  0 }, {     40,   10, -203, 24,  7,  0 }, {     40,    9, -204, 24,  7,  0 }, {     40,    8, -205, 24,  7,  0 },
    {     40,    7, -206, 24,  7,  0 }, {     40,    6, -206, 24,  7,  0 }, {     40,    5, -207, 24,  7,  0 }, {     41,    4, -208, 24,  7,  0 }, {     41,    3, -209, 24,  7,  0 },
    {     41,    2, -210, 24,  7,  0 }, {     41,    1, -211, 24,  7,  0 }, {     41,    0, -212, 24,  7,  0 }, {     41,   -1, -212, 24,  7,  0 }, {     41,   -2, -213, 24,  7,  0 },
    {     41,   -3, -214, 24,  6,  0 }, {     41,   -4, -215, 24,  6,  0 }, {     41,   -5, -215, 24,  6,  0 }, {     42,   -6, -216, 24,  6,  0 }, {     42,   -7, -217, 24,  6,  0 },
    {     42,   -8, -218, 24,  6,  0 }, {     42,   -9, -218, 24,  6,  0 }, {     42,  -10, -219, 24,  6,  0 }, {     42,  -11, -220, 24,  6,  0 }, {     42,  -12, -221, 24,  6,  0 },
    {     42,  -13, -221, 24,  6,  0 }, {     42,  -14, -222, 24,  6,  0 }, {     42,  -15, -223, 24,  6,  0 }, {     43,  -16, -223, 24,  6,  0 }, {     43,  -17, -224, 24,  6,  0 },
    {     43,  -18, -224, 24,  6,  0 }, {     43,  -19, -225, 24,  6,  0 }, {     43,  -20, -226, 24,  6,  0 }, {     43,  -21, -226, 24,  6,  0 }, {     43,  -22, -227, 24,  6,  0 },
    {     43,  -23, -227, 24,  6,  0 }, {     43,  -24, -228, 24,  6,  0 }, {     43,  -25, -229, 24,  6,  0 }, {     44,  -26, -229, 24,  6,  0 }, {     44,  -27, -230, 24,  6,  0 },
    {     44,  -28, -230, 24,  6,  0 }, {     44,  -29, -231, 24,  6,  0 }, {     44,  -30, -231, 24,  6,  0 }, {     44,  -31, -232, 24,  6,  0 }, {     44,  -32, -232, 24,  6,  0 },
    {     44,  -33, -233, 24,  6,  0 }, {     44,  -34, -233, 24,  6,  0 }, {     45,  -35, -234, 24,  6,  0 }, {     45,  -36, -234, 24,  6,  0 }, {     45,  -37, -235, 24,  6,  0 },
    {     45,  -38, -235, 24,  6,  0 }, {     45,  -39, -236, 24,  6,  0 }, {     45,  -40, -236, 24,  6,  0 }, {     45,  -41, -237, 24,  6,  0 }, {     45,  -42, -237, 24,  6,  0 },
    {     45,  -43, -238, 24,  6,  0 }, {     45,  -44, -238, 24,  6,  0 }, {     46,  -45, -239, 24,  6,  0 }, {     46,  -46, -239, 24,  6,  0 }, {     46,  -47, -240, 24,  6,  0 },
    {     46,  -48, -240, 24,  6,  0 }, {     46,  -49, -241, 24,  6,  0 }, {     46,  -50, -241, 24,  6,  0 }, {     46,  -51, -242, 24,  6,  0 }, {     46,  -52, -242, 24,  6,  0 },
    {     46,  -53, -243, 24,  6,  0 }, {     46,  -54, -243, 24,  6,  0 }, {     47,  -55, -244, 24,  6,  0 }, {     47,  -56, -244, 24,  6,  0 }, {     47,  -57, -245, 24,  6,  0 },
    {     47,  -58, -245, 24,  6,  0 }, {     47,  -59, -246, 24,  6,  0 }, {     47,  -60, -246, 24,  6,  0 }, {     47,  -61, -247, 24,  6,  0 }, {     47,  -62, -247, 24,  6,  0 },
    {     47,  -63, -248, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92B064, {
    {      0,   16,   16,  0, 16,  0 }, {      1,   16,   16,  0, 16,  0 }, {      2,   16,   16,  0, 16,  0 }, {      3,   16,   16,  0, 16,  0 }, {      4,   16,   16,  0, 16,  0 },
    {      5,   16,   16,  0, 16,  0 }, {      6,   16,   16,  0, 16,  0 }, {      7,   16,   16,  0, 16,  0 }, {      8,   16,   15,  0, 16,  0 }, {      9,   16,   15,  0, 16,  0 },
    {     10,   15,   15,  0, 16,  0 }, {     11,   15,   15,  0, 16,  0 }, {     12,   15,   14,  0, 16,  0 }, {     13,   15,   14,  0, 16,  0 }, {     14,   15,   14,  0, 16,  0 },
    {     15,   15,   13,  0, 23,  0 }, {     16,   15,   13,  0, 23,  0 }, {     17,   15,   12,  0, 23,  0 }, {     18,   15,   12,  0, 23,  0 }, {     19,   15,   11,  0, 23,  0 },
    {     20,   14,   11,  0, 23,  0 }, {     21,   14,   10,  0, 23,  0 }, {     22,   14,   10,  0, 23,  0 }, {     23,   14,    9,  0, 23,  0 }, {     24,   14,    8,  0, 23,  0 },
    {     25,   14,    8,  0, 23,  0 }, {     26,   14,    7,  0, 23,  0 }, {     27,   14,    6,  0, 23,  0 }, {     28,   14,    5,  0, 23,  0 }, {     29,   14,    5,  0, 23,  0 },
    {     30,   13,    4,  0, 22,  0 }, {     31,   13,    3,  0, 22,  0 }, {     32,   13,    2,  0, 22,  0 }, {     33,   13,    1,  0, 22,  0 }, {     34,   13,    0,  0, 22,  0 },
    {     35,   13,   -1,  0, 22,  0 }, {     36,   13,   -2,  0, 22,  0 }, {     37,   13,   -3,  0, 22,  0 }, {     38,   13,   -4,  0, 22,  0 }, {     39,   12,   -5,  0, 22,  0 },
    {     40,   12,   -6,  0, 22,  0 }, {     40,   12,   -7,  0, 22,  0 }, {     41,   12,   -8,  0, 22,  0 }, {     42,   12,   -9,  0, 21,  0 }, {     43,   12,  -10,  0, 21,  0 },
    {     43,   12,  -11,  0, 21,  0 }, {     44,   12,  -12,  0, 21,  0 }, {     45,   12,  -13,  0, 21,  0 }, {     45,   12,  -14,  0, 21,  0 }, {     46,   11,  -15,  0, 21,  0 },
    {     47,   11,  -16,  0, 21,  0 }, {     47,   11,  -17,  0, 21,  0 }, {     48,   11,  -18,  0, 21,  0 }, {     48,   11,  -19,  0, 21,  0 }, {     49,   11,  -20,  0, 21,  0 },
    {     49,   11,  -21,  0, 21,  0 }, {     50,   11,  -22,  0, 21,  0 }, {     50,   11,  -23,  0, 21,  0 }, {     51,   11,  -24,  0, 20,  0 }, {     51,   10,  -25,  0, 20,  0 },
    {     52,   10,  -26,  0, 20,  0 }, {     52,   10,  -27,  0, 20,  0 }, {     53,   10,  -28,  0, 20,  0 }, {     53,   10,  -29,  0, 20,  0 }, {     53,   10,  -30,  0, 20,  0 },
    {     54,   10,  -31,  0, 20,  0 }, {     54,   10,  -32,  0, 20,  0 }, {     54,   10,  -33,  0, 20,  0 }, {     55,   10,  -34,  0, 20,  0 }, {     55,    9,  -35,  0, 20,  0 },
    {     56,    9,  -36,  0, 20,  0 }, {     56,    9,  -37,  0, 20,  0 }, {     56,    9,  -38,  0, 20,  0 }, {     57,    9,  -39,  0, 19,  0 }, {     57,    9,  -40,  0, 19,  0 },
    {     57,    9,  -41,  0, 19,  0 }, {     57,    9,  -42,  0, 19,  0 }, {     58,    9,  -43,  0, 19,  0 }, {     58,    8,  -44,  0, 19,  0 }, {     58,    8,  -45,  0, 19,  0 },
    {     58,    8,  -46,  0, 19,  0 }, {     59,    8,  -47,  0, 19,  0 }, {     59,    8,  -48,  0, 19,  0 }, {     59,    8,  -49,  0, 19,  0 }, {     59,    8,  -50,  0, 19,  0 },
    {     59,    8,  -51,  0, 19,  0 }, {     59,    8,  -52,  0, 19,  0 }, {     60,    8,  -53,  0, 19,  0 }, {     60,    7,  -54,  0, 19,  0 }, {     60,    7,  -55,  0, 19,  0 },
    {     60,    7,  -56,  0, 19,  0 }, {     60,    7,  -57,  0, 19,  0 }, {     60,    7,  -58,  0, 19,  0 }, {     60,    7,  -59,  0, 19,  0 }, {     60,    7,  -60,  0, 19,  0 },
    {     61,    7,  -61,  0, 19,  0 }, {     61,    7,  -62,  0, 19,  0 }, {     61,    7,  -63,  0, 18,  0 }, {     61,    6,  -64,  0, 18,  0 }, {     61,    6,  -65,  0, 18,  0 },
    {     61,    6,  -66,  0, 18,  0 }, {     61,    6,  -67,  0, 18,  0 }, {     61,    6,  -68,  0, 18,  0 }, {     61,    6,  -69,  0, 18,  0 }, {     61,    6,  -70,  0, 18,  0 },
    {     61,    6,  -71,  0, 18,  0 }, {     61,    6,  -72,  0, 18,  0 }, {     61,    5,  -73,  0, 18,  0 }, {     61,    5,  -74,  0, 18,  0 }, {     61,    5,  -75,  0, 18,  0 },
    {     61,    5,  -76,  0, 18,  0 }, {     61,    5,  -77,  0, 18,  0 }, {     61,    5,  -78,  0, 18,  0 }, {     61,    5,  -79,  0, 18,  0 }, {     61,    5,  -80,  0, 18,  0 },
    {     61,    5,  -81,  0, 18,  0 }, {     61,    5,  -82,  0, 18,  0 }, {     61,    4,  -83,  0, 18,  0 }, {     61,    4,  -84,  0, 18,  0 }, {     61,    4,  -85,  0, 18,  0 },
    {     61,    4,  -86,  0, 18,  0 }, {     61,    4,  -87,  0, 18,  0 }, {     61,    4,  -88,  0, 18,  0 }, {     61,    4,  -89,  0, 18,  0 }, {     61,    4,  -90,  0, 18,  0 },
    {     61,    4,  -91,  0, 18,  0 }, {     61,    4,  -92,  0, 18,  0 }, {     61,    3,  -93,  0, 18,  0 }, {     61,    3,  -94,  0, 18,  0 }, {     61,    3,  -95,  0, 18,  0 },
    {     61,    3,  -96,  0, 18,  0 }, {     61,    3,  -97,  0, 18,  0 }, {     61,    3,  -98,  0, 18,  0 }, {     61,    3,  -99,  0, 18,  0 }, {     61,    3, -100,  0, 17,  0 },
    {     61,    3, -101,  0, 17,  0 }, {     60,    3, -102,  0, 17,  0 }, {     60,    2, -103,  0, 17,  0 }, {     60,    2, -104,  0, 17,  0 }, {     60,    2, -105,  0, 17,  0 },
    {     60,    2, -106,  0, 17,  0 }, {     60,    2, -107,  0, 17,  0 }, {     59,    2, -108,  0, 17,  0 }, {     59,    2, -109,  0, 17,  0 }, {     59,    2, -110,  0, 17,  0 },
    {     59,    2, -111,  0, 17,  0 }, {     59,    1, -112,  0, 17,  0 }, {     59,    1, -113,  0, 17,  0 }, {     58,    1, -114,  0, 17,  0 }, {     58,    1, -115,  0, 17,  0 },
    {     58,    1, -116,  0, 17,  0 }, {     58,    1, -117,  0, 17,  0 }, {     58,    1, -118,  0, 17,  0 }, {     57,    1, -119,  0, 17,  0 }, {     57,    1, -120,  0, 17,  0 },
    {     57,    1, -121,  0, 17,  0 }, {     57,    0, -122,  0, 17,  0 }, {     56,    0, -123,  0, 17,  0 }, {     56,    0, -124,  0, 17,  0 }, {     56,    0, -125,  0, 17,  0 },
    {     55,    0, -126,  0, 17,  0 }, {     55,    0, -127,  0, 17,  0 }, {     55,    0, -128,  0, 17,  0 }, {     54,    0, -129,  0, 17,  0 }, {     54,    0, -130,  0, 17,  0 },
    {     54,    0, -131,  0, 17,  0 }, {     54,   -1, -132,  0, 17,  0 }, {     53,   -1, -133,  0,  8,  0 }, {     53,   -1, -134,  0,  8,  0 }, {     53,   -1, -135,  0,  8,  0 },
    {     52,   -1, -136,  0,  8,  0 }, {     52,   -1, -137,  0,  8,  0 }, {     51,   -1, -138,  0,  8,  0 }, {     51,   -1, -139,  0,  8,  0 }, {     50,   -1, -140,  0,  8,  0 },
    {     50,   -2, -141,  0,  8,  0 }, {     50,   -2, -142,  0,  8,  0 }, {     49,   -2, -143,  0,  8,  0 }, {     49,   -2, -144,  0,  8,  0 }, {     48,   -2, -145,  0,  8,  0 },
    {     48,   -2, -146,  0,  8,  0 }, {     48,   -2, -147,  0,  8,  0 }, {     47,   -2, -148,  0,  8,  0 }, {     47,   -2, -149,  0,  8,  0 }, {     46,   -2, -150,  0,  8,  0 },
    {     46,   -3, -151,  0,  8,  0 }, {     45,   -3, -152,  0,  8,  0 }, {     45,   -3, -153,  0,  8,  0 }, {     45,   -3, -154,  0,  8,  0 }, {     44,   -3, -155,  0,  8,  0 },
    {     44,   -3, -156,  0,  8,  0 }, {     43,   -3, -157,  0,  8,  0 }, {     43,   -3, -158,  0,  8,  0 }, {     42,   -3, -159,  0,  8,  0 }, {     42,   -3, -160,  0,  8,  0 },
    {     41,   -4, -161,  0,  8,  0 }, {     41,   -4, -162,  0,  8,  0 }, {     40,   -4, -163,  0,  8,  0 }, {     39,   -4, -164,  0,  8,  0 }, {     39,   -4, -165,  0,  8,  0 },
    {     38,   -4, -166,  0,  8,  0 }, {     38,   -4, -167,  0,  8,  0 }, {     37,   -4, -168,  0,  8,  0 }, {     36,   -4, -169,  0,  7,  0 }, {     36,   -4, -170,  0,  7,  0 },
    {     35,   -5, -171,  0,  7,  0 }, {     35,   -5, -172,  0,  7,  0 }, {     34,   -5, -173,  0,  7,  0 }, {     33,   -5, -174,  0,  7,  0 }, {     33,   -5, -175,  0,  7,  0 },
    {     32,   -5, -176,  0,  7,  0 }, {     31,   -5, -177,  0,  7,  0 }, {     31,   -5, -178,  0,  7,  0 }, {     30,   -5, -179,  0,  7,  0 }, {     29,   -6, -180,  0,  7,  0 },
    {     28,   -6, -181,  0,  7,  0 }, {     28,   -6, -182,  0,  7,  0 }, {     27,   -6, -183,  0,  7,  0 }, {     26,   -6, -184,  0,  7,  0 }, {     26,   -6, -185,  0,  7,  0 },
    {     25,   -6, -186,  0,  7,  0 }, {     24,   -6, -187,  0,  7,  0 }, {     24,   -6, -188,  0,  7,  0 }, {     23,   -6, -189,  0,  7,  0 }, {     22,   -7, -190,  0,  7,  0 },
    {     21,   -7, -191,  0,  7,  0 }, {     20,   -7, -192,  0,  7,  0 }, {     19,   -7, -193,  0,  7,  0 }, {     18,   -7, -194,  0,  7,  0 }, {     17,   -7, -195,  0,  7,  0 },
    {     17,   -7, -196,  0,  7,  0 }, {     16,   -7, -197,  0,  7,  0 }, {     15,   -7, -198,  0,  7,  0 }, {     14,   -7, -199,  0,  7,  0 }, {     13,   -8, -200,  0,  7,  0 },
    {     12,   -8, -201,  0,  7,  0 }, {     11,   -8, -202,  0,  7,  0 }, {     10,   -8, -203,  0,  7,  0 }, {      9,   -8, -204,  0,  7,  0 }, {      8,   -8, -205,  0,  7,  0 },
    {      7,   -8, -206,  0,  7,  0 }, {      6,   -8, -206,  0,  7,  0 }, {      5,   -8, -207,  0,  7,  0 }, {      4,   -9, -208,  0,  7,  0 }, {      3,   -9, -209,  0,  7,  0 },
    {      2,   -9, -210,  0,  7,  0 }, {      1,   -9, -211,  0,  7,  0 }, {      0,   -9, -212,  0,  7,  0 }, {     -1,   -9, -212,  0,  7,  0 }, {     -2,   -9, -213,  0,  7,  0 },
    {     -3,   -9, -214,  0,  6,  0 }, {     -4,   -9, -215,  0,  6,  0 }, {     -5,   -9, -215,  0,  6,  0 }, {     -6,  -10, -216,  0,  6,  0 }, {     -7,  -10, -217,  0,  6,  0 },
    {     -8,  -10, -218,  0,  6,  0 }, {     -9,  -10, -218,  0,  6,  0 }, {    -10,  -10, -219,  0,  6,  0 }, {    -11,  -10, -220,  0,  6,  0 }, {    -12,  -10, -221,  0,  6,  0 },
    {    -13,  -10, -221,  0,  6,  0 }, {    -14,  -10, -222,  0,  6,  0 }, {    -15,  -10, -223,  0,  6,  0 }, {    -16,  -11, -223,  0,  6,  0 }, {    -17,  -11, -224,  0,  6,  0 },
    {    -18,  -11, -224,  0,  6,  0 }, {    -19,  -11, -225,  0,  6,  0 }, {    -20,  -11, -226,  0,  6,  0 }, {    -21,  -11, -226,  0,  6,  0 }, {    -22,  -11, -227,  0,  6,  0 },
    {    -23,  -11, -227,  0,  6,  0 }, {    -24,  -11, -228,  0,  6,  0 }, {    -25,  -11, -229,  0,  6,  0 }, {    -26,  -12, -229,  0,  6,  0 }, {    -27,  -12, -230,  0,  6,  0 },
    {    -28,  -12, -230,  0,  6,  0 }, {    -29,  -12, -231,  0,  6,  0 }, {    -30,  -12, -231,  0,  6,  0 }, {    -31,  -12, -232,  0,  6,  0 }, {    -32,  -12, -232,  0,  6,  0 },
    {    -33,  -12, -233,  0,  6,  0 }, {    -34,  -12, -233,  0,  6,  0 }, {    -35,  -13, -234,  0,  6,  0 }, {    -36,  -13, -234,  0,  6,  0 }, {    -37,  -13, -235,  0,  6,  0 },
    {    -38,  -13, -235,  0,  6,  0 }, {    -39,  -13, -236,  0,  6,  0 }, {    -40,  -13, -236,  0,  6,  0 }, {    -41,  -13, -237,  0,  6,  0 }, {    -42,  -13, -237,  0,  6,  0 },
    {    -43,  -13, -238,  0,  6,  0 }, {    -44,  -13, -238,  0,  6,  0 }, {    -45,  -14, -239,  0,  6,  0 }, {    -46,  -14, -239,  0,  6,  0 }, {    -47,  -14, -240,  0,  6,  0 },
    {    -48,  -14, -240,  0,  6,  0 }, {    -49,  -14, -241,  0,  6,  0 }, {    -50,  -14, -241,  0,  6,  0 }, {    -51,  -14, -242,  0,  6,  0 }, {    -52,  -14, -242,  0,  6,  0 },
    {    -53,  -14, -243,  0,  6,  0 }, {    -54,  -14, -243,  0,  6,  0 }, {    -55,  -15, -244,  0,  6,  0 }, {    -56,  -15, -244,  0,  6,  0 }, {    -57,  -15, -245,  0,  6,  0 },
    {    -58,  -15, -245,  0,  6,  0 }, {    -59,  -15, -246,  0,  6,  0 }, {    -60,  -15, -246,  0,  6,  0 }, {    -61,  -15, -247,  0,  6,  0 }, {    -62,  -15, -247,  0,  6,  0 },
    {    -63,  -15, -248,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92C658, {
    {     16,   31,   16,  8, 16,  0 }, {     16,   30,   16,  8, 16,  0 }, {     16,   29,   16,  8, 16,  0 }, {     16,   28,   16,  8, 16,  0 }, {     16,   27,   16,  8, 16,  0 },
    {     16,   26,   16,  8, 16,  0 }, {     16,   25,   16,  8, 16,  0 }, {     16,   24,   16,  8, 16,  0 }, {     16,   23,   15,  8, 16,  0 }, {     16,   22,   15,  8, 16,  0 },
    {     15,   21,   15,  8, 16,  0 }, {     15,   20,   15,  8, 16,  0 }, {     15,   19,   14,  8, 16,  0 }, {     15,   18,   14,  8, 16,  0 }, {     15,   17,   14,  8, 16,  0 },
    {     15,   16,   13,  8, 23,  0 }, {     15,   15,   13,  8, 23,  0 }, {     15,   14,   12,  8, 23,  0 }, {     15,   13,   12,  8, 23,  0 }, {     15,   12,   11,  8, 23,  0 },
    {     14,   11,   11,  8, 23,  0 }, {     14,   10,   10,  8, 23,  0 }, {     14,    9,   10,  8, 23,  0 }, {     14,    8,    9,  8, 23,  0 }, {     14,    7,    8,  8, 23,  0 },
    {     14,    6,    8,  8, 23,  0 }, {     14,    5,    7,  8, 23,  0 }, {     14,    4,    6,  8, 23,  0 }, {     14,    3,    5,  8, 23,  0 }, {     14,    2,    5,  8, 23,  0 },
    {     13,    1,    4,  8, 22,  0 }, {     13,    0,    3,  8, 22,  0 }, {     13,   -1,    2,  8, 22,  0 }, {     13,   -2,    1,  8, 22,  0 }, {     13,   -3,    0,  8, 22,  0 },
    {     13,   -4,   -1,  8, 22,  0 }, {     13,   -5,   -2,  8, 22,  0 }, {     13,   -6,   -3,  8, 22,  0 }, {     13,   -7,   -4,  8, 22,  0 }, {     12,   -8,   -5,  8, 22,  0 },
    {     12,   -9,   -6,  8, 22,  0 }, {     12,   -9,   -7,  8, 22,  0 }, {     12,  -10,   -8,  8, 22,  0 }, {     12,  -11,   -9,  8, 21,  0 }, {     12,  -12,  -10,  8, 21,  0 },
    {     12,  -12,  -11,  8, 21,  0 }, {     12,  -13,  -12,  8, 21,  0 }, {     12,  -14,  -13,  8, 21,  0 }, {     12,  -14,  -14,  8, 21,  0 }, {     11,  -15,  -15,  8, 21,  0 },
    {     11,  -16,  -16,  8, 21,  0 }, {     11,  -16,  -17,  8, 21,  0 }, {     11,  -17,  -18,  8, 21,  0 }, {     11,  -17,  -19,  8, 21,  0 }, {     11,  -18,  -20,  8, 21,  0 },
    {     11,  -18,  -21,  8, 21,  0 }, {     11,  -19,  -22,  8, 21,  0 }, {     11,  -19,  -23,  8, 21,  0 }, {     11,  -20,  -24,  8, 20,  0 }, {     10,  -20,  -25,  8, 20,  0 },
    {     10,  -21,  -26,  8, 20,  0 }, {     10,  -21,  -27,  8, 20,  0 }, {     10,  -22,  -28,  8, 20,  0 }, {     10,  -22,  -29,  8, 20,  0 }, {     10,  -22,  -30,  8, 20,  0 },
    {     10,  -23,  -31,  8, 20,  0 }, {     10,  -23,  -32,  8, 20,  0 }, {     10,  -23,  -33,  8, 20,  0 }, {     10,  -24,  -34,  8, 20,  0 }, {      9,  -24,  -35,  8, 20,  0 },
    {      9,  -25,  -36,  8, 20,  0 }, {      9,  -25,  -37,  8, 20,  0 }, {      9,  -25,  -38,  8, 20,  0 }, {      9,  -26,  -39,  8, 19,  0 }, {      9,  -26,  -40,  8, 19,  0 },
    {      9,  -26,  -41,  8, 19,  0 }, {      9,  -26,  -42,  8, 19,  0 }, {      9,  -27,  -43,  8, 19,  0 }, {      8,  -27,  -44,  8, 19,  0 }, {      8,  -27,  -45,  8, 19,  0 },
    {      8,  -27,  -46,  8, 19,  0 }, {      8,  -28,  -47,  8, 19,  0 }, {      8,  -28,  -48,  8, 19,  0 }, {      8,  -28,  -49,  8, 19,  0 }, {      8,  -28,  -50,  8, 19,  0 },
    {      8,  -28,  -51,  8, 19,  0 }, {      8,  -28,  -52,  8, 19,  0 }, {      8,  -29,  -53,  8, 19,  0 }, {      7,  -29,  -54,  8, 19,  0 }, {      7,  -29,  -55,  8, 19,  0 },
    {      7,  -29,  -56,  8, 19,  0 }, {      7,  -29,  -57,  8, 19,  0 }, {      7,  -29,  -58,  8, 19,  0 }, {      7,  -29,  -59,  8, 19,  0 }, {      7,  -29,  -60,  8, 19,  0 },
    {      7,  -30,  -61,  8, 19,  0 }, {      7,  -30,  -62,  8, 19,  0 }, {      7,  -30,  -63,  8, 18,  0 }, {      6,  -30,  -64,  8, 18,  0 }, {      6,  -30,  -65,  8, 18,  0 },
    {      6,  -30,  -66,  8, 18,  0 }, {      6,  -30,  -67,  8, 18,  0 }, {      6,  -30,  -68,  8, 18,  0 }, {      6,  -30,  -69,  8, 18,  0 }, {      6,  -30,  -70,  8, 18,  0 },
    {      6,  -30,  -71,  8, 18,  0 }, {      6,  -30,  -72,  8, 18,  0 }, {      5,  -30,  -73,  8, 18,  0 }, {      5,  -30,  -74,  8, 18,  0 }, {      5,  -30,  -75,  8, 18,  0 },
    {      5,  -30,  -76,  8, 18,  0 }, {      5,  -30,  -77,  8, 18,  0 }, {      5,  -30,  -78,  8, 18,  0 }, {      5,  -30,  -79,  8, 18,  0 }, {      5,  -30,  -80,  8, 18,  0 },
    {      5,  -30,  -81,  8, 18,  0 }, {      5,  -30,  -82,  8, 18,  0 }, {      4,  -30,  -83,  8, 18,  0 }, {      4,  -30,  -84,  8, 18,  0 }, {      4,  -30,  -85,  8, 18,  0 },
    {      4,  -30,  -86,  8, 18,  0 }, {      4,  -30,  -87,  8, 18,  0 }, {      4,  -30,  -88,  8, 18,  0 }, {      4,  -30,  -89,  8, 18,  0 }, {      4,  -30,  -90,  8, 18,  0 },
    {      4,  -30,  -91,  8, 18,  0 }, {      4,  -30,  -92,  8, 18,  0 }, {      3,  -30,  -93,  8, 18,  0 }, {      3,  -30,  -94,  8, 18,  0 }, {      3,  -30,  -95,  8, 18,  0 },
    {      3,  -30,  -96,  8, 18,  0 }, {      3,  -30,  -97,  8, 18,  0 }, {      3,  -30,  -98,  8, 18,  0 }, {      3,  -30,  -99,  8, 18,  0 }, {      3,  -30, -100,  8, 17,  0 },
    {      3,  -30, -101,  8, 17,  0 }, {      3,  -29, -102,  8, 17,  0 }, {      2,  -29, -103,  8, 17,  0 }, {      2,  -29, -104,  8, 17,  0 }, {      2,  -29, -105,  8, 17,  0 },
    {      2,  -29, -106,  8, 17,  0 }, {      2,  -29, -107,  8, 17,  0 }, {      2,  -28, -108,  8, 17,  0 }, {      2,  -28, -109,  8, 17,  0 }, {      2,  -28, -110,  8, 17,  0 },
    {      2,  -28, -111,  8, 17,  0 }, {      1,  -28, -112,  8, 17,  0 }, {      1,  -28, -113,  8, 17,  0 }, {      1,  -27, -114,  8, 17,  0 }, {      1,  -27, -115,  8, 17,  0 },
    {      1,  -27, -116,  8, 17,  0 }, {      1,  -27, -117,  8, 17,  0 }, {      1,  -27, -118,  8, 17,  0 }, {      1,  -26, -119,  8, 17,  0 }, {      1,  -26, -120,  8, 17,  0 },
    {      1,  -26, -121,  8, 17,  0 }, {      0,  -26, -122,  8, 17,  0 }, {      0,  -25, -123,  8, 17,  0 }, {      0,  -25, -124,  8, 17,  0 }, {      0,  -25, -125,  8, 17,  0 },
    {      0,  -24, -126,  8, 17,  0 }, {      0,  -24, -127,  8, 17,  0 }, {      0,  -24, -128,  8, 17,  0 }, {      0,  -23, -129,  8, 17,  0 }, {      0,  -23, -130,  8, 17,  0 },
    {      0,  -23, -131,  8, 17,  0 }, {     -1,  -23, -132,  8, 17,  0 }, {     -1,  -22, -133,  8,  8,  0 }, {     -1,  -22, -134,  8,  8,  0 }, {     -1,  -22, -135,  8,  8,  0 },
    {     -1,  -21, -136,  8,  8,  0 }, {     -1,  -21, -137,  8,  8,  0 }, {     -1,  -20, -138,  8,  8,  0 }, {     -1,  -20, -139,  8,  8,  0 }, {     -1,  -19, -140,  8,  8,  0 },
    {     -2,  -19, -141,  8,  8,  0 }, {     -2,  -19, -142,  8,  8,  0 }, {     -2,  -18, -143,  8,  8,  0 }, {     -2,  -18, -144,  8,  8,  0 }, {     -2,  -17, -145,  8,  8,  0 },
    {     -2,  -17, -146,  8,  8,  0 }, {     -2,  -17, -147,  8,  8,  0 }, {     -2,  -16, -148,  8,  8,  0 }, {     -2,  -16, -149,  8,  8,  0 }, {     -2,  -15, -150,  8,  8,  0 },
    {     -3,  -15, -151,  8,  8,  0 }, {     -3,  -14, -152,  8,  8,  0 }, {     -3,  -14, -153,  8,  8,  0 }, {     -3,  -14, -154,  8,  8,  0 }, {     -3,  -13, -155,  8,  8,  0 },
    {     -3,  -13, -156,  8,  8,  0 }, {     -3,  -12, -157,  8,  8,  0 }, {     -3,  -12, -158,  8,  8,  0 }, {     -3,  -11, -159,  8,  8,  0 }, {     -3,  -11, -160,  8,  8,  0 },
    {     -4,  -10, -161,  8,  8,  0 }, {     -4,  -10, -162,  8,  8,  0 }, {     -4,   -9, -163,  8,  8,  0 }, {     -4,   -8, -164,  8,  8,  0 }, {     -4,   -8, -165,  8,  8,  0 },
    {     -4,   -7, -166,  8,  8,  0 }, {     -4,   -7, -167,  8,  8,  0 }, {     -4,   -6, -168,  8,  8,  0 }, {     -4,   -5, -169,  8,  7,  0 }, {     -4,   -5, -170,  8,  7,  0 },
    {     -5,   -4, -171,  8,  7,  0 }, {     -5,   -4, -172,  8,  7,  0 }, {     -5,   -3, -173,  8,  7,  0 }, {     -5,   -2, -174,  8,  7,  0 }, {     -5,   -2, -175,  8,  7,  0 },
    {     -5,   -1, -176,  8,  7,  0 }, {     -5,    0, -177,  8,  7,  0 }, {     -5,    0, -178,  8,  7,  0 }, {     -5,    1, -179,  8,  7,  0 }, {     -6,    2, -180,  8,  7,  0 },
    {     -6,    3, -181,  8,  7,  0 }, {     -6,    3, -182,  8,  7,  0 }, {     -6,    4, -183,  8,  7,  0 }, {     -6,    5, -184,  8,  7,  0 }, {     -6,    5, -185,  8,  7,  0 },
    {     -6,    6, -186,  8,  7,  0 }, {     -6,    7, -187,  8,  7,  0 }, {     -6,    7, -188,  8,  7,  0 }, {     -6,    8, -189,  8,  7,  0 }, {     -7,    9, -190,  8,  7,  0 },
    {     -7,   10, -191,  8,  7,  0 }, {     -7,   11, -192,  8,  7,  0 }, {     -7,   12, -193,  8,  7,  0 }, {     -7,   13, -194,  8,  7,  0 }, {     -7,   14, -195,  8,  7,  0 },
    {     -7,   14, -196,  8,  7,  0 }, {     -7,   15, -197,  8,  7,  0 }, {     -7,   16, -198,  8,  7,  0 }, {     -7,   17, -199,  8,  7,  0 }, {     -8,   18, -200,  8,  7,  0 },
    {     -8,   19, -201,  8,  7,  0 }, {     -8,   20, -202,  8,  7,  0 }, {     -8,   21, -203,  8,  7,  0 }, {     -8,   22, -204,  8,  7,  0 }, {     -8,   23, -205,  8,  7,  0 },
    {     -8,   24, -206,  8,  7,  0 }, {     -8,   25, -206,  8,  7,  0 }, {     -8,   26, -207,  8,  7,  0 }, {     -9,   27, -208,  8,  7,  0 }, {     -9,   28, -209,  8,  7,  0 },
    {     -9,   29, -210,  8,  7,  0 }, {     -9,   30, -211,  8,  7,  0 }, {     -9,   31, -212,  8,  7,  0 }, {     -9,   32, -212,  8,  7,  0 }, {     -9,   33, -213,  8,  7,  0 },
    {     -9,   34, -214,  8,  6,  0 }, {     -9,   35, -215,  8,  6,  0 }, {     -9,   36, -215,  8,  6,  0 }, {    -10,   37, -216,  8,  6,  0 }, {    -10,   38, -217,  8,  6,  0 },
    {    -10,   39, -218,  8,  6,  0 }, {    -10,   40, -218,  8,  6,  0 }, {    -10,   41, -219,  8,  6,  0 }, {    -10,   42, -220,  8,  6,  0 }, {    -10,   43, -221,  8,  6,  0 },
    {    -10,   44, -221,  8,  6,  0 }, {    -10,   45, -222,  8,  6,  0 }, {    -10,   46, -223,  8,  6,  0 }, {    -11,   47, -223,  8,  6,  0 }, {    -11,   48, -224,  8,  6,  0 },
    {    -11,   49, -224,  8,  6,  0 }, {    -11,   50, -225,  8,  6,  0 }, {    -11,   51, -226,  8,  6,  0 }, {    -11,   52, -226,  8,  6,  0 }, {    -11,   53, -227,  8,  6,  0 },
    {    -11,   54, -227,  8,  6,  0 }, {    -11,   55, -228,  8,  6,  0 }, {    -11,   56, -229,  8,  6,  0 }, {    -12,   57, -229,  8,  6,  0 }, {    -12,   58, -230,  8,  6,  0 },
    {    -12,   59, -230,  8,  6,  0 }, {    -12,   60, -231,  8,  6,  0 }, {    -12,   61, -231,  8,  6,  0 }, {    -12,   62, -232,  8,  6,  0 }, {    -12,   63, -232,  8,  6,  0 },
    {    -12,   64, -233,  8,  6,  0 }, {    -12,   65, -233,  8,  6,  0 }, {    -13,   66, -234,  8,  6,  0 }, {    -13,   67, -234,  8,  6,  0 }, {    -13,   68, -235,  8,  6,  0 },
    {    -13,   69, -235,  8,  6,  0 }, {    -13,   70, -236,  8,  6,  0 }, {    -13,   71, -236,  8,  6,  0 }, {    -13,   72, -237,  8,  6,  0 }, {    -13,   73, -237,  8,  6,  0 },
    {    -13,   74, -238,  8,  6,  0 }, {    -13,   75, -238,  8,  6,  0 }, {    -14,   76, -239,  8,  6,  0 }, {    -14,   77, -239,  8,  6,  0 }, {    -14,   78, -240,  8,  6,  0 },
    {    -14,   79, -240,  8,  6,  0 }, {    -14,   80, -241,  8,  6,  0 }, {    -14,   81, -241,  8,  6,  0 }, {    -14,   82, -242,  8,  6,  0 }, {    -14,   83, -242,  8,  6,  0 },
    {    -14,   84, -243,  8,  6,  0 }, {    -14,   85, -243,  8,  6,  0 }, {    -15,   86, -244,  8,  6,  0 }, {    -15,   87, -244,  8,  6,  0 }, {    -15,   88, -245,  8,  6,  0 },
    {    -15,   89, -245,  8,  6,  0 }, {    -15,   90, -246,  8,  6,  0 }, {    -15,   91, -246,  8,  6,  0 }, {    -15,   92, -247,  8,  6,  0 }, {    -15,   93, -247,  8,  6,  0 },
    {    -15,   94, -248,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DD21E, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0, 14 }, {     25,   16,    0,  0,  0, 14 }, {     24,   16,    0,  0,  0, 14 }, {     23,   16,    0,  0,  0, 14 }, {     22,   16,    0,  0,  0, 14 },
    {     21,   16,    0,  0,  0, 14 }, {     20,   16,    0,  0,  0, 14 }, {     19,   16,    0,  0,  0, 14 }, {     18,   16,    0,  0,  0, 14 }, {     17,   16,    0,  0,  0, 14 },
    {     16,   16,    0,  0,  0, 14 }, {     15,   16,    0,  0,  0, 14 }, {     14,   16,    0,  0,  0, 14 }, {     13,   16,    0,  0,  0, 13 }, {     12,   16,    0,  0,  0, 13 },
    {     11,   16,    0,  0,  0, 13 }, {     10,   16,    0,  0,  0, 13 }, {      9,   16,    0,  0,  0, 13 }, {      8,   16,    0,  0,  0, 13 }, {      7,   16,    0,  0,  0, 13 },
    {      6,   16,    0,  0,  0, 13 }, {      5,   16,    0,  0,  0, 13 }, {      4,   16,    0,  0,  0, 13 }, {      3,   16,    0,  0,  0, 13 }, {      2,   16,    0,  0,  0, 12 },
    {      1,   16,    0,  0,  0, 12 }, {      0,   16,    0,  0,  0, 12 }, {     -1,   16,    0,  0,  0, 12 }, {     -2,   16,    0,  0,  0, 12 }, {     -3,   16,    0,  0,  0, 12 },
    {     -4,   16,    0,  0,  0, 12 }, {     -5,   16,    0,  0,  0, 12 }, {     -6,   16,    0,  0,  0, 12 }, {     -7,   16,    0,  0,  0, 12 }, {     -8,   16,    0,  0,  0, 12 },
    {     -9,   16,    0,  0,  0, 12 }, {    -10,   16,    0,  0,  0, 12 }, {    -11,   16,    0,  0,  0, 11 }, {    -12,   16,    0,  0,  0, 11 }, {    -13,   16,    0,  0,  0, 11 },
    {    -14,   16,    0,  0,  0, 11 }, {    -15,   16,    0,  0,  0, 11 }, {    -16,   16,    0,  0,  0, 11 }, {    -17,   16,    0,  0,  0, 11 }, {    -18,   16,    0,  0,  0, 11 },
    {    -19,   16,    0,  0,  0, 11 }, {    -20,   16,    0,  0,  0, 11 }, {    -21,   16,    0,  0,  0, 11 }, {    -22,   16,    0,  0,  0, 10 }, {    -23,   16,    0,  0,  0, 10 },
    {    -24,   16,    0,  0,  0, 10 }, {    -25,   16,    0,  0,  0, 10 }, {    -26,   16,    0,  0,  0, 10 }, {    -27,   16,    0,  0,  0, 10 }, {    -28,   16,    0,  0,  0, 10 },
    {    -29,   16,    0,  0,  0, 10 }, {    -30,   16,    0,  0,  0, 10 }, {    -31,   16,    0,  0,  0, 10 }, {    -32,   16,    0,  0,  0, 10 }, {    -33,   16,    0,  0,  0, 10 },
    {    -34,   16,    0,  0,  0, 10 }, {    -35,   16,    0,  0,  0, 19 }, {    -36,   16,    0,  0,  0, 19 }, {    -37,   16,    0,  0,  0, 19 }, {    -38,   16,    0,  0,  0, 19 },
    {    -39,   16,    0,  0,  0, 19 }, {    -40,   16,    0,  0,  0, 19 }, {    -41,   16,    0,  0,  0, 19 }, {    -42,   16,    0,  0,  0, 19 }, {    -43,   16,    0,  0,  0, 19 },
    {    -44,   16,    0,  0,  0, 19 }, {    -45,   16,    0,  0,  0, 19 }, {    -46,   16,    0,  0,  0, 18 }, {    -47,   16,    0,  0,  0, 18 }, {    -48,   16,    0,  0,  0, 18 },
    {    -49,   16,    0,  0,  0, 18 }, {    -50,   16,    0,  0,  0, 18 }, {    -51,   16,    0,  0,  0, 18 }, {    -52,   16,    0,  0,  0, 18 }, {    -53,   16,    0,  0,  0, 18 },
    {    -54,   16,    0,  0,  0, 18 }, {    -55,   16,    0,  0,  0, 18 }, {    -56,   16,    0,  0,  0, 18 }, {    -57,   16,    0,  0,  0, 18 }, {    -58,   16,    0,  0,  0, 18 },
    {    -59,   16,    0, 16, 16,  0 }, {    -60,   16,    0, 16, 16,  0 }, {    -61,   16,    0, 16, 16,  0 }, {    -62,   16,    0, 16, 16,  0 }, {    -63,   16,    0, 16, 16,  0 },
    {    -64,   16,    0, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DD580, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0, 14 }, {     16,    6,    0,  8,  0, 14 }, {     16,    7,    0,  8,  0, 14 }, {     16,    8,    0,  8,  0, 14 }, {     16,    9,    0,  8,  0, 14 },
    {     16,   10,    0,  8,  0, 14 }, {     16,   11,    0,  8,  0, 14 }, {     16,   12,    0,  8,  0, 14 }, {     16,   13,    0,  8,  0, 14 }, {     16,   14,    0,  8,  0, 14 },
    {     16,   15,    0,  8,  0, 14 }, {     16,   16,    0,  8,  0, 14 }, {     16,   17,    0,  8,  0, 14 }, {     16,   18,    0,  8,  0, 13 }, {     16,   19,    0,  8,  0, 13 },
    {     16,   20,    0,  8,  0, 13 }, {     16,   21,    0,  8,  0, 13 }, {     16,   22,    0,  8,  0, 13 }, {     16,   23,    0,  8,  0, 13 }, {     16,   24,    0,  8,  0, 13 },
    {     16,   25,    0,  8,  0, 13 }, {     16,   26,    0,  8,  0, 13 }, {     16,   27,    0,  8,  0, 13 }, {     16,   28,    0,  8,  0, 13 }, {     16,   29,    0,  8,  0, 12 },
    {     16,   30,    0,  8,  0, 12 }, {     16,   31,    0,  8,  0, 12 }, {     16,   32,    0,  8,  0, 12 }, {     16,   33,    0,  8,  0, 12 }, {     16,   34,    0,  8,  0, 12 },
    {     16,   35,    0,  8,  0, 12 }, {     16,   36,    0,  8,  0, 12 }, {     16,   37,    0,  8,  0, 12 }, {     16,   38,    0,  8,  0, 12 }, {     16,   39,    0,  8,  0, 12 },
    {     16,   40,    0,  8,  0, 12 }, {     16,   41,    0,  8,  0, 12 }, {     16,   42,    0,  8,  0, 11 }, {     16,   43,    0,  8,  0, 11 }, {     16,   44,    0,  8,  0, 11 },
    {     16,   45,    0,  8,  0, 11 }, {     16,   46,    0,  8,  0, 11 }, {     16,   47,    0,  8,  0, 11 }, {     16,   48,    0,  8,  0, 11 }, {     16,   49,    0,  8,  0, 11 },
    {     16,   50,    0,  8,  0, 11 }, {     16,   51,    0,  8,  0, 11 }, {     16,   52,    0,  8,  0, 11 }, {     16,   53,    0,  8,  0, 10 }, {     16,   54,    0,  8,  0, 10 },
    {     16,   55,    0,  8,  0, 10 }, {     16,   56,    0,  8,  0, 10 }, {     16,   57,    0,  8,  0, 10 }, {     16,   58,    0,  8,  0, 10 }, {     16,   59,    0,  8,  0, 10 },
    {     16,   60,    0,  8,  0, 10 }, {     16,   61,    0,  8,  0, 10 }, {     16,   62,    0,  8,  0, 10 }, {     16,   63,    0,  8,  0, 10 }, {     16,   64,    0,  8,  0, 10 },
    {     16,   65,    0,  8,  0, 10 }, {     16,   66,    0,  8,  0, 19 }, {     16,   67,    0,  8,  0, 19 }, {     16,   68,    0,  8,  0, 19 }, {     16,   69,    0,  8,  0, 19 },
    {     16,   70,    0,  8,  0, 19 }, {     16,   71,    0,  8,  0, 19 }, {     16,   72,    0,  8,  0, 19 }, {     16,   73,    0,  8,  0, 19 }, {     16,   74,    0,  8,  0, 19 },
    {     16,   75,    0,  8,  0, 19 }, {     16,   76,    0,  8,  0, 19 }, {     16,   77,    0,  8,  0, 18 }, {     16,   78,    0,  8,  0, 18 }, {     16,   79,    0,  8,  0, 18 },
    {     16,   80,    0,  8,  0, 18 }, {     16,   81,    0,  8,  0, 18 }, {     16,   82,    0,  8,  0, 18 }, {     16,   83,    0,  8,  0, 18 }, {     16,   84,    0,  8,  0, 18 },
    {     16,   85,    0,  8,  0, 18 }, {     16,   86,    0,  8,  0, 18 }, {     16,   87,    0,  8,  0, 18 }, {     16,   88,    0,  8,  0, 18 }, {     16,   89,    0,  8,  0, 18 },
    {     16,   90,    0, 24, 16,  0 }, {     16,   91,    0, 24, 16,  0 }, {     16,   92,    0, 24, 16,  0 }, {     16,   93,    0, 24, 16,  0 }, {     16,   94,    0, 24, 16,  0 },
    {     16,   95,    0, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DD8E2, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0, 14 }, {      6,   16,    0, 16,  0, 14 }, {      7,   16,    0, 16,  0, 14 }, {      8,   16,    0, 16,  0, 14 }, {      9,   16,    0, 16,  0, 14 },
    {     10,   16,    0, 16,  0, 14 }, {     11,   16,    0, 16,  0, 14 }, {     12,   16,    0, 16,  0, 14 }, {     13,   16,    0, 16,  0, 14 }, {     14,   16,    0, 16,  0, 14 },
    {     15,   16,    0, 16,  0, 14 }, {     16,   16,    0, 16,  0, 14 }, {     17,   16,    0, 16,  0, 14 }, {     18,   16,    0, 16,  0, 13 }, {     19,   16,    0, 16,  0, 13 },
    {     20,   16,    0, 16,  0, 13 }, {     21,   16,    0, 16,  0, 13 }, {     22,   16,    0, 16,  0, 13 }, {     23,   16,    0, 16,  0, 13 }, {     24,   16,    0, 16,  0, 13 },
    {     25,   16,    0, 16,  0, 13 }, {     26,   16,    0, 16,  0, 13 }, {     27,   16,    0, 16,  0, 13 }, {     28,   16,    0, 16,  0, 13 }, {     29,   16,    0, 16,  0, 12 },
    {     30,   16,    0, 16,  0, 12 }, {     31,   16,    0, 16,  0, 12 }, {     32,   16,    0, 16,  0, 12 }, {     33,   16,    0, 16,  0, 12 }, {     34,   16,    0, 16,  0, 12 },
    {     35,   16,    0, 16,  0, 12 }, {     36,   16,    0, 16,  0, 12 }, {     37,   16,    0, 16,  0, 12 }, {     38,   16,    0, 16,  0, 12 }, {     39,   16,    0, 16,  0, 12 },
    {     40,   16,    0, 16,  0, 12 }, {     41,   16,    0, 16,  0, 12 }, {     42,   16,    0, 16,  0, 11 }, {     43,   16,    0, 16,  0, 11 }, {     44,   16,    0, 16,  0, 11 },
    {     45,   16,    0, 16,  0, 11 }, {     46,   16,    0, 16,  0, 11 }, {     47,   16,    0, 16,  0, 11 }, {     48,   16,    0, 16,  0, 11 }, {     49,   16,    0, 16,  0, 11 },
    {     50,   16,    0, 16,  0, 11 }, {     51,   16,    0, 16,  0, 11 }, {     52,   16,    0, 16,  0, 11 }, {     53,   16,    0, 16,  0, 10 }, {     54,   16,    0, 16,  0, 10 },
    {     55,   16,    0, 16,  0, 10 }, {     56,   16,    0, 16,  0, 10 }, {     57,   16,    0, 16,  0, 10 }, {     58,   16,    0, 16,  0, 10 }, {     59,   16,    0, 16,  0, 10 },
    {     60,   16,    0, 16,  0, 10 }, {     61,   16,    0, 16,  0, 10 }, {     62,   16,    0, 16,  0, 10 }, {     63,   16,    0, 16,  0, 10 }, {     64,   16,    0, 16,  0, 10 },
    {     65,   16,    0, 16,  0, 10 }, {     66,   16,    0, 16,  0, 19 }, {     67,   16,    0, 16,  0, 19 }, {     68,   16,    0, 16,  0, 19 }, {     69,   16,    0, 16,  0, 19 },
    {     70,   16,    0, 16,  0, 19 }, {     71,   16,    0, 16,  0, 19 }, {     72,   16,    0, 16,  0, 19 }, {     73,   16,    0, 16,  0, 19 }, {     74,   16,    0, 16,  0, 19 },
    {     75,   16,    0, 16,  0, 19 }, {     76,   16,    0, 16,  0, 19 }, {     77,   16,    0, 16,  0, 18 }, {     78,   16,    0, 16,  0, 18 }, {     79,   16,    0, 16,  0, 18 },
    {     80,   16,    0, 16,  0, 18 }, {     81,   16,    0, 16,  0, 18 }, {     82,   16,    0, 16,  0, 18 }, {     83,   16,    0, 16,  0, 18 }, {     84,   16,    0, 16,  0, 18 },
    {     85,   16,    0, 16,  0, 18 }, {     86,   16,    0, 16,  0, 18 }, {     87,   16,    0, 16,  0, 18 }, {     88,   16,    0, 16,  0, 18 }, {     89,   16,    0, 16,  0, 18 },
    {     90,   16,    0,  0, 16,  0 }, {     91,   16,    0,  0, 16,  0 }, {     92,   16,    0,  0, 16,  0 }, {     93,   16,    0,  0, 16,  0 }, {     94,   16,    0,  0, 16,  0 },
    {     95,   16,    0,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DDC44, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0, 14 }, {     16,   25,    0, 24,  0, 14 }, {     16,   24,    0, 24,  0, 14 }, {     16,   23,    0, 24,  0, 14 }, {     16,   22,    0, 24,  0, 14 },
    {     16,   21,    0, 24,  0, 14 }, {     16,   20,    0, 24,  0, 14 }, {     16,   19,    0, 24,  0, 14 }, {     16,   18,    0, 24,  0, 14 }, {     16,   17,    0, 24,  0, 14 },
    {     16,   16,    0, 24,  0, 14 }, {     16,   15,    0, 24,  0, 14 }, {     16,   14,    0, 24,  0, 14 }, {     16,   13,    0, 24,  0, 13 }, {     16,   12,    0, 24,  0, 13 },
    {     16,   11,    0, 24,  0, 13 }, {     16,   10,    0, 24,  0, 13 }, {     16,    9,    0, 24,  0, 13 }, {     16,    8,    0, 24,  0, 13 }, {     16,    7,    0, 24,  0, 13 },
    {     16,    6,    0, 24,  0, 13 }, {     16,    5,    0, 24,  0, 13 }, {     16,    4,    0, 24,  0, 13 }, {     16,    3,    0, 24,  0, 13 }, {     16,    2,    0, 24,  0, 12 },
    {     16,    1,    0, 24,  0, 12 }, {     16,    0,    0, 24,  0, 12 }, {     16,   -1,    0, 24,  0, 12 }, {     16,   -2,    0, 24,  0, 12 }, {     16,   -3,    0, 24,  0, 12 },
    {     16,   -4,    0, 24,  0, 12 }, {     16,   -5,    0, 24,  0, 12 }, {     16,   -6,    0, 24,  0, 12 }, {     16,   -7,    0, 24,  0, 12 }, {     16,   -8,    0, 24,  0, 12 },
    {     16,   -9,    0, 24,  0, 12 }, {     16,  -10,    0, 24,  0, 12 }, {     16,  -11,    0, 24,  0, 11 }, {     16,  -12,    0, 24,  0, 11 }, {     16,  -13,    0, 24,  0, 11 },
    {     16,  -14,    0, 24,  0, 11 }, {     16,  -15,    0, 24,  0, 11 }, {     16,  -16,    0, 24,  0, 11 }, {     16,  -17,    0, 24,  0, 11 }, {     16,  -18,    0, 24,  0, 11 },
    {     16,  -19,    0, 24,  0, 11 }, {     16,  -20,    0, 24,  0, 11 }, {     16,  -21,    0, 24,  0, 11 }, {     16,  -22,    0, 24,  0, 10 }, {     16,  -23,    0, 24,  0, 10 },
    {     16,  -24,    0, 24,  0, 10 }, {     16,  -25,    0, 24,  0, 10 }, {     16,  -26,    0, 24,  0, 10 }, {     16,  -27,    0, 24,  0, 10 }, {     16,  -28,    0, 24,  0, 10 },
    {     16,  -29,    0, 24,  0, 10 }, {     16,  -30,    0, 24,  0, 10 }, {     16,  -31,    0, 24,  0, 10 }, {     16,  -32,    0, 24,  0, 10 }, {     16,  -33,    0, 24,  0, 10 },
    {     16,  -34,    0, 24,  0, 10 }, {     16,  -35,    0, 24,  0, 19 }, {     16,  -36,    0, 24,  0, 19 }, {     16,  -37,    0, 24,  0, 19 }, {     16,  -38,    0, 24,  0, 19 },
    {     16,  -39,    0, 24,  0, 19 }, {     16,  -40,    0, 24,  0, 19 }, {     16,  -41,    0, 24,  0, 19 }, {     16,  -42,    0, 24,  0, 19 }, {     16,  -43,    0, 24,  0, 19 },
    {     16,  -44,    0, 24,  0, 19 }, {     16,  -45,    0, 24,  0, 19 }, {     16,  -46,    0, 24,  0, 18 }, {     16,  -47,    0, 24,  0, 18 }, {     16,  -48,    0, 24,  0, 18 },
    {     16,  -49,    0, 24,  0, 18 }, {     16,  -50,    0, 24,  0, 18 }, {     16,  -51,    0, 24,  0, 18 }, {     16,  -52,    0, 24,  0, 18 }, {     16,  -53,    0, 24,  0, 18 },
    {     16,  -54,    0, 24,  0, 18 }, {     16,  -55,    0, 24,  0, 18 }, {     16,  -56,    0, 24,  0, 18 }, {     16,  -57,    0, 24,  0, 18 }, {     16,  -58,    0, 24,  0, 18 },
    {     16,  -59,    0,  8, 16,  0 }, {     16,  -60,    0,  8, 16,  0 }, {     16,  -61,    0,  8, 16,  0 }, {     16,  -62,    0,  8, 16,  0 }, {     16,  -63,    0,  8, 16,  0 },
    {     16,  -64,    0,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DDFA6, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  9 }, {     25,   16,    0,  0,  0,  9 }, {     24,   16,    0,  0,  0,  9 }, {     23,   16,    0,  0,  0,  9 }, {     22,   16,    0,  0,  0,  9 },
    {     21,   16,    0,  0,  0,  9 }, {     20,   16,    0,  0,  0,  9 }, {     19,   16,    0,  0,  0,  9 }, {     18,   16,    0,  0,  0,  9 }, {     17,   16,    0,  0,  0,  9 },
    {     16,   16,    0,  0,  0,  9 }, {     15,   16,    0,  0,  0,  9 }, {     14,   16,    0,  0,  0,  9 }, {     13,   16,    0,  0,  0,  8 }, {     12,   16,    0,  0,  0,  8 },
    {     11,   16,    0,  0,  0,  8 }, {     10,   16,    0,  0,  0,  8 }, {      9,   16,    0,  0,  0,  8 }, {      8,   16,    0,  0,  0,  8 }, {      7,   16,    0,  0,  0,  8 },
    {      6,   16,    0,  0,  0,  8 }, {      5,   16,    0,  0,  0,  8 }, {      4,   16,    0,  0,  0,  8 }, {      3,   16,    0,  0,  0,  8 }, {      2,   16,    0,  0,  0,  7 },
    {      1,   16,    0,  0,  0,  7 }, {      0,   16,    0,  0,  0,  7 }, {     -1,   16,    0,  0,  0,  7 }, {     -2,   16,    0,  0,  0,  7 }, {     -3,   16,    0,  0,  0,  7 },
    {     -4,   16,    0,  0,  0,  7 }, {     -5,   16,    0,  0,  0,  7 }, {     -6,   16,    0,  0,  0,  7 }, {     -7,   16,    0,  0,  0,  7 }, {     -8,   16,    0,  0,  0,  7 },
    {     -9,   16,    0,  0,  0,  7 }, {    -10,   16,    0,  0,  0,  7 }, {    -11,   16,    0,  0,  0,  6 }, {    -12,   16,    0,  0,  0,  6 }, {    -13,   16,    0,  0,  0,  6 },
    {    -14,   16,    0,  0,  0,  6 }, {    -15,   16,    0,  0,  0,  6 }, {    -16,   16,    0,  0,  0,  6 }, {    -17,   16,    0,  0,  0,  6 }, {    -18,   16,    0,  0,  0,  6 },
    {    -19,   16,    0,  0,  0,  6 }, {    -20,   16,    0,  0,  0,  6 }, {    -21,   16,    0,  0,  0,  6 }, {    -22,   16,    0,  0,  0,  5 }, {    -23,   16,    0,  0,  0,  5 },
    {    -24,   16,    0,  0,  0,  5 }, {    -25,   16,    0,  0,  0,  5 }, {    -26,   16,    0,  0,  0,  5 }, {    -27,   16,    0,  0,  0,  5 }, {    -28,   16,    0,  0,  0,  5 },
    {    -29,   16,    0,  0,  0,  5 }, {    -30,   16,    0,  0,  0,  5 }, {    -31,   16,    0,  0,  0,  5 }, {    -32,   16,    0,  0,  0,  5 }, {    -33,   16,    0,  0,  0,  5 },
    {    -34,   16,    0,  0,  0,  5 }, {    -35,   16,    0,  0,  0, 17 }, {    -36,   16,    0,  0,  0, 17 }, {    -37,   16,    0,  0,  0, 17 }, {    -38,   16,    0,  0,  0, 17 },
    {    -39,   16,    0,  0,  0, 17 }, {    -40,   16,    0,  0,  0, 17 }, {    -41,   16,    0,  0,  0, 17 }, {    -42,   16,    0,  0,  0, 17 }, {    -43,   16,    0,  0,  0, 17 },
    {    -44,   16,    0,  0,  0, 17 }, {    -45,   16,    0,  0,  0, 17 }, {    -46,   16,    0,  0,  0, 16 }, {    -47,   16,    0,  0,  0, 16 }, {    -48,   16,    0,  0,  0, 16 },
    {    -49,   16,    0,  0,  0, 16 }, {    -50,   16,    0,  0,  0, 16 }, {    -51,   16,    0,  0,  0, 16 }, {    -52,   16,    0,  0,  0, 16 }, {    -53,   16,    0,  0,  0, 16 },
    {    -54,   16,    0,  0,  0, 16 }, {    -55,   16,    0,  0,  0, 16 }, {    -56,   16,    0,  0,  0, 16 }, {    -57,   16,    0,  0,  0, 16 }, {    -58,   16,    0,  0,  0, 16 },
    {    -59,   16,    0, 16, 16,  0 }, {    -60,   16,    0, 16, 16,  0 }, {    -61,   16,    0, 16, 16,  0 }, {    -62,   16,    0, 16, 16,  0 }, {    -63,   16,    0, 16, 16,  0 },
    {    -64,   16,    0, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DE308, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  9 }, {     16,    6,    0,  8,  0,  9 }, {     16,    7,    0,  8,  0,  9 }, {     16,    8,    0,  8,  0,  9 }, {     16,    9,    0,  8,  0,  9 },
    {     16,   10,    0,  8,  0,  9 }, {     16,   11,    0,  8,  0,  9 }, {     16,   12,    0,  8,  0,  9 }, {     16,   13,    0,  8,  0,  9 }, {     16,   14,    0,  8,  0,  9 },
    {     16,   15,    0,  8,  0,  9 }, {     16,   16,    0,  8,  0,  9 }, {     16,   17,    0,  8,  0,  9 }, {     16,   18,    0,  8,  0,  8 }, {     16,   19,    0,  8,  0,  8 },
    {     16,   20,    0,  8,  0,  8 }, {     16,   21,    0,  8,  0,  8 }, {     16,   22,    0,  8,  0,  8 }, {     16,   23,    0,  8,  0,  8 }, {     16,   24,    0,  8,  0,  8 },
    {     16,   25,    0,  8,  0,  8 }, {     16,   26,    0,  8,  0,  8 }, {     16,   27,    0,  8,  0,  8 }, {     16,   28,    0,  8,  0,  8 }, {     16,   29,    0,  8,  0,  7 },
    {     16,   30,    0,  8,  0,  7 }, {     16,   31,    0,  8,  0,  7 }, {     16,   32,    0,  8,  0,  7 }, {     16,   33,    0,  8,  0,  7 }, {     16,   34,    0,  8,  0,  7 },
    {     16,   35,    0,  8,  0,  7 }, {     16,   36,    0,  8,  0,  7 }, {     16,   37,    0,  8,  0,  7 }, {     16,   38,    0,  8,  0,  7 }, {     16,   39,    0,  8,  0,  7 },
    {     16,   40,    0,  8,  0,  7 }, {     16,   41,    0,  8,  0,  7 }, {     16,   42,    0,  8,  0,  6 }, {     16,   43,    0,  8,  0,  6 }, {     16,   44,    0,  8,  0,  6 },
    {     16,   45,    0,  8,  0,  6 }, {     16,   46,    0,  8,  0,  6 }, {     16,   47,    0,  8,  0,  6 }, {     16,   48,    0,  8,  0,  6 }, {     16,   49,    0,  8,  0,  6 },
    {     16,   50,    0,  8,  0,  6 }, {     16,   51,    0,  8,  0,  6 }, {     16,   52,    0,  8,  0,  6 }, {     16,   53,    0,  8,  0,  5 }, {     16,   54,    0,  8,  0,  5 },
    {     16,   55,    0,  8,  0,  5 }, {     16,   56,    0,  8,  0,  5 }, {     16,   57,    0,  8,  0,  5 }, {     16,   58,    0,  8,  0,  5 }, {     16,   59,    0,  8,  0,  5 },
    {     16,   60,    0,  8,  0,  5 }, {     16,   61,    0,  8,  0,  5 }, {     16,   62,    0,  8,  0,  5 }, {     16,   63,    0,  8,  0,  5 }, {     16,   64,    0,  8,  0,  5 },
    {     16,   65,    0,  8,  0,  5 }, {     16,   66,    0,  8,  0, 17 }, {     16,   67,    0,  8,  0, 17 }, {     16,   68,    0,  8,  0, 17 }, {     16,   69,    0,  8,  0, 17 },
    {     16,   70,    0,  8,  0, 17 }, {     16,   71,    0,  8,  0, 17 }, {     16,   72,    0,  8,  0, 17 }, {     16,   73,    0,  8,  0, 17 }, {     16,   74,    0,  8,  0, 17 },
    {     16,   75,    0,  8,  0, 17 }, {     16,   76,    0,  8,  0, 17 }, {     16,   77,    0,  8,  0, 16 }, {     16,   78,    0,  8,  0, 16 }, {     16,   79,    0,  8,  0, 16 },
    {     16,   80,    0,  8,  0, 16 }, {     16,   81,    0,  8,  0, 16 }, {     16,   82,    0,  8,  0, 16 }, {     16,   83,    0,  8,  0, 16 }, {     16,   84,    0,  8,  0, 16 },
    {     16,   85,    0,  8,  0, 16 }, {     16,   86,    0,  8,  0, 16 }, {     16,   87,    0,  8,  0, 16 }, {     16,   88,    0,  8,  0, 16 }, {     16,   89,    0,  8,  0, 16 },
    {     16,   90,    0, 24, 16,  0 }, {     16,   91,    0, 24, 16,  0 }, {     16,   92,    0, 24, 16,  0 }, {     16,   93,    0, 24, 16,  0 }, {     16,   94,    0, 24, 16,  0 },
    {     16,   95,    0, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DE66A, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  9 }, {      6,   16,    0, 16,  0,  9 }, {      7,   16,    0, 16,  0,  9 }, {      8,   16,    0, 16,  0,  9 }, {      9,   16,    0, 16,  0,  9 },
    {     10,   16,    0, 16,  0,  9 }, {     11,   16,    0, 16,  0,  9 }, {     12,   16,    0, 16,  0,  9 }, {     13,   16,    0, 16,  0,  9 }, {     14,   16,    0, 16,  0,  9 },
    {     15,   16,    0, 16,  0,  9 }, {     16,   16,    0, 16,  0,  9 }, {     17,   16,    0, 16,  0,  9 }, {     18,   16,    0, 16,  0,  8 }, {     19,   16,    0, 16,  0,  8 },
    {     20,   16,    0, 16,  0,  8 }, {     21,   16,    0, 16,  0,  8 }, {     22,   16,    0, 16,  0,  8 }, {     23,   16,    0, 16,  0,  8 }, {     24,   16,    0, 16,  0,  8 },
    {     25,   16,    0, 16,  0,  8 }, {     26,   16,    0, 16,  0,  8 }, {     27,   16,    0, 16,  0,  8 }, {     28,   16,    0, 16,  0,  8 }, {     29,   16,    0, 16,  0,  7 },
    {     30,   16,    0, 16,  0,  7 }, {     31,   16,    0, 16,  0,  7 }, {     32,   16,    0, 16,  0,  7 }, {     33,   16,    0, 16,  0,  7 }, {     34,   16,    0, 16,  0,  7 },
    {     35,   16,    0, 16,  0,  7 }, {     36,   16,    0, 16,  0,  7 }, {     37,   16,    0, 16,  0,  7 }, {     38,   16,    0, 16,  0,  7 }, {     39,   16,    0, 16,  0,  7 },
    {     40,   16,    0, 16,  0,  7 }, {     41,   16,    0, 16,  0,  7 }, {     42,   16,    0, 16,  0,  6 }, {     43,   16,    0, 16,  0,  6 }, {     44,   16,    0, 16,  0,  6 },
    {     45,   16,    0, 16,  0,  6 }, {     46,   16,    0, 16,  0,  6 }, {     47,   16,    0, 16,  0,  6 }, {     48,   16,    0, 16,  0,  6 }, {     49,   16,    0, 16,  0,  6 },
    {     50,   16,    0, 16,  0,  6 }, {     51,   16,    0, 16,  0,  6 }, {     52,   16,    0, 16,  0,  6 }, {     53,   16,    0, 16,  0,  5 }, {     54,   16,    0, 16,  0,  5 },
    {     55,   16,    0, 16,  0,  5 }, {     56,   16,    0, 16,  0,  5 }, {     57,   16,    0, 16,  0,  5 }, {     58,   16,    0, 16,  0,  5 }, {     59,   16,    0, 16,  0,  5 },
    {     60,   16,    0, 16,  0,  5 }, {     61,   16,    0, 16,  0,  5 }, {     62,   16,    0, 16,  0,  5 }, {     63,   16,    0, 16,  0,  5 }, {     64,   16,    0, 16,  0,  5 },
    {     65,   16,    0, 16,  0,  5 }, {     66,   16,    0, 16,  0, 17 }, {     67,   16,    0, 16,  0, 17 }, {     68,   16,    0, 16,  0, 17 }, {     69,   16,    0, 16,  0, 17 },
    {     70,   16,    0, 16,  0, 17 }, {     71,   16,    0, 16,  0, 17 }, {     72,   16,    0, 16,  0, 17 }, {     73,   16,    0, 16,  0, 17 }, {     74,   16,    0, 16,  0, 17 },
    {     75,   16,    0, 16,  0, 17 }, {     76,   16,    0, 16,  0, 17 }, {     77,   16,    0, 16,  0, 16 }, {     78,   16,    0, 16,  0, 16 }, {     79,   16,    0, 16,  0, 16 },
    {     80,   16,    0, 16,  0, 16 }, {     81,   16,    0, 16,  0, 16 }, {     82,   16,    0, 16,  0, 16 }, {     83,   16,    0, 16,  0, 16 }, {     84,   16,    0, 16,  0, 16 },
    {     85,   16,    0, 16,  0, 16 }, {     86,   16,    0, 16,  0, 16 }, {     87,   16,    0, 16,  0, 16 }, {     88,   16,    0, 16,  0, 16 }, {     89,   16,    0, 16,  0, 16 },
    {     90,   16,    0,  0, 16,  0 }, {     91,   16,    0,  0, 16,  0 }, {     92,   16,    0,  0, 16,  0 }, {     93,   16,    0,  0, 16,  0 }, {     94,   16,    0,  0, 16,  0 },
    {     95,   16,    0,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8DE9CC, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  9 }, {     16,   25,    0, 24,  0,  9 }, {     16,   24,    0, 24,  0,  9 }, {     16,   23,    0, 24,  0,  9 }, {     16,   22,    0, 24,  0,  9 },
    {     16,   21,    0, 24,  0,  9 }, {     16,   20,    0, 24,  0,  9 }, {     16,   19,    0, 24,  0,  9 }, {     16,   18,    0, 24,  0,  9 }, {     16,   17,    0, 24,  0,  9 },
    {     16,   16,    0, 24,  0,  9 }, {     16,   15,    0, 24,  0,  9 }, {     16,   14,    0, 24,  0,  9 }, {     16,   13,    0, 24,  0,  8 }, {     16,   12,    0, 24,  0,  8 },
    {     16,   11,    0, 24,  0,  8 }, {     16,   10,    0, 24,  0,  8 }, {     16,    9,    0, 24,  0,  8 }, {     16,    8,    0, 24,  0,  8 }, {     16,    7,    0, 24,  0,  8 },
    {     16,    6,    0, 24,  0,  8 }, {     16,    5,    0, 24,  0,  8 }, {     16,    4,    0, 24,  0,  8 }, {     16,    3,    0, 24,  0,  8 }, {     16,    2,    0, 24,  0,  7 },
    {     16,    1,    0, 24,  0,  7 }, {     16,    0,    0, 24,  0,  7 }, {     16,   -1,    0, 24,  0,  7 }, {     16,   -2,    0, 24,  0,  7 }, {     16,   -3,    0, 24,  0,  7 },
    {     16,   -4,    0, 24,  0,  7 }, {     16,   -5,    0, 24,  0,  7 }, {     16,   -6,    0, 24,  0,  7 }, {     16,   -7,    0, 24,  0,  7 }, {     16,   -8,    0, 24,  0,  7 },
    {     16,   -9,    0, 24,  0,  7 }, {     16,  -10,    0, 24,  0,  7 }, {     16,  -11,    0, 24,  0,  6 }, {     16,  -12,    0, 24,  0,  6 }, {     16,  -13,    0, 24,  0,  6 },
    {     16,  -14,    0, 24,  0,  6 }, {     16,  -15,    0, 24,  0,  6 }, {     16,  -16,    0, 24,  0,  6 }, {     16,  -17,    0, 24,  0,  6 }, {     16,  -18,    0, 24,  0,  6 },
    {     16,  -19,    0, 24,  0,  6 }, {     16,  -20,    0, 24,  0,  6 }, {     16,  -21,    0, 24,  0,  6 }, {     16,  -22,    0, 24,  0,  5 }, {     16,  -23,    0, 24,  0,  5 },
    {     16,  -24,    0, 24,  0,  5 }, {     16,  -25,    0, 24,  0,  5 }, {     16,  -26,    0, 24,  0,  5 }, {     16,  -27,    0, 24,  0,  5 }, {     16,  -28,    0, 24,  0,  5 },
    {     16,  -29,    0, 24,  0,  5 }, {     16,  -30,    0, 24,  0,  5 }, {     16,  -31,    0, 24,  0,  5 }, {     16,  -32,    0, 24,  0,  5 }, {     16,  -33,    0, 24,  0,  5 },
    {     16,  -34,    0, 24,  0,  5 }, {     16,  -35,    0, 24,  0, 17 }, {     16,  -36,    0, 24,  0, 17 }, {     16,  -37,    0, 24,  0, 17 }, {     16,  -38,    0, 24,  0, 17 },
    {     16,  -39,    0, 24,  0, 17 }, {     16,  -40,    0, 24,  0, 17 }, {     16,  -41,    0, 24,  0, 17 }, {     16,  -42,    0, 24,  0, 17 }, {     16,  -43,    0, 24,  0, 17 },
    {     16,  -44,    0, 24,  0, 17 }, {     16,  -45,    0, 24,  0, 17 }, {     16,  -46,    0, 24,  0, 16 }, {     16,  -47,    0, 24,  0, 16 }, {     16,  -48,    0, 24,  0, 16 },
    {     16,  -49,    0, 24,  0, 16 }, {     16,  -50,    0, 24,  0, 16 }, {     16,  -51,    0, 24,  0, 16 }, {     16,  -52,    0, 24,  0, 16 }, {     16,  -53,    0, 24,  0, 16 },
    {     16,  -54,    0, 24,  0, 16 }, {     16,  -55,    0, 24,  0, 16 }, {     16,  -56,    0, 24,  0, 16 }, {     16,  -57,    0, 24,  0, 16 }, {     16,  -58,    0, 24,  0, 16 },
    {     16,  -59,    0,  8, 16,  0 }, {     16,  -60,    0,  8, 16,  0 }, {     16,  -61,    0,  8, 16,  0 }, {     16,  -62,    0,  8, 16,  0 }, {     16,  -63,    0,  8, 16,  0 },
    {     16,  -64,    0,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E91A6, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0, 16, 23,  0 }, {     25,   16,   -1, 16, 23,  0 }, {     24,   16,   -1, 16, 23,  0 }, {     23,   16,   -1, 16, 23,  0 }, {     22,   16,   -2, 16, 23,  0 },
    {     21,   16,   -2, 16, 22,  0 }, {     20,   16,   -3, 16, 22,  0 }, {     19,   16,   -4, 16, 22,  0 }, {     18,   16,   -5, 16, 22,  0 }, {     17,   16,   -6, 16, 22,  0 },
    {     16,   16,   -6, 16, 21,  0 }, {     15,   16,   -7, 16, 21,  0 }, {     14,   16,   -8, 16, 21,  0 }, {     13,   16,   -9, 16, 21,  0 }, {     12,   16,  -10, 16, 21,  0 },
    {     11,   16,  -11, 16, 21,  0 }, {     10,   16,  -12, 16, 21,  0 }, {     10,   16,  -13, 16, 21,  0 }, {      9,   16,  -14, 16, 20,  0 }, {      8,   16,  -15, 16, 20,  0 },
    {      8,   16,  -16, 16, 20,  0 }, {      7,   16,  -17, 16, 20,  0 }, {      7,   16,  -18, 16, 20,  0 }, {      6,   16,  -19, 16, 20,  0 }, {      6,   16,  -20, 16, 20,  0 },
    {      6,   16,  -21, 16, 20,  0 }, {      5,   16,  -22, 16, 20,  0 }, {      5,   16,  -23, 16, 19,  0 }, {      4,   16,  -24, 16, 19,  0 }, {      4,   16,  -25, 16, 19,  0 },
    {      3,   16,  -26, 16, 19,  0 }, {      3,   16,  -27, 16, 19,  0 }, {      3,   16,  -28, 16, 19,  0 }, {      2,   16,  -29, 16, 19,  0 }, {      2,   16,  -30, 16, 19,  0 },
    {      2,   16,  -31, 16, 19,  0 }, {      2,   16,  -32, 16, 19,  0 }, {      1,   16,  -33, 16, 19,  0 }, {      1,   16,  -34, 16, 19,  0 }, {      1,   16,  -35, 16, 19,  0 },
    {      1,   16,  -36, 16, 19,  0 }, {      1,   16,  -37, 16, 18,  0 }, {      0,   16,  -38, 16, 18,  0 }, {      0,   16,  -39, 16, 18,  0 }, {      0,   16,  -40, 16, 18,  0 },
    {      0,   16,  -41, 16, 18,  0 }, {      0,   16,  -42, 16, 18,  0 }, {      0,   16,  -43, 16, 18,  0 }, {      0,   16,  -44, 16, 18,  0 }, {      0,   16,  -45, 16, 18,  0 },
    {      0,   16,  -46, 16, 18,  0 }, {      0,   16,  -47, 16, 18,  0 }, {      0,   16,  -48, 16, 18,  0 }, {      0,   16,  -49, 16, 18,  0 }, {      0,   16,  -50, 16, 18,  0 },
    {      0,   16,  -51, 16, 18,  0 }, {      0,   16,  -52, 16, 18,  0 }, {      0,   16,  -53, 16, 18,  0 }, {      0,   16,  -54, 16, 18,  0 }, {      0,   16,  -55, 16, 18,  0 },
    {      0,   16,  -56, 16, 18,  0 }, {      0,   16,  -57, 16, 18,  0 }, {      0,   16,  -58, 16, 18,  0 }, {      0,   16,  -59, 16, 18,  0 }, {      0,   16,  -60, 16, 18,  0 },
    {      0,   16,  -61, 16, 18,  0 }, {      0,   16,  -62, 16, 18,  0 }, {      0,   16,  -63, 16, 18,  0 }, {      0,   16,  -64, 16, 18,  0 }, {      0,   16,  -65, 16, 18,  0 },
    {      1,   16,  -66, 16, 18,  0 }, {      1,   16,  -67, 16, 18,  0 }, {      1,   16,  -68, 16, 18,  0 }, {      1,   16,  -69, 16, 18,  0 }, {      1,   16,  -70, 16, 17,  0 },
    {      2,   16,  -71, 16, 17,  0 }, {      2,   16,  -72, 16, 17,  0 }, {      2,   16,  -73, 16, 17,  0 }, {      2,   16,  -74, 16, 17,  0 }, {      3,   16,  -75, 16, 17,  0 },
    {      3,   16,  -76, 16, 17,  0 }, {      3,   16,  -77, 16, 17,  0 }, {      4,   16,  -78, 16, 17,  0 }, {      4,   16,  -79, 16, 17,  0 }, {      4,   16,  -80, 16, 17,  0 },
    {      5,   16,  -81, 16, 17,  0 }, {      5,   16,  -82, 16, 17,  0 }, {      5,   16,  -83, 16, 17,  0 }, {      6,   16,  -84, 16, 17,  0 }, {      6,   16,  -85, 16, 17,  0 },
    {      6,   16,  -86, 16, 17,  0 }, {      7,   16,  -87, 16, 17,  0 }, {      7,   16,  -88, 16, 17,  0 }, {      7,   16,  -89, 16, 17,  0 }, {      8,   16,  -90, 16, 17,  0 },
    {      8,   16,  -91, 16, 58,  0 }, {      9,   16,  -92, 16, 58,  0 }, {     10,   16,  -93, 16, 58,  0 }, {     10,   16,  -94, 16, 58,  0 }, {     11,   16,  -95, 16, 58,  0 },
    {     12,   16,  -96, 16, 58,  0 }, {     12,   16,  -97, 16, 58,  0 }, {     13,   16,  -98, 16, 58,  0 }, {     13,   16,  -99, 16, 58,  0 }, {     14,   16, -100, 16, 58,  0 },
    {     15,   16, -101, 16, 58,  0 }, {     16,   16, -102, 16, 58,  0 }, {     16,   16, -103, 16, 58,  0 }, {     17,   16, -104, 16, 58,  0 }, {     18,   16, -105, 16, 58,  0 },
    {     19,   16, -106, 16, 58,  0 }, {     19,   16, -107, 16, 57,  0 }, {     20,   16, -108, 16, 57,  0 }, {     21,   16, -109, 16, 57,  0 }, {     22,   16, -110, 16, 57,  0 },
    {     23,   16, -111, 16, 57,  0 }, {     24,   16, -112, 16, 57,  0 }, {     25,   16, -113, 16, 57,  0 }, {     26,   16, -114, 16, 57,  0 }, {     27,   16, -115, 16, 57,  0 },
    {     28,   16, -116, 16, 57,  0 }, {     29,   16, -117, 16, 57,  0 }, {     30,   16, -118, 16, 57,  0 }, {     31,   16, -118, 16, 57,  0 }, {     32,   16, -119, 16, 57,  0 },
    {     33,   16, -120, 16, 57,  0 }, {     34,   16, -121, 16, 57,  0 }, {     35,   16, -121, 16, 57,  0 }, {     36,   16, -122, 16, 57,  0 }, {     37,   16, -123, 16, 57,  0 },
    {     38,   16, -124, 16, 57,  0 }, {     39,   16, -125, 16, 57,  0 }, {     40,   16, -125, 16, 57,  0 }, {     41,   16, -126, 16, 57,  0 }, {     42,   16, -126, 16, 56,  0 },
    {     43,   16, -127, 16, 56,  0 }, {     44,   16, -127, 16, 56,  0 }, {     45,   16, -128, 16, 56,  0 }, {     46,   16, -128, 16, 56,  0 }, {     47,   16, -129, 16, 56,  0 },
    {     48,   16, -129, 16, 56,  0 }, {     49,   16, -130, 16, 56,  0 }, {     50,   16, -130, 16, 56,  0 }, {     51,   16, -131, 16, 56,  0 }, {     52,   16, -131, 16, 56,  0 },
    {     53,   16, -132, 16, 56,  0 }, {     54,   16, -132, 16, 56,  0 }, {     55,   16, -133, 16, 56,  0 }, {     56,   16, -133, 16, 56,  0 }, {     57,   16, -133, 16, 56,  0 },
    {     58,   16, -134, 16, 56,  0 }, {     59,   16, -134, 16, 56,  0 }, {     60,   16, -135, 16, 56,  0 }, {     61,   16, -135, 16, 56,  0 }, {     62,   16, -136, 16, 56,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E9751, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0, 24, 23,  0 }, {     16,    6,   -1, 24, 23,  0 }, {     16,    7,   -1, 24, 23,  0 }, {     16,    8,   -1, 24, 23,  0 }, {     16,    9,   -2, 24, 23,  0 },
    {     16,   10,   -2, 24, 22,  0 }, {     16,   11,   -3, 24, 22,  0 }, {     16,   12,   -4, 24, 22,  0 }, {     16,   13,   -5, 24, 22,  0 }, {     16,   14,   -6, 24, 22,  0 },
    {     16,   15,   -6, 24, 21,  0 }, {     16,   16,   -7, 24, 21,  0 }, {     16,   17,   -8, 24, 21,  0 }, {     16,   18,   -9, 24, 21,  0 }, {     16,   19,  -10, 24, 21,  0 },
    {     16,   20,  -11, 24, 21,  0 }, {     16,   21,  -12, 24, 21,  0 }, {     16,   21,  -13, 24, 21,  0 }, {     16,   22,  -14, 24, 20,  0 }, {     16,   23,  -15, 24, 20,  0 },
    {     16,   23,  -16, 24, 20,  0 }, {     16,   24,  -17, 24, 20,  0 }, {     16,   24,  -18, 24, 20,  0 }, {     16,   25,  -19, 24, 20,  0 }, {     16,   25,  -20, 24, 20,  0 },
    {     16,   25,  -21, 24, 20,  0 }, {     16,   26,  -22, 24, 20,  0 }, {     16,   26,  -23, 24, 19,  0 }, {     16,   27,  -24, 24, 19,  0 }, {     16,   27,  -25, 24, 19,  0 },
    {     16,   28,  -26, 24, 19,  0 }, {     16,   28,  -27, 24, 19,  0 }, {     16,   28,  -28, 24, 19,  0 }, {     16,   29,  -29, 24, 19,  0 }, {     16,   29,  -30, 24, 19,  0 },
    {     16,   29,  -31, 24, 19,  0 }, {     16,   29,  -32, 24, 19,  0 }, {     16,   30,  -33, 24, 19,  0 }, {     16,   30,  -34, 24, 19,  0 }, {     16,   30,  -35, 24, 19,  0 },
    {     16,   30,  -36, 24, 19,  0 }, {     16,   30,  -37, 24, 18,  0 }, {     16,   31,  -38, 24, 18,  0 }, {     16,   31,  -39, 24, 18,  0 }, {     16,   31,  -40, 24, 18,  0 },
    {     16,   31,  -41, 24, 18,  0 }, {     16,   31,  -42, 24, 18,  0 }, {     16,   31,  -43, 24, 18,  0 }, {     16,   31,  -44, 24, 18,  0 }, {     16,   31,  -45, 24, 18,  0 },
    {     16,   31,  -46, 24, 18,  0 }, {     16,   31,  -47, 24, 18,  0 }, {     16,   31,  -48, 24, 18,  0 }, {     16,   31,  -49, 24, 18,  0 }, {     16,   31,  -50, 24, 18,  0 },
    {     16,   31,  -51, 24, 18,  0 }, {     16,   31,  -52, 24, 18,  0 }, {     16,   31,  -53, 24, 18,  0 }, {     16,   31,  -54, 24, 18,  0 }, {     16,   31,  -55, 24, 18,  0 },
    {     16,   31,  -56, 24, 18,  0 }, {     16,   31,  -57, 24, 18,  0 }, {     16,   31,  -58, 24, 18,  0 }, {     16,   31,  -59, 24, 18,  0 }, {     16,   31,  -60, 24, 18,  0 },
    {     16,   31,  -61, 24, 18,  0 }, {     16,   31,  -62, 24, 18,  0 }, {     16,   31,  -63, 24, 18,  0 }, {     16,   31,  -64, 24, 18,  0 }, {     16,   31,  -65, 24, 18,  0 },
    {     16,   30,  -66, 24, 18,  0 }, {     16,   30,  -67, 24, 18,  0 }, {     16,   30,  -68, 24, 18,  0 }, {     16,   30,  -69, 24, 18,  0 }, {     16,   30,  -70, 24, 17,  0 },
    {     16,   29,  -71, 24, 17,  0 }, {     16,   29,  -72, 24, 17,  0 }, {     16,   29,  -73, 24, 17,  0 }, {     16,   29,  -74, 24, 17,  0 }, {     16,   28,  -75, 24, 17,  0 },
    {     16,   28,  -76, 24, 17,  0 }, {     16,   28,  -77, 24, 17,  0 }, {     16,   27,  -78, 24, 17,  0 }, {     16,   27,  -79, 24, 17,  0 }, {     16,   27,  -80, 24, 17,  0 },
    {     16,   26,  -81, 24, 17,  0 }, {     16,   26,  -82, 24, 17,  0 }, {     16,   26,  -83, 24, 17,  0 }, {     16,   25,  -84, 24, 17,  0 }, {     16,   25,  -85, 24, 17,  0 },
    {     16,   25,  -86, 24, 17,  0 }, {     16,   24,  -87, 24, 17,  0 }, {     16,   24,  -88, 24, 17,  0 }, {     16,   24,  -89, 24, 17,  0 }, {     16,   23,  -90, 24, 17,  0 },
    {     16,   23,  -91, 24, 58,  0 }, {     16,   22,  -92, 24, 58,  0 }, {     16,   21,  -93, 24, 58,  0 }, {     16,   21,  -94, 24, 58,  0 }, {     16,   20,  -95, 24, 58,  0 },
    {     16,   19,  -96, 24, 58,  0 }, {     16,   19,  -97, 24, 58,  0 }, {     16,   18,  -98, 24, 58,  0 }, {     16,   18,  -99, 24, 58,  0 }, {     16,   17, -100, 24, 58,  0 },
    {     16,   16, -101, 24, 58,  0 }, {     16,   15, -102, 24, 58,  0 }, {     16,   15, -103, 24, 58,  0 }, {     16,   14, -104, 24, 58,  0 }, {     16,   13, -105, 24, 58,  0 },
    {     16,   12, -106, 24, 58,  0 }, {     16,   12, -107, 24, 57,  0 }, {     16,   11, -108, 24, 57,  0 }, {     16,   10, -109, 24, 57,  0 }, {     16,    9, -110, 24, 57,  0 },
    {     16,    8, -111, 24, 57,  0 }, {     16,    7, -112, 24, 57,  0 }, {     16,    6, -113, 24, 57,  0 }, {     16,    5, -114, 24, 57,  0 }, {     16,    4, -115, 24, 57,  0 },
    {     16,    3, -116, 24, 57,  0 }, {     16,    2, -117, 24, 57,  0 }, {     16,    1, -118, 24, 57,  0 }, {     16,    0, -118, 24, 57,  0 }, {     16,   -1, -119, 24, 57,  0 },
    {     16,   -2, -120, 24, 57,  0 }, {     16,   -3, -121, 24, 57,  0 }, {     16,   -4, -121, 24, 57,  0 }, {     16,   -5, -122, 24, 57,  0 }, {     16,   -6, -123, 24, 57,  0 },
    {     16,   -7, -124, 24, 57,  0 }, {     16,   -8, -125, 24, 57,  0 }, {     16,   -9, -125, 24, 57,  0 }, {     16,  -10, -126, 24, 57,  0 }, {     16,  -11, -126, 24, 56,  0 },
    {     16,  -12, -127, 24, 56,  0 }, {     16,  -13, -127, 24, 56,  0 }, {     16,  -14, -128, 24, 56,  0 }, {     16,  -15, -128, 24, 56,  0 }, {     16,  -16, -129, 24, 56,  0 },
    {     16,  -17, -129, 24, 56,  0 }, {     16,  -18, -130, 24, 56,  0 }, {     16,  -19, -130, 24, 56,  0 }, {     16,  -20, -131, 24, 56,  0 }, {     16,  -21, -131, 24, 56,  0 },
    {     16,  -22, -132, 24, 56,  0 }, {     16,  -23, -132, 24, 56,  0 }, {     16,  -24, -133, 24, 56,  0 }, {     16,  -25, -133, 24, 56,  0 }, {     16,  -26, -133, 24, 56,  0 },
    {     16,  -27, -134, 24, 56,  0 }, {     16,  -28, -134, 24, 56,  0 }, {     16,  -29, -135, 24, 56,  0 }, {     16,  -30, -135, 24, 56,  0 }, {     16,  -31, -136, 24, 56,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8E9CFC, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0,  0, 23,  0 }, {      6,   16,   -1,  0, 23,  0 }, {      7,   16,   -1,  0, 23,  0 }, {      8,   16,   -1,  0, 23,  0 }, {      9,   16,   -2,  0, 23,  0 },
    {     10,   16,   -2,  0, 22,  0 }, {     11,   16,   -3,  0, 22,  0 }, {     12,   16,   -4,  0, 22,  0 }, {     13,   16,   -5,  0, 22,  0 }, {     14,   16,   -6,  0, 22,  0 },
    {     15,   16,   -6,  0, 21,  0 }, {     16,   16,   -7,  0, 21,  0 }, {     17,   16,   -8,  0, 21,  0 }, {     18,   16,   -9,  0, 21,  0 }, {     19,   16,  -10,  0, 21,  0 },
    {     20,   16,  -11,  0, 21,  0 }, {     21,   16,  -12,  0, 21,  0 }, {     21,   16,  -13,  0, 21,  0 }, {     22,   16,  -14,  0, 20,  0 }, {     23,   16,  -15,  0, 20,  0 },
    {     23,   16,  -16,  0, 20,  0 }, {     24,   16,  -17,  0, 20,  0 }, {     24,   16,  -18,  0, 20,  0 }, {     25,   16,  -19,  0, 20,  0 }, {     25,   16,  -20,  0, 20,  0 },
    {     25,   16,  -21,  0, 20,  0 }, {     26,   16,  -22,  0, 20,  0 }, {     26,   16,  -23,  0, 19,  0 }, {     27,   16,  -24,  0, 19,  0 }, {     27,   16,  -25,  0, 19,  0 },
    {     28,   16,  -26,  0, 19,  0 }, {     28,   16,  -27,  0, 19,  0 }, {     28,   16,  -28,  0, 19,  0 }, {     29,   16,  -29,  0, 19,  0 }, {     29,   16,  -30,  0, 19,  0 },
    {     29,   16,  -31,  0, 19,  0 }, {     29,   16,  -32,  0, 19,  0 }, {     30,   16,  -33,  0, 19,  0 }, {     30,   16,  -34,  0, 19,  0 }, {     30,   16,  -35,  0, 19,  0 },
    {     30,   16,  -36,  0, 19,  0 }, {     30,   16,  -37,  0, 18,  0 }, {     31,   16,  -38,  0, 18,  0 }, {     31,   16,  -39,  0, 18,  0 }, {     31,   16,  -40,  0, 18,  0 },
    {     31,   16,  -41,  0, 18,  0 }, {     31,   16,  -42,  0, 18,  0 }, {     31,   16,  -43,  0, 18,  0 }, {     31,   16,  -44,  0, 18,  0 }, {     31,   16,  -45,  0, 18,  0 },
    {     31,   16,  -46,  0, 18,  0 }, {     31,   16,  -47,  0, 18,  0 }, {     31,   16,  -48,  0, 18,  0 }, {     31,   16,  -49,  0, 18,  0 }, {     31,   16,  -50,  0, 18,  0 },
    {     31,   16,  -51,  0, 18,  0 }, {     31,   16,  -52,  0, 18,  0 }, {     31,   16,  -53,  0, 18,  0 }, {     31,   16,  -54,  0, 18,  0 }, {     31,   16,  -55,  0, 18,  0 },
    {     31,   16,  -56,  0, 18,  0 }, {     31,   16,  -57,  0, 18,  0 }, {     31,   16,  -58,  0, 18,  0 }, {     31,   16,  -59,  0, 18,  0 }, {     31,   16,  -60,  0, 18,  0 },
    {     31,   16,  -61,  0, 18,  0 }, {     31,   16,  -62,  0, 18,  0 }, {     31,   16,  -63,  0, 18,  0 }, {     31,   16,  -64,  0, 18,  0 }, {     31,   16,  -65,  0, 18,  0 },
    {     30,   16,  -66,  0, 18,  0 }, {     30,   16,  -67,  0, 18,  0 }, {     30,   16,  -68,  0, 18,  0 }, {     30,   16,  -69,  0, 18,  0 }, {     30,   16,  -70,  0, 17,  0 },
    {     29,   16,  -71,  0, 17,  0 }, {     29,   16,  -72,  0, 17,  0 }, {     29,   16,  -73,  0, 17,  0 }, {     29,   16,  -74,  0, 17,  0 }, {     28,   16,  -75,  0, 17,  0 },
    {     28,   16,  -76,  0, 17,  0 }, {     28,   16,  -77,  0, 17,  0 }, {     27,   16,  -78,  0, 17,  0 }, {     27,   16,  -79,  0, 17,  0 }, {     27,   16,  -80,  0, 17,  0 },
    {     26,   16,  -81,  0, 17,  0 }, {     26,   16,  -82,  0, 17,  0 }, {     26,   16,  -83,  0, 17,  0 }, {     25,   16,  -84,  0, 17,  0 }, {     25,   16,  -85,  0, 17,  0 },
    {     25,   16,  -86,  0, 17,  0 }, {     24,   16,  -87,  0, 17,  0 }, {     24,   16,  -88,  0, 17,  0 }, {     24,   16,  -89,  0, 17,  0 }, {     23,   16,  -90,  0, 17,  0 },
    {     23,   16,  -91,  0, 58,  0 }, {     22,   16,  -92,  0, 58,  0 }, {     21,   16,  -93,  0, 58,  0 }, {     21,   16,  -94,  0, 58,  0 }, {     20,   16,  -95,  0, 58,  0 },
    {     19,   16,  -96,  0, 58,  0 }, {     19,   16,  -97,  0, 58,  0 }, {     18,   16,  -98,  0, 58,  0 }, {     18,   16,  -99,  0, 58,  0 }, {     17,   16, -100,  0, 58,  0 },
    {     16,   16, -101,  0, 58,  0 }, {     15,   16, -102,  0, 58,  0 }, {     15,   16, -103,  0, 58,  0 }, {     14,   16, -104,  0, 58,  0 }, {     13,   16, -105,  0, 58,  0 },
    {     12,   16, -106,  0, 58,  0 }, {     12,   16, -107,  0, 57,  0 }, {     11,   16, -108,  0, 57,  0 }, {     10,   16, -109,  0, 57,  0 }, {      9,   16, -110,  0, 57,  0 },
    {      8,   16, -111,  0, 57,  0 }, {      7,   16, -112,  0, 57,  0 }, {      6,   16, -113,  0, 57,  0 }, {      5,   16, -114,  0, 57,  0 }, {      4,   16, -115,  0, 57,  0 },
    {      3,   16, -116,  0, 57,  0 }, {      2,   16, -117,  0, 57,  0 }, {      1,   16, -118,  0, 57,  0 }, {      0,   16, -118,  0, 57,  0 }, {     -1,   16, -119,  0, 57,  0 },
    {     -2,   16, -120,  0, 57,  0 }, {     -3,   16, -121,  0, 57,  0 }, {     -4,   16, -121,  0, 57,  0 }, {     -5,   16, -122,  0, 57,  0 }, {     -6,   16, -123,  0, 57,  0 },
    {     -7,   16, -124,  0, 57,  0 }, {     -8,   16, -125,  0, 57,  0 }, {     -9,   16, -125,  0, 57,  0 }, {    -10,   16, -126,  0, 57,  0 }, {    -11,   16, -126,  0, 56,  0 },
    {    -12,   16, -127,  0, 56,  0 }, {    -13,   16, -127,  0, 56,  0 }, {    -14,   16, -128,  0, 56,  0 }, {    -15,   16, -128,  0, 56,  0 }, {    -16,   16, -129,  0, 56,  0 },
    {    -17,   16, -129,  0, 56,  0 }, {    -18,   16, -130,  0, 56,  0 }, {    -19,   16, -130,  0, 56,  0 }, {    -20,   16, -131,  0, 56,  0 }, {    -21,   16, -131,  0, 56,  0 },
    {    -22,   16, -132,  0, 56,  0 }, {    -23,   16, -132,  0, 56,  0 }, {    -24,   16, -133,  0, 56,  0 }, {    -25,   16, -133,  0, 56,  0 }, {    -26,   16, -133,  0, 56,  0 },
    {    -27,   16, -134,  0, 56,  0 }, {    -28,   16, -134,  0, 56,  0 }, {    -29,   16, -135,  0, 56,  0 }, {    -30,   16, -135,  0, 56,  0 }, {    -31,   16, -136,  0, 56,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EA2A7, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0,  8, 23,  0 }, {     16,   25,   -1,  8, 23,  0 }, {     16,   24,   -1,  8, 23,  0 }, {     16,   23,   -1,  8, 23,  0 }, {     16,   22,   -2,  8, 23,  0 },
    {     16,   21,   -2,  8, 22,  0 }, {     16,   20,   -3,  8, 22,  0 }, {     16,   19,   -4,  8, 22,  0 }, {     16,   18,   -5,  8, 22,  0 }, {     16,   17,   -6,  8, 22,  0 },
    {     16,   16,   -6,  8, 21,  0 }, {     16,   15,   -7,  8, 21,  0 }, {     16,   14,   -8,  8, 21,  0 }, {     16,   13,   -9,  8, 21,  0 }, {     16,   12,  -10,  8, 21,  0 },
    {     16,   11,  -11,  8, 21,  0 }, {     16,   10,  -12,  8, 21,  0 }, {     16,   10,  -13,  8, 21,  0 }, {     16,    9,  -14,  8, 20,  0 }, {     16,    8,  -15,  8, 20,  0 },
    {     16,    8,  -16,  8, 20,  0 }, {     16,    7,  -17,  8, 20,  0 }, {     16,    7,  -18,  8, 20,  0 }, {     16,    6,  -19,  8, 20,  0 }, {     16,    6,  -20,  8, 20,  0 },
    {     16,    6,  -21,  8, 20,  0 }, {     16,    5,  -22,  8, 20,  0 }, {     16,    5,  -23,  8, 19,  0 }, {     16,    4,  -24,  8, 19,  0 }, {     16,    4,  -25,  8, 19,  0 },
    {     16,    3,  -26,  8, 19,  0 }, {     16,    3,  -27,  8, 19,  0 }, {     16,    3,  -28,  8, 19,  0 }, {     16,    2,  -29,  8, 19,  0 }, {     16,    2,  -30,  8, 19,  0 },
    {     16,    2,  -31,  8, 19,  0 }, {     16,    2,  -32,  8, 19,  0 }, {     16,    1,  -33,  8, 19,  0 }, {     16,    1,  -34,  8, 19,  0 }, {     16,    1,  -35,  8, 19,  0 },
    {     16,    1,  -36,  8, 19,  0 }, {     16,    1,  -37,  8, 18,  0 }, {     16,    0,  -38,  8, 18,  0 }, {     16,    0,  -39,  8, 18,  0 }, {     16,    0,  -40,  8, 18,  0 },
    {     16,    0,  -41,  8, 18,  0 }, {     16,    0,  -42,  8, 18,  0 }, {     16,    0,  -43,  8, 18,  0 }, {     16,    0,  -44,  8, 18,  0 }, {     16,    0,  -45,  8, 18,  0 },
    {     16,    0,  -46,  8, 18,  0 }, {     16,    0,  -47,  8, 18,  0 }, {     16,    0,  -48,  8, 18,  0 }, {     16,    0,  -49,  8, 18,  0 }, {     16,    0,  -50,  8, 18,  0 },
    {     16,    0,  -51,  8, 18,  0 }, {     16,    0,  -52,  8, 18,  0 }, {     16,    0,  -53,  8, 18,  0 }, {     16,    0,  -54,  8, 18,  0 }, {     16,    0,  -55,  8, 18,  0 },
    {     16,    0,  -56,  8, 18,  0 }, {     16,    0,  -57,  8, 18,  0 }, {     16,    0,  -58,  8, 18,  0 }, {     16,    0,  -59,  8, 18,  0 }, {     16,    0,  -60,  8, 18,  0 },
    {     16,    0,  -61,  8, 18,  0 }, {     16,    0,  -62,  8, 18,  0 }, {     16,    0,  -63,  8, 18,  0 }, {     16,    0,  -64,  8, 18,  0 }, {     16,    0,  -65,  8, 18,  0 },
    {     16,    1,  -66,  8, 18,  0 }, {     16,    1,  -67,  8, 18,  0 }, {     16,    1,  -68,  8, 18,  0 }, {     16,    1,  -69,  8, 18,  0 }, {     16,    1,  -70,  8, 17,  0 },
    {     16,    2,  -71,  8, 17,  0 }, {     16,    2,  -72,  8, 17,  0 }, {     16,    2,  -73,  8, 17,  0 }, {     16,    2,  -74,  8, 17,  0 }, {     16,    3,  -75,  8, 17,  0 },
    {     16,    3,  -76,  8, 17,  0 }, {     16,    3,  -77,  8, 17,  0 }, {     16,    4,  -78,  8, 17,  0 }, {     16,    4,  -79,  8, 17,  0 }, {     16,    4,  -80,  8, 17,  0 },
    {     16,    5,  -81,  8, 17,  0 }, {     16,    5,  -82,  8, 17,  0 }, {     16,    5,  -83,  8, 17,  0 }, {     16,    6,  -84,  8, 17,  0 }, {     16,    6,  -85,  8, 17,  0 },
    {     16,    6,  -86,  8, 17,  0 }, {     16,    7,  -87,  8, 17,  0 }, {     16,    7,  -88,  8, 17,  0 }, {     16,    7,  -89,  8, 17,  0 }, {     16,    8,  -90,  8, 17,  0 },
    {     16,    8,  -91,  8, 58,  0 }, {     16,    9,  -92,  8, 58,  0 }, {     16,   10,  -93,  8, 58,  0 }, {     16,   10,  -94,  8, 58,  0 }, {     16,   11,  -95,  8, 58,  0 },
    {     16,   12,  -96,  8, 58,  0 }, {     16,   12,  -97,  8, 58,  0 }, {     16,   13,  -98,  8, 58,  0 }, {     16,   13,  -99,  8, 58,  0 }, {     16,   14, -100,  8, 58,  0 },
    {     16,   15, -101,  8, 58,  0 }, {     16,   16, -102,  8, 58,  0 }, {     16,   16, -103,  8, 58,  0 }, {     16,   17, -104,  8, 58,  0 }, {     16,   18, -105,  8, 58,  0 },
    {     16,   19, -106,  8, 58,  0 }, {     16,   19, -107,  8, 57,  0 }, {     16,   20, -108,  8, 57,  0 }, {     16,   21, -109,  8, 57,  0 }, {     16,   22, -110,  8, 57,  0 },
    {     16,   23, -111,  8, 57,  0 }, {     16,   24, -112,  8, 57,  0 }, {     16,   25, -113,  8, 57,  0 }, {     16,   26, -114,  8, 57,  0 }, {     16,   27, -115,  8, 57,  0 },
    {     16,   28, -116,  8, 57,  0 }, {     16,   29, -117,  8, 57,  0 }, {     16,   30, -118,  8, 57,  0 }, {     16,   31, -118,  8, 57,  0 }, {     16,   32, -119,  8, 57,  0 },
    {     16,   33, -120,  8, 57,  0 }, {     16,   34, -121,  8, 57,  0 }, {     16,   35, -121,  8, 57,  0 }, {     16,   36, -122,  8, 57,  0 }, {     16,   37, -123,  8, 57,  0 },
    {     16,   38, -124,  8, 57,  0 }, {     16,   39, -125,  8, 57,  0 }, {     16,   40, -125,  8, 57,  0 }, {     16,   41, -126,  8, 57,  0 }, {     16,   42, -126,  8, 56,  0 },
    {     16,   43, -127,  8, 56,  0 }, {     16,   44, -127,  8, 56,  0 }, {     16,   45, -128,  8, 56,  0 }, {     16,   46, -128,  8, 56,  0 }, {     16,   47, -129,  8, 56,  0 },
    {     16,   48, -129,  8, 56,  0 }, {     16,   49, -130,  8, 56,  0 }, {     16,   50, -130,  8, 56,  0 }, {     16,   51, -131,  8, 56,  0 }, {     16,   52, -131,  8, 56,  0 },
    {     16,   53, -132,  8, 56,  0 }, {     16,   54, -132,  8, 56,  0 }, {     16,   55, -133,  8, 56,  0 }, {     16,   56, -133,  8, 56,  0 }, {     16,   57, -133,  8, 56,  0 },
    {     16,   58, -134,  8, 56,  0 }, {     16,   59, -134,  8, 56,  0 }, {     16,   60, -135,  8, 56,  0 }, {     16,   61, -135,  8, 56,  0 }, {     16,   62, -136,  8, 56,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EDF02, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,   -1,  0,  0,  0 }, {     24,   16,   -1,  0,  0,  0 }, {     23,   16,   -1, 24, 33,  0 }, {     22,   16,   -1, 24, 33,  0 },
    {     21,   16,   -1, 24, 33,  0 }, {     20,   16,   -2, 24, 33,  0 }, {     19,   16,   -2, 24, 33,  0 }, {     18,   16,   -2, 24, 33,  0 }, {     17,   16,   -3, 24, 33,  0 },
    {     16,   16,   -3, 24, 33,  0 }, {     15,   16,   -4, 24, 33,  0 }, {     14,   16,   -4, 24, 33,  0 }, {     13,   16,   -5, 24, 33,  0 }, {     12,   16,   -5, 24, 33,  0 },
    {     11,   16,   -6, 24, 33,  0 }, {     10,   16,   -6, 24, 33,  0 }, {      9,   16,   -7, 24, 33,  0 }, {      8,   16,   -8, 24, 33,  0 }, {      7,   16,   -9, 24, 32,  0 },
    {      6,   16,   -9, 24, 32,  0 }, {      5,   15,  -10, 24, 32,  0 }, {      4,   15,  -11, 24, 32,  0 }, {      3,   15,  -12, 24, 32,  0 }, {      2,   15,  -13, 24, 32,  0 },
    {      1,   15,  -14, 24, 32,  0 }, {      0,   15,  -15, 24, 32,  0 }, {     -1,   14,  -16, 24, 32,  0 }, {     -2,   14,  -17, 24, 32,  0 }, {     -2,   14,  -18, 24, 32,  0 },
    {     -3,   14,  -19, 24, 32,  0 }, {     -4,   14,  -20, 24, 32,  0 }, {     -5,   13,  -21, 24, 32,  0 }, {     -5,   13,  -22, 24, 32,  0 }, {     -6,   13,  -23, 24, 32,  0 },
    {     -6,   12,  -24, 24, 31,  0 }, {     -7,   12,  -25, 24, 31,  0 }, {     -8,   12,  -26, 24, 31,  0 }, {     -8,   12,  -27, 24, 31,  0 }, {     -9,   11,  -28, 24, 31,  0 },
    {     -9,   11,  -29, 24, 31,  0 }, {    -10,   10,  -30, 24, 31,  0 }, {    -10,   10,  -31, 24, 31,  0 }, {    -11,   10,  -32, 24, 31,  0 }, {    -11,    9,  -33, 24, 31,  0 },
    {    -11,    9,  -34, 24, 31,  0 }, {    -12,    8,  -35, 24, 31,  0 }, {    -12,    8,  -36, 24, 31,  0 }, {    -13,    7,  -37, 24, 31,  0 }, {    -13,    7,  -38, 24, 31,  0 },
    {    -13,    6,  -39, 24, 31,  0 }, {    -13,    5,  -40, 24, 31,  0 }, {    -14,    5,  -41, 24, 30,  0 }, {    -14,    4,  -42, 24, 30,  0 }, {    -14,    4,  -43, 24, 30,  0 },
    {    -15,    3,  -44, 24, 30,  0 }, {    -15,    2,  -45, 24, 30,  0 }, {    -15,    1,  -46, 24, 30,  0 }, {    -15,    1,  -47, 24, 30,  0 }, {    -15,    0,  -48, 24, 30,  0 },
    {    -16,   -1,  -49, 24, 30,  0 }, {    -16,   -2,  -50, 24, 30,  0 }, {    -16,   -3,  -51, 24, 30,  0 }, {    -16,   -4,  -52, 24, 30,  0 }, {    -16,   -5,  -53, 24, 30,  0 },
    {    -16,   -6,  -54, 24, 30,  0 }, {    -17,   -7,  -55, 24, 30,  0 }, {    -17,   -8,  -55, 24, 30,  0 }, {    -17,   -9,  -56, 24, 29,  0 }, {    -17,  -10,  -57, 24, 29,  0 },
    {    -17,  -11,  -58, 24, 29,  0 }, {    -17,  -12,  -58, 24, 29,  0 }, {    -17,  -13,  -59, 24, 29,  0 }, {    -17,  -14,  -59, 24, 29,  0 }, {    -17,  -15,  -60, 24, 29,  0 },
    {    -17,  -16,  -60, 24, 29,  0 }, {    -17,  -17,  -61, 24, 29,  0 }, {    -17,  -18,  -61, 24, 29,  0 }, {    -17,  -19,  -62, 24, 29,  0 }, {    -17,  -20,  -62, 24, 29,  0 },
    {    -17,  -21,  -62, 24, 29,  0 }, {    -17,  -22,  -63, 24, 29,  0 }, {    -17,  -23,  -63, 24, 29,  0 }, {    -17,  -24,  -63, 24, 29,  0 }, {    -17,  -25,  -63, 24, 29,  0 },
    {    -17,  -26,  -63,  8, 16,  0 }, {    -17,  -27,  -64,  8, 16,  0 }, {    -17,  -28,  -64,  8, 16,  0 }, {    -17,  -29,  -64,  8, 16,  0 }, {    -17,  -30,  -64,  8, 16,  0 },
    {    -17,  -31,  -64,  8, 16,  0 }, {    -17,  -32,  -64,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EE26D, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,   -1,  8,  0,  0 }, {     16,    7,   -1,  8,  0,  0 }, {     16,    8,   -1,  0, 33,  0 }, {     16,    9,   -1,  0, 33,  0 },
    {     16,   10,   -1,  0, 33,  0 }, {     16,   11,   -2,  0, 33,  0 }, {     16,   12,   -2,  0, 33,  0 }, {     16,   13,   -2,  0, 33,  0 }, {     16,   14,   -3,  0, 33,  0 },
    {     16,   15,   -3,  0, 33,  0 }, {     16,   16,   -4,  0, 33,  0 }, {     16,   17,   -4,  0, 33,  0 }, {     16,   18,   -5,  0, 33,  0 }, {     16,   19,   -5,  0, 33,  0 },
    {     16,   20,   -6,  0, 33,  0 }, {     16,   21,   -6,  0, 33,  0 }, {     16,   22,   -7,  0, 33,  0 }, {     16,   23,   -8,  0, 33,  0 }, {     16,   24,   -9,  0, 32,  0 },
    {     16,   25,   -9,  0, 32,  0 }, {     15,   26,  -10,  0, 32,  0 }, {     15,   27,  -11,  0, 32,  0 }, {     15,   28,  -12,  0, 32,  0 }, {     15,   29,  -13,  0, 32,  0 },
    {     15,   30,  -14,  0, 32,  0 }, {     15,   31,  -15,  0, 32,  0 }, {     14,   32,  -16,  0, 32,  0 }, {     14,   33,  -17,  0, 32,  0 }, {     14,   33,  -18,  0, 32,  0 },
    {     14,   34,  -19,  0, 32,  0 }, {     14,   35,  -20,  0, 32,  0 }, {     13,   36,  -21,  0, 32,  0 }, {     13,   36,  -22,  0, 32,  0 }, {     13,   37,  -23,  0, 32,  0 },
    {     12,   37,  -24,  0, 31,  0 }, {     12,   38,  -25,  0, 31,  0 }, {     12,   39,  -26,  0, 31,  0 }, {     12,   39,  -27,  0, 31,  0 }, {     11,   40,  -28,  0, 31,  0 },
    {     11,   40,  -29,  0, 31,  0 }, {     10,   41,  -30,  0, 31,  0 }, {     10,   41,  -31,  0, 31,  0 }, {     10,   42,  -32,  0, 31,  0 }, {      9,   42,  -33,  0, 31,  0 },
    {      9,   42,  -34,  0, 31,  0 }, {      8,   43,  -35,  0, 31,  0 }, {      8,   43,  -36,  0, 31,  0 }, {      7,   44,  -37,  0, 31,  0 }, {      7,   44,  -38,  0, 31,  0 },
    {      6,   44,  -39,  0, 31,  0 }, {      5,   44,  -40,  0, 31,  0 }, {      5,   45,  -41,  0, 30,  0 }, {      4,   45,  -42,  0, 30,  0 }, {      4,   45,  -43,  0, 30,  0 },
    {      3,   46,  -44,  0, 30,  0 }, {      2,   46,  -45,  0, 30,  0 }, {      1,   46,  -46,  0, 30,  0 }, {      1,   46,  -47,  0, 30,  0 }, {      0,   46,  -48,  0, 30,  0 },
    {     -1,   47,  -49,  0, 30,  0 }, {     -2,   47,  -50,  0, 30,  0 }, {     -3,   47,  -51,  0, 30,  0 }, {     -4,   47,  -52,  0, 30,  0 }, {     -5,   47,  -53,  0, 30,  0 },
    {     -6,   47,  -54,  0, 30,  0 }, {     -7,   48,  -55,  0, 30,  0 }, {     -8,   48,  -55,  0, 30,  0 }, {     -9,   48,  -56,  0, 29,  0 }, {    -10,   48,  -57,  0, 29,  0 },
    {    -11,   48,  -58,  0, 29,  0 }, {    -12,   48,  -58,  0, 29,  0 }, {    -13,   48,  -59,  0, 29,  0 }, {    -14,   48,  -59,  0, 29,  0 }, {    -15,   48,  -60,  0, 29,  0 },
    {    -16,   48,  -60,  0, 29,  0 }, {    -17,   48,  -61,  0, 29,  0 }, {    -18,   48,  -61,  0, 29,  0 }, {    -19,   48,  -62,  0, 29,  0 }, {    -20,   48,  -62,  0, 29,  0 },
    {    -21,   48,  -62,  0, 29,  0 }, {    -22,   48,  -63,  0, 29,  0 }, {    -23,   48,  -63,  0, 29,  0 }, {    -24,   48,  -63,  0, 29,  0 }, {    -25,   48,  -63,  0, 29,  0 },
    {    -26,   48,  -63, 16, 16,  0 }, {    -27,   48,  -64, 16, 16,  0 }, {    -28,   48,  -64, 16, 16,  0 }, {    -29,   48,  -64, 16, 16,  0 }, {    -30,   48,  -64, 16, 16,  0 },
    {    -31,   48,  -64, 16, 16,  0 }, {    -32,   48,  -64, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EE5D8, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,   -1, 16,  0,  0 }, {      7,   16,   -1, 16,  0,  0 }, {      8,   16,   -1,  8, 33,  0 }, {      9,   16,   -1,  8, 33,  0 },
    {     10,   16,   -1,  8, 33,  0 }, {     11,   16,   -2,  8, 33,  0 }, {     12,   16,   -2,  8, 33,  0 }, {     13,   16,   -2,  8, 33,  0 }, {     14,   16,   -3,  8, 33,  0 },
    {     15,   16,   -3,  8, 33,  0 }, {     16,   16,   -4,  8, 33,  0 }, {     17,   16,   -4,  8, 33,  0 }, {     18,   16,   -5,  8, 33,  0 }, {     19,   16,   -5,  8, 33,  0 },
    {     20,   16,   -6,  8, 33,  0 }, {     21,   16,   -6,  8, 33,  0 }, {     22,   16,   -7,  8, 33,  0 }, {     23,   16,   -8,  8, 33,  0 }, {     24,   16,   -9,  8, 32,  0 },
    {     25,   16,   -9,  8, 32,  0 }, {     26,   17,  -10,  8, 32,  0 }, {     27,   17,  -11,  8, 32,  0 }, {     28,   17,  -12,  8, 32,  0 }, {     29,   17,  -13,  8, 32,  0 },
    {     30,   17,  -14,  8, 32,  0 }, {     31,   17,  -15,  8, 32,  0 }, {     32,   18,  -16,  8, 32,  0 }, {     33,   18,  -17,  8, 32,  0 }, {     33,   18,  -18,  8, 32,  0 },
    {     34,   18,  -19,  8, 32,  0 }, {     35,   18,  -20,  8, 32,  0 }, {     36,   19,  -21,  8, 32,  0 }, {     36,   19,  -22,  8, 32,  0 }, {     37,   19,  -23,  8, 32,  0 },
    {     37,   20,  -24,  8, 31,  0 }, {     38,   20,  -25,  8, 31,  0 }, {     39,   20,  -26,  8, 31,  0 }, {     39,   20,  -27,  8, 31,  0 }, {     40,   21,  -28,  8, 31,  0 },
    {     40,   21,  -29,  8, 31,  0 }, {     41,   22,  -30,  8, 31,  0 }, {     41,   22,  -31,  8, 31,  0 }, {     42,   22,  -32,  8, 31,  0 }, {     42,   23,  -33,  8, 31,  0 },
    {     42,   23,  -34,  8, 31,  0 }, {     43,   24,  -35,  8, 31,  0 }, {     43,   24,  -36,  8, 31,  0 }, {     44,   25,  -37,  8, 31,  0 }, {     44,   25,  -38,  8, 31,  0 },
    {     44,   26,  -39,  8, 31,  0 }, {     44,   27,  -40,  8, 31,  0 }, {     45,   27,  -41,  8, 30,  0 }, {     45,   28,  -42,  8, 30,  0 }, {     45,   28,  -43,  8, 30,  0 },
    {     46,   29,  -44,  8, 30,  0 }, {     46,   30,  -45,  8, 30,  0 }, {     46,   31,  -46,  8, 30,  0 }, {     46,   31,  -47,  8, 30,  0 }, {     46,   32,  -48,  8, 30,  0 },
    {     47,   33,  -49,  8, 30,  0 }, {     47,   34,  -50,  8, 30,  0 }, {     47,   35,  -51,  8, 30,  0 }, {     47,   36,  -52,  8, 30,  0 }, {     47,   37,  -53,  8, 30,  0 },
    {     47,   38,  -54,  8, 30,  0 }, {     48,   39,  -55,  8, 30,  0 }, {     48,   40,  -55,  8, 30,  0 }, {     48,   41,  -56,  8, 29,  0 }, {     48,   42,  -57,  8, 29,  0 },
    {     48,   43,  -58,  8, 29,  0 }, {     48,   44,  -58,  8, 29,  0 }, {     48,   45,  -59,  8, 29,  0 }, {     48,   46,  -59,  8, 29,  0 }, {     48,   47,  -60,  8, 29,  0 },
    {     48,   48,  -60,  8, 29,  0 }, {     48,   49,  -61,  8, 29,  0 }, {     48,   50,  -61,  8, 29,  0 }, {     48,   51,  -62,  8, 29,  0 }, {     48,   52,  -62,  8, 29,  0 },
    {     48,   53,  -62,  8, 29,  0 }, {     48,   54,  -63,  8, 29,  0 }, {     48,   55,  -63,  8, 29,  0 }, {     48,   56,  -63,  8, 29,  0 }, {     48,   57,  -63,  8, 29,  0 },
    {     48,   58,  -63, 24, 16,  0 }, {     48,   59,  -64, 24, 16,  0 }, {     48,   60,  -64, 24, 16,  0 }, {     48,   61,  -64, 24, 16,  0 }, {     48,   62,  -64, 24, 16,  0 },
    {     48,   63,  -64, 24, 16,  0 }, {     48,   64,  -64, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EE943, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,   -1, 24,  0,  0 }, {     16,   24,   -1, 24,  0,  0 }, {     16,   23,   -1, 16, 33,  0 }, {     16,   22,   -1, 16, 33,  0 },
    {     16,   21,   -1, 16, 33,  0 }, {     16,   20,   -2, 16, 33,  0 }, {     16,   19,   -2, 16, 33,  0 }, {     16,   18,   -2, 16, 33,  0 }, {     16,   17,   -3, 16, 33,  0 },
    {     16,   16,   -3, 16, 33,  0 }, {     16,   15,   -4, 16, 33,  0 }, {     16,   14,   -4, 16, 33,  0 }, {     16,   13,   -5, 16, 33,  0 }, {     16,   12,   -5, 16, 33,  0 },
    {     16,   11,   -6, 16, 33,  0 }, {     16,   10,   -6, 16, 33,  0 }, {     16,    9,   -7, 16, 33,  0 }, {     16,    8,   -8, 16, 33,  0 }, {     16,    7,   -9, 16, 32,  0 },
    {     16,    6,   -9, 16, 32,  0 }, {     17,    5,  -10, 16, 32,  0 }, {     17,    4,  -11, 16, 32,  0 }, {     17,    3,  -12, 16, 32,  0 }, {     17,    2,  -13, 16, 32,  0 },
    {     17,    1,  -14, 16, 32,  0 }, {     17,    0,  -15, 16, 32,  0 }, {     18,   -1,  -16, 16, 32,  0 }, {     18,   -2,  -17, 16, 32,  0 }, {     18,   -2,  -18, 16, 32,  0 },
    {     18,   -3,  -19, 16, 32,  0 }, {     18,   -4,  -20, 16, 32,  0 }, {     19,   -5,  -21, 16, 32,  0 }, {     19,   -5,  -22, 16, 32,  0 }, {     19,   -6,  -23, 16, 32,  0 },
    {     20,   -6,  -24, 16, 31,  0 }, {     20,   -7,  -25, 16, 31,  0 }, {     20,   -8,  -26, 16, 31,  0 }, {     20,   -8,  -27, 16, 31,  0 }, {     21,   -9,  -28, 16, 31,  0 },
    {     21,   -9,  -29, 16, 31,  0 }, {     22,  -10,  -30, 16, 31,  0 }, {     22,  -10,  -31, 16, 31,  0 }, {     22,  -11,  -32, 16, 31,  0 }, {     23,  -11,  -33, 16, 31,  0 },
    {     23,  -11,  -34, 16, 31,  0 }, {     24,  -12,  -35, 16, 31,  0 }, {     24,  -12,  -36, 16, 31,  0 }, {     25,  -13,  -37, 16, 31,  0 }, {     25,  -13,  -38, 16, 31,  0 },
    {     26,  -13,  -39, 16, 31,  0 }, {     27,  -13,  -40, 16, 31,  0 }, {     27,  -14,  -41, 16, 30,  0 }, {     28,  -14,  -42, 16, 30,  0 }, {     28,  -14,  -43, 16, 30,  0 },
    {     29,  -15,  -44, 16, 30,  0 }, {     30,  -15,  -45, 16, 30,  0 }, {     31,  -15,  -46, 16, 30,  0 }, {     31,  -15,  -47, 16, 30,  0 }, {     32,  -15,  -48, 16, 30,  0 },
    {     33,  -16,  -49, 16, 30,  0 }, {     34,  -16,  -50, 16, 30,  0 }, {     35,  -16,  -51, 16, 30,  0 }, {     36,  -16,  -52, 16, 30,  0 }, {     37,  -16,  -53, 16, 30,  0 },
    {     38,  -16,  -54, 16, 30,  0 }, {     39,  -17,  -55, 16, 30,  0 }, {     40,  -17,  -55, 16, 30,  0 }, {     41,  -17,  -56, 16, 29,  0 }, {     42,  -17,  -57, 16, 29,  0 },
    {     43,  -17,  -58, 16, 29,  0 }, {     44,  -17,  -58, 16, 29,  0 }, {     45,  -17,  -59, 16, 29,  0 }, {     46,  -17,  -59, 16, 29,  0 }, {     47,  -17,  -60, 16, 29,  0 },
    {     48,  -17,  -60, 16, 29,  0 }, {     49,  -17,  -61, 16, 29,  0 }, {     50,  -17,  -61, 16, 29,  0 }, {     51,  -17,  -62, 16, 29,  0 }, {     52,  -17,  -62, 16, 29,  0 },
    {     53,  -17,  -62, 16, 29,  0 }, {     54,  -17,  -63, 16, 29,  0 }, {     55,  -17,  -63, 16, 29,  0 }, {     56,  -17,  -63, 16, 29,  0 }, {     57,  -17,  -63, 16, 29,  0 },
    {     58,  -17,  -63,  0, 16,  0 }, {     59,  -17,  -64,  0, 16,  0 }, {     60,  -17,  -64,  0, 16,  0 }, {     61,  -17,  -64,  0, 16,  0 }, {     62,  -17,  -64,  0, 16,  0 },
    {     63,  -17,  -64,  0, 16,  0 }, {     64,  -17,  -64,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EECAE, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,   -1,  0,  0,  0 }, {     24,   16,   -1,  0,  0,  0 }, {     23,   16,   -1,  8, 43,  0 }, {     22,   16,   -1,  8, 43,  0 },
    {     21,   16,   -1,  8, 43,  0 }, {     20,   16,   -2,  8, 43,  0 }, {     19,   16,   -2,  8, 43,  0 }, {     18,   16,   -2,  8, 43,  0 }, {     17,   16,   -3,  8, 43,  0 },
    {     16,   16,   -3,  8, 43,  0 }, {     15,   16,   -4,  8, 43,  0 }, {     14,   16,   -4,  8, 43,  0 }, {     13,   16,   -5,  8, 43,  0 }, {     12,   16,   -5,  8, 43,  0 },
    {     11,   16,   -6,  8, 43,  0 }, {     10,   16,   -6,  8, 43,  0 }, {      9,   16,   -7,  8, 43,  0 }, {      8,   16,   -8,  8, 43,  0 }, {      7,   16,   -9,  8, 42,  0 },
    {      6,   16,   -9,  8, 42,  0 }, {      5,   17,  -10,  8, 42,  0 }, {      4,   17,  -11,  8, 42,  0 }, {      3,   17,  -12,  8, 42,  0 }, {      2,   17,  -13,  8, 42,  0 },
    {      1,   17,  -14,  8, 42,  0 }, {      0,   17,  -15,  8, 42,  0 }, {     -1,   18,  -16,  8, 42,  0 }, {     -2,   18,  -17,  8, 42,  0 }, {     -2,   18,  -18,  8, 42,  0 },
    {     -3,   18,  -19,  8, 42,  0 }, {     -4,   18,  -20,  8, 42,  0 }, {     -5,   19,  -21,  8, 42,  0 }, {     -5,   19,  -22,  8, 42,  0 }, {     -6,   19,  -23,  8, 42,  0 },
    {     -6,   20,  -24,  8, 41,  0 }, {     -7,   20,  -25,  8, 41,  0 }, {     -8,   20,  -26,  8, 41,  0 }, {     -8,   20,  -27,  8, 41,  0 }, {     -9,   21,  -28,  8, 41,  0 },
    {     -9,   21,  -29,  8, 41,  0 }, {    -10,   22,  -30,  8, 41,  0 }, {    -10,   22,  -31,  8, 41,  0 }, {    -11,   22,  -32,  8, 41,  0 }, {    -11,   23,  -33,  8, 41,  0 },
    {    -11,   23,  -34,  8, 41,  0 }, {    -12,   24,  -35,  8, 41,  0 }, {    -12,   24,  -36,  8, 41,  0 }, {    -13,   25,  -37,  8, 41,  0 }, {    -13,   25,  -38,  8, 41,  0 },
    {    -13,   26,  -39,  8, 41,  0 }, {    -13,   27,  -40,  8, 41,  0 }, {    -14,   27,  -41,  8, 40,  0 }, {    -14,   28,  -42,  8, 40,  0 }, {    -14,   28,  -43,  8, 40,  0 },
    {    -15,   29,  -44,  8, 40,  0 }, {    -15,   30,  -45,  8, 40,  0 }, {    -15,   31,  -46,  8, 40,  0 }, {    -15,   31,  -47,  8, 40,  0 }, {    -15,   32,  -48,  8, 40,  0 },
    {    -16,   33,  -49,  8, 40,  0 }, {    -16,   34,  -50,  8, 40,  0 }, {    -16,   35,  -51,  8, 40,  0 }, {    -16,   36,  -52,  8, 40,  0 }, {    -16,   37,  -53,  8, 40,  0 },
    {    -16,   38,  -54,  8, 40,  0 }, {    -17,   39,  -55,  8, 40,  0 }, {    -17,   40,  -55,  8, 40,  0 }, {    -17,   41,  -56,  8, 39,  0 }, {    -17,   42,  -57,  8, 39,  0 },
    {    -17,   43,  -58,  8, 39,  0 }, {    -17,   44,  -58,  8, 39,  0 }, {    -17,   45,  -59,  8, 39,  0 }, {    -17,   46,  -59,  8, 39,  0 }, {    -17,   47,  -60,  8, 39,  0 },
    {    -17,   48,  -60,  8, 39,  0 }, {    -17,   49,  -61,  8, 39,  0 }, {    -17,   50,  -61,  8, 39,  0 }, {    -17,   51,  -62,  8, 39,  0 }, {    -17,   52,  -62,  8, 39,  0 },
    {    -17,   53,  -62,  8, 39,  0 }, {    -17,   54,  -63,  8, 39,  0 }, {    -17,   55,  -63,  8, 39,  0 }, {    -17,   56,  -63,  8, 39,  0 }, {    -17,   57,  -63,  8, 39,  0 },
    {    -17,   58,  -63, 24, 16,  0 }, {    -17,   59,  -64, 24, 16,  0 }, {    -17,   60,  -64, 24, 16,  0 }, {    -17,   61,  -64, 24, 16,  0 }, {    -17,   62,  -64, 24, 16,  0 },
    {    -17,   63,  -64, 24, 16,  0 }, {    -17,   64,  -64, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EF019, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,   -1,  8,  0,  0 }, {     16,    7,   -1,  8,  0,  0 }, {     16,    8,   -1, 16, 43,  0 }, {     16,    9,   -1, 16, 43,  0 },
    {     16,   10,   -1, 16, 43,  0 }, {     16,   11,   -2, 16, 43,  0 }, {     16,   12,   -2, 16, 43,  0 }, {     16,   13,   -2, 16, 43,  0 }, {     16,   14,   -3, 16, 43,  0 },
    {     16,   15,   -3, 16, 43,  0 }, {     16,   16,   -4, 16, 43,  0 }, {     16,   17,   -4, 16, 43,  0 }, {     16,   18,   -5, 16, 43,  0 }, {     16,   19,   -5, 16, 43,  0 },
    {     16,   20,   -6, 16, 43,  0 }, {     16,   21,   -6, 16, 43,  0 }, {     16,   22,   -7, 16, 43,  0 }, {     16,   23,   -8, 16, 43,  0 }, {     16,   24,   -9, 16, 42,  0 },
    {     16,   25,   -9, 16, 42,  0 }, {     17,   26,  -10, 16, 42,  0 }, {     17,   27,  -11, 16, 42,  0 }, {     17,   28,  -12, 16, 42,  0 }, {     17,   29,  -13, 16, 42,  0 },
    {     17,   30,  -14, 16, 42,  0 }, {     17,   31,  -15, 16, 42,  0 }, {     18,   32,  -16, 16, 42,  0 }, {     18,   33,  -17, 16, 42,  0 }, {     18,   33,  -18, 16, 42,  0 },
    {     18,   34,  -19, 16, 42,  0 }, {     18,   35,  -20, 16, 42,  0 }, {     19,   36,  -21, 16, 42,  0 }, {     19,   36,  -22, 16, 42,  0 }, {     19,   37,  -23, 16, 42,  0 },
    {     20,   37,  -24, 16, 41,  0 }, {     20,   38,  -25, 16, 41,  0 }, {     20,   39,  -26, 16, 41,  0 }, {     20,   39,  -27, 16, 41,  0 }, {     21,   40,  -28, 16, 41,  0 },
    {     21,   40,  -29, 16, 41,  0 }, {     22,   41,  -30, 16, 41,  0 }, {     22,   41,  -31, 16, 41,  0 }, {     22,   42,  -32, 16, 41,  0 }, {     23,   42,  -33, 16, 41,  0 },
    {     23,   42,  -34, 16, 41,  0 }, {     24,   43,  -35, 16, 41,  0 }, {     24,   43,  -36, 16, 41,  0 }, {     25,   44,  -37, 16, 41,  0 }, {     25,   44,  -38, 16, 41,  0 },
    {     26,   44,  -39, 16, 41,  0 }, {     27,   44,  -40, 16, 41,  0 }, {     27,   45,  -41, 16, 40,  0 }, {     28,   45,  -42, 16, 40,  0 }, {     28,   45,  -43, 16, 40,  0 },
    {     29,   46,  -44, 16, 40,  0 }, {     30,   46,  -45, 16, 40,  0 }, {     31,   46,  -46, 16, 40,  0 }, {     31,   46,  -47, 16, 40,  0 }, {     32,   46,  -48, 16, 40,  0 },
    {     33,   47,  -49, 16, 40,  0 }, {     34,   47,  -50, 16, 40,  0 }, {     35,   47,  -51, 16, 40,  0 }, {     36,   47,  -52, 16, 40,  0 }, {     37,   47,  -53, 16, 40,  0 },
    {     38,   47,  -54, 16, 40,  0 }, {     39,   48,  -55, 16, 40,  0 }, {     40,   48,  -55, 16, 40,  0 }, {     41,   48,  -56, 16, 39,  0 }, {     42,   48,  -57, 16, 39,  0 },
    {     43,   48,  -58, 16, 39,  0 }, {     44,   48,  -58, 16, 39,  0 }, {     45,   48,  -59, 16, 39,  0 }, {     46,   48,  -59, 16, 39,  0 }, {     47,   48,  -60, 16, 39,  0 },
    {     48,   48,  -60, 16, 39,  0 }, {     49,   48,  -61, 16, 39,  0 }, {     50,   48,  -61, 16, 39,  0 }, {     51,   48,  -62, 16, 39,  0 }, {     52,   48,  -62, 16, 39,  0 },
    {     53,   48,  -62, 16, 39,  0 }, {     54,   48,  -63, 16, 39,  0 }, {     55,   48,  -63, 16, 39,  0 }, {     56,   48,  -63, 16, 39,  0 }, {     57,   48,  -63, 16, 39,  0 },
    {     58,   48,  -63,  0, 16,  0 }, {     59,   48,  -64,  0, 16,  0 }, {     60,   48,  -64,  0, 16,  0 }, {     61,   48,  -64,  0, 16,  0 }, {     62,   48,  -64,  0, 16,  0 },
    {     63,   48,  -64,  0, 16,  0 }, {     64,   48,  -64,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EF384, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,   -1, 16,  0,  0 }, {      7,   16,   -1, 16,  0,  0 }, {      8,   16,   -1, 24, 43,  0 }, {      9,   16,   -1, 24, 43,  0 },
    {     10,   16,   -1, 24, 43,  0 }, {     11,   16,   -2, 24, 43,  0 }, {     12,   16,   -2, 24, 43,  0 }, {     13,   16,   -2, 24, 43,  0 }, {     14,   16,   -3, 24, 43,  0 },
    {     15,   16,   -3, 24, 43,  0 }, {     16,   16,   -4, 24, 43,  0 }, {     17,   16,   -4, 24, 43,  0 }, {     18,   16,   -5, 24, 43,  0 }, {     19,   16,   -5, 24, 43,  0 },
    {     20,   16,   -6, 24, 43,  0 }, {     21,   16,   -6, 24, 43,  0 }, {     22,   16,   -7, 24, 43,  0 }, {     23,   16,   -8, 24, 43,  0 }, {     24,   16,   -9, 24, 42,  0 },
    {     25,   16,   -9, 24, 42,  0 }, {     26,   15,  -10, 24, 42,  0 }, {     27,   15,  -11, 24, 42,  0 }, {     28,   15,  -12, 24, 42,  0 }, {     29,   15,  -13, 24, 42,  0 },
    {     30,   15,  -14, 24, 42,  0 }, {     31,   15,  -15, 24, 42,  0 }, {     32,   14,  -16, 24, 42,  0 }, {     33,   14,  -17, 24, 42,  0 }, {     33,   14,  -18, 24, 42,  0 },
    {     34,   14,  -19, 24, 42,  0 }, {     35,   14,  -20, 24, 42,  0 }, {     36,   13,  -21, 24, 42,  0 }, {     36,   13,  -22, 24, 42,  0 }, {     37,   13,  -23, 24, 42,  0 },
    {     37,   12,  -24, 24, 41,  0 }, {     38,   12,  -25, 24, 41,  0 }, {     39,   12,  -26, 24, 41,  0 }, {     39,   12,  -27, 24, 41,  0 }, {     40,   11,  -28, 24, 41,  0 },
    {     40,   11,  -29, 24, 41,  0 }, {     41,   10,  -30, 24, 41,  0 }, {     41,   10,  -31, 24, 41,  0 }, {     42,   10,  -32, 24, 41,  0 }, {     42,    9,  -33, 24, 41,  0 },
    {     42,    9,  -34, 24, 41,  0 }, {     43,    8,  -35, 24, 41,  0 }, {     43,    8,  -36, 24, 41,  0 }, {     44,    7,  -37, 24, 41,  0 }, {     44,    7,  -38, 24, 41,  0 },
    {     44,    6,  -39, 24, 41,  0 }, {     44,    5,  -40, 24, 41,  0 }, {     45,    5,  -41, 24, 40,  0 }, {     45,    4,  -42, 24, 40,  0 }, {     45,    4,  -43, 24, 40,  0 },
    {     46,    3,  -44, 24, 40,  0 }, {     46,    2,  -45, 24, 40,  0 }, {     46,    1,  -46, 24, 40,  0 }, {     46,    1,  -47, 24, 40,  0 }, {     46,    0,  -48, 24, 40,  0 },
    {     47,   -1,  -49, 24, 40,  0 }, {     47,   -2,  -50, 24, 40,  0 }, {     47,   -3,  -51, 24, 40,  0 }, {     47,   -4,  -52, 24, 40,  0 }, {     47,   -5,  -53, 24, 40,  0 },
    {     47,   -6,  -54, 24, 40,  0 }, {     48,   -7,  -55, 24, 40,  0 }, {     48,   -8,  -55, 24, 40,  0 }, {     48,   -9,  -56, 24, 39,  0 }, {     48,  -10,  -57, 24, 39,  0 },
    {     48,  -11,  -58, 24, 39,  0 }, {     48,  -12,  -58, 24, 39,  0 }, {     48,  -13,  -59, 24, 39,  0 }, {     48,  -14,  -59, 24, 39,  0 }, {     48,  -15,  -60, 24, 39,  0 },
    {     48,  -16,  -60, 24, 39,  0 }, {     48,  -17,  -61, 24, 39,  0 }, {     48,  -18,  -61, 24, 39,  0 }, {     48,  -19,  -62, 24, 39,  0 }, {     48,  -20,  -62, 24, 39,  0 },
    {     48,  -21,  -62, 24, 39,  0 }, {     48,  -22,  -63, 24, 39,  0 }, {     48,  -23,  -63, 24, 39,  0 }, {     48,  -24,  -63, 24, 39,  0 }, {     48,  -25,  -63, 24, 39,  0 },
    {     48,  -26,  -63,  8, 16,  0 }, {     48,  -27,  -64,  8, 16,  0 }, {     48,  -28,  -64,  8, 16,  0 }, {     48,  -29,  -64,  8, 16,  0 }, {     48,  -30,  -64,  8, 16,  0 },
    {     48,  -31,  -64,  8, 16,  0 }, {     48,  -32,  -64,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8EF6EF, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,   -1, 24,  0,  0 }, {     16,   24,   -1, 24,  0,  0 }, {     16,   23,   -1,  0, 43,  0 }, {     16,   22,   -1,  0, 43,  0 },
    {     16,   21,   -1,  0, 43,  0 }, {     16,   20,   -2,  0, 43,  0 }, {     16,   19,   -2,  0, 43,  0 }, {     16,   18,   -2,  0, 43,  0 }, {     16,   17,   -3,  0, 43,  0 },
    {     16,   16,   -3,  0, 43,  0 }, {     16,   15,   -4,  0, 43,  0 }, {     16,   14,   -4,  0, 43,  0 }, {     16,   13,   -5,  0, 43,  0 }, {     16,   12,   -5,  0, 43,  0 },
    {     16,   11,   -6,  0, 43,  0 }, {     16,   10,   -6,  0, 43,  0 }, {     16,    9,   -7,  0, 43,  0 }, {     16,    8,   -8,  0, 43,  0 }, {     16,    7,   -9,  0, 42,  0 },
    {     16,    6,   -9,  0, 42,  0 }, {     15,    5,  -10,  0, 42,  0 }, {     15,    4,  -11,  0, 42,  0 }, {     15,    3,  -12,  0, 42,  0 }, {     15,    2,  -13,  0, 42,  0 },
    {     15,    1,  -14,  0, 42,  0 }, {     15,    0,  -15,  0, 42,  0 }, {     14,   -1,  -16,  0, 42,  0 }, {     14,   -2,  -17,  0, 42,  0 }, {     14,   -2,  -18,  0, 42,  0 },
    {     14,   -3,  -19,  0, 42,  0 }, {     14,   -4,  -20,  0, 42,  0 }, {     13,   -5,  -21,  0, 42,  0 }, {     13,   -5,  -22,  0, 42,  0 }, {     13,   -6,  -23,  0, 42,  0 },
    {     12,   -6,  -24,  0, 41,  0 }, {     12,   -7,  -25,  0, 41,  0 }, {     12,   -8,  -26,  0, 41,  0 }, {     12,   -8,  -27,  0, 41,  0 }, {     11,   -9,  -28,  0, 41,  0 },
    {     11,   -9,  -29,  0, 41,  0 }, {     10,  -10,  -30,  0, 41,  0 }, {     10,  -10,  -31,  0, 41,  0 }, {     10,  -11,  -32,  0, 41,  0 }, {      9,  -11,  -33,  0, 41,  0 },
    {      9,  -11,  -34,  0, 41,  0 }, {      8,  -12,  -35,  0, 41,  0 }, {      8,  -12,  -36,  0, 41,  0 }, {      7,  -13,  -37,  0, 41,  0 }, {      7,  -13,  -38,  0, 41,  0 },
    {      6,  -13,  -39,  0, 41,  0 }, {      5,  -13,  -40,  0, 41,  0 }, {      5,  -14,  -41,  0, 40,  0 }, {      4,  -14,  -42,  0, 40,  0 }, {      4,  -14,  -43,  0, 40,  0 },
    {      3,  -15,  -44,  0, 40,  0 }, {      2,  -15,  -45,  0, 40,  0 }, {      1,  -15,  -46,  0, 40,  0 }, {      1,  -15,  -47,  0, 40,  0 }, {      0,  -15,  -48,  0, 40,  0 },
    {     -1,  -16,  -49,  0, 40,  0 }, {     -2,  -16,  -50,  0, 40,  0 }, {     -3,  -16,  -51,  0, 40,  0 }, {     -4,  -16,  -52,  0, 40,  0 }, {     -5,  -16,  -53,  0, 40,  0 },
    {     -6,  -16,  -54,  0, 40,  0 }, {     -7,  -17,  -55,  0, 40,  0 }, {     -8,  -17,  -55,  0, 40,  0 }, {     -9,  -17,  -56,  0, 39,  0 }, {    -10,  -17,  -57,  0, 39,  0 },
    {    -11,  -17,  -58,  0, 39,  0 }, {    -12,  -17,  -58,  0, 39,  0 }, {    -13,  -17,  -59,  0, 39,  0 }, {    -14,  -17,  -59,  0, 39,  0 }, {    -15,  -17,  -60,  0, 39,  0 },
    {    -16,  -17,  -60,  0, 39,  0 }, {    -17,  -17,  -61,  0, 39,  0 }, {    -18,  -17,  -61,  0, 39,  0 }, {    -19,  -17,  -62,  0, 39,  0 }, {    -20,  -17,  -62,  0, 39,  0 },
    {    -21,  -17,  -62,  0, 39,  0 }, {    -22,  -17,  -63,  0, 39,  0 }, {    -23,  -17,  -63,  0, 39,  0 }, {    -24,  -17,  -63,  0, 39,  0 }, {    -25,  -17,  -63,  0, 39,  0 },
    {    -26,  -17,  -63, 16, 16,  0 }, {    -27,  -17,  -64, 16, 16,  0 }, {    -28,  -17,  -64, 16, 16,  0 }, {    -29,  -17,  -64, 16, 16,  0 }, {    -30,  -17,  -64, 16, 16,  0 },
    {    -31,  -17,  -64, 16, 16,  0 }, {    -32,  -17,  -64, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92D152, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     21,   16,    1,  0,  1,  0 }, {     20,   16,    1,  0,  1,  0 }, {     19,   16,    1,  0,  1,  0 }, {     18,   16,    1,  0,  1,  0 }, {     17,   16,    1,  0,  1,  0 },
    {     16,   16,    1,  0,  1,  0 }, {     15,   16,    2,  0,  1,  0 }, {     14,   16,    2,  0,  1,  0 }, {     13,   16,    2,  0,  1,  0 }, {     12,   16,    2,  0,  1,  0 },
    {     11,   16,    3,  0,  1,  0 }, {     10,   16,    3,  0,  1,  0 }, {      9,   16,    3,  0,  1,  0 }, {      8,   16,    4,  0,  1,  0 }, {      7,   16,    4,  0,  2,  0 },
    {      6,   16,    5,  0,  2,  0 }, {      5,   16,    5,  0,  2,  0 }, {      4,   16,    6,  0,  2,  0 }, {      3,   16,    6,  0,  2,  0 }, {      2,   16,    7,  0,  2,  0 },
    {      1,   16,    7,  0,  2,  0 }, {      0,   16,    8,  0,  2,  0 }, {     -1,   16,    8,  0,  2,  0 }, {     -2,   16,    9,  0,  2,  0 }, {     -3,   16,    9,  0,  2,  0 },
    {     -4,   16,   10,  0,  2,  0 }, {     -5,   16,   10,  0,  2,  0 }, {     -6,   16,   11,  0,  2,  0 }, {     -7,   16,   11,  0,  2,  0 }, {     -8,   16,   11,  0,  2,  0 },
    {     -9,   16,   12,  0,  1,  0 }, {    -10,   16,   12,  0,  1,  0 }, {    -11,   16,   12,  0,  1,  0 }, {    -12,   16,   13,  0,  1,  0 }, {    -13,   16,   13,  0,  1,  0 },
    {    -14,   16,   13,  0,  1,  0 }, {    -15,   16,   14,  0,  1,  0 }, {    -16,   16,   14,  0,  1,  0 }, {    -17,   16,   14,  0,  1,  0 }, {    -18,   16,   14,  0,  1,  0 },
    {    -19,   16,   15,  0,  1,  0 }, {    -20,   16,   15,  0,  1,  0 }, {    -21,   16,   15,  0,  1,  0 }, {    -22,   16,   15,  0,  1,  0 }, {    -23,   16,   15,  0,  0,  0 },
    {    -24,   16,   15,  0,  0,  0 }, {    -25,   16,   16,  0,  0,  0 }, {    -26,   16,   16,  0,  0,  0 }, {    -27,   16,   16,  0,  0,  0 }, {    -28,   16,   16,  0,  0,  0 },
    {    -29,   16,   16,  0,  0,  0 }, {    -30,   16,   16,  0,  0,  0 }, {    -31,   16,   16,  0,  0,  0 }, {    -32,   16,   16,  0,  0,  0 }, {    -33,   16,   16,  0,  0,  0 },
    {    -34,   16,   16,  0,  0,  0 }, {    -35,   16,   16,  0,  0,  0 }, {    -36,   16,   16,  0,  0,  0 }, {    -37,   16,   16,  0,  0,  0 }, {    -38,   16,   16,  0,  0,  0 },
    {    -39,   16,   16,  0,  0,  0 }, {    -40,   16,   16,  0,  0,  0 }, {    -41,   16,   16,  0,  0,  0 }, {    -42,   16,   16,  0,  0,  0 }, {    -43,   16,   16,  0,  0,  0 },
    {    -44,   16,   16,  0,  0,  0 }, {    -45,   16,   16,  0,  0,  0 }, {    -46,   16,   16,  0,  0,  0 }, {    -47,   16,   16,  0,  0,  0 }, {    -48,   16,   16,  0,  0,  0 },
    {    -48,   16,   16, 16,  0,  0 }, {    -47,   16,   16, 16,  0,  0 }, {    -46,   16,   16, 16,  0,  0 }, {    -45,   16,   16, 16,  0,  0 }, {    -44,   16,   16, 16,  0,  0 },
    {    -43,   16,   16, 16,  0,  0 }, {    -42,   16,   16, 16,  0,  0 }, {    -41,   16,   16, 16,  0,  0 }, {    -40,   16,   16, 16,  0,  0 }, {    -39,   16,   16, 16,  0,  0 },
    {    -38,   16,   16, 16,  0,  0 }, {    -37,   16,   16, 16,  0,  0 }, {    -36,   16,   16, 16,  0,  0 }, {    -35,   16,   16, 16,  0,  0 }, {    -34,   16,   16, 16,  0,  0 },
    {    -33,   16,   16, 16,  0,  0 }, {    -32,   16,   16, 16,  0,  0 }, {    -31,   16,   16, 16,  0,  0 }, {    -30,   16,   16, 16,  0,  0 }, {    -29,   16,   16, 16,  0,  0 },
    {    -28,   16,   16, 16,  0,  0 }, {    -27,   16,   16, 16,  0,  0 }, {    -26,   16,   16, 16,  0,  0 }, {    -25,   16,   16, 16,  0,  0 }, {    -24,   16,   16, 16,  0,  0 },
    {    -23,   16,   16, 16,  0,  0 }, {    -22,   16,   17, 16,  1,  0 }, {    -21,   16,   17, 16,  1,  0 }, {    -20,   16,   17, 16,  1,  0 }, {    -19,   16,   17, 16,  1,  0 },
    {    -18,   16,   17, 16,  1,  0 }, {    -17,   16,   17, 16,  1,  0 }, {    -16,   16,   18, 16,  1,  0 }, {    -15,   16,   18, 16,  1,  0 }, {    -14,   16,   18, 16,  1,  0 },
    {    -13,   16,   18, 16,  1,  0 }, {    -12,   16,   19, 16,  1,  0 }, {    -11,   16,   19, 16,  1,  0 }, {    -10,   16,   19, 16,  1,  0 }, {     -9,   16,   20, 16,  1,  0 },
    {     -8,   16,   20, 16,  2,  0 }, {     -7,   16,   21, 16,  2,  0 }, {     -6,   16,   21, 16,  2,  0 }, {     -5,   16,   22, 16,  2,  0 }, {     -4,   16,   22, 16,  2,  0 },
    {     -3,   16,   23, 16,  2,  0 }, {     -2,   16,   23, 16,  2,  0 }, {     -1,   16,   24, 16,  2,  0 }, {      0,   16,   24, 16,  2,  0 }, {      1,   16,   25, 16,  2,  0 },
    {      2,   16,   25, 16,  2,  0 }, {      3,   16,   26, 16,  2,  0 }, {      4,   16,   26, 16,  2,  0 }, {      5,   16,   27, 16,  2,  0 }, {      6,   16,   27, 16,  2,  0 },
    {      7,   16,   27, 16,  2,  0 }, {      8,   16,   28, 16,  1,  0 }, {      9,   16,   28, 16,  1,  0 }, {     10,   16,   28, 16,  1,  0 }, {     11,   16,   29, 16,  1,  0 },
    {     12,   16,   29, 16,  1,  0 }, {     13,   16,   29, 16,  1,  0 }, {     14,   16,   30, 16,  1,  0 }, {     15,   16,   30, 16,  1,  0 }, {     16,   16,   30, 16,  1,  0 },
    {     17,   16,   30, 16,  1,  0 }, {     18,   16,   31, 16,  1,  0 }, {     19,   16,   31, 16,  1,  0 }, {     20,   16,   31, 16,  1,  0 }, {     21,   16,   31, 16,  1,  0 },
    {     22,   16,   31, 16,  0,  0 }, {     23,   16,   31, 16,  0,  0 }, {     24,   16,   32, 16,  0,  0 }, {     25,   16,   32, 16,  0,  0 }, {     26,   16,   32, 16,  0,  0 },
    {     27,   16,   32, 16,  0,  0 }, {     28,   16,   32, 16,  0,  0 }, {     29,   16,   32, 16,  0,  0 }, {     30,   16,   32, 16,  0,  0 }, {     31,   16,   32, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92D6F4, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 },
    {     16,   10,    1,  8,  1,  0 }, {     16,   11,    1,  8,  1,  0 }, {     16,   12,    1,  8,  1,  0 }, {     16,   13,    1,  8,  1,  0 }, {     16,   14,    1,  8,  1,  0 },
    {     16,   15,    1,  8,  1,  0 }, {     16,   16,    2,  8,  1,  0 }, {     16,   17,    2,  8,  1,  0 }, {     16,   18,    2,  8,  1,  0 }, {     16,   19,    2,  8,  1,  0 },
    {     16,   20,    3,  8,  1,  0 }, {     16,   21,    3,  8,  1,  0 }, {     16,   22,    3,  8,  1,  0 }, {     16,   23,    4,  8,  1,  0 }, {     16,   24,    4,  8,  2,  0 },
    {     16,   25,    4,  8,  2,  0 }, {     16,   26,    5,  8,  2,  0 }, {     16,   27,    5,  8,  2,  0 }, {     16,   28,    6,  8,  2,  0 }, {     16,   29,    6,  8,  2,  0 },
    {     16,   30,    7,  8,  2,  0 }, {     16,   31,    7,  8,  2,  0 }, {     16,   32,    8,  8,  2,  0 }, {     16,   33,    8,  8,  2,  0 }, {     16,   34,    9,  8,  2,  0 },
    {     16,   35,    9,  8,  2,  0 }, {     16,   36,   10,  8,  2,  0 }, {     16,   37,   10,  8,  2,  0 }, {     16,   38,   11,  8,  2,  0 }, {     16,   39,   11,  8,  2,  0 },
    {     16,   40,   12,  8,  1,  0 }, {     16,   41,   12,  8,  1,  0 }, {     16,   42,   12,  8,  1,  0 }, {     16,   43,   13,  8,  1,  0 }, {     16,   44,   13,  8,  1,  0 },
    {     16,   45,   13,  8,  1,  0 }, {     16,   46,   14,  8,  1,  0 }, {     16,   47,   14,  8,  1,  0 }, {     16,   48,   14,  8,  1,  0 }, {     16,   49,   14,  8,  1,  0 },
    {     16,   50,   15,  8,  1,  0 }, {     16,   51,   15,  8,  1,  0 }, {     16,   52,   15,  8,  1,  0 }, {     16,   53,   15,  8,  1,  0 }, {     16,   54,   15,  8,  0,  0 },
    {     16,   55,   15,  8,  0,  0 }, {     16,   56,   16,  8,  0,  0 }, {     16,   57,   16,  8,  0,  0 }, {     16,   58,   16,  8,  0,  0 }, {     16,   59,   16,  8,  0,  0 },
    {     16,   60,   16,  8,  0,  0 }, {     16,   61,   16,  8,  0,  0 }, {     16,   62,   16,  8,  0,  0 }, {     16,   63,   16,  8,  0,  0 }, {     16,   64,   16,  8,  0,  0 },
    {     16,   65,   16,  8,  0,  0 }, {     16,   66,   16,  8,  0,  0 }, {     16,   67,   16,  8,  0,  0 }, {     16,   68,   16,  8,  0,  0 }, {     16,   69,   16,  8,  0,  0 },
    {     16,   70,   16,  8,  0,  0 }, {     16,   71,   16,  8,  0,  0 }, {     16,   72,   16,  8,  0,  0 }, {     16,   73,   16,  8,  0,  0 }, {     16,   74,   16,  8,  0,  0 },
    {     16,   75,   16,  8,  0,  0 }, {     16,   76,   16,  8,  0,  0 }, {     16,   77,   16,  8,  0,  0 }, {     16,   78,   16,  8,  0,  0 }, {     16,   79,   16,  8,  0,  0 },
    {     16,   79,   16, 24,  0,  0 }, {     16,   78,   16, 24,  0,  0 }, {     16,   77,   16, 24,  0,  0 }, {     16,   76,   16, 24,  0,  0 }, {     16,   75,   16, 24,  0,  0 },
    {     16,   74,   16, 24,  0,  0 }, {     16,   73,   16, 24,  0,  0 }, {     16,   72,   16, 24,  0,  0 }, {     16,   71,   16, 24,  0,  0 }, {     16,   70,   16, 24,  0,  0 },
    {     16,   69,   16, 24,  0,  0 }, {     16,   68,   16, 24,  0,  0 }, {     16,   67,   16, 24,  0,  0 }, {     16,   66,   16, 24,  0,  0 }, {     16,   65,   16, 24,  0,  0 },
    {     16,   64,   16, 24,  0,  0 }, {     16,   63,   16, 24,  0,  0 }, {     16,   62,   16, 24,  0,  0 }, {     16,   61,   16, 24,  0,  0 }, {     16,   60,   16, 24,  0,  0 },
    {     16,   59,   16, 24,  0,  0 }, {     16,   58,   16, 24,  0,  0 }, {     16,   57,   16, 24,  0,  0 }, {     16,   56,   16, 24,  0,  0 }, {     16,   55,   16, 24,  0,  0 },
    {     16,   54,   16, 24,  0,  0 }, {     16,   53,   17, 24,  1,  0 }, {     16,   52,   17, 24,  1,  0 }, {     16,   51,   17, 24,  1,  0 }, {     16,   50,   17, 24,  1,  0 },
    {     16,   49,   17, 24,  1,  0 }, {     16,   48,   17, 24,  1,  0 }, {     16,   47,   18, 24,  1,  0 }, {     16,   46,   18, 24,  1,  0 }, {     16,   45,   18, 24,  1,  0 },
    {     16,   44,   18, 24,  1,  0 }, {     16,   43,   19, 24,  1,  0 }, {     16,   42,   19, 24,  1,  0 }, {     16,   41,   19, 24,  1,  0 }, {     16,   40,   20, 24,  1,  0 },
    {     16,   39,   20, 24,  2,  0 }, {     16,   38,   20, 24,  2,  0 }, {     16,   37,   21, 24,  2,  0 }, {     16,   36,   21, 24,  2,  0 }, {     16,   35,   22, 24,  2,  0 },
    {     16,   34,   22, 24,  2,  0 }, {     16,   33,   23, 24,  2,  0 }, {     16,   32,   23, 24,  2,  0 }, {     16,   31,   24, 24,  2,  0 }, {     16,   30,   24, 24,  2,  0 },
    {     16,   29,   25, 24,  2,  0 }, {     16,   28,   25, 24,  2,  0 }, {     16,   27,   26, 24,  2,  0 }, {     16,   26,   26, 24,  2,  0 }, {     16,   25,   27, 24,  2,  0 },
    {     16,   24,   27, 24,  2,  0 }, {     16,   23,   28, 24,  1,  0 }, {     16,   22,   28, 24,  1,  0 }, {     16,   21,   28, 24,  1,  0 }, {     16,   20,   29, 24,  1,  0 },
    {     16,   19,   29, 24,  1,  0 }, {     16,   18,   29, 24,  1,  0 }, {     16,   17,   30, 24,  1,  0 }, {     16,   16,   30, 24,  1,  0 }, {     16,   15,   30, 24,  1,  0 },
    {     16,   14,   30, 24,  1,  0 }, {     16,   13,   31, 24,  1,  0 }, {     16,   12,   31, 24,  1,  0 }, {     16,   11,   31, 24,  1,  0 }, {     16,   10,   31, 24,  1,  0 },
    {     16,    9,   31, 24,  0,  0 }, {     16,    8,   31, 24,  0,  0 }, {     16,    7,   32, 24,  0,  0 }, {     16,    6,   32, 24,  0,  0 }, {     16,    5,   32, 24,  0,  0 },
    {     16,    4,   32, 24,  0,  0 }, {     16,    3,   32, 24,  0,  0 }, {     16,    2,   32, 24,  0,  0 }, {     16,    1,   32, 24,  0,  0 }, {     16,    0,   32, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92DC96, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 }, {      9,   16,    0, 16,  0,  0 },
    {     10,   16,    1, 16,  1,  0 }, {     11,   16,    1, 16,  1,  0 }, {     12,   16,    1, 16,  1,  0 }, {     13,   16,    1, 16,  1,  0 }, {     14,   16,    1, 16,  1,  0 },
    {     15,   16,    1, 16,  1,  0 }, {     16,   16,    2, 16,  1,  0 }, {     17,   16,    2, 16,  1,  0 }, {     18,   16,    2, 16,  1,  0 }, {     19,   16,    2, 16,  1,  0 },
    {     20,   16,    3, 16,  1,  0 }, {     21,   16,    3, 16,  1,  0 }, {     22,   16,    3, 16,  1,  0 }, {     23,   16,    4, 16,  1,  0 }, {     24,   16,    4, 16,  2,  0 },
    {     25,   16,    4, 16,  2,  0 }, {     26,   16,    5, 16,  2,  0 }, {     27,   16,    5, 16,  2,  0 }, {     28,   16,    6, 16,  2,  0 }, {     29,   16,    6, 16,  2,  0 },
    {     30,   16,    7, 16,  2,  0 }, {     31,   16,    7, 16,  2,  0 }, {     32,   16,    8, 16,  2,  0 }, {     33,   16,    8, 16,  2,  0 }, {     34,   16,    9, 16,  2,  0 },
    {     35,   16,    9, 16,  2,  0 }, {     36,   16,   10, 16,  2,  0 }, {     37,   16,   10, 16,  2,  0 }, {     38,   16,   11, 16,  2,  0 }, {     39,   16,   11, 16,  2,  0 },
    {     40,   16,   12, 16,  1,  0 }, {     41,   16,   12, 16,  1,  0 }, {     42,   16,   12, 16,  1,  0 }, {     43,   16,   13, 16,  1,  0 }, {     44,   16,   13, 16,  1,  0 },
    {     45,   16,   13, 16,  1,  0 }, {     46,   16,   14, 16,  1,  0 }, {     47,   16,   14, 16,  1,  0 }, {     48,   16,   14, 16,  1,  0 }, {     49,   16,   14, 16,  1,  0 },
    {     50,   16,   15, 16,  1,  0 }, {     51,   16,   15, 16,  1,  0 }, {     52,   16,   15, 16,  1,  0 }, {     53,   16,   15, 16,  1,  0 }, {     54,   16,   15, 16,  0,  0 },
    {     55,   16,   15, 16,  0,  0 }, {     56,   16,   16, 16,  0,  0 }, {     57,   16,   16, 16,  0,  0 }, {     58,   16,   16, 16,  0,  0 }, {     59,   16,   16, 16,  0,  0 },
    {     60,   16,   16, 16,  0,  0 }, {     61,   16,   16, 16,  0,  0 }, {     62,   16,   16, 16,  0,  0 }, {     63,   16,   16, 16,  0,  0 }, {     64,   16,   16, 16,  0,  0 },
    {     65,   16,   16, 16,  0,  0 }, {     66,   16,   16, 16,  0,  0 }, {     67,   16,   16, 16,  0,  0 }, {     68,   16,   16, 16,  0,  0 }, {     69,   16,   16, 16,  0,  0 },
    {     70,   16,   16, 16,  0,  0 }, {     71,   16,   16, 16,  0,  0 }, {     72,   16,   16, 16,  0,  0 }, {     73,   16,   16, 16,  0,  0 }, {     74,   16,   16, 16,  0,  0 },
    {     75,   16,   16, 16,  0,  0 }, {     76,   16,   16, 16,  0,  0 }, {     77,   16,   16, 16,  0,  0 }, {     78,   16,   16, 16,  0,  0 }, {     79,   16,   16, 16,  0,  0 },
    {     79,   16,   16,  0,  0,  0 }, {     78,   16,   16,  0,  0,  0 }, {     77,   16,   16,  0,  0,  0 }, {     76,   16,   16,  0,  0,  0 }, {     75,   16,   16,  0,  0,  0 },
    {     74,   16,   16,  0,  0,  0 }, {     73,   16,   16,  0,  0,  0 }, {     72,   16,   16,  0,  0,  0 }, {     71,   16,   16,  0,  0,  0 }, {     70,   16,   16,  0,  0,  0 },
    {     69,   16,   16,  0,  0,  0 }, {     68,   16,   16,  0,  0,  0 }, {     67,   16,   16,  0,  0,  0 }, {     66,   16,   16,  0,  0,  0 }, {     65,   16,   16,  0,  0,  0 },
    {     64,   16,   16,  0,  0,  0 }, {     63,   16,   16,  0,  0,  0 }, {     62,   16,   16,  0,  0,  0 }, {     61,   16,   16,  0,  0,  0 }, {     60,   16,   16,  0,  0,  0 },
    {     59,   16,   16,  0,  0,  0 }, {     58,   16,   16,  0,  0,  0 }, {     57,   16,   16,  0,  0,  0 }, {     56,   16,   16,  0,  0,  0 }, {     55,   16,   16,  0,  0,  0 },
    {     54,   16,   16,  0,  0,  0 }, {     53,   16,   17,  0,  1,  0 }, {     52,   16,   17,  0,  1,  0 }, {     51,   16,   17,  0,  1,  0 }, {     50,   16,   17,  0,  1,  0 },
    {     49,   16,   17,  0,  1,  0 }, {     48,   16,   17,  0,  1,  0 }, {     47,   16,   18,  0,  1,  0 }, {     46,   16,   18,  0,  1,  0 }, {     45,   16,   18,  0,  1,  0 },
    {     44,   16,   18,  0,  1,  0 }, {     43,   16,   19,  0,  1,  0 }, {     42,   16,   19,  0,  1,  0 }, {     41,   16,   19,  0,  1,  0 }, {     40,   16,   20,  0,  1,  0 },
    {     39,   16,   20,  0,  2,  0 }, {     38,   16,   20,  0,  2,  0 }, {     37,   16,   21,  0,  2,  0 }, {     36,   16,   21,  0,  2,  0 }, {     35,   16,   22,  0,  2,  0 },
    {     34,   16,   22,  0,  2,  0 }, {     33,   16,   23,  0,  2,  0 }, {     32,   16,   23,  0,  2,  0 }, {     31,   16,   24,  0,  2,  0 }, {     30,   16,   24,  0,  2,  0 },
    {     29,   16,   25,  0,  2,  0 }, {     28,   16,   25,  0,  2,  0 }, {     27,   16,   26,  0,  2,  0 }, {     26,   16,   26,  0,  2,  0 }, {     25,   16,   27,  0,  2,  0 },
    {     24,   16,   27,  0,  2,  0 }, {     23,   16,   28,  0,  1,  0 }, {     22,   16,   28,  0,  1,  0 }, {     21,   16,   28,  0,  1,  0 }, {     20,   16,   29,  0,  1,  0 },
    {     19,   16,   29,  0,  1,  0 }, {     18,   16,   29,  0,  1,  0 }, {     17,   16,   30,  0,  1,  0 }, {     16,   16,   30,  0,  1,  0 }, {     15,   16,   30,  0,  1,  0 },
    {     14,   16,   30,  0,  1,  0 }, {     13,   16,   31,  0,  1,  0 }, {     12,   16,   31,  0,  1,  0 }, {     11,   16,   31,  0,  1,  0 }, {     10,   16,   31,  0,  1,  0 },
    {      9,   16,   31,  0,  0,  0 }, {      8,   16,   31,  0,  0,  0 }, {      7,   16,   32,  0,  0,  0 }, {      6,   16,   32,  0,  0,  0 }, {      5,   16,   32,  0,  0,  0 },
    {      4,   16,   32,  0,  0,  0 }, {      3,   16,   32,  0,  0,  0 }, {      2,   16,   32,  0,  0,  0 }, {      1,   16,   32,  0,  0,  0 }, {      0,   16,   32,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92E238, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   21,    1, 24,  1,  0 }, {     16,   20,    1, 24,  1,  0 }, {     16,   19,    1, 24,  1,  0 }, {     16,   18,    1, 24,  1,  0 }, {     16,   17,    1, 24,  1,  0 },
    {     16,   16,    1, 24,  1,  0 }, {     16,   15,    2, 24,  1,  0 }, {     16,   14,    2, 24,  1,  0 }, {     16,   13,    2, 24,  1,  0 }, {     16,   12,    2, 24,  1,  0 },
    {     16,   11,    3, 24,  1,  0 }, {     16,   10,    3, 24,  1,  0 }, {     16,    9,    3, 24,  1,  0 }, {     16,    8,    4, 24,  1,  0 }, {     16,    7,    4, 24,  2,  0 },
    {     16,    6,    5, 24,  2,  0 }, {     16,    5,    5, 24,  2,  0 }, {     16,    4,    6, 24,  2,  0 }, {     16,    3,    6, 24,  2,  0 }, {     16,    2,    7, 24,  2,  0 },
    {     16,    1,    7, 24,  2,  0 }, {     16,    0,    8, 24,  2,  0 }, {     16,   -1,    8, 24,  2,  0 }, {     16,   -2,    9, 24,  2,  0 }, {     16,   -3,    9, 24,  2,  0 },
    {     16,   -4,   10, 24,  2,  0 }, {     16,   -5,   10, 24,  2,  0 }, {     16,   -6,   11, 24,  2,  0 }, {     16,   -7,   11, 24,  2,  0 }, {     16,   -8,   11, 24,  2,  0 },
    {     16,   -9,   12, 24,  1,  0 }, {     16,  -10,   12, 24,  1,  0 }, {     16,  -11,   12, 24,  1,  0 }, {     16,  -12,   13, 24,  1,  0 }, {     16,  -13,   13, 24,  1,  0 },
    {     16,  -14,   13, 24,  1,  0 }, {     16,  -15,   14, 24,  1,  0 }, {     16,  -16,   14, 24,  1,  0 }, {     16,  -17,   14, 24,  1,  0 }, {     16,  -18,   14, 24,  1,  0 },
    {     16,  -19,   15, 24,  1,  0 }, {     16,  -20,   15, 24,  1,  0 }, {     16,  -21,   15, 24,  1,  0 }, {     16,  -22,   15, 24,  1,  0 }, {     16,  -23,   15, 24,  0,  0 },
    {     16,  -24,   15, 24,  0,  0 }, {     16,  -25,   16, 24,  0,  0 }, {     16,  -26,   16, 24,  0,  0 }, {     16,  -27,   16, 24,  0,  0 }, {     16,  -28,   16, 24,  0,  0 },
    {     16,  -29,   16, 24,  0,  0 }, {     16,  -30,   16, 24,  0,  0 }, {     16,  -31,   16, 24,  0,  0 }, {     16,  -32,   16, 24,  0,  0 }, {     16,  -33,   16, 24,  0,  0 },
    {     16,  -34,   16, 24,  0,  0 }, {     16,  -35,   16, 24,  0,  0 }, {     16,  -36,   16, 24,  0,  0 }, {     16,  -37,   16, 24,  0,  0 }, {     16,  -38,   16, 24,  0,  0 },
    {     16,  -39,   16, 24,  0,  0 }, {     16,  -40,   16, 24,  0,  0 }, {     16,  -41,   16, 24,  0,  0 }, {     16,  -42,   16, 24,  0,  0 }, {     16,  -43,   16, 24,  0,  0 },
    {     16,  -44,   16, 24,  0,  0 }, {     16,  -45,   16, 24,  0,  0 }, {     16,  -46,   16, 24,  0,  0 }, {     16,  -47,   16, 24,  0,  0 }, {     16,  -48,   16, 24,  0,  0 },
    {     16,  -48,   16,  8,  0,  0 }, {     16,  -47,   16,  8,  0,  0 }, {     16,  -46,   16,  8,  0,  0 }, {     16,  -45,   16,  8,  0,  0 }, {     16,  -44,   16,  8,  0,  0 },
    {     16,  -43,   16,  8,  0,  0 }, {     16,  -42,   16,  8,  0,  0 }, {     16,  -41,   16,  8,  0,  0 }, {     16,  -40,   16,  8,  0,  0 }, {     16,  -39,   16,  8,  0,  0 },
    {     16,  -38,   16,  8,  0,  0 }, {     16,  -37,   16,  8,  0,  0 }, {     16,  -36,   16,  8,  0,  0 }, {     16,  -35,   16,  8,  0,  0 }, {     16,  -34,   16,  8,  0,  0 },
    {     16,  -33,   16,  8,  0,  0 }, {     16,  -32,   16,  8,  0,  0 }, {     16,  -31,   16,  8,  0,  0 }, {     16,  -30,   16,  8,  0,  0 }, {     16,  -29,   16,  8,  0,  0 },
    {     16,  -28,   16,  8,  0,  0 }, {     16,  -27,   16,  8,  0,  0 }, {     16,  -26,   16,  8,  0,  0 }, {     16,  -25,   16,  8,  0,  0 }, {     16,  -24,   16,  8,  0,  0 },
    {     16,  -23,   16,  8,  0,  0 }, {     16,  -22,   17,  8,  1,  0 }, {     16,  -21,   17,  8,  1,  0 }, {     16,  -20,   17,  8,  1,  0 }, {     16,  -19,   17,  8,  1,  0 },
    {     16,  -18,   17,  8,  1,  0 }, {     16,  -17,   17,  8,  1,  0 }, {     16,  -16,   18,  8,  1,  0 }, {     16,  -15,   18,  8,  1,  0 }, {     16,  -14,   18,  8,  1,  0 },
    {     16,  -13,   18,  8,  1,  0 }, {     16,  -12,   19,  8,  1,  0 }, {     16,  -11,   19,  8,  1,  0 }, {     16,  -10,   19,  8,  1,  0 }, {     16,   -9,   20,  8,  1,  0 },
    {     16,   -8,   20,  8,  2,  0 }, {     16,   -7,   21,  8,  2,  0 }, {     16,   -6,   21,  8,  2,  0 }, {     16,   -5,   22,  8,  2,  0 }, {     16,   -4,   22,  8,  2,  0 },
    {     16,   -3,   23,  8,  2,  0 }, {     16,   -2,   23,  8,  2,  0 }, {     16,   -1,   24,  8,  2,  0 }, {     16,    0,   24,  8,  2,  0 }, {     16,    1,   25,  8,  2,  0 },
    {     16,    2,   25,  8,  2,  0 }, {     16,    3,   26,  8,  2,  0 }, {     16,    4,   26,  8,  2,  0 }, {     16,    5,   27,  8,  2,  0 }, {     16,    6,   27,  8,  2,  0 },
    {     16,    7,   27,  8,  2,  0 }, {     16,    8,   28,  8,  1,  0 }, {     16,    9,   28,  8,  1,  0 }, {     16,   10,   28,  8,  1,  0 }, {     16,   11,   29,  8,  1,  0 },
    {     16,   12,   29,  8,  1,  0 }, {     16,   13,   29,  8,  1,  0 }, {     16,   14,   30,  8,  1,  0 }, {     16,   15,   30,  8,  1,  0 }, {     16,   16,   30,  8,  1,  0 },
    {     16,   17,   30,  8,  1,  0 }, {     16,   18,   31,  8,  1,  0 }, {     16,   19,   31,  8,  1,  0 }, {     16,   20,   31,  8,  1,  0 }, {     16,   21,   31,  8,  1,  0 },
    {     16,   22,   31,  8,  0,  0 }, {     16,   23,   31,  8,  0,  0 }, {     16,   24,   32,  8,  0,  0 }, {     16,   25,   32,  8,  0,  0 }, {     16,   26,   32,  8,  0,  0 },
    {     16,   27,   32,  8,  0,  0 }, {     16,   28,   32,  8,  0,  0 }, {     16,   29,   32,  8,  0,  0 }, {     16,   30,   32,  8,  0,  0 }, {     16,   31,   32,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92E7DA, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,   -1,  0,  0,  0 }, {     22,   16,   -1,  0,  0,  0 },
    {     21,   16,   -1,  0,  5,  0 }, {     20,   16,   -1,  0,  5,  0 }, {     19,   16,   -1,  0,  5,  0 }, {     18,   16,   -1,  0,  5,  0 }, {     17,   16,   -2,  0,  5,  0 },
    {     16,   16,   -2,  0,  5,  0 }, {     15,   16,   -2,  0,  5,  0 }, {     14,   16,   -2,  0,  5,  0 }, {     13,   16,   -3,  0,  5,  0 }, {     12,   16,   -3,  0,  5,  0 },
    {     11,   16,   -3,  0,  5,  0 }, {     10,   16,   -4,  0,  5,  0 }, {      9,   16,   -4,  0,  5,  0 }, {      8,   16,   -4,  0,  5,  0 }, {      7,   16,   -5,  0,  6,  0 },
    {      6,   16,   -5,  0,  6,  0 }, {      5,   16,   -6,  0,  6,  0 }, {      4,   16,   -6,  0,  6,  0 }, {      3,   16,   -7,  0,  6,  0 }, {      2,   16,   -7,  0,  6,  0 },
    {      1,   16,   -8,  0,  6,  0 }, {      0,   16,   -8,  0,  6,  0 }, {     -1,   16,   -9,  0,  6,  0 }, {     -2,   16,   -9,  0,  6,  0 }, {     -3,   16,  -10,  0,  6,  0 },
    {     -4,   16,  -10,  0,  6,  0 }, {     -5,   16,  -11,  0,  6,  0 }, {     -6,   16,  -11,  0,  6,  0 }, {     -7,   16,  -12,  0,  6,  0 }, {     -8,   16,  -12,  0,  6,  0 },
    {     -9,   16,  -12,  0,  5,  0 }, {    -10,   16,  -13,  0,  5,  0 }, {    -11,   16,  -13,  0,  5,  0 }, {    -12,   16,  -13,  0,  5,  0 }, {    -13,   16,  -14,  0,  5,  0 },
    {    -14,   16,  -14,  0,  5,  0 }, {    -15,   16,  -14,  0,  5,  0 }, {    -16,   16,  -14,  0,  5,  0 }, {    -17,   16,  -15,  0,  5,  0 }, {    -18,   16,  -15,  0,  5,  0 },
    {    -19,   16,  -15,  0,  5,  0 }, {    -20,   16,  -15,  0,  5,  0 }, {    -21,   16,  -15,  0,  5,  0 }, {    -22,   16,  -15,  0,  5,  0 }, {    -23,   16,  -16,  0,  0,  0 },
    {    -24,   16,  -16,  0,  0,  0 }, {    -25,   16,  -16,  0,  0,  0 }, {    -26,   16,  -16,  0,  0,  0 }, {    -27,   16,  -16,  0,  0,  0 }, {    -28,   16,  -16,  0,  0,  0 },
    {    -29,   16,  -16,  0,  0,  0 }, {    -30,   16,  -16,  0,  0,  0 }, {    -31,   16,  -16,  0,  0,  0 }, {    -32,   16,  -16,  0,  0,  0 }, {    -33,   16,  -16,  0,  0,  0 },
    {    -34,   16,  -16,  0,  0,  0 }, {    -35,   16,  -16,  0,  0,  0 }, {    -36,   16,  -16,  0,  0,  0 }, {    -37,   16,  -16,  0,  0,  0 }, {    -38,   16,  -16,  0,  0,  0 },
    {    -39,   16,  -16,  0,  0,  0 }, {    -40,   16,  -16,  0,  0,  0 }, {    -41,   16,  -16,  0,  0,  0 }, {    -42,   16,  -16,  0,  0,  0 }, {    -43,   16,  -16,  0,  0,  0 },
    {    -44,   16,  -16,  0,  0,  0 }, {    -45,   16,  -16,  0,  0,  0 }, {    -46,   16,  -16,  0,  0,  0 }, {    -47,   16,  -16,  0,  0,  0 }, {    -48,   16,  -16,  0,  0,  0 },
    {    -48,   16,  -16, 16,  0,  0 }, {    -47,   16,  -16, 16,  0,  0 }, {    -46,   16,  -16, 16,  0,  0 }, {    -45,   16,  -16, 16,  0,  0 }, {    -44,   16,  -16, 16,  0,  0 },
    {    -43,   16,  -16, 16,  0,  0 }, {    -42,   16,  -16, 16,  0,  0 }, {    -41,   16,  -16, 16,  0,  0 }, {    -40,   16,  -16, 16,  0,  0 }, {    -39,   16,  -16, 16,  0,  0 },
    {    -38,   16,  -16, 16,  0,  0 }, {    -37,   16,  -16, 16,  0,  0 }, {    -36,   16,  -16, 16,  0,  0 }, {    -35,   16,  -16, 16,  0,  0 }, {    -34,   16,  -16, 16,  0,  0 },
    {    -33,   16,  -16, 16,  0,  0 }, {    -32,   16,  -16, 16,  0,  0 }, {    -31,   16,  -16, 16,  0,  0 }, {    -30,   16,  -16, 16,  0,  0 }, {    -29,   16,  -16, 16,  0,  0 },
    {    -28,   16,  -16, 16,  0,  0 }, {    -27,   16,  -16, 16,  0,  0 }, {    -26,   16,  -16, 16,  0,  0 }, {    -25,   16,  -16, 16,  0,  0 }, {    -24,   16,  -17, 16,  0,  0 },
    {    -23,   16,  -17, 16,  0,  0 }, {    -22,   16,  -17, 16,  5,  0 }, {    -21,   16,  -17, 16,  5,  0 }, {    -20,   16,  -17, 16,  5,  0 }, {    -19,   16,  -17, 16,  5,  0 },
    {    -18,   16,  -18, 16,  5,  0 }, {    -17,   16,  -18, 16,  5,  0 }, {    -16,   16,  -18, 16,  5,  0 }, {    -15,   16,  -18, 16,  5,  0 }, {    -14,   16,  -19, 16,  5,  0 },
    {    -13,   16,  -19, 16,  5,  0 }, {    -12,   16,  -19, 16,  5,  0 }, {    -11,   16,  -20, 16,  5,  0 }, {    -10,   16,  -20, 16,  5,  0 }, {     -9,   16,  -20, 16,  5,  0 },
    {     -8,   16,  -21, 16,  6,  0 }, {     -7,   16,  -21, 16,  6,  0 }, {     -6,   16,  -22, 16,  6,  0 }, {     -5,   16,  -22, 16,  6,  0 }, {     -4,   16,  -23, 16,  6,  0 },
    {     -3,   16,  -23, 16,  6,  0 }, {     -2,   16,  -24, 16,  6,  0 }, {     -1,   16,  -24, 16,  6,  0 }, {      0,   16,  -25, 16,  6,  0 }, {      1,   16,  -25, 16,  6,  0 },
    {      2,   16,  -26, 16,  6,  0 }, {      3,   16,  -26, 16,  6,  0 }, {      4,   16,  -27, 16,  6,  0 }, {      5,   16,  -27, 16,  6,  0 }, {      6,   16,  -28, 16,  6,  0 },
    {      7,   16,  -28, 16,  6,  0 }, {      8,   16,  -28, 16,  5,  0 }, {      9,   16,  -29, 16,  5,  0 }, {     10,   16,  -29, 16,  5,  0 }, {     11,   16,  -29, 16,  5,  0 },
    {     12,   16,  -30, 16,  5,  0 }, {     13,   16,  -30, 16,  5,  0 }, {     14,   16,  -30, 16,  5,  0 }, {     15,   16,  -30, 16,  5,  0 }, {     16,   16,  -31, 16,  5,  0 },
    {     17,   16,  -31, 16,  5,  0 }, {     18,   16,  -31, 16,  5,  0 }, {     19,   16,  -31, 16,  5,  0 }, {     20,   16,  -31, 16,  5,  0 }, {     21,   16,  -31, 16,  5,  0 },
    {     22,   16,  -32, 16,  0,  0 }, {     23,   16,  -32, 16,  0,  0 }, {     24,   16,  -32, 16,  0,  0 }, {     25,   16,  -32, 16,  0,  0 }, {     26,   16,  -32, 16,  0,  0 },
    {     27,   16,  -32, 16,  0,  0 }, {     28,   16,  -32, 16,  0,  0 }, {     29,   16,  -32, 16,  0,  0 }, {     30,   16,  -32, 16,  0,  0 }, {     31,   16,  -32, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92ED7C, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,   -1,  8,  0,  0 }, {     16,    9,   -1,  8,  0,  0 },
    {     16,   10,   -1,  8,  5,  0 }, {     16,   11,   -1,  8,  5,  0 }, {     16,   12,   -1,  8,  5,  0 }, {     16,   13,   -1,  8,  5,  0 }, {     16,   14,   -2,  8,  5,  0 },
    {     16,   15,   -2,  8,  5,  0 }, {     16,   16,   -2,  8,  5,  0 }, {     16,   17,   -2,  8,  5,  0 }, {     16,   18,   -3,  8,  5,  0 }, {     16,   19,   -3,  8,  5,  0 },
    {     16,   20,   -3,  8,  5,  0 }, {     16,   21,   -4,  8,  5,  0 }, {     16,   22,   -4,  8,  5,  0 }, {     16,   23,   -4,  8,  5,  0 }, {     16,   24,   -5,  8,  6,  0 },
    {     16,   25,   -5,  8,  6,  0 }, {     16,   26,   -5,  8,  6,  0 }, {     16,   27,   -6,  8,  6,  0 }, {     16,   28,   -6,  8,  6,  0 }, {     16,   29,   -7,  8,  6,  0 },
    {     16,   30,   -7,  8,  6,  0 }, {     16,   31,   -8,  8,  6,  0 }, {     16,   32,   -8,  8,  6,  0 }, {     16,   33,   -9,  8,  6,  0 }, {     16,   34,   -9,  8,  6,  0 },
    {     16,   35,  -10,  8,  6,  0 }, {     16,   36,  -10,  8,  6,  0 }, {     16,   37,  -11,  8,  6,  0 }, {     16,   38,  -11,  8,  6,  0 }, {     16,   39,  -12,  8,  6,  0 },
    {     16,   40,  -12,  8,  5,  0 }, {     16,   41,  -13,  8,  5,  0 }, {     16,   42,  -13,  8,  5,  0 }, {     16,   43,  -13,  8,  5,  0 }, {     16,   44,  -14,  8,  5,  0 },
    {     16,   45,  -14,  8,  5,  0 }, {     16,   46,  -14,  8,  5,  0 }, {     16,   47,  -14,  8,  5,  0 }, {     16,   48,  -15,  8,  5,  0 }, {     16,   49,  -15,  8,  5,  0 },
    {     16,   50,  -15,  8,  5,  0 }, {     16,   51,  -15,  8,  5,  0 }, {     16,   52,  -15,  8,  5,  0 }, {     16,   53,  -15,  8,  5,  0 }, {     16,   54,  -16,  8,  0,  0 },
    {     16,   55,  -16,  8,  0,  0 }, {     16,   56,  -16,  8,  0,  0 }, {     16,   57,  -16,  8,  0,  0 }, {     16,   58,  -16,  8,  0,  0 }, {     16,   59,  -16,  8,  0,  0 },
    {     16,   60,  -16,  8,  0,  0 }, {     16,   61,  -16,  8,  0,  0 }, {     16,   62,  -16,  8,  0,  0 }, {     16,   63,  -16,  8,  0,  0 }, {     16,   64,  -16,  8,  0,  0 },
    {     16,   65,  -16,  8,  0,  0 }, {     16,   66,  -16,  8,  0,  0 }, {     16,   67,  -16,  8,  0,  0 }, {     16,   68,  -16,  8,  0,  0 }, {     16,   69,  -16,  8,  0,  0 },
    {     16,   70,  -16,  8,  0,  0 }, {     16,   71,  -16,  8,  0,  0 }, {     16,   72,  -16,  8,  0,  0 }, {     16,   73,  -16,  8,  0,  0 }, {     16,   74,  -16,  8,  0,  0 },
    {     16,   75,  -16,  8,  0,  0 }, {     16,   76,  -16,  8,  0,  0 }, {     16,   77,  -16,  8,  0,  0 }, {     16,   78,  -16,  8,  0,  0 }, {     16,   79,  -16,  8,  0,  0 },
    {     16,   79,  -16, 24,  0,  0 }, {     16,   78,  -16, 24,  0,  0 }, {     16,   77,  -16, 24,  0,  0 }, {     16,   76,  -16, 24,  0,  0 }, {     16,   75,  -16, 24,  0,  0 },
    {     16,   74,  -16, 24,  0,  0 }, {     16,   73,  -16, 24,  0,  0 }, {     16,   72,  -16, 24,  0,  0 }, {     16,   71,  -16, 24,  0,  0 }, {     16,   70,  -16, 24,  0,  0 },
    {     16,   69,  -16, 24,  0,  0 }, {     16,   68,  -16, 24,  0,  0 }, {     16,   67,  -16, 24,  0,  0 }, {     16,   66,  -16, 24,  0,  0 }, {     16,   65,  -16, 24,  0,  0 },
    {     16,   64,  -16, 24,  0,  0 }, {     16,   63,  -16, 24,  0,  0 }, {     16,   62,  -16, 24,  0,  0 }, {     16,   61,  -16, 24,  0,  0 }, {     16,   60,  -16, 24,  0,  0 },
    {     16,   59,  -16, 24,  0,  0 }, {     16,   58,  -16, 24,  0,  0 }, {     16,   57,  -16, 24,  0,  0 }, {     16,   56,  -16, 24,  0,  0 }, {     16,   55,  -17, 24,  0,  0 },
    {     16,   54,  -17, 24,  0,  0 }, {     16,   53,  -17, 24,  5,  0 }, {     16,   52,  -17, 24,  5,  0 }, {     16,   51,  -17, 24,  5,  0 }, {     16,   50,  -17, 24,  5,  0 },
    {     16,   49,  -18, 24,  5,  0 }, {     16,   48,  -18, 24,  5,  0 }, {     16,   47,  -18, 24,  5,  0 }, {     16,   46,  -18, 24,  5,  0 }, {     16,   45,  -19, 24,  5,  0 },
    {     16,   44,  -19, 24,  5,  0 }, {     16,   43,  -19, 24,  5,  0 }, {     16,   42,  -20, 24,  5,  0 }, {     16,   41,  -20, 24,  5,  0 }, {     16,   40,  -20, 24,  5,  0 },
    {     16,   39,  -21, 24,  6,  0 }, {     16,   38,  -21, 24,  6,  0 }, {     16,   37,  -21, 24,  6,  0 }, {     16,   36,  -22, 24,  6,  0 }, {     16,   35,  -22, 24,  6,  0 },
    {     16,   34,  -23, 24,  6,  0 }, {     16,   33,  -23, 24,  6,  0 }, {     16,   32,  -24, 24,  6,  0 }, {     16,   31,  -24, 24,  6,  0 }, {     16,   30,  -25, 24,  6,  0 },
    {     16,   29,  -25, 24,  6,  0 }, {     16,   28,  -26, 24,  6,  0 }, {     16,   27,  -26, 24,  6,  0 }, {     16,   26,  -27, 24,  6,  0 }, {     16,   25,  -27, 24,  6,  0 },
    {     16,   24,  -28, 24,  6,  0 }, {     16,   23,  -28, 24,  5,  0 }, {     16,   22,  -29, 24,  5,  0 }, {     16,   21,  -29, 24,  5,  0 }, {     16,   20,  -29, 24,  5,  0 },
    {     16,   19,  -30, 24,  5,  0 }, {     16,   18,  -30, 24,  5,  0 }, {     16,   17,  -30, 24,  5,  0 }, {     16,   16,  -30, 24,  5,  0 }, {     16,   15,  -31, 24,  5,  0 },
    {     16,   14,  -31, 24,  5,  0 }, {     16,   13,  -31, 24,  5,  0 }, {     16,   12,  -31, 24,  5,  0 }, {     16,   11,  -31, 24,  5,  0 }, {     16,   10,  -31, 24,  5,  0 },
    {     16,    9,  -32, 24,  0,  0 }, {     16,    8,  -32, 24,  0,  0 }, {     16,    7,  -32, 24,  0,  0 }, {     16,    6,  -32, 24,  0,  0 }, {     16,    5,  -32, 24,  0,  0 },
    {     16,    4,  -32, 24,  0,  0 }, {     16,    3,  -32, 24,  0,  0 }, {     16,    2,  -32, 24,  0,  0 }, {     16,    1,  -32, 24,  0,  0 }, {     16,    0,  -32, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92F31E, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,   -1, 16,  0,  0 }, {      9,   16,   -1, 16,  0,  0 },
    {     10,   16,   -1, 16,  5,  0 }, {     11,   16,   -1, 16,  5,  0 }, {     12,   16,   -1, 16,  5,  0 }, {     13,   16,   -1, 16,  5,  0 }, {     14,   16,   -2, 16,  5,  0 },
    {     15,   16,   -2, 16,  5,  0 }, {     16,   16,   -2, 16,  5,  0 }, {     17,   16,   -2, 16,  5,  0 }, {     18,   16,   -3, 16,  5,  0 }, {     19,   16,   -3, 16,  5,  0 },
    {     20,   16,   -3, 16,  5,  0 }, {     21,   16,   -4, 16,  5,  0 }, {     22,   16,   -4, 16,  5,  0 }, {     23,   16,   -4, 16,  5,  0 }, {     24,   16,   -5, 16,  6,  0 },
    {     25,   16,   -5, 16,  6,  0 }, {     26,   16,   -5, 16,  6,  0 }, {     27,   16,   -6, 16,  6,  0 }, {     28,   16,   -6, 16,  6,  0 }, {     29,   16,   -7, 16,  6,  0 },
    {     30,   16,   -7, 16,  6,  0 }, {     31,   16,   -8, 16,  6,  0 }, {     32,   16,   -8, 16,  6,  0 }, {     33,   16,   -9, 16,  6,  0 }, {     34,   16,   -9, 16,  6,  0 },
    {     35,   16,  -10, 16,  6,  0 }, {     36,   16,  -10, 16,  6,  0 }, {     37,   16,  -11, 16,  6,  0 }, {     38,   16,  -11, 16,  6,  0 }, {     39,   16,  -12, 16,  6,  0 },
    {     40,   16,  -12, 16,  5,  0 }, {     41,   16,  -13, 16,  5,  0 }, {     42,   16,  -13, 16,  5,  0 }, {     43,   16,  -13, 16,  5,  0 }, {     44,   16,  -14, 16,  5,  0 },
    {     45,   16,  -14, 16,  5,  0 }, {     46,   16,  -14, 16,  5,  0 }, {     47,   16,  -14, 16,  5,  0 }, {     48,   16,  -15, 16,  5,  0 }, {     49,   16,  -15, 16,  5,  0 },
    {     50,   16,  -15, 16,  5,  0 }, {     51,   16,  -15, 16,  5,  0 }, {     52,   16,  -15, 16,  5,  0 }, {     53,   16,  -15, 16,  5,  0 }, {     54,   16,  -16, 16,  0,  0 },
    {     55,   16,  -16, 16,  0,  0 }, {     56,   16,  -16, 16,  0,  0 }, {     57,   16,  -16, 16,  0,  0 }, {     58,   16,  -16, 16,  0,  0 }, {     59,   16,  -16, 16,  0,  0 },
    {     60,   16,  -16, 16,  0,  0 }, {     61,   16,  -16, 16,  0,  0 }, {     62,   16,  -16, 16,  0,  0 }, {     63,   16,  -16, 16,  0,  0 }, {     64,   16,  -16, 16,  0,  0 },
    {     65,   16,  -16, 16,  0,  0 }, {     66,   16,  -16, 16,  0,  0 }, {     67,   16,  -16, 16,  0,  0 }, {     68,   16,  -16, 16,  0,  0 }, {     69,   16,  -16, 16,  0,  0 },
    {     70,   16,  -16, 16,  0,  0 }, {     71,   16,  -16, 16,  0,  0 }, {     72,   16,  -16, 16,  0,  0 }, {     73,   16,  -16, 16,  0,  0 }, {     74,   16,  -16, 16,  0,  0 },
    {     75,   16,  -16, 16,  0,  0 }, {     76,   16,  -16, 16,  0,  0 }, {     77,   16,  -16, 16,  0,  0 }, {     78,   16,  -16, 16,  0,  0 }, {     79,   16,  -16, 16,  0,  0 },
    {     79,   16,  -16,  0,  0,  0 }, {     78,   16,  -16,  0,  0,  0 }, {     77,   16,  -16,  0,  0,  0 }, {     76,   16,  -16,  0,  0,  0 }, {     75,   16,  -16,  0,  0,  0 },
    {     74,   16,  -16,  0,  0,  0 }, {     73,   16,  -16,  0,  0,  0 }, {     72,   16,  -16,  0,  0,  0 }, {     71,   16,  -16,  0,  0,  0 }, {     70,   16,  -16,  0,  0,  0 },
    {     69,   16,  -16,  0,  0,  0 }, {     68,   16,  -16,  0,  0,  0 }, {     67,   16,  -16,  0,  0,  0 }, {     66,   16,  -16,  0,  0,  0 }, {     65,   16,  -16,  0,  0,  0 },
    {     64,   16,  -16,  0,  0,  0 }, {     63,   16,  -16,  0,  0,  0 }, {     62,   16,  -16,  0,  0,  0 }, {     61,   16,  -16,  0,  0,  0 }, {     60,   16,  -16,  0,  0,  0 },
    {     59,   16,  -16,  0,  0,  0 }, {     58,   16,  -16,  0,  0,  0 }, {     57,   16,  -16,  0,  0,  0 }, {     56,   16,  -16,  0,  0,  0 }, {     55,   16,  -17,  0,  0,  0 },
    {     54,   16,  -17,  0,  0,  0 }, {     53,   16,  -17,  0,  5,  0 }, {     52,   16,  -17,  0,  5,  0 }, {     51,   16,  -17,  0,  5,  0 }, {     50,   16,  -17,  0,  5,  0 },
    {     49,   16,  -18,  0,  5,  0 }, {     48,   16,  -18,  0,  5,  0 }, {     47,   16,  -18,  0,  5,  0 }, {     46,   16,  -18,  0,  5,  0 }, {     45,   16,  -19,  0,  5,  0 },
    {     44,   16,  -19,  0,  5,  0 }, {     43,   16,  -19,  0,  5,  0 }, {     42,   16,  -20,  0,  5,  0 }, {     41,   16,  -20,  0,  5,  0 }, {     40,   16,  -20,  0,  5,  0 },
    {     39,   16,  -21,  0,  6,  0 }, {     38,   16,  -21,  0,  6,  0 }, {     37,   16,  -21,  0,  6,  0 }, {     36,   16,  -22,  0,  6,  0 }, {     35,   16,  -22,  0,  6,  0 },
    {     34,   16,  -23,  0,  6,  0 }, {     33,   16,  -23,  0,  6,  0 }, {     32,   16,  -24,  0,  6,  0 }, {     31,   16,  -24,  0,  6,  0 }, {     30,   16,  -25,  0,  6,  0 },
    {     29,   16,  -25,  0,  6,  0 }, {     28,   16,  -26,  0,  6,  0 }, {     27,   16,  -26,  0,  6,  0 }, {     26,   16,  -27,  0,  6,  0 }, {     25,   16,  -27,  0,  6,  0 },
    {     24,   16,  -28,  0,  6,  0 }, {     23,   16,  -28,  0,  5,  0 }, {     22,   16,  -29,  0,  5,  0 }, {     21,   16,  -29,  0,  5,  0 }, {     20,   16,  -29,  0,  5,  0 },
    {     19,   16,  -30,  0,  5,  0 }, {     18,   16,  -30,  0,  5,  0 }, {     17,   16,  -30,  0,  5,  0 }, {     16,   16,  -30,  0,  5,  0 }, {     15,   16,  -31,  0,  5,  0 },
    {     14,   16,  -31,  0,  5,  0 }, {     13,   16,  -31,  0,  5,  0 }, {     12,   16,  -31,  0,  5,  0 }, {     11,   16,  -31,  0,  5,  0 }, {     10,   16,  -31,  0,  5,  0 },
    {      9,   16,  -32,  0,  0,  0 }, {      8,   16,  -32,  0,  0,  0 }, {      7,   16,  -32,  0,  0,  0 }, {      6,   16,  -32,  0,  0,  0 }, {      5,   16,  -32,  0,  0,  0 },
    {      4,   16,  -32,  0,  0,  0 }, {      3,   16,  -32,  0,  0,  0 }, {      2,   16,  -32,  0,  0,  0 }, {      1,   16,  -32,  0,  0,  0 }, {      0,   16,  -32,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92F8C0, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,   -1, 24,  0,  0 }, {     16,   22,   -1, 24,  0,  0 },
    {     16,   21,   -1, 24,  5,  0 }, {     16,   20,   -1, 24,  5,  0 }, {     16,   19,   -1, 24,  5,  0 }, {     16,   18,   -1, 24,  5,  0 }, {     16,   17,   -2, 24,  5,  0 },
    {     16,   16,   -2, 24,  5,  0 }, {     16,   15,   -2, 24,  5,  0 }, {     16,   14,   -2, 24,  5,  0 }, {     16,   13,   -3, 24,  5,  0 }, {     16,   12,   -3, 24,  5,  0 },
    {     16,   11,   -3, 24,  5,  0 }, {     16,   10,   -4, 24,  5,  0 }, {     16,    9,   -4, 24,  5,  0 }, {     16,    8,   -4, 24,  5,  0 }, {     16,    7,   -5, 24,  6,  0 },
    {     16,    6,   -5, 24,  6,  0 }, {     16,    5,   -6, 24,  6,  0 }, {     16,    4,   -6, 24,  6,  0 }, {     16,    3,   -7, 24,  6,  0 }, {     16,    2,   -7, 24,  6,  0 },
    {     16,    1,   -8, 24,  6,  0 }, {     16,    0,   -8, 24,  6,  0 }, {     16,   -1,   -9, 24,  6,  0 }, {     16,   -2,   -9, 24,  6,  0 }, {     16,   -3,  -10, 24,  6,  0 },
    {     16,   -4,  -10, 24,  6,  0 }, {     16,   -5,  -11, 24,  6,  0 }, {     16,   -6,  -11, 24,  6,  0 }, {     16,   -7,  -12, 24,  6,  0 }, {     16,   -8,  -12, 24,  6,  0 },
    {     16,   -9,  -12, 24,  5,  0 }, {     16,  -10,  -13, 24,  5,  0 }, {     16,  -11,  -13, 24,  5,  0 }, {     16,  -12,  -13, 24,  5,  0 }, {     16,  -13,  -14, 24,  5,  0 },
    {     16,  -14,  -14, 24,  5,  0 }, {     16,  -15,  -14, 24,  5,  0 }, {     16,  -16,  -14, 24,  5,  0 }, {     16,  -17,  -15, 24,  5,  0 }, {     16,  -18,  -15, 24,  5,  0 },
    {     16,  -19,  -15, 24,  5,  0 }, {     16,  -20,  -15, 24,  5,  0 }, {     16,  -21,  -15, 24,  5,  0 }, {     16,  -22,  -15, 24,  5,  0 }, {     16,  -23,  -16, 24,  0,  0 },
    {     16,  -24,  -16, 24,  0,  0 }, {     16,  -25,  -16, 24,  0,  0 }, {     16,  -26,  -16, 24,  0,  0 }, {     16,  -27,  -16, 24,  0,  0 }, {     16,  -28,  -16, 24,  0,  0 },
    {     16,  -29,  -16, 24,  0,  0 }, {     16,  -30,  -16, 24,  0,  0 }, {     16,  -31,  -16, 24,  0,  0 }, {     16,  -32,  -16, 24,  0,  0 }, {     16,  -33,  -16, 24,  0,  0 },
    {     16,  -34,  -16, 24,  0,  0 }, {     16,  -35,  -16, 24,  0,  0 }, {     16,  -36,  -16, 24,  0,  0 }, {     16,  -37,  -16, 24,  0,  0 }, {     16,  -38,  -16, 24,  0,  0 },
    {     16,  -39,  -16, 24,  0,  0 }, {     16,  -40,  -16, 24,  0,  0 }, {     16,  -41,  -16, 24,  0,  0 }, {     16,  -42,  -16, 24,  0,  0 }, {     16,  -43,  -16, 24,  0,  0 },
    {     16,  -44,  -16, 24,  0,  0 }, {     16,  -45,  -16, 24,  0,  0 }, {     16,  -46,  -16, 24,  0,  0 }, {     16,  -47,  -16, 24,  0,  0 }, {     16,  -48,  -16, 24,  0,  0 },
    {     16,  -48,  -16,  8,  0,  0 }, {     16,  -47,  -16,  8,  0,  0 }, {     16,  -46,  -16,  8,  0,  0 }, {     16,  -45,  -16,  8,  0,  0 }, {     16,  -44,  -16,  8,  0,  0 },
    {     16,  -43,  -16,  8,  0,  0 }, {     16,  -42,  -16,  8,  0,  0 }, {     16,  -41,  -16,  8,  0,  0 }, {     16,  -40,  -16,  8,  0,  0 }, {     16,  -39,  -16,  8,  0,  0 },
    {     16,  -38,  -16,  8,  0,  0 }, {     16,  -37,  -16,  8,  0,  0 }, {     16,  -36,  -16,  8,  0,  0 }, {     16,  -35,  -16,  8,  0,  0 }, {     16,  -34,  -16,  8,  0,  0 },
    {     16,  -33,  -16,  8,  0,  0 }, {     16,  -32,  -16,  8,  0,  0 }, {     16,  -31,  -16,  8,  0,  0 }, {     16,  -30,  -16,  8,  0,  0 }, {     16,  -29,  -16,  8,  0,  0 },
    {     16,  -28,  -16,  8,  0,  0 }, {     16,  -27,  -16,  8,  0,  0 }, {     16,  -26,  -16,  8,  0,  0 }, {     16,  -25,  -16,  8,  0,  0 }, {     16,  -24,  -17,  8,  0,  0 },
    {     16,  -23,  -17,  8,  0,  0 }, {     16,  -22,  -17,  8,  5,  0 }, {     16,  -21,  -17,  8,  5,  0 }, {     16,  -20,  -17,  8,  5,  0 }, {     16,  -19,  -17,  8,  5,  0 },
    {     16,  -18,  -18,  8,  5,  0 }, {     16,  -17,  -18,  8,  5,  0 }, {     16,  -16,  -18,  8,  5,  0 }, {     16,  -15,  -18,  8,  5,  0 }, {     16,  -14,  -19,  8,  5,  0 },
    {     16,  -13,  -19,  8,  5,  0 }, {     16,  -12,  -19,  8,  5,  0 }, {     16,  -11,  -20,  8,  5,  0 }, {     16,  -10,  -20,  8,  5,  0 }, {     16,   -9,  -20,  8,  5,  0 },
    {     16,   -8,  -21,  8,  6,  0 }, {     16,   -7,  -21,  8,  6,  0 }, {     16,   -6,  -22,  8,  6,  0 }, {     16,   -5,  -22,  8,  6,  0 }, {     16,   -4,  -23,  8,  6,  0 },
    {     16,   -3,  -23,  8,  6,  0 }, {     16,   -2,  -24,  8,  6,  0 }, {     16,   -1,  -24,  8,  6,  0 }, {     16,    0,  -25,  8,  6,  0 }, {     16,    1,  -25,  8,  6,  0 },
    {     16,    2,  -26,  8,  6,  0 }, {     16,    3,  -26,  8,  6,  0 }, {     16,    4,  -27,  8,  6,  0 }, {     16,    5,  -27,  8,  6,  0 }, {     16,    6,  -28,  8,  6,  0 },
    {     16,    7,  -28,  8,  6,  0 }, {     16,    8,  -28,  8,  5,  0 }, {     16,    9,  -29,  8,  5,  0 }, {     16,   10,  -29,  8,  5,  0 }, {     16,   11,  -29,  8,  5,  0 },
    {     16,   12,  -30,  8,  5,  0 }, {     16,   13,  -30,  8,  5,  0 }, {     16,   14,  -30,  8,  5,  0 }, {     16,   15,  -30,  8,  5,  0 }, {     16,   16,  -31,  8,  5,  0 },
    {     16,   17,  -31,  8,  5,  0 }, {     16,   18,  -31,  8,  5,  0 }, {     16,   19,  -31,  8,  5,  0 }, {     16,   20,  -31,  8,  5,  0 }, {     16,   21,  -31,  8,  5,  0 },
    {     16,   22,  -32,  8,  0,  0 }, {     16,   23,  -32,  8,  0,  0 }, {     16,   24,  -32,  8,  0,  0 }, {     16,   25,  -32,  8,  0,  0 }, {     16,   26,  -32,  8,  0,  0 },
    {     16,   27,  -32,  8,  0,  0 }, {     16,   28,  -32,  8,  0,  0 }, {     16,   29,  -32,  8,  0,  0 }, {     16,   30,  -32,  8,  0,  0 }, {     16,   31,  -32,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_92FE62, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  1 }, {     25,   16,    0,  0,  0,  1 }, {     24,   16,    0,  0,  0,  1 }, {     23,   16,    0,  0,  0,  1 }, {     22,   16,    0,  0,  0,  1 },
    {     21,   16,    0,  0,  0,  1 }, {     20,   16,    0,  0,  0,  1 }, {     19,   16,    0,  0,  0,  1 }, {     18,   16,    0,  0,  0,  1 }, {     17,   16,    0,  0,  0,  1 },
    {     16,   16,    0,  0,  0,  1 }, {     15,   16,    0,  0,  0,  1 }, {     14,   16,    0,  0,  0,  2 }, {     13,   16,    0,  0,  0,  2 }, {     12,   16,    0,  0,  0,  2 },
    {     11,   16,    0,  0,  0,  2 }, {     10,   16,    0,  0,  0,  2 }, {      9,   16,    0,  0,  0,  2 }, {      8,   16,    0,  0,  0,  2 }, {      7,   16,    0,  0,  0,  2 },
    {      6,   16,    0,  0,  0,  2 }, {      5,   16,    0,  0,  0,  2 }, {      4,   16,    0,  0,  0,  2 }, {      3,   16,    0,  0,  0,  2 }, {      2,   16,    0,  0,  0,  5 },
    {      1,   16,    0,  0,  0,  5 }, {      0,   16,    0,  0,  0,  5 }, {     -1,   16,    0,  0,  0,  5 }, {     -2,   16,    0,  0,  0,  5 }, {     -3,   16,    0,  0,  0,  5 },
    {     -4,   16,    0,  0,  0,  5 }, {     -5,   16,    0,  0,  0,  5 }, {     -6,   16,    0,  0,  0,  5 }, {     -7,   16,    0,  0,  0,  5 }, {     -8,   16,    0,  0,  0,  5 },
    {     -9,   16,    0,  0,  0,  5 }, {    -10,   16,    0,  0,  0,  6 }, {    -11,   16,    0,  0,  0,  6 }, {    -12,   16,    0,  0,  0,  6 }, {    -13,   16,    0,  0,  0,  6 },
    {    -14,   16,    0,  0,  0,  6 }, {    -15,   16,    0,  0,  0,  6 }, {    -16,   16,    0,  0,  0,  6 }, {    -17,   16,    0,  0,  0,  6 }, {    -18,   16,    0,  0,  0,  6 },
    {    -19,   16,    0,  0,  0,  6 }, {    -20,   16,    0,  0,  0,  6 }, {    -21,   16,    0,  0,  0,  6 }, {    -22,   16,    0,  0,  0,  7 }, {    -23,   16,    0,  0,  0,  7 },
    {    -24,   16,    0,  0,  0,  7 }, {    -25,   16,    0,  0,  0,  7 }, {    -26,   16,    0,  0,  0,  7 }, {    -27,   16,    0,  0,  0,  7 }, {    -28,   16,    0,  0,  0,  7 },
    {    -29,   16,    0,  0,  0,  7 }, {    -30,   16,    0,  0,  0,  7 }, {    -31,   16,    0,  0,  0,  7 }, {    -32,   16,    0,  0,  0,  7 }, {    -33,   16,    0,  0,  0,  7 },
    {    -34,   16,    0,  0,  0,  8 }, {    -35,   16,    0,  0,  0,  8 }, {    -36,   16,    0,  0,  0,  8 }, {    -37,   16,    0,  0,  0,  8 }, {    -38,   16,    0,  0,  0,  8 },
    {    -39,   16,    0,  0,  0,  8 }, {    -40,   16,    0,  0,  0,  8 }, {    -41,   16,    0,  0,  0,  8 }, {    -42,   16,    0,  0,  0,  8 }, {    -43,   16,    0,  0,  0,  8 },
    {    -44,   16,    0,  0,  0,  8 }, {    -45,   16,    0,  0,  0,  8 }, {    -46,   16,    0,  0,  0,  9 }, {    -47,   16,    0,  0,  0,  9 }, {    -48,   16,    0,  0,  0,  9 },
    {    -49,   16,    0,  0,  0,  9 }, {    -50,   16,    0,  0,  0,  9 }, {    -51,   16,    0,  0,  0,  9 }, {    -52,   16,    0,  0,  0,  9 }, {    -53,   16,    0,  0,  0,  9 },
    {    -54,   16,    0,  0,  0,  9 }, {    -55,   16,    0,  0,  0,  9 }, {    -56,   16,    0,  0,  0,  9 }, {    -57,   16,    0,  0,  0,  9 }, {    -58,   16,    0, 16, 16,  0 },
    {    -59,   16,    0, 16, 16,  0 }, {    -60,   16,    0, 16, 16,  0 }, {    -61,   16,    0, 16, 16,  0 }, {    -62,   16,    0, 16, 16,  0 }, {    -63,   16,    0, 16, 16,  0 },
    {    -64,   16,    0, 16, 16,  0 }, {    -65,   16,    0, 16, 16,  0 }, {    -66,   16,    0, 16, 16,  0 }, {    -67,   16,    0, 16, 16,  0 }, {    -68,   16,    0, 16, 16,  0 },
    {    -69,   16,    0, 16, 16,  0 }, {    -70,   16,    0,  0,  0, 14 }, {    -71,   16,    0,  0,  0, 14 }, {    -72,   16,    0,  0,  0, 14 }, {    -73,   16,    0,  0,  0, 14 },
    {    -74,   16,    0,  0,  0, 14 }, {    -75,   16,    0,  0,  0, 14 }, {    -76,   16,    0,  0,  0, 14 }, {    -77,   16,    0,  0,  0, 14 }, {    -78,   16,    0,  0,  0, 14 },
    {    -79,   16,    0,  0,  0, 14 }, {    -80,   16,    0,  0,  0, 14 }, {    -81,   16,    0,  0,  0, 14 }, {    -82,   16,    0,  0,  0, 13 }, {    -83,   16,    0,  0,  0, 13 },
    {    -84,   16,    0,  0,  0, 13 }, {    -85,   16,    0,  0,  0, 13 }, {    -86,   16,    0,  0,  0, 13 }, {    -87,   16,    0,  0,  0, 13 }, {    -88,   16,    0,  0,  0, 13 },
    {    -89,   16,    0,  0,  0, 13 }, {    -90,   16,    0,  0,  0, 13 }, {    -91,   16,    0,  0,  0, 13 }, {    -92,   16,    0,  0,  0, 13 }, {    -93,   16,    0,  0,  0, 13 },
    {    -94,   16,    0,  0,  0, 12 }, {    -95,   16,    0,  0,  0, 12 }, {    -96,   16,    0,  0,  0, 12 }, {    -97,   16,    0,  0,  0, 12 }, {    -98,   16,    0,  0,  0, 12 },
    {    -99,   16,    0,  0,  0, 12 }, {   -100,   16,    0,  0,  0, 12 }, {   -101,   16,    0,  0,  0, 12 }, {   -102,   16,    0,  0,  0, 12 }, {   -103,   16,    0,  0,  0, 12 },
    {   -104,   16,    0,  0,  0, 12 }, {   -105,   16,    0,  0,  0, 12 }, {   -106,   16,    0,  0,  0, 11 }, {   -107,   16,    0,  0,  0, 11 }, {   -108,   16,    0,  0,  0, 11 },
    {   -109,   16,    0,  0,  0, 11 }, {   -110,   16,    0,  0,  0, 11 }, {   -111,   16,    0,  0,  0, 11 }, {   -112,   16,    0,  0,  0, 11 }, {   -113,   16,    0,  0,  0, 11 },
    {   -114,   16,    0,  0,  0, 11 }, {   -115,   16,    0,  0,  0, 11 }, {   -116,   16,    0,  0,  0, 11 }, {   -117,   16,    0,  0,  0, 11 }, {   -118,   16,    0,  0,  0, 10 },
    {   -119,   16,    0,  0,  0, 10 }, {   -120,   16,    0,  0,  0, 10 }, {   -121,   16,    0,  0,  0, 10 }, {   -122,   16,    0,  0,  0, 10 }, {   -123,   16,    0,  0,  0, 10 },
    {   -124,   16,    0,  0,  0, 10 }, {   -125,   16,    0,  0,  0, 10 }, {   -126,   16,    0,  0,  0, 10 }, {   -127,   16,    0,  0,  0, 10 }, {   -128,   16,    0,  0,  0, 10 },
    {   -129,   16,    0,  0,  0, 10 }, {   -130,   16,    0,  0,  0,  4 }, {   -131,   16,    0,  0,  0,  4 }, {   -132,   16,    0,  0,  0,  4 }, {   -133,   16,    0,  0,  0,  4 },
    {   -134,   16,    0,  0,  0,  4 }, {   -135,   16,    0,  0,  0,  4 }, {   -136,   16,    0,  0,  0,  4 }, {   -137,   16,    0,  0,  0,  4 }, {   -138,   16,    0,  0,  0,  4 },
    {   -139,   16,    0,  0,  0,  4 }, {   -140,   16,    0,  0,  0,  4 }, {   -141,   16,    0,  0,  0,  4 }, {   -142,   16,    0,  0,  0,  3 }, {   -143,   16,    0,  0,  0,  3 },
    {   -144,   16,    0,  0,  0,  3 }, {   -145,   16,    0,  0,  0,  3 }, {   -146,   16,    0,  0,  0,  3 }, {   -147,   16,    0,  0,  0,  3 }, {   -148,   16,    0,  0,  0,  3 },
    {   -149,   16,    0,  0,  0,  3 }, {   -150,   16,    0,  0,  0,  3 }, {   -151,   16,    0,  0,  0,  3 }, {   -152,   16,    0,  0,  0,  3 }, {   -153,   16,    0,  0,  0,  3 },
    {   -154,   16,    0,  0,  0,  0 }, {   -155,   16,    0,  0,  0,  0 }, {   -156,   16,    0,  0,  0,  0 }, {   -157,   16,    0,  0,  0,  0 }, {   -158,   16,    0,  0,  0,  0 },
    {   -159,   16,    0,  0,  0,  0 }, {   -160,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_930524, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  1 }, {     16,    6,    0,  8,  0,  1 }, {     16,    7,    0,  8,  0,  1 }, {     16,    8,    0,  8,  0,  1 }, {     16,    9,    0,  8,  0,  1 },
    {     16,   10,    0,  8,  0,  1 }, {     16,   11,    0,  8,  0,  1 }, {     16,   12,    0,  8,  0,  1 }, {     16,   13,    0,  8,  0,  1 }, {     16,   14,    0,  8,  0,  1 },
    {     16,   15,    0,  8,  0,  1 }, {     16,   16,    0,  8,  0,  1 }, {     16,   17,    0,  8,  0,  2 }, {     16,   18,    0,  8,  0,  2 }, {     16,   19,    0,  8,  0,  2 },
    {     16,   20,    0,  8,  0,  2 }, {     16,   21,    0,  8,  0,  2 }, {     16,   22,    0,  8,  0,  2 }, {     16,   23,    0,  8,  0,  2 }, {     16,   24,    0,  8,  0,  2 },
    {     16,   25,    0,  8,  0,  2 }, {     16,   26,    0,  8,  0,  2 }, {     16,   27,    0,  8,  0,  2 }, {     16,   28,    0,  8,  0,  2 }, {     16,   29,    0,  8,  0,  5 },
    {     16,   30,    0,  8,  0,  5 }, {     16,   31,    0,  8,  0,  5 }, {     16,   32,    0,  8,  0,  5 }, {     16,   33,    0,  8,  0,  5 }, {     16,   34,    0,  8,  0,  5 },
    {     16,   35,    0,  8,  0,  5 }, {     16,   36,    0,  8,  0,  5 }, {     16,   37,    0,  8,  0,  5 }, {     16,   38,    0,  8,  0,  5 }, {     16,   39,    0,  8,  0,  5 },
    {     16,   40,    0,  8,  0,  5 }, {     16,   41,    0,  8,  0,  6 }, {     16,   42,    0,  8,  0,  6 }, {     16,   43,    0,  8,  0,  6 }, {     16,   44,    0,  8,  0,  6 },
    {     16,   45,    0,  8,  0,  6 }, {     16,   46,    0,  8,  0,  6 }, {     16,   47,    0,  8,  0,  6 }, {     16,   48,    0,  8,  0,  6 }, {     16,   49,    0,  8,  0,  6 },
    {     16,   50,    0,  8,  0,  6 }, {     16,   51,    0,  8,  0,  6 }, {     16,   52,    0,  8,  0,  6 }, {     16,   53,    0,  8,  0,  7 }, {     16,   54,    0,  8,  0,  7 },
    {     16,   55,    0,  8,  0,  7 }, {     16,   56,    0,  8,  0,  7 }, {     16,   57,    0,  8,  0,  7 }, {     16,   58,    0,  8,  0,  7 }, {     16,   59,    0,  8,  0,  7 },
    {     16,   60,    0,  8,  0,  7 }, {     16,   61,    0,  8,  0,  7 }, {     16,   62,    0,  8,  0,  7 }, {     16,   63,    0,  8,  0,  7 }, {     16,   64,    0,  8,  0,  7 },
    {     16,   65,    0,  8,  0,  8 }, {     16,   66,    0,  8,  0,  8 }, {     16,   67,    0,  8,  0,  8 }, {     16,   68,    0,  8,  0,  8 }, {     16,   69,    0,  8,  0,  8 },
    {     16,   70,    0,  8,  0,  8 }, {     16,   71,    0,  8,  0,  8 }, {     16,   72,    0,  8,  0,  8 }, {     16,   73,    0,  8,  0,  8 }, {     16,   74,    0,  8,  0,  8 },
    {     16,   75,    0,  8,  0,  8 }, {     16,   76,    0,  8,  0,  8 }, {     16,   77,    0,  8,  0,  9 }, {     16,   78,    0,  8,  0,  9 }, {     16,   79,    0,  8,  0,  9 },
    {     16,   80,    0,  8,  0,  9 }, {     16,   81,    0,  8,  0,  9 }, {     16,   82,    0,  8,  0,  9 }, {     16,   83,    0,  8,  0,  9 }, {     16,   84,    0,  8,  0,  9 },
    {     16,   85,    0,  8,  0,  9 }, {     16,   86,    0,  8,  0,  9 }, {     16,   87,    0,  8,  0,  9 }, {     16,   88,    0,  8,  0,  9 }, {     16,   89,    0, 24, 16,  0 },
    {     16,   90,    0, 24, 16,  0 }, {     16,   91,    0, 24, 16,  0 }, {     16,   92,    0, 24, 16,  0 }, {     16,   93,    0, 24, 16,  0 }, {     16,   94,    0, 24, 16,  0 },
    {     16,   95,    0, 24, 16,  0 }, {     16,   96,    0, 24, 16,  0 }, {     16,   97,    0, 24, 16,  0 }, {     16,   98,    0, 24, 16,  0 }, {     16,   99,    0, 24, 16,  0 },
    {     16,  100,    0, 24, 16,  0 }, {     16,  101,    0,  8,  0, 14 }, {     16,  102,    0,  8,  0, 14 }, {     16,  103,    0,  8,  0, 14 }, {     16,  104,    0,  8,  0, 14 },
    {     16,  105,    0,  8,  0, 14 }, {     16,  106,    0,  8,  0, 14 }, {     16,  107,    0,  8,  0, 14 }, {     16,  108,    0,  8,  0, 14 }, {     16,  109,    0,  8,  0, 14 },
    {     16,  110,    0,  8,  0, 14 }, {     16,  111,    0,  8,  0, 14 }, {     16,  112,    0,  8,  0, 14 }, {     16,  113,    0,  8,  0, 13 }, {     16,  114,    0,  8,  0, 13 },
    {     16,  115,    0,  8,  0, 13 }, {     16,  116,    0,  8,  0, 13 }, {     16,  117,    0,  8,  0, 13 }, {     16,  118,    0,  8,  0, 13 }, {     16,  119,    0,  8,  0, 13 },
    {     16,  120,    0,  8,  0, 13 }, {     16,  121,    0,  8,  0, 13 }, {     16,  122,    0,  8,  0, 13 }, {     16,  123,    0,  8,  0, 13 }, {     16,  124,    0,  8,  0, 13 },
    {     16,  125,    0,  8,  0, 12 }, {     16,  126,    0,  8,  0, 12 }, {     16,  127,    0,  8,  0, 12 }, {     16,  128,    0,  8,  0, 12 }, {     16,  129,    0,  8,  0, 12 },
    {     16,  130,    0,  8,  0, 12 }, {     16,  131,    0,  8,  0, 12 }, {     16,  132,    0,  8,  0, 12 }, {     16,  133,    0,  8,  0, 12 }, {     16,  134,    0,  8,  0, 12 },
    {     16,  135,    0,  8,  0, 12 }, {     16,  136,    0,  8,  0, 12 }, {     16,  137,    0,  8,  0, 11 }, {     16,  138,    0,  8,  0, 11 }, {     16,  139,    0,  8,  0, 11 },
    {     16,  140,    0,  8,  0, 11 }, {     16,  141,    0,  8,  0, 11 }, {     16,  142,    0,  8,  0, 11 }, {     16,  143,    0,  8,  0, 11 }, {     16,  144,    0,  8,  0, 11 },
    {     16,  145,    0,  8,  0, 11 }, {     16,  146,    0,  8,  0, 11 }, {     16,  147,    0,  8,  0, 11 }, {     16,  148,    0,  8,  0, 11 }, {     16,  149,    0,  8,  0, 10 },
    {     16,  150,    0,  8,  0, 10 }, {     16,  151,    0,  8,  0, 10 }, {     16,  152,    0,  8,  0, 10 }, {     16,  153,    0,  8,  0, 10 }, {     16,  154,    0,  8,  0, 10 },
    {     16,  155,    0,  8,  0, 10 }, {     16,  156,    0,  8,  0, 10 }, {     16,  157,    0,  8,  0, 10 }, {     16,  158,    0,  8,  0, 10 }, {     16,  159,    0,  8,  0, 10 },
    {     16,  160,    0,  8,  0, 10 }, {     16,  161,    0,  8,  0,  4 }, {     16,  162,    0,  8,  0,  4 }, {     16,  163,    0,  8,  0,  4 }, {     16,  164,    0,  8,  0,  4 },
    {     16,  165,    0,  8,  0,  4 }, {     16,  166,    0,  8,  0,  4 }, {     16,  167,    0,  8,  0,  4 }, {     16,  168,    0,  8,  0,  4 }, {     16,  169,    0,  8,  0,  4 },
    {     16,  170,    0,  8,  0,  4 }, {     16,  171,    0,  8,  0,  4 }, {     16,  172,    0,  8,  0,  4 }, {     16,  173,    0,  8,  0,  3 }, {     16,  174,    0,  8,  0,  3 },
    {     16,  175,    0,  8,  0,  3 }, {     16,  176,    0,  8,  0,  3 }, {     16,  177,    0,  8,  0,  3 }, {     16,  178,    0,  8,  0,  3 }, {     16,  179,    0,  8,  0,  3 },
    {     16,  180,    0,  8,  0,  3 }, {     16,  181,    0,  8,  0,  3 }, {     16,  182,    0,  8,  0,  3 }, {     16,  183,    0,  8,  0,  3 }, {     16,  184,    0,  8,  0,  3 },
    {     16,  185,    0,  8,  0,  0 }, {     16,  186,    0,  8,  0,  0 }, {     16,  187,    0,  8,  0,  0 }, {     16,  188,    0,  8,  0,  0 }, {     16,  189,    0,  8,  0,  0 },
    {     16,  190,    0,  8,  0,  0 }, {     16,  191,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_930BE6, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  1 }, {      6,   16,    0, 16,  0,  1 }, {      7,   16,    0, 16,  0,  1 }, {      8,   16,    0, 16,  0,  1 }, {      9,   16,    0, 16,  0,  1 },
    {     10,   16,    0, 16,  0,  1 }, {     11,   16,    0, 16,  0,  1 }, {     12,   16,    0, 16,  0,  1 }, {     13,   16,    0, 16,  0,  1 }, {     14,   16,    0, 16,  0,  1 },
    {     15,   16,    0, 16,  0,  1 }, {     16,   16,    0, 16,  0,  1 }, {     17,   16,    0, 16,  0,  2 }, {     18,   16,    0, 16,  0,  2 }, {     19,   16,    0, 16,  0,  2 },
    {     20,   16,    0, 16,  0,  2 }, {     21,   16,    0, 16,  0,  2 }, {     22,   16,    0, 16,  0,  2 }, {     23,   16,    0, 16,  0,  2 }, {     24,   16,    0, 16,  0,  2 },
    {     25,   16,    0, 16,  0,  2 }, {     26,   16,    0, 16,  0,  2 }, {     27,   16,    0, 16,  0,  2 }, {     28,   16,    0, 16,  0,  2 }, {     29,   16,    0, 16,  0,  5 },
    {     30,   16,    0, 16,  0,  5 }, {     31,   16,    0, 16,  0,  5 }, {     32,   16,    0, 16,  0,  5 }, {     33,   16,    0, 16,  0,  5 }, {     34,   16,    0, 16,  0,  5 },
    {     35,   16,    0, 16,  0,  5 }, {     36,   16,    0, 16,  0,  5 }, {     37,   16,    0, 16,  0,  5 }, {     38,   16,    0, 16,  0,  5 }, {     39,   16,    0, 16,  0,  5 },
    {     40,   16,    0, 16,  0,  5 }, {     41,   16,    0, 16,  0,  6 }, {     42,   16,    0, 16,  0,  6 }, {     43,   16,    0, 16,  0,  6 }, {     44,   16,    0, 16,  0,  6 },
    {     45,   16,    0, 16,  0,  6 }, {     46,   16,    0, 16,  0,  6 }, {     47,   16,    0, 16,  0,  6 }, {     48,   16,    0, 16,  0,  6 }, {     49,   16,    0, 16,  0,  6 },
    {     50,   16,    0, 16,  0,  6 }, {     51,   16,    0, 16,  0,  6 }, {     52,   16,    0, 16,  0,  6 }, {     53,   16,    0, 16,  0,  7 }, {     54,   16,    0, 16,  0,  7 },
    {     55,   16,    0, 16,  0,  7 }, {     56,   16,    0, 16,  0,  7 }, {     57,   16,    0, 16,  0,  7 }, {     58,   16,    0, 16,  0,  7 }, {     59,   16,    0, 16,  0,  7 },
    {     60,   16,    0, 16,  0,  7 }, {     61,   16,    0, 16,  0,  7 }, {     62,   16,    0, 16,  0,  7 }, {     63,   16,    0, 16,  0,  7 }, {     64,   16,    0, 16,  0,  7 },
    {     65,   16,    0, 16,  0,  8 }, {     66,   16,    0, 16,  0,  8 }, {     67,   16,    0, 16,  0,  8 }, {     68,   16,    0, 16,  0,  8 }, {     69,   16,    0, 16,  0,  8 },
    {     70,   16,    0, 16,  0,  8 }, {     71,   16,    0, 16,  0,  8 }, {     72,   16,    0, 16,  0,  8 }, {     73,   16,    0, 16,  0,  8 }, {     74,   16,    0, 16,  0,  8 },
    {     75,   16,    0, 16,  0,  8 }, {     76,   16,    0, 16,  0,  8 }, {     77,   16,    0, 16,  0,  9 }, {     78,   16,    0, 16,  0,  9 }, {     79,   16,    0, 16,  0,  9 },
    {     80,   16,    0, 16,  0,  9 }, {     81,   16,    0, 16,  0,  9 }, {     82,   16,    0, 16,  0,  9 }, {     83,   16,    0, 16,  0,  9 }, {     84,   16,    0, 16,  0,  9 },
    {     85,   16,    0, 16,  0,  9 }, {     86,   16,    0, 16,  0,  9 }, {     87,   16,    0, 16,  0,  9 }, {     88,   16,    0, 16,  0,  9 }, {     89,   16,    0,  0, 16,  0 },
    {     90,   16,    0,  0, 16,  0 }, {     91,   16,    0,  0, 16,  0 }, {     92,   16,    0,  0, 16,  0 }, {     93,   16,    0,  0, 16,  0 }, {     94,   16,    0,  0, 16,  0 },
    {     95,   16,    0,  0, 16,  0 }, {     96,   16,    0,  0, 16,  0 }, {     97,   16,    0,  0, 16,  0 }, {     98,   16,    0,  0, 16,  0 }, {     99,   16,    0,  0, 16,  0 },
    {    100,   16,    0,  0, 16,  0 }, {    101,   16,    0, 16,  0, 14 }, {    102,   16,    0, 16,  0, 14 }, {    103,   16,    0, 16,  0, 14 }, {    104,   16,    0, 16,  0, 14 },
    {    105,   16,    0, 16,  0, 14 }, {    106,   16,    0, 16,  0, 14 }, {    107,   16,    0, 16,  0, 14 }, {    108,   16,    0, 16,  0, 14 }, {    109,   16,    0, 16,  0, 14 },
    {    110,   16,    0, 16,  0, 14 }, {    111,   16,    0, 16,  0, 14 }, {    112,   16,    0, 16,  0, 14 }, {    113,   16,    0, 16,  0, 13 }, {    114,   16,    0, 16,  0, 13 },
    {    115,   16,    0, 16,  0, 13 }, {    116,   16,    0, 16,  0, 13 }, {    117,   16,    0, 16,  0, 13 }, {    118,   16,    0, 16,  0, 13 }, {    119,   16,    0, 16,  0, 13 },
    {    120,   16,    0, 16,  0, 13 }, {    121,   16,    0, 16,  0, 13 }, {    122,   16,    0, 16,  0, 13 }, {    123,   16,    0, 16,  0, 13 }, {    124,   16,    0, 16,  0, 13 },
    {    125,   16,    0, 16,  0, 12 }, {    126,   16,    0, 16,  0, 12 }, {    127,   16,    0, 16,  0, 12 }, {    128,   16,    0, 16,  0, 12 }, {    129,   16,    0, 16,  0, 12 },
    {    130,   16,    0, 16,  0, 12 }, {    131,   16,    0, 16,  0, 12 }, {    132,   16,    0, 16,  0, 12 }, {    133,   16,    0, 16,  0, 12 }, {    134,   16,    0, 16,  0, 12 },
    {    135,   16,    0, 16,  0, 12 }, {    136,   16,    0, 16,  0, 12 }, {    137,   16,    0, 16,  0, 11 }, {    138,   16,    0, 16,  0, 11 }, {    139,   16,    0, 16,  0, 11 },
    {    140,   16,    0, 16,  0, 11 }, {    141,   16,    0, 16,  0, 11 }, {    142,   16,    0, 16,  0, 11 }, {    143,   16,    0, 16,  0, 11 }, {    144,   16,    0, 16,  0, 11 },
    {    145,   16,    0, 16,  0, 11 }, {    146,   16,    0, 16,  0, 11 }, {    147,   16,    0, 16,  0, 11 }, {    148,   16,    0, 16,  0, 11 }, {    149,   16,    0, 16,  0, 10 },
    {    150,   16,    0, 16,  0, 10 }, {    151,   16,    0, 16,  0, 10 }, {    152,   16,    0, 16,  0, 10 }, {    153,   16,    0, 16,  0, 10 }, {    154,   16,    0, 16,  0, 10 },
    {    155,   16,    0, 16,  0, 10 }, {    156,   16,    0, 16,  0, 10 }, {    157,   16,    0, 16,  0, 10 }, {    158,   16,    0, 16,  0, 10 }, {    159,   16,    0, 16,  0, 10 },
    {    160,   16,    0, 16,  0, 10 }, {    161,   16,    0, 16,  0,  4 }, {    162,   16,    0, 16,  0,  4 }, {    163,   16,    0, 16,  0,  4 }, {    164,   16,    0, 16,  0,  4 },
    {    165,   16,    0, 16,  0,  4 }, {    166,   16,    0, 16,  0,  4 }, {    167,   16,    0, 16,  0,  4 }, {    168,   16,    0, 16,  0,  4 }, {    169,   16,    0, 16,  0,  4 },
    {    170,   16,    0, 16,  0,  4 }, {    171,   16,    0, 16,  0,  4 }, {    172,   16,    0, 16,  0,  4 }, {    173,   16,    0, 16,  0,  3 }, {    174,   16,    0, 16,  0,  3 },
    {    175,   16,    0, 16,  0,  3 }, {    176,   16,    0, 16,  0,  3 }, {    177,   16,    0, 16,  0,  3 }, {    178,   16,    0, 16,  0,  3 }, {    179,   16,    0, 16,  0,  3 },
    {    180,   16,    0, 16,  0,  3 }, {    181,   16,    0, 16,  0,  3 }, {    182,   16,    0, 16,  0,  3 }, {    183,   16,    0, 16,  0,  3 }, {    184,   16,    0, 16,  0,  3 },
    {    185,   16,    0, 16,  0,  0 }, {    186,   16,    0, 16,  0,  0 }, {    187,   16,    0, 16,  0,  0 }, {    188,   16,    0, 16,  0,  0 }, {    189,   16,    0, 16,  0,  0 },
    {    190,   16,    0, 16,  0,  0 }, {    191,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9312A8, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  1 }, {     16,   25,    0, 24,  0,  1 }, {     16,   24,    0, 24,  0,  1 }, {     16,   23,    0, 24,  0,  1 }, {     16,   22,    0, 24,  0,  1 },
    {     16,   21,    0, 24,  0,  1 }, {     16,   20,    0, 24,  0,  1 }, {     16,   19,    0, 24,  0,  1 }, {     16,   18,    0, 24,  0,  1 }, {     16,   17,    0, 24,  0,  1 },
    {     16,   16,    0, 24,  0,  1 }, {     16,   15,    0, 24,  0,  1 }, {     16,   14,    0, 24,  0,  2 }, {     16,   13,    0, 24,  0,  2 }, {     16,   12,    0, 24,  0,  2 },
    {     16,   11,    0, 24,  0,  2 }, {     16,   10,    0, 24,  0,  2 }, {     16,    9,    0, 24,  0,  2 }, {     16,    8,    0, 24,  0,  2 }, {     16,    7,    0, 24,  0,  2 },
    {     16,    6,    0, 24,  0,  2 }, {     16,    5,    0, 24,  0,  2 }, {     16,    4,    0, 24,  0,  2 }, {     16,    3,    0, 24,  0,  2 }, {     16,    2,    0, 24,  0,  5 },
    {     16,    1,    0, 24,  0,  5 }, {     16,    0,    0, 24,  0,  5 }, {     16,   -1,    0, 24,  0,  5 }, {     16,   -2,    0, 24,  0,  5 }, {     16,   -3,    0, 24,  0,  5 },
    {     16,   -4,    0, 24,  0,  5 }, {     16,   -5,    0, 24,  0,  5 }, {     16,   -6,    0, 24,  0,  5 }, {     16,   -7,    0, 24,  0,  5 }, {     16,   -8,    0, 24,  0,  5 },
    {     16,   -9,    0, 24,  0,  5 }, {     16,  -10,    0, 24,  0,  6 }, {     16,  -11,    0, 24,  0,  6 }, {     16,  -12,    0, 24,  0,  6 }, {     16,  -13,    0, 24,  0,  6 },
    {     16,  -14,    0, 24,  0,  6 }, {     16,  -15,    0, 24,  0,  6 }, {     16,  -16,    0, 24,  0,  6 }, {     16,  -17,    0, 24,  0,  6 }, {     16,  -18,    0, 24,  0,  6 },
    {     16,  -19,    0, 24,  0,  6 }, {     16,  -20,    0, 24,  0,  6 }, {     16,  -21,    0, 24,  0,  6 }, {     16,  -22,    0, 24,  0,  7 }, {     16,  -23,    0, 24,  0,  7 },
    {     16,  -24,    0, 24,  0,  7 }, {     16,  -25,    0, 24,  0,  7 }, {     16,  -26,    0, 24,  0,  7 }, {     16,  -27,    0, 24,  0,  7 }, {     16,  -28,    0, 24,  0,  7 },
    {     16,  -29,    0, 24,  0,  7 }, {     16,  -30,    0, 24,  0,  7 }, {     16,  -31,    0, 24,  0,  7 }, {     16,  -32,    0, 24,  0,  7 }, {     16,  -33,    0, 24,  0,  7 },
    {     16,  -34,    0, 24,  0,  8 }, {     16,  -35,    0, 24,  0,  8 }, {     16,  -36,    0, 24,  0,  8 }, {     16,  -37,    0, 24,  0,  8 }, {     16,  -38,    0, 24,  0,  8 },
    {     16,  -39,    0, 24,  0,  8 }, {     16,  -40,    0, 24,  0,  8 }, {     16,  -41,    0, 24,  0,  8 }, {     16,  -42,    0, 24,  0,  8 }, {     16,  -43,    0, 24,  0,  8 },
    {     16,  -44,    0, 24,  0,  8 }, {     16,  -45,    0, 24,  0,  8 }, {     16,  -46,    0, 24,  0,  9 }, {     16,  -47,    0, 24,  0,  9 }, {     16,  -48,    0, 24,  0,  9 },
    {     16,  -49,    0, 24,  0,  9 }, {     16,  -50,    0, 24,  0,  9 }, {     16,  -51,    0, 24,  0,  9 }, {     16,  -52,    0, 24,  0,  9 }, {     16,  -53,    0, 24,  0,  9 },
    {     16,  -54,    0, 24,  0,  9 }, {     16,  -55,    0, 24,  0,  9 }, {     16,  -56,    0, 24,  0,  9 }, {     16,  -57,    0, 24,  0,  9 }, {     16,  -58,    0,  8, 16,  0 },
    {     16,  -59,    0,  8, 16,  0 }, {     16,  -60,    0,  8, 16,  0 }, {     16,  -61,    0,  8, 16,  0 }, {     16,  -62,    0,  8, 16,  0 }, {     16,  -63,    0,  8, 16,  0 },
    {     16,  -64,    0,  8, 16,  0 }, {     16,  -65,    0,  8, 16,  0 }, {     16,  -66,    0,  8, 16,  0 }, {     16,  -67,    0,  8, 16,  0 }, {     16,  -68,    0,  8, 16,  0 },
    {     16,  -69,    0,  8, 16,  0 }, {     16,  -70,    0, 24,  0, 14 }, {     16,  -71,    0, 24,  0, 14 }, {     16,  -72,    0, 24,  0, 14 }, {     16,  -73,    0, 24,  0, 14 },
    {     16,  -74,    0, 24,  0, 14 }, {     16,  -75,    0, 24,  0, 14 }, {     16,  -76,    0, 24,  0, 14 }, {     16,  -77,    0, 24,  0, 14 }, {     16,  -78,    0, 24,  0, 14 },
    {     16,  -79,    0, 24,  0, 14 }, {     16,  -80,    0, 24,  0, 14 }, {     16,  -81,    0, 24,  0, 14 }, {     16,  -82,    0, 24,  0, 13 }, {     16,  -83,    0, 24,  0, 13 },
    {     16,  -84,    0, 24,  0, 13 }, {     16,  -85,    0, 24,  0, 13 }, {     16,  -86,    0, 24,  0, 13 }, {     16,  -87,    0, 24,  0, 13 }, {     16,  -88,    0, 24,  0, 13 },
    {     16,  -89,    0, 24,  0, 13 }, {     16,  -90,    0, 24,  0, 13 }, {     16,  -91,    0, 24,  0, 13 }, {     16,  -92,    0, 24,  0, 13 }, {     16,  -93,    0, 24,  0, 13 },
    {     16,  -94,    0, 24,  0, 12 }, {     16,  -95,    0, 24,  0, 12 }, {     16,  -96,    0, 24,  0, 12 }, {     16,  -97,    0, 24,  0, 12 }, {     16,  -98,    0, 24,  0, 12 },
    {     16,  -99,    0, 24,  0, 12 }, {     16, -100,    0, 24,  0, 12 }, {     16, -101,    0, 24,  0, 12 }, {     16, -102,    0, 24,  0, 12 }, {     16, -103,    0, 24,  0, 12 },
    {     16, -104,    0, 24,  0, 12 }, {     16, -105,    0, 24,  0, 12 }, {     16, -106,    0, 24,  0, 11 }, {     16, -107,    0, 24,  0, 11 }, {     16, -108,    0, 24,  0, 11 },
    {     16, -109,    0, 24,  0, 11 }, {     16, -110,    0, 24,  0, 11 }, {     16, -111,    0, 24,  0, 11 }, {     16, -112,    0, 24,  0, 11 }, {     16, -113,    0, 24,  0, 11 },
    {     16, -114,    0, 24,  0, 11 }, {     16, -115,    0, 24,  0, 11 }, {     16, -116,    0, 24,  0, 11 }, {     16, -117,    0, 24,  0, 11 }, {     16, -118,    0, 24,  0, 10 },
    {     16, -119,    0, 24,  0, 10 }, {     16, -120,    0, 24,  0, 10 }, {     16, -121,    0, 24,  0, 10 }, {     16, -122,    0, 24,  0, 10 }, {     16, -123,    0, 24,  0, 10 },
    {     16, -124,    0, 24,  0, 10 }, {     16, -125,    0, 24,  0, 10 }, {     16, -126,    0, 24,  0, 10 }, {     16, -127,    0, 24,  0, 10 }, {     16, -128,    0, 24,  0, 10 },
    {     16, -129,    0, 24,  0, 10 }, {     16, -130,    0, 24,  0,  4 }, {     16, -131,    0, 24,  0,  4 }, {     16, -132,    0, 24,  0,  4 }, {     16, -133,    0, 24,  0,  4 },
    {     16, -134,    0, 24,  0,  4 }, {     16, -135,    0, 24,  0,  4 }, {     16, -136,    0, 24,  0,  4 }, {     16, -137,    0, 24,  0,  4 }, {     16, -138,    0, 24,  0,  4 },
    {     16, -139,    0, 24,  0,  4 }, {     16, -140,    0, 24,  0,  4 }, {     16, -141,    0, 24,  0,  4 }, {     16, -142,    0, 24,  0,  3 }, {     16, -143,    0, 24,  0,  3 },
    {     16, -144,    0, 24,  0,  3 }, {     16, -145,    0, 24,  0,  3 }, {     16, -146,    0, 24,  0,  3 }, {     16, -147,    0, 24,  0,  3 }, {     16, -148,    0, 24,  0,  3 },
    {     16, -149,    0, 24,  0,  3 }, {     16, -150,    0, 24,  0,  3 }, {     16, -151,    0, 24,  0,  3 }, {     16, -152,    0, 24,  0,  3 }, {     16, -153,    0, 24,  0,  3 },
    {     16, -154,    0, 24,  0,  0 }, {     16, -155,    0, 24,  0,  0 }, {     16, -156,    0, 24,  0,  0 }, {     16, -157,    0, 24,  0,  0 }, {     16, -158,    0, 24,  0,  0 },
    {     16, -159,    0, 24,  0,  0 }, {     16, -160,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93196A, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  3 }, {     25,   16,    0,  0,  0,  3 }, {     24,   16,    0,  0,  0,  3 }, {     23,   16,    0,  0,  0,  3 }, {     22,   16,    0,  0,  0,  3 },
    {     21,   16,    0,  0,  0,  3 }, {     20,   16,    0,  0,  0,  3 }, {     19,   16,    0,  0,  0,  3 }, {     18,   16,    0,  0,  0,  3 }, {     17,   16,    0,  0,  0,  3 },
    {     16,   16,    0,  0,  0,  3 }, {     15,   16,    0,  0,  0,  3 }, {     14,   16,    0,  0,  0,  4 }, {     13,   16,    0,  0,  0,  4 }, {     12,   16,    0,  0,  0,  4 },
    {     11,   16,    0,  0,  0,  4 }, {     10,   16,    0,  0,  0,  4 }, {      9,   16,    0,  0,  0,  4 }, {      8,   16,    0,  0,  0,  4 }, {      7,   16,    0,  0,  0,  4 },
    {      6,   16,    0,  0,  0,  4 }, {      5,   16,    0,  0,  0,  4 }, {      4,   16,    0,  0,  0,  4 }, {      3,   16,    0,  0,  0,  4 }, {      2,   16,    0,  0,  0, 10 },
    {      1,   16,    0,  0,  0, 10 }, {      0,   16,    0,  0,  0, 10 }, {     -1,   16,    0,  0,  0, 10 }, {     -2,   16,    0,  0,  0, 10 }, {     -3,   16,    0,  0,  0, 10 },
    {     -4,   16,    0,  0,  0, 10 }, {     -5,   16,    0,  0,  0, 10 }, {     -6,   16,    0,  0,  0, 10 }, {     -7,   16,    0,  0,  0, 10 }, {     -8,   16,    0,  0,  0, 10 },
    {     -9,   16,    0,  0,  0, 10 }, {    -10,   16,    0,  0,  0, 11 }, {    -11,   16,    0,  0,  0, 11 }, {    -12,   16,    0,  0,  0, 11 }, {    -13,   16,    0,  0,  0, 11 },
    {    -14,   16,    0,  0,  0, 11 }, {    -15,   16,    0,  0,  0, 11 }, {    -16,   16,    0,  0,  0, 11 }, {    -17,   16,    0,  0,  0, 11 }, {    -18,   16,    0,  0,  0, 11 },
    {    -19,   16,    0,  0,  0, 11 }, {    -20,   16,    0,  0,  0, 11 }, {    -21,   16,    0,  0,  0, 11 }, {    -22,   16,    0,  0,  0, 12 }, {    -23,   16,    0,  0,  0, 12 },
    {    -24,   16,    0,  0,  0, 12 }, {    -25,   16,    0,  0,  0, 12 }, {    -26,   16,    0,  0,  0, 12 }, {    -27,   16,    0,  0,  0, 12 }, {    -28,   16,    0,  0,  0, 12 },
    {    -29,   16,    0,  0,  0, 12 }, {    -30,   16,    0,  0,  0, 12 }, {    -31,   16,    0,  0,  0, 12 }, {    -32,   16,    0,  0,  0, 12 }, {    -33,   16,    0,  0,  0, 12 },
    {    -34,   16,    0,  0,  0, 13 }, {    -35,   16,    0,  0,  0, 13 }, {    -36,   16,    0,  0,  0, 13 }, {    -37,   16,    0,  0,  0, 13 }, {    -38,   16,    0,  0,  0, 13 },
    {    -39,   16,    0,  0,  0, 13 }, {    -40,   16,    0,  0,  0, 13 }, {    -41,   16,    0,  0,  0, 13 }, {    -42,   16,    0,  0,  0, 13 }, {    -43,   16,    0,  0,  0, 13 },
    {    -44,   16,    0,  0,  0, 13 }, {    -45,   16,    0,  0,  0, 13 }, {    -46,   16,    0,  0,  0, 14 }, {    -47,   16,    0,  0,  0, 14 }, {    -48,   16,    0,  0,  0, 14 },
    {    -49,   16,    0,  0,  0, 14 }, {    -50,   16,    0,  0,  0, 14 }, {    -51,   16,    0,  0,  0, 14 }, {    -52,   16,    0,  0,  0, 14 }, {    -53,   16,    0,  0,  0, 14 },
    {    -54,   16,    0,  0,  0, 14 }, {    -55,   16,    0,  0,  0, 14 }, {    -56,   16,    0,  0,  0, 14 }, {    -57,   16,    0,  0,  0, 14 }, {    -58,   16,    0, 16, 16,  0 },
    {    -59,   16,    0, 16, 16,  0 }, {    -60,   16,    0, 16, 16,  0 }, {    -61,   16,    0, 16, 16,  0 }, {    -62,   16,    0, 16, 16,  0 }, {    -63,   16,    0, 16, 16,  0 },
    {    -64,   16,    0, 16, 16,  0 }, {    -65,   16,    0, 16, 16,  0 }, {    -66,   16,    0, 16, 16,  0 }, {    -67,   16,    0, 16, 16,  0 }, {    -68,   16,    0, 16, 16,  0 },
    {    -69,   16,    0, 16, 16,  0 }, {    -70,   16,    0,  0,  0,  9 }, {    -71,   16,    0,  0,  0,  9 }, {    -72,   16,    0,  0,  0,  9 }, {    -73,   16,    0,  0,  0,  9 },
    {    -74,   16,    0,  0,  0,  9 }, {    -75,   16,    0,  0,  0,  9 }, {    -76,   16,    0,  0,  0,  9 }, {    -77,   16,    0,  0,  0,  9 }, {    -78,   16,    0,  0,  0,  9 },
    {    -79,   16,    0,  0,  0,  9 }, {    -80,   16,    0,  0,  0,  9 }, {    -81,   16,    0,  0,  0,  9 }, {    -82,   16,    0,  0,  0,  8 }, {    -83,   16,    0,  0,  0,  8 },
    {    -84,   16,    0,  0,  0,  8 }, {    -85,   16,    0,  0,  0,  8 }, {    -86,   16,    0,  0,  0,  8 }, {    -87,   16,    0,  0,  0,  8 }, {    -88,   16,    0,  0,  0,  8 },
    {    -89,   16,    0,  0,  0,  8 }, {    -90,   16,    0,  0,  0,  8 }, {    -91,   16,    0,  0,  0,  8 }, {    -92,   16,    0,  0,  0,  8 }, {    -93,   16,    0,  0,  0,  8 },
    {    -94,   16,    0,  0,  0,  7 }, {    -95,   16,    0,  0,  0,  7 }, {    -96,   16,    0,  0,  0,  7 }, {    -97,   16,    0,  0,  0,  7 }, {    -98,   16,    0,  0,  0,  7 },
    {    -99,   16,    0,  0,  0,  7 }, {   -100,   16,    0,  0,  0,  7 }, {   -101,   16,    0,  0,  0,  7 }, {   -102,   16,    0,  0,  0,  7 }, {   -103,   16,    0,  0,  0,  7 },
    {   -104,   16,    0,  0,  0,  7 }, {   -105,   16,    0,  0,  0,  7 }, {   -106,   16,    0,  0,  0,  6 }, {   -107,   16,    0,  0,  0,  6 }, {   -108,   16,    0,  0,  0,  6 },
    {   -109,   16,    0,  0,  0,  6 }, {   -110,   16,    0,  0,  0,  6 }, {   -111,   16,    0,  0,  0,  6 }, {   -112,   16,    0,  0,  0,  6 }, {   -113,   16,    0,  0,  0,  6 },
    {   -114,   16,    0,  0,  0,  6 }, {   -115,   16,    0,  0,  0,  6 }, {   -116,   16,    0,  0,  0,  6 }, {   -117,   16,    0,  0,  0,  6 }, {   -118,   16,    0,  0,  0,  5 },
    {   -119,   16,    0,  0,  0,  5 }, {   -120,   16,    0,  0,  0,  5 }, {   -121,   16,    0,  0,  0,  5 }, {   -122,   16,    0,  0,  0,  5 }, {   -123,   16,    0,  0,  0,  5 },
    {   -124,   16,    0,  0,  0,  5 }, {   -125,   16,    0,  0,  0,  5 }, {   -126,   16,    0,  0,  0,  5 }, {   -127,   16,    0,  0,  0,  5 }, {   -128,   16,    0,  0,  0,  5 },
    {   -129,   16,    0,  0,  0,  5 }, {   -130,   16,    0,  0,  0,  2 }, {   -131,   16,    0,  0,  0,  2 }, {   -132,   16,    0,  0,  0,  2 }, {   -133,   16,    0,  0,  0,  2 },
    {   -134,   16,    0,  0,  0,  2 }, {   -135,   16,    0,  0,  0,  2 }, {   -136,   16,    0,  0,  0,  2 }, {   -137,   16,    0,  0,  0,  2 }, {   -138,   16,    0,  0,  0,  2 },
    {   -139,   16,    0,  0,  0,  2 }, {   -140,   16,    0,  0,  0,  2 }, {   -141,   16,    0,  0,  0,  2 }, {   -142,   16,    0,  0,  0,  1 }, {   -143,   16,    0,  0,  0,  1 },
    {   -144,   16,    0,  0,  0,  1 }, {   -145,   16,    0,  0,  0,  1 }, {   -146,   16,    0,  0,  0,  1 }, {   -147,   16,    0,  0,  0,  1 }, {   -148,   16,    0,  0,  0,  1 },
    {   -149,   16,    0,  0,  0,  1 }, {   -150,   16,    0,  0,  0,  1 }, {   -151,   16,    0,  0,  0,  1 }, {   -152,   16,    0,  0,  0,  1 }, {   -153,   16,    0,  0,  0,  1 },
    {   -154,   16,    0,  0,  0,  0 }, {   -155,   16,    0,  0,  0,  0 }, {   -156,   16,    0,  0,  0,  0 }, {   -157,   16,    0,  0,  0,  0 }, {   -158,   16,    0,  0,  0,  0 },
    {   -159,   16,    0,  0,  0,  0 }, {   -160,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93202C, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  3 }, {     16,    6,    0,  8,  0,  3 }, {     16,    7,    0,  8,  0,  3 }, {     16,    8,    0,  8,  0,  3 }, {     16,    9,    0,  8,  0,  3 },
    {     16,   10,    0,  8,  0,  3 }, {     16,   11,    0,  8,  0,  3 }, {     16,   12,    0,  8,  0,  3 }, {     16,   13,    0,  8,  0,  3 }, {     16,   14,    0,  8,  0,  3 },
    {     16,   15,    0,  8,  0,  3 }, {     16,   16,    0,  8,  0,  3 }, {     16,   17,    0,  8,  0,  4 }, {     16,   18,    0,  8,  0,  4 }, {     16,   19,    0,  8,  0,  4 },
    {     16,   20,    0,  8,  0,  4 }, {     16,   21,    0,  8,  0,  4 }, {     16,   22,    0,  8,  0,  4 }, {     16,   23,    0,  8,  0,  4 }, {     16,   24,    0,  8,  0,  4 },
    {     16,   25,    0,  8,  0,  4 }, {     16,   26,    0,  8,  0,  4 }, {     16,   27,    0,  8,  0,  4 }, {     16,   28,    0,  8,  0,  4 }, {     16,   29,    0,  8,  0, 10 },
    {     16,   30,    0,  8,  0, 10 }, {     16,   31,    0,  8,  0, 10 }, {     16,   32,    0,  8,  0, 10 }, {     16,   33,    0,  8,  0, 10 }, {     16,   34,    0,  8,  0, 10 },
    {     16,   35,    0,  8,  0, 10 }, {     16,   36,    0,  8,  0, 10 }, {     16,   37,    0,  8,  0, 10 }, {     16,   38,    0,  8,  0, 10 }, {     16,   39,    0,  8,  0, 10 },
    {     16,   40,    0,  8,  0, 10 }, {     16,   41,    0,  8,  0, 11 }, {     16,   42,    0,  8,  0, 11 }, {     16,   43,    0,  8,  0, 11 }, {     16,   44,    0,  8,  0, 11 },
    {     16,   45,    0,  8,  0, 11 }, {     16,   46,    0,  8,  0, 11 }, {     16,   47,    0,  8,  0, 11 }, {     16,   48,    0,  8,  0, 11 }, {     16,   49,    0,  8,  0, 11 },
    {     16,   50,    0,  8,  0, 11 }, {     16,   51,    0,  8,  0, 11 }, {     16,   52,    0,  8,  0, 11 }, {     16,   53,    0,  8,  0, 12 }, {     16,   54,    0,  8,  0, 12 },
    {     16,   55,    0,  8,  0, 12 }, {     16,   56,    0,  8,  0, 12 }, {     16,   57,    0,  8,  0, 12 }, {     16,   58,    0,  8,  0, 12 }, {     16,   59,    0,  8,  0, 12 },
    {     16,   60,    0,  8,  0, 12 }, {     16,   61,    0,  8,  0, 12 }, {     16,   62,    0,  8,  0, 12 }, {     16,   63,    0,  8,  0, 12 }, {     16,   64,    0,  8,  0, 12 },
    {     16,   65,    0,  8,  0, 13 }, {     16,   66,    0,  8,  0, 13 }, {     16,   67,    0,  8,  0, 13 }, {     16,   68,    0,  8,  0, 13 }, {     16,   69,    0,  8,  0, 13 },
    {     16,   70,    0,  8,  0, 13 }, {     16,   71,    0,  8,  0, 13 }, {     16,   72,    0,  8,  0, 13 }, {     16,   73,    0,  8,  0, 13 }, {     16,   74,    0,  8,  0, 13 },
    {     16,   75,    0,  8,  0, 13 }, {     16,   76,    0,  8,  0, 13 }, {     16,   77,    0,  8,  0, 14 }, {     16,   78,    0,  8,  0, 14 }, {     16,   79,    0,  8,  0, 14 },
    {     16,   80,    0,  8,  0, 14 }, {     16,   81,    0,  8,  0, 14 }, {     16,   82,    0,  8,  0, 14 }, {     16,   83,    0,  8,  0, 14 }, {     16,   84,    0,  8,  0, 14 },
    {     16,   85,    0,  8,  0, 14 }, {     16,   86,    0,  8,  0, 14 }, {     16,   87,    0,  8,  0, 14 }, {     16,   88,    0,  8,  0, 14 }, {     16,   89,    0, 24, 16,  0 },
    {     16,   90,    0, 24, 16,  0 }, {     16,   91,    0, 24, 16,  0 }, {     16,   92,    0, 24, 16,  0 }, {     16,   93,    0, 24, 16,  0 }, {     16,   94,    0, 24, 16,  0 },
    {     16,   95,    0, 24, 16,  0 }, {     16,   96,    0, 24, 16,  0 }, {     16,   97,    0, 24, 16,  0 }, {     16,   98,    0, 24, 16,  0 }, {     16,   99,    0, 24, 16,  0 },
    {     16,  100,    0, 24, 16,  0 }, {     16,  101,    0,  8,  0,  9 }, {     16,  102,    0,  8,  0,  9 }, {     16,  103,    0,  8,  0,  9 }, {     16,  104,    0,  8,  0,  9 },
    {     16,  105,    0,  8,  0,  9 }, {     16,  106,    0,  8,  0,  9 }, {     16,  107,    0,  8,  0,  9 }, {     16,  108,    0,  8,  0,  9 }, {     16,  109,    0,  8,  0,  9 },
    {     16,  110,    0,  8,  0,  9 }, {     16,  111,    0,  8,  0,  9 }, {     16,  112,    0,  8,  0,  9 }, {     16,  113,    0,  8,  0,  8 }, {     16,  114,    0,  8,  0,  8 },
    {     16,  115,    0,  8,  0,  8 }, {     16,  116,    0,  8,  0,  8 }, {     16,  117,    0,  8,  0,  8 }, {     16,  118,    0,  8,  0,  8 }, {     16,  119,    0,  8,  0,  8 },
    {     16,  120,    0,  8,  0,  8 }, {     16,  121,    0,  8,  0,  8 }, {     16,  122,    0,  8,  0,  8 }, {     16,  123,    0,  8,  0,  8 }, {     16,  124,    0,  8,  0,  8 },
    {     16,  125,    0,  8,  0,  7 }, {     16,  126,    0,  8,  0,  7 }, {     16,  127,    0,  8,  0,  7 }, {     16,  128,    0,  8,  0,  7 }, {     16,  129,    0,  8,  0,  7 },
    {     16,  130,    0,  8,  0,  7 }, {     16,  131,    0,  8,  0,  7 }, {     16,  132,    0,  8,  0,  7 }, {     16,  133,    0,  8,  0,  7 }, {     16,  134,    0,  8,  0,  7 },
    {     16,  135,    0,  8,  0,  7 }, {     16,  136,    0,  8,  0,  7 }, {     16,  137,    0,  8,  0,  6 }, {     16,  138,    0,  8,  0,  6 }, {     16,  139,    0,  8,  0,  6 },
    {     16,  140,    0,  8,  0,  6 }, {     16,  141,    0,  8,  0,  6 }, {     16,  142,    0,  8,  0,  6 }, {     16,  143,    0,  8,  0,  6 }, {     16,  144,    0,  8,  0,  6 },
    {     16,  145,    0,  8,  0,  6 }, {     16,  146,    0,  8,  0,  6 }, {     16,  147,    0,  8,  0,  6 }, {     16,  148,    0,  8,  0,  6 }, {     16,  149,    0,  8,  0,  5 },
    {     16,  150,    0,  8,  0,  5 }, {     16,  151,    0,  8,  0,  5 }, {     16,  152,    0,  8,  0,  5 }, {     16,  153,    0,  8,  0,  5 }, {     16,  154,    0,  8,  0,  5 },
    {     16,  155,    0,  8,  0,  5 }, {     16,  156,    0,  8,  0,  5 }, {     16,  157,    0,  8,  0,  5 }, {     16,  158,    0,  8,  0,  5 }, {     16,  159,    0,  8,  0,  5 },
    {     16,  160,    0,  8,  0,  5 }, {     16,  161,    0,  8,  0,  2 }, {     16,  162,    0,  8,  0,  2 }, {     16,  163,    0,  8,  0,  2 }, {     16,  164,    0,  8,  0,  2 },
    {     16,  165,    0,  8,  0,  2 }, {     16,  166,    0,  8,  0,  2 }, {     16,  167,    0,  8,  0,  2 }, {     16,  168,    0,  8,  0,  2 }, {     16,  169,    0,  8,  0,  2 },
    {     16,  170,    0,  8,  0,  2 }, {     16,  171,    0,  8,  0,  2 }, {     16,  172,    0,  8,  0,  2 }, {     16,  173,    0,  8,  0,  1 }, {     16,  174,    0,  8,  0,  1 },
    {     16,  175,    0,  8,  0,  1 }, {     16,  176,    0,  8,  0,  1 }, {     16,  177,    0,  8,  0,  1 }, {     16,  178,    0,  8,  0,  1 }, {     16,  179,    0,  8,  0,  1 },
    {     16,  180,    0,  8,  0,  1 }, {     16,  181,    0,  8,  0,  1 }, {     16,  182,    0,  8,  0,  1 }, {     16,  183,    0,  8,  0,  1 }, {     16,  184,    0,  8,  0,  1 },
    {     16,  185,    0,  8,  0,  0 }, {     16,  186,    0,  8,  0,  0 }, {     16,  187,    0,  8,  0,  0 }, {     16,  188,    0,  8,  0,  0 }, {     16,  189,    0,  8,  0,  0 },
    {     16,  190,    0,  8,  0,  0 }, {     16,  191,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9326EE, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  3 }, {      6,   16,    0, 16,  0,  3 }, {      7,   16,    0, 16,  0,  3 }, {      8,   16,    0, 16,  0,  3 }, {      9,   16,    0, 16,  0,  3 },
    {     10,   16,    0, 16,  0,  3 }, {     11,   16,    0, 16,  0,  3 }, {     12,   16,    0, 16,  0,  3 }, {     13,   16,    0, 16,  0,  3 }, {     14,   16,    0, 16,  0,  3 },
    {     15,   16,    0, 16,  0,  3 }, {     16,   16,    0, 16,  0,  3 }, {     17,   16,    0, 16,  0,  4 }, {     18,   16,    0, 16,  0,  4 }, {     19,   16,    0, 16,  0,  4 },
    {     20,   16,    0, 16,  0,  4 }, {     21,   16,    0, 16,  0,  4 }, {     22,   16,    0, 16,  0,  4 }, {     23,   16,    0, 16,  0,  4 }, {     24,   16,    0, 16,  0,  4 },
    {     25,   16,    0, 16,  0,  4 }, {     26,   16,    0, 16,  0,  4 }, {     27,   16,    0, 16,  0,  4 }, {     28,   16,    0, 16,  0,  4 }, {     29,   16,    0, 16,  0, 10 },
    {     30,   16,    0, 16,  0, 10 }, {     31,   16,    0, 16,  0, 10 }, {     32,   16,    0, 16,  0, 10 }, {     33,   16,    0, 16,  0, 10 }, {     34,   16,    0, 16,  0, 10 },
    {     35,   16,    0, 16,  0, 10 }, {     36,   16,    0, 16,  0, 10 }, {     37,   16,    0, 16,  0, 10 }, {     38,   16,    0, 16,  0, 10 }, {     39,   16,    0, 16,  0, 10 },
    {     40,   16,    0, 16,  0, 10 }, {     41,   16,    0, 16,  0, 11 }, {     42,   16,    0, 16,  0, 11 }, {     43,   16,    0, 16,  0, 11 }, {     44,   16,    0, 16,  0, 11 },
    {     45,   16,    0, 16,  0, 11 }, {     46,   16,    0, 16,  0, 11 }, {     47,   16,    0, 16,  0, 11 }, {     48,   16,    0, 16,  0, 11 }, {     49,   16,    0, 16,  0, 11 },
    {     50,   16,    0, 16,  0, 11 }, {     51,   16,    0, 16,  0, 11 }, {     52,   16,    0, 16,  0, 11 }, {     53,   16,    0, 16,  0, 12 }, {     54,   16,    0, 16,  0, 12 },
    {     55,   16,    0, 16,  0, 12 }, {     56,   16,    0, 16,  0, 12 }, {     57,   16,    0, 16,  0, 12 }, {     58,   16,    0, 16,  0, 12 }, {     59,   16,    0, 16,  0, 12 },
    {     60,   16,    0, 16,  0, 12 }, {     61,   16,    0, 16,  0, 12 }, {     62,   16,    0, 16,  0, 12 }, {     63,   16,    0, 16,  0, 12 }, {     64,   16,    0, 16,  0, 12 },
    {     65,   16,    0, 16,  0, 13 }, {     66,   16,    0, 16,  0, 13 }, {     67,   16,    0, 16,  0, 13 }, {     68,   16,    0, 16,  0, 13 }, {     69,   16,    0, 16,  0, 13 },
    {     70,   16,    0, 16,  0, 13 }, {     71,   16,    0, 16,  0, 13 }, {     72,   16,    0, 16,  0, 13 }, {     73,   16,    0, 16,  0, 13 }, {     74,   16,    0, 16,  0, 13 },
    {     75,   16,    0, 16,  0, 13 }, {     76,   16,    0, 16,  0, 13 }, {     77,   16,    0, 16,  0, 14 }, {     78,   16,    0, 16,  0, 14 }, {     79,   16,    0, 16,  0, 14 },
    {     80,   16,    0, 16,  0, 14 }, {     81,   16,    0, 16,  0, 14 }, {     82,   16,    0, 16,  0, 14 }, {     83,   16,    0, 16,  0, 14 }, {     84,   16,    0, 16,  0, 14 },
    {     85,   16,    0, 16,  0, 14 }, {     86,   16,    0, 16,  0, 14 }, {     87,   16,    0, 16,  0, 14 }, {     88,   16,    0, 16,  0, 14 }, {     89,   16,    0,  0, 16,  0 },
    {     90,   16,    0,  0, 16,  0 }, {     91,   16,    0,  0, 16,  0 }, {     92,   16,    0,  0, 16,  0 }, {     93,   16,    0,  0, 16,  0 }, {     94,   16,    0,  0, 16,  0 },
    {     95,   16,    0,  0, 16,  0 }, {     96,   16,    0,  0, 16,  0 }, {     97,   16,    0,  0, 16,  0 }, {     98,   16,    0,  0, 16,  0 }, {     99,   16,    0,  0, 16,  0 },
    {    100,   16,    0,  0, 16,  0 }, {    101,   16,    0, 16,  0,  9 }, {    102,   16,    0, 16,  0,  9 }, {    103,   16,    0, 16,  0,  9 }, {    104,   16,    0, 16,  0,  9 },
    {    105,   16,    0, 16,  0,  9 }, {    106,   16,    0, 16,  0,  9 }, {    107,   16,    0, 16,  0,  9 }, {    108,   16,    0, 16,  0,  9 }, {    109,   16,    0, 16,  0,  9 },
    {    110,   16,    0, 16,  0,  9 }, {    111,   16,    0, 16,  0,  9 }, {    112,   16,    0, 16,  0,  9 }, {    113,   16,    0, 16,  0,  8 }, {    114,   16,    0, 16,  0,  8 },
    {    115,   16,    0, 16,  0,  8 }, {    116,   16,    0, 16,  0,  8 }, {    117,   16,    0, 16,  0,  8 }, {    118,   16,    0, 16,  0,  8 }, {    119,   16,    0, 16,  0,  8 },
    {    120,   16,    0, 16,  0,  8 }, {    121,   16,    0, 16,  0,  8 }, {    122,   16,    0, 16,  0,  8 }, {    123,   16,    0, 16,  0,  8 }, {    124,   16,    0, 16,  0,  8 },
    {    125,   16,    0, 16,  0,  7 }, {    126,   16,    0, 16,  0,  7 }, {    127,   16,    0, 16,  0,  7 }, {    128,   16,    0, 16,  0,  7 }, {    129,   16,    0, 16,  0,  7 },
    {    130,   16,    0, 16,  0,  7 }, {    131,   16,    0, 16,  0,  7 }, {    132,   16,    0, 16,  0,  7 }, {    133,   16,    0, 16,  0,  7 }, {    134,   16,    0, 16,  0,  7 },
    {    135,   16,    0, 16,  0,  7 }, {    136,   16,    0, 16,  0,  7 }, {    137,   16,    0, 16,  0,  6 }, {    138,   16,    0, 16,  0,  6 }, {    139,   16,    0, 16,  0,  6 },
    {    140,   16,    0, 16,  0,  6 }, {    141,   16,    0, 16,  0,  6 }, {    142,   16,    0, 16,  0,  6 }, {    143,   16,    0, 16,  0,  6 }, {    144,   16,    0, 16,  0,  6 },
    {    145,   16,    0, 16,  0,  6 }, {    146,   16,    0, 16,  0,  6 }, {    147,   16,    0, 16,  0,  6 }, {    148,   16,    0, 16,  0,  6 }, {    149,   16,    0, 16,  0,  5 },
    {    150,   16,    0, 16,  0,  5 }, {    151,   16,    0, 16,  0,  5 }, {    152,   16,    0, 16,  0,  5 }, {    153,   16,    0, 16,  0,  5 }, {    154,   16,    0, 16,  0,  5 },
    {    155,   16,    0, 16,  0,  5 }, {    156,   16,    0, 16,  0,  5 }, {    157,   16,    0, 16,  0,  5 }, {    158,   16,    0, 16,  0,  5 }, {    159,   16,    0, 16,  0,  5 },
    {    160,   16,    0, 16,  0,  5 }, {    161,   16,    0, 16,  0,  2 }, {    162,   16,    0, 16,  0,  2 }, {    163,   16,    0, 16,  0,  2 }, {    164,   16,    0, 16,  0,  2 },
    {    165,   16,    0, 16,  0,  2 }, {    166,   16,    0, 16,  0,  2 }, {    167,   16,    0, 16,  0,  2 }, {    168,   16,    0, 16,  0,  2 }, {    169,   16,    0, 16,  0,  2 },
    {    170,   16,    0, 16,  0,  2 }, {    171,   16,    0, 16,  0,  2 }, {    172,   16,    0, 16,  0,  2 }, {    173,   16,    0, 16,  0,  1 }, {    174,   16,    0, 16,  0,  1 },
    {    175,   16,    0, 16,  0,  1 }, {    176,   16,    0, 16,  0,  1 }, {    177,   16,    0, 16,  0,  1 }, {    178,   16,    0, 16,  0,  1 }, {    179,   16,    0, 16,  0,  1 },
    {    180,   16,    0, 16,  0,  1 }, {    181,   16,    0, 16,  0,  1 }, {    182,   16,    0, 16,  0,  1 }, {    183,   16,    0, 16,  0,  1 }, {    184,   16,    0, 16,  0,  1 },
    {    185,   16,    0, 16,  0,  0 }, {    186,   16,    0, 16,  0,  0 }, {    187,   16,    0, 16,  0,  0 }, {    188,   16,    0, 16,  0,  0 }, {    189,   16,    0, 16,  0,  0 },
    {    190,   16,    0, 16,  0,  0 }, {    191,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_932DB0, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  3 }, {     16,   25,    0, 24,  0,  3 }, {     16,   24,    0, 24,  0,  3 }, {     16,   23,    0, 24,  0,  3 }, {     16,   22,    0, 24,  0,  3 },
    {     16,   21,    0, 24,  0,  3 }, {     16,   20,    0, 24,  0,  3 }, {     16,   19,    0, 24,  0,  3 }, {     16,   18,    0, 24,  0,  3 }, {     16,   17,    0, 24,  0,  3 },
    {     16,   16,    0, 24,  0,  3 }, {     16,   15,    0, 24,  0,  3 }, {     16,   14,    0, 24,  0,  4 }, {     16,   13,    0, 24,  0,  4 }, {     16,   12,    0, 24,  0,  4 },
    {     16,   11,    0, 24,  0,  4 }, {     16,   10,    0, 24,  0,  4 }, {     16,    9,    0, 24,  0,  4 }, {     16,    8,    0, 24,  0,  4 }, {     16,    7,    0, 24,  0,  4 },
    {     16,    6,    0, 24,  0,  4 }, {     16,    5,    0, 24,  0,  4 }, {     16,    4,    0, 24,  0,  4 }, {     16,    3,    0, 24,  0,  4 }, {     16,    2,    0, 24,  0, 10 },
    {     16,    1,    0, 24,  0, 10 }, {     16,    0,    0, 24,  0, 10 }, {     16,   -1,    0, 24,  0, 10 }, {     16,   -2,    0, 24,  0, 10 }, {     16,   -3,    0, 24,  0, 10 },
    {     16,   -4,    0, 24,  0, 10 }, {     16,   -5,    0, 24,  0, 10 }, {     16,   -6,    0, 24,  0, 10 }, {     16,   -7,    0, 24,  0, 10 }, {     16,   -8,    0, 24,  0, 10 },
    {     16,   -9,    0, 24,  0, 10 }, {     16,  -10,    0, 24,  0, 11 }, {     16,  -11,    0, 24,  0, 11 }, {     16,  -12,    0, 24,  0, 11 }, {     16,  -13,    0, 24,  0, 11 },
    {     16,  -14,    0, 24,  0, 11 }, {     16,  -15,    0, 24,  0, 11 }, {     16,  -16,    0, 24,  0, 11 }, {     16,  -17,    0, 24,  0, 11 }, {     16,  -18,    0, 24,  0, 11 },
    {     16,  -19,    0, 24,  0, 11 }, {     16,  -20,    0, 24,  0, 11 }, {     16,  -21,    0, 24,  0, 11 }, {     16,  -22,    0, 24,  0, 12 }, {     16,  -23,    0, 24,  0, 12 },
    {     16,  -24,    0, 24,  0, 12 }, {     16,  -25,    0, 24,  0, 12 }, {     16,  -26,    0, 24,  0, 12 }, {     16,  -27,    0, 24,  0, 12 }, {     16,  -28,    0, 24,  0, 12 },
    {     16,  -29,    0, 24,  0, 12 }, {     16,  -30,    0, 24,  0, 12 }, {     16,  -31,    0, 24,  0, 12 }, {     16,  -32,    0, 24,  0, 12 }, {     16,  -33,    0, 24,  0, 12 },
    {     16,  -34,    0, 24,  0, 13 }, {     16,  -35,    0, 24,  0, 13 }, {     16,  -36,    0, 24,  0, 13 }, {     16,  -37,    0, 24,  0, 13 }, {     16,  -38,    0, 24,  0, 13 },
    {     16,  -39,    0, 24,  0, 13 }, {     16,  -40,    0, 24,  0, 13 }, {     16,  -41,    0, 24,  0, 13 }, {     16,  -42,    0, 24,  0, 13 }, {     16,  -43,    0, 24,  0, 13 },
    {     16,  -44,    0, 24,  0, 13 }, {     16,  -45,    0, 24,  0, 13 }, {     16,  -46,    0, 24,  0, 14 }, {     16,  -47,    0, 24,  0, 14 }, {     16,  -48,    0, 24,  0, 14 },
    {     16,  -49,    0, 24,  0, 14 }, {     16,  -50,    0, 24,  0, 14 }, {     16,  -51,    0, 24,  0, 14 }, {     16,  -52,    0, 24,  0, 14 }, {     16,  -53,    0, 24,  0, 14 },
    {     16,  -54,    0, 24,  0, 14 }, {     16,  -55,    0, 24,  0, 14 }, {     16,  -56,    0, 24,  0, 14 }, {     16,  -57,    0, 24,  0, 14 }, {     16,  -58,    0,  8, 16,  0 },
    {     16,  -59,    0,  8, 16,  0 }, {     16,  -60,    0,  8, 16,  0 }, {     16,  -61,    0,  8, 16,  0 }, {     16,  -62,    0,  8, 16,  0 }, {     16,  -63,    0,  8, 16,  0 },
    {     16,  -64,    0,  8, 16,  0 }, {     16,  -65,    0,  8, 16,  0 }, {     16,  -66,    0,  8, 16,  0 }, {     16,  -67,    0,  8, 16,  0 }, {     16,  -68,    0,  8, 16,  0 },
    {     16,  -69,    0,  8, 16,  0 }, {     16,  -70,    0, 24,  0,  9 }, {     16,  -71,    0, 24,  0,  9 }, {     16,  -72,    0, 24,  0,  9 }, {     16,  -73,    0, 24,  0,  9 },
    {     16,  -74,    0, 24,  0,  9 }, {     16,  -75,    0, 24,  0,  9 }, {     16,  -76,    0, 24,  0,  9 }, {     16,  -77,    0, 24,  0,  9 }, {     16,  -78,    0, 24,  0,  9 },
    {     16,  -79,    0, 24,  0,  9 }, {     16,  -80,    0, 24,  0,  9 }, {     16,  -81,    0, 24,  0,  9 }, {     16,  -82,    0, 24,  0,  8 }, {     16,  -83,    0, 24,  0,  8 },
    {     16,  -84,    0, 24,  0,  8 }, {     16,  -85,    0, 24,  0,  8 }, {     16,  -86,    0, 24,  0,  8 }, {     16,  -87,    0, 24,  0,  8 }, {     16,  -88,    0, 24,  0,  8 },
    {     16,  -89,    0, 24,  0,  8 }, {     16,  -90,    0, 24,  0,  8 }, {     16,  -91,    0, 24,  0,  8 }, {     16,  -92,    0, 24,  0,  8 }, {     16,  -93,    0, 24,  0,  8 },
    {     16,  -94,    0, 24,  0,  7 }, {     16,  -95,    0, 24,  0,  7 }, {     16,  -96,    0, 24,  0,  7 }, {     16,  -97,    0, 24,  0,  7 }, {     16,  -98,    0, 24,  0,  7 },
    {     16,  -99,    0, 24,  0,  7 }, {     16, -100,    0, 24,  0,  7 }, {     16, -101,    0, 24,  0,  7 }, {     16, -102,    0, 24,  0,  7 }, {     16, -103,    0, 24,  0,  7 },
    {     16, -104,    0, 24,  0,  7 }, {     16, -105,    0, 24,  0,  7 }, {     16, -106,    0, 24,  0,  6 }, {     16, -107,    0, 24,  0,  6 }, {     16, -108,    0, 24,  0,  6 },
    {     16, -109,    0, 24,  0,  6 }, {     16, -110,    0, 24,  0,  6 }, {     16, -111,    0, 24,  0,  6 }, {     16, -112,    0, 24,  0,  6 }, {     16, -113,    0, 24,  0,  6 },
    {     16, -114,    0, 24,  0,  6 }, {     16, -115,    0, 24,  0,  6 }, {     16, -116,    0, 24,  0,  6 }, {     16, -117,    0, 24,  0,  6 }, {     16, -118,    0, 24,  0,  5 },
    {     16, -119,    0, 24,  0,  5 }, {     16, -120,    0, 24,  0,  5 }, {     16, -121,    0, 24,  0,  5 }, {     16, -122,    0, 24,  0,  5 }, {     16, -123,    0, 24,  0,  5 },
    {     16, -124,    0, 24,  0,  5 }, {     16, -125,    0, 24,  0,  5 }, {     16, -126,    0, 24,  0,  5 }, {     16, -127,    0, 24,  0,  5 }, {     16, -128,    0, 24,  0,  5 },
    {     16, -129,    0, 24,  0,  5 }, {     16, -130,    0, 24,  0,  2 }, {     16, -131,    0, 24,  0,  2 }, {     16, -132,    0, 24,  0,  2 }, {     16, -133,    0, 24,  0,  2 },
    {     16, -134,    0, 24,  0,  2 }, {     16, -135,    0, 24,  0,  2 }, {     16, -136,    0, 24,  0,  2 }, {     16, -137,    0, 24,  0,  2 }, {     16, -138,    0, 24,  0,  2 },
    {     16, -139,    0, 24,  0,  2 }, {     16, -140,    0, 24,  0,  2 }, {     16, -141,    0, 24,  0,  2 }, {     16, -142,    0, 24,  0,  1 }, {     16, -143,    0, 24,  0,  1 },
    {     16, -144,    0, 24,  0,  1 }, {     16, -145,    0, 24,  0,  1 }, {     16, -146,    0, 24,  0,  1 }, {     16, -147,    0, 24,  0,  1 }, {     16, -148,    0, 24,  0,  1 },
    {     16, -149,    0, 24,  0,  1 }, {     16, -150,    0, 24,  0,  1 }, {     16, -151,    0, 24,  0,  1 }, {     16, -152,    0, 24,  0,  1 }, {     16, -153,    0, 24,  0,  1 },
    {     16, -154,    0, 24,  0,  0 }, {     16, -155,    0, 24,  0,  0 }, {     16, -156,    0, 24,  0,  0 }, {     16, -157,    0, 24,  0,  0 }, {     16, -158,    0, 24,  0,  0 },
    {     16, -159,    0, 24,  0,  0 }, {     16, -160,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_979BD6, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,   -1,  0,  0,  0 }, {     22,   16,   -1, 16, 23,  0 },
    {     21,   16,   -1, 16, 23,  0 }, {     20,   16,   -1, 16, 23,  0 }, {     19,   16,   -1, 16, 23,  0 }, {     18,   16,   -2, 16, 23,  0 }, {     17,   16,   -2, 16, 23,  0 },
    {     16,   16,   -2, 16, 23,  0 }, {     15,   16,   -2, 16, 23,  0 }, {     14,   16,   -3, 16, 23,  0 }, {     13,   16,   -3, 16, 23,  0 }, {     12,   16,   -3, 16, 23,  0 },
    {     11,   16,   -4, 16, 22,  0 }, {     10,   16,   -4, 16, 22,  0 }, {      9,   16,   -4, 16, 22,  0 }, {      8,   16,   -5, 16, 22,  0 }, {      7,   16,   -5, 16, 22,  0 },
    {      6,   16,   -6, 16, 22,  0 }, {      5,   16,   -6, 16, 22,  0 }, {      4,   16,   -7, 16, 22,  0 }, {      3,   16,   -7, 16, 22,  0 }, {      2,   16,   -8, 16, 22,  0 },
    {      1,   16,   -8, 16, 22,  0 }, {      0,   16,   -9, 16, 22,  0 }, {     -1,   16,  -10, 16, 22,  0 }, {     -2,   16,  -10, 16, 22,  0 }, {     -3,   16,  -11, 16, 22,  0 },
    {     -4,   16,  -11, 16, 22,  0 }, {     -5,   16,  -12, 16, 21,  0 }, {     -6,   16,  -13, 16, 21,  0 }, {     -7,   16,  -14, 16, 21,  0 }, {     -8,   16,  -14, 16, 21,  0 },
    {     -9,   16,  -15, 16, 21,  0 }, {    -10,   16,  -16, 16, 21,  0 }, {    -11,   16,  -17, 16, 21,  0 }, {    -12,   16,  -18, 16, 21,  0 }, {    -13,   16,  -19, 16, 21,  0 },
    {    -14,   16,  -20, 16, 21,  0 }, {    -15,   16,  -21, 16, 21,  0 }, {    -16,   16,  -22, 16, 21,  0 }, {    -17,   16,  -23, 16, 21,  0 }, {    -18,   16,  -24, 16, 21,  0 },
    {    -19,   16,  -25, 16, 21,  0 }, {    -20,   16,  -26, 16, 21,  0 }, {    -21,   16,  -27, 16, 21,  0 }, {    -21,   16,  -28, 16, 21,  0 }, {    -22,   16,  -29, 16, 21,  0 },
    {    -23,   16,  -30, 16, 21,  0 }, {    -24,   16,  -31, 16, 20,  0 }, {    -24,   16,  -32, 16, 20,  0 }, {    -25,   16,  -33, 16, 20,  0 }, {    -26,   16,  -34, 16, 20,  0 },
    {    -27,   16,  -35, 16, 20,  0 }, {    -27,   16,  -36, 16, 20,  0 }, {    -28,   16,  -37, 16, 20,  0 }, {    -29,   16,  -38, 16, 20,  0 }, {    -29,   16,  -39, 16, 20,  0 },
    {    -30,   16,  -40, 16, 20,  0 }, {    -30,   16,  -41, 16, 20,  0 }, {    -31,   16,  -42, 16, 20,  0 }, {    -31,   16,  -43, 16, 20,  0 }, {    -32,   16,  -44, 16, 20,  0 },
    {    -33,   16,  -45, 16, 20,  0 }, {    -33,   16,  -46, 16, 20,  0 }, {    -34,   16,  -47, 16, 20,  0 }, {    -34,   16,  -48, 16, 20,  0 }, {    -35,   16,  -49, 16, 20,  0 },
    {    -35,   16,  -50, 16, 20,  0 }, {    -35,   16,  -51, 16, 20,  0 }, {    -36,   16,  -52, 16, 20,  0 }, {    -36,   16,  -53, 16, 20,  0 }, {    -37,   16,  -54, 16, 20,  0 },
    {    -37,   16,  -55, 16, 20,  0 }, {    -38,   16,  -56, 16, 19,  0 }, {    -38,   16,  -57, 16, 19,  0 }, {    -38,   16,  -58, 16, 19,  0 }, {    -39,   16,  -59, 16, 19,  0 },
    {    -39,   16,  -60, 16, 19,  0 }, {    -40,   16,  -61, 16, 19,  0 }, {    -40,   16,  -62, 16, 19,  0 }, {    -40,   16,  -63, 16, 19,  0 }, {    -41,   16,  -64, 16, 19,  0 },
    {    -41,   16,  -65, 16, 19,  0 }, {    -41,   16,  -66, 16, 19,  0 }, {    -42,   16,  -67, 16, 19,  0 }, {    -42,   16,  -68, 16, 19,  0 }, {    -42,   16,  -69, 16, 19,  0 },
    {    -42,   16,  -70, 16, 19,  0 }, {    -43,   16,  -71, 16, 19,  0 }, {    -43,   16,  -72, 16, 19,  0 }, {    -43,   16,  -73, 16, 19,  0 }, {    -43,   16,  -74, 16, 19,  0 },
    {    -44,   16,  -75, 16, 19,  0 }, {    -44,   16,  -76, 16, 19,  0 }, {    -44,   16,  -77, 16, 19,  0 }, {    -44,   16,  -78, 16, 19,  0 }, {    -45,   16,  -79, 16, 19,  0 },
    {    -45,   16,  -80, 16, 19,  0 }, {    -45,   16,  -81, 16, 19,  0 }, {    -45,   16,  -82, 16, 19,  0 }, {    -45,   16,  -83, 16, 19,  0 }, {    -46,   16,  -84, 16, 19,  0 },
    {    -46,   16,  -85, 16, 19,  0 }, {    -46,   16,  -86, 16, 19,  0 }, {    -46,   16,  -87, 16, 19,  0 }, {    -46,   16,  -88, 16, 19,  0 }, {    -46,   16,  -89, 16, 19,  0 },
    {    -47,   16,  -90, 16, 19,  0 }, {    -47,   16,  -91, 16, 18,  0 }, {    -47,   16,  -92, 16, 18,  0 }, {    -47,   16,  -93, 16, 18,  0 }, {    -47,   16,  -94, 16, 18,  0 },
    {    -47,   16,  -95, 16, 18,  0 }, {    -47,   16,  -96, 16, 18,  0 }, {    -47,   16,  -97, 16, 18,  0 }, {    -47,   16,  -98, 16, 18,  0 }, {    -48,   16,  -99, 16, 18,  0 },
    {    -48,   16, -100, 16, 18,  0 }, {    -48,   16, -101, 16, 18,  0 }, {    -48,   16, -102, 16, 18,  0 }, {    -48,   16, -103, 16, 18,  0 }, {    -48,   16, -104, 16, 18,  0 },
    {    -48,   16, -105, 16, 18,  0 }, {    -48,   16, -106, 16, 18,  0 }, {    -48,   16, -107, 16, 18,  0 }, {    -48,   16, -108, 16, 18,  0 }, {    -48,   16, -109, 16, 18,  0 },
    {    -48,   16, -110, 16, 18,  0 }, {    -48,   16, -111, 16, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_97A0A9, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,   -1,  8,  0,  0 }, {     16,    9,   -1, 24, 23,  0 },
    {     16,   10,   -1, 24, 23,  0 }, {     16,   11,   -1, 24, 23,  0 }, {     16,   12,   -1, 24, 23,  0 }, {     16,   13,   -2, 24, 23,  0 }, {     16,   14,   -2, 24, 23,  0 },
    {     16,   15,   -2, 24, 23,  0 }, {     16,   16,   -2, 24, 23,  0 }, {     16,   17,   -3, 24, 23,  0 }, {     16,   18,   -3, 24, 23,  0 }, {     16,   19,   -3, 24, 23,  0 },
    {     16,   20,   -4, 24, 22,  0 }, {     16,   21,   -4, 24, 22,  0 }, {     16,   22,   -4, 24, 22,  0 }, {     16,   23,   -5, 24, 22,  0 }, {     16,   24,   -5, 24, 22,  0 },
    {     16,   25,   -6, 24, 22,  0 }, {     16,   26,   -6, 24, 22,  0 }, {     16,   27,   -7, 24, 22,  0 }, {     16,   28,   -7, 24, 22,  0 }, {     16,   29,   -8, 24, 22,  0 },
    {     16,   30,   -8, 24, 22,  0 }, {     16,   31,   -9, 24, 22,  0 }, {     16,   32,  -10, 24, 22,  0 }, {     16,   33,  -10, 24, 22,  0 }, {     16,   34,  -11, 24, 22,  0 },
    {     16,   35,  -11, 24, 22,  0 }, {     16,   36,  -12, 24, 21,  0 }, {     16,   37,  -13, 24, 21,  0 }, {     16,   38,  -14, 24, 21,  0 }, {     16,   39,  -14, 24, 21,  0 },
    {     16,   40,  -15, 24, 21,  0 }, {     16,   41,  -16, 24, 21,  0 }, {     16,   42,  -17, 24, 21,  0 }, {     16,   43,  -18, 24, 21,  0 }, {     16,   44,  -19, 24, 21,  0 },
    {     16,   45,  -20, 24, 21,  0 }, {     16,   46,  -21, 24, 21,  0 }, {     16,   47,  -22, 24, 21,  0 }, {     16,   48,  -23, 24, 21,  0 }, {     16,   49,  -24, 24, 21,  0 },
    {     16,   50,  -25, 24, 21,  0 }, {     16,   51,  -26, 24, 21,  0 }, {     16,   52,  -27, 24, 21,  0 }, {     16,   52,  -28, 24, 21,  0 }, {     16,   53,  -29, 24, 21,  0 },
    {     16,   54,  -30, 24, 21,  0 }, {     16,   55,  -31, 24, 20,  0 }, {     16,   55,  -32, 24, 20,  0 }, {     16,   56,  -33, 24, 20,  0 }, {     16,   57,  -34, 24, 20,  0 },
    {     16,   58,  -35, 24, 20,  0 }, {     16,   58,  -36, 24, 20,  0 }, {     16,   59,  -37, 24, 20,  0 }, {     16,   60,  -38, 24, 20,  0 }, {     16,   60,  -39, 24, 20,  0 },
    {     16,   61,  -40, 24, 20,  0 }, {     16,   61,  -41, 24, 20,  0 }, {     16,   62,  -42, 24, 20,  0 }, {     16,   62,  -43, 24, 20,  0 }, {     16,   63,  -44, 24, 20,  0 },
    {     16,   64,  -45, 24, 20,  0 }, {     16,   64,  -46, 24, 20,  0 }, {     16,   65,  -47, 24, 20,  0 }, {     16,   65,  -48, 24, 20,  0 }, {     16,   66,  -49, 24, 20,  0 },
    {     16,   66,  -50, 24, 20,  0 }, {     16,   66,  -51, 24, 20,  0 }, {     16,   67,  -52, 24, 20,  0 }, {     16,   67,  -53, 24, 20,  0 }, {     16,   68,  -54, 24, 20,  0 },
    {     16,   68,  -55, 24, 20,  0 }, {     16,   69,  -56, 24, 19,  0 }, {     16,   69,  -57, 24, 19,  0 }, {     16,   69,  -58, 24, 19,  0 }, {     16,   70,  -59, 24, 19,  0 },
    {     16,   70,  -60, 24, 19,  0 }, {     16,   71,  -61, 24, 19,  0 }, {     16,   71,  -62, 24, 19,  0 }, {     16,   71,  -63, 24, 19,  0 }, {     16,   72,  -64, 24, 19,  0 },
    {     16,   72,  -65, 24, 19,  0 }, {     16,   72,  -66, 24, 19,  0 }, {     16,   73,  -67, 24, 19,  0 }, {     16,   73,  -68, 24, 19,  0 }, {     16,   73,  -69, 24, 19,  0 },
    {     16,   73,  -70, 24, 19,  0 }, {     16,   74,  -71, 24, 19,  0 }, {     16,   74,  -72, 24, 19,  0 }, {     16,   74,  -73, 24, 19,  0 }, {     16,   74,  -74, 24, 19,  0 },
    {     16,   75,  -75, 24, 19,  0 }, {     16,   75,  -76, 24, 19,  0 }, {     16,   75,  -77, 24, 19,  0 }, {     16,   75,  -78, 24, 19,  0 }, {     16,   76,  -79, 24, 19,  0 },
    {     16,   76,  -80, 24, 19,  0 }, {     16,   76,  -81, 24, 19,  0 }, {     16,   76,  -82, 24, 19,  0 }, {     16,   76,  -83, 24, 19,  0 }, {     16,   77,  -84, 24, 19,  0 },
    {     16,   77,  -85, 24, 19,  0 }, {     16,   77,  -86, 24, 19,  0 }, {     16,   77,  -87, 24, 19,  0 }, {     16,   77,  -88, 24, 19,  0 }, {     16,   77,  -89, 24, 19,  0 },
    {     16,   78,  -90, 24, 19,  0 }, {     16,   78,  -91, 24, 18,  0 }, {     16,   78,  -92, 24, 18,  0 }, {     16,   78,  -93, 24, 18,  0 }, {     16,   78,  -94, 24, 18,  0 },
    {     16,   78,  -95, 24, 18,  0 }, {     16,   78,  -96, 24, 18,  0 }, {     16,   78,  -97, 24, 18,  0 }, {     16,   78,  -98, 24, 18,  0 }, {     16,   79,  -99, 24, 18,  0 },
    {     16,   79, -100, 24, 18,  0 }, {     16,   79, -101, 24, 18,  0 }, {     16,   79, -102, 24, 18,  0 }, {     16,   79, -103, 24, 18,  0 }, {     16,   79, -104, 24, 18,  0 },
    {     16,   79, -105, 24, 18,  0 }, {     16,   79, -106, 24, 18,  0 }, {     16,   79, -107, 24, 18,  0 }, {     16,   79, -108, 24, 18,  0 }, {     16,   79, -109, 24, 18,  0 },
    {     16,   79, -110, 24, 18,  0 }, {     16,   79, -111, 24, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_97A57C, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,   -1, 16,  0,  0 }, {      9,   16,   -1,  0, 23,  0 },
    {     10,   16,   -1,  0, 23,  0 }, {     11,   16,   -1,  0, 23,  0 }, {     12,   16,   -1,  0, 23,  0 }, {     13,   16,   -2,  0, 23,  0 }, {     14,   16,   -2,  0, 23,  0 },
    {     15,   16,   -2,  0, 23,  0 }, {     16,   16,   -2,  0, 23,  0 }, {     17,   16,   -3,  0, 23,  0 }, {     18,   16,   -3,  0, 23,  0 }, {     19,   16,   -3,  0, 23,  0 },
    {     20,   16,   -4,  0, 22,  0 }, {     21,   16,   -4,  0, 22,  0 }, {     22,   16,   -4,  0, 22,  0 }, {     23,   16,   -5,  0, 22,  0 }, {     24,   16,   -5,  0, 22,  0 },
    {     25,   16,   -6,  0, 22,  0 }, {     26,   16,   -6,  0, 22,  0 }, {     27,   16,   -7,  0, 22,  0 }, {     28,   16,   -7,  0, 22,  0 }, {     29,   16,   -8,  0, 22,  0 },
    {     30,   16,   -8,  0, 22,  0 }, {     31,   16,   -9,  0, 22,  0 }, {     32,   16,  -10,  0, 22,  0 }, {     33,   16,  -10,  0, 22,  0 }, {     34,   16,  -11,  0, 22,  0 },
    {     35,   16,  -11,  0, 22,  0 }, {     36,   16,  -12,  0, 21,  0 }, {     37,   16,  -13,  0, 21,  0 }, {     38,   16,  -14,  0, 21,  0 }, {     39,   16,  -14,  0, 21,  0 },
    {     40,   16,  -15,  0, 21,  0 }, {     41,   16,  -16,  0, 21,  0 }, {     42,   16,  -17,  0, 21,  0 }, {     43,   16,  -18,  0, 21,  0 }, {     44,   16,  -19,  0, 21,  0 },
    {     45,   16,  -20,  0, 21,  0 }, {     46,   16,  -21,  0, 21,  0 }, {     47,   16,  -22,  0, 21,  0 }, {     48,   16,  -23,  0, 21,  0 }, {     49,   16,  -24,  0, 21,  0 },
    {     50,   16,  -25,  0, 21,  0 }, {     51,   16,  -26,  0, 21,  0 }, {     52,   16,  -27,  0, 21,  0 }, {     52,   16,  -28,  0, 21,  0 }, {     53,   16,  -29,  0, 21,  0 },
    {     54,   16,  -30,  0, 21,  0 }, {     55,   16,  -31,  0, 20,  0 }, {     55,   16,  -32,  0, 20,  0 }, {     56,   16,  -33,  0, 20,  0 }, {     57,   16,  -34,  0, 20,  0 },
    {     58,   16,  -35,  0, 20,  0 }, {     58,   16,  -36,  0, 20,  0 }, {     59,   16,  -37,  0, 20,  0 }, {     60,   16,  -38,  0, 20,  0 }, {     60,   16,  -39,  0, 20,  0 },
    {     61,   16,  -40,  0, 20,  0 }, {     61,   16,  -41,  0, 20,  0 }, {     62,   16,  -42,  0, 20,  0 }, {     62,   16,  -43,  0, 20,  0 }, {     63,   16,  -44,  0, 20,  0 },
    {     64,   16,  -45,  0, 20,  0 }, {     64,   16,  -46,  0, 20,  0 }, {     65,   16,  -47,  0, 20,  0 }, {     65,   16,  -48,  0, 20,  0 }, {     66,   16,  -49,  0, 20,  0 },
    {     66,   16,  -50,  0, 20,  0 }, {     66,   16,  -51,  0, 20,  0 }, {     67,   16,  -52,  0, 20,  0 }, {     67,   16,  -53,  0, 20,  0 }, {     68,   16,  -54,  0, 20,  0 },
    {     68,   16,  -55,  0, 20,  0 }, {     69,   16,  -56,  0, 19,  0 }, {     69,   16,  -57,  0, 19,  0 }, {     69,   16,  -58,  0, 19,  0 }, {     70,   16,  -59,  0, 19,  0 },
    {     70,   16,  -60,  0, 19,  0 }, {     71,   16,  -61,  0, 19,  0 }, {     71,   16,  -62,  0, 19,  0 }, {     71,   16,  -63,  0, 19,  0 }, {     72,   16,  -64,  0, 19,  0 },
    {     72,   16,  -65,  0, 19,  0 }, {     72,   16,  -66,  0, 19,  0 }, {     73,   16,  -67,  0, 19,  0 }, {     73,   16,  -68,  0, 19,  0 }, {     73,   16,  -69,  0, 19,  0 },
    {     73,   16,  -70,  0, 19,  0 }, {     74,   16,  -71,  0, 19,  0 }, {     74,   16,  -72,  0, 19,  0 }, {     74,   16,  -73,  0, 19,  0 }, {     74,   16,  -74,  0, 19,  0 },
    {     75,   16,  -75,  0, 19,  0 }, {     75,   16,  -76,  0, 19,  0 }, {     75,   16,  -77,  0, 19,  0 }, {     75,   16,  -78,  0, 19,  0 }, {     76,   16,  -79,  0, 19,  0 },
    {     76,   16,  -80,  0, 19,  0 }, {     76,   16,  -81,  0, 19,  0 }, {     76,   16,  -82,  0, 19,  0 }, {     76,   16,  -83,  0, 19,  0 }, {     77,   16,  -84,  0, 19,  0 },
    {     77,   16,  -85,  0, 19,  0 }, {     77,   16,  -86,  0, 19,  0 }, {     77,   16,  -87,  0, 19,  0 }, {     77,   16,  -88,  0, 19,  0 }, {     77,   16,  -89,  0, 19,  0 },
    {     78,   16,  -90,  0, 19,  0 }, {     78,   16,  -91,  0, 18,  0 }, {     78,   16,  -92,  0, 18,  0 }, {     78,   16,  -93,  0, 18,  0 }, {     78,   16,  -94,  0, 18,  0 },
    {     78,   16,  -95,  0, 18,  0 }, {     78,   16,  -96,  0, 18,  0 }, {     78,   16,  -97,  0, 18,  0 }, {     78,   16,  -98,  0, 18,  0 }, {     79,   16,  -99,  0, 18,  0 },
    {     79,   16, -100,  0, 18,  0 }, {     79,   16, -101,  0, 18,  0 }, {     79,   16, -102,  0, 18,  0 }, {     79,   16, -103,  0, 18,  0 }, {     79,   16, -104,  0, 18,  0 },
    {     79,   16, -105,  0, 18,  0 }, {     79,   16, -106,  0, 18,  0 }, {     79,   16, -107,  0, 18,  0 }, {     79,   16, -108,  0, 18,  0 }, {     79,   16, -109,  0, 18,  0 },
    {     79,   16, -110,  0, 18,  0 }, {     79,   16, -111,  0, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_97AA4F, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,   -1, 24,  0,  0 }, {     16,   22,   -1,  8, 23,  0 },
    {     16,   21,   -1,  8, 23,  0 }, {     16,   20,   -1,  8, 23,  0 }, {     16,   19,   -1,  8, 23,  0 }, {     16,   18,   -2,  8, 23,  0 }, {     16,   17,   -2,  8, 23,  0 },
    {     16,   16,   -2,  8, 23,  0 }, {     16,   15,   -2,  8, 23,  0 }, {     16,   14,   -3,  8, 23,  0 }, {     16,   13,   -3,  8, 23,  0 }, {     16,   12,   -3,  8, 23,  0 },
    {     16,   11,   -4,  8, 22,  0 }, {     16,   10,   -4,  8, 22,  0 }, {     16,    9,   -4,  8, 22,  0 }, {     16,    8,   -5,  8, 22,  0 }, {     16,    7,   -5,  8, 22,  0 },
    {     16,    6,   -6,  8, 22,  0 }, {     16,    5,   -6,  8, 22,  0 }, {     16,    4,   -7,  8, 22,  0 }, {     16,    3,   -7,  8, 22,  0 }, {     16,    2,   -8,  8, 22,  0 },
    {     16,    1,   -8,  8, 22,  0 }, {     16,    0,   -9,  8, 22,  0 }, {     16,   -1,  -10,  8, 22,  0 }, {     16,   -2,  -10,  8, 22,  0 }, {     16,   -3,  -11,  8, 22,  0 },
    {     16,   -4,  -11,  8, 22,  0 }, {     16,   -5,  -12,  8, 21,  0 }, {     16,   -6,  -13,  8, 21,  0 }, {     16,   -7,  -14,  8, 21,  0 }, {     16,   -8,  -14,  8, 21,  0 },
    {     16,   -9,  -15,  8, 21,  0 }, {     16,  -10,  -16,  8, 21,  0 }, {     16,  -11,  -17,  8, 21,  0 }, {     16,  -12,  -18,  8, 21,  0 }, {     16,  -13,  -19,  8, 21,  0 },
    {     16,  -14,  -20,  8, 21,  0 }, {     16,  -15,  -21,  8, 21,  0 }, {     16,  -16,  -22,  8, 21,  0 }, {     16,  -17,  -23,  8, 21,  0 }, {     16,  -18,  -24,  8, 21,  0 },
    {     16,  -19,  -25,  8, 21,  0 }, {     16,  -20,  -26,  8, 21,  0 }, {     16,  -21,  -27,  8, 21,  0 }, {     16,  -21,  -28,  8, 21,  0 }, {     16,  -22,  -29,  8, 21,  0 },
    {     16,  -23,  -30,  8, 21,  0 }, {     16,  -24,  -31,  8, 20,  0 }, {     16,  -24,  -32,  8, 20,  0 }, {     16,  -25,  -33,  8, 20,  0 }, {     16,  -26,  -34,  8, 20,  0 },
    {     16,  -27,  -35,  8, 20,  0 }, {     16,  -27,  -36,  8, 20,  0 }, {     16,  -28,  -37,  8, 20,  0 }, {     16,  -29,  -38,  8, 20,  0 }, {     16,  -29,  -39,  8, 20,  0 },
    {     16,  -30,  -40,  8, 20,  0 }, {     16,  -30,  -41,  8, 20,  0 }, {     16,  -31,  -42,  8, 20,  0 }, {     16,  -31,  -43,  8, 20,  0 }, {     16,  -32,  -44,  8, 20,  0 },
    {     16,  -33,  -45,  8, 20,  0 }, {     16,  -33,  -46,  8, 20,  0 }, {     16,  -34,  -47,  8, 20,  0 }, {     16,  -34,  -48,  8, 20,  0 }, {     16,  -35,  -49,  8, 20,  0 },
    {     16,  -35,  -50,  8, 20,  0 }, {     16,  -35,  -51,  8, 20,  0 }, {     16,  -36,  -52,  8, 20,  0 }, {     16,  -36,  -53,  8, 20,  0 }, {     16,  -37,  -54,  8, 20,  0 },
    {     16,  -37,  -55,  8, 20,  0 }, {     16,  -38,  -56,  8, 19,  0 }, {     16,  -38,  -57,  8, 19,  0 }, {     16,  -38,  -58,  8, 19,  0 }, {     16,  -39,  -59,  8, 19,  0 },
    {     16,  -39,  -60,  8, 19,  0 }, {     16,  -40,  -61,  8, 19,  0 }, {     16,  -40,  -62,  8, 19,  0 }, {     16,  -40,  -63,  8, 19,  0 }, {     16,  -41,  -64,  8, 19,  0 },
    {     16,  -41,  -65,  8, 19,  0 }, {     16,  -41,  -66,  8, 19,  0 }, {     16,  -42,  -67,  8, 19,  0 }, {     16,  -42,  -68,  8, 19,  0 }, {     16,  -42,  -69,  8, 19,  0 },
    {     16,  -42,  -70,  8, 19,  0 }, {     16,  -43,  -71,  8, 19,  0 }, {     16,  -43,  -72,  8, 19,  0 }, {     16,  -43,  -73,  8, 19,  0 }, {     16,  -43,  -74,  8, 19,  0 },
    {     16,  -44,  -75,  8, 19,  0 }, {     16,  -44,  -76,  8, 19,  0 }, {     16,  -44,  -77,  8, 19,  0 }, {     16,  -44,  -78,  8, 19,  0 }, {     16,  -45,  -79,  8, 19,  0 },
    {     16,  -45,  -80,  8, 19,  0 }, {     16,  -45,  -81,  8, 19,  0 }, {     16,  -45,  -82,  8, 19,  0 }, {     16,  -45,  -83,  8, 19,  0 }, {     16,  -46,  -84,  8, 19,  0 },
    {     16,  -46,  -85,  8, 19,  0 }, {     16,  -46,  -86,  8, 19,  0 }, {     16,  -46,  -87,  8, 19,  0 }, {     16,  -46,  -88,  8, 19,  0 }, {     16,  -46,  -89,  8, 19,  0 },
    {     16,  -47,  -90,  8, 19,  0 }, {     16,  -47,  -91,  8, 18,  0 }, {     16,  -47,  -92,  8, 18,  0 }, {     16,  -47,  -93,  8, 18,  0 }, {     16,  -47,  -94,  8, 18,  0 },
    {     16,  -47,  -95,  8, 18,  0 }, {     16,  -47,  -96,  8, 18,  0 }, {     16,  -47,  -97,  8, 18,  0 }, {     16,  -47,  -98,  8, 18,  0 }, {     16,  -48,  -99,  8, 18,  0 },
    {     16,  -48, -100,  8, 18,  0 }, {     16,  -48, -101,  8, 18,  0 }, {     16,  -48, -102,  8, 18,  0 }, {     16,  -48, -103,  8, 18,  0 }, {     16,  -48, -104,  8, 18,  0 },
    {     16,  -48, -105,  8, 18,  0 }, {     16,  -48, -106,  8, 18,  0 }, {     16,  -48, -107,  8, 18,  0 }, {     16,  -48, -108,  8, 18,  0 }, {     16,  -48, -109,  8, 18,  0 },
    {     16,  -48, -110,  8, 18,  0 }, {     16,  -48, -111,  8, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_973B5A, {
    {     16,   16,    0,  0, 10,  0 }, {     16,   16,    1,  0, 10,  0 }, {     16,   16,    2,  0, 10,  0 }, {     16,   16,    3,  0, 10,  0 }, {     16,   16,    4,  0, 10,  0 },
    {     16,   16,    5,  0, 10,  0 }, {     16,   16,    6,  0, 10,  0 }, {     16,   16,    7,  0, 10,  0 }, {     16,   16,    8,  0, 10,  0 }, {     16,   16,    9,  0, 10,  0 },
    {     16,   16,   10,  0, 10,  0 }, {     16,   16,   11,  0, 10,  0 }, {     16,   16,   12,  0, 10,  0 }, {     17,   16,   13,  0, 10,  0 }, {     17,   16,   14,  0, 10,  0 },
    {     17,   16,   15,  0, 10,  0 }, {     17,   16,   16,  0, 10,  0 }, {     17,   16,   17,  0, 10,  0 }, {     17,   16,   18,  0, 10,  0 }, {     17,   16,   19,  0, 10,  0 },
    {     17,   16,   20,  0, 10,  0 }, {     17,   16,   21,  0, 10,  0 }, {     18,   16,   22,  0, 11,  0 }, {     18,   16,   23,  0, 11,  0 }, {     18,   16,   24,  0, 11,  0 },
    {     18,   16,   25,  0, 11,  0 }, {     18,   16,   26,  0, 11,  0 }, {     18,   16,   27,  0, 11,  0 }, {     19,   16,   28,  0, 11,  0 }, {     19,   16,   29,  0, 11,  0 },
    {     19,   16,   30,  0, 11,  0 }, {     19,   16,   31,  0, 11,  0 }, {     19,   16,   32,  0, 11,  0 }, {     20,   16,   33,  0, 11,  0 }, {     20,   16,   34,  0, 11,  0 },
    {     20,   16,   35,  0, 11,  0 }, {     20,   16,   36,  0, 11,  0 }, {     21,   16,   37,  0, 11,  0 }, {     21,   16,   38,  0, 11,  0 }, {     21,   16,   39,  0, 11,  0 },
    {     21,   16,   40,  0, 11,  0 }, {     22,   16,   41,  0, 11,  0 }, {     22,   16,   42,  0, 11,  0 }, {     22,   16,   43,  0, 11,  0 }, {     22,   16,   44,  0, 11,  0 },
    {     23,   16,   45,  0, 11,  0 }, {     23,   16,   46,  0, 11,  0 }, {     23,   16,   47,  0, 11,  0 }, {     24,   16,   48,  0, 11,  0 }, {     24,   16,   49,  0, 11,  0 },
    {     24,   16,   50,  0, 11,  0 }, {     25,   16,   51,  0, 11,  0 }, {     25,   16,   52,  0, 11,  0 }, {     26,   16,   53,  0, 11,  0 }, {     26,   16,   54,  0, 11,  0 },
    {     26,   16,   55,  0, 11,  0 }, {     27,   16,   56,  0, 12,  0 }, {     27,   16,   57,  0, 12,  0 }, {     28,   16,   58,  0, 12,  0 }, {     28,   16,   59,  0, 12,  0 },
    {     29,   16,   60,  0, 12,  0 }, {     29,   16,   61,  0, 12,  0 }, {     29,   16,   62,  0, 12,  0 }, {     30,   16,   63,  0, 12,  0 }, {     30,   16,   64,  0, 12,  0 },
    {     31,   16,   65,  0, 12,  0 }, {     31,   16,   66,  0, 12,  0 }, {     32,   16,   67,  0, 12,  0 }, {     33,   16,   68,  0, 12,  0 }, {     33,   16,   69,  0, 12,  0 },
    {     34,   16,   70,  0, 12,  0 }, {     34,   16,   71,  0, 12,  0 }, {     35,   16,   72,  0, 12,  0 }, {     35,   16,   73,  0, 12,  0 }, {     36,   16,   74,  0, 12,  0 },
    {     37,   16,   75,  0, 12,  0 }, {     37,   16,   76,  0, 12,  0 }, {     38,   16,   77,  0, 12,  0 }, {     39,   16,   78,  0, 12,  0 }, {     40,   16,   79,  0, 12,  0 },
    {     40,   16,   80,  0, 12,  0 }, {     41,   16,   81,  0, 13,  0 }, {     42,   16,   82,  0, 13,  0 }, {     43,   16,   83,  0, 13,  0 }, {     43,   16,   84,  0, 13,  0 },
    {     44,   16,   85,  0, 13,  0 }, {     45,   16,   86,  0, 13,  0 }, {     46,   16,   87,  0, 13,  0 }, {     47,   16,   88,  0, 13,  0 }, {     48,   16,   89,  0, 13,  0 },
    {     49,   16,   90,  0, 13,  0 }, {     50,   16,   91,  0, 13,  0 }, {     51,   16,   92,  0, 13,  0 }, {     52,   16,   93,  0, 13,  0 }, {     53,   16,   94,  0, 13,  0 },
    {     54,   16,   95,  0, 13,  0 }, {     55,   16,   96,  0, 13,  0 }, {     56,   16,   97,  0, 13,  0 }, {     57,   16,   97,  0, 13,  0 }, {     58,   16,   98,  0, 13,  0 },
    {     59,   16,   99,  0, 13,  0 }, {     60,   16,  100,  0, 14,  0 }, {     61,   16,  100,  0, 14,  0 }, {     62,   16,  101,  0, 14,  0 }, {     63,   16,  101,  0, 14,  0 },
    {     64,   16,  102,  0, 14,  0 }, {     65,   16,  103,  0, 14,  0 }, {     66,   16,  103,  0, 14,  0 }, {     67,   16,  104,  0, 14,  0 }, {     68,   16,  104,  0, 14,  0 },
    {     69,   16,  105,  0, 14,  0 }, {     70,   16,  105,  0, 14,  0 }, {     71,   16,  106,  0, 14,  0 }, {     72,   16,  106,  0, 14,  0 }, {     73,   16,  107,  0, 14,  0 },
    {     74,   16,  107,  0, 14,  0 }, {     75,   16,  107,  0, 14,  0 }, {     76,   16,  108,  0, 15,  0 }, {     77,   16,  108,  0, 15,  0 }, {     78,   16,  108,  0, 15,  0 },
    {     79,   16,  109,  0, 15,  0 }, {     80,   16,  109,  0, 15,  0 }, {     81,   16,  109,  0, 15,  0 }, {     82,   16,  109,  0, 15,  0 }, {     83,   16,  110,  0, 15,  0 },
    {     84,   16,  110,  0, 15,  0 }, {     85,   16,  110,  0, 15,  0 }, {     86,   16,  110,  0, 15,  0 }, {     87,   16,  110,  0, 16,  0 }, {     88,   16,  111,  0, 16,  0 },
    {     89,   16,  111,  0, 16,  0 }, {     90,   16,  111,  0, 16,  0 }, {     91,   16,  111,  0, 16,  0 }, {     92,   16,  111,  0, 16,  0 }, {     93,   16,  111,  0, 16,  0 },
    {     94,   16,  111,  0, 16,  0 }, {     95,   16,  111,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_97402D, {
    {     16,   16,    0,  8, 10,  0 }, {     16,   16,    1,  8, 10,  0 }, {     16,   16,    2,  8, 10,  0 }, {     16,   16,    3,  8, 10,  0 }, {     16,   16,    4,  8, 10,  0 },
    {     16,   16,    5,  8, 10,  0 }, {     16,   16,    6,  8, 10,  0 }, {     16,   16,    7,  8, 10,  0 }, {     16,   16,    8,  8, 10,  0 }, {     16,   16,    9,  8, 10,  0 },
    {     16,   16,   10,  8, 10,  0 }, {     16,   16,   11,  8, 10,  0 }, {     16,   16,   12,  8, 10,  0 }, {     16,   15,   13,  8, 10,  0 }, {     16,   15,   14,  8, 10,  0 },
    {     16,   15,   15,  8, 10,  0 }, {     16,   15,   16,  8, 10,  0 }, {     16,   15,   17,  8, 10,  0 }, {     16,   15,   18,  8, 10,  0 }, {     16,   15,   19,  8, 10,  0 },
    {     16,   15,   20,  8, 10,  0 }, {     16,   15,   21,  8, 10,  0 }, {     16,   14,   22,  8, 11,  0 }, {     16,   14,   23,  8, 11,  0 }, {     16,   14,   24,  8, 11,  0 },
    {     16,   14,   25,  8, 11,  0 }, {     16,   14,   26,  8, 11,  0 }, {     16,   14,   27,  8, 11,  0 }, {     16,   13,   28,  8, 11,  0 }, {     16,   13,   29,  8, 11,  0 },
    {     16,   13,   30,  8, 11,  0 }, {     16,   13,   31,  8, 11,  0 }, {     16,   13,   32,  8, 11,  0 }, {     16,   12,   33,  8, 11,  0 }, {     16,   12,   34,  8, 11,  0 },
    {     16,   12,   35,  8, 11,  0 }, {     16,   12,   36,  8, 11,  0 }, {     16,   11,   37,  8, 11,  0 }, {     16,   11,   38,  8, 11,  0 }, {     16,   11,   39,  8, 11,  0 },
    {     16,   11,   40,  8, 11,  0 }, {     16,   10,   41,  8, 11,  0 }, {     16,   10,   42,  8, 11,  0 }, {     16,   10,   43,  8, 11,  0 }, {     16,   10,   44,  8, 11,  0 },
    {     16,    9,   45,  8, 11,  0 }, {     16,    9,   46,  8, 11,  0 }, {     16,    9,   47,  8, 11,  0 }, {     16,    8,   48,  8, 11,  0 }, {     16,    8,   49,  8, 11,  0 },
    {     16,    8,   50,  8, 11,  0 }, {     16,    7,   51,  8, 11,  0 }, {     16,    7,   52,  8, 11,  0 }, {     16,    6,   53,  8, 11,  0 }, {     16,    6,   54,  8, 11,  0 },
    {     16,    6,   55,  8, 11,  0 }, {     16,    5,   56,  8, 12,  0 }, {     16,    5,   57,  8, 12,  0 }, {     16,    4,   58,  8, 12,  0 }, {     16,    4,   59,  8, 12,  0 },
    {     16,    3,   60,  8, 12,  0 }, {     16,    3,   61,  8, 12,  0 }, {     16,    3,   62,  8, 12,  0 }, {     16,    2,   63,  8, 12,  0 }, {     16,    2,   64,  8, 12,  0 },
    {     16,    1,   65,  8, 12,  0 }, {     16,    1,   66,  8, 12,  0 }, {     16,    0,   67,  8, 12,  0 }, {     16,   -1,   68,  8, 12,  0 }, {     16,   -1,   69,  8, 12,  0 },
    {     16,   -2,   70,  8, 12,  0 }, {     16,   -2,   71,  8, 12,  0 }, {     16,   -3,   72,  8, 12,  0 }, {     16,   -3,   73,  8, 12,  0 }, {     16,   -4,   74,  8, 12,  0 },
    {     16,   -5,   75,  8, 12,  0 }, {     16,   -5,   76,  8, 12,  0 }, {     16,   -6,   77,  8, 12,  0 }, {     16,   -7,   78,  8, 12,  0 }, {     16,   -8,   79,  8, 12,  0 },
    {     16,   -8,   80,  8, 12,  0 }, {     16,   -9,   81,  8, 13,  0 }, {     16,  -10,   82,  8, 13,  0 }, {     16,  -11,   83,  8, 13,  0 }, {     16,  -11,   84,  8, 13,  0 },
    {     16,  -12,   85,  8, 13,  0 }, {     16,  -13,   86,  8, 13,  0 }, {     16,  -14,   87,  8, 13,  0 }, {     16,  -15,   88,  8, 13,  0 }, {     16,  -16,   89,  8, 13,  0 },
    {     16,  -17,   90,  8, 13,  0 }, {     16,  -18,   91,  8, 13,  0 }, {     16,  -19,   92,  8, 13,  0 }, {     16,  -20,   93,  8, 13,  0 }, {     16,  -21,   94,  8, 13,  0 },
    {     16,  -22,   95,  8, 13,  0 }, {     16,  -23,   96,  8, 13,  0 }, {     16,  -24,   97,  8, 13,  0 }, {     16,  -25,   97,  8, 13,  0 }, {     16,  -26,   98,  8, 13,  0 },
    {     16,  -27,   99,  8, 13,  0 }, {     16,  -28,  100,  8, 14,  0 }, {     16,  -29,  100,  8, 14,  0 }, {     16,  -30,  101,  8, 14,  0 }, {     16,  -31,  101,  8, 14,  0 },
    {     16,  -32,  102,  8, 14,  0 }, {     16,  -33,  103,  8, 14,  0 }, {     16,  -34,  103,  8, 14,  0 }, {     16,  -35,  104,  8, 14,  0 }, {     16,  -36,  104,  8, 14,  0 },
    {     16,  -37,  105,  8, 14,  0 }, {     16,  -38,  105,  8, 14,  0 }, {     16,  -39,  106,  8, 14,  0 }, {     16,  -40,  106,  8, 14,  0 }, {     16,  -41,  107,  8, 14,  0 },
    {     16,  -42,  107,  8, 14,  0 }, {     16,  -43,  107,  8, 14,  0 }, {     16,  -44,  108,  8, 15,  0 }, {     16,  -45,  108,  8, 15,  0 }, {     16,  -46,  108,  8, 15,  0 },
    {     16,  -47,  109,  8, 15,  0 }, {     16,  -48,  109,  8, 15,  0 }, {     16,  -49,  109,  8, 15,  0 }, {     16,  -50,  109,  8, 15,  0 }, {     16,  -51,  110,  8, 15,  0 },
    {     16,  -52,  110,  8, 15,  0 }, {     16,  -53,  110,  8, 15,  0 }, {     16,  -54,  110,  8, 15,  0 }, {     16,  -55,  110,  8, 16,  0 }, {     16,  -56,  111,  8, 16,  0 },
    {     16,  -57,  111,  8, 16,  0 }, {     16,  -58,  111,  8, 16,  0 }, {     16,  -59,  111,  8, 16,  0 }, {     16,  -60,  111,  8, 16,  0 }, {     16,  -61,  111,  8, 16,  0 },
    {     16,  -62,  111,  8, 16,  0 }, {     16,  -63,  111,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_974500, {
    {     16,   16,    0, 16, 10,  0 }, {     16,   16,    1, 16, 10,  0 }, {     16,   16,    2, 16, 10,  0 }, {     16,   16,    3, 16, 10,  0 }, {     16,   16,    4, 16, 10,  0 },
    {     16,   16,    5, 16, 10,  0 }, {     16,   16,    6, 16, 10,  0 }, {     16,   16,    7, 16, 10,  0 }, {     16,   16,    8, 16, 10,  0 }, {     16,   16,    9, 16, 10,  0 },
    {     16,   16,   10, 16, 10,  0 }, {     16,   16,   11, 16, 10,  0 }, {     16,   16,   12, 16, 10,  0 }, {     15,   16,   13, 16, 10,  0 }, {     15,   16,   14, 16, 10,  0 },
    {     15,   16,   15, 16, 10,  0 }, {     15,   16,   16, 16, 10,  0 }, {     15,   16,   17, 16, 10,  0 }, {     15,   16,   18, 16, 10,  0 }, {     15,   16,   19, 16, 10,  0 },
    {     15,   16,   20, 16, 10,  0 }, {     15,   16,   21, 16, 10,  0 }, {     14,   16,   22, 16, 11,  0 }, {     14,   16,   23, 16, 11,  0 }, {     14,   16,   24, 16, 11,  0 },
    {     14,   16,   25, 16, 11,  0 }, {     14,   16,   26, 16, 11,  0 }, {     14,   16,   27, 16, 11,  0 }, {     13,   16,   28, 16, 11,  0 }, {     13,   16,   29, 16, 11,  0 },
    {     13,   16,   30, 16, 11,  0 }, {     13,   16,   31, 16, 11,  0 }, {     13,   16,   32, 16, 11,  0 }, {     12,   16,   33, 16, 11,  0 }, {     12,   16,   34, 16, 11,  0 },
    {     12,   16,   35, 16, 11,  0 }, {     12,   16,   36, 16, 11,  0 }, {     11,   16,   37, 16, 11,  0 }, {     11,   16,   38, 16, 11,  0 }, {     11,   16,   39, 16, 11,  0 },
    {     11,   16,   40, 16, 11,  0 }, {     10,   16,   41, 16, 11,  0 }, {     10,   16,   42, 16, 11,  0 }, {     10,   16,   43, 16, 11,  0 }, {     10,   16,   44, 16, 11,  0 },
    {      9,   16,   45, 16, 11,  0 }, {      9,   16,   46, 16, 11,  0 }, {      9,   16,   47, 16, 11,  0 }, {      8,   16,   48, 16, 11,  0 }, {      8,   16,   49, 16, 11,  0 },
    {      8,   16,   50, 16, 11,  0 }, {      7,   16,   51, 16, 11,  0 }, {      7,   16,   52, 16, 11,  0 }, {      6,   16,   53, 16, 11,  0 }, {      6,   16,   54, 16, 11,  0 },
    {      6,   16,   55, 16, 11,  0 }, {      5,   16,   56, 16, 12,  0 }, {      5,   16,   57, 16, 12,  0 }, {      4,   16,   58, 16, 12,  0 }, {      4,   16,   59, 16, 12,  0 },
    {      3,   16,   60, 16, 12,  0 }, {      3,   16,   61, 16, 12,  0 }, {      3,   16,   62, 16, 12,  0 }, {      2,   16,   63, 16, 12,  0 }, {      2,   16,   64, 16, 12,  0 },
    {      1,   16,   65, 16, 12,  0 }, {      1,   16,   66, 16, 12,  0 }, {      0,   16,   67, 16, 12,  0 }, {     -1,   16,   68, 16, 12,  0 }, {     -1,   16,   69, 16, 12,  0 },
    {     -2,   16,   70, 16, 12,  0 }, {     -2,   16,   71, 16, 12,  0 }, {     -3,   16,   72, 16, 12,  0 }, {     -3,   16,   73, 16, 12,  0 }, {     -4,   16,   74, 16, 12,  0 },
    {     -5,   16,   75, 16, 12,  0 }, {     -5,   16,   76, 16, 12,  0 }, {     -6,   16,   77, 16, 12,  0 }, {     -7,   16,   78, 16, 12,  0 }, {     -8,   16,   79, 16, 12,  0 },
    {     -8,   16,   80, 16, 12,  0 }, {     -9,   16,   81, 16, 13,  0 }, {    -10,   16,   82, 16, 13,  0 }, {    -11,   16,   83, 16, 13,  0 }, {    -11,   16,   84, 16, 13,  0 },
    {    -12,   16,   85, 16, 13,  0 }, {    -13,   16,   86, 16, 13,  0 }, {    -14,   16,   87, 16, 13,  0 }, {    -15,   16,   88, 16, 13,  0 }, {    -16,   16,   89, 16, 13,  0 },
    {    -17,   16,   90, 16, 13,  0 }, {    -18,   16,   91, 16, 13,  0 }, {    -19,   16,   92, 16, 13,  0 }, {    -20,   16,   93, 16, 13,  0 }, {    -21,   16,   94, 16, 13,  0 },
    {    -22,   16,   95, 16, 13,  0 }, {    -23,   16,   96, 16, 13,  0 }, {    -24,   16,   97, 16, 13,  0 }, {    -25,   16,   97, 16, 13,  0 }, {    -26,   16,   98, 16, 13,  0 },
    {    -27,   16,   99, 16, 13,  0 }, {    -28,   16,  100, 16, 14,  0 }, {    -29,   16,  100, 16, 14,  0 }, {    -30,   16,  101, 16, 14,  0 }, {    -31,   16,  101, 16, 14,  0 },
    {    -32,   16,  102, 16, 14,  0 }, {    -33,   16,  103, 16, 14,  0 }, {    -34,   16,  103, 16, 14,  0 }, {    -35,   16,  104, 16, 14,  0 }, {    -36,   16,  104, 16, 14,  0 },
    {    -37,   16,  105, 16, 14,  0 }, {    -38,   16,  105, 16, 14,  0 }, {    -39,   16,  106, 16, 14,  0 }, {    -40,   16,  106, 16, 14,  0 }, {    -41,   16,  107, 16, 14,  0 },
    {    -42,   16,  107, 16, 14,  0 }, {    -43,   16,  107, 16, 14,  0 }, {    -44,   16,  108, 16, 15,  0 }, {    -45,   16,  108, 16, 15,  0 }, {    -46,   16,  108, 16, 15,  0 },
    {    -47,   16,  109, 16, 15,  0 }, {    -48,   16,  109, 16, 15,  0 }, {    -49,   16,  109, 16, 15,  0 }, {    -50,   16,  109, 16, 15,  0 }, {    -51,   16,  110, 16, 15,  0 },
    {    -52,   16,  110, 16, 15,  0 }, {    -53,   16,  110, 16, 15,  0 }, {    -54,   16,  110, 16, 15,  0 }, {    -55,   16,  110, 16, 16,  0 }, {    -56,   16,  111, 16, 16,  0 },
    {    -57,   16,  111, 16, 16,  0 }, {    -58,   16,  111, 16, 16,  0 }, {    -59,   16,  111, 16, 16,  0 }, {    -60,   16,  111, 16, 16,  0 }, {    -61,   16,  111, 16, 16,  0 },
    {    -62,   16,  111, 16, 16,  0 }, {    -63,   16,  111, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9749D3, {
    {     16,   16,    0, 24, 10,  0 }, {     16,   16,    1, 24, 10,  0 }, {     16,   16,    2, 24, 10,  0 }, {     16,   16,    3, 24, 10,  0 }, {     16,   16,    4, 24, 10,  0 },
    {     16,   16,    5, 24, 10,  0 }, {     16,   16,    6, 24, 10,  0 }, {     16,   16,    7, 24, 10,  0 }, {     16,   16,    8, 24, 10,  0 }, {     16,   16,    9, 24, 10,  0 },
    {     16,   16,   10, 24, 10,  0 }, {     16,   16,   11, 24, 10,  0 }, {     16,   16,   12, 24, 10,  0 }, {     16,   17,   13, 24, 10,  0 }, {     16,   17,   14, 24, 10,  0 },
    {     16,   17,   15, 24, 10,  0 }, {     16,   17,   16, 24, 10,  0 }, {     16,   17,   17, 24, 10,  0 }, {     16,   17,   18, 24, 10,  0 }, {     16,   17,   19, 24, 10,  0 },
    {     16,   17,   20, 24, 10,  0 }, {     16,   17,   21, 24, 10,  0 }, {     16,   18,   22, 24, 11,  0 }, {     16,   18,   23, 24, 11,  0 }, {     16,   18,   24, 24, 11,  0 },
    {     16,   18,   25, 24, 11,  0 }, {     16,   18,   26, 24, 11,  0 }, {     16,   18,   27, 24, 11,  0 }, {     16,   19,   28, 24, 11,  0 }, {     16,   19,   29, 24, 11,  0 },
    {     16,   19,   30, 24, 11,  0 }, {     16,   19,   31, 24, 11,  0 }, {     16,   19,   32, 24, 11,  0 }, {     16,   20,   33, 24, 11,  0 }, {     16,   20,   34, 24, 11,  0 },
    {     16,   20,   35, 24, 11,  0 }, {     16,   20,   36, 24, 11,  0 }, {     16,   21,   37, 24, 11,  0 }, {     16,   21,   38, 24, 11,  0 }, {     16,   21,   39, 24, 11,  0 },
    {     16,   21,   40, 24, 11,  0 }, {     16,   22,   41, 24, 11,  0 }, {     16,   22,   42, 24, 11,  0 }, {     16,   22,   43, 24, 11,  0 }, {     16,   22,   44, 24, 11,  0 },
    {     16,   23,   45, 24, 11,  0 }, {     16,   23,   46, 24, 11,  0 }, {     16,   23,   47, 24, 11,  0 }, {     16,   24,   48, 24, 11,  0 }, {     16,   24,   49, 24, 11,  0 },
    {     16,   24,   50, 24, 11,  0 }, {     16,   25,   51, 24, 11,  0 }, {     16,   25,   52, 24, 11,  0 }, {     16,   26,   53, 24, 11,  0 }, {     16,   26,   54, 24, 11,  0 },
    {     16,   26,   55, 24, 11,  0 }, {     16,   27,   56, 24, 12,  0 }, {     16,   27,   57, 24, 12,  0 }, {     16,   28,   58, 24, 12,  0 }, {     16,   28,   59, 24, 12,  0 },
    {     16,   29,   60, 24, 12,  0 }, {     16,   29,   61, 24, 12,  0 }, {     16,   29,   62, 24, 12,  0 }, {     16,   30,   63, 24, 12,  0 }, {     16,   30,   64, 24, 12,  0 },
    {     16,   31,   65, 24, 12,  0 }, {     16,   31,   66, 24, 12,  0 }, {     16,   32,   67, 24, 12,  0 }, {     16,   33,   68, 24, 12,  0 }, {     16,   33,   69, 24, 12,  0 },
    {     16,   34,   70, 24, 12,  0 }, {     16,   34,   71, 24, 12,  0 }, {     16,   35,   72, 24, 12,  0 }, {     16,   35,   73, 24, 12,  0 }, {     16,   36,   74, 24, 12,  0 },
    {     16,   37,   75, 24, 12,  0 }, {     16,   37,   76, 24, 12,  0 }, {     16,   38,   77, 24, 12,  0 }, {     16,   39,   78, 24, 12,  0 }, {     16,   40,   79, 24, 12,  0 },
    {     16,   40,   80, 24, 12,  0 }, {     16,   41,   81, 24, 13,  0 }, {     16,   42,   82, 24, 13,  0 }, {     16,   43,   83, 24, 13,  0 }, {     16,   43,   84, 24, 13,  0 },
    {     16,   44,   85, 24, 13,  0 }, {     16,   45,   86, 24, 13,  0 }, {     16,   46,   87, 24, 13,  0 }, {     16,   47,   88, 24, 13,  0 }, {     16,   48,   89, 24, 13,  0 },
    {     16,   49,   90, 24, 13,  0 }, {     16,   50,   91, 24, 13,  0 }, {     16,   51,   92, 24, 13,  0 }, {     16,   52,   93, 24, 13,  0 }, {     16,   53,   94, 24, 13,  0 },
    {     16,   54,   95, 24, 13,  0 }, {     16,   55,   96, 24, 13,  0 }, {     16,   56,   97, 24, 13,  0 }, {     16,   57,   97, 24, 13,  0 }, {     16,   58,   98, 24, 13,  0 },
    {     16,   59,   99, 24, 13,  0 }, {     16,   60,  100, 24, 14,  0 }, {     16,   61,  100, 24, 14,  0 }, {     16,   62,  101, 24, 14,  0 }, {     16,   63,  101, 24, 14,  0 },
    {     16,   64,  102, 24, 14,  0 }, {     16,   65,  103, 24, 14,  0 }, {     16,   66,  103, 24, 14,  0 }, {     16,   67,  104, 24, 14,  0 }, {     16,   68,  104, 24, 14,  0 },
    {     16,   69,  105, 24, 14,  0 }, {     16,   70,  105, 24, 14,  0 }, {     16,   71,  106, 24, 14,  0 }, {     16,   72,  106, 24, 14,  0 }, {     16,   73,  107, 24, 14,  0 },
    {     16,   74,  107, 24, 14,  0 }, {     16,   75,  107, 24, 14,  0 }, {     16,   76,  108, 24, 15,  0 }, {     16,   77,  108, 24, 15,  0 }, {     16,   78,  108, 24, 15,  0 },
    {     16,   79,  109, 24, 15,  0 }, {     16,   80,  109, 24, 15,  0 }, {     16,   81,  109, 24, 15,  0 }, {     16,   82,  109, 24, 15,  0 }, {     16,   83,  110, 24, 15,  0 },
    {     16,   84,  110, 24, 15,  0 }, {     16,   85,  110, 24, 15,  0 }, {     16,   86,  110, 24, 15,  0 }, {     16,   87,  110, 24, 16,  0 }, {     16,   88,  111, 24, 16,  0 },
    {     16,   89,  111, 24, 16,  0 }, {     16,   90,  111, 24, 16,  0 }, {     16,   91,  111, 24, 16,  0 }, {     16,   92,  111, 24, 16,  0 }, {     16,   93,  111, 24, 16,  0 },
    {     16,   94,  111, 24, 16,  0 }, {     16,   95,  111, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_974EA6, {
    {     31,   16,   16, 16, 16,  0 }, {     30,   16,   16, 16, 16,  0 }, {     29,   16,   16, 16, 16,  0 }, {     28,   16,   16, 16, 16,  0 }, {     27,   16,   16, 16, 16,  0 },
    {     26,   16,   16, 16, 16,  0 }, {     25,   16,   16, 16, 16,  0 }, {     24,   16,   16, 16, 16,  0 }, {     23,   16,   15, 16, 16,  0 }, {     22,   16,   15, 16, 23,  0 },
    {     21,   16,   15, 16, 23,  0 }, {     20,   16,   15, 16, 23,  0 }, {     19,   16,   15, 16, 23,  0 }, {     18,   16,   14, 16, 23,  0 }, {     17,   16,   14, 16, 23,  0 },
    {     16,   16,   14, 16, 23,  0 }, {     15,   16,   14, 16, 23,  0 }, {     14,   16,   13, 16, 23,  0 }, {     13,   16,   13, 16, 23,  0 }, {     12,   16,   13, 16, 23,  0 },
    {     11,   16,   12, 16, 22,  0 }, {     10,   16,   12, 16, 22,  0 }, {      9,   16,   12, 16, 22,  0 }, {      8,   16,   11, 16, 22,  0 }, {      7,   16,   11, 16, 22,  0 },
    {      6,   16,   10, 16, 22,  0 }, {      5,   16,   10, 16, 22,  0 }, {      4,   16,    9, 16, 22,  0 }, {      3,   16,    9, 16, 22,  0 }, {      2,   16,    8, 16, 22,  0 },
    {      1,   16,    8, 16, 22,  0 }, {      0,   16,    7, 16, 22,  0 }, {     -1,   16,    6, 16, 22,  0 }, {     -2,   16,    6, 16, 22,  0 }, {     -3,   16,    5, 16, 22,  0 },
    {     -4,   16,    5, 16, 22,  0 }, {     -5,   16,    4, 16, 21,  0 }, {     -6,   16,    3, 16, 21,  0 }, {     -7,   16,    2, 16, 21,  0 }, {     -8,   16,    2, 16, 21,  0 },
    {     -9,   16,    1, 16, 21,  0 }, {    -10,   16,    0, 16, 21,  0 }, {    -11,   16,   -1, 16, 21,  0 }, {    -12,   16,   -2, 16, 21,  0 }, {    -13,   16,   -3, 16, 21,  0 },
    {    -14,   16,   -4, 16, 21,  0 }, {    -15,   16,   -5, 16, 21,  0 }, {    -16,   16,   -6, 16, 21,  0 }, {    -17,   16,   -7, 16, 21,  0 }, {    -18,   16,   -8, 16, 21,  0 },
    {    -19,   16,   -9, 16, 21,  0 }, {    -20,   16,  -10, 16, 21,  0 }, {    -21,   16,  -11, 16, 21,  0 }, {    -21,   16,  -12, 16, 21,  0 }, {    -22,   16,  -13, 16, 21,  0 },
    {    -23,   16,  -14, 16, 21,  0 }, {    -24,   16,  -15, 16, 20,  0 }, {    -24,   16,  -16, 16, 20,  0 }, {    -25,   16,  -17, 16, 20,  0 }, {    -26,   16,  -18, 16, 20,  0 },
    {    -27,   16,  -19, 16, 20,  0 }, {    -27,   16,  -20, 16, 20,  0 }, {    -28,   16,  -21, 16, 20,  0 }, {    -29,   16,  -22, 16, 20,  0 }, {    -29,   16,  -23, 16, 20,  0 },
    {    -30,   16,  -24, 16, 20,  0 }, {    -30,   16,  -25, 16, 20,  0 }, {    -31,   16,  -26, 16, 20,  0 }, {    -31,   16,  -27, 16, 20,  0 }, {    -32,   16,  -28, 16, 20,  0 },
    {    -33,   16,  -29, 16, 20,  0 }, {    -33,   16,  -30, 16, 20,  0 }, {    -34,   16,  -31, 16, 20,  0 }, {    -34,   16,  -32, 16, 20,  0 }, {    -35,   16,  -33, 16, 20,  0 },
    {    -35,   16,  -34, 16, 20,  0 }, {    -35,   16,  -35, 16, 20,  0 }, {    -36,   16,  -36, 16, 20,  0 }, {    -36,   16,  -37, 16, 20,  0 }, {    -37,   16,  -38, 16, 20,  0 },
    {    -37,   16,  -39, 16, 20,  0 }, {    -38,   16,  -40, 16, 19,  0 }, {    -38,   16,  -41, 16, 19,  0 }, {    -38,   16,  -42, 16, 19,  0 }, {    -39,   16,  -43, 16, 19,  0 },
    {    -39,   16,  -44, 16, 19,  0 }, {    -40,   16,  -45, 16, 19,  0 }, {    -40,   16,  -46, 16, 19,  0 }, {    -40,   16,  -47, 16, 19,  0 }, {    -41,   16,  -48, 16, 19,  0 },
    {    -41,   16,  -49, 16, 19,  0 }, {    -41,   16,  -50, 16, 19,  0 }, {    -42,   16,  -51, 16, 19,  0 }, {    -42,   16,  -52, 16, 19,  0 }, {    -42,   16,  -53, 16, 19,  0 },
    {    -42,   16,  -54, 16, 19,  0 }, {    -43,   16,  -55, 16, 19,  0 }, {    -43,   16,  -56, 16, 19,  0 }, {    -43,   16,  -57, 16, 19,  0 }, {    -43,   16,  -58, 16, 19,  0 },
    {    -44,   16,  -59, 16, 19,  0 }, {    -44,   16,  -60, 16, 19,  0 }, {    -44,   16,  -61, 16, 19,  0 }, {    -44,   16,  -62, 16, 19,  0 }, {    -45,   16,  -63, 16, 19,  0 },
    {    -45,   16,  -64, 16, 19,  0 }, {    -45,   16,  -65, 16, 19,  0 }, {    -45,   16,  -66, 16, 19,  0 }, {    -45,   16,  -67, 16, 19,  0 }, {    -46,   16,  -68, 16, 19,  0 },
    {    -46,   16,  -69, 16, 19,  0 }, {    -46,   16,  -70, 16, 19,  0 }, {    -46,   16,  -71, 16, 19,  0 }, {    -46,   16,  -72, 16, 19,  0 }, {    -46,   16,  -73, 16, 19,  0 },
    {    -47,   16,  -74, 16, 19,  0 }, {    -47,   16,  -75, 16, 18,  0 }, {    -47,   16,  -76, 16, 18,  0 }, {    -47,   16,  -77, 16, 18,  0 }, {    -47,   16,  -78, 16, 18,  0 },
    {    -47,   16,  -79, 16, 18,  0 }, {    -47,   16,  -80, 16, 18,  0 }, {    -47,   16,  -81, 16, 18,  0 }, {    -47,   16,  -82, 16, 18,  0 }, {    -48,   16,  -83, 16, 18,  0 },
    {    -48,   16,  -84, 16, 18,  0 }, {    -48,   16,  -85, 16, 18,  0 }, {    -48,   16,  -86, 16, 18,  0 }, {    -48,   16,  -87, 16, 18,  0 }, {    -48,   16,  -88, 16, 18,  0 },
    {    -48,   16,  -89, 16, 18,  0 }, {    -48,   16,  -90, 16, 18,  0 }, {    -48,   16,  -91, 16, 18,  0 }, {    -48,   16,  -92, 16, 18,  0 }, {    -48,   16,  -93, 16, 18,  0 },
    {    -48,   16,  -94, 16, 18,  0 }, {    -48,   16,  -95, 16, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_975379, {
    {     16,    0,   16, 24, 16,  0 }, {     16,    1,   16, 24, 16,  0 }, {     16,    2,   16, 24, 16,  0 }, {     16,    3,   16, 24, 16,  0 }, {     16,    4,   16, 24, 16,  0 },
    {     16,    5,   16, 24, 16,  0 }, {     16,    6,   16, 24, 16,  0 }, {     16,    7,   16, 24, 16,  0 }, {     16,    8,   15, 24, 16,  0 }, {     16,    9,   15, 24, 23,  0 },
    {     16,   10,   15, 24, 23,  0 }, {     16,   11,   15, 24, 23,  0 }, {     16,   12,   15, 24, 23,  0 }, {     16,   13,   14, 24, 23,  0 }, {     16,   14,   14, 24, 23,  0 },
    {     16,   15,   14, 24, 23,  0 }, {     16,   16,   14, 24, 23,  0 }, {     16,   17,   13, 24, 23,  0 }, {     16,   18,   13, 24, 23,  0 }, {     16,   19,   13, 24, 23,  0 },
    {     16,   20,   12, 24, 22,  0 }, {     16,   21,   12, 24, 22,  0 }, {     16,   22,   12, 24, 22,  0 }, {     16,   23,   11, 24, 22,  0 }, {     16,   24,   11, 24, 22,  0 },
    {     16,   25,   10, 24, 22,  0 }, {     16,   26,   10, 24, 22,  0 }, {     16,   27,    9, 24, 22,  0 }, {     16,   28,    9, 24, 22,  0 }, {     16,   29,    8, 24, 22,  0 },
    {     16,   30,    8, 24, 22,  0 }, {     16,   31,    7, 24, 22,  0 }, {     16,   32,    6, 24, 22,  0 }, {     16,   33,    6, 24, 22,  0 }, {     16,   34,    5, 24, 22,  0 },
    {     16,   35,    5, 24, 22,  0 }, {     16,   36,    4, 24, 21,  0 }, {     16,   37,    3, 24, 21,  0 }, {     16,   38,    2, 24, 21,  0 }, {     16,   39,    2, 24, 21,  0 },
    {     16,   40,    1, 24, 21,  0 }, {     16,   41,    0, 24, 21,  0 }, {     16,   42,   -1, 24, 21,  0 }, {     16,   43,   -2, 24, 21,  0 }, {     16,   44,   -3, 24, 21,  0 },
    {     16,   45,   -4, 24, 21,  0 }, {     16,   46,   -5, 24, 21,  0 }, {     16,   47,   -6, 24, 21,  0 }, {     16,   48,   -7, 24, 21,  0 }, {     16,   49,   -8, 24, 21,  0 },
    {     16,   50,   -9, 24, 21,  0 }, {     16,   51,  -10, 24, 21,  0 }, {     16,   52,  -11, 24, 21,  0 }, {     16,   52,  -12, 24, 21,  0 }, {     16,   53,  -13, 24, 21,  0 },
    {     16,   54,  -14, 24, 21,  0 }, {     16,   55,  -15, 24, 20,  0 }, {     16,   55,  -16, 24, 20,  0 }, {     16,   56,  -17, 24, 20,  0 }, {     16,   57,  -18, 24, 20,  0 },
    {     16,   58,  -19, 24, 20,  0 }, {     16,   58,  -20, 24, 20,  0 }, {     16,   59,  -21, 24, 20,  0 }, {     16,   60,  -22, 24, 20,  0 }, {     16,   60,  -23, 24, 20,  0 },
    {     16,   61,  -24, 24, 20,  0 }, {     16,   61,  -25, 24, 20,  0 }, {     16,   62,  -26, 24, 20,  0 }, {     16,   62,  -27, 24, 20,  0 }, {     16,   63,  -28, 24, 20,  0 },
    {     16,   64,  -29, 24, 20,  0 }, {     16,   64,  -30, 24, 20,  0 }, {     16,   65,  -31, 24, 20,  0 }, {     16,   65,  -32, 24, 20,  0 }, {     16,   66,  -33, 24, 20,  0 },
    {     16,   66,  -34, 24, 20,  0 }, {     16,   66,  -35, 24, 20,  0 }, {     16,   67,  -36, 24, 20,  0 }, {     16,   67,  -37, 24, 20,  0 }, {     16,   68,  -38, 24, 20,  0 },
    {     16,   68,  -39, 24, 20,  0 }, {     16,   69,  -40, 24, 19,  0 }, {     16,   69,  -41, 24, 19,  0 }, {     16,   69,  -42, 24, 19,  0 }, {     16,   70,  -43, 24, 19,  0 },
    {     16,   70,  -44, 24, 19,  0 }, {     16,   71,  -45, 24, 19,  0 }, {     16,   71,  -46, 24, 19,  0 }, {     16,   71,  -47, 24, 19,  0 }, {     16,   72,  -48, 24, 19,  0 },
    {     16,   72,  -49, 24, 19,  0 }, {     16,   72,  -50, 24, 19,  0 }, {     16,   73,  -51, 24, 19,  0 }, {     16,   73,  -52, 24, 19,  0 }, {     16,   73,  -53, 24, 19,  0 },
    {     16,   73,  -54, 24, 19,  0 }, {     16,   74,  -55, 24, 19,  0 }, {     16,   74,  -56, 24, 19,  0 }, {     16,   74,  -57, 24, 19,  0 }, {     16,   74,  -58, 24, 19,  0 },
    {     16,   75,  -59, 24, 19,  0 }, {     16,   75,  -60, 24, 19,  0 }, {     16,   75,  -61, 24, 19,  0 }, {     16,   75,  -62, 24, 19,  0 }, {     16,   76,  -63, 24, 19,  0 },
    {     16,   76,  -64, 24, 19,  0 }, {     16,   76,  -65, 24, 19,  0 }, {     16,   76,  -66, 24, 19,  0 }, {     16,   76,  -67, 24, 19,  0 }, {     16,   77,  -68, 24, 19,  0 },
    {     16,   77,  -69, 24, 19,  0 }, {     16,   77,  -70, 24, 19,  0 }, {     16,   77,  -71, 24, 19,  0 }, {     16,   77,  -72, 24, 19,  0 }, {     16,   77,  -73, 24, 19,  0 },
    {     16,   78,  -74, 24, 19,  0 }, {     16,   78,  -75, 24, 18,  0 }, {     16,   78,  -76, 24, 18,  0 }, {     16,   78,  -77, 24, 18,  0 }, {     16,   78,  -78, 24, 18,  0 },
    {     16,   78,  -79, 24, 18,  0 }, {     16,   78,  -80, 24, 18,  0 }, {     16,   78,  -81, 24, 18,  0 }, {     16,   78,  -82, 24, 18,  0 }, {     16,   79,  -83, 24, 18,  0 },
    {     16,   79,  -84, 24, 18,  0 }, {     16,   79,  -85, 24, 18,  0 }, {     16,   79,  -86, 24, 18,  0 }, {     16,   79,  -87, 24, 18,  0 }, {     16,   79,  -88, 24, 18,  0 },
    {     16,   79,  -89, 24, 18,  0 }, {     16,   79,  -90, 24, 18,  0 }, {     16,   79,  -91, 24, 18,  0 }, {     16,   79,  -92, 24, 18,  0 }, {     16,   79,  -93, 24, 18,  0 },
    {     16,   79,  -94, 24, 18,  0 }, {     16,   79,  -95, 24, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_97584C, {
    {      0,   16,   16,  0, 16,  0 }, {      1,   16,   16,  0, 16,  0 }, {      2,   16,   16,  0, 16,  0 }, {      3,   16,   16,  0, 16,  0 }, {      4,   16,   16,  0, 16,  0 },
    {      5,   16,   16,  0, 16,  0 }, {      6,   16,   16,  0, 16,  0 }, {      7,   16,   16,  0, 16,  0 }, {      8,   16,   15,  0, 16,  0 }, {      9,   16,   15,  0, 23,  0 },
    {     10,   16,   15,  0, 23,  0 }, {     11,   16,   15,  0, 23,  0 }, {     12,   16,   15,  0, 23,  0 }, {     13,   16,   14,  0, 23,  0 }, {     14,   16,   14,  0, 23,  0 },
    {     15,   16,   14,  0, 23,  0 }, {     16,   16,   14,  0, 23,  0 }, {     17,   16,   13,  0, 23,  0 }, {     18,   16,   13,  0, 23,  0 }, {     19,   16,   13,  0, 23,  0 },
    {     20,   16,   12,  0, 22,  0 }, {     21,   16,   12,  0, 22,  0 }, {     22,   16,   12,  0, 22,  0 }, {     23,   16,   11,  0, 22,  0 }, {     24,   16,   11,  0, 22,  0 },
    {     25,   16,   10,  0, 22,  0 }, {     26,   16,   10,  0, 22,  0 }, {     27,   16,    9,  0, 22,  0 }, {     28,   16,    9,  0, 22,  0 }, {     29,   16,    8,  0, 22,  0 },
    {     30,   16,    8,  0, 22,  0 }, {     31,   16,    7,  0, 22,  0 }, {     32,   16,    6,  0, 22,  0 }, {     33,   16,    6,  0, 22,  0 }, {     34,   16,    5,  0, 22,  0 },
    {     35,   16,    5,  0, 22,  0 }, {     36,   16,    4,  0, 21,  0 }, {     37,   16,    3,  0, 21,  0 }, {     38,   16,    2,  0, 21,  0 }, {     39,   16,    2,  0, 21,  0 },
    {     40,   16,    1,  0, 21,  0 }, {     41,   16,    0,  0, 21,  0 }, {     42,   16,   -1,  0, 21,  0 }, {     43,   16,   -2,  0, 21,  0 }, {     44,   16,   -3,  0, 21,  0 },
    {     45,   16,   -4,  0, 21,  0 }, {     46,   16,   -5,  0, 21,  0 }, {     47,   16,   -6,  0, 21,  0 }, {     48,   16,   -7,  0, 21,  0 }, {     49,   16,   -8,  0, 21,  0 },
    {     50,   16,   -9,  0, 21,  0 }, {     51,   16,  -10,  0, 21,  0 }, {     52,   16,  -11,  0, 21,  0 }, {     52,   16,  -12,  0, 21,  0 }, {     53,   16,  -13,  0, 21,  0 },
    {     54,   16,  -14,  0, 21,  0 }, {     55,   16,  -15,  0, 20,  0 }, {     55,   16,  -16,  0, 20,  0 }, {     56,   16,  -17,  0, 20,  0 }, {     57,   16,  -18,  0, 20,  0 },
    {     58,   16,  -19,  0, 20,  0 }, {     58,   16,  -20,  0, 20,  0 }, {     59,   16,  -21,  0, 20,  0 }, {     60,   16,  -22,  0, 20,  0 }, {     60,   16,  -23,  0, 20,  0 },
    {     61,   16,  -24,  0, 20,  0 }, {     61,   16,  -25,  0, 20,  0 }, {     62,   16,  -26,  0, 20,  0 }, {     62,   16,  -27,  0, 20,  0 }, {     63,   16,  -28,  0, 20,  0 },
    {     64,   16,  -29,  0, 20,  0 }, {     64,   16,  -30,  0, 20,  0 }, {     65,   16,  -31,  0, 20,  0 }, {     65,   16,  -32,  0, 20,  0 }, {     66,   16,  -33,  0, 20,  0 },
    {     66,   16,  -34,  0, 20,  0 }, {     66,   16,  -35,  0, 20,  0 }, {     67,   16,  -36,  0, 20,  0 }, {     67,   16,  -37,  0, 20,  0 }, {     68,   16,  -38,  0, 20,  0 },
    {     68,   16,  -39,  0, 20,  0 }, {     69,   16,  -40,  0, 19,  0 }, {     69,   16,  -41,  0, 19,  0 }, {     69,   16,  -42,  0, 19,  0 }, {     70,   16,  -43,  0, 19,  0 },
    {     70,   16,  -44,  0, 19,  0 }, {     71,   16,  -45,  0, 19,  0 }, {     71,   16,  -46,  0, 19,  0 }, {     71,   16,  -47,  0, 19,  0 }, {     72,   16,  -48,  0, 19,  0 },
    {     72,   16,  -49,  0, 19,  0 }, {     72,   16,  -50,  0, 19,  0 }, {     73,   16,  -51,  0, 19,  0 }, {     73,   16,  -52,  0, 19,  0 }, {     73,   16,  -53,  0, 19,  0 },
    {     73,   16,  -54,  0, 19,  0 }, {     74,   16,  -55,  0, 19,  0 }, {     74,   16,  -56,  0, 19,  0 }, {     74,   16,  -57,  0, 19,  0 }, {     74,   16,  -58,  0, 19,  0 },
    {     75,   16,  -59,  0, 19,  0 }, {     75,   16,  -60,  0, 19,  0 }, {     75,   16,  -61,  0, 19,  0 }, {     75,   16,  -62,  0, 19,  0 }, {     76,   16,  -63,  0, 19,  0 },
    {     76,   16,  -64,  0, 19,  0 }, {     76,   16,  -65,  0, 19,  0 }, {     76,   16,  -66,  0, 19,  0 }, {     76,   16,  -67,  0, 19,  0 }, {     77,   16,  -68,  0, 19,  0 },
    {     77,   16,  -69,  0, 19,  0 }, {     77,   16,  -70,  0, 19,  0 }, {     77,   16,  -71,  0, 19,  0 }, {     77,   16,  -72,  0, 19,  0 }, {     77,   16,  -73,  0, 19,  0 },
    {     78,   16,  -74,  0, 19,  0 }, {     78,   16,  -75,  0, 18,  0 }, {     78,   16,  -76,  0, 18,  0 }, {     78,   16,  -77,  0, 18,  0 }, {     78,   16,  -78,  0, 18,  0 },
    {     78,   16,  -79,  0, 18,  0 }, {     78,   16,  -80,  0, 18,  0 }, {     78,   16,  -81,  0, 18,  0 }, {     78,   16,  -82,  0, 18,  0 }, {     79,   16,  -83,  0, 18,  0 },
    {     79,   16,  -84,  0, 18,  0 }, {     79,   16,  -85,  0, 18,  0 }, {     79,   16,  -86,  0, 18,  0 }, {     79,   16,  -87,  0, 18,  0 }, {     79,   16,  -88,  0, 18,  0 },
    {     79,   16,  -89,  0, 18,  0 }, {     79,   16,  -90,  0, 18,  0 }, {     79,   16,  -91,  0, 18,  0 }, {     79,   16,  -92,  0, 18,  0 }, {     79,   16,  -93,  0, 18,  0 },
    {     79,   16,  -94,  0, 18,  0 }, {     79,   16,  -95,  0, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_975D1F, {
    {     16,   31,   16,  8, 16,  0 }, {     16,   30,   16,  8, 16,  0 }, {     16,   29,   16,  8, 16,  0 }, {     16,   28,   16,  8, 16,  0 }, {     16,   27,   16,  8, 16,  0 },
    {     16,   26,   16,  8, 16,  0 }, {     16,   25,   16,  8, 16,  0 }, {     16,   24,   16,  8, 16,  0 }, {     16,   23,   15,  8, 16,  0 }, {     16,   22,   15,  8, 23,  0 },
    {     16,   21,   15,  8, 23,  0 }, {     16,   20,   15,  8, 23,  0 }, {     16,   19,   15,  8, 23,  0 }, {     16,   18,   14,  8, 23,  0 }, {     16,   17,   14,  8, 23,  0 },
    {     16,   16,   14,  8, 23,  0 }, {     16,   15,   14,  8, 23,  0 }, {     16,   14,   13,  8, 23,  0 }, {     16,   13,   13,  8, 23,  0 }, {     16,   12,   13,  8, 23,  0 },
    {     16,   11,   12,  8, 22,  0 }, {     16,   10,   12,  8, 22,  0 }, {     16,    9,   12,  8, 22,  0 }, {     16,    8,   11,  8, 22,  0 }, {     16,    7,   11,  8, 22,  0 },
    {     16,    6,   10,  8, 22,  0 }, {     16,    5,   10,  8, 22,  0 }, {     16,    4,    9,  8, 22,  0 }, {     16,    3,    9,  8, 22,  0 }, {     16,    2,    8,  8, 22,  0 },
    {     16,    1,    8,  8, 22,  0 }, {     16,    0,    7,  8, 22,  0 }, {     16,   -1,    6,  8, 22,  0 }, {     16,   -2,    6,  8, 22,  0 }, {     16,   -3,    5,  8, 22,  0 },
    {     16,   -4,    5,  8, 22,  0 }, {     16,   -5,    4,  8, 21,  0 }, {     16,   -6,    3,  8, 21,  0 }, {     16,   -7,    2,  8, 21,  0 }, {     16,   -8,    2,  8, 21,  0 },
    {     16,   -9,    1,  8, 21,  0 }, {     16,  -10,    0,  8, 21,  0 }, {     16,  -11,   -1,  8, 21,  0 }, {     16,  -12,   -2,  8, 21,  0 }, {     16,  -13,   -3,  8, 21,  0 },
    {     16,  -14,   -4,  8, 21,  0 }, {     16,  -15,   -5,  8, 21,  0 }, {     16,  -16,   -6,  8, 21,  0 }, {     16,  -17,   -7,  8, 21,  0 }, {     16,  -18,   -8,  8, 21,  0 },
    {     16,  -19,   -9,  8, 21,  0 }, {     16,  -20,  -10,  8, 21,  0 }, {     16,  -21,  -11,  8, 21,  0 }, {     16,  -21,  -12,  8, 21,  0 }, {     16,  -22,  -13,  8, 21,  0 },
    {     16,  -23,  -14,  8, 21,  0 }, {     16,  -24,  -15,  8, 20,  0 }, {     16,  -24,  -16,  8, 20,  0 }, {     16,  -25,  -17,  8, 20,  0 }, {     16,  -26,  -18,  8, 20,  0 },
    {     16,  -27,  -19,  8, 20,  0 }, {     16,  -27,  -20,  8, 20,  0 }, {     16,  -28,  -21,  8, 20,  0 }, {     16,  -29,  -22,  8, 20,  0 }, {     16,  -29,  -23,  8, 20,  0 },
    {     16,  -30,  -24,  8, 20,  0 }, {     16,  -30,  -25,  8, 20,  0 }, {     16,  -31,  -26,  8, 20,  0 }, {     16,  -31,  -27,  8, 20,  0 }, {     16,  -32,  -28,  8, 20,  0 },
    {     16,  -33,  -29,  8, 20,  0 }, {     16,  -33,  -30,  8, 20,  0 }, {     16,  -34,  -31,  8, 20,  0 }, {     16,  -34,  -32,  8, 20,  0 }, {     16,  -35,  -33,  8, 20,  0 },
    {     16,  -35,  -34,  8, 20,  0 }, {     16,  -35,  -35,  8, 20,  0 }, {     16,  -36,  -36,  8, 20,  0 }, {     16,  -36,  -37,  8, 20,  0 }, {     16,  -37,  -38,  8, 20,  0 },
    {     16,  -37,  -39,  8, 20,  0 }, {     16,  -38,  -40,  8, 19,  0 }, {     16,  -38,  -41,  8, 19,  0 }, {     16,  -38,  -42,  8, 19,  0 }, {     16,  -39,  -43,  8, 19,  0 },
    {     16,  -39,  -44,  8, 19,  0 }, {     16,  -40,  -45,  8, 19,  0 }, {     16,  -40,  -46,  8, 19,  0 }, {     16,  -40,  -47,  8, 19,  0 }, {     16,  -41,  -48,  8, 19,  0 },
    {     16,  -41,  -49,  8, 19,  0 }, {     16,  -41,  -50,  8, 19,  0 }, {     16,  -42,  -51,  8, 19,  0 }, {     16,  -42,  -52,  8, 19,  0 }, {     16,  -42,  -53,  8, 19,  0 },
    {     16,  -42,  -54,  8, 19,  0 }, {     16,  -43,  -55,  8, 19,  0 }, {     16,  -43,  -56,  8, 19,  0 }, {     16,  -43,  -57,  8, 19,  0 }, {     16,  -43,  -58,  8, 19,  0 },
    {     16,  -44,  -59,  8, 19,  0 }, {     16,  -44,  -60,  8, 19,  0 }, {     16,  -44,  -61,  8, 19,  0 }, {     16,  -44,  -62,  8, 19,  0 }, {     16,  -45,  -63,  8, 19,  0 },
    {     16,  -45,  -64,  8, 19,  0 }, {     16,  -45,  -65,  8, 19,  0 }, {     16,  -45,  -66,  8, 19,  0 }, {     16,  -45,  -67,  8, 19,  0 }, {     16,  -46,  -68,  8, 19,  0 },
    {     16,  -46,  -69,  8, 19,  0 }, {     16,  -46,  -70,  8, 19,  0 }, {     16,  -46,  -71,  8, 19,  0 }, {     16,  -46,  -72,  8, 19,  0 }, {     16,  -46,  -73,  8, 19,  0 },
    {     16,  -47,  -74,  8, 19,  0 }, {     16,  -47,  -75,  8, 18,  0 }, {     16,  -47,  -76,  8, 18,  0 }, {     16,  -47,  -77,  8, 18,  0 }, {     16,  -47,  -78,  8, 18,  0 },
    {     16,  -47,  -79,  8, 18,  0 }, {     16,  -47,  -80,  8, 18,  0 }, {     16,  -47,  -81,  8, 18,  0 }, {     16,  -47,  -82,  8, 18,  0 }, {     16,  -48,  -83,  8, 18,  0 },
    {     16,  -48,  -84,  8, 18,  0 }, {     16,  -48,  -85,  8, 18,  0 }, {     16,  -48,  -86,  8, 18,  0 }, {     16,  -48,  -87,  8, 18,  0 }, {     16,  -48,  -88,  8, 18,  0 },
    {     16,  -48,  -89,  8, 18,  0 }, {     16,  -48,  -90,  8, 18,  0 }, {     16,  -48,  -91,  8, 18,  0 }, {     16,  -48,  -92,  8, 18,  0 }, {     16,  -48,  -93,  8, 18,  0 },
    {     16,  -48,  -94,  8, 18,  0 }, {     16,  -48,  -95,  8, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FDFAA, {
    {     31,   16,    0,  0, 59,  0 }, {     30,   16,    0,  0, 59,  0 }, {     29,   16,    0,  0, 59,  0 }, {     28,   16,    0,  0, 59,  0 }, {     27,   16,    1, 31, 59,  0 },
    {     26,   16,    1, 31, 59,  0 }, {     25,   15,    1, 31, 59,  0 }, {     24,   15,    1, 31, 59,  0 }, {     23,   15,    1, 31, 59,  0 }, {     22,   15,    2, 31, 59,  0 },
    {     21,   15,    2, 31, 59,  0 }, {     20,   15,    2, 31, 59,  0 }, {     19,   14,    2, 31, 59,  0 }, {     18,   14,    2, 30, 59,  0 }, {     17,   14,    3, 30, 59,  0 },
    {     16,   13,    3, 30, 59,  0 }, {     15,   13,    3, 30, 59,  0 }, {     14,   13,    3, 30, 59,  0 }, {     13,   12,    4, 30, 59,  0 }, {     12,   12,    4, 30, 59,  0 },
    {     11,   11,    4, 30, 59,  0 }, {     10,   11,    4, 30, 59,  0 }, {      9,   10,    5, 30, 59,  0 }, {      8,   10,    5, 29, 59,  0 }, {      7,    9,    5, 29, 59,  0 },
    {      6,    9,    5, 29, 59,  0 }, {      5,    8,    5, 29, 59,  0 }, {      4,    7,    6, 29, 59,  0 }, {      3,    7,    6, 29, 59,  0 }, {      2,    6,    6, 29, 59,  0 },
    {      1,    5,    7, 29, 59,  0 }, {      0,    4,    7, 29, 59,  0 }, {     -1,    3,    7, 28, 59,  0 }, {     -3,    3,    7, 28, 59,  0 }, {     -4,    2,    8, 28, 59,  0 },
    {     -5,    1,    8, 28, 59,  0 }, {     -6,    0,    8, 28, 59,  0 }, {     -7,   -1,    8, 27, 59,  0 }, {     -7,   -2,    9, 27, 59,  0 }, {     -8,   -3,    9, 27, 59,  0 },
    {     -9,   -4,    9, 27, 59,  0 }, {     -9,   -5,    9, 27, 59,  0 }, {    -10,   -6,   10, 27, 59,  0 }, {    -10,   -7,   10, 27, 59,  0 }, {    -11,   -8,   10, 27, 59,  0 },
    {    -11,   -9,   10, 27, 59,  0 }, {    -12,  -10,   11, 26, 59,  0 }, {    -12,  -11,   11, 26, 59,  0 }, {    -13,  -12,   11, 26, 59,  0 }, {    -13,  -13,   11, 26, 59,  0 },
    {    -13,  -14,   12, 26, 59,  0 }, {    -14,  -15,   12, 26, 59,  0 }, {    -14,  -16,   12, 26, 59,  0 }, {    -14,  -17,   12, 26, 59,  0 }, {    -15,  -18,   12, 26, 59,  0 },
    {    -15,  -19,   13, 26, 59,  0 }, {    -15,  -20,   13, 25, 59,  0 }, {    -15,  -21,   13, 25, 59,  0 }, {    -15,  -22,   13, 25, 59,  0 }, {    -15,  -23,   14, 25, 59,  0 },
    {    -16,  -24,   14, 25, 59,  0 }, {    -16,  -25,   14, 25, 59,  0 }, {    -16,  -26,   14, 25, 59,  0 }, {    -16,  -27,   14, 25, 59,  0 }, {    -16,  -28,   15, 24, 59,  0 },
    {    -16,  -29,   15, 24, 59,  0 }, {    -16,  -30,   15, 24, 59,  0 }, {    -16,  -31,   15, 24, 59,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FE210, {
    {     16,    0,    0,  8, 59,  0 }, {     16,    1,    0,  8, 59,  0 }, {     16,    2,    0,  8, 59,  0 }, {     16,    3,    0,  8, 59,  0 }, {     16,    4,    0,  8, 59,  0 },
    {     16,    5,    1,  7, 59,  0 }, {     16,    6,    1,  7, 59,  0 }, {     15,    7,    1,  7, 59,  0 }, {     15,    8,    1,  7, 59,  0 }, {     15,    9,    1,  7, 59,  0 },
    {     15,   10,    2,  7, 59,  0 }, {     15,   11,    2,  7, 59,  0 }, {     15,   12,    2,  7, 59,  0 }, {     14,   13,    2,  7, 59,  0 }, {     14,   14,    2,  6, 59,  0 },
    {     14,   15,    3,  6, 59,  0 }, {     13,   16,    3,  6, 59,  0 }, {     13,   17,    3,  6, 59,  0 }, {     13,   18,    3,  6, 59,  0 }, {     12,   19,    4,  6, 59,  0 },
    {     12,   20,    4,  6, 59,  0 }, {     11,   21,    4,  6, 59,  0 }, {     11,   22,    4,  6, 59,  0 }, {     10,   23,    5,  6, 59,  0 }, {     10,   24,    5,  5, 59,  0 },
    {      9,   25,    5,  5, 59,  0 }, {      9,   26,    5,  5, 59,  0 }, {      8,   27,    5,  5, 59,  0 }, {      7,   28,    6,  5, 59,  0 }, {      7,   29,    6,  5, 59,  0 },
    {      6,   30,    6,  5, 59,  0 }, {      5,   31,    7,  5, 59,  0 }, {      4,   32,    7,  5, 59,  0 }, {      3,   33,    7,  4, 59,  0 }, {      3,   35,    7,  4, 59,  0 },
    {      2,   36,    8,  4, 59,  0 }, {      1,   37,    8,  4, 59,  0 }, {      0,   38,    8,  4, 59,  0 }, {     -1,   39,    8,  3, 59,  0 }, {     -2,   39,    9,  3, 59,  0 },
    {     -3,   40,    9,  3, 59,  0 }, {     -4,   41,    9,  3, 59,  0 }, {     -5,   41,    9,  3, 59,  0 }, {     -6,   42,   10,  3, 59,  0 }, {     -7,   42,   10,  3, 59,  0 },
    {     -8,   43,   10,  3, 59,  0 }, {     -9,   43,   10,  3, 59,  0 }, {    -10,   44,   11,  2, 59,  0 }, {    -11,   44,   11,  2, 59,  0 }, {    -12,   45,   11,  2, 59,  0 },
    {    -13,   45,   11,  2, 59,  0 }, {    -14,   45,   12,  2, 59,  0 }, {    -15,   46,   12,  2, 59,  0 }, {    -16,   46,   12,  2, 59,  0 }, {    -17,   46,   12,  2, 59,  0 },
    {    -18,   47,   12,  2, 59,  0 }, {    -19,   47,   13,  2, 59,  0 }, {    -20,   47,   13,  1, 59,  0 }, {    -21,   47,   13,  1, 59,  0 }, {    -22,   47,   13,  1, 59,  0 },
    {    -23,   47,   14,  1, 59,  0 }, {    -24,   48,   14,  1, 59,  0 }, {    -25,   48,   14,  1, 59,  0 }, {    -26,   48,   14,  1, 59,  0 }, {    -27,   48,   14,  1, 59,  0 },
    {    -28,   48,   15,  0, 59,  0 }, {    -29,   48,   15,  0, 59,  0 }, {    -30,   48,   15,  0, 59,  0 }, {    -31,   48,   15,  0, 59,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FE47F, {
    {      0,   16,    0, 16, 59,  0 }, {      1,   16,    0, 16, 59,  0 }, {      2,   16,    0, 16, 59,  0 }, {      3,   16,    0, 16, 59,  0 }, {      4,   16,    0, 16, 59,  0 },
    {      5,   16,    1, 15, 59,  0 }, {      6,   16,    1, 15, 59,  0 }, {      7,   17,    1, 15, 59,  0 }, {      8,   17,    1, 15, 59,  0 }, {      9,   17,    1, 15, 59,  0 },
    {     10,   17,    2, 15, 59,  0 }, {     11,   17,    2, 15, 59,  0 }, {     12,   17,    2, 15, 59,  0 }, {     13,   18,    2, 15, 59,  0 }, {     14,   18,    3, 14, 59,  0 },
    {     15,   18,    3, 14, 59,  0 }, {     16,   19,    3, 14, 59,  0 }, {     17,   19,    3, 14, 59,  0 }, {     18,   19,    3, 14, 59,  0 }, {     19,   20,    4, 14, 59,  0 },
    {     20,   20,    4, 14, 59,  0 }, {     21,   21,    4, 14, 59,  0 }, {     22,   21,    4, 14, 59,  0 }, {     23,   22,    5, 14, 59,  0 }, {     24,   22,    5, 13, 59,  0 },
    {     25,   23,    5, 13, 59,  0 }, {     26,   23,    5, 13, 59,  0 }, {     27,   24,    6, 13, 59,  0 }, {     28,   25,    6, 13, 59,  0 }, {     29,   25,    6, 13, 59,  0 },
    {     30,   26,    6, 13, 59,  0 }, {     31,   27,    7, 13, 59,  0 }, {     32,   28,    7, 13, 59,  0 }, {     33,   29,    7, 12, 59,  0 }, {     35,   29,    7, 12, 59,  0 },
    {     36,   30,    8, 12, 59,  0 }, {     37,   31,    8, 12, 59,  0 }, {     38,   32,    8, 12, 59,  0 }, {     39,   33,    9, 11, 59,  0 }, {     39,   34,    9, 11, 59,  0 },
    {     40,   35,    9, 11, 59,  0 }, {     41,   36,    9, 11, 59,  0 }, {     41,   37,   10, 11, 59,  0 }, {     42,   38,   10, 11, 59,  0 }, {     42,   39,   10, 11, 59,  0 },
    {     43,   40,   10, 11, 59,  0 }, {     43,   41,   11, 11, 59,  0 }, {     44,   42,   11, 10, 59,  0 }, {     44,   43,   11, 10, 59,  0 }, {     45,   44,   11, 10, 59,  0 },
    {     45,   45,   12, 10, 59,  0 }, {     45,   46,   12, 10, 59,  0 }, {     46,   47,   12, 10, 59,  0 }, {     46,   48,   12, 10, 59,  0 }, {     46,   49,   12, 10, 59,  0 },
    {     47,   50,   13, 10, 59,  0 }, {     47,   51,   13, 10, 59,  0 }, {     47,   52,   13,  9, 59,  0 }, {     47,   53,   13,  9, 59,  0 }, {     47,   54,   14,  9, 59,  0 },
    {     47,   55,   14,  9, 59,  0 }, {     48,   56,   14,  9, 59,  0 }, {     48,   57,   14,  9, 59,  0 }, {     48,   58,   14,  9, 59,  0 }, {     48,   59,   15,  9, 59,  0 },
    {     48,   60,   15,  8, 59,  0 }, {     48,   61,   15,  8, 59,  0 }, {     48,   62,   15,  8, 59,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FE6E5, {
    {     16,   31,    0, 24, 59,  0 }, {     16,   30,    0, 24, 59,  0 }, {     16,   29,    0, 24, 59,  0 }, {     16,   28,    0, 24, 59,  0 }, {     16,   27,    1, 23, 59,  0 },
    {     16,   26,    1, 23, 59,  0 }, {     17,   25,    1, 23, 59,  0 }, {     17,   24,    1, 23, 59,  0 }, {     17,   23,    1, 23, 59,  0 }, {     17,   22,    2, 23, 59,  0 },
    {     17,   21,    2, 23, 59,  0 }, {     17,   20,    2, 23, 59,  0 }, {     18,   19,    2, 23, 59,  0 }, {     18,   18,    3, 22, 59,  0 }, {     18,   17,    3, 22, 59,  0 },
    {     19,   16,    3, 22, 59,  0 }, {     19,   15,    3, 22, 59,  0 }, {     19,   14,    3, 22, 59,  0 }, {     20,   13,    4, 22, 59,  0 }, {     20,   12,    4, 22, 59,  0 },
    {     21,   11,    4, 22, 59,  0 }, {     21,   10,    4, 22, 59,  0 }, {     22,    9,    5, 22, 59,  0 }, {     22,    8,    5, 21, 59,  0 }, {     23,    7,    5, 21, 59,  0 },
    {     23,    6,    5, 21, 59,  0 }, {     24,    5,    6, 21, 59,  0 }, {     25,    4,    6, 21, 59,  0 }, {     25,    3,    6, 21, 59,  0 }, {     26,    2,    6, 21, 59,  0 },
    {     27,    1,    7, 21, 59,  0 }, {     28,    0,    7, 21, 59,  0 }, {     29,   -1,    7, 20, 59,  0 }, {     29,   -3,    7, 20, 59,  0 }, {     30,   -4,    8, 20, 59,  0 },
    {     31,   -5,    8, 20, 59,  0 }, {     32,   -6,    8, 20, 59,  0 }, {     33,   -7,    9, 19, 59,  0 }, {     34,   -7,    9, 19, 59,  0 }, {     35,   -8,    9, 19, 59,  0 },
    {     36,   -9,    9, 19, 59,  0 }, {     37,   -9,   10, 19, 59,  0 }, {     38,  -10,   10, 19, 59,  0 }, {     39,  -10,   10, 19, 59,  0 }, {     40,  -11,   10, 19, 59,  0 },
    {     41,  -11,   11, 19, 59,  0 }, {     42,  -12,   11, 18, 59,  0 }, {     43,  -12,   11, 18, 59,  0 }, {     44,  -13,   11, 18, 59,  0 }, {     45,  -13,   12, 18, 59,  0 },
    {     46,  -13,   12, 18, 59,  0 }, {     47,  -14,   12, 18, 59,  0 }, {     48,  -14,   12, 18, 59,  0 }, {     49,  -14,   12, 18, 59,  0 }, {     50,  -15,   13, 18, 59,  0 },
    {     51,  -15,   13, 18, 59,  0 }, {     52,  -15,   13, 17, 59,  0 }, {     53,  -15,   13, 17, 59,  0 }, {     54,  -15,   14, 17, 59,  0 }, {     55,  -15,   14, 17, 59,  0 },
    {     56,  -16,   14, 17, 59,  0 }, {     57,  -16,   14, 17, 59,  0 }, {     58,  -16,   14, 17, 59,  0 }, {     59,  -16,   15, 17, 59,  0 }, {     60,  -16,   15, 16, 59,  0 },
    {     61,  -16,   15, 16, 59,  0 }, {     62,  -16,   15, 16, 59,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FE942, {
    {     31,   16,    0,  0, 59,  0 }, {     30,   16,    0,  0, 59,  0 }, {     29,   16,    0,  0, 59,  0 }, {     28,   16,    0,  0, 59,  0 }, {     27,   16,    1,  1, 59,  0 },
    {     26,   16,    1,  1, 59,  0 }, {     25,   17,    1,  1, 59,  0 }, {     24,   17,    1,  1, 59,  0 }, {     23,   17,    1,  1, 59,  0 }, {     22,   17,    2,  1, 59,  0 },
    {     21,   17,    2,  1, 59,  0 }, {     20,   17,    2,  1, 59,  0 }, {     19,   18,    2,  1, 59,  0 }, {     18,   18,    3,  2, 59,  0 }, {     17,   18,    3,  2, 59,  0 },
    {     16,   19,    3,  2, 59,  0 }, {     15,   19,    3,  2, 59,  0 }, {     14,   19,    3,  2, 59,  0 }, {     13,   20,    4,  2, 59,  0 }, {     12,   20,    4,  2, 59,  0 },
    {     11,   21,    4,  2, 59,  0 }, {     10,   21,    4,  2, 59,  0 }, {      9,   22,    5,  2, 59,  0 }, {      8,   22,    5,  3, 59,  0 }, {      7,   23,    5,  3, 59,  0 },
    {      6,   23,    5,  3, 59,  0 }, {      5,   24,    6,  3, 59,  0 }, {      4,   25,    6,  3, 59,  0 }, {      3,   25,    6,  3, 59,  0 }, {      2,   26,    6,  3, 59,  0 },
    {      1,   27,    7,  3, 59,  0 }, {      0,   28,    7,  3, 59,  0 }, {     -1,   29,    7,  4, 59,  0 }, {     -3,   29,    7,  4, 59,  0 }, {     -4,   30,    8,  4, 59,  0 },
    {     -5,   31,    8,  4, 59,  0 }, {     -6,   32,    8,  4, 59,  0 }, {     -7,   33,    9,  5, 59,  0 }, {     -7,   34,    9,  5, 59,  0 }, {     -8,   35,    9,  5, 59,  0 },
    {     -9,   36,    9,  5, 59,  0 }, {     -9,   37,   10,  5, 59,  0 }, {    -10,   38,   10,  5, 59,  0 }, {    -10,   39,   10,  5, 59,  0 }, {    -11,   40,   10,  5, 59,  0 },
    {    -11,   41,   11,  5, 59,  0 }, {    -12,   42,   11,  6, 59,  0 }, {    -12,   43,   11,  6, 59,  0 }, {    -13,   44,   11,  6, 59,  0 }, {    -13,   45,   12,  6, 59,  0 },
    {    -13,   46,   12,  6, 59,  0 }, {    -14,   47,   12,  6, 59,  0 }, {    -14,   48,   12,  6, 59,  0 }, {    -14,   49,   12,  6, 59,  0 }, {    -15,   50,   13,  6, 59,  0 },
    {    -15,   51,   13,  6, 59,  0 }, {    -15,   52,   13,  7, 59,  0 }, {    -15,   53,   13,  7, 59,  0 }, {    -15,   54,   14,  7, 59,  0 }, {    -15,   55,   14,  7, 59,  0 },
    {    -16,   56,   14,  7, 59,  0 }, {    -16,   57,   14,  7, 59,  0 }, {    -16,   58,   14,  7, 59,  0 }, {    -16,   59,   15,  7, 59,  0 }, {    -16,   60,   15,  8, 59,  0 },
    {    -16,   61,   15,  8, 59,  0 }, {    -16,   62,   15,  8, 59,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FEB9F, {
    {     16,    0,    0,  8, 59,  0 }, {     16,    1,    0,  8, 59,  0 }, {     16,    2,    0,  8, 59,  0 }, {     16,    3,    0,  8, 59,  0 }, {     16,    4,    0,  8, 59,  0 },
    {     16,    5,    1,  9, 59,  0 }, {     16,    6,    1,  9, 59,  0 }, {     17,    7,    1,  9, 59,  0 }, {     17,    8,    1,  9, 59,  0 }, {     17,    9,    1,  9, 59,  0 },
    {     17,   10,    2,  9, 59,  0 }, {     17,   11,    2,  9, 59,  0 }, {     17,   12,    2,  9, 59,  0 }, {     18,   13,    2,  9, 59,  0 }, {     18,   14,    3, 10, 59,  0 },
    {     18,   15,    3, 10, 59,  0 }, {     19,   16,    3, 10, 59,  0 }, {     19,   17,    3, 10, 59,  0 }, {     19,   18,    3, 10, 59,  0 }, {     20,   19,    4, 10, 59,  0 },
    {     20,   20,    4, 10, 59,  0 }, {     21,   21,    4, 10, 59,  0 }, {     21,   22,    4, 10, 59,  0 }, {     22,   23,    5, 10, 59,  0 }, {     22,   24,    5, 11, 59,  0 },
    {     23,   25,    5, 11, 59,  0 }, {     23,   26,    5, 11, 59,  0 }, {     24,   27,    6, 11, 59,  0 }, {     25,   28,    6, 11, 59,  0 }, {     25,   29,    6, 11, 59,  0 },
    {     26,   30,    6, 11, 59,  0 }, {     27,   31,    7, 11, 59,  0 }, {     28,   32,    7, 11, 59,  0 }, {     29,   33,    7, 12, 59,  0 }, {     29,   35,    7, 12, 59,  0 },
    {     30,   36,    8, 12, 59,  0 }, {     31,   37,    8, 12, 59,  0 }, {     32,   38,    8, 12, 59,  0 }, {     33,   39,    9, 13, 59,  0 }, {     34,   39,    9, 13, 59,  0 },
    {     35,   40,    9, 13, 59,  0 }, {     36,   41,    9, 13, 59,  0 }, {     37,   41,   10, 13, 59,  0 }, {     38,   42,   10, 13, 59,  0 }, {     39,   42,   10, 13, 59,  0 },
    {     40,   43,   10, 13, 59,  0 }, {     41,   43,   11, 13, 59,  0 }, {     42,   44,   11, 14, 59,  0 }, {     43,   44,   11, 14, 59,  0 }, {     44,   45,   11, 14, 59,  0 },
    {     45,   45,   12, 14, 59,  0 }, {     46,   45,   12, 14, 59,  0 }, {     47,   46,   12, 14, 59,  0 }, {     48,   46,   12, 14, 59,  0 }, {     49,   46,   12, 14, 59,  0 },
    {     50,   47,   13, 14, 59,  0 }, {     51,   47,   13, 14, 59,  0 }, {     52,   47,   13, 15, 59,  0 }, {     53,   47,   13, 15, 59,  0 }, {     54,   47,   14, 15, 59,  0 },
    {     55,   47,   14, 15, 59,  0 }, {     56,   48,   14, 15, 59,  0 }, {     57,   48,   14, 15, 59,  0 }, {     58,   48,   14, 15, 59,  0 }, {     59,   48,   15, 15, 59,  0 },
    {     60,   48,   15, 16, 59,  0 }, {     61,   48,   15, 16, 59,  0 }, {     62,   48,   15, 16, 59,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FEE05, {
    {      0,   16,    0, 16, 59,  0 }, {      1,   16,    0, 16, 59,  0 }, {      2,   16,    0, 16, 59,  0 }, {      3,   16,    0, 16, 59,  0 }, {      4,   16,    0, 16, 59,  0 },
    {      5,   16,    1, 17, 59,  0 }, {      6,   16,    1, 17, 59,  0 }, {      7,   15,    1, 17, 59,  0 }, {      8,   15,    1, 17, 59,  0 }, {      9,   15,    1, 17, 59,  0 },
    {     10,   15,    2, 17, 59,  0 }, {     11,   15,    2, 17, 59,  0 }, {     12,   15,    2, 17, 59,  0 }, {     13,   14,    2, 17, 59,  0 }, {     14,   14,    2, 18, 59,  0 },
    {     15,   14,    3, 18, 59,  0 }, {     16,   13,    3, 18, 59,  0 }, {     17,   13,    3, 18, 59,  0 }, {     18,   13,    3, 18, 59,  0 }, {     19,   12,    4, 18, 59,  0 },
    {     20,   12,    4, 18, 59,  0 }, {     21,   11,    4, 18, 59,  0 }, {     22,   11,    4, 18, 59,  0 }, {     23,   10,    5, 18, 59,  0 }, {     24,   10,    5, 19, 59,  0 },
    {     25,    9,    5, 19, 59,  0 }, {     26,    9,    5, 19, 59,  0 }, {     27,    8,    5, 19, 59,  0 }, {     28,    7,    6, 19, 59,  0 }, {     29,    7,    6, 19, 59,  0 },
    {     30,    6,    6, 19, 59,  0 }, {     31,    5,    7, 19, 59,  0 }, {     32,    4,    7, 19, 59,  0 }, {     33,    3,    7, 20, 59,  0 }, {     35,    3,    7, 20, 59,  0 },
    {     36,    2,    8, 20, 59,  0 }, {     37,    1,    8, 20, 59,  0 }, {     38,    0,    8, 20, 59,  0 }, {     39,   -1,    8, 21, 59,  0 }, {     39,   -2,    9, 21, 59,  0 },
    {     40,   -3,    9, 21, 59,  0 }, {     41,   -4,    9, 21, 59,  0 }, {     41,   -5,    9, 21, 59,  0 }, {     42,   -6,   10, 21, 59,  0 }, {     42,   -7,   10, 21, 59,  0 },
    {     43,   -8,   10, 21, 59,  0 }, {     43,   -9,   10, 21, 59,  0 }, {     44,  -10,   11, 22, 59,  0 }, {     44,  -11,   11, 22, 59,  0 }, {     45,  -12,   11, 22, 59,  0 },
    {     45,  -13,   11, 22, 59,  0 }, {     45,  -14,   12, 22, 59,  0 }, {     46,  -15,   12, 22, 59,  0 }, {     46,  -16,   12, 22, 59,  0 }, {     46,  -17,   12, 22, 59,  0 },
    {     47,  -18,   12, 22, 59,  0 }, {     47,  -19,   13, 22, 59,  0 }, {     47,  -20,   13, 23, 59,  0 }, {     47,  -21,   13, 23, 59,  0 }, {     47,  -22,   13, 23, 59,  0 },
    {     47,  -23,   14, 23, 59,  0 }, {     48,  -24,   14, 23, 59,  0 }, {     48,  -25,   14, 23, 59,  0 }, {     48,  -26,   14, 23, 59,  0 }, {     48,  -27,   14, 23, 59,  0 },
    {     48,  -28,   15, 24, 59,  0 }, {     48,  -29,   15, 24, 59,  0 }, {     48,  -30,   15, 24, 59,  0 }, {     48,  -31,   15, 24, 59,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FF074, {
    {     16,   31,    0, 24, 59,  0 }, {     16,   30,    0, 24, 59,  0 }, {     16,   29,    0, 24, 59,  0 }, {     16,   28,    0, 24, 59,  0 }, {     16,   27,    1, 25, 59,  0 },
    {     16,   26,    1, 25, 59,  0 }, {     15,   25,    1, 25, 59,  0 }, {     15,   24,    1, 25, 59,  0 }, {     15,   23,    1, 25, 59,  0 }, {     15,   22,    2, 25, 59,  0 },
    {     15,   21,    2, 25, 59,  0 }, {     15,   20,    2, 25, 59,  0 }, {     14,   19,    2, 25, 59,  0 }, {     14,   18,    2, 26, 59,  0 }, {     14,   17,    3, 26, 59,  0 },
    {     13,   16,    3, 26, 59,  0 }, {     13,   15,    3, 26, 59,  0 }, {     13,   14,    3, 26, 59,  0 }, {     12,   13,    4, 26, 59,  0 }, {     12,   12,    4, 26, 59,  0 },
    {     11,   11,    4, 26, 59,  0 }, {     11,   10,    4, 26, 59,  0 }, {     10,    9,    5, 26, 59,  0 }, {     10,    8,    5, 27, 59,  0 }, {      9,    7,    5, 27, 59,  0 },
    {      9,    6,    5, 27, 59,  0 }, {      8,    5,    5, 27, 59,  0 }, {      7,    4,    6, 27, 59,  0 }, {      7,    3,    6, 27, 59,  0 }, {      6,    2,    6, 27, 59,  0 },
    {      5,    1,    7, 27, 59,  0 }, {      4,    0,    7, 27, 59,  0 }, {      3,   -1,    7, 28, 59,  0 }, {      3,   -3,    7, 28, 59,  0 }, {      2,   -4,    8, 28, 59,  0 },
    {      1,   -5,    8, 28, 59,  0 }, {      0,   -6,    8, 28, 59,  0 }, {     -1,   -7,    8, 29, 59,  0 }, {     -2,   -7,    9, 29, 59,  0 }, {     -3,   -8,    9, 29, 59,  0 },
    {     -4,   -9,    9, 29, 59,  0 }, {     -5,   -9,    9, 29, 59,  0 }, {     -6,  -10,   10, 29, 59,  0 }, {     -7,  -10,   10, 29, 59,  0 }, {     -8,  -11,   10, 29, 59,  0 },
    {     -9,  -11,   10, 29, 59,  0 }, {    -10,  -12,   11, 30, 59,  0 }, {    -11,  -12,   11, 30, 59,  0 }, {    -12,  -13,   11, 30, 59,  0 }, {    -13,  -13,   11, 30, 59,  0 },
    {    -14,  -13,   12, 30, 59,  0 }, {    -15,  -14,   12, 30, 59,  0 }, {    -16,  -14,   12, 30, 59,  0 }, {    -17,  -14,   12, 30, 59,  0 }, {    -18,  -15,   12, 30, 59,  0 },
    {    -19,  -15,   13, 30, 59,  0 }, {    -20,  -15,   13, 31, 59,  0 }, {    -21,  -15,   13, 31, 59,  0 }, {    -22,  -15,   13, 31, 59,  0 }, {    -23,  -15,   14, 31, 59,  0 },
    {    -24,  -16,   14, 31, 59,  0 }, {    -25,  -16,   14, 31, 59,  0 }, {    -26,  -16,   14, 31, 59,  0 }, {    -27,  -16,   14, 31, 59,  0 }, {    -28,  -16,   15,  0, 59,  0 },
    {    -29,  -16,   15,  0, 59,  0 }, {    -30,  -16,   15,  0, 59,  0 }, {    -31,  -16,   15,  0, 59,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94F14E, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   15,    0,  0,  0,  0 }, {     25,   15,    0,  0,  0,  0 }, {     24,   14,    0,  0,  0,  0 }, {     23,   14,    0,  0,  0,  0 }, {     22,   13,    0,  0,  0,  0 },
    {     21,   13,    0,  0,  0,  0 }, {     20,   12,    0,  0,  0,  0 }, {     19,   11,    0,  0,  0,  0 }, {     18,   11,    0,  0,  0,  0 }, {     17,   10,    0,  0,  0,  0 },
    {     16,    9,    0,  0,  0,  0 }, {     15,    9,    0,  0,  0,  0 }, {     14,    8,    0,  0,  0,  0 }, {     13,    8,    0,  0,  0,  0 }, {     12,    7,    0,  0,  0,  0 },
    {     11,    7,    0,  0,  0,  0 }, {     10,    6,    0,  0,  0,  0 }, {      9,    6,    0,  0,  0,  0 }, {      8,    6,    0,  0,  0,  0 }, {      7,    5,    0,  0,  0,  0 },
    {      6,    5,    0,  0,  0,  0 }, {      5,    4,    0,  0,  0,  0 }, {      4,    4,    0,  0,  0,  0 }, {      3,    4,    0,  0,  0,  0 }, {      2,    3,    0,  0,  0,  0 },
    {      1,    3,    0,  0,  0,  0 }, {      0,    3,    0,  0,  0,  0 }, {     -1,    2,    0,  0,  0,  0 }, {     -2,    2,    0,  0,  0,  0 }, {     -3,    2,    0,  0,  0,  0 },
    {     -4,    2,    0,  0,  0,  0 }, {     -5,    2,    0,  0,  0,  0 }, {     -6,    1,    0,  0,  0,  0 }, {     -7,    1,    0,  0,  0,  0 }, {     -8,    1,    0,  0,  0,  0 },
    {     -9,    1,    0,  0,  0,  0 }, {    -10,    1,    0,  0,  0,  0 }, {    -11,    0,    0,  0,  0,  0 }, {    -12,    0,    0,  0,  0,  0 }, {    -13,    0,    0,  0,  0,  0 },
    {    -14,    0,    0,  0,  0,  0 }, {    -15,    0,    0,  0,  0,  0 }, {    -16,    0,    0,  0,  0,  0 }, {    -17,    0,    0,  0,  0,  0 }, {    -18,    0,    0,  0,  0,  0 },
    {    -19,    0,    0,  0,  0,  0 }, {    -20,    0,    0,  0,  0,  0 }, {    -21,    0,    0,  0,  0,  0 }, {    -22,    0,    0,  0,  0,  0 }, {    -23,    1,    0,  0,  0,  0 },
    {    -24,    1,    0,  0,  0,  0 }, {    -25,    1,    0,  0,  0,  0 }, {    -26,    1,    0,  0,  0,  0 }, {    -27,    1,    0,  0,  0,  0 }, {    -28,    2,    0,  0,  0,  0 },
    {    -29,    2,    0,  0,  0,  0 }, {    -30,    2,    0,  0,  0,  0 }, {    -31,    2,    0,  0,  0,  0 }, {    -32,    2,    0,  0,  0,  0 }, {    -33,    3,    0,  0,  0,  0 },
    {    -34,    3,    0,  0,  0,  0 }, {    -35,    3,    0,  0,  0,  0 }, {    -36,    4,    0,  0,  0,  0 }, {    -37,    4,    0,  0,  0,  0 }, {    -38,    4,    0,  0,  0,  0 },
    {    -39,    5,    0,  0,  0,  0 }, {    -40,    5,    0,  0,  0,  0 }, {    -41,    6,    0,  0,  0,  0 }, {    -42,    6,    0,  0,  0,  0 }, {    -43,    6,    0,  0,  0,  0 },
    {    -44,    7,    0,  0,  0,  0 }, {    -45,    7,    0,  0,  0,  0 }, {    -46,    8,    0,  0,  0,  0 }, {    -47,    8,    0,  0,  0,  0 }, {    -48,    9,    0,  0,  0,  0 },
    {    -49,    9,    0,  0,  0,  0 }, {    -50,   10,    0,  0,  0,  0 }, {    -51,   11,    0,  0,  0,  0 }, {    -52,   11,    0,  0,  0,  0 }, {    -53,   12,    0,  0,  0,  0 },
    {    -54,   13,    0,  0,  0,  0 }, {    -55,   13,    0,  0,  0,  0 }, {    -56,   14,    0,  0,  0,  0 }, {    -57,   14,    0,  0,  0,  0 }, {    -58,   15,    0,  0,  0,  0 },
    {    -59,   15,    0,  0,  0,  0 }, {    -60,   16,    0,  0,  0,  0 }, {    -61,   16,    0,  0,  0,  0 }, {    -62,   16,    0,  0,  0,  0 }, {    -63,   16,    0,  0,  0,  0 },
    {    -64,   16,    0,  0,  0,  0 }, {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 },
    {     27,   16,    0,  0,  0,  0 }, {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 },
    {     22,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 },
    {     17,   16,    0,  0,  0,  0 }, {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 },
    {     12,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {     10,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 },
    {      7,   16,    0,  0,  0,  0 }, {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 },
    {      2,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -2,   16,    0,  0,  0,  0 },
    {     -3,   16,    0,  0,  0,  0 }, {     -4,   16,    0,  0,  0,  0 }, {     -5,   16,    0,  0,  0,  0 }, {     -6,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 },
    {     -8,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, {    -10,   16,    0,  0,  0,  0 }, {    -11,   16,    0,  0,  0,  0 }, {    -12,   16,    0,  0,  0,  0 },
    {    -13,   16,    0,  0,  0,  0 }, {    -14,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, {    -16,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 },
    {    -18,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 }, {    -20,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -22,   16,    0,  0,  0,  0 },
    {    -23,   16,    0,  0,  0,  0 }, {    -24,   16,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 }, {    -26,   16,    0,  0,  0,  0 }, {    -27,   16,    0,  0,  0,  0 },
    {    -28,   16,    0,  0,  0,  0 }, {    -29,   16,    0,  0,  0,  0 }, {    -30,   16,    0,  0,  0,  0 }, {    -31,   16,    0,  0,  0,  0 }, {    -32,   16,    0,  0,  0,  0 },
    {    -33,   16,    0,  0,  0,  0 }, {    -34,   16,    0,  0,  0,  0 }, {    -35,   16,    0,  0,  0,  0 }, {    -36,   16,    0,  0,  0,  0 }, {    -37,   16,    0,  0,  0,  0 },
    {    -38,   16,    0,  0,  0,  0 }, {    -39,   16,    0,  0,  0,  0 }, {    -40,   16,    0,  0,  0,  0 }, {    -41,   16,    0,  0,  0,  0 }, {    -42,   16,    0,  0,  0,  0 },
    {    -43,   16,    0,  0,  0,  0 }, {    -44,   16,    0,  0,  0,  0 }, {    -45,   16,    0,  0,  0,  0 }, {    -46,   16,    0,  0,  0,  0 }, {    -47,   16,    0,  0,  0,  0 },
    {    -48,   16,    0,  0,  0,  0 }, {    -49,   16,    0,  0,  0,  0 }, {    -50,   16,    0,  0,  0,  0 }, {    -51,   16,    0,  0,  0,  0 }, {    -52,   16,    0,  0,  0,  0 },
    {    -53,   16,    0,  0,  0,  0 }, {    -54,   16,    0,  0,  0,  0 }, {    -55,   16,    0,  0,  0,  0 }, {    -56,   16,    0,  0,  0,  0 }, {    -57,   16,    0,  0,  0,  0 },
    {    -58,   16,    0,  0,  0,  0 }, {    -59,   16,    0,  0,  0,  0 }, {    -60,   16,    0,  0,  0,  0 }, {    -61,   16,    0,  0,  0,  0 }, {    -62,   16,    0,  0,  0,  0 },
    {    -63,   16,    0,  0,  0,  0 }, {    -64,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94F810, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     15,    5,    0,  8,  0,  0 }, {     15,    6,    0,  8,  0,  0 }, {     14,    7,    0,  8,  0,  0 }, {     14,    8,    0,  8,  0,  0 }, {     13,    9,    0,  8,  0,  0 },
    {     13,   10,    0,  8,  0,  0 }, {     12,   11,    0,  8,  0,  0 }, {     11,   12,    0,  8,  0,  0 }, {     11,   13,    0,  8,  0,  0 }, {     10,   14,    0,  8,  0,  0 },
    {      9,   15,    0,  8,  0,  0 }, {      9,   16,    0,  8,  0,  0 }, {      8,   17,    0,  8,  0,  0 }, {      8,   18,    0,  8,  0,  0 }, {      7,   19,    0,  8,  0,  0 },
    {      7,   20,    0,  8,  0,  0 }, {      6,   21,    0,  8,  0,  0 }, {      6,   22,    0,  8,  0,  0 }, {      6,   23,    0,  8,  0,  0 }, {      5,   24,    0,  8,  0,  0 },
    {      5,   25,    0,  8,  0,  0 }, {      4,   26,    0,  8,  0,  0 }, {      4,   27,    0,  8,  0,  0 }, {      4,   28,    0,  8,  0,  0 }, {      3,   29,    0,  8,  0,  0 },
    {      3,   30,    0,  8,  0,  0 }, {      3,   31,    0,  8,  0,  0 }, {      2,   32,    0,  8,  0,  0 }, {      2,   33,    0,  8,  0,  0 }, {      2,   34,    0,  8,  0,  0 },
    {      2,   35,    0,  8,  0,  0 }, {      2,   36,    0,  8,  0,  0 }, {      1,   37,    0,  8,  0,  0 }, {      1,   38,    0,  8,  0,  0 }, {      1,   39,    0,  8,  0,  0 },
    {      1,   40,    0,  8,  0,  0 }, {      1,   41,    0,  8,  0,  0 }, {      0,   42,    0,  8,  0,  0 }, {      0,   43,    0,  8,  0,  0 }, {      0,   44,    0,  8,  0,  0 },
    {      0,   45,    0,  8,  0,  0 }, {      0,   46,    0,  8,  0,  0 }, {      0,   47,    0,  8,  0,  0 }, {      0,   48,    0,  8,  0,  0 }, {      0,   49,    0,  8,  0,  0 },
    {      0,   50,    0,  8,  0,  0 }, {      0,   51,    0,  8,  0,  0 }, {      0,   52,    0,  8,  0,  0 }, {      0,   53,    0,  8,  0,  0 }, {      1,   54,    0,  8,  0,  0 },
    {      1,   55,    0,  8,  0,  0 }, {      1,   56,    0,  8,  0,  0 }, {      1,   57,    0,  8,  0,  0 }, {      1,   58,    0,  8,  0,  0 }, {      2,   59,    0,  8,  0,  0 },
    {      2,   60,    0,  8,  0,  0 }, {      2,   61,    0,  8,  0,  0 }, {      2,   62,    0,  8,  0,  0 }, {      2,   63,    0,  8,  0,  0 }, {      3,   64,    0,  8,  0,  0 },
    {      3,   65,    0,  8,  0,  0 }, {      3,   66,    0,  8,  0,  0 }, {      4,   67,    0,  8,  0,  0 }, {      4,   68,    0,  8,  0,  0 }, {      4,   69,    0,  8,  0,  0 },
    {      5,   70,    0,  8,  0,  0 }, {      5,   71,    0,  8,  0,  0 }, {      6,   72,    0,  8,  0,  0 }, {      6,   73,    0,  8,  0,  0 }, {      6,   74,    0,  8,  0,  0 },
    {      7,   75,    0,  8,  0,  0 }, {      7,   76,    0,  8,  0,  0 }, {      8,   77,    0,  8,  0,  0 }, {      8,   78,    0,  8,  0,  0 }, {      9,   79,    0,  8,  0,  0 },
    {      9,   80,    0,  8,  0,  0 }, {     10,   81,    0,  8,  0,  0 }, {     11,   82,    0,  8,  0,  0 }, {     11,   83,    0,  8,  0,  0 }, {     12,   84,    0,  8,  0,  0 },
    {     13,   85,    0,  8,  0,  0 }, {     13,   86,    0,  8,  0,  0 }, {     14,   87,    0,  8,  0,  0 }, {     14,   88,    0,  8,  0,  0 }, {     15,   89,    0,  8,  0,  0 },
    {     15,   90,    0,  8,  0,  0 }, {     16,   91,    0,  8,  0,  0 }, {     16,   92,    0,  8,  0,  0 }, {     16,   93,    0,  8,  0,  0 }, {     16,   94,    0,  8,  0,  0 },
    {     16,   95,    0,  8,  0,  0 }, {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 },
    {     16,    4,    0,  8,  0,  0 }, {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 },
    {     16,    9,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 },
    {     16,   14,    0,  8,  0,  0 }, {     16,   15,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   17,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 },
    {     16,   19,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   21,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 },
    {     16,   24,    0,  8,  0,  0 }, {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 },
    {     16,   29,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     16,   33,    0,  8,  0,  0 },
    {     16,   34,    0,  8,  0,  0 }, {     16,   35,    0,  8,  0,  0 }, {     16,   36,    0,  8,  0,  0 }, {     16,   37,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 },
    {     16,   39,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, {     16,   41,    0,  8,  0,  0 }, {     16,   42,    0,  8,  0,  0 }, {     16,   43,    0,  8,  0,  0 },
    {     16,   44,    0,  8,  0,  0 }, {     16,   45,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, {     16,   47,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 },
    {     16,   49,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 }, {     16,   51,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   53,    0,  8,  0,  0 },
    {     16,   54,    0,  8,  0,  0 }, {     16,   55,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 }, {     16,   57,    0,  8,  0,  0 }, {     16,   58,    0,  8,  0,  0 },
    {     16,   59,    0,  8,  0,  0 }, {     16,   60,    0,  8,  0,  0 }, {     16,   61,    0,  8,  0,  0 }, {     16,   62,    0,  8,  0,  0 }, {     16,   63,    0,  8,  0,  0 },
    {     16,   64,    0,  8,  0,  0 }, {     16,   65,    0,  8,  0,  0 }, {     16,   66,    0,  8,  0,  0 }, {     16,   67,    0,  8,  0,  0 }, {     16,   68,    0,  8,  0,  0 },
    {     16,   69,    0,  8,  0,  0 }, {     16,   70,    0,  8,  0,  0 }, {     16,   71,    0,  8,  0,  0 }, {     16,   72,    0,  8,  0,  0 }, {     16,   73,    0,  8,  0,  0 },
    {     16,   74,    0,  8,  0,  0 }, {     16,   75,    0,  8,  0,  0 }, {     16,   76,    0,  8,  0,  0 }, {     16,   77,    0,  8,  0,  0 }, {     16,   78,    0,  8,  0,  0 },
    {     16,   79,    0,  8,  0,  0 }, {     16,   80,    0,  8,  0,  0 }, {     16,   81,    0,  8,  0,  0 }, {     16,   82,    0,  8,  0,  0 }, {     16,   83,    0,  8,  0,  0 },
    {     16,   84,    0,  8,  0,  0 }, {     16,   85,    0,  8,  0,  0 }, {     16,   86,    0,  8,  0,  0 }, {     16,   87,    0,  8,  0,  0 }, {     16,   88,    0,  8,  0,  0 },
    {     16,   89,    0,  8,  0,  0 }, {     16,   90,    0,  8,  0,  0 }, {     16,   91,    0,  8,  0,  0 }, {     16,   92,    0,  8,  0,  0 }, {     16,   93,    0,  8,  0,  0 },
    {     16,   94,    0,  8,  0,  0 }, {     16,   95,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94FED2, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   17,    0, 16,  0,  0 }, {      6,   17,    0, 16,  0,  0 }, {      7,   18,    0, 16,  0,  0 }, {      8,   18,    0, 16,  0,  0 }, {      9,   19,    0, 16,  0,  0 },
    {     10,   19,    0, 16,  0,  0 }, {     11,   20,    0, 16,  0,  0 }, {     12,   21,    0, 16,  0,  0 }, {     13,   21,    0, 16,  0,  0 }, {     14,   22,    0, 16,  0,  0 },
    {     15,   23,    0, 16,  0,  0 }, {     16,   23,    0, 16,  0,  0 }, {     17,   24,    0, 16,  0,  0 }, {     18,   24,    0, 16,  0,  0 }, {     19,   25,    0, 16,  0,  0 },
    {     20,   25,    0, 16,  0,  0 }, {     21,   26,    0, 16,  0,  0 }, {     22,   26,    0, 16,  0,  0 }, {     23,   26,    0, 16,  0,  0 }, {     24,   27,    0, 16,  0,  0 },
    {     25,   27,    0, 16,  0,  0 }, {     26,   28,    0, 16,  0,  0 }, {     27,   28,    0, 16,  0,  0 }, {     28,   28,    0, 16,  0,  0 }, {     29,   29,    0, 16,  0,  0 },
    {     30,   29,    0, 16,  0,  0 }, {     31,   29,    0, 16,  0,  0 }, {     32,   30,    0, 16,  0,  0 }, {     33,   30,    0, 16,  0,  0 }, {     34,   30,    0, 16,  0,  0 },
    {     35,   30,    0, 16,  0,  0 }, {     36,   30,    0, 16,  0,  0 }, {     37,   31,    0, 16,  0,  0 }, {     38,   31,    0, 16,  0,  0 }, {     39,   31,    0, 16,  0,  0 },
    {     40,   31,    0, 16,  0,  0 }, {     41,   31,    0, 16,  0,  0 }, {     42,   32,    0, 16,  0,  0 }, {     43,   32,    0, 16,  0,  0 }, {     44,   32,    0, 16,  0,  0 },
    {     45,   32,    0, 16,  0,  0 }, {     46,   32,    0, 16,  0,  0 }, {     47,   32,    0, 16,  0,  0 }, {     48,   32,    0, 16,  0,  0 }, {     49,   32,    0, 16,  0,  0 },
    {     50,   32,    0, 16,  0,  0 }, {     51,   32,    0, 16,  0,  0 }, {     52,   32,    0, 16,  0,  0 }, {     53,   32,    0, 16,  0,  0 }, {     54,   31,    0, 16,  0,  0 },
    {     55,   31,    0, 16,  0,  0 }, {     56,   31,    0, 16,  0,  0 }, {     57,   31,    0, 16,  0,  0 }, {     58,   31,    0, 16,  0,  0 }, {     59,   30,    0, 16,  0,  0 },
    {     60,   30,    0, 16,  0,  0 }, {     61,   30,    0, 16,  0,  0 }, {     62,   30,    0, 16,  0,  0 }, {     63,   30,    0, 16,  0,  0 }, {     64,   29,    0, 16,  0,  0 },
    {     65,   29,    0, 16,  0,  0 }, {     66,   29,    0, 16,  0,  0 }, {     67,   28,    0, 16,  0,  0 }, {     68,   28,    0, 16,  0,  0 }, {     69,   28,    0, 16,  0,  0 },
    {     70,   27,    0, 16,  0,  0 }, {     71,   27,    0, 16,  0,  0 }, {     72,   26,    0, 16,  0,  0 }, {     73,   26,    0, 16,  0,  0 }, {     74,   26,    0, 16,  0,  0 },
    {     75,   25,    0, 16,  0,  0 }, {     76,   25,    0, 16,  0,  0 }, {     77,   24,    0, 16,  0,  0 }, {     78,   24,    0, 16,  0,  0 }, {     79,   23,    0, 16,  0,  0 },
    {     80,   23,    0, 16,  0,  0 }, {     81,   22,    0, 16,  0,  0 }, {     82,   21,    0, 16,  0,  0 }, {     83,   21,    0, 16,  0,  0 }, {     84,   20,    0, 16,  0,  0 },
    {     85,   19,    0, 16,  0,  0 }, {     86,   19,    0, 16,  0,  0 }, {     87,   18,    0, 16,  0,  0 }, {     88,   18,    0, 16,  0,  0 }, {     89,   17,    0, 16,  0,  0 },
    {     90,   17,    0, 16,  0,  0 }, {     91,   16,    0, 16,  0,  0 }, {     92,   16,    0, 16,  0,  0 }, {     93,   16,    0, 16,  0,  0 }, {     94,   16,    0, 16,  0,  0 },
    {     95,   16,    0, 16,  0,  0 }, {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 },
    {      4,   16,    0, 16,  0,  0 }, {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 },
    {      9,   16,    0, 16,  0,  0 }, {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     13,   16,    0, 16,  0,  0 },
    {     14,   16,    0, 16,  0,  0 }, {     15,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     17,   16,    0, 16,  0,  0 }, {     18,   16,    0, 16,  0,  0 },
    {     19,   16,    0, 16,  0,  0 }, {     20,   16,    0, 16,  0,  0 }, {     21,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 },
    {     24,   16,    0, 16,  0,  0 }, {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 },
    {     29,   16,    0, 16,  0,  0 }, {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 }, {     32,   16,    0, 16,  0,  0 }, {     33,   16,    0, 16,  0,  0 },
    {     34,   16,    0, 16,  0,  0 }, {     35,   16,    0, 16,  0,  0 }, {     36,   16,    0, 16,  0,  0 }, {     37,   16,    0, 16,  0,  0 }, {     38,   16,    0, 16,  0,  0 },
    {     39,   16,    0, 16,  0,  0 }, {     40,   16,    0, 16,  0,  0 }, {     41,   16,    0, 16,  0,  0 }, {     42,   16,    0, 16,  0,  0 }, {     43,   16,    0, 16,  0,  0 },
    {     44,   16,    0, 16,  0,  0 }, {     45,   16,    0, 16,  0,  0 }, {     46,   16,    0, 16,  0,  0 }, {     47,   16,    0, 16,  0,  0 }, {     48,   16,    0, 16,  0,  0 },
    {     49,   16,    0, 16,  0,  0 }, {     50,   16,    0, 16,  0,  0 }, {     51,   16,    0, 16,  0,  0 }, {     52,   16,    0, 16,  0,  0 }, {     53,   16,    0, 16,  0,  0 },
    {     54,   16,    0, 16,  0,  0 }, {     55,   16,    0, 16,  0,  0 }, {     56,   16,    0, 16,  0,  0 }, {     57,   16,    0, 16,  0,  0 }, {     58,   16,    0, 16,  0,  0 },
    {     59,   16,    0, 16,  0,  0 }, {     60,   16,    0, 16,  0,  0 }, {     61,   16,    0, 16,  0,  0 }, {     62,   16,    0, 16,  0,  0 }, {     63,   16,    0, 16,  0,  0 },
    {     64,   16,    0, 16,  0,  0 }, {     65,   16,    0, 16,  0,  0 }, {     66,   16,    0, 16,  0,  0 }, {     67,   16,    0, 16,  0,  0 }, {     68,   16,    0, 16,  0,  0 },
    {     69,   16,    0, 16,  0,  0 }, {     70,   16,    0, 16,  0,  0 }, {     71,   16,    0, 16,  0,  0 }, {     72,   16,    0, 16,  0,  0 }, {     73,   16,    0, 16,  0,  0 },
    {     74,   16,    0, 16,  0,  0 }, {     75,   16,    0, 16,  0,  0 }, {     76,   16,    0, 16,  0,  0 }, {     77,   16,    0, 16,  0,  0 }, {     78,   16,    0, 16,  0,  0 },
    {     79,   16,    0, 16,  0,  0 }, {     80,   16,    0, 16,  0,  0 }, {     81,   16,    0, 16,  0,  0 }, {     82,   16,    0, 16,  0,  0 }, {     83,   16,    0, 16,  0,  0 },
    {     84,   16,    0, 16,  0,  0 }, {     85,   16,    0, 16,  0,  0 }, {     86,   16,    0, 16,  0,  0 }, {     87,   16,    0, 16,  0,  0 }, {     88,   16,    0, 16,  0,  0 },
    {     89,   16,    0, 16,  0,  0 }, {     90,   16,    0, 16,  0,  0 }, {     91,   16,    0, 16,  0,  0 }, {     92,   16,    0, 16,  0,  0 }, {     93,   16,    0, 16,  0,  0 },
    {     94,   16,    0, 16,  0,  0 }, {     95,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_950594, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     17,   26,    0, 24,  0,  0 }, {     17,   25,    0, 24,  0,  0 }, {     18,   24,    0, 24,  0,  0 }, {     18,   23,    0, 24,  0,  0 }, {     19,   22,    0, 24,  0,  0 },
    {     19,   21,    0, 24,  0,  0 }, {     20,   20,    0, 24,  0,  0 }, {     21,   19,    0, 24,  0,  0 }, {     21,   18,    0, 24,  0,  0 }, {     22,   17,    0, 24,  0,  0 },
    {     23,   16,    0, 24,  0,  0 }, {     23,   15,    0, 24,  0,  0 }, {     24,   14,    0, 24,  0,  0 }, {     24,   13,    0, 24,  0,  0 }, {     25,   12,    0, 24,  0,  0 },
    {     25,   11,    0, 24,  0,  0 }, {     26,   10,    0, 24,  0,  0 }, {     26,    9,    0, 24,  0,  0 }, {     26,    8,    0, 24,  0,  0 }, {     27,    7,    0, 24,  0,  0 },
    {     27,    6,    0, 24,  0,  0 }, {     28,    5,    0, 24,  0,  0 }, {     28,    4,    0, 24,  0,  0 }, {     28,    3,    0, 24,  0,  0 }, {     29,    2,    0, 24,  0,  0 },
    {     29,    1,    0, 24,  0,  0 }, {     29,    0,    0, 24,  0,  0 }, {     30,   -1,    0, 24,  0,  0 }, {     30,   -2,    0, 24,  0,  0 }, {     30,   -3,    0, 24,  0,  0 },
    {     30,   -4,    0, 24,  0,  0 }, {     30,   -5,    0, 24,  0,  0 }, {     31,   -6,    0, 24,  0,  0 }, {     31,   -7,    0, 24,  0,  0 }, {     31,   -8,    0, 24,  0,  0 },
    {     31,   -9,    0, 24,  0,  0 }, {     31,  -10,    0, 24,  0,  0 }, {     32,  -11,    0, 24,  0,  0 }, {     32,  -12,    0, 24,  0,  0 }, {     32,  -13,    0, 24,  0,  0 },
    {     32,  -14,    0, 24,  0,  0 }, {     32,  -15,    0, 24,  0,  0 }, {     32,  -16,    0, 24,  0,  0 }, {     32,  -17,    0, 24,  0,  0 }, {     32,  -18,    0, 24,  0,  0 },
    {     32,  -19,    0, 24,  0,  0 }, {     32,  -20,    0, 24,  0,  0 }, {     32,  -21,    0, 24,  0,  0 }, {     32,  -22,    0, 24,  0,  0 }, {     31,  -23,    0, 24,  0,  0 },
    {     31,  -24,    0, 24,  0,  0 }, {     31,  -25,    0, 24,  0,  0 }, {     31,  -26,    0, 24,  0,  0 }, {     31,  -27,    0, 24,  0,  0 }, {     30,  -28,    0, 24,  0,  0 },
    {     30,  -29,    0, 24,  0,  0 }, {     30,  -30,    0, 24,  0,  0 }, {     30,  -31,    0, 24,  0,  0 }, {     30,  -32,    0, 24,  0,  0 }, {     29,  -33,    0, 24,  0,  0 },
    {     29,  -34,    0, 24,  0,  0 }, {     29,  -35,    0, 24,  0,  0 }, {     28,  -36,    0, 24,  0,  0 }, {     28,  -37,    0, 24,  0,  0 }, {     28,  -38,    0, 24,  0,  0 },
    {     27,  -39,    0, 24,  0,  0 }, {     27,  -40,    0, 24,  0,  0 }, {     26,  -41,    0, 24,  0,  0 }, {     26,  -42,    0, 24,  0,  0 }, {     26,  -43,    0, 24,  0,  0 },
    {     25,  -44,    0, 24,  0,  0 }, {     25,  -45,    0, 24,  0,  0 }, {     24,  -46,    0, 24,  0,  0 }, {     24,  -47,    0, 24,  0,  0 }, {     23,  -48,    0, 24,  0,  0 },
    {     23,  -49,    0, 24,  0,  0 }, {     22,  -50,    0, 24,  0,  0 }, {     21,  -51,    0, 24,  0,  0 }, {     21,  -52,    0, 24,  0,  0 }, {     20,  -53,    0, 24,  0,  0 },
    {     19,  -54,    0, 24,  0,  0 }, {     19,  -55,    0, 24,  0,  0 }, {     18,  -56,    0, 24,  0,  0 }, {     18,  -57,    0, 24,  0,  0 }, {     17,  -58,    0, 24,  0,  0 },
    {     17,  -59,    0, 24,  0,  0 }, {     16,  -60,    0, 24,  0,  0 }, {     16,  -61,    0, 24,  0,  0 }, {     16,  -62,    0, 24,  0,  0 }, {     16,  -63,    0, 24,  0,  0 },
    {     16,  -64,    0, 24,  0,  0 }, {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 },
    {     16,   27,    0, 24,  0,  0 }, {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 },
    {     16,   22,    0, 24,  0,  0 }, {     16,   21,    0, 24,  0,  0 }, {     16,   20,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 },
    {     16,   17,    0, 24,  0,  0 }, {     16,   16,    0, 24,  0,  0 }, {     16,   15,    0, 24,  0,  0 }, {     16,   14,    0, 24,  0,  0 }, {     16,   13,    0, 24,  0,  0 },
    {     16,   12,    0, 24,  0,  0 }, {     16,   11,    0, 24,  0,  0 }, {     16,   10,    0, 24,  0,  0 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 },
    {     16,    7,    0, 24,  0,  0 }, {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 },
    {     16,    2,    0, 24,  0,  0 }, {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 }, {     16,   -1,    0, 24,  0,  0 }, {     16,   -2,    0, 24,  0,  0 },
    {     16,   -3,    0, 24,  0,  0 }, {     16,   -4,    0, 24,  0,  0 }, {     16,   -5,    0, 24,  0,  0 }, {     16,   -6,    0, 24,  0,  0 }, {     16,   -7,    0, 24,  0,  0 },
    {     16,   -8,    0, 24,  0,  0 }, {     16,   -9,    0, 24,  0,  0 }, {     16,  -10,    0, 24,  0,  0 }, {     16,  -11,    0, 24,  0,  0 }, {     16,  -12,    0, 24,  0,  0 },
    {     16,  -13,    0, 24,  0,  0 }, {     16,  -14,    0, 24,  0,  0 }, {     16,  -15,    0, 24,  0,  0 }, {     16,  -16,    0, 24,  0,  0 }, {     16,  -17,    0, 24,  0,  0 },
    {     16,  -18,    0, 24,  0,  0 }, {     16,  -19,    0, 24,  0,  0 }, {     16,  -20,    0, 24,  0,  0 }, {     16,  -21,    0, 24,  0,  0 }, {     16,  -22,    0, 24,  0,  0 },
    {     16,  -23,    0, 24,  0,  0 }, {     16,  -24,    0, 24,  0,  0 }, {     16,  -25,    0, 24,  0,  0 }, {     16,  -26,    0, 24,  0,  0 }, {     16,  -27,    0, 24,  0,  0 },
    {     16,  -28,    0, 24,  0,  0 }, {     16,  -29,    0, 24,  0,  0 }, {     16,  -30,    0, 24,  0,  0 }, {     16,  -31,    0, 24,  0,  0 }, {     16,  -32,    0, 24,  0,  0 },
    {     16,  -33,    0, 24,  0,  0 }, {     16,  -34,    0, 24,  0,  0 }, {     16,  -35,    0, 24,  0,  0 }, {     16,  -36,    0, 24,  0,  0 }, {     16,  -37,    0, 24,  0,  0 },
    {     16,  -38,    0, 24,  0,  0 }, {     16,  -39,    0, 24,  0,  0 }, {     16,  -40,    0, 24,  0,  0 }, {     16,  -41,    0, 24,  0,  0 }, {     16,  -42,    0, 24,  0,  0 },
    {     16,  -43,    0, 24,  0,  0 }, {     16,  -44,    0, 24,  0,  0 }, {     16,  -45,    0, 24,  0,  0 }, {     16,  -46,    0, 24,  0,  0 }, {     16,  -47,    0, 24,  0,  0 },
    {     16,  -48,    0, 24,  0,  0 }, {     16,  -49,    0, 24,  0,  0 }, {     16,  -50,    0, 24,  0,  0 }, {     16,  -51,    0, 24,  0,  0 }, {     16,  -52,    0, 24,  0,  0 },
    {     16,  -53,    0, 24,  0,  0 }, {     16,  -54,    0, 24,  0,  0 }, {     16,  -55,    0, 24,  0,  0 }, {     16,  -56,    0, 24,  0,  0 }, {     16,  -57,    0, 24,  0,  0 },
    {     16,  -58,    0, 24,  0,  0 }, {     16,  -59,    0, 24,  0,  0 }, {     16,  -60,    0, 24,  0,  0 }, {     16,  -61,    0, 24,  0,  0 }, {     16,  -62,    0, 24,  0,  0 },
    {     16,  -63,    0, 24,  0,  0 }, {     16,  -64,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_950C56, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   17,    0,  0,  0,  0 }, {     25,   17,    0,  0,  0,  0 }, {     24,   18,    0,  0,  0,  0 }, {     23,   18,    0,  0,  0,  0 }, {     22,   19,    0,  0,  0,  0 },
    {     21,   19,    0,  0,  0,  0 }, {     20,   20,    0,  0,  0,  0 }, {     19,   21,    0,  0,  0,  0 }, {     18,   21,    0,  0,  0,  0 }, {     17,   22,    0,  0,  0,  0 },
    {     16,   23,    0,  0,  0,  0 }, {     15,   23,    0,  0,  0,  0 }, {     14,   24,    0,  0,  0,  0 }, {     13,   24,    0,  0,  0,  0 }, {     12,   25,    0,  0,  0,  0 },
    {     11,   25,    0,  0,  0,  0 }, {     10,   26,    0,  0,  0,  0 }, {      9,   26,    0,  0,  0,  0 }, {      8,   26,    0,  0,  0,  0 }, {      7,   27,    0,  0,  0,  0 },
    {      6,   27,    0,  0,  0,  0 }, {      5,   28,    0,  0,  0,  0 }, {      4,   28,    0,  0,  0,  0 }, {      3,   28,    0,  0,  0,  0 }, {      2,   29,    0,  0,  0,  0 },
    {      1,   29,    0,  0,  0,  0 }, {      0,   29,    0,  0,  0,  0 }, {     -1,   30,    0,  0,  0,  0 }, {     -2,   30,    0,  0,  0,  0 }, {     -3,   30,    0,  0,  0,  0 },
    {     -4,   30,    0,  0,  0,  0 }, {     -5,   30,    0,  0,  0,  0 }, {     -6,   31,    0,  0,  0,  0 }, {     -7,   31,    0,  0,  0,  0 }, {     -8,   31,    0,  0,  0,  0 },
    {     -9,   31,    0,  0,  0,  0 }, {    -10,   31,    0,  0,  0,  0 }, {    -11,   32,    0,  0,  0,  0 }, {    -12,   32,    0,  0,  0,  0 }, {    -13,   32,    0,  0,  0,  0 },
    {    -14,   32,    0,  0,  0,  0 }, {    -15,   32,    0,  0,  0,  0 }, {    -16,   32,    0,  0,  0,  0 }, {    -17,   32,    0,  0,  0,  0 }, {    -18,   32,    0,  0,  0,  0 },
    {    -19,   32,    0,  0,  0,  0 }, {    -20,   32,    0,  0,  0,  0 }, {    -21,   32,    0,  0,  0,  0 }, {    -22,   32,    0,  0,  0,  0 }, {    -23,   31,    0,  0,  0,  0 },
    {    -24,   31,    0,  0,  0,  0 }, {    -25,   31,    0,  0,  0,  0 }, {    -26,   31,    0,  0,  0,  0 }, {    -27,   31,    0,  0,  0,  0 }, {    -28,   30,    0,  0,  0,  0 },
    {    -29,   30,    0,  0,  0,  0 }, {    -30,   30,    0,  0,  0,  0 }, {    -31,   30,    0,  0,  0,  0 }, {    -32,   30,    0,  0,  0,  0 }, {    -33,   29,    0,  0,  0,  0 },
    {    -34,   29,    0,  0,  0,  0 }, {    -35,   29,    0,  0,  0,  0 }, {    -36,   28,    0,  0,  0,  0 }, {    -37,   28,    0,  0,  0,  0 }, {    -38,   28,    0,  0,  0,  0 },
    {    -39,   27,    0,  0,  0,  0 }, {    -40,   27,    0,  0,  0,  0 }, {    -41,   26,    0,  0,  0,  0 }, {    -42,   26,    0,  0,  0,  0 }, {    -43,   26,    0,  0,  0,  0 },
    {    -44,   25,    0,  0,  0,  0 }, {    -45,   25,    0,  0,  0,  0 }, {    -46,   24,    0,  0,  0,  0 }, {    -47,   24,    0,  0,  0,  0 }, {    -48,   23,    0,  0,  0,  0 },
    {    -49,   23,    0,  0,  0,  0 }, {    -50,   22,    0,  0,  0,  0 }, {    -51,   21,    0,  0,  0,  0 }, {    -52,   21,    0,  0,  0,  0 }, {    -53,   20,    0,  0,  0,  0 },
    {    -54,   19,    0,  0,  0,  0 }, {    -55,   19,    0,  0,  0,  0 }, {    -56,   18,    0,  0,  0,  0 }, {    -57,   18,    0,  0,  0,  0 }, {    -58,   17,    0,  0,  0,  0 },
    {    -59,   17,    0,  0,  0,  0 }, {    -60,   16,    0,  0,  0,  0 }, {    -61,   16,    0,  0,  0,  0 }, {    -62,   16,    0,  0,  0,  0 }, {    -63,   16,    0,  0,  0,  0 },
    {    -64,   16,    0,  0,  0,  0 }, {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 },
    {     27,   16,    0,  0,  0,  0 }, {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 },
    {     22,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 },
    {     17,   16,    0,  0,  0,  0 }, {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 },
    {     12,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {     10,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 },
    {      7,   16,    0,  0,  0,  0 }, {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 },
    {      2,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -2,   16,    0,  0,  0,  0 },
    {     -3,   16,    0,  0,  0,  0 }, {     -4,   16,    0,  0,  0,  0 }, {     -5,   16,    0,  0,  0,  0 }, {     -6,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 },
    {     -8,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, {    -10,   16,    0,  0,  0,  0 }, {    -11,   16,    0,  0,  0,  0 }, {    -12,   16,    0,  0,  0,  0 },
    {    -13,   16,    0,  0,  0,  0 }, {    -14,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, {    -16,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 },
    {    -18,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 }, {    -20,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -22,   16,    0,  0,  0,  0 },
    {    -23,   16,    0,  0,  0,  0 }, {    -24,   16,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 }, {    -26,   16,    0,  0,  0,  0 }, {    -27,   16,    0,  0,  0,  0 },
    {    -28,   16,    0,  0,  0,  0 }, {    -29,   16,    0,  0,  0,  0 }, {    -30,   16,    0,  0,  0,  0 }, {    -31,   16,    0,  0,  0,  0 }, {    -32,   16,    0,  0,  0,  0 },
    {    -33,   16,    0,  0,  0,  0 }, {    -34,   16,    0,  0,  0,  0 }, {    -35,   16,    0,  0,  0,  0 }, {    -36,   16,    0,  0,  0,  0 }, {    -37,   16,    0,  0,  0,  0 },
    {    -38,   16,    0,  0,  0,  0 }, {    -39,   16,    0,  0,  0,  0 }, {    -40,   16,    0,  0,  0,  0 }, {    -41,   16,    0,  0,  0,  0 }, {    -42,   16,    0,  0,  0,  0 },
    {    -43,   16,    0,  0,  0,  0 }, {    -44,   16,    0,  0,  0,  0 }, {    -45,   16,    0,  0,  0,  0 }, {    -46,   16,    0,  0,  0,  0 }, {    -47,   16,    0,  0,  0,  0 },
    {    -48,   16,    0,  0,  0,  0 }, {    -49,   16,    0,  0,  0,  0 }, {    -50,   16,    0,  0,  0,  0 }, {    -51,   16,    0,  0,  0,  0 }, {    -52,   16,    0,  0,  0,  0 },
    {    -53,   16,    0,  0,  0,  0 }, {    -54,   16,    0,  0,  0,  0 }, {    -55,   16,    0,  0,  0,  0 }, {    -56,   16,    0,  0,  0,  0 }, {    -57,   16,    0,  0,  0,  0 },
    {    -58,   16,    0,  0,  0,  0 }, {    -59,   16,    0,  0,  0,  0 }, {    -60,   16,    0,  0,  0,  0 }, {    -61,   16,    0,  0,  0,  0 }, {    -62,   16,    0,  0,  0,  0 },
    {    -63,   16,    0,  0,  0,  0 }, {    -64,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_951318, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     17,    5,    0,  8,  0,  0 }, {     17,    6,    0,  8,  0,  0 }, {     18,    7,    0,  8,  0,  0 }, {     18,    8,    0,  8,  0,  0 }, {     19,    9,    0,  8,  0,  0 },
    {     19,   10,    0,  8,  0,  0 }, {     20,   11,    0,  8,  0,  0 }, {     21,   12,    0,  8,  0,  0 }, {     21,   13,    0,  8,  0,  0 }, {     22,   14,    0,  8,  0,  0 },
    {     23,   15,    0,  8,  0,  0 }, {     23,   16,    0,  8,  0,  0 }, {     24,   17,    0,  8,  0,  0 }, {     24,   18,    0,  8,  0,  0 }, {     25,   19,    0,  8,  0,  0 },
    {     25,   20,    0,  8,  0,  0 }, {     26,   21,    0,  8,  0,  0 }, {     26,   22,    0,  8,  0,  0 }, {     26,   23,    0,  8,  0,  0 }, {     27,   24,    0,  8,  0,  0 },
    {     27,   25,    0,  8,  0,  0 }, {     28,   26,    0,  8,  0,  0 }, {     28,   27,    0,  8,  0,  0 }, {     28,   28,    0,  8,  0,  0 }, {     29,   29,    0,  8,  0,  0 },
    {     29,   30,    0,  8,  0,  0 }, {     29,   31,    0,  8,  0,  0 }, {     30,   32,    0,  8,  0,  0 }, {     30,   33,    0,  8,  0,  0 }, {     30,   34,    0,  8,  0,  0 },
    {     30,   35,    0,  8,  0,  0 }, {     30,   36,    0,  8,  0,  0 }, {     31,   37,    0,  8,  0,  0 }, {     31,   38,    0,  8,  0,  0 }, {     31,   39,    0,  8,  0,  0 },
    {     31,   40,    0,  8,  0,  0 }, {     31,   41,    0,  8,  0,  0 }, {     32,   42,    0,  8,  0,  0 }, {     32,   43,    0,  8,  0,  0 }, {     32,   44,    0,  8,  0,  0 },
    {     32,   45,    0,  8,  0,  0 }, {     32,   46,    0,  8,  0,  0 }, {     32,   47,    0,  8,  0,  0 }, {     32,   48,    0,  8,  0,  0 }, {     32,   49,    0,  8,  0,  0 },
    {     32,   50,    0,  8,  0,  0 }, {     32,   51,    0,  8,  0,  0 }, {     32,   52,    0,  8,  0,  0 }, {     32,   53,    0,  8,  0,  0 }, {     31,   54,    0,  8,  0,  0 },
    {     31,   55,    0,  8,  0,  0 }, {     31,   56,    0,  8,  0,  0 }, {     31,   57,    0,  8,  0,  0 }, {     31,   58,    0,  8,  0,  0 }, {     30,   59,    0,  8,  0,  0 },
    {     30,   60,    0,  8,  0,  0 }, {     30,   61,    0,  8,  0,  0 }, {     30,   62,    0,  8,  0,  0 }, {     30,   63,    0,  8,  0,  0 }, {     29,   64,    0,  8,  0,  0 },
    {     29,   65,    0,  8,  0,  0 }, {     29,   66,    0,  8,  0,  0 }, {     28,   67,    0,  8,  0,  0 }, {     28,   68,    0,  8,  0,  0 }, {     28,   69,    0,  8,  0,  0 },
    {     27,   70,    0,  8,  0,  0 }, {     27,   71,    0,  8,  0,  0 }, {     26,   72,    0,  8,  0,  0 }, {     26,   73,    0,  8,  0,  0 }, {     26,   74,    0,  8,  0,  0 },
    {     25,   75,    0,  8,  0,  0 }, {     25,   76,    0,  8,  0,  0 }, {     24,   77,    0,  8,  0,  0 }, {     24,   78,    0,  8,  0,  0 }, {     23,   79,    0,  8,  0,  0 },
    {     23,   80,    0,  8,  0,  0 }, {     22,   81,    0,  8,  0,  0 }, {     21,   82,    0,  8,  0,  0 }, {     21,   83,    0,  8,  0,  0 }, {     20,   84,    0,  8,  0,  0 },
    {     19,   85,    0,  8,  0,  0 }, {     19,   86,    0,  8,  0,  0 }, {     18,   87,    0,  8,  0,  0 }, {     18,   88,    0,  8,  0,  0 }, {     17,   89,    0,  8,  0,  0 },
    {     17,   90,    0,  8,  0,  0 }, {     16,   91,    0,  8,  0,  0 }, {     16,   92,    0,  8,  0,  0 }, {     16,   93,    0,  8,  0,  0 }, {     16,   94,    0,  8,  0,  0 },
    {     16,   95,    0,  8,  0,  0 }, {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 },
    {     16,    4,    0,  8,  0,  0 }, {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 },
    {     16,    9,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 },
    {     16,   14,    0,  8,  0,  0 }, {     16,   15,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   17,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 },
    {     16,   19,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   21,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 },
    {     16,   24,    0,  8,  0,  0 }, {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 },
    {     16,   29,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     16,   33,    0,  8,  0,  0 },
    {     16,   34,    0,  8,  0,  0 }, {     16,   35,    0,  8,  0,  0 }, {     16,   36,    0,  8,  0,  0 }, {     16,   37,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 },
    {     16,   39,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, {     16,   41,    0,  8,  0,  0 }, {     16,   42,    0,  8,  0,  0 }, {     16,   43,    0,  8,  0,  0 },
    {     16,   44,    0,  8,  0,  0 }, {     16,   45,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, {     16,   47,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 },
    {     16,   49,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 }, {     16,   51,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   53,    0,  8,  0,  0 },
    {     16,   54,    0,  8,  0,  0 }, {     16,   55,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 }, {     16,   57,    0,  8,  0,  0 }, {     16,   58,    0,  8,  0,  0 },
    {     16,   59,    0,  8,  0,  0 }, {     16,   60,    0,  8,  0,  0 }, {     16,   61,    0,  8,  0,  0 }, {     16,   62,    0,  8,  0,  0 }, {     16,   63,    0,  8,  0,  0 },
    {     16,   64,    0,  8,  0,  0 }, {     16,   65,    0,  8,  0,  0 }, {     16,   66,    0,  8,  0,  0 }, {     16,   67,    0,  8,  0,  0 }, {     16,   68,    0,  8,  0,  0 },
    {     16,   69,    0,  8,  0,  0 }, {     16,   70,    0,  8,  0,  0 }, {     16,   71,    0,  8,  0,  0 }, {     16,   72,    0,  8,  0,  0 }, {     16,   73,    0,  8,  0,  0 },
    {     16,   74,    0,  8,  0,  0 }, {     16,   75,    0,  8,  0,  0 }, {     16,   76,    0,  8,  0,  0 }, {     16,   77,    0,  8,  0,  0 }, {     16,   78,    0,  8,  0,  0 },
    {     16,   79,    0,  8,  0,  0 }, {     16,   80,    0,  8,  0,  0 }, {     16,   81,    0,  8,  0,  0 }, {     16,   82,    0,  8,  0,  0 }, {     16,   83,    0,  8,  0,  0 },
    {     16,   84,    0,  8,  0,  0 }, {     16,   85,    0,  8,  0,  0 }, {     16,   86,    0,  8,  0,  0 }, {     16,   87,    0,  8,  0,  0 }, {     16,   88,    0,  8,  0,  0 },
    {     16,   89,    0,  8,  0,  0 }, {     16,   90,    0,  8,  0,  0 }, {     16,   91,    0,  8,  0,  0 }, {     16,   92,    0,  8,  0,  0 }, {     16,   93,    0,  8,  0,  0 },
    {     16,   94,    0,  8,  0,  0 }, {     16,   95,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9519DA, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   15,    0, 16,  0,  0 }, {      6,   15,    0, 16,  0,  0 }, {      7,   14,    0, 16,  0,  0 }, {      8,   14,    0, 16,  0,  0 }, {      9,   13,    0, 16,  0,  0 },
    {     10,   13,    0, 16,  0,  0 }, {     11,   12,    0, 16,  0,  0 }, {     12,   11,    0, 16,  0,  0 }, {     13,   11,    0, 16,  0,  0 }, {     14,   10,    0, 16,  0,  0 },
    {     15,    9,    0, 16,  0,  0 }, {     16,    9,    0, 16,  0,  0 }, {     17,    8,    0, 16,  0,  0 }, {     18,    8,    0, 16,  0,  0 }, {     19,    7,    0, 16,  0,  0 },
    {     20,    7,    0, 16,  0,  0 }, {     21,    6,    0, 16,  0,  0 }, {     22,    6,    0, 16,  0,  0 }, {     23,    6,    0, 16,  0,  0 }, {     24,    5,    0, 16,  0,  0 },
    {     25,    5,    0, 16,  0,  0 }, {     26,    4,    0, 16,  0,  0 }, {     27,    4,    0, 16,  0,  0 }, {     28,    4,    0, 16,  0,  0 }, {     29,    3,    0, 16,  0,  0 },
    {     30,    3,    0, 16,  0,  0 }, {     31,    3,    0, 16,  0,  0 }, {     32,    2,    0, 16,  0,  0 }, {     33,    2,    0, 16,  0,  0 }, {     34,    2,    0, 16,  0,  0 },
    {     35,    2,    0, 16,  0,  0 }, {     36,    2,    0, 16,  0,  0 }, {     37,    1,    0, 16,  0,  0 }, {     38,    1,    0, 16,  0,  0 }, {     39,    1,    0, 16,  0,  0 },
    {     40,    1,    0, 16,  0,  0 }, {     41,    1,    0, 16,  0,  0 }, {     42,    0,    0, 16,  0,  0 }, {     43,    0,    0, 16,  0,  0 }, {     44,    0,    0, 16,  0,  0 },
    {     45,    0,    0, 16,  0,  0 }, {     46,    0,    0, 16,  0,  0 }, {     47,    0,    0, 16,  0,  0 }, {     48,    0,    0, 16,  0,  0 }, {     49,    0,    0, 16,  0,  0 },
    {     50,    0,    0, 16,  0,  0 }, {     51,    0,    0, 16,  0,  0 }, {     52,    0,    0, 16,  0,  0 }, {     53,    0,    0, 16,  0,  0 }, {     54,    1,    0, 16,  0,  0 },
    {     55,    1,    0, 16,  0,  0 }, {     56,    1,    0, 16,  0,  0 }, {     57,    1,    0, 16,  0,  0 }, {     58,    1,    0, 16,  0,  0 }, {     59,    2,    0, 16,  0,  0 },
    {     60,    2,    0, 16,  0,  0 }, {     61,    2,    0, 16,  0,  0 }, {     62,    2,    0, 16,  0,  0 }, {     63,    2,    0, 16,  0,  0 }, {     64,    3,    0, 16,  0,  0 },
    {     65,    3,    0, 16,  0,  0 }, {     66,    3,    0, 16,  0,  0 }, {     67,    4,    0, 16,  0,  0 }, {     68,    4,    0, 16,  0,  0 }, {     69,    4,    0, 16,  0,  0 },
    {     70,    5,    0, 16,  0,  0 }, {     71,    5,    0, 16,  0,  0 }, {     72,    6,    0, 16,  0,  0 }, {     73,    6,    0, 16,  0,  0 }, {     74,    6,    0, 16,  0,  0 },
    {     75,    7,    0, 16,  0,  0 }, {     76,    7,    0, 16,  0,  0 }, {     77,    8,    0, 16,  0,  0 }, {     78,    8,    0, 16,  0,  0 }, {     79,    9,    0, 16,  0,  0 },
    {     80,    9,    0, 16,  0,  0 }, {     81,   10,    0, 16,  0,  0 }, {     82,   11,    0, 16,  0,  0 }, {     83,   11,    0, 16,  0,  0 }, {     84,   12,    0, 16,  0,  0 },
    {     85,   13,    0, 16,  0,  0 }, {     86,   13,    0, 16,  0,  0 }, {     87,   14,    0, 16,  0,  0 }, {     88,   14,    0, 16,  0,  0 }, {     89,   15,    0, 16,  0,  0 },
    {     90,   15,    0, 16,  0,  0 }, {     91,   16,    0, 16,  0,  0 }, {     92,   16,    0, 16,  0,  0 }, {     93,   16,    0, 16,  0,  0 }, {     94,   16,    0, 16,  0,  0 },
    {     95,   16,    0, 16,  0,  0 }, {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 },
    {      4,   16,    0, 16,  0,  0 }, {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 },
    {      9,   16,    0, 16,  0,  0 }, {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     13,   16,    0, 16,  0,  0 },
    {     14,   16,    0, 16,  0,  0 }, {     15,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     17,   16,    0, 16,  0,  0 }, {     18,   16,    0, 16,  0,  0 },
    {     19,   16,    0, 16,  0,  0 }, {     20,   16,    0, 16,  0,  0 }, {     21,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 },
    {     24,   16,    0, 16,  0,  0 }, {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 },
    {     29,   16,    0, 16,  0,  0 }, {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 }, {     32,   16,    0, 16,  0,  0 }, {     33,   16,    0, 16,  0,  0 },
    {     34,   16,    0, 16,  0,  0 }, {     35,   16,    0, 16,  0,  0 }, {     36,   16,    0, 16,  0,  0 }, {     37,   16,    0, 16,  0,  0 }, {     38,   16,    0, 16,  0,  0 },
    {     39,   16,    0, 16,  0,  0 }, {     40,   16,    0, 16,  0,  0 }, {     41,   16,    0, 16,  0,  0 }, {     42,   16,    0, 16,  0,  0 }, {     43,   16,    0, 16,  0,  0 },
    {     44,   16,    0, 16,  0,  0 }, {     45,   16,    0, 16,  0,  0 }, {     46,   16,    0, 16,  0,  0 }, {     47,   16,    0, 16,  0,  0 }, {     48,   16,    0, 16,  0,  0 },
    {     49,   16,    0, 16,  0,  0 }, {     50,   16,    0, 16,  0,  0 }, {     51,   16,    0, 16,  0,  0 }, {     52,   16,    0, 16,  0,  0 }, {     53,   16,    0, 16,  0,  0 },
    {     54,   16,    0, 16,  0,  0 }, {     55,   16,    0, 16,  0,  0 }, {     56,   16,    0, 16,  0,  0 }, {     57,   16,    0, 16,  0,  0 }, {     58,   16,    0, 16,  0,  0 },
    {     59,   16,    0, 16,  0,  0 }, {     60,   16,    0, 16,  0,  0 }, {     61,   16,    0, 16,  0,  0 }, {     62,   16,    0, 16,  0,  0 }, {     63,   16,    0, 16,  0,  0 },
    {     64,   16,    0, 16,  0,  0 }, {     65,   16,    0, 16,  0,  0 }, {     66,   16,    0, 16,  0,  0 }, {     67,   16,    0, 16,  0,  0 }, {     68,   16,    0, 16,  0,  0 },
    {     69,   16,    0, 16,  0,  0 }, {     70,   16,    0, 16,  0,  0 }, {     71,   16,    0, 16,  0,  0 }, {     72,   16,    0, 16,  0,  0 }, {     73,   16,    0, 16,  0,  0 },
    {     74,   16,    0, 16,  0,  0 }, {     75,   16,    0, 16,  0,  0 }, {     76,   16,    0, 16,  0,  0 }, {     77,   16,    0, 16,  0,  0 }, {     78,   16,    0, 16,  0,  0 },
    {     79,   16,    0, 16,  0,  0 }, {     80,   16,    0, 16,  0,  0 }, {     81,   16,    0, 16,  0,  0 }, {     82,   16,    0, 16,  0,  0 }, {     83,   16,    0, 16,  0,  0 },
    {     84,   16,    0, 16,  0,  0 }, {     85,   16,    0, 16,  0,  0 }, {     86,   16,    0, 16,  0,  0 }, {     87,   16,    0, 16,  0,  0 }, {     88,   16,    0, 16,  0,  0 },
    {     89,   16,    0, 16,  0,  0 }, {     90,   16,    0, 16,  0,  0 }, {     91,   16,    0, 16,  0,  0 }, {     92,   16,    0, 16,  0,  0 }, {     93,   16,    0, 16,  0,  0 },
    {     94,   16,    0, 16,  0,  0 }, {     95,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95209C, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     15,   26,    0, 24,  0,  0 }, {     15,   25,    0, 24,  0,  0 }, {     14,   24,    0, 24,  0,  0 }, {     14,   23,    0, 24,  0,  0 }, {     13,   22,    0, 24,  0,  0 },
    {     13,   21,    0, 24,  0,  0 }, {     12,   20,    0, 24,  0,  0 }, {     11,   19,    0, 24,  0,  0 }, {     11,   18,    0, 24,  0,  0 }, {     10,   17,    0, 24,  0,  0 },
    {      9,   16,    0, 24,  0,  0 }, {      9,   15,    0, 24,  0,  0 }, {      8,   14,    0, 24,  0,  0 }, {      8,   13,    0, 24,  0,  0 }, {      7,   12,    0, 24,  0,  0 },
    {      7,   11,    0, 24,  0,  0 }, {      6,   10,    0, 24,  0,  0 }, {      6,    9,    0, 24,  0,  0 }, {      6,    8,    0, 24,  0,  0 }, {      5,    7,    0, 24,  0,  0 },
    {      5,    6,    0, 24,  0,  0 }, {      4,    5,    0, 24,  0,  0 }, {      4,    4,    0, 24,  0,  0 }, {      4,    3,    0, 24,  0,  0 }, {      3,    2,    0, 24,  0,  0 },
    {      3,    1,    0, 24,  0,  0 }, {      3,    0,    0, 24,  0,  0 }, {      2,   -1,    0, 24,  0,  0 }, {      2,   -2,    0, 24,  0,  0 }, {      2,   -3,    0, 24,  0,  0 },
    {      2,   -4,    0, 24,  0,  0 }, {      2,   -5,    0, 24,  0,  0 }, {      1,   -6,    0, 24,  0,  0 }, {      1,   -7,    0, 24,  0,  0 }, {      1,   -8,    0, 24,  0,  0 },
    {      1,   -9,    0, 24,  0,  0 }, {      1,  -10,    0, 24,  0,  0 }, {      0,  -11,    0, 24,  0,  0 }, {      0,  -12,    0, 24,  0,  0 }, {      0,  -13,    0, 24,  0,  0 },
    {      0,  -14,    0, 24,  0,  0 }, {      0,  -15,    0, 24,  0,  0 }, {      0,  -16,    0, 24,  0,  0 }, {      0,  -17,    0, 24,  0,  0 }, {      0,  -18,    0, 24,  0,  0 },
    {      0,  -19,    0, 24,  0,  0 }, {      0,  -20,    0, 24,  0,  0 }, {      0,  -21,    0, 24,  0,  0 }, {      0,  -22,    0, 24,  0,  0 }, {      1,  -23,    0, 24,  0,  0 },
    {      1,  -24,    0, 24,  0,  0 }, {      1,  -25,    0, 24,  0,  0 }, {      1,  -26,    0, 24,  0,  0 }, {      1,  -27,    0, 24,  0,  0 }, {      2,  -28,    0, 24,  0,  0 },
    {      2,  -29,    0, 24,  0,  0 }, {      2,  -30,    0, 24,  0,  0 }, {      2,  -31,    0, 24,  0,  0 }, {      2,  -32,    0, 24,  0,  0 }, {      3,  -33,    0, 24,  0,  0 },
    {      3,  -34,    0, 24,  0,  0 }, {      3,  -35,    0, 24,  0,  0 }, {      4,  -36,    0, 24,  0,  0 }, {      4,  -37,    0, 24,  0,  0 }, {      4,  -38,    0, 24,  0,  0 },
    {      5,  -39,    0, 24,  0,  0 }, {      5,  -40,    0, 24,  0,  0 }, {      6,  -41,    0, 24,  0,  0 }, {      6,  -42,    0, 24,  0,  0 }, {      6,  -43,    0, 24,  0,  0 },
    {      7,  -44,    0, 24,  0,  0 }, {      7,  -45,    0, 24,  0,  0 }, {      8,  -46,    0, 24,  0,  0 }, {      8,  -47,    0, 24,  0,  0 }, {      9,  -48,    0, 24,  0,  0 },
    {      9,  -49,    0, 24,  0,  0 }, {     10,  -50,    0, 24,  0,  0 }, {     11,  -51,    0, 24,  0,  0 }, {     11,  -52,    0, 24,  0,  0 }, {     12,  -53,    0, 24,  0,  0 },
    {     13,  -54,    0, 24,  0,  0 }, {     13,  -55,    0, 24,  0,  0 }, {     14,  -56,    0, 24,  0,  0 }, {     14,  -57,    0, 24,  0,  0 }, {     15,  -58,    0, 24,  0,  0 },
    {     15,  -59,    0, 24,  0,  0 }, {     16,  -60,    0, 24,  0,  0 }, {     16,  -61,    0, 24,  0,  0 }, {     16,  -62,    0, 24,  0,  0 }, {     16,  -63,    0, 24,  0,  0 },
    {     16,  -64,    0, 24,  0,  0 }, {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 },
    {     16,   27,    0, 24,  0,  0 }, {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 },
    {     16,   22,    0, 24,  0,  0 }, {     16,   21,    0, 24,  0,  0 }, {     16,   20,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 },
    {     16,   17,    0, 24,  0,  0 }, {     16,   16,    0, 24,  0,  0 }, {     16,   15,    0, 24,  0,  0 }, {     16,   14,    0, 24,  0,  0 }, {     16,   13,    0, 24,  0,  0 },
    {     16,   12,    0, 24,  0,  0 }, {     16,   11,    0, 24,  0,  0 }, {     16,   10,    0, 24,  0,  0 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 },
    {     16,    7,    0, 24,  0,  0 }, {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 },
    {     16,    2,    0, 24,  0,  0 }, {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 }, {     16,   -1,    0, 24,  0,  0 }, {     16,   -2,    0, 24,  0,  0 },
    {     16,   -3,    0, 24,  0,  0 }, {     16,   -4,    0, 24,  0,  0 }, {     16,   -5,    0, 24,  0,  0 }, {     16,   -6,    0, 24,  0,  0 }, {     16,   -7,    0, 24,  0,  0 },
    {     16,   -8,    0, 24,  0,  0 }, {     16,   -9,    0, 24,  0,  0 }, {     16,  -10,    0, 24,  0,  0 }, {     16,  -11,    0, 24,  0,  0 }, {     16,  -12,    0, 24,  0,  0 },
    {     16,  -13,    0, 24,  0,  0 }, {     16,  -14,    0, 24,  0,  0 }, {     16,  -15,    0, 24,  0,  0 }, {     16,  -16,    0, 24,  0,  0 }, {     16,  -17,    0, 24,  0,  0 },
    {     16,  -18,    0, 24,  0,  0 }, {     16,  -19,    0, 24,  0,  0 }, {     16,  -20,    0, 24,  0,  0 }, {     16,  -21,    0, 24,  0,  0 }, {     16,  -22,    0, 24,  0,  0 },
    {     16,  -23,    0, 24,  0,  0 }, {     16,  -24,    0, 24,  0,  0 }, {     16,  -25,    0, 24,  0,  0 }, {     16,  -26,    0, 24,  0,  0 }, {     16,  -27,    0, 24,  0,  0 },
    {     16,  -28,    0, 24,  0,  0 }, {     16,  -29,    0, 24,  0,  0 }, {     16,  -30,    0, 24,  0,  0 }, {     16,  -31,    0, 24,  0,  0 }, {     16,  -32,    0, 24,  0,  0 },
    {     16,  -33,    0, 24,  0,  0 }, {     16,  -34,    0, 24,  0,  0 }, {     16,  -35,    0, 24,  0,  0 }, {     16,  -36,    0, 24,  0,  0 }, {     16,  -37,    0, 24,  0,  0 },
    {     16,  -38,    0, 24,  0,  0 }, {     16,  -39,    0, 24,  0,  0 }, {     16,  -40,    0, 24,  0,  0 }, {     16,  -41,    0, 24,  0,  0 }, {     16,  -42,    0, 24,  0,  0 },
    {     16,  -43,    0, 24,  0,  0 }, {     16,  -44,    0, 24,  0,  0 }, {     16,  -45,    0, 24,  0,  0 }, {     16,  -46,    0, 24,  0,  0 }, {     16,  -47,    0, 24,  0,  0 },
    {     16,  -48,    0, 24,  0,  0 }, {     16,  -49,    0, 24,  0,  0 }, {     16,  -50,    0, 24,  0,  0 }, {     16,  -51,    0, 24,  0,  0 }, {     16,  -52,    0, 24,  0,  0 },
    {     16,  -53,    0, 24,  0,  0 }, {     16,  -54,    0, 24,  0,  0 }, {     16,  -55,    0, 24,  0,  0 }, {     16,  -56,    0, 24,  0,  0 }, {     16,  -57,    0, 24,  0,  0 },
    {     16,  -58,    0, 24,  0,  0 }, {     16,  -59,    0, 24,  0,  0 }, {     16,  -60,    0, 24,  0,  0 }, {     16,  -61,    0, 24,  0,  0 }, {     16,  -62,    0, 24,  0,  0 },
    {     16,  -63,    0, 24,  0,  0 }, {     16,  -64,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90C4D2, {
    {     37,   16,    1,  0, 10,  0 }, {     36,   16,    2,  0, 10,  0 }, {     36,   16,    3,  0, 10,  0 }, {     36,   16,    4,  0, 10,  0 }, {     36,   16,    5,  0, 10,  0 },
    {     36,   16,    6,  0, 10,  0 }, {     35,   16,    7,  0, 10,  0 }, {     35,   16,    8,  0, 10,  0 }, {     35,   16,    9,  0,  9,  0 }, {     35,   16,   10,  0,  9,  0 },
    {     34,   16,   11,  0,  9,  0 }, {     34,   16,   12,  0,  9,  0 }, {     34,   16,   13,  0,  9,  0 }, {     33,   16,   14,  0,  9,  0 }, {     33,   16,   15,  0,  9,  0 },
    {     33,   16,   16,  0,  9,  0 }, {     32,   16,   17,  0,  9,  0 }, {     32,   16,   18,  0,  4,  0 }, {     31,   16,   19,  0,  4,  0 }, {     31,   16,   20,  0,  4,  0 },
    {     30,   16,   21,  0,  4,  0 }, {     30,   16,   22,  0,  4,  0 }, {     29,   16,   23,  0,  4,  0 }, {     29,   16,   24,  0,  4,  0 }, {     28,   16,   25,  0,  4,  0 },
    {     28,   16,   26,  0,  4,  0 }, {     27,   16,   27,  0,  3,  0 }, {     26,   16,   28,  0,  3,  0 }, {     26,   16,   29,  0,  3,  0 }, {     25,   16,   30,  0,  3,  0 },
    {     25,   16,   31,  0,  3,  0 }, {     24,   16,   32,  0,  3,  0 }, {     23,   16,   33,  0,  3,  0 }, {     22,   16,   34,  0,  3,  0 }, {     21,   16,   35,  0,  3,  0 },
    {     21,   16,   36,  0,  2,  0 }, {     20,   16,   37,  0,  2,  0 }, {     19,   16,   38,  0,  2,  0 }, {     18,   16,   39,  0,  2,  0 }, {     17,   16,   39,  0,  2,  0 },
    {     16,   16,   40,  0,  2,  0 }, {     15,   16,   41,  0,  2,  0 }, {     14,   16,   41,  0,  2,  0 }, {     13,   16,   42,  0,  2,  0 }, {     12,   16,   43,  0,  1,  0 },
    {     11,   16,   43,  0,  1,  0 }, {     10,   16,   44,  0,  1,  0 }, {      9,   16,   44,  0,  1,  0 }, {      8,   16,   45,  0,  1,  0 }, {      7,   16,   45,  0,  1,  0 },
    {      6,   16,   46,  0,  1,  0 }, {      5,   16,   46,  0,  1,  0 }, {      4,   16,   46,  0,  1,  0 }, {      3,   16,   47,  0,  0,  0 }, {      2,   16,   47,  0,  0,  0 },
    {      1,   16,   47,  0,  0,  0 }, {      0,   16,   47,  0,  0,  0 }, {     -1,   16,   47,  0,  0,  0 }, {     -2,   16,   47,  0,  0,  0 }, {     -3,   16,   47,  0,  0,  0 },
    {     -4,   16,   47,  0,  0,  0 }, {     -5,   16,   46,  0,  0,  0 }, {     -6,   16,   46,  0,  0,  0 }, {     -7,   16,   46,  0,  0,  0 }, {     -8,   16,   45,  0,  0,  0 },
    {     -9,   16,   45,  0,  0,  0 }, {    -10,   16,   44,  0,  0,  0 }, {    -11,   16,   44,  0,  0,  0 }, {    -12,   16,   43,  0,  5,  0 }, {    -13,   16,   43,  0,  5,  0 },
    {    -14,   16,   42,  0,  5,  0 }, {    -15,   16,   41,  0,  5,  0 }, {    -16,   16,   41,  0,  5,  0 }, {    -17,   16,   40,  0,  5,  0 }, {    -18,   16,   40,  0,  5,  0 },
    {    -19,   16,   39,  0,  5,  0 }, {    -20,   16,   38,  0,  5,  0 }, {    -21,   16,   37,  0,  6,  0 }, {    -21,   16,   36,  0,  6,  0 }, {    -22,   16,   35,  0,  6,  0 },
    {    -23,   16,   34,  0,  6,  0 }, {    -24,   16,   33,  0,  6,  0 }, {    -25,   16,   32,  0,  6,  0 }, {    -25,   16,   31,  0,  6,  0 }, {    -26,   16,   30,  0,  6,  0 },
    {    -26,   16,   29,  0,  6,  0 }, {    -27,   16,   28,  0,  7,  0 }, {    -28,   16,   27,  0,  7,  0 }, {    -28,   16,   26,  0,  7,  0 }, {    -29,   16,   25,  0,  7,  0 },
    {    -29,   16,   24,  0,  7,  0 }, {    -30,   16,   23,  0,  7,  0 }, {    -30,   16,   22,  0,  7,  0 }, {    -31,   16,   21,  0,  7,  0 }, {    -31,   16,   20,  0,  7,  0 },
    {    -32,   16,   19,  0,  8,  0 }, {    -32,   16,   18,  0,  8,  0 }, {    -33,   16,   17,  0,  8,  0 }, {    -33,   16,   16,  0,  8,  0 }, {    -33,   16,   15,  0,  8,  0 },
    {    -34,   16,   14,  0,  8,  0 }, {    -34,   16,   13,  0,  8,  0 }, {    -34,   16,   12,  0,  8,  0 }, {    -35,   16,   11,  0,  8,  0 }, {    -35,   16,   10,  0, 17,  0 },
    {    -35,   16,    9,  0, 17,  0 }, {    -35,   16,    8,  0, 17,  0 }, {    -36,   16,    7,  0, 17,  0 }, {    -36,   16,    6,  0, 17,  0 }, {    -36,   16,    5,  0, 17,  0 },
    {    -36,   16,    4,  0, 17,  0 }, {    -36,   16,    3,  0, 17,  0 }, {    -37,   16,    2,  0, 17,  0 }, {    -37,   16,    1,  0, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90C8D6, {
    {     16,   -6,    1,  8, 10,  0 }, {     16,   -5,    2,  8, 10,  0 }, {     16,   -5,    3,  8, 10,  0 }, {     16,   -5,    4,  8, 10,  0 }, {     16,   -5,    5,  8, 10,  0 },
    {     16,   -5,    6,  8, 10,  0 }, {     16,   -4,    7,  8, 10,  0 }, {     16,   -4,    8,  8, 10,  0 }, {     16,   -4,    9,  8,  9,  0 }, {     16,   -4,   10,  8,  9,  0 },
    {     16,   -3,   11,  8,  9,  0 }, {     16,   -3,   12,  8,  9,  0 }, {     16,   -3,   13,  8,  9,  0 }, {     16,   -2,   14,  8,  9,  0 }, {     16,   -2,   15,  8,  9,  0 },
    {     16,   -2,   16,  8,  9,  0 }, {     16,   -1,   17,  8,  9,  0 }, {     16,   -1,   18,  8,  4,  0 }, {     16,    0,   19,  8,  4,  0 }, {     16,    0,   20,  8,  4,  0 },
    {     16,    1,   21,  8,  4,  0 }, {     16,    1,   22,  8,  4,  0 }, {     16,    2,   23,  8,  4,  0 }, {     16,    2,   24,  8,  4,  0 }, {     16,    3,   25,  8,  4,  0 },
    {     16,    3,   26,  8,  4,  0 }, {     16,    4,   27,  8,  3,  0 }, {     16,    5,   28,  8,  3,  0 }, {     16,    5,   29,  8,  3,  0 }, {     16,    6,   30,  8,  3,  0 },
    {     16,    6,   31,  8,  3,  0 }, {     16,    7,   32,  8,  3,  0 }, {     16,    8,   33,  8,  3,  0 }, {     16,    9,   34,  8,  3,  0 }, {     16,   10,   35,  8,  3,  0 },
    {     16,   10,   36,  8,  2,  0 }, {     16,   11,   37,  8,  2,  0 }, {     16,   12,   38,  8,  2,  0 }, {     16,   13,   39,  8,  2,  0 }, {     16,   14,   39,  8,  2,  0 },
    {     16,   15,   40,  8,  2,  0 }, {     16,   16,   41,  8,  2,  0 }, {     16,   17,   41,  8,  2,  0 }, {     16,   18,   42,  8,  2,  0 }, {     16,   19,   43,  8,  1,  0 },
    {     16,   20,   43,  8,  1,  0 }, {     16,   21,   44,  8,  1,  0 }, {     16,   22,   44,  8,  1,  0 }, {     16,   23,   45,  8,  1,  0 }, {     16,   24,   45,  8,  1,  0 },
    {     16,   25,   46,  8,  1,  0 }, {     16,   26,   46,  8,  1,  0 }, {     16,   27,   46,  8,  1,  0 }, {     16,   28,   47,  8,  0,  0 }, {     16,   29,   47,  8,  0,  0 },
    {     16,   30,   47,  8,  0,  0 }, {     16,   31,   47,  8,  0,  0 }, {     16,   32,   47,  8,  0,  0 }, {     16,   33,   47,  8,  0,  0 }, {     16,   34,   47,  8,  0,  0 },
    {     16,   35,   47,  8,  0,  0 }, {     16,   36,   46,  8,  0,  0 }, {     16,   37,   46,  8,  0,  0 }, {     16,   38,   46,  8,  0,  0 }, {     16,   39,   45,  8,  0,  0 },
    {     16,   40,   45,  8,  0,  0 }, {     16,   41,   44,  8,  0,  0 }, {     16,   42,   44,  8,  0,  0 }, {     16,   43,   43,  8,  5,  0 }, {     16,   44,   43,  8,  5,  0 },
    {     16,   45,   42,  8,  5,  0 }, {     16,   46,   41,  8,  5,  0 }, {     16,   47,   41,  8,  5,  0 }, {     16,   48,   40,  8,  5,  0 }, {     16,   49,   40,  8,  5,  0 },
    {     16,   50,   39,  8,  5,  0 }, {     16,   51,   38,  8,  5,  0 }, {     16,   52,   37,  8,  6,  0 }, {     16,   52,   36,  8,  6,  0 }, {     16,   53,   35,  8,  6,  0 },
    {     16,   54,   34,  8,  6,  0 }, {     16,   55,   33,  8,  6,  0 }, {     16,   56,   32,  8,  6,  0 }, {     16,   56,   31,  8,  6,  0 }, {     16,   57,   30,  8,  6,  0 },
    {     16,   57,   29,  8,  6,  0 }, {     16,   58,   28,  8,  7,  0 }, {     16,   59,   27,  8,  7,  0 }, {     16,   59,   26,  8,  7,  0 }, {     16,   60,   25,  8,  7,  0 },
    {     16,   60,   24,  8,  7,  0 }, {     16,   61,   23,  8,  7,  0 }, {     16,   61,   22,  8,  7,  0 }, {     16,   62,   21,  8,  7,  0 }, {     16,   62,   20,  8,  7,  0 },
    {     16,   63,   19,  8,  8,  0 }, {     16,   63,   18,  8,  8,  0 }, {     16,   64,   17,  8,  8,  0 }, {     16,   64,   16,  8,  8,  0 }, {     16,   64,   15,  8,  8,  0 },
    {     16,   65,   14,  8,  8,  0 }, {     16,   65,   13,  8,  8,  0 }, {     16,   65,   12,  8,  8,  0 }, {     16,   66,   11,  8,  8,  0 }, {     16,   66,   10,  8, 17,  0 },
    {     16,   66,    9,  8, 17,  0 }, {     16,   66,    8,  8, 17,  0 }, {     16,   67,    7,  8, 17,  0 }, {     16,   67,    6,  8, 17,  0 }, {     16,   67,    5,  8, 17,  0 },
    {     16,   67,    4,  8, 17,  0 }, {     16,   67,    3,  8, 17,  0 }, {     16,   68,    2,  8, 17,  0 }, {     16,   68,    1,  8, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90CCDA, {
    {     -6,   16,    1, 16, 10,  0 }, {     -5,   16,    2, 16, 10,  0 }, {     -5,   16,    3, 16, 10,  0 }, {     -5,   16,    4, 16, 10,  0 }, {     -5,   16,    5, 16, 10,  0 },
    {     -5,   16,    6, 16, 10,  0 }, {     -4,   16,    7, 16, 10,  0 }, {     -4,   16,    8, 16, 10,  0 }, {     -4,   16,    9, 16,  9,  0 }, {     -4,   16,   10, 16,  9,  0 },
    {     -3,   16,   11, 16,  9,  0 }, {     -3,   16,   12, 16,  9,  0 }, {     -3,   16,   13, 16,  9,  0 }, {     -2,   16,   14, 16,  9,  0 }, {     -2,   16,   15, 16,  9,  0 },
    {     -2,   16,   16, 16,  9,  0 }, {     -1,   16,   17, 16,  9,  0 }, {     -1,   16,   18, 16,  4,  0 }, {      0,   16,   19, 16,  4,  0 }, {      0,   16,   20, 16,  4,  0 },
    {      1,   16,   21, 16,  4,  0 }, {      1,   16,   22, 16,  4,  0 }, {      2,   16,   23, 16,  4,  0 }, {      2,   16,   24, 16,  4,  0 }, {      3,   16,   25, 16,  4,  0 },
    {      3,   16,   26, 16,  4,  0 }, {      4,   16,   27, 16,  3,  0 }, {      5,   16,   28, 16,  3,  0 }, {      5,   16,   29, 16,  3,  0 }, {      6,   16,   30, 16,  3,  0 },
    {      6,   16,   31, 16,  3,  0 }, {      7,   16,   32, 16,  3,  0 }, {      8,   16,   33, 16,  3,  0 }, {      9,   16,   34, 16,  3,  0 }, {     10,   16,   35, 16,  3,  0 },
    {     10,   16,   36, 16,  2,  0 }, {     11,   16,   37, 16,  2,  0 }, {     12,   16,   38, 16,  2,  0 }, {     13,   16,   39, 16,  2,  0 }, {     14,   16,   39, 16,  2,  0 },
    {     15,   16,   40, 16,  2,  0 }, {     16,   16,   41, 16,  2,  0 }, {     17,   16,   41, 16,  2,  0 }, {     18,   16,   42, 16,  2,  0 }, {     19,   16,   43, 16,  1,  0 },
    {     20,   16,   43, 16,  1,  0 }, {     21,   16,   44, 16,  1,  0 }, {     22,   16,   44, 16,  1,  0 }, {     23,   16,   45, 16,  1,  0 }, {     24,   16,   45, 16,  1,  0 },
    {     25,   16,   46, 16,  1,  0 }, {     26,   16,   46, 16,  1,  0 }, {     27,   16,   46, 16,  1,  0 }, {     28,   16,   47, 16,  0,  0 }, {     29,   16,   47, 16,  0,  0 },
    {     30,   16,   47, 16,  0,  0 }, {     31,   16,   47, 16,  0,  0 }, {     32,   16,   47, 16,  0,  0 }, {     33,   16,   47, 16,  0,  0 }, {     34,   16,   47, 16,  0,  0 },
    {     35,   16,   47, 16,  0,  0 }, {     36,   16,   46, 16,  0,  0 }, {     37,   16,   46, 16,  0,  0 }, {     38,   16,   46, 16,  0,  0 }, {     39,   16,   45, 16,  0,  0 },
    {     40,   16,   45, 16,  0,  0 }, {     41,   16,   44, 16,  0,  0 }, {     42,   16,   44, 16,  0,  0 }, {     43,   16,   43, 16,  5,  0 }, {     44,   16,   43, 16,  5,  0 },
    {     45,   16,   42, 16,  5,  0 }, {     46,   16,   41, 16,  5,  0 }, {     47,   16,   41, 16,  5,  0 }, {     48,   16,   40, 16,  5,  0 }, {     49,   16,   40, 16,  5,  0 },
    {     50,   16,   39, 16,  5,  0 }, {     51,   16,   38, 16,  5,  0 }, {     52,   16,   37, 16,  6,  0 }, {     52,   16,   36, 16,  6,  0 }, {     53,   16,   35, 16,  6,  0 },
    {     54,   16,   34, 16,  6,  0 }, {     55,   16,   33, 16,  6,  0 }, {     56,   16,   32, 16,  6,  0 }, {     56,   16,   31, 16,  6,  0 }, {     57,   16,   30, 16,  6,  0 },
    {     57,   16,   29, 16,  6,  0 }, {     58,   16,   28, 16,  7,  0 }, {     59,   16,   27, 16,  7,  0 }, {     59,   16,   26, 16,  7,  0 }, {     60,   16,   25, 16,  7,  0 },
    {     60,   16,   24, 16,  7,  0 }, {     61,   16,   23, 16,  7,  0 }, {     61,   16,   22, 16,  7,  0 }, {     62,   16,   21, 16,  7,  0 }, {     62,   16,   20, 16,  7,  0 },
    {     63,   16,   19, 16,  8,  0 }, {     63,   16,   18, 16,  8,  0 }, {     64,   16,   17, 16,  8,  0 }, {     64,   16,   16, 16,  8,  0 }, {     64,   16,   15, 16,  8,  0 },
    {     65,   16,   14, 16,  8,  0 }, {     65,   16,   13, 16,  8,  0 }, {     65,   16,   12, 16,  8,  0 }, {     66,   16,   11, 16,  8,  0 }, {     66,   16,   10, 16, 17,  0 },
    {     66,   16,    9, 16, 17,  0 }, {     66,   16,    8, 16, 17,  0 }, {     67,   16,    7, 16, 17,  0 }, {     67,   16,    6, 16, 17,  0 }, {     67,   16,    5, 16, 17,  0 },
    {     67,   16,    4, 16, 17,  0 }, {     67,   16,    3, 16, 17,  0 }, {     68,   16,    2, 16, 17,  0 }, {     68,   16,    1, 16, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90D0DE, {
    {     16,   37,    1, 24, 10,  0 }, {     16,   36,    2, 24, 10,  0 }, {     16,   36,    3, 24, 10,  0 }, {     16,   36,    4, 24, 10,  0 }, {     16,   36,    5, 24, 10,  0 },
    {     16,   36,    6, 24, 10,  0 }, {     16,   35,    7, 24, 10,  0 }, {     16,   35,    8, 24, 10,  0 }, {     16,   35,    9, 24,  9,  0 }, {     16,   35,   10, 24,  9,  0 },
    {     16,   34,   11, 24,  9,  0 }, {     16,   34,   12, 24,  9,  0 }, {     16,   34,   13, 24,  9,  0 }, {     16,   33,   14, 24,  9,  0 }, {     16,   33,   15, 24,  9,  0 },
    {     16,   33,   16, 24,  9,  0 }, {     16,   32,   17, 24,  9,  0 }, {     16,   32,   18, 24,  4,  0 }, {     16,   31,   19, 24,  4,  0 }, {     16,   31,   20, 24,  4,  0 },
    {     16,   30,   21, 24,  4,  0 }, {     16,   30,   22, 24,  4,  0 }, {     16,   29,   23, 24,  4,  0 }, {     16,   29,   24, 24,  4,  0 }, {     16,   28,   25, 24,  4,  0 },
    {     16,   28,   26, 24,  4,  0 }, {     16,   27,   27, 24,  3,  0 }, {     16,   26,   28, 24,  3,  0 }, {     16,   26,   29, 24,  3,  0 }, {     16,   25,   30, 24,  3,  0 },
    {     16,   25,   31, 24,  3,  0 }, {     16,   24,   32, 24,  3,  0 }, {     16,   23,   33, 24,  3,  0 }, {     16,   22,   34, 24,  3,  0 }, {     16,   21,   35, 24,  3,  0 },
    {     16,   21,   36, 24,  2,  0 }, {     16,   20,   37, 24,  2,  0 }, {     16,   19,   38, 24,  2,  0 }, {     16,   18,   39, 24,  2,  0 }, {     16,   17,   39, 24,  2,  0 },
    {     16,   16,   40, 24,  2,  0 }, {     16,   15,   41, 24,  2,  0 }, {     16,   14,   41, 24,  2,  0 }, {     16,   13,   42, 24,  2,  0 }, {     16,   12,   43, 24,  1,  0 },
    {     16,   11,   43, 24,  1,  0 }, {     16,   10,   44, 24,  1,  0 }, {     16,    9,   44, 24,  1,  0 }, {     16,    8,   45, 24,  1,  0 }, {     16,    7,   45, 24,  1,  0 },
    {     16,    6,   46, 24,  1,  0 }, {     16,    5,   46, 24,  1,  0 }, {     16,    4,   46, 24,  1,  0 }, {     16,    3,   47, 24,  0,  0 }, {     16,    2,   47, 24,  0,  0 },
    {     16,    1,   47, 24,  0,  0 }, {     16,    0,   47, 24,  0,  0 }, {     16,   -1,   47, 24,  0,  0 }, {     16,   -2,   47, 24,  0,  0 }, {     16,   -3,   47, 24,  0,  0 },
    {     16,   -4,   47, 24,  0,  0 }, {     16,   -5,   46, 24,  0,  0 }, {     16,   -6,   46, 24,  0,  0 }, {     16,   -7,   46, 24,  0,  0 }, {     16,   -8,   45, 24,  0,  0 },
    {     16,   -9,   45, 24,  0,  0 }, {     16,  -10,   44, 24,  0,  0 }, {     16,  -11,   44, 24,  0,  0 }, {     16,  -12,   43, 24,  5,  0 }, {     16,  -13,   43, 24,  5,  0 },
    {     16,  -14,   42, 24,  5,  0 }, {     16,  -15,   41, 24,  5,  0 }, {     16,  -16,   41, 24,  5,  0 }, {     16,  -17,   40, 24,  5,  0 }, {     16,  -18,   40, 24,  5,  0 },
    {     16,  -19,   39, 24,  5,  0 }, {     16,  -20,   38, 24,  5,  0 }, {     16,  -21,   37, 24,  6,  0 }, {     16,  -21,   36, 24,  6,  0 }, {     16,  -22,   35, 24,  6,  0 },
    {     16,  -23,   34, 24,  6,  0 }, {     16,  -24,   33, 24,  6,  0 }, {     16,  -25,   32, 24,  6,  0 }, {     16,  -25,   31, 24,  6,  0 }, {     16,  -26,   30, 24,  6,  0 },
    {     16,  -26,   29, 24,  6,  0 }, {     16,  -27,   28, 24,  7,  0 }, {     16,  -28,   27, 24,  7,  0 }, {     16,  -28,   26, 24,  7,  0 }, {     16,  -29,   25, 24,  7,  0 },
    {     16,  -29,   24, 24,  7,  0 }, {     16,  -30,   23, 24,  7,  0 }, {     16,  -30,   22, 24,  7,  0 }, {     16,  -31,   21, 24,  7,  0 }, {     16,  -31,   20, 24,  7,  0 },
    {     16,  -32,   19, 24,  8,  0 }, {     16,  -32,   18, 24,  8,  0 }, {     16,  -33,   17, 24,  8,  0 }, {     16,  -33,   16, 24,  8,  0 }, {     16,  -33,   15, 24,  8,  0 },
    {     16,  -34,   14, 24,  8,  0 }, {     16,  -34,   13, 24,  8,  0 }, {     16,  -34,   12, 24,  8,  0 }, {     16,  -35,   11, 24,  8,  0 }, {     16,  -35,   10, 24, 17,  0 },
    {     16,  -35,    9, 24, 17,  0 }, {     16,  -35,    8, 24, 17,  0 }, {     16,  -36,    7, 24, 17,  0 }, {     16,  -36,    6, 24, 17,  0 }, {     16,  -36,    5, 24, 17,  0 },
    {     16,  -36,    4, 24, 17,  0 }, {     16,  -36,    3, 24, 17,  0 }, {     16,  -37,    2, 24, 17,  0 }, {     16,  -37,    1, 24, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90D4E2, {
    {     27,   16,   79,  0, 18,  0 }, {     27,   16,   78,  0, 18,  0 }, {     27,   16,   77,  0, 18,  0 }, {     27,   16,   76,  0, 18,  0 }, {     27,   16,   75,  0, 18,  0 },
    {     27,   16,   74,  0, 18,  0 }, {     27,   16,   73,  0, 18,  0 }, {     27,   16,   72,  0, 18,  0 }, {     27,   16,   71,  0, 18,  0 }, {     27,   16,   70,  0, 18,  0 },
    {     27,   16,   69,  0, 18,  0 }, {     27,   16,   68,  0, 18,  0 }, {     27,   16,   67,  0, 18,  0 }, {     27,   16,   66,  0, 18,  0 }, {     27,   16,   65,  0, 18,  0 },
    {     27,   16,   64,  0, 18,  0 }, {     27,   16,   63,  0, 18,  0 }, {     27,   16,   62,  0, 18,  0 }, {     27,   16,   61,  0, 18,  0 }, {     27,   16,   60,  0, 18,  0 },
    {     27,   16,   59,  0, 18,  0 }, {     27,   16,   58,  0, 18,  0 }, {     27,   16,   57,  0, 18,  0 }, {     27,   16,   56,  0, 18,  0 }, {     27,   16,   55,  0, 18,  0 },
    {     27,   16,   54,  0, 18,  0 }, {     27,   16,   53,  0, 18,  0 }, {     27,   16,   52,  0, 18,  0 }, {     27,   16,   51,  0, 18,  0 }, {     27,   16,   50,  0, 18,  0 },
    {     27,   16,   49,  0, 18,  0 }, {     27,   16,   48,  0, 18,  0 }, {     27,   16,   47,  0, 18,  0 }, {     27,   16,   46,  0, 18,  0 }, {     27,   16,   45,  0, 18,  0 },
    {     27,   16,   44,  0, 18,  0 }, {     27,   16,   43,  0, 18,  0 }, {     27,   16,   42,  0, 18,  0 }, {     27,   16,   41,  0, 18,  0 }, {     27,   16,   40,  0, 18,  0 },
    {     27,   16,   39,  0, 18,  0 }, {     27,   16,   38,  0, 18,  0 }, {     27,   16,   37,  0, 18,  0 }, {     27,   16,   36,  0, 18,  0 }, {     27,   16,   35,  0, 18,  0 },
    {     27,   16,   34,  0, 18,  0 }, {     27,   16,   33,  0, 18,  0 }, {     27,   16,   32,  0, 18,  0 }, {     27,   16,   31,  0, 18,  0 }, {     27,   16,   30,  0, 18,  0 },
    {     27,   16,   29,  0, 18,  0 }, {     27,   16,   28,  0, 18,  0 }, {     27,   16,   27,  0, 18,  0 }, {     27,   16,   26,  0, 18,  0 }, {     27,   16,   25,  0, 18,  0 },
    {     27,   16,   24,  0, 18,  0 }, {     27,   16,   23,  0, 18,  0 }, {     27,   16,   22,  0, 18,  0 }, {     27,   16,   21,  0, 18,  0 }, {     27,   16,   20,  0, 18,  0 },
    {     27,   16,   19,  0, 18,  0 }, {     27,   16,   18,  0, 18,  0 }, {     27,   16,   17,  0, 18,  0 }, {     27,   16,   16,  0, 18,  0 }, {     27,   16,   15,  0, 18,  0 },
    {     27,   16,   14,  0, 18,  0 }, {     27,   16,   13,  0, 18,  0 }, {     27,   16,   12,  0, 18,  0 }, {     27,   16,   11,  0, 18,  0 }, {     27,   16,   10,  0, 18,  0 },
    {     27,   16,    9,  0, 18,  0 }, {     27,   16,    8,  0, 18,  0 }, {     27,   16,    7,  0, 18,  0 }, {     27,   16,    6,  0, 18,  0 }, {     27,   16,    5,  0, 18,  0 },
    {     27,   16,    4,  0, 18,  0 }, {     27,   16,    3,  0, 18,  0 }, {     27,   16,    2,  0, 18,  0 }, {     27,   16,    1,  0, 18,  0 }, {     27,   16,    0,  0, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90D7B4, {
    {     16,    5,   79,  8, 18,  0 }, {     16,    5,   78,  8, 18,  0 }, {     16,    5,   77,  8, 18,  0 }, {     16,    5,   76,  8, 18,  0 }, {     16,    5,   75,  8, 18,  0 },
    {     16,    5,   74,  8, 18,  0 }, {     16,    5,   73,  8, 18,  0 }, {     16,    5,   72,  8, 18,  0 }, {     16,    5,   71,  8, 18,  0 }, {     16,    5,   70,  8, 18,  0 },
    {     16,    5,   69,  8, 18,  0 }, {     16,    5,   68,  8, 18,  0 }, {     16,    5,   67,  8, 18,  0 }, {     16,    5,   66,  8, 18,  0 }, {     16,    5,   65,  8, 18,  0 },
    {     16,    5,   64,  8, 18,  0 }, {     16,    5,   63,  8, 18,  0 }, {     16,    5,   62,  8, 18,  0 }, {     16,    5,   61,  8, 18,  0 }, {     16,    5,   60,  8, 18,  0 },
    {     16,    5,   59,  8, 18,  0 }, {     16,    5,   58,  8, 18,  0 }, {     16,    5,   57,  8, 18,  0 }, {     16,    5,   56,  8, 18,  0 }, {     16,    5,   55,  8, 18,  0 },
    {     16,    5,   54,  8, 18,  0 }, {     16,    5,   53,  8, 18,  0 }, {     16,    5,   52,  8, 18,  0 }, {     16,    5,   51,  8, 18,  0 }, {     16,    5,   50,  8, 18,  0 },
    {     16,    5,   49,  8, 18,  0 }, {     16,    5,   48,  8, 18,  0 }, {     16,    5,   47,  8, 18,  0 }, {     16,    5,   46,  8, 18,  0 }, {     16,    5,   45,  8, 18,  0 },
    {     16,    5,   44,  8, 18,  0 }, {     16,    5,   43,  8, 18,  0 }, {     16,    5,   42,  8, 18,  0 }, {     16,    5,   41,  8, 18,  0 }, {     16,    5,   40,  8, 18,  0 },
    {     16,    5,   39,  8, 18,  0 }, {     16,    5,   38,  8, 18,  0 }, {     16,    5,   37,  8, 18,  0 }, {     16,    5,   36,  8, 18,  0 }, {     16,    5,   35,  8, 18,  0 },
    {     16,    5,   34,  8, 18,  0 }, {     16,    5,   33,  8, 18,  0 }, {     16,    5,   32,  8, 18,  0 }, {     16,    5,   31,  8, 18,  0 }, {     16,    5,   30,  8, 18,  0 },
    {     16,    5,   29,  8, 18,  0 }, {     16,    5,   28,  8, 18,  0 }, {     16,    5,   27,  8, 18,  0 }, {     16,    5,   26,  8, 18,  0 }, {     16,    5,   25,  8, 18,  0 },
    {     16,    5,   24,  8, 18,  0 }, {     16,    5,   23,  8, 18,  0 }, {     16,    5,   22,  8, 18,  0 }, {     16,    5,   21,  8, 18,  0 }, {     16,    5,   20,  8, 18,  0 },
    {     16,    5,   19,  8, 18,  0 }, {     16,    5,   18,  8, 18,  0 }, {     16,    5,   17,  8, 18,  0 }, {     16,    5,   16,  8, 18,  0 }, {     16,    5,   15,  8, 18,  0 },
    {     16,    5,   14,  8, 18,  0 }, {     16,    5,   13,  8, 18,  0 }, {     16,    5,   12,  8, 18,  0 }, {     16,    5,   11,  8, 18,  0 }, {     16,    5,   10,  8, 18,  0 },
    {     16,    5,    9,  8, 18,  0 }, {     16,    5,    8,  8, 18,  0 }, {     16,    5,    7,  8, 18,  0 }, {     16,    5,    6,  8, 18,  0 }, {     16,    5,    5,  8, 18,  0 },
    {     16,    5,    4,  8, 18,  0 }, {     16,    5,    3,  8, 18,  0 }, {     16,    5,    2,  8, 18,  0 }, {     16,    5,    1,  8, 18,  0 }, {     16,    5,    0,  8, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90DA86, {
    {      5,   16,   79, 16, 18,  0 }, {      5,   16,   78, 16, 18,  0 }, {      5,   16,   77, 16, 18,  0 }, {      5,   16,   76, 16, 18,  0 }, {      5,   16,   75, 16, 18,  0 },
    {      5,   16,   74, 16, 18,  0 }, {      5,   16,   73, 16, 18,  0 }, {      5,   16,   72, 16, 18,  0 }, {      5,   16,   71, 16, 18,  0 }, {      5,   16,   70, 16, 18,  0 },
    {      5,   16,   69, 16, 18,  0 }, {      5,   16,   68, 16, 18,  0 }, {      5,   16,   67, 16, 18,  0 }, {      5,   16,   66, 16, 18,  0 }, {      5,   16,   65, 16, 18,  0 },
    {      5,   16,   64, 16, 18,  0 }, {      5,   16,   63, 16, 18,  0 }, {      5,   16,   62, 16, 18,  0 }, {      5,   16,   61, 16, 18,  0 }, {      5,   16,   60, 16, 18,  0 },
    {      5,   16,   59, 16, 18,  0 }, {      5,   16,   58, 16, 18,  0 }, {      5,   16,   57, 16, 18,  0 }, {      5,   16,   56, 16, 18,  0 }, {      5,   16,   55, 16, 18,  0 },
    {      5,   16,   54, 16, 18,  0 }, {      5,   16,   53, 16, 18,  0 }, {      5,   16,   52, 16, 18,  0 }, {      5,   16,   51, 16, 18,  0 }, {      5,   16,   50, 16, 18,  0 },
    {      5,   16,   49, 16, 18,  0 }, {      5,   16,   48, 16, 18,  0 }, {      5,   16,   47, 16, 18,  0 }, {      5,   16,   46, 16, 18,  0 }, {      5,   16,   45, 16, 18,  0 },
    {      5,   16,   44, 16, 18,  0 }, {      5,   16,   43, 16, 18,  0 }, {      5,   16,   42, 16, 18,  0 }, {      5,   16,   41, 16, 18,  0 }, {      5,   16,   40, 16, 18,  0 },
    {      5,   16,   39, 16, 18,  0 }, {      5,   16,   38, 16, 18,  0 }, {      5,   16,   37, 16, 18,  0 }, {      5,   16,   36, 16, 18,  0 }, {      5,   16,   35, 16, 18,  0 },
    {      5,   16,   34, 16, 18,  0 }, {      5,   16,   33, 16, 18,  0 }, {      5,   16,   32, 16, 18,  0 }, {      5,   16,   31, 16, 18,  0 }, {      5,   16,   30, 16, 18,  0 },
    {      5,   16,   29, 16, 18,  0 }, {      5,   16,   28, 16, 18,  0 }, {      5,   16,   27, 16, 18,  0 }, {      5,   16,   26, 16, 18,  0 }, {      5,   16,   25, 16, 18,  0 },
    {      5,   16,   24, 16, 18,  0 }, {      5,   16,   23, 16, 18,  0 }, {      5,   16,   22, 16, 18,  0 }, {      5,   16,   21, 16, 18,  0 }, {      5,   16,   20, 16, 18,  0 },
    {      5,   16,   19, 16, 18,  0 }, {      5,   16,   18, 16, 18,  0 }, {      5,   16,   17, 16, 18,  0 }, {      5,   16,   16, 16, 18,  0 }, {      5,   16,   15, 16, 18,  0 },
    {      5,   16,   14, 16, 18,  0 }, {      5,   16,   13, 16, 18,  0 }, {      5,   16,   12, 16, 18,  0 }, {      5,   16,   11, 16, 18,  0 }, {      5,   16,   10, 16, 18,  0 },
    {      5,   16,    9, 16, 18,  0 }, {      5,   16,    8, 16, 18,  0 }, {      5,   16,    7, 16, 18,  0 }, {      5,   16,    6, 16, 18,  0 }, {      5,   16,    5, 16, 18,  0 },
    {      5,   16,    4, 16, 18,  0 }, {      5,   16,    3, 16, 18,  0 }, {      5,   16,    2, 16, 18,  0 }, {      5,   16,    1, 16, 18,  0 }, {      5,   16,    0, 16, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90DD58, {
    {     16,   27,   79, 24, 18,  0 }, {     16,   27,   78, 24, 18,  0 }, {     16,   27,   77, 24, 18,  0 }, {     16,   27,   76, 24, 18,  0 }, {     16,   27,   75, 24, 18,  0 },
    {     16,   27,   74, 24, 18,  0 }, {     16,   27,   73, 24, 18,  0 }, {     16,   27,   72, 24, 18,  0 }, {     16,   27,   71, 24, 18,  0 }, {     16,   27,   70, 24, 18,  0 },
    {     16,   27,   69, 24, 18,  0 }, {     16,   27,   68, 24, 18,  0 }, {     16,   27,   67, 24, 18,  0 }, {     16,   27,   66, 24, 18,  0 }, {     16,   27,   65, 24, 18,  0 },
    {     16,   27,   64, 24, 18,  0 }, {     16,   27,   63, 24, 18,  0 }, {     16,   27,   62, 24, 18,  0 }, {     16,   27,   61, 24, 18,  0 }, {     16,   27,   60, 24, 18,  0 },
    {     16,   27,   59, 24, 18,  0 }, {     16,   27,   58, 24, 18,  0 }, {     16,   27,   57, 24, 18,  0 }, {     16,   27,   56, 24, 18,  0 }, {     16,   27,   55, 24, 18,  0 },
    {     16,   27,   54, 24, 18,  0 }, {     16,   27,   53, 24, 18,  0 }, {     16,   27,   52, 24, 18,  0 }, {     16,   27,   51, 24, 18,  0 }, {     16,   27,   50, 24, 18,  0 },
    {     16,   27,   49, 24, 18,  0 }, {     16,   27,   48, 24, 18,  0 }, {     16,   27,   47, 24, 18,  0 }, {     16,   27,   46, 24, 18,  0 }, {     16,   27,   45, 24, 18,  0 },
    {     16,   27,   44, 24, 18,  0 }, {     16,   27,   43, 24, 18,  0 }, {     16,   27,   42, 24, 18,  0 }, {     16,   27,   41, 24, 18,  0 }, {     16,   27,   40, 24, 18,  0 },
    {     16,   27,   39, 24, 18,  0 }, {     16,   27,   38, 24, 18,  0 }, {     16,   27,   37, 24, 18,  0 }, {     16,   27,   36, 24, 18,  0 }, {     16,   27,   35, 24, 18,  0 },
    {     16,   27,   34, 24, 18,  0 }, {     16,   27,   33, 24, 18,  0 }, {     16,   27,   32, 24, 18,  0 }, {     16,   27,   31, 24, 18,  0 }, {     16,   27,   30, 24, 18,  0 },
    {     16,   27,   29, 24, 18,  0 }, {     16,   27,   28, 24, 18,  0 }, {     16,   27,   27, 24, 18,  0 }, {     16,   27,   26, 24, 18,  0 }, {     16,   27,   25, 24, 18,  0 },
    {     16,   27,   24, 24, 18,  0 }, {     16,   27,   23, 24, 18,  0 }, {     16,   27,   22, 24, 18,  0 }, {     16,   27,   21, 24, 18,  0 }, {     16,   27,   20, 24, 18,  0 },
    {     16,   27,   19, 24, 18,  0 }, {     16,   27,   18, 24, 18,  0 }, {     16,   27,   17, 24, 18,  0 }, {     16,   27,   16, 24, 18,  0 }, {     16,   27,   15, 24, 18,  0 },
    {     16,   27,   14, 24, 18,  0 }, {     16,   27,   13, 24, 18,  0 }, {     16,   27,   12, 24, 18,  0 }, {     16,   27,   11, 24, 18,  0 }, {     16,   27,   10, 24, 18,  0 },
    {     16,   27,    9, 24, 18,  0 }, {     16,   27,    8, 24, 18,  0 }, {     16,   27,    7, 24, 18,  0 }, {     16,   27,    6, 24, 18,  0 }, {     16,   27,    5, 24, 18,  0 },
    {     16,   27,    4, 24, 18,  0 }, {     16,   27,    3, 24, 18,  0 }, {     16,   27,    2, 24, 18,  0 }, {     16,   27,    1, 24, 18,  0 }, {     16,   27,    0, 24, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_908EC2, {
    {     27,   16,  239,  0, 18,  0 }, {     27,   16,  238,  0, 18,  0 }, {     27,   16,  237,  0, 18,  0 }, {     27,   16,  236,  0, 18,  0 }, {     27,   16,  235,  0, 18,  0 },
    {     27,   16,  234,  0, 18,  0 }, {     27,   16,  233,  0, 18,  0 }, {     27,   16,  232,  0, 18,  0 }, {     27,   16,  231,  0, 18,  0 }, {     27,   16,  229,  0, 18,  0 },
    {     27,   16,  228,  0, 18,  0 }, {     27,   16,  227,  0, 18,  0 }, {     27,   16,  226,  0, 18,  0 }, {     27,   16,  225,  0, 18,  0 }, {     27,   16,  224,  0, 18,  0 },
    {     27,   16,  223,  0, 18,  0 }, {     27,   16,  222,  0, 18,  0 }, {     27,   16,  221,  0, 18,  0 }, {     27,   16,  220,  0, 18,  0 }, {     27,   16,  219,  0, 18,  0 },
    {     27,   16,  218,  0, 18,  0 }, {     27,   16,  217,  0, 18,  0 }, {     27,   16,  216,  0, 18,  0 }, {     27,   16,  215,  0, 18,  0 }, {     27,   16,  214,  0, 18,  0 },
    {     27,   16,  213,  0, 18,  0 }, {     27,   16,  212,  0, 18,  0 }, {     26,   16,  211,  0, 18,  0 }, {     26,   16,  210,  0, 18,  0 }, {     26,   16,  209,  0, 18,  0 },
    {     26,   16,  208,  0, 18,  0 }, {     26,   16,  207,  0, 18,  0 }, {     26,   16,  206,  0, 18,  0 }, {     26,   16,  205,  0, 18,  0 }, {     26,   16,  204,  0, 18,  0 },
    {     26,   16,  203,  0, 18,  0 }, {     26,   16,  202,  0, 18,  0 }, {     26,   16,  201,  0, 18,  0 }, {     26,   16,  200,  0, 18,  0 }, {     25,   16,  199,  0, 18,  0 },
    {     25,   16,  198,  0, 18,  0 }, {     25,   16,  197,  0, 18,  0 }, {     25,   16,  196,  0, 18,  0 }, {     25,   16,  195,  0, 18,  0 }, {     25,   16,  194,  0, 18,  0 },
    {     25,   16,  193,  0, 18,  0 }, {     25,   16,  192,  0, 18,  0 }, {     24,   16,  191,  0, 18,  0 }, {     24,   16,  190,  0, 18,  0 }, {     24,   16,  189,  0, 18,  0 },
    {     24,   16,  188,  0, 17,  0 }, {     24,   16,  187,  0, 17,  0 }, {     24,   16,  186,  0, 17,  0 }, {     24,   16,  185,  0, 17,  0 }, {     23,   16,  184,  0, 17,  0 },
    {     23,   16,  183,  0, 17,  0 }, {     23,   16,  182,  0, 17,  0 }, {     23,   16,  181,  0, 17,  0 }, {     23,   16,  180,  0, 17,  0 }, {     23,   16,  179,  0, 17,  0 },
    {     22,   16,  178,  0, 17,  0 }, {     22,   16,  177,  0, 17,  0 }, {     22,   16,  176,  0, 17,  0 }, {     22,   16,  175,  0, 17,  0 }, {     22,   16,  174,  0, 17,  0 },
    {     21,   16,  173,  0, 17,  0 }, {     21,   16,  172,  0, 17,  0 }, {     21,   16,  171,  0, 17,  0 }, {     21,   16,  170,  0, 17,  0 }, {     20,   16,  169,  0, 17,  0 },
    {     20,   16,  168,  0, 17,  0 }, {     20,   16,  167,  0, 17,  0 }, {     20,   16,  166,  0, 17,  0 }, {     20,   16,  165,  0, 17,  0 }, {     19,   16,  164,  0, 17,  0 },
    {     19,   16,  163,  0, 17,  0 }, {     19,   16,  162,  0, 17,  0 }, {     19,   16,  161,  0, 17,  0 }, {     18,   16,  160,  0, 17,  0 }, {     18,   16,  159,  0, 17,  0 },
    {     18,   16,  158,  0, 17,  0 }, {     17,   16,  157,  0, 17,  0 }, {     17,   16,  156,  0, 17,  0 }, {     17,   16,  155,  0, 17,  0 }, {     17,   16,  154,  0, 17,  0 },
    {     16,   16,  153,  0, 17,  0 }, {     16,   16,  152,  0, 17,  0 }, {     16,   16,  151,  0, 17,  0 }, {     15,   16,  150,  0, 17,  0 }, {     15,   16,  149,  0, 17,  0 },
    {     15,   16,  148,  0, 17,  0 }, {     14,   16,  147,  0, 17,  0 }, {     14,   16,  146,  0, 17,  0 }, {     14,   16,  145,  0, 17,  0 }, {     13,   16,  144,  0, 17,  0 },
    {     13,   16,  143,  0, 17,  0 }, {     13,   16,  142,  0, 17,  0 }, {     12,   16,  141,  0, 17,  0 }, {     12,   16,  140,  0, 17,  0 }, {     12,   16,  139,  0, 17,  0 },
    {     11,   16,  138,  0, 17,  0 }, {     11,   16,  137,  0, 17,  0 }, {     11,   16,  136,  0, 17,  0 }, {     10,   16,  135,  0,  8,  0 }, {     10,   16,  134,  0,  8,  0 },
    {     10,   16,  133,  0,  8,  0 }, {      9,   16,  132,  0,  8,  0 }, {      9,   16,  131,  0,  8,  0 }, {      8,   16,  130,  0,  8,  0 }, {      8,   16,  129,  0,  8,  0 },
    {      8,   16,  128,  0,  8,  0 }, {      7,   16,  127,  0,  8,  0 }, {      7,   16,  126,  0,  8,  0 }, {      6,   16,  125,  0,  8,  0 }, {      6,   16,  124,  0,  8,  0 },
    {      5,   16,  123,  0,  8,  0 }, {      5,   16,  122,  0,  8,  0 }, {      5,   16,  121,  0,  8,  0 }, {      4,   16,  120,  0,  8,  0 }, {      4,   16,  119,  0,  8,  0 },
    {      3,   16,  118,  0,  8,  0 }, {      3,   16,  117,  0,  8,  0 }, {      2,   16,  116,  0,  8,  0 }, {      2,   16,  115,  0,  8,  0 }, {      1,   16,  114,  0,  8,  0 },
    {      1,   16,  113,  0,  8,  0 }, {      0,   16,  112,  0,  8,  0 }, {      0,   16,  111,  0,  8,  0 }, {     -1,   16,  110,  0,  8,  0 }, {     -1,   16,  109,  0,  8,  0 },
    {     -2,   16,  108,  0,  8,  0 }, {     -2,   16,  107,  0,  8,  0 }, {     -3,   16,  106,  0,  8,  0 }, {     -3,   16,  105,  0,  8,  0 }, {     -4,   16,  104,  0,  8,  0 },
    {     -4,   16,  103,  0,  8,  0 }, {     -5,   16,  102,  0,  8,  0 }, {     -6,   16,  101,  0,  8,  0 }, {     -6,   16,  100,  0,  8,  0 }, {     -7,   16,   99,  0,  8,  0 },
    {     -7,   16,   98,  0,  8,  0 }, {     -8,   16,   97,  0,  8,  0 }, {     -8,   16,   96,  0,  8,  0 }, {     -9,   16,   95,  0,  8,  0 }, {    -10,   16,   94,  0,  8,  0 },
    {    -10,   16,   93,  0,  8,  0 }, {    -11,   16,   92,  0,  8,  0 }, {    -12,   16,   91,  0,  8,  0 }, {    -12,   16,   90,  0,  7,  0 }, {    -13,   16,   89,  0,  7,  0 },
    {    -13,   16,   88,  0,  7,  0 }, {    -14,   16,   87,  0,  7,  0 }, {    -15,   16,   86,  0,  7,  0 }, {    -15,   16,   85,  0,  7,  0 }, {    -16,   16,   84,  0,  7,  0 },
    {    -17,   16,   83,  0,  7,  0 }, {    -18,   16,   82,  0,  7,  0 }, {    -18,   16,   81,  0,  7,  0 }, {    -19,   16,   80,  0,  7,  0 }, {    -20,   16,   79,  0,  7,  0 },
    {    -20,   16,   78,  0,  7,  0 }, {    -21,   16,   77,  0,  7,  0 }, {    -22,   16,   76,  0,  7,  0 }, {    -23,   16,   75,  0,  7,  0 }, {    -23,   16,   74,  0,  7,  0 },
    {    -24,   16,   73,  0,  7,  0 }, {    -25,   16,   72,  0,  7,  0 }, {    -26,   16,   71,  0,  7,  0 }, {    -27,   16,   70,  0,  7,  0 }, {    -27,   16,   69,  0,  7,  0 },
    {    -28,   16,   68,  0,  7,  0 }, {    -29,   16,   67,  0,  7,  0 }, {    -30,   16,   66,  0,  7,  0 }, {    -31,   16,   65,  0,  7,  0 }, {    -32,   16,   64,  0,  7,  0 },
    {    -32,   16,   63,  0,  7,  0 }, {    -33,   16,   62,  0,  7,  0 }, {    -34,   16,   61,  0,  7,  0 }, {    -35,   16,   60,  0,  7,  0 }, {    -36,   16,   59,  0,  7,  0 },
    {    -37,   16,   58,  0,  7,  0 }, {    -38,   16,   57,  0,  7,  0 }, {    -39,   16,   56,  0,  7,  0 }, {    -40,   16,   55,  0,  7,  0 }, {    -41,   16,   54,  0,  7,  0 },
    {    -42,   16,   53,  0,  7,  0 }, {    -43,   16,   52,  0,  7,  0 }, {    -44,   16,   51,  0,  7,  0 }, {    -45,   16,   50,  0,  7,  0 }, {    -46,   16,   49,  0,  7,  0 },
    {    -47,   16,   48,  0,  7,  0 }, {    -48,   16,   47,  0,  7,  0 }, {    -49,   16,   46,  0,  7,  0 }, {    -50,   16,   45,  0,  7,  0 }, {    -51,   16,   45,  0,  7,  0 },
    {    -52,   16,   44,  0,  7,  0 }, {    -53,   16,   43,  0,  7,  0 }, {    -54,   16,   42,  0,  7,  0 }, {    -55,   16,   41,  0,  7,  0 }, {    -56,   16,   40,  0,  7,  0 },
    {    -57,   16,   39,  0,  6,  0 }, {    -58,   16,   39,  0,  6,  0 }, {    -59,   16,   38,  0,  6,  0 }, {    -60,   16,   37,  0,  6,  0 }, {    -61,   16,   36,  0,  6,  0 },
    {    -62,   16,   36,  0,  6,  0 }, {    -63,   16,   35,  0,  6,  0 }, {    -64,   16,   34,  0,  6,  0 }, {    -65,   16,   33,  0,  6,  0 }, {    -66,   16,   33,  0,  6,  0 },
    {    -67,   16,   32,  0,  6,  0 }, {    -68,   16,   31,  0,  6,  0 }, {    -69,   16,   31,  0,  6,  0 }, {    -70,   16,   30,  0,  6,  0 }, {    -71,   16,   29,  0,  6,  0 },
    {    -72,   16,   29,  0,  6,  0 }, {    -73,   16,   28,  0,  6,  0 }, {    -74,   16,   27,  0,  6,  0 }, {    -75,   16,   27,  0,  6,  0 }, {    -76,   16,   26,  0,  6,  0 },
    {    -77,   16,   25,  0,  6,  0 }, {    -78,   16,   25,  0,  6,  0 }, {    -79,   16,   24,  0,  6,  0 }, {    -80,   16,   24,  0,  6,  0 }, {    -81,   16,   23,  0,  6,  0 },
    {    -82,   16,   22,  0,  6,  0 }, {    -83,   16,   22,  0,  6,  0 }, {    -84,   16,   21,  0,  6,  0 }, {    -85,   16,   21,  0,  6,  0 }, {    -86,   16,   20,  0,  6,  0 },
    {    -87,   16,   20,  0,  6,  0 }, {    -88,   16,   19,  0,  6,  0 }, {    -89,   16,   19,  0,  6,  0 }, {    -90,   16,   18,  0,  6,  0 }, {    -91,   16,   18,  0,  6,  0 },
    {    -92,   16,   17,  0,  6,  0 }, {    -93,   16,   17,  0,  6,  0 }, {    -94,   16,   16,  0,  6,  0 }, {    -95,   16,   16,  0,  6,  0 }, {    -96,   16,   15,  0,  6,  0 },
    {    -97,   16,   15,  0,  6,  0 }, {    -98,   16,   14,  0,  6,  0 }, {    -99,   16,   14,  0,  6,  0 }, {   -100,   16,   13,  0,  6,  0 }, {   -101,   16,   13,  0,  6,  0 },
    {   -102,   16,   13,  0,  6,  0 }, {   -103,   16,   12,  0,  6,  0 }, {   -104,   16,   12,  0,  6,  0 }, {   -105,   16,   11,  0,  5,  0 }, {   -106,   16,   11,  0,  5,  0 },
    {   -107,   16,   11,  0,  5,  0 }, {   -108,   16,   10,  0,  5,  0 }, {   -109,   16,   10,  0,  5,  0 }, {   -110,   16,   10,  0,  5,  0 }, {   -111,   16,    9,  0,  5,  0 },
    {   -112,   16,    9,  0,  5,  0 }, {   -113,   16,    9,  0,  5,  0 }, {   -114,   16,    8,  0,  5,  0 }, {   -115,   16,    8,  0,  5,  0 }, {   -116,   16,    8,  0,  5,  0 },
    {   -117,   16,    7,  0,  5,  0 }, {   -118,   16,    7,  0,  5,  0 }, {   -119,   16,    7,  0,  5,  0 }, {   -120,   16,    6,  0,  5,  0 }, {   -121,   16,    6,  0,  5,  0 },
    {   -122,   16,    6,  0,  5,  0 }, {   -123,   16,    6,  0,  5,  0 }, {   -124,   16,    5,  0,  5,  0 }, {   -125,   16,    5,  0,  5,  0 }, {   -126,   16,    5,  0,  5,  0 },
    {   -127,   16,    5,  0,  5,  0 }, {   -128,   16,    4,  0,  5,  0 }, {   -129,   16,    4,  0,  5,  0 }, {   -130,   16,    4,  0,  5,  0 }, {   -131,   16,    4,  0,  5,  0 },
    {   -132,   16,    3,  0,  5,  0 }, {   -133,   16,    3,  0,  5,  0 }, {   -134,   16,    3,  0,  5,  0 }, {   -135,   16,    3,  0,  5,  0 }, {   -136,   16,    3,  0,  5,  0 },
    {   -137,   16,    2,  0,  5,  0 }, {   -138,   16,    2,  0,  5,  0 }, {   -139,   16,    2,  0,  5,  0 }, {   -140,   16,    2,  0,  5,  0 }, {   -141,   16,    2,  0,  5,  0 },
    {   -142,   16,    2,  0,  0,  0 }, {   -143,   16,    2,  0,  0,  0 }, {   -144,   16,    1,  0,  0,  0 }, {   -145,   16,    1,  0,  0,  0 }, {   -146,   16,    1,  0,  0,  0 },
    {   -147,   16,    1,  0,  0,  0 }, {   -148,   16,    1,  0,  0,  0 }, {   -149,   16,    1,  0,  0,  0 }, {   -150,   16,    1,  0,  0,  0 }, {   -151,   16,    1,  0,  0,  0 },
    {   -152,   16,    1,  0,  0,  0 }, {   -153,   16,    0,  0,  0,  0 }, {   -154,   16,    0,  0,  0,  0 }, {   -155,   16,    0,  0,  0,  0 }, {   -156,   16,    0,  0,  0,  0 },
    {   -157,   16,    0,  0,  0,  0 }, {   -158,   16,    0,  0,  0,  0 }, {   -159,   16,    0,  0,  0,  0 }, {   -160,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_909974, {
    {     16,    5,  239,  8, 18,  0 }, {     16,    5,  238,  8, 18,  0 }, {     16,    5,  237,  8, 18,  0 }, {     16,    5,  236,  8, 18,  0 }, {     16,    5,  235,  8, 18,  0 },
    {     16,    5,  234,  8, 18,  0 }, {     16,    5,  233,  8, 18,  0 }, {     16,    5,  232,  8, 18,  0 }, {     16,    5,  231,  8, 18,  0 }, {     16,    5,  229,  8, 18,  0 },
    {     16,    5,  228,  8, 18,  0 }, {     16,    5,  227,  8, 18,  0 }, {     16,    5,  226,  8, 18,  0 }, {     16,    5,  225,  8, 18,  0 }, {     16,    5,  224,  8, 18,  0 },
    {     16,    5,  223,  8, 18,  0 }, {     16,    5,  222,  8, 18,  0 }, {     16,    5,  221,  8, 18,  0 }, {     16,    5,  220,  8, 18,  0 }, {     16,    5,  219,  8, 18,  0 },
    {     16,    5,  218,  8, 18,  0 }, {     16,    5,  217,  8, 18,  0 }, {     16,    5,  216,  8, 18,  0 }, {     16,    5,  215,  8, 18,  0 }, {     16,    5,  214,  8, 18,  0 },
    {     16,    5,  213,  8, 18,  0 }, {     16,    5,  212,  8, 18,  0 }, {     16,    6,  211,  8, 18,  0 }, {     16,    6,  210,  8, 18,  0 }, {     16,    6,  209,  8, 18,  0 },
    {     16,    6,  208,  8, 18,  0 }, {     16,    6,  207,  8, 18,  0 }, {     16,    6,  206,  8, 18,  0 }, {     16,    6,  205,  8, 18,  0 }, {     16,    6,  204,  8, 18,  0 },
    {     16,    6,  203,  8, 18,  0 }, {     16,    6,  202,  8, 18,  0 }, {     16,    6,  201,  8, 18,  0 }, {     16,    6,  200,  8, 18,  0 }, {     16,    7,  199,  8, 18,  0 },
    {     16,    7,  198,  8, 18,  0 }, {     16,    7,  197,  8, 18,  0 }, {     16,    7,  196,  8, 18,  0 }, {     16,    7,  195,  8, 18,  0 }, {     16,    7,  194,  8, 18,  0 },
    {     16,    7,  193,  8, 18,  0 }, {     16,    7,  192,  8, 18,  0 }, {     16,    8,  191,  8, 18,  0 }, {     16,    8,  190,  8, 18,  0 }, {     16,    8,  189,  8, 18,  0 },
    {     16,    8,  188,  8, 17,  0 }, {     16,    8,  187,  8, 17,  0 }, {     16,    8,  186,  8, 17,  0 }, {     16,    8,  185,  8, 17,  0 }, {     16,    9,  184,  8, 17,  0 },
    {     16,    9,  183,  8, 17,  0 }, {     16,    9,  182,  8, 17,  0 }, {     16,    9,  181,  8, 17,  0 }, {     16,    9,  180,  8, 17,  0 }, {     16,    9,  179,  8, 17,  0 },
    {     16,   10,  178,  8, 17,  0 }, {     16,   10,  177,  8, 17,  0 }, {     16,   10,  176,  8, 17,  0 }, {     16,   10,  175,  8, 17,  0 }, {     16,   10,  174,  8, 17,  0 },
    {     16,   11,  173,  8, 17,  0 }, {     16,   11,  172,  8, 17,  0 }, {     16,   11,  171,  8, 17,  0 }, {     16,   11,  170,  8, 17,  0 }, {     16,   12,  169,  8, 17,  0 },
    {     16,   12,  168,  8, 17,  0 }, {     16,   12,  167,  8, 17,  0 }, {     16,   12,  166,  8, 17,  0 }, {     16,   12,  165,  8, 17,  0 }, {     16,   13,  164,  8, 17,  0 },
    {     16,   13,  163,  8, 17,  0 }, {     16,   13,  162,  8, 17,  0 }, {     16,   13,  161,  8, 17,  0 }, {     16,   14,  160,  8, 17,  0 }, {     16,   14,  159,  8, 17,  0 },
    {     16,   14,  158,  8, 17,  0 }, {     16,   15,  157,  8, 17,  0 }, {     16,   15,  156,  8, 17,  0 }, {     16,   15,  155,  8, 17,  0 }, {     16,   15,  154,  8, 17,  0 },
    {     16,   16,  153,  8, 17,  0 }, {     16,   16,  152,  8, 17,  0 }, {     16,   16,  151,  8, 17,  0 }, {     16,   17,  150,  8, 17,  0 }, {     16,   17,  149,  8, 17,  0 },
    {     16,   17,  148,  8, 17,  0 }, {     16,   18,  147,  8, 17,  0 }, {     16,   18,  146,  8, 17,  0 }, {     16,   18,  145,  8, 17,  0 }, {     16,   19,  144,  8, 17,  0 },
    {     16,   19,  143,  8, 17,  0 }, {     16,   19,  142,  8, 17,  0 }, {     16,   20,  141,  8, 17,  0 }, {     16,   20,  140,  8, 17,  0 }, {     16,   20,  139,  8, 17,  0 },
    {     16,   21,  138,  8, 17,  0 }, {     16,   21,  137,  8, 17,  0 }, {     16,   21,  136,  8, 17,  0 }, {     16,   22,  135,  8,  8,  0 }, {     16,   22,  134,  8,  8,  0 },
    {     16,   22,  133,  8,  8,  0 }, {     16,   23,  132,  8,  8,  0 }, {     16,   23,  131,  8,  8,  0 }, {     16,   24,  130,  8,  8,  0 }, {     16,   24,  129,  8,  8,  0 },
    {     16,   24,  128,  8,  8,  0 }, {     16,   25,  127,  8,  8,  0 }, {     16,   25,  126,  8,  8,  0 }, {     16,   26,  125,  8,  8,  0 }, {     16,   26,  124,  8,  8,  0 },
    {     16,   27,  123,  8,  8,  0 }, {     16,   27,  122,  8,  8,  0 }, {     16,   27,  121,  8,  8,  0 }, {     16,   28,  120,  8,  8,  0 }, {     16,   28,  119,  8,  8,  0 },
    {     16,   29,  118,  8,  8,  0 }, {     16,   29,  117,  8,  8,  0 }, {     16,   30,  116,  8,  8,  0 }, {     16,   30,  115,  8,  8,  0 }, {     16,   31,  114,  8,  8,  0 },
    {     16,   31,  113,  8,  8,  0 }, {     16,   32,  112,  8,  8,  0 }, {     16,   32,  111,  8,  8,  0 }, {     16,   33,  110,  8,  8,  0 }, {     16,   33,  109,  8,  8,  0 },
    {     16,   34,  108,  8,  8,  0 }, {     16,   34,  107,  8,  8,  0 }, {     16,   35,  106,  8,  8,  0 }, {     16,   35,  105,  8,  8,  0 }, {     16,   36,  104,  8,  8,  0 },
    {     16,   36,  103,  8,  8,  0 }, {     16,   37,  102,  8,  8,  0 }, {     16,   38,  101,  8,  8,  0 }, {     16,   38,  100,  8,  8,  0 }, {     16,   39,   99,  8,  8,  0 },
    {     16,   39,   98,  8,  8,  0 }, {     16,   40,   97,  8,  8,  0 }, {     16,   40,   96,  8,  8,  0 }, {     16,   41,   95,  8,  8,  0 }, {     16,   42,   94,  8,  8,  0 },
    {     16,   42,   93,  8,  8,  0 }, {     16,   43,   92,  8,  8,  0 }, {     16,   44,   91,  8,  8,  0 }, {     16,   44,   90,  8,  7,  0 }, {     16,   45,   89,  8,  7,  0 },
    {     16,   45,   88,  8,  7,  0 }, {     16,   46,   87,  8,  7,  0 }, {     16,   47,   86,  8,  7,  0 }, {     16,   47,   85,  8,  7,  0 }, {     16,   48,   84,  8,  7,  0 },
    {     16,   49,   83,  8,  7,  0 }, {     16,   50,   82,  8,  7,  0 }, {     16,   50,   81,  8,  7,  0 }, {     16,   51,   80,  8,  7,  0 }, {     16,   52,   79,  8,  7,  0 },
    {     16,   52,   78,  8,  7,  0 }, {     16,   53,   77,  8,  7,  0 }, {     16,   54,   76,  8,  7,  0 }, {     16,   55,   75,  8,  7,  0 }, {     16,   55,   74,  8,  7,  0 },
    {     16,   56,   73,  8,  7,  0 }, {     16,   57,   72,  8,  7,  0 }, {     16,   58,   71,  8,  7,  0 }, {     16,   59,   70,  8,  7,  0 }, {     16,   59,   69,  8,  7,  0 },
    {     16,   60,   68,  8,  7,  0 }, {     16,   61,   67,  8,  7,  0 }, {     16,   62,   66,  8,  7,  0 }, {     16,   63,   65,  8,  7,  0 }, {     16,   64,   64,  8,  7,  0 },
    {     16,   64,   63,  8,  7,  0 }, {     16,   65,   62,  8,  7,  0 }, {     16,   66,   61,  8,  7,  0 }, {     16,   67,   60,  8,  7,  0 }, {     16,   68,   59,  8,  7,  0 },
    {     16,   69,   58,  8,  7,  0 }, {     16,   70,   57,  8,  7,  0 }, {     16,   71,   56,  8,  7,  0 }, {     16,   72,   55,  8,  7,  0 }, {     16,   73,   54,  8,  7,  0 },
    {     16,   74,   53,  8,  7,  0 }, {     16,   75,   52,  8,  7,  0 }, {     16,   76,   51,  8,  7,  0 }, {     16,   77,   50,  8,  7,  0 }, {     16,   78,   49,  8,  7,  0 },
    {     16,   79,   48,  8,  7,  0 }, {     16,   80,   47,  8,  7,  0 }, {     16,   81,   46,  8,  7,  0 }, {     16,   82,   45,  8,  7,  0 }, {     16,   83,   45,  8,  7,  0 },
    {     16,   84,   44,  8,  7,  0 }, {     16,   85,   43,  8,  7,  0 }, {     16,   86,   42,  8,  7,  0 }, {     16,   87,   41,  8,  7,  0 }, {     16,   88,   40,  8,  7,  0 },
    {     16,   89,   39,  8,  6,  0 }, {     16,   90,   39,  8,  6,  0 }, {     16,   91,   38,  8,  6,  0 }, {     16,   92,   37,  8,  6,  0 }, {     16,   93,   36,  8,  6,  0 },
    {     16,   94,   36,  8,  6,  0 }, {     16,   95,   35,  8,  6,  0 }, {     16,   96,   34,  8,  6,  0 }, {     16,   97,   33,  8,  6,  0 }, {     16,   98,   33,  8,  6,  0 },
    {     16,   99,   32,  8,  6,  0 }, {     16,  100,   31,  8,  6,  0 }, {     16,  101,   31,  8,  6,  0 }, {     16,  102,   30,  8,  6,  0 }, {     16,  103,   29,  8,  6,  0 },
    {     16,  104,   29,  8,  6,  0 }, {     16,  105,   28,  8,  6,  0 }, {     16,  106,   27,  8,  6,  0 }, {     16,  107,   27,  8,  6,  0 }, {     16,  108,   26,  8,  6,  0 },
    {     16,  109,   25,  8,  6,  0 }, {     16,  110,   25,  8,  6,  0 }, {     16,  111,   24,  8,  6,  0 }, {     16,  112,   24,  8,  6,  0 }, {     16,  113,   23,  8,  6,  0 },
    {     16,  114,   22,  8,  6,  0 }, {     16,  115,   22,  8,  6,  0 }, {     16,  116,   21,  8,  6,  0 }, {     16,  117,   21,  8,  6,  0 }, {     16,  118,   20,  8,  6,  0 },
    {     16,  119,   20,  8,  6,  0 }, {     16,  120,   19,  8,  6,  0 }, {     16,  121,   19,  8,  6,  0 }, {     16,  122,   18,  8,  6,  0 }, {     16,  123,   18,  8,  6,  0 },
    {     16,  124,   17,  8,  6,  0 }, {     16,  125,   17,  8,  6,  0 }, {     16,  126,   16,  8,  6,  0 }, {     16,  127,   16,  8,  6,  0 }, {     16,  128,   15,  8,  6,  0 },
    {     16,  129,   15,  8,  6,  0 }, {     16,  130,   14,  8,  6,  0 }, {     16,  131,   14,  8,  6,  0 }, {     16,  132,   13,  8,  6,  0 }, {     16,  133,   13,  8,  6,  0 },
    {     16,  134,   13,  8,  6,  0 }, {     16,  135,   12,  8,  6,  0 }, {     16,  136,   12,  8,  6,  0 }, {     16,  137,   11,  8,  5,  0 }, {     16,  138,   11,  8,  5,  0 },
    {     16,  139,   11,  8,  5,  0 }, {     16,  140,   10,  8,  5,  0 }, {     16,  141,   10,  8,  5,  0 }, {     16,  142,   10,  8,  5,  0 }, {     16,  143,    9,  8,  5,  0 },
    {     16,  144,    9,  8,  5,  0 }, {     16,  145,    9,  8,  5,  0 }, {     16,  146,    8,  8,  5,  0 }, {     16,  147,    8,  8,  5,  0 }, {     16,  148,    8,  8,  5,  0 },
    {     16,  149,    7,  8,  5,  0 }, {     16,  150,    7,  8,  5,  0 }, {     16,  151,    7,  8,  5,  0 }, {     16,  152,    6,  8,  5,  0 }, {     16,  153,    6,  8,  5,  0 },
    {     16,  154,    6,  8,  5,  0 }, {     16,  155,    6,  8,  5,  0 }, {     16,  156,    5,  8,  5,  0 }, {     16,  157,    5,  8,  5,  0 }, {     16,  158,    5,  8,  5,  0 },
    {     16,  159,    5,  8,  5,  0 }, {     16,  160,    4,  8,  5,  0 }, {     16,  161,    4,  8,  5,  0 }, {     16,  162,    4,  8,  5,  0 }, {     16,  163,    4,  8,  5,  0 },
    {     16,  164,    3,  8,  5,  0 }, {     16,  165,    3,  8,  5,  0 }, {     16,  166,    3,  8,  5,  0 }, {     16,  167,    3,  8,  5,  0 }, {     16,  168,    3,  8,  5,  0 },
    {     16,  169,    2,  8,  5,  0 }, {     16,  170,    2,  8,  5,  0 }, {     16,  171,    2,  8,  5,  0 }, {     16,  172,    2,  8,  5,  0 }, {     16,  173,    2,  8,  5,  0 },
    {     16,  174,    2,  8,  0,  0 }, {     16,  175,    2,  8,  0,  0 }, {     16,  176,    1,  8,  0,  0 }, {     16,  177,    1,  8,  0,  0 }, {     16,  178,    1,  8,  0,  0 },
    {     16,  179,    1,  8,  0,  0 }, {     16,  180,    1,  8,  0,  0 }, {     16,  181,    1,  8,  0,  0 }, {     16,  182,    1,  8,  0,  0 }, {     16,  183,    1,  8,  0,  0 },
    {     16,  184,    1,  8,  0,  0 }, {     16,  185,    0,  8,  0,  0 }, {     16,  186,    0,  8,  0,  0 }, {     16,  187,    0,  8,  0,  0 }, {     16,  188,    0,  8,  0,  0 },
    {     16,  189,    0,  8,  0,  0 }, {     16,  190,    0,  8,  0,  0 }, {     16,  191,    0,  8,  0,  0 }, {     16,  192,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90A426, {
    {      5,   16,  239, 16, 18,  0 }, {      5,   16,  238, 16, 18,  0 }, {      5,   16,  237, 16, 18,  0 }, {      5,   16,  236, 16, 18,  0 }, {      5,   16,  235, 16, 18,  0 },
    {      5,   16,  234, 16, 18,  0 }, {      5,   16,  233, 16, 18,  0 }, {      5,   16,  232, 16, 18,  0 }, {      5,   16,  231, 16, 18,  0 }, {      5,   16,  229, 16, 18,  0 },
    {      5,   16,  228, 16, 18,  0 }, {      5,   16,  227, 16, 18,  0 }, {      5,   16,  226, 16, 18,  0 }, {      5,   16,  225, 16, 18,  0 }, {      5,   16,  224, 16, 18,  0 },
    {      5,   16,  223, 16, 18,  0 }, {      5,   16,  222, 16, 18,  0 }, {      5,   16,  221, 16, 18,  0 }, {      5,   16,  220, 16, 18,  0 }, {      5,   16,  219, 16, 18,  0 },
    {      5,   16,  218, 16, 18,  0 }, {      5,   16,  217, 16, 18,  0 }, {      5,   16,  216, 16, 18,  0 }, {      5,   16,  215, 16, 18,  0 }, {      5,   16,  214, 16, 18,  0 },
    {      5,   16,  213, 16, 18,  0 }, {      5,   16,  212, 16, 18,  0 }, {      6,   16,  211, 16, 18,  0 }, {      6,   16,  210, 16, 18,  0 }, {      6,   16,  209, 16, 18,  0 },
    {      6,   16,  208, 16, 18,  0 }, {      6,   16,  207, 16, 18,  0 }, {      6,   16,  206, 16, 18,  0 }, {      6,   16,  205, 16, 18,  0 }, {      6,   16,  204, 16, 18,  0 },
    {      6,   16,  203, 16, 18,  0 }, {      6,   16,  202, 16, 18,  0 }, {      6,   16,  201, 16, 18,  0 }, {      6,   16,  200, 16, 18,  0 }, {      7,   16,  199, 16, 18,  0 },
    {      7,   16,  198, 16, 18,  0 }, {      7,   16,  197, 16, 18,  0 }, {      7,   16,  196, 16, 18,  0 }, {      7,   16,  195, 16, 18,  0 }, {      7,   16,  194, 16, 18,  0 },
    {      7,   16,  193, 16, 18,  0 }, {      7,   16,  192, 16, 18,  0 }, {      8,   16,  191, 16, 18,  0 }, {      8,   16,  190, 16, 18,  0 }, {      8,   16,  189, 16, 18,  0 },
    {      8,   16,  188, 16, 17,  0 }, {      8,   16,  187, 16, 17,  0 }, {      8,   16,  186, 16, 17,  0 }, {      8,   16,  185, 16, 17,  0 }, {      9,   16,  184, 16, 17,  0 },
    {      9,   16,  183, 16, 17,  0 }, {      9,   16,  182, 16, 17,  0 }, {      9,   16,  181, 16, 17,  0 }, {      9,   16,  180, 16, 17,  0 }, {      9,   16,  179, 16, 17,  0 },
    {     10,   16,  178, 16, 17,  0 }, {     10,   16,  177, 16, 17,  0 }, {     10,   16,  176, 16, 17,  0 }, {     10,   16,  175, 16, 17,  0 }, {     10,   16,  174, 16, 17,  0 },
    {     11,   16,  173, 16, 17,  0 }, {     11,   16,  172, 16, 17,  0 }, {     11,   16,  171, 16, 17,  0 }, {     11,   16,  170, 16, 17,  0 }, {     12,   16,  169, 16, 17,  0 },
    {     12,   16,  168, 16, 17,  0 }, {     12,   16,  167, 16, 17,  0 }, {     12,   16,  166, 16, 17,  0 }, {     12,   16,  165, 16, 17,  0 }, {     13,   16,  164, 16, 17,  0 },
    {     13,   16,  163, 16, 17,  0 }, {     13,   16,  162, 16, 17,  0 }, {     13,   16,  161, 16, 17,  0 }, {     14,   16,  160, 16, 17,  0 }, {     14,   16,  159, 16, 17,  0 },
    {     14,   16,  158, 16, 17,  0 }, {     15,   16,  157, 16, 17,  0 }, {     15,   16,  156, 16, 17,  0 }, {     15,   16,  155, 16, 17,  0 }, {     15,   16,  154, 16, 17,  0 },
    {     16,   16,  153, 16, 17,  0 }, {     16,   16,  152, 16, 17,  0 }, {     16,   16,  151, 16, 17,  0 }, {     17,   16,  150, 16, 17,  0 }, {     17,   16,  149, 16, 17,  0 },
    {     17,   16,  148, 16, 17,  0 }, {     18,   16,  147, 16, 17,  0 }, {     18,   16,  146, 16, 17,  0 }, {     18,   16,  145, 16, 17,  0 }, {     19,   16,  144, 16, 17,  0 },
    {     19,   16,  143, 16, 17,  0 }, {     19,   16,  142, 16, 17,  0 }, {     20,   16,  141, 16, 17,  0 }, {     20,   16,  140, 16, 17,  0 }, {     20,   16,  139, 16, 17,  0 },
    {     21,   16,  138, 16, 17,  0 }, {     21,   16,  137, 16, 17,  0 }, {     21,   16,  136, 16, 17,  0 }, {     22,   16,  135, 16,  8,  0 }, {     22,   16,  134, 16,  8,  0 },
    {     22,   16,  133, 16,  8,  0 }, {     23,   16,  132, 16,  8,  0 }, {     23,   16,  131, 16,  8,  0 }, {     24,   16,  130, 16,  8,  0 }, {     24,   16,  129, 16,  8,  0 },
    {     24,   16,  128, 16,  8,  0 }, {     25,   16,  127, 16,  8,  0 }, {     25,   16,  126, 16,  8,  0 }, {     26,   16,  125, 16,  8,  0 }, {     26,   16,  124, 16,  8,  0 },
    {     27,   16,  123, 16,  8,  0 }, {     27,   16,  122, 16,  8,  0 }, {     27,   16,  121, 16,  8,  0 }, {     28,   16,  120, 16,  8,  0 }, {     28,   16,  119, 16,  8,  0 },
    {     29,   16,  118, 16,  8,  0 }, {     29,   16,  117, 16,  8,  0 }, {     30,   16,  116, 16,  8,  0 }, {     30,   16,  115, 16,  8,  0 }, {     31,   16,  114, 16,  8,  0 },
    {     31,   16,  113, 16,  8,  0 }, {     32,   16,  112, 16,  8,  0 }, {     32,   16,  111, 16,  8,  0 }, {     33,   16,  110, 16,  8,  0 }, {     33,   16,  109, 16,  8,  0 },
    {     34,   16,  108, 16,  8,  0 }, {     34,   16,  107, 16,  8,  0 }, {     35,   16,  106, 16,  8,  0 }, {     35,   16,  105, 16,  8,  0 }, {     36,   16,  104, 16,  8,  0 },
    {     36,   16,  103, 16,  8,  0 }, {     37,   16,  102, 16,  8,  0 }, {     38,   16,  101, 16,  8,  0 }, {     38,   16,  100, 16,  8,  0 }, {     39,   16,   99, 16,  8,  0 },
    {     39,   16,   98, 16,  8,  0 }, {     40,   16,   97, 16,  8,  0 }, {     40,   16,   96, 16,  8,  0 }, {     41,   16,   95, 16,  8,  0 }, {     42,   16,   94, 16,  8,  0 },
    {     42,   16,   93, 16,  8,  0 }, {     43,   16,   92, 16,  8,  0 }, {     44,   16,   91, 16,  8,  0 }, {     44,   16,   90, 16,  7,  0 }, {     45,   16,   89, 16,  7,  0 },
    {     45,   16,   88, 16,  7,  0 }, {     46,   16,   87, 16,  7,  0 }, {     47,   16,   86, 16,  7,  0 }, {     47,   16,   85, 16,  7,  0 }, {     48,   16,   84, 16,  7,  0 },
    {     49,   16,   83, 16,  7,  0 }, {     50,   16,   82, 16,  7,  0 }, {     50,   16,   81, 16,  7,  0 }, {     51,   16,   80, 16,  7,  0 }, {     52,   16,   79, 16,  7,  0 },
    {     52,   16,   78, 16,  7,  0 }, {     53,   16,   77, 16,  7,  0 }, {     54,   16,   76, 16,  7,  0 }, {     55,   16,   75, 16,  7,  0 }, {     55,   16,   74, 16,  7,  0 },
    {     56,   16,   73, 16,  7,  0 }, {     57,   16,   72, 16,  7,  0 }, {     58,   16,   71, 16,  7,  0 }, {     59,   16,   70, 16,  7,  0 }, {     59,   16,   69, 16,  7,  0 },
    {     60,   16,   68, 16,  7,  0 }, {     61,   16,   67, 16,  7,  0 }, {     62,   16,   66, 16,  7,  0 }, {     63,   16,   65, 16,  7,  0 }, {     64,   16,   64, 16,  7,  0 },
    {     64,   16,   63, 16,  7,  0 }, {     65,   16,   62, 16,  7,  0 }, {     66,   16,   61, 16,  7,  0 }, {     67,   16,   60, 16,  7,  0 }, {     68,   16,   59, 16,  7,  0 },
    {     69,   16,   58, 16,  7,  0 }, {     70,   16,   57, 16,  7,  0 }, {     71,   16,   56, 16,  7,  0 }, {     72,   16,   55, 16,  7,  0 }, {     73,   16,   54, 16,  7,  0 },
    {     74,   16,   53, 16,  7,  0 }, {     75,   16,   52, 16,  7,  0 }, {     76,   16,   51, 16,  7,  0 }, {     77,   16,   50, 16,  7,  0 }, {     78,   16,   49, 16,  7,  0 },
    {     79,   16,   48, 16,  7,  0 }, {     80,   16,   47, 16,  7,  0 }, {     81,   16,   46, 16,  7,  0 }, {     82,   16,   45, 16,  7,  0 }, {     83,   16,   45, 16,  7,  0 },
    {     84,   16,   44, 16,  7,  0 }, {     85,   16,   43, 16,  7,  0 }, {     86,   16,   42, 16,  7,  0 }, {     87,   16,   41, 16,  7,  0 }, {     88,   16,   40, 16,  7,  0 },
    {     89,   16,   39, 16,  6,  0 }, {     90,   16,   39, 16,  6,  0 }, {     91,   16,   38, 16,  6,  0 }, {     92,   16,   37, 16,  6,  0 }, {     93,   16,   36, 16,  6,  0 },
    {     94,   16,   36, 16,  6,  0 }, {     95,   16,   35, 16,  6,  0 }, {     96,   16,   34, 16,  6,  0 }, {     97,   16,   33, 16,  6,  0 }, {     98,   16,   33, 16,  6,  0 },
    {     99,   16,   32, 16,  6,  0 }, {    100,   16,   31, 16,  6,  0 }, {    101,   16,   31, 16,  6,  0 }, {    102,   16,   30, 16,  6,  0 }, {    103,   16,   29, 16,  6,  0 },
    {    104,   16,   29, 16,  6,  0 }, {    105,   16,   28, 16,  6,  0 }, {    106,   16,   27, 16,  6,  0 }, {    107,   16,   27, 16,  6,  0 }, {    108,   16,   26, 16,  6,  0 },
    {    109,   16,   25, 16,  6,  0 }, {    110,   16,   25, 16,  6,  0 }, {    111,   16,   24, 16,  6,  0 }, {    112,   16,   24, 16,  6,  0 }, {    113,   16,   23, 16,  6,  0 },
    {    114,   16,   22, 16,  6,  0 }, {    115,   16,   22, 16,  6,  0 }, {    116,   16,   21, 16,  6,  0 }, {    117,   16,   21, 16,  6,  0 }, {    118,   16,   20, 16,  6,  0 },
    {    119,   16,   20, 16,  6,  0 }, {    120,   16,   19, 16,  6,  0 }, {    121,   16,   19, 16,  6,  0 }, {    122,   16,   18, 16,  6,  0 }, {    123,   16,   18, 16,  6,  0 },
    {    124,   16,   17, 16,  6,  0 }, {    125,   16,   17, 16,  6,  0 }, {    126,   16,   16, 16,  6,  0 }, {    127,   16,   16, 16,  6,  0 }, {    128,   16,   15, 16,  6,  0 },
    {    129,   16,   15, 16,  6,  0 }, {    130,   16,   14, 16,  6,  0 }, {    131,   16,   14, 16,  6,  0 }, {    132,   16,   13, 16,  6,  0 }, {    133,   16,   13, 16,  6,  0 },
    {    134,   16,   13, 16,  6,  0 }, {    135,   16,   12, 16,  6,  0 }, {    136,   16,   12, 16,  6,  0 }, {    137,   16,   11, 16,  5,  0 }, {    138,   16,   11, 16,  5,  0 },
    {    139,   16,   11, 16,  5,  0 }, {    140,   16,   10, 16,  5,  0 }, {    141,   16,   10, 16,  5,  0 }, {    142,   16,   10, 16,  5,  0 }, {    143,   16,    9, 16,  5,  0 },
    {    144,   16,    9, 16,  5,  0 }, {    145,   16,    9, 16,  5,  0 }, {    146,   16,    8, 16,  5,  0 }, {    147,   16,    8, 16,  5,  0 }, {    148,   16,    8, 16,  5,  0 },
    {    149,   16,    7, 16,  5,  0 }, {    150,   16,    7, 16,  5,  0 }, {    151,   16,    7, 16,  5,  0 }, {    152,   16,    6, 16,  5,  0 }, {    153,   16,    6, 16,  5,  0 },
    {    154,   16,    6, 16,  5,  0 }, {    155,   16,    6, 16,  5,  0 }, {    156,   16,    5, 16,  5,  0 }, {    157,   16,    5, 16,  5,  0 }, {    158,   16,    5, 16,  5,  0 },
    {    159,   16,    5, 16,  5,  0 }, {    160,   16,    4, 16,  5,  0 }, {    161,   16,    4, 16,  5,  0 }, {    162,   16,    4, 16,  5,  0 }, {    163,   16,    4, 16,  5,  0 },
    {    164,   16,    3, 16,  5,  0 }, {    165,   16,    3, 16,  5,  0 }, {    166,   16,    3, 16,  5,  0 }, {    167,   16,    3, 16,  5,  0 }, {    168,   16,    3, 16,  5,  0 },
    {    169,   16,    2, 16,  5,  0 }, {    170,   16,    2, 16,  5,  0 }, {    171,   16,    2, 16,  5,  0 }, {    172,   16,    2, 16,  5,  0 }, {    173,   16,    2, 16,  5,  0 },
    {    174,   16,    2, 16,  0,  0 }, {    175,   16,    2, 16,  0,  0 }, {    176,   16,    1, 16,  0,  0 }, {    177,   16,    1, 16,  0,  0 }, {    178,   16,    1, 16,  0,  0 },
    {    179,   16,    1, 16,  0,  0 }, {    180,   16,    1, 16,  0,  0 }, {    181,   16,    1, 16,  0,  0 }, {    182,   16,    1, 16,  0,  0 }, {    183,   16,    1, 16,  0,  0 },
    {    184,   16,    1, 16,  0,  0 }, {    185,   16,    0, 16,  0,  0 }, {    186,   16,    0, 16,  0,  0 }, {    187,   16,    0, 16,  0,  0 }, {    188,   16,    0, 16,  0,  0 },
    {    189,   16,    0, 16,  0,  0 }, {    190,   16,    0, 16,  0,  0 }, {    191,   16,    0, 16,  0,  0 }, {    192,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90AED8, {
    {     16,   27,  239, 24, 18,  0 }, {     16,   27,  238, 24, 18,  0 }, {     16,   27,  237, 24, 18,  0 }, {     16,   27,  236, 24, 18,  0 }, {     16,   27,  235, 24, 18,  0 },
    {     16,   27,  234, 24, 18,  0 }, {     16,   27,  233, 24, 18,  0 }, {     16,   27,  232, 24, 18,  0 }, {     16,   27,  231, 24, 18,  0 }, {     16,   27,  229, 24, 18,  0 },
    {     16,   27,  228, 24, 18,  0 }, {     16,   27,  227, 24, 18,  0 }, {     16,   27,  226, 24, 18,  0 }, {     16,   27,  225, 24, 18,  0 }, {     16,   27,  224, 24, 18,  0 },
    {     16,   27,  223, 24, 18,  0 }, {     16,   27,  222, 24, 18,  0 }, {     16,   27,  221, 24, 18,  0 }, {     16,   27,  220, 24, 18,  0 }, {     16,   27,  219, 24, 18,  0 },
    {     16,   27,  218, 24, 18,  0 }, {     16,   27,  217, 24, 18,  0 }, {     16,   27,  216, 24, 18,  0 }, {     16,   27,  215, 24, 18,  0 }, {     16,   27,  214, 24, 18,  0 },
    {     16,   27,  213, 24, 18,  0 }, {     16,   27,  212, 24, 18,  0 }, {     16,   26,  211, 24, 18,  0 }, {     16,   26,  210, 24, 18,  0 }, {     16,   26,  209, 24, 18,  0 },
    {     16,   26,  208, 24, 18,  0 }, {     16,   26,  207, 24, 18,  0 }, {     16,   26,  206, 24, 18,  0 }, {     16,   26,  205, 24, 18,  0 }, {     16,   26,  204, 24, 18,  0 },
    {     16,   26,  203, 24, 18,  0 }, {     16,   26,  202, 24, 18,  0 }, {     16,   26,  201, 24, 18,  0 }, {     16,   26,  200, 24, 18,  0 }, {     16,   25,  199, 24, 18,  0 },
    {     16,   25,  198, 24, 18,  0 }, {     16,   25,  197, 24, 18,  0 }, {     16,   25,  196, 24, 18,  0 }, {     16,   25,  195, 24, 18,  0 }, {     16,   25,  194, 24, 18,  0 },
    {     16,   25,  193, 24, 18,  0 }, {     16,   25,  192, 24, 18,  0 }, {     16,   24,  191, 24, 18,  0 }, {     16,   24,  190, 24, 18,  0 }, {     16,   24,  189, 24, 18,  0 },
    {     16,   24,  188, 24, 17,  0 }, {     16,   24,  187, 24, 17,  0 }, {     16,   24,  186, 24, 17,  0 }, {     16,   24,  185, 24, 17,  0 }, {     16,   23,  184, 24, 17,  0 },
    {     16,   23,  183, 24, 17,  0 }, {     16,   23,  182, 24, 17,  0 }, {     16,   23,  181, 24, 17,  0 }, {     16,   23,  180, 24, 17,  0 }, {     16,   23,  179, 24, 17,  0 },
    {     16,   22,  178, 24, 17,  0 }, {     16,   22,  177, 24, 17,  0 }, {     16,   22,  176, 24, 17,  0 }, {     16,   22,  175, 24, 17,  0 }, {     16,   22,  174, 24, 17,  0 },
    {     16,   21,  173, 24, 17,  0 }, {     16,   21,  172, 24, 17,  0 }, {     16,   21,  171, 24, 17,  0 }, {     16,   21,  170, 24, 17,  0 }, {     16,   20,  169, 24, 17,  0 },
    {     16,   20,  168, 24, 17,  0 }, {     16,   20,  167, 24, 17,  0 }, {     16,   20,  166, 24, 17,  0 }, {     16,   20,  165, 24, 17,  0 }, {     16,   19,  164, 24, 17,  0 },
    {     16,   19,  163, 24, 17,  0 }, {     16,   19,  162, 24, 17,  0 }, {     16,   19,  161, 24, 17,  0 }, {     16,   18,  160, 24, 17,  0 }, {     16,   18,  159, 24, 17,  0 },
    {     16,   18,  158, 24, 17,  0 }, {     16,   17,  157, 24, 17,  0 }, {     16,   17,  156, 24, 17,  0 }, {     16,   17,  155, 24, 17,  0 }, {     16,   17,  154, 24, 17,  0 },
    {     16,   16,  153, 24, 17,  0 }, {     16,   16,  152, 24, 17,  0 }, {     16,   16,  151, 24, 17,  0 }, {     16,   15,  150, 24, 17,  0 }, {     16,   15,  149, 24, 17,  0 },
    {     16,   15,  148, 24, 17,  0 }, {     16,   14,  147, 24, 17,  0 }, {     16,   14,  146, 24, 17,  0 }, {     16,   14,  145, 24, 17,  0 }, {     16,   13,  144, 24, 17,  0 },
    {     16,   13,  143, 24, 17,  0 }, {     16,   13,  142, 24, 17,  0 }, {     16,   12,  141, 24, 17,  0 }, {     16,   12,  140, 24, 17,  0 }, {     16,   12,  139, 24, 17,  0 },
    {     16,   11,  138, 24, 17,  0 }, {     16,   11,  137, 24, 17,  0 }, {     16,   11,  136, 24, 17,  0 }, {     16,   10,  135, 24,  8,  0 }, {     16,   10,  134, 24,  8,  0 },
    {     16,   10,  133, 24,  8,  0 }, {     16,    9,  132, 24,  8,  0 }, {     16,    9,  131, 24,  8,  0 }, {     16,    8,  130, 24,  8,  0 }, {     16,    8,  129, 24,  8,  0 },
    {     16,    8,  128, 24,  8,  0 }, {     16,    7,  127, 24,  8,  0 }, {     16,    7,  126, 24,  8,  0 }, {     16,    6,  125, 24,  8,  0 }, {     16,    6,  124, 24,  8,  0 },
    {     16,    5,  123, 24,  8,  0 }, {     16,    5,  122, 24,  8,  0 }, {     16,    5,  121, 24,  8,  0 }, {     16,    4,  120, 24,  8,  0 }, {     16,    4,  119, 24,  8,  0 },
    {     16,    3,  118, 24,  8,  0 }, {     16,    3,  117, 24,  8,  0 }, {     16,    2,  116, 24,  8,  0 }, {     16,    2,  115, 24,  8,  0 }, {     16,    1,  114, 24,  8,  0 },
    {     16,    1,  113, 24,  8,  0 }, {     16,    0,  112, 24,  8,  0 }, {     16,    0,  111, 24,  8,  0 }, {     16,   -1,  110, 24,  8,  0 }, {     16,   -1,  109, 24,  8,  0 },
    {     16,   -2,  108, 24,  8,  0 }, {     16,   -2,  107, 24,  8,  0 }, {     16,   -3,  106, 24,  8,  0 }, {     16,   -3,  105, 24,  8,  0 }, {     16,   -4,  104, 24,  8,  0 },
    {     16,   -4,  103, 24,  8,  0 }, {     16,   -5,  102, 24,  8,  0 }, {     16,   -6,  101, 24,  8,  0 }, {     16,   -6,  100, 24,  8,  0 }, {     16,   -7,   99, 24,  8,  0 },
    {     16,   -7,   98, 24,  8,  0 }, {     16,   -8,   97, 24,  8,  0 }, {     16,   -8,   96, 24,  8,  0 }, {     16,   -9,   95, 24,  8,  0 }, {     16,  -10,   94, 24,  8,  0 },
    {     16,  -10,   93, 24,  8,  0 }, {     16,  -11,   92, 24,  8,  0 }, {     16,  -12,   91, 24,  8,  0 }, {     16,  -12,   90, 24,  7,  0 }, {     16,  -13,   89, 24,  7,  0 },
    {     16,  -13,   88, 24,  7,  0 }, {     16,  -14,   87, 24,  7,  0 }, {     16,  -15,   86, 24,  7,  0 }, {     16,  -15,   85, 24,  7,  0 }, {     16,  -16,   84, 24,  7,  0 },
    {     16,  -17,   83, 24,  7,  0 }, {     16,  -18,   82, 24,  7,  0 }, {     16,  -18,   81, 24,  7,  0 }, {     16,  -19,   80, 24,  7,  0 }, {     16,  -20,   79, 24,  7,  0 },
    {     16,  -20,   78, 24,  7,  0 }, {     16,  -21,   77, 24,  7,  0 }, {     16,  -22,   76, 24,  7,  0 }, {     16,  -23,   75, 24,  7,  0 }, {     16,  -23,   74, 24,  7,  0 },
    {     16,  -24,   73, 24,  7,  0 }, {     16,  -25,   72, 24,  7,  0 }, {     16,  -26,   71, 24,  7,  0 }, {     16,  -27,   70, 24,  7,  0 }, {     16,  -27,   69, 24,  7,  0 },
    {     16,  -28,   68, 24,  7,  0 }, {     16,  -29,   67, 24,  7,  0 }, {     16,  -30,   66, 24,  7,  0 }, {     16,  -31,   65, 24,  7,  0 }, {     16,  -32,   64, 24,  7,  0 },
    {     16,  -32,   63, 24,  7,  0 }, {     16,  -33,   62, 24,  7,  0 }, {     16,  -34,   61, 24,  7,  0 }, {     16,  -35,   60, 24,  7,  0 }, {     16,  -36,   59, 24,  7,  0 },
    {     16,  -37,   58, 24,  7,  0 }, {     16,  -38,   57, 24,  7,  0 }, {     16,  -39,   56, 24,  7,  0 }, {     16,  -40,   55, 24,  7,  0 }, {     16,  -41,   54, 24,  7,  0 },
    {     16,  -42,   53, 24,  7,  0 }, {     16,  -43,   52, 24,  7,  0 }, {     16,  -44,   51, 24,  7,  0 }, {     16,  -45,   50, 24,  7,  0 }, {     16,  -46,   49, 24,  7,  0 },
    {     16,  -47,   48, 24,  7,  0 }, {     16,  -48,   47, 24,  7,  0 }, {     16,  -49,   46, 24,  7,  0 }, {     16,  -50,   45, 24,  7,  0 }, {     16,  -51,   45, 24,  7,  0 },
    {     16,  -52,   44, 24,  7,  0 }, {     16,  -53,   43, 24,  7,  0 }, {     16,  -54,   42, 24,  7,  0 }, {     16,  -55,   41, 24,  7,  0 }, {     16,  -56,   40, 24,  7,  0 },
    {     16,  -57,   39, 24,  6,  0 }, {     16,  -58,   39, 24,  6,  0 }, {     16,  -59,   38, 24,  6,  0 }, {     16,  -60,   37, 24,  6,  0 }, {     16,  -61,   36, 24,  6,  0 },
    {     16,  -62,   36, 24,  6,  0 }, {     16,  -63,   35, 24,  6,  0 }, {     16,  -64,   34, 24,  6,  0 }, {     16,  -65,   33, 24,  6,  0 }, {     16,  -66,   33, 24,  6,  0 },
    {     16,  -67,   32, 24,  6,  0 }, {     16,  -68,   31, 24,  6,  0 }, {     16,  -69,   31, 24,  6,  0 }, {     16,  -70,   30, 24,  6,  0 }, {     16,  -71,   29, 24,  6,  0 },
    {     16,  -72,   29, 24,  6,  0 }, {     16,  -73,   28, 24,  6,  0 }, {     16,  -74,   27, 24,  6,  0 }, {     16,  -75,   27, 24,  6,  0 }, {     16,  -76,   26, 24,  6,  0 },
    {     16,  -77,   25, 24,  6,  0 }, {     16,  -78,   25, 24,  6,  0 }, {     16,  -79,   24, 24,  6,  0 }, {     16,  -80,   24, 24,  6,  0 }, {     16,  -81,   23, 24,  6,  0 },
    {     16,  -82,   22, 24,  6,  0 }, {     16,  -83,   22, 24,  6,  0 }, {     16,  -84,   21, 24,  6,  0 }, {     16,  -85,   21, 24,  6,  0 }, {     16,  -86,   20, 24,  6,  0 },
    {     16,  -87,   20, 24,  6,  0 }, {     16,  -88,   19, 24,  6,  0 }, {     16,  -89,   19, 24,  6,  0 }, {     16,  -90,   18, 24,  6,  0 }, {     16,  -91,   18, 24,  6,  0 },
    {     16,  -92,   17, 24,  6,  0 }, {     16,  -93,   17, 24,  6,  0 }, {     16,  -94,   16, 24,  6,  0 }, {     16,  -95,   16, 24,  6,  0 }, {     16,  -96,   15, 24,  6,  0 },
    {     16,  -97,   15, 24,  6,  0 }, {     16,  -98,   14, 24,  6,  0 }, {     16,  -99,   14, 24,  6,  0 }, {     16, -100,   13, 24,  6,  0 }, {     16, -101,   13, 24,  6,  0 },
    {     16, -102,   13, 24,  6,  0 }, {     16, -103,   12, 24,  6,  0 }, {     16, -104,   12, 24,  6,  0 }, {     16, -105,   11, 24,  5,  0 }, {     16, -106,   11, 24,  5,  0 },
    {     16, -107,   11, 24,  5,  0 }, {     16, -108,   10, 24,  5,  0 }, {     16, -109,   10, 24,  5,  0 }, {     16, -110,   10, 24,  5,  0 }, {     16, -111,    9, 24,  5,  0 },
    {     16, -112,    9, 24,  5,  0 }, {     16, -113,    9, 24,  5,  0 }, {     16, -114,    8, 24,  5,  0 }, {     16, -115,    8, 24,  5,  0 }, {     16, -116,    8, 24,  5,  0 },
    {     16, -117,    7, 24,  5,  0 }, {     16, -118,    7, 24,  5,  0 }, {     16, -119,    7, 24,  5,  0 }, {     16, -120,    6, 24,  5,  0 }, {     16, -121,    6, 24,  5,  0 },
    {     16, -122,    6, 24,  5,  0 }, {     16, -123,    6, 24,  5,  0 }, {     16, -124,    5, 24,  5,  0 }, {     16, -125,    5, 24,  5,  0 }, {     16, -126,    5, 24,  5,  0 },
    {     16, -127,    5, 24,  5,  0 }, {     16, -128,    4, 24,  5,  0 }, {     16, -129,    4, 24,  5,  0 }, {     16, -130,    4, 24,  5,  0 }, {     16, -131,    4, 24,  5,  0 },
    {     16, -132,    3, 24,  5,  0 }, {     16, -133,    3, 24,  5,  0 }, {     16, -134,    3, 24,  5,  0 }, {     16, -135,    3, 24,  5,  0 }, {     16, -136,    3, 24,  5,  0 },
    {     16, -137,    2, 24,  5,  0 }, {     16, -138,    2, 24,  5,  0 }, {     16, -139,    2, 24,  5,  0 }, {     16, -140,    2, 24,  5,  0 }, {     16, -141,    2, 24,  5,  0 },
    {     16, -142,    2, 24,  0,  0 }, {     16, -143,    2, 24,  0,  0 }, {     16, -144,    1, 24,  0,  0 }, {     16, -145,    1, 24,  0,  0 }, {     16, -146,    1, 24,  0,  0 },
    {     16, -147,    1, 24,  0,  0 }, {     16, -148,    1, 24,  0,  0 }, {     16, -149,    1, 24,  0,  0 }, {     16, -150,    1, 24,  0,  0 }, {     16, -151,    1, 24,  0,  0 },
    {     16, -152,    1, 24,  0,  0 }, {     16, -153,    0, 24,  0,  0 }, {     16, -154,    0, 24,  0,  0 }, {     16, -155,    0, 24,  0,  0 }, {     16, -156,    0, 24,  0,  0 },
    {     16, -157,    0, 24,  0,  0 }, {     16, -158,    0, 24,  0,  0 }, {     16, -159,    0, 24,  0,  0 }, {     16, -160,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_960BEE, {
    {     31,   16,    0,  0,  2,  2 }, {     30,   16,    0,  0,  2,  2 }, {     29,   16,    1,  0,  2,  2 }, {     28,   16,    1,  0,  2,  2 }, {     27,   16,    2, 31,  2,  2 },
    {     26,   16,    2, 31,  2,  2 }, {     25,   15,    2, 31,  2,  2 }, {     24,   15,    3, 31,  2,  2 }, {     23,   15,    3, 31,  2,  2 }, {     22,   15,    4, 31,  2,  2 },
    {     21,   15,    4, 31,  2,  2 }, {     20,   15,    4, 31,  2,  2 }, {     19,   14,    5, 31,  2,  2 }, {     18,   14,    5, 30,  2,  2 }, {     17,   14,    6, 30,  2,  2 },
    {     16,   13,    6, 30,  2,  2 }, {     15,   13,    7, 30,  2,  2 }, {     14,   13,    7, 30,  2,  2 }, {     13,   12,    8, 30,  2,  2 }, {     12,   12,    8, 30,  2,  2 },
    {     11,   11,    9, 30,  2,  2 }, {     10,   11,    9, 30,  2,  2 }, {      9,   10,   10, 30,  2,  2 }, {      8,   10,   10, 29,  2,  2 }, {      7,    9,   11, 29,  2,  2 },
    {      6,    9,   11, 29,  2,  2 }, {      5,    8,   11, 29,  2,  2 }, {      4,    7,   12, 29,  2,  2 }, {      3,    7,   13, 29,  2,  2 }, {      2,    6,   13, 29,  2,  2 },
    {      1,    5,   14, 29,  2,  2 }, {      0,    4,   14, 29,  2,  2 }, {     -1,    3,   15, 28,  2,  2 }, {     -3,    3,   15, 28,  2,  2 }, {     -4,    2,   16, 28,  2,  2 },
    {     -5,    1,   16, 28,  2,  2 }, {     -6,    0,   17, 28,  2,  2 }, {     -7,   -1,   17, 27,  2,  2 }, {     -7,   -2,   18, 27,  2,  2 }, {     -8,   -3,   18, 27,  2,  2 },
    {     -9,   -4,   19, 27,  2,  2 }, {     -9,   -5,   19, 27,  2,  2 }, {    -10,   -6,   20, 27,  2,  2 }, {    -10,   -7,   20, 27,  2,  2 }, {    -11,   -8,   21, 27,  2,  2 },
    {    -11,   -9,   21, 27,  2,  2 }, {    -12,  -10,   22, 26,  2,  2 }, {    -12,  -11,   22, 26,  2,  2 }, {    -13,  -12,   23, 26,  2,  2 }, {    -13,  -13,   23, 26,  2,  2 },
    {    -13,  -14,   24, 26,  2,  2 }, {    -14,  -15,   24, 26,  2,  2 }, {    -14,  -16,   25, 26,  2,  2 }, {    -14,  -17,   25, 26,  2,  2 }, {    -15,  -18,   25, 26,  2,  2 },
    {    -15,  -19,   26, 26,  2,  2 }, {    -15,  -20,   26, 25,  2,  2 }, {    -15,  -21,   27, 25,  2,  2 }, {    -15,  -22,   27, 25,  2,  2 }, {    -15,  -23,   28, 25,  2,  2 },
    {    -16,  -24,   28, 25,  2,  2 }, {    -16,  -25,   29, 25,  2,  2 }, {    -16,  -26,   29, 25,  2,  2 }, {    -16,  -27,   29, 25,  2,  2 }, {    -16,  -28,   30, 24,  2,  2 },
    {    -16,  -29,   30, 24,  2,  2 }, {    -16,  -30,   31, 24,  2,  2 }, {    -16,  -31,   31, 24,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_960E54, {
    {     16,    0,    0,  8,  2,  2 }, {     16,    1,    0,  8,  2,  2 }, {     16,    2,    0,  8,  2,  2 }, {     16,    3,    1,  8,  2,  2 }, {     16,    4,    1,  8,  2,  2 },
    {     16,    5,    2,  7,  2,  2 }, {     16,    6,    2,  7,  2,  2 }, {     15,    7,    2,  7,  2,  2 }, {     15,    8,    3,  7,  2,  2 }, {     15,    9,    3,  7,  2,  2 },
    {     15,   10,    4,  7,  2,  2 }, {     15,   11,    4,  7,  2,  2 }, {     15,   12,    4,  7,  2,  2 }, {     14,   13,    5,  7,  2,  2 }, {     14,   14,    5,  6,  2,  2 },
    {     14,   15,    6,  6,  2,  2 }, {     13,   16,    6,  6,  2,  2 }, {     13,   17,    7,  6,  2,  2 }, {     13,   18,    7,  6,  2,  2 }, {     12,   19,    8,  6,  2,  2 },
    {     12,   20,    8,  6,  2,  2 }, {     11,   21,    9,  6,  2,  2 }, {     11,   22,    9,  6,  2,  2 }, {     10,   23,   10,  6,  2,  2 }, {     10,   24,   10,  5,  2,  2 },
    {      9,   25,   11,  5,  2,  2 }, {      9,   26,   11,  5,  2,  2 }, {      8,   27,   11,  5,  2,  2 }, {      7,   28,   12,  5,  2,  2 }, {      7,   29,   13,  5,  2,  2 },
    {      6,   30,   13,  5,  2,  2 }, {      5,   31,   14,  5,  2,  2 }, {      4,   32,   14,  5,  2,  2 }, {      3,   33,   15,  4,  2,  2 }, {      3,   35,   15,  4,  2,  2 },
    {      2,   36,   16,  4,  2,  2 }, {      1,   37,   16,  4,  2,  2 }, {      0,   38,   17,  4,  2,  2 }, {     -1,   39,   17,  3,  2,  2 }, {     -2,   39,   18,  3,  2,  2 },
    {     -3,   40,   18,  3,  2,  2 }, {     -4,   41,   19,  3,  2,  2 }, {     -5,   41,   19,  3,  2,  2 }, {     -6,   42,   20,  3,  2,  2 }, {     -7,   42,   20,  3,  2,  2 },
    {     -8,   43,   21,  3,  2,  2 }, {     -9,   43,   21,  3,  2,  2 }, {    -10,   44,   22,  2,  2,  2 }, {    -11,   44,   22,  2,  2,  2 }, {    -12,   45,   23,  2,  2,  2 },
    {    -13,   45,   23,  2,  2,  2 }, {    -14,   45,   24,  2,  2,  2 }, {    -15,   46,   24,  2,  2,  2 }, {    -16,   46,   25,  2,  2,  2 }, {    -17,   46,   25,  2,  2,  2 },
    {    -18,   47,   25,  2,  2,  2 }, {    -19,   47,   26,  2,  2,  2 }, {    -20,   47,   26,  1,  2,  2 }, {    -21,   47,   27,  1,  2,  2 }, {    -22,   47,   27,  1,  2,  2 },
    {    -23,   47,   28,  1,  2,  2 }, {    -24,   48,   28,  1,  2,  2 }, {    -25,   48,   29,  1,  2,  2 }, {    -26,   48,   29,  1,  2,  2 }, {    -27,   48,   29,  1,  2,  2 },
    {    -28,   48,   30,  0,  2,  2 }, {    -29,   48,   30,  0,  2,  2 }, {    -30,   48,   31,  0,  2,  2 }, {    -31,   48,   31,  0,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9610C3, {
    {      0,   16,    0, 16,  2,  2 }, {      1,   16,    0, 16,  2,  2 }, {      2,   16,    0, 16,  2,  2 }, {      3,   16,    1, 16,  2,  2 }, {      4,   16,    1, 16,  2,  2 },
    {      5,   16,    2, 15,  2,  2 }, {      6,   16,    2, 15,  2,  2 }, {      7,   17,    2, 15,  2,  2 }, {      8,   17,    3, 15,  2,  2 }, {      9,   17,    3, 15,  2,  2 },
    {     10,   17,    4, 15,  2,  2 }, {     11,   17,    4, 15,  2,  2 }, {     12,   17,    5, 15,  2,  2 }, {     13,   18,    5, 15,  2,  2 }, {     14,   18,    6, 14,  2,  2 },
    {     15,   18,    6, 14,  2,  2 }, {     16,   19,    6, 14,  2,  2 }, {     17,   19,    7, 14,  2,  2 }, {     18,   19,    7, 14,  2,  2 }, {     19,   20,    8, 14,  2,  2 },
    {     20,   20,    8, 14,  2,  2 }, {     21,   21,    9, 14,  2,  2 }, {     22,   21,    9, 14,  2,  2 }, {     23,   22,   10, 14,  2,  2 }, {     24,   22,   10, 13,  2,  2 },
    {     25,   23,   11, 13,  2,  2 }, {     26,   23,   11, 13,  2,  2 }, {     27,   24,   12, 13,  2,  2 }, {     28,   25,   12, 13,  2,  2 }, {     29,   25,   13, 13,  2,  2 },
    {     30,   26,   13, 13,  2,  2 }, {     31,   27,   14, 13,  2,  2 }, {     32,   28,   14, 13,  2,  2 }, {     33,   29,   15, 12,  2,  2 }, {     35,   29,   15, 12,  2,  2 },
    {     36,   30,   16, 12,  2,  2 }, {     37,   31,   16, 12,  2,  2 }, {     38,   32,   17, 12,  2,  2 }, {     39,   33,   18, 11,  2,  2 }, {     39,   34,   18, 11,  2,  2 },
    {     40,   35,   19, 11,  2,  2 }, {     41,   36,   19, 11,  2,  2 }, {     41,   37,   20, 11,  2,  2 }, {     42,   38,   20, 11,  2,  2 }, {     42,   39,   21, 11,  2,  2 },
    {     43,   40,   21, 11,  2,  2 }, {     43,   41,   22, 11,  2,  2 }, {     44,   42,   22, 10,  2,  2 }, {     44,   43,   23, 10,  2,  2 }, {     45,   44,   23, 10,  2,  2 },
    {     45,   45,   24, 10,  2,  2 }, {     45,   46,   24, 10,  2,  2 }, {     46,   47,   24, 10,  2,  2 }, {     46,   48,   25, 10,  2,  2 }, {     46,   49,   25, 10,  2,  2 },
    {     47,   50,   26, 10,  2,  2 }, {     47,   51,   26, 10,  2,  2 }, {     47,   52,   27,  9,  2,  2 }, {     47,   53,   27,  9,  2,  2 }, {     47,   54,   28,  9,  2,  2 },
    {     47,   55,   28,  9,  2,  2 }, {     48,   56,   28,  9,  2,  2 }, {     48,   57,   29,  9,  2,  2 }, {     48,   58,   29,  9,  2,  2 }, {     48,   59,   30,  9,  2,  2 },
    {     48,   60,   30,  8,  2,  2 }, {     48,   61,   31,  8,  2,  2 }, {     48,   62,   31,  8,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_961329, {
    {     16,   31,    0, 24,  2,  2 }, {     16,   30,    0, 24,  2,  2 }, {     16,   29,    1, 24,  2,  2 }, {     16,   28,    1, 24,  2,  2 }, {     16,   27,    2, 23,  2,  2 },
    {     16,   26,    2, 23,  2,  2 }, {     17,   25,    2, 23,  2,  2 }, {     17,   24,    3, 23,  2,  2 }, {     17,   23,    3, 23,  2,  2 }, {     17,   22,    4, 23,  2,  2 },
    {     17,   21,    4, 23,  2,  2 }, {     17,   20,    5, 23,  2,  2 }, {     18,   19,    5, 23,  2,  2 }, {     18,   18,    6, 22,  2,  2 }, {     18,   17,    6, 22,  2,  2 },
    {     19,   16,    6, 22,  2,  2 }, {     19,   15,    7, 22,  2,  2 }, {     19,   14,    7, 22,  2,  2 }, {     20,   13,    8, 22,  2,  2 }, {     20,   12,    8, 22,  2,  2 },
    {     21,   11,    9, 22,  2,  2 }, {     21,   10,    9, 22,  2,  2 }, {     22,    9,   10, 22,  2,  2 }, {     22,    8,   10, 21,  2,  2 }, {     23,    7,   11, 21,  2,  2 },
    {     23,    6,   11, 21,  2,  2 }, {     24,    5,   12, 21,  2,  2 }, {     25,    4,   12, 21,  2,  2 }, {     25,    3,   13, 21,  2,  2 }, {     26,    2,   13, 21,  2,  2 },
    {     27,    1,   14, 21,  2,  2 }, {     28,    0,   14, 21,  2,  2 }, {     29,   -1,   15, 20,  2,  2 }, {     29,   -3,   15, 20,  2,  2 }, {     30,   -4,   16, 20,  2,  2 },
    {     31,   -5,   16, 20,  2,  2 }, {     32,   -6,   17, 20,  2,  2 }, {     33,   -7,   18, 19,  2,  2 }, {     34,   -7,   18, 19,  2,  2 }, {     35,   -8,   19, 19,  2,  2 },
    {     36,   -9,   19, 19,  2,  2 }, {     37,   -9,   20, 19,  2,  2 }, {     38,  -10,   20, 19,  2,  2 }, {     39,  -10,   21, 19,  2,  2 }, {     40,  -11,   21, 19,  2,  2 },
    {     41,  -11,   22, 19,  2,  2 }, {     42,  -12,   22, 18,  2,  2 }, {     43,  -12,   23, 18,  2,  2 }, {     44,  -13,   23, 18,  2,  2 }, {     45,  -13,   24, 18,  2,  2 },
    {     46,  -13,   24, 18,  2,  2 }, {     47,  -14,   24, 18,  2,  2 }, {     48,  -14,   25, 18,  2,  2 }, {     49,  -14,   25, 18,  2,  2 }, {     50,  -15,   26, 18,  2,  2 },
    {     51,  -15,   26, 18,  2,  2 }, {     52,  -15,   27, 17,  2,  2 }, {     53,  -15,   27, 17,  2,  2 }, {     54,  -15,   28, 17,  2,  2 }, {     55,  -15,   28, 17,  2,  2 },
    {     56,  -16,   28, 17,  2,  2 }, {     57,  -16,   29, 17,  2,  2 }, {     58,  -16,   29, 17,  2,  2 }, {     59,  -16,   30, 17,  2,  2 }, {     60,  -16,   30, 16,  2,  2 },
    {     61,  -16,   31, 16,  2,  2 }, {     62,  -16,   31, 16,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_961586, {
    {     31,   16,    0,  0,  2,  4 }, {     30,   16,    0,  0,  2,  4 }, {     29,   16,    1,  0,  2,  4 }, {     28,   16,    1,  0,  2,  4 }, {     27,   16,    2,  1,  2,  4 },
    {     26,   16,    2,  1,  2,  4 }, {     25,   17,    2,  1,  2,  4 }, {     24,   17,    3,  1,  2,  4 }, {     23,   17,    3,  1,  2,  4 }, {     22,   17,    4,  1,  2,  4 },
    {     21,   17,    4,  1,  2,  4 }, {     20,   17,    5,  1,  2,  4 }, {     19,   18,    5,  1,  2,  4 }, {     18,   18,    6,  2,  2,  4 }, {     17,   18,    6,  2,  2,  4 },
    {     16,   19,    6,  2,  2,  4 }, {     15,   19,    7,  2,  2,  4 }, {     14,   19,    7,  2,  2,  4 }, {     13,   20,    8,  2,  2,  4 }, {     12,   20,    8,  2,  2,  4 },
    {     11,   21,    9,  2,  2,  4 }, {     10,   21,    9,  2,  2,  4 }, {      9,   22,   10,  2,  2,  4 }, {      8,   22,   10,  3,  2,  4 }, {      7,   23,   11,  3,  2,  4 },
    {      6,   23,   11,  3,  2,  4 }, {      5,   24,   12,  3,  2,  4 }, {      4,   25,   12,  3,  2,  4 }, {      3,   25,   13,  3,  2,  4 }, {      2,   26,   13,  3,  2,  4 },
    {      1,   27,   14,  3,  2,  4 }, {      0,   28,   14,  3,  2,  4 }, {     -1,   29,   15,  4,  2,  4 }, {     -3,   29,   15,  4,  2,  4 }, {     -4,   30,   16,  4,  2,  4 },
    {     -5,   31,   16,  4,  2,  4 }, {     -6,   32,   17,  4,  2,  4 }, {     -7,   33,   18,  5,  2,  4 }, {     -7,   34,   18,  5,  2,  4 }, {     -8,   35,   19,  5,  2,  4 },
    {     -9,   36,   19,  5,  2,  4 }, {     -9,   37,   20,  5,  2,  4 }, {    -10,   38,   20,  5,  2,  4 }, {    -10,   39,   21,  5,  2,  4 }, {    -11,   40,   21,  5,  2,  4 },
    {    -11,   41,   22,  5,  2,  4 }, {    -12,   42,   22,  6,  2,  4 }, {    -12,   43,   23,  6,  2,  4 }, {    -13,   44,   23,  6,  2,  4 }, {    -13,   45,   24,  6,  2,  4 },
    {    -13,   46,   24,  6,  2,  4 }, {    -14,   47,   24,  6,  2,  4 }, {    -14,   48,   25,  6,  2,  4 }, {    -14,   49,   25,  6,  2,  4 }, {    -15,   50,   26,  6,  2,  4 },
    {    -15,   51,   26,  6,  2,  4 }, {    -15,   52,   27,  7,  2,  4 }, {    -15,   53,   27,  7,  2,  4 }, {    -15,   54,   28,  7,  2,  4 }, {    -15,   55,   28,  7,  2,  4 },
    {    -16,   56,   28,  7,  2,  4 }, {    -16,   57,   29,  7,  2,  4 }, {    -16,   58,   29,  7,  2,  4 }, {    -16,   59,   30,  7,  2,  4 }, {    -16,   60,   30,  8,  2,  4 },
    {    -16,   61,   31,  8,  2,  4 }, {    -16,   62,   31,  8,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9617E3, {
    {     16,    0,    0,  8,  2,  4 }, {     16,    1,    0,  8,  2,  4 }, {     16,    2,    0,  8,  2,  4 }, {     16,    3,    1,  8,  2,  4 }, {     16,    4,    1,  8,  2,  4 },
    {     16,    5,    2,  9,  2,  4 }, {     16,    6,    2,  9,  2,  4 }, {     17,    7,    2,  9,  2,  4 }, {     17,    8,    3,  9,  2,  4 }, {     17,    9,    3,  9,  2,  4 },
    {     17,   10,    4,  9,  2,  4 }, {     17,   11,    4,  9,  2,  4 }, {     17,   12,    5,  9,  2,  4 }, {     18,   13,    5,  9,  2,  4 }, {     18,   14,    6, 10,  2,  4 },
    {     18,   15,    6, 10,  2,  4 }, {     19,   16,    6, 10,  2,  4 }, {     19,   17,    7, 10,  2,  4 }, {     19,   18,    7, 10,  2,  4 }, {     20,   19,    8, 10,  2,  4 },
    {     20,   20,    8, 10,  2,  4 }, {     21,   21,    9, 10,  2,  4 }, {     21,   22,    9, 10,  2,  4 }, {     22,   23,   10, 10,  2,  4 }, {     22,   24,   10, 11,  2,  4 },
    {     23,   25,   11, 11,  2,  4 }, {     23,   26,   11, 11,  2,  4 }, {     24,   27,   12, 11,  2,  4 }, {     25,   28,   12, 11,  2,  4 }, {     25,   29,   13, 11,  2,  4 },
    {     26,   30,   13, 11,  2,  4 }, {     27,   31,   14, 11,  2,  4 }, {     28,   32,   14, 11,  2,  4 }, {     29,   33,   15, 12,  2,  4 }, {     29,   35,   15, 12,  2,  4 },
    {     30,   36,   16, 12,  2,  4 }, {     31,   37,   16, 12,  2,  4 }, {     32,   38,   17, 12,  2,  4 }, {     33,   39,   18, 13,  2,  4 }, {     34,   39,   18, 13,  2,  4 },
    {     35,   40,   19, 13,  2,  4 }, {     36,   41,   19, 13,  2,  4 }, {     37,   41,   20, 13,  2,  4 }, {     38,   42,   20, 13,  2,  4 }, {     39,   42,   21, 13,  2,  4 },
    {     40,   43,   21, 13,  2,  4 }, {     41,   43,   22, 13,  2,  4 }, {     42,   44,   22, 14,  2,  4 }, {     43,   44,   23, 14,  2,  4 }, {     44,   45,   23, 14,  2,  4 },
    {     45,   45,   24, 14,  2,  4 }, {     46,   45,   24, 14,  2,  4 }, {     47,   46,   24, 14,  2,  4 }, {     48,   46,   25, 14,  2,  4 }, {     49,   46,   25, 14,  2,  4 },
    {     50,   47,   26, 14,  2,  4 }, {     51,   47,   26, 14,  2,  4 }, {     52,   47,   27, 15,  2,  4 }, {     53,   47,   27, 15,  2,  4 }, {     54,   47,   28, 15,  2,  4 },
    {     55,   47,   28, 15,  2,  4 }, {     56,   48,   28, 15,  2,  4 }, {     57,   48,   29, 15,  2,  4 }, {     58,   48,   29, 15,  2,  4 }, {     59,   48,   30, 15,  2,  4 },
    {     60,   48,   30, 16,  2,  4 }, {     61,   48,   31, 16,  2,  4 }, {     62,   48,   31, 16,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_961A49, {
    {      0,   16,    0, 16,  2,  4 }, {      1,   16,    0, 16,  2,  4 }, {      2,   16,    0, 16,  2,  4 }, {      3,   16,    1, 16,  2,  4 }, {      4,   16,    1, 16,  2,  4 },
    {      5,   16,    2, 17,  2,  4 }, {      6,   16,    2, 17,  2,  4 }, {      7,   15,    2, 17,  2,  4 }, {      8,   15,    3, 17,  2,  4 }, {      9,   15,    3, 17,  2,  4 },
    {     10,   15,    4, 17,  2,  4 }, {     11,   15,    4, 17,  2,  4 }, {     12,   15,    4, 17,  2,  4 }, {     13,   14,    5, 17,  2,  4 }, {     14,   14,    5, 18,  2,  4 },
    {     15,   14,    6, 18,  2,  4 }, {     16,   13,    6, 18,  2,  4 }, {     17,   13,    7, 18,  2,  4 }, {     18,   13,    7, 18,  2,  4 }, {     19,   12,    8, 18,  2,  4 },
    {     20,   12,    8, 18,  2,  4 }, {     21,   11,    9, 18,  2,  4 }, {     22,   11,    9, 18,  2,  4 }, {     23,   10,   10, 18,  2,  4 }, {     24,   10,   10, 19,  2,  4 },
    {     25,    9,   11, 19,  2,  4 }, {     26,    9,   11, 19,  2,  4 }, {     27,    8,   11, 19,  2,  4 }, {     28,    7,   12, 19,  2,  4 }, {     29,    7,   13, 19,  2,  4 },
    {     30,    6,   13, 19,  2,  4 }, {     31,    5,   14, 19,  2,  4 }, {     32,    4,   14, 19,  2,  4 }, {     33,    3,   15, 20,  2,  4 }, {     35,    3,   15, 20,  2,  4 },
    {     36,    2,   16, 20,  2,  4 }, {     37,    1,   16, 20,  2,  4 }, {     38,    0,   17, 20,  2,  4 }, {     39,   -1,   17, 21,  2,  4 }, {     39,   -2,   18, 21,  2,  4 },
    {     40,   -3,   18, 21,  2,  4 }, {     41,   -4,   19, 21,  2,  4 }, {     41,   -5,   19, 21,  2,  4 }, {     42,   -6,   20, 21,  2,  4 }, {     42,   -7,   20, 21,  2,  4 },
    {     43,   -8,   21, 21,  2,  4 }, {     43,   -9,   21, 21,  2,  4 }, {     44,  -10,   22, 22,  2,  4 }, {     44,  -11,   22, 22,  2,  4 }, {     45,  -12,   23, 22,  2,  4 },
    {     45,  -13,   23, 22,  2,  4 }, {     45,  -14,   24, 22,  2,  4 }, {     46,  -15,   24, 22,  2,  4 }, {     46,  -16,   25, 22,  2,  4 }, {     46,  -17,   25, 22,  2,  4 },
    {     47,  -18,   25, 22,  2,  4 }, {     47,  -19,   26, 22,  2,  4 }, {     47,  -20,   26, 23,  2,  4 }, {     47,  -21,   27, 23,  2,  4 }, {     47,  -22,   27, 23,  2,  4 },
    {     47,  -23,   28, 23,  2,  4 }, {     48,  -24,   28, 23,  2,  4 }, {     48,  -25,   29, 23,  2,  4 }, {     48,  -26,   29, 23,  2,  4 }, {     48,  -27,   29, 23,  2,  4 },
    {     48,  -28,   30, 24,  2,  4 }, {     48,  -29,   30, 24,  2,  4 }, {     48,  -30,   31, 24,  2,  4 }, {     48,  -31,   31, 24,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_961CB8, {
    {     16,   31,    0, 24,  2,  4 }, {     16,   30,    0, 24,  2,  4 }, {     16,   29,    1, 24,  2,  4 }, {     16,   28,    1, 24,  2,  4 }, {     16,   27,    2, 25,  2,  4 },
    {     16,   26,    2, 25,  2,  4 }, {     15,   25,    2, 25,  2,  4 }, {     15,   24,    3, 25,  2,  4 }, {     15,   23,    3, 25,  2,  4 }, {     15,   22,    4, 25,  2,  4 },
    {     15,   21,    4, 25,  2,  4 }, {     15,   20,    4, 25,  2,  4 }, {     14,   19,    5, 25,  2,  4 }, {     14,   18,    5, 26,  2,  4 }, {     14,   17,    6, 26,  2,  4 },
    {     13,   16,    6, 26,  2,  4 }, {     13,   15,    7, 26,  2,  4 }, {     13,   14,    7, 26,  2,  4 }, {     12,   13,    8, 26,  2,  4 }, {     12,   12,    8, 26,  2,  4 },
    {     11,   11,    9, 26,  2,  4 }, {     11,   10,    9, 26,  2,  4 }, {     10,    9,   10, 26,  2,  4 }, {     10,    8,   10, 27,  2,  4 }, {      9,    7,   11, 27,  2,  4 },
    {      9,    6,   11, 27,  2,  4 }, {      8,    5,   11, 27,  2,  4 }, {      7,    4,   12, 27,  2,  4 }, {      7,    3,   13, 27,  2,  4 }, {      6,    2,   13, 27,  2,  4 },
    {      5,    1,   14, 27,  2,  4 }, {      4,    0,   14, 27,  2,  4 }, {      3,   -1,   15, 28,  2,  4 }, {      3,   -3,   15, 28,  2,  4 }, {      2,   -4,   16, 28,  2,  4 },
    {      1,   -5,   16, 28,  2,  4 }, {      0,   -6,   17, 28,  2,  4 }, {     -1,   -7,   17, 29,  2,  4 }, {     -2,   -7,   18, 29,  2,  4 }, {     -3,   -8,   18, 29,  2,  4 },
    {     -4,   -9,   19, 29,  2,  4 }, {     -5,   -9,   19, 29,  2,  4 }, {     -6,  -10,   20, 29,  2,  4 }, {     -7,  -10,   20, 29,  2,  4 }, {     -8,  -11,   21, 29,  2,  4 },
    {     -9,  -11,   21, 29,  2,  4 }, {    -10,  -12,   22, 30,  2,  4 }, {    -11,  -12,   22, 30,  2,  4 }, {    -12,  -13,   23, 30,  2,  4 }, {    -13,  -13,   23, 30,  2,  4 },
    {    -14,  -13,   24, 30,  2,  4 }, {    -15,  -14,   24, 30,  2,  4 }, {    -16,  -14,   25, 30,  2,  4 }, {    -17,  -14,   25, 30,  2,  4 }, {    -18,  -15,   25, 30,  2,  4 },
    {    -19,  -15,   26, 30,  2,  4 }, {    -20,  -15,   26, 31,  2,  4 }, {    -21,  -15,   27, 31,  2,  4 }, {    -22,  -15,   27, 31,  2,  4 }, {    -23,  -15,   28, 31,  2,  4 },
    {    -24,  -16,   28, 31,  2,  4 }, {    -25,  -16,   29, 31,  2,  4 }, {    -26,  -16,   29, 31,  2,  4 }, {    -27,  -16,   29, 31,  2,  4 }, {    -28,  -16,   30,  0,  2,  4 },
    {    -29,  -16,   30,  0,  2,  4 }, {    -30,  -16,   31,  0,  2,  4 }, {    -31,  -16,   31,  0,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95F8BE, {
    {     31,   16,   15,  0,  6,  2 }, {     30,   16,   15,  0,  6,  2 }, {     29,   16,   14,  0,  6,  2 }, {     28,   16,   14,  0,  6,  2 }, {     27,   16,   13, 31,  6,  2 },
    {     26,   16,   13, 31,  6,  2 }, {     25,   15,   13, 31,  6,  2 }, {     24,   15,   12, 31,  6,  2 }, {     23,   15,   12, 31,  6,  2 }, {     22,   15,   11, 31,  6,  2 },
    {     21,   15,   11, 31,  6,  2 }, {     20,   15,   11, 31,  6,  2 }, {     19,   14,   10, 31,  6,  2 }, {     18,   14,   10, 30,  6,  2 }, {     17,   14,    9, 30,  6,  2 },
    {     16,   13,    9, 30,  6,  2 }, {     15,   13,    8, 30,  6,  2 }, {     14,   13,    8, 30,  6,  2 }, {     13,   12,    7, 30,  6,  2 }, {     12,   12,    7, 30,  6,  2 },
    {     11,   11,    6, 30,  6,  2 }, {     10,   11,    6, 30,  6,  2 }, {      9,   10,    5, 30,  6,  2 }, {      8,   10,    5, 29,  6,  2 }, {      7,    9,    4, 29,  6,  2 },
    {      6,    9,    4, 29,  6,  2 }, {      5,    8,    4, 29,  6,  2 }, {      4,    7,    3, 29,  6,  2 }, {      3,    7,    2, 29,  6,  2 }, {      2,    6,    2, 29,  6,  2 },
    {      1,    5,    1, 29,  6,  2 }, {      0,    4,    1, 29,  6,  2 }, {     -1,    3,    0, 28,  6,  2 }, {     -3,    3,    0, 28,  6,  2 }, {     -4,    2,   -1, 28,  6,  2 },
    {     -5,    1,   -1, 28,  6,  2 }, {     -6,    0,   -2, 28,  6,  2 }, {     -7,   -1,   -2, 27,  6,  2 }, {     -7,   -2,   -3, 27,  6,  2 }, {     -8,   -3,   -3, 27,  6,  2 },
    {     -9,   -4,   -4, 27,  6,  2 }, {     -9,   -5,   -5, 27,  6,  2 }, {    -10,   -6,   -5, 27,  6,  2 }, {    -10,   -7,   -5, 27,  6,  2 }, {    -11,   -8,   -6, 27,  6,  2 },
    {    -11,   -9,   -6, 27,  6,  2 }, {    -12,  -10,   -7, 26,  6,  2 }, {    -12,  -11,   -7, 26,  6,  2 }, {    -13,  -12,   -8, 26,  6,  2 }, {    -13,  -13,   -8, 26,  6,  2 },
    {    -13,  -14,   -9, 26,  6,  2 }, {    -14,  -15,   -9, 26,  6,  2 }, {    -14,  -16,  -10, 26,  6,  2 }, {    -14,  -17,  -10, 26,  6,  2 }, {    -15,  -18,  -11, 26,  6,  2 },
    {    -15,  -19,  -11, 26,  6,  2 }, {    -15,  -20,  -12, 25,  6,  2 }, {    -15,  -21,  -12, 25,  6,  2 }, {    -15,  -22,  -12, 25,  6,  2 }, {    -15,  -23,  -13, 25,  6,  2 },
    {    -16,  -24,  -13, 25,  6,  2 }, {    -16,  -25,  -14, 25,  6,  2 }, {    -16,  -26,  -14, 25,  6,  2 }, {    -16,  -27,  -14, 25,  6,  2 }, {    -16,  -28,  -15, 24,  6,  2 },
    {    -16,  -29,  -15, 24,  6,  2 }, {    -16,  -30,  -16, 24,  6,  2 }, {    -16,  -31,  -17, 24,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95FB24, {
    {     16,    0,   15,  8,  6,  2 }, {     16,    1,   15,  8,  6,  2 }, {     16,    2,   15,  8,  6,  2 }, {     16,    3,   14,  8,  6,  2 }, {     16,    4,   14,  8,  6,  2 },
    {     16,    5,   13,  7,  6,  2 }, {     16,    6,   13,  7,  6,  2 }, {     15,    7,   13,  7,  6,  2 }, {     15,    8,   12,  7,  6,  2 }, {     15,    9,   12,  7,  6,  2 },
    {     15,   10,   11,  7,  6,  2 }, {     15,   11,   11,  7,  6,  2 }, {     15,   12,   11,  7,  6,  2 }, {     14,   13,   10,  7,  6,  2 }, {     14,   14,   10,  6,  6,  2 },
    {     14,   15,    9,  6,  6,  2 }, {     13,   16,    9,  6,  6,  2 }, {     13,   17,    8,  6,  6,  2 }, {     13,   18,    8,  6,  6,  2 }, {     12,   19,    7,  6,  6,  2 },
    {     12,   20,    7,  6,  6,  2 }, {     11,   21,    6,  6,  6,  2 }, {     11,   22,    6,  6,  6,  2 }, {     10,   23,    5,  6,  6,  2 }, {     10,   24,    5,  5,  6,  2 },
    {      9,   25,    4,  5,  6,  2 }, {      9,   26,    4,  5,  6,  2 }, {      8,   27,    4,  5,  6,  2 }, {      7,   28,    3,  5,  6,  2 }, {      7,   29,    2,  5,  6,  2 },
    {      6,   30,    2,  5,  6,  2 }, {      5,   31,    1,  5,  6,  2 }, {      4,   32,    1,  5,  6,  2 }, {      3,   33,    0,  4,  6,  2 }, {      3,   35,    0,  4,  6,  2 },
    {      2,   36,   -1,  4,  6,  2 }, {      1,   37,   -1,  4,  6,  2 }, {      0,   38,   -2,  4,  6,  2 }, {     -1,   39,   -2,  3,  6,  2 }, {     -2,   39,   -3,  3,  6,  2 },
    {     -3,   40,   -3,  3,  6,  2 }, {     -4,   41,   -4,  3,  6,  2 }, {     -5,   41,   -5,  3,  6,  2 }, {     -6,   42,   -5,  3,  6,  2 }, {     -7,   42,   -5,  3,  6,  2 },
    {     -8,   43,   -6,  3,  6,  2 }, {     -9,   43,   -6,  3,  6,  2 }, {    -10,   44,   -7,  2,  6,  2 }, {    -11,   44,   -7,  2,  6,  2 }, {    -12,   45,   -8,  2,  6,  2 },
    {    -13,   45,   -8,  2,  6,  2 }, {    -14,   45,   -9,  2,  6,  2 }, {    -15,   46,   -9,  2,  6,  2 }, {    -16,   46,  -10,  2,  6,  2 }, {    -17,   46,  -10,  2,  6,  2 },
    {    -18,   47,  -11,  2,  6,  2 }, {    -19,   47,  -11,  2,  6,  2 }, {    -20,   47,  -12,  1,  6,  2 }, {    -21,   47,  -12,  1,  6,  2 }, {    -22,   47,  -12,  1,  6,  2 },
    {    -23,   47,  -13,  1,  6,  2 }, {    -24,   48,  -13,  1,  6,  2 }, {    -25,   48,  -14,  1,  6,  2 }, {    -26,   48,  -14,  1,  6,  2 }, {    -27,   48,  -14,  1,  6,  2 },
    {    -28,   48,  -15,  0,  6,  2 }, {    -29,   48,  -15,  0,  6,  2 }, {    -30,   48,  -16,  0,  6,  2 }, {    -31,   48,  -17,  0,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95FD93, {
    {      0,   16,   15, 16,  6,  2 }, {      1,   16,   15, 16,  6,  2 }, {      2,   16,   15, 16,  6,  2 }, {      3,   16,   14, 16,  6,  2 }, {      4,   16,   14, 16,  6,  2 },
    {      5,   16,   13, 15,  6,  2 }, {      6,   16,   13, 15,  6,  2 }, {      7,   17,   13, 15,  6,  2 }, {      8,   17,   12, 15,  6,  2 }, {      9,   17,   12, 15,  6,  2 },
    {     10,   17,   11, 15,  6,  2 }, {     11,   17,   11, 15,  6,  2 }, {     12,   17,   10, 15,  6,  2 }, {     13,   18,   10, 15,  6,  2 }, {     14,   18,    9, 14,  6,  2 },
    {     15,   18,    9, 14,  6,  2 }, {     16,   19,    9, 14,  6,  2 }, {     17,   19,    8, 14,  6,  2 }, {     18,   19,    8, 14,  6,  2 }, {     19,   20,    7, 14,  6,  2 },
    {     20,   20,    7, 14,  6,  2 }, {     21,   21,    6, 14,  6,  2 }, {     22,   21,    6, 14,  6,  2 }, {     23,   22,    5, 14,  6,  2 }, {     24,   22,    5, 13,  6,  2 },
    {     25,   23,    4, 13,  6,  2 }, {     26,   23,    4, 13,  6,  2 }, {     27,   24,    3, 13,  6,  2 }, {     28,   25,    3, 13,  6,  2 }, {     29,   25,    2, 13,  6,  2 },
    {     30,   26,    2, 13,  6,  2 }, {     31,   27,    1, 13,  6,  2 }, {     32,   28,    1, 13,  6,  2 }, {     33,   29,    0, 12,  6,  2 }, {     35,   29,   -1, 12,  6,  2 },
    {     36,   30,   -1, 12,  6,  2 }, {     37,   31,   -1, 12,  6,  2 }, {     38,   32,   -2, 12,  6,  2 }, {     39,   33,   -3, 11,  6,  2 }, {     39,   34,   -3, 11,  6,  2 },
    {     40,   35,   -4, 11,  6,  2 }, {     41,   36,   -4, 11,  6,  2 }, {     41,   37,   -5, 11,  6,  2 }, {     42,   38,   -5, 11,  6,  2 }, {     42,   39,   -6, 11,  6,  2 },
    {     43,   40,   -6, 11,  6,  2 }, {     43,   41,   -7, 11,  6,  2 }, {     44,   42,   -7, 10,  6,  2 }, {     44,   43,   -8, 10,  6,  2 }, {     45,   44,   -8, 10,  6,  2 },
    {     45,   45,   -9, 10,  6,  2 }, {     45,   46,   -9, 10,  6,  2 }, {     46,   47,   -9, 10,  6,  2 }, {     46,   48,  -10, 10,  6,  2 }, {     46,   49,  -10, 10,  6,  2 },
    {     47,   50,  -11, 10,  6,  2 }, {     47,   51,  -11, 10,  6,  2 }, {     47,   52,  -12,  9,  6,  2 }, {     47,   53,  -12,  9,  6,  2 }, {     47,   54,  -13,  9,  6,  2 },
    {     47,   55,  -13,  9,  6,  2 }, {     48,   56,  -13,  9,  6,  2 }, {     48,   57,  -14,  9,  6,  2 }, {     48,   58,  -14,  9,  6,  2 }, {     48,   59,  -15,  9,  6,  2 },
    {     48,   60,  -15,  8,  6,  2 }, {     48,   61,  -16,  8,  6,  2 }, {     48,   62,  -16,  8,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95FFF9, {
    {     16,   31,   15, 24,  6,  2 }, {     16,   30,   15, 24,  6,  2 }, {     16,   29,   14, 24,  6,  2 }, {     16,   28,   14, 24,  6,  2 }, {     16,   27,   13, 23,  6,  2 },
    {     16,   26,   13, 23,  6,  2 }, {     17,   25,   13, 23,  6,  2 }, {     17,   24,   12, 23,  6,  2 }, {     17,   23,   12, 23,  6,  2 }, {     17,   22,   11, 23,  6,  2 },
    {     17,   21,   11, 23,  6,  2 }, {     17,   20,   10, 23,  6,  2 }, {     18,   19,   10, 23,  6,  2 }, {     18,   18,    9, 22,  6,  2 }, {     18,   17,    9, 22,  6,  2 },
    {     19,   16,    9, 22,  6,  2 }, {     19,   15,    8, 22,  6,  2 }, {     19,   14,    8, 22,  6,  2 }, {     20,   13,    7, 22,  6,  2 }, {     20,   12,    7, 22,  6,  2 },
    {     21,   11,    6, 22,  6,  2 }, {     21,   10,    6, 22,  6,  2 }, {     22,    9,    5, 22,  6,  2 }, {     22,    8,    5, 21,  6,  2 }, {     23,    7,    4, 21,  6,  2 },
    {     23,    6,    4, 21,  6,  2 }, {     24,    5,    3, 21,  6,  2 }, {     25,    4,    3, 21,  6,  2 }, {     25,    3,    2, 21,  6,  2 }, {     26,    2,    2, 21,  6,  2 },
    {     27,    1,    1, 21,  6,  2 }, {     28,    0,    1, 21,  6,  2 }, {     29,   -1,    0, 20,  6,  2 }, {     29,   -3,   -1, 20,  6,  2 }, {     30,   -4,   -1, 20,  6,  2 },
    {     31,   -5,   -1, 20,  6,  2 }, {     32,   -6,   -2, 20,  6,  2 }, {     33,   -7,   -3, 19,  6,  2 }, {     34,   -7,   -3, 19,  6,  2 }, {     35,   -8,   -4, 19,  6,  2 },
    {     36,   -9,   -4, 19,  6,  2 }, {     37,   -9,   -5, 19,  6,  2 }, {     38,  -10,   -5, 19,  6,  2 }, {     39,  -10,   -6, 19,  6,  2 }, {     40,  -11,   -6, 19,  6,  2 },
    {     41,  -11,   -7, 19,  6,  2 }, {     42,  -12,   -7, 18,  6,  2 }, {     43,  -12,   -8, 18,  6,  2 }, {     44,  -13,   -8, 18,  6,  2 }, {     45,  -13,   -9, 18,  6,  2 },
    {     46,  -13,   -9, 18,  6,  2 }, {     47,  -14,   -9, 18,  6,  2 }, {     48,  -14,  -10, 18,  6,  2 }, {     49,  -14,  -10, 18,  6,  2 }, {     50,  -15,  -11, 18,  6,  2 },
    {     51,  -15,  -11, 18,  6,  2 }, {     52,  -15,  -12, 17,  6,  2 }, {     53,  -15,  -12, 17,  6,  2 }, {     54,  -15,  -13, 17,  6,  2 }, {     55,  -15,  -13, 17,  6,  2 },
    {     56,  -16,  -13, 17,  6,  2 }, {     57,  -16,  -14, 17,  6,  2 }, {     58,  -16,  -14, 17,  6,  2 }, {     59,  -16,  -15, 17,  6,  2 }, {     60,  -16,  -15, 16,  6,  2 },
    {     61,  -16,  -16, 16,  6,  2 }, {     62,  -16,  -16, 16,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_960256, {
    {     31,   16,   15,  0,  6,  4 }, {     30,   16,   15,  0,  6,  4 }, {     29,   16,   14,  0,  6,  4 }, {     28,   16,   14,  0,  6,  4 }, {     27,   16,   13,  1,  6,  4 },
    {     26,   16,   13,  1,  6,  4 }, {     25,   17,   13,  1,  6,  4 }, {     24,   17,   12,  1,  6,  4 }, {     23,   17,   12,  1,  6,  4 }, {     22,   17,   11,  1,  6,  4 },
    {     21,   17,   11,  1,  6,  4 }, {     20,   17,   10,  1,  6,  4 }, {     19,   18,   10,  1,  6,  4 }, {     18,   18,    9,  2,  6,  4 }, {     17,   18,    9,  2,  6,  4 },
    {     16,   19,    9,  2,  6,  4 }, {     15,   19,    8,  2,  6,  4 }, {     14,   19,    8,  2,  6,  4 }, {     13,   20,    7,  2,  6,  4 }, {     12,   20,    7,  2,  6,  4 },
    {     11,   21,    6,  2,  6,  4 }, {     10,   21,    6,  2,  6,  4 }, {      9,   22,    5,  2,  6,  4 }, {      8,   22,    5,  3,  6,  4 }, {      7,   23,    4,  3,  6,  4 },
    {      6,   23,    4,  3,  6,  4 }, {      5,   24,    3,  3,  6,  4 }, {      4,   25,    3,  3,  6,  4 }, {      3,   25,    2,  3,  6,  4 }, {      2,   26,    2,  3,  6,  4 },
    {      1,   27,    1,  3,  6,  4 }, {      0,   28,    1,  3,  6,  4 }, {     -1,   29,    0,  4,  6,  4 }, {     -3,   29,   -1,  4,  6,  4 }, {     -4,   30,   -1,  4,  6,  4 },
    {     -5,   31,   -1,  4,  6,  4 }, {     -6,   32,   -2,  4,  6,  4 }, {     -7,   33,   -3,  5,  6,  4 }, {     -7,   34,   -3,  5,  6,  4 }, {     -8,   35,   -4,  5,  6,  4 },
    {     -9,   36,   -4,  5,  6,  4 }, {     -9,   37,   -5,  5,  6,  4 }, {    -10,   38,   -5,  5,  6,  4 }, {    -10,   39,   -6,  5,  6,  4 }, {    -11,   40,   -6,  5,  6,  4 },
    {    -11,   41,   -7,  5,  6,  4 }, {    -12,   42,   -7,  6,  6,  4 }, {    -12,   43,   -8,  6,  6,  4 }, {    -13,   44,   -8,  6,  6,  4 }, {    -13,   45,   -9,  6,  6,  4 },
    {    -13,   46,   -9,  6,  6,  4 }, {    -14,   47,   -9,  6,  6,  4 }, {    -14,   48,  -10,  6,  6,  4 }, {    -14,   49,  -10,  6,  6,  4 }, {    -15,   50,  -11,  6,  6,  4 },
    {    -15,   51,  -11,  6,  6,  4 }, {    -15,   52,  -12,  7,  6,  4 }, {    -15,   53,  -12,  7,  6,  4 }, {    -15,   54,  -13,  7,  6,  4 }, {    -15,   55,  -13,  7,  6,  4 },
    {    -16,   56,  -13,  7,  6,  4 }, {    -16,   57,  -14,  7,  6,  4 }, {    -16,   58,  -14,  7,  6,  4 }, {    -16,   59,  -15,  7,  6,  4 }, {    -16,   60,  -15,  8,  6,  4 },
    {    -16,   61,  -16,  8,  6,  4 }, {    -16,   62,  -16,  8,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9604B3, {
    {     16,    0,   15,  8,  6,  4 }, {     16,    1,   15,  8,  6,  4 }, {     16,    2,   15,  8,  6,  4 }, {     16,    3,   14,  8,  6,  4 }, {     16,    4,   14,  8,  6,  4 },
    {     16,    5,   13,  9,  6,  4 }, {     16,    6,   13,  9,  6,  4 }, {     17,    7,   13,  9,  6,  4 }, {     17,    8,   12,  9,  6,  4 }, {     17,    9,   12,  9,  6,  4 },
    {     17,   10,   11,  9,  6,  4 }, {     17,   11,   11,  9,  6,  4 }, {     17,   12,   10,  9,  6,  4 }, {     18,   13,   10,  9,  6,  4 }, {     18,   14,    9, 10,  6,  4 },
    {     18,   15,    9, 10,  6,  4 }, {     19,   16,    9, 10,  6,  4 }, {     19,   17,    8, 10,  6,  4 }, {     19,   18,    8, 10,  6,  4 }, {     20,   19,    7, 10,  6,  4 },
    {     20,   20,    7, 10,  6,  4 }, {     21,   21,    6, 10,  6,  4 }, {     21,   22,    6, 10,  6,  4 }, {     22,   23,    5, 10,  6,  4 }, {     22,   24,    5, 11,  6,  4 },
    {     23,   25,    4, 11,  6,  4 }, {     23,   26,    4, 11,  6,  4 }, {     24,   27,    3, 11,  6,  4 }, {     25,   28,    3, 11,  6,  4 }, {     25,   29,    2, 11,  6,  4 },
    {     26,   30,    2, 11,  6,  4 }, {     27,   31,    1, 11,  6,  4 }, {     28,   32,    1, 11,  6,  4 }, {     29,   33,    0, 12,  6,  4 }, {     29,   35,   -1, 12,  6,  4 },
    {     30,   36,   -1, 12,  6,  4 }, {     31,   37,   -1, 12,  6,  4 }, {     32,   38,   -2, 12,  6,  4 }, {     33,   39,   -3, 13,  6,  4 }, {     34,   39,   -3, 13,  6,  4 },
    {     35,   40,   -4, 13,  6,  4 }, {     36,   41,   -4, 13,  6,  4 }, {     37,   41,   -5, 13,  6,  4 }, {     38,   42,   -5, 13,  6,  4 }, {     39,   42,   -6, 13,  6,  4 },
    {     40,   43,   -6, 13,  6,  4 }, {     41,   43,   -7, 13,  6,  4 }, {     42,   44,   -7, 14,  6,  4 }, {     43,   44,   -8, 14,  6,  4 }, {     44,   45,   -8, 14,  6,  4 },
    {     45,   45,   -9, 14,  6,  4 }, {     46,   45,   -9, 14,  6,  4 }, {     47,   46,   -9, 14,  6,  4 }, {     48,   46,  -10, 14,  6,  4 }, {     49,   46,  -10, 14,  6,  4 },
    {     50,   47,  -11, 14,  6,  4 }, {     51,   47,  -11, 14,  6,  4 }, {     52,   47,  -12, 15,  6,  4 }, {     53,   47,  -12, 15,  6,  4 }, {     54,   47,  -13, 15,  6,  4 },
    {     55,   47,  -13, 15,  6,  4 }, {     56,   48,  -13, 15,  6,  4 }, {     57,   48,  -14, 15,  6,  4 }, {     58,   48,  -14, 15,  6,  4 }, {     59,   48,  -15, 15,  6,  4 },
    {     60,   48,  -15, 16,  6,  4 }, {     61,   48,  -16, 16,  6,  4 }, {     62,   48,  -16, 16,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_960719, {
    {      0,   16,   15, 16,  6,  4 }, {      1,   16,   15, 16,  6,  4 }, {      2,   16,   15, 16,  6,  4 }, {      3,   16,   14, 16,  6,  4 }, {      4,   16,   14, 16,  6,  4 },
    {      5,   16,   13, 17,  6,  4 }, {      6,   16,   13, 17,  6,  4 }, {      7,   15,   13, 17,  6,  4 }, {      8,   15,   12, 17,  6,  4 }, {      9,   15,   12, 17,  6,  4 },
    {     10,   15,   11, 17,  6,  4 }, {     11,   15,   11, 17,  6,  4 }, {     12,   15,   11, 17,  6,  4 }, {     13,   14,   10, 17,  6,  4 }, {     14,   14,   10, 18,  6,  4 },
    {     15,   14,    9, 18,  6,  4 }, {     16,   13,    9, 18,  6,  4 }, {     17,   13,    8, 18,  6,  4 }, {     18,   13,    8, 18,  6,  4 }, {     19,   12,    7, 18,  6,  4 },
    {     20,   12,    7, 18,  6,  4 }, {     21,   11,    6, 18,  6,  4 }, {     22,   11,    6, 18,  6,  4 }, {     23,   10,    5, 18,  6,  4 }, {     24,   10,    5, 19,  6,  4 },
    {     25,    9,    4, 19,  6,  4 }, {     26,    9,    4, 19,  6,  4 }, {     27,    8,    4, 19,  6,  4 }, {     28,    7,    3, 19,  6,  4 }, {     29,    7,    2, 19,  6,  4 },
    {     30,    6,    2, 19,  6,  4 }, {     31,    5,    1, 19,  6,  4 }, {     32,    4,    1, 19,  6,  4 }, {     33,    3,    0, 20,  6,  4 }, {     35,    3,    0, 20,  6,  4 },
    {     36,    2,   -1, 20,  6,  4 }, {     37,    1,   -1, 20,  6,  4 }, {     38,    0,   -2, 20,  6,  4 }, {     39,   -1,   -2, 21,  6,  4 }, {     39,   -2,   -3, 21,  6,  4 },
    {     40,   -3,   -3, 21,  6,  4 }, {     41,   -4,   -4, 21,  6,  4 }, {     41,   -5,   -4, 21,  6,  4 }, {     42,   -6,   -5, 21,  6,  4 }, {     42,   -7,   -5, 21,  6,  4 },
    {     43,   -8,   -6, 21,  6,  4 }, {     43,   -9,   -6, 21,  6,  4 }, {     44,  -10,   -7, 22,  6,  4 }, {     44,  -11,   -7, 22,  6,  4 }, {     45,  -12,   -8, 22,  6,  4 },
    {     45,  -13,   -8, 22,  6,  4 }, {     45,  -14,   -9, 22,  6,  4 }, {     46,  -15,   -9, 22,  6,  4 }, {     46,  -16,  -10, 22,  6,  4 }, {     46,  -17,  -10, 22,  6,  4 },
    {     47,  -18,  -10, 22,  6,  4 }, {     47,  -19,  -11, 22,  6,  4 }, {     47,  -20,  -11, 23,  6,  4 }, {     47,  -21,  -12, 23,  6,  4 }, {     47,  -22,  -12, 23,  6,  4 },
    {     47,  -23,  -13, 23,  6,  4 }, {     48,  -24,  -13, 23,  6,  4 }, {     48,  -25,  -14, 23,  6,  4 }, {     48,  -26,  -14, 23,  6,  4 }, {     48,  -27,  -14, 23,  6,  4 },
    {     48,  -28,  -15, 24,  6,  4 }, {     48,  -29,  -15, 24,  6,  4 }, {     48,  -30,  -16, 24,  6,  4 }, {     48,  -31,  -16, 24,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_960988, {
    {     16,   31,   15, 24,  6,  4 }, {     16,   30,   15, 24,  6,  4 }, {     16,   29,   14, 24,  6,  4 }, {     16,   28,   14, 24,  6,  4 }, {     16,   27,   13, 25,  6,  4 },
    {     16,   26,   13, 25,  6,  4 }, {     15,   25,   13, 25,  6,  4 }, {     15,   24,   12, 25,  6,  4 }, {     15,   23,   12, 25,  6,  4 }, {     15,   22,   11, 25,  6,  4 },
    {     15,   21,   11, 25,  6,  4 }, {     15,   20,   11, 25,  6,  4 }, {     14,   19,   10, 25,  6,  4 }, {     14,   18,   10, 26,  6,  4 }, {     14,   17,    9, 26,  6,  4 },
    {     13,   16,    9, 26,  6,  4 }, {     13,   15,    8, 26,  6,  4 }, {     13,   14,    8, 26,  6,  4 }, {     12,   13,    7, 26,  6,  4 }, {     12,   12,    7, 26,  6,  4 },
    {     11,   11,    6, 26,  6,  4 }, {     11,   10,    6, 26,  6,  4 }, {     10,    9,    5, 26,  6,  4 }, {     10,    8,    5, 27,  6,  4 }, {      9,    7,    4, 27,  6,  4 },
    {      9,    6,    4, 27,  6,  4 }, {      8,    5,    4, 27,  6,  4 }, {      7,    4,    3, 27,  6,  4 }, {      7,    3,    2, 27,  6,  4 }, {      6,    2,    2, 27,  6,  4 },
    {      5,    1,    1, 27,  6,  4 }, {      4,    0,    1, 27,  6,  4 }, {      3,   -1,    0, 28,  6,  4 }, {      3,   -3,    0, 28,  6,  4 }, {      2,   -4,   -1, 28,  6,  4 },
    {      1,   -5,   -1, 28,  6,  4 }, {      0,   -6,   -2, 28,  6,  4 }, {     -1,   -7,   -2, 29,  6,  4 }, {     -2,   -7,   -3, 29,  6,  4 }, {     -3,   -8,   -3, 29,  6,  4 },
    {     -4,   -9,   -4, 29,  6,  4 }, {     -5,   -9,   -4, 29,  6,  4 }, {     -6,  -10,   -5, 29,  6,  4 }, {     -7,  -10,   -5, 29,  6,  4 }, {     -8,  -11,   -6, 29,  6,  4 },
    {     -9,  -11,   -6, 29,  6,  4 }, {    -10,  -12,   -7, 30,  6,  4 }, {    -11,  -12,   -7, 30,  6,  4 }, {    -12,  -13,   -8, 30,  6,  4 }, {    -13,  -13,   -8, 30,  6,  4 },
    {    -14,  -13,   -9, 30,  6,  4 }, {    -15,  -14,   -9, 30,  6,  4 }, {    -16,  -14,  -10, 30,  6,  4 }, {    -17,  -14,  -10, 30,  6,  4 }, {    -18,  -15,  -10, 30,  6,  4 },
    {    -19,  -15,  -11, 30,  6,  4 }, {    -20,  -15,  -11, 31,  6,  4 }, {    -21,  -15,  -12, 31,  6,  4 }, {    -22,  -15,  -12, 31,  6,  4 }, {    -23,  -15,  -13, 31,  6,  4 },
    {    -24,  -16,  -13, 31,  6,  4 }, {    -25,  -16,  -14, 31,  6,  4 }, {    -26,  -16,  -14, 31,  6,  4 }, {    -27,  -16,  -14, 31,  6,  4 }, {    -28,  -16,  -15,  0,  6,  4 },
    {    -29,  -16,  -15,  0,  6,  4 }, {    -30,  -16,  -16,  0,  6,  4 }, {    -31,  -16,  -16,  0,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95B87E, {
    {     31,   16,    0,  0,  2,  2 }, {     30,   16,    0,  0,  2,  2 }, {     29,   16,    1,  0,  2,  2 }, {     28,   16,    1,  0,  2,  2 }, {     27,   16,    2,  0,  2,  2 },
    {     26,   16,    2,  0,  2,  2 }, {     25,   16,    3,  0,  2,  2 }, {     24,   16,    3, 31,  2,  2 }, {     23,   15,    4, 31,  2,  2 }, {     22,   15,    4, 31,  2,  2 },
    {     21,   15,    5, 31,  2,  2 }, {     20,   15,    5, 31,  2,  2 }, {     19,   15,    6, 31,  2,  2 }, {     18,   15,    6, 31,  2,  2 }, {     17,   14,    7, 31,  2,  2 },
    {     16,   14,    8, 31,  2,  2 }, {     15,   14,    8, 31,  2,  2 }, {     14,   14,    8, 31,  2,  2 }, {     13,   14,    9, 31,  2,  2 }, {     12,   13,    9, 31,  2,  2 },
    {     11,   13,   10, 31,  2,  2 }, {     10,   13,   11, 30,  2,  2 }, {      9,   13,   11, 30,  2,  2 }, {      8,   12,   12, 30,  2,  2 }, {      7,   12,   12, 30,  2,  2 },
    {      6,   12,   13, 30,  2,  2 }, {      5,   11,   13, 30,  2,  2 }, {      4,   11,   14, 30,  2,  2 }, {      3,   11,   14, 30,  2,  2 }, {      2,   10,   15, 30,  2,  2 },
    {      1,   10,   15, 30,  2,  2 }, {      0,    9,   16, 30,  2,  2 }, {     -1,    9,   17, 30,  2,  2 }, {     -2,    8,   17, 30,  2,  2 }, {     -3,    8,   18, 30,  2,  2 },
    {     -4,    7,   18, 30,  2,  2 }, {     -5,    7,   19, 29,  2,  2 }, {     -6,    6,   19, 29,  2,  2 }, {     -7,    6,   20, 29,  2,  2 }, {     -8,    5,   21, 29,  2,  2 },
    {     -9,    4,   21, 29,  2,  2 }, {    -10,    4,   22, 29,  2,  2 }, {    -11,    3,   22, 29,  2,  2 }, {    -12,    2,   23, 29,  2,  2 }, {    -13,    2,   24, 29,  2,  2 },
    {    -14,    1,   24, 29,  2,  2 }, {    -15,    0,   25, 29,  2,  2 }, {    -16,    0,   26, 29,  2,  2 }, {    -17,   -1,   26, 29,  2,  2 }, {    -18,   -2,   27, 28,  2,  2 },
    {    -19,   -3,   27, 28,  2,  2 }, {    -20,   -3,   28, 28,  2,  2 }, {    -21,   -4,   29, 28,  2,  2 }, {    -22,   -5,   29, 28,  2,  2 }, {    -23,   -6,   30, 28,  2,  2 },
    {    -24,   -7,   31, 28,  2,  2 }, {    -25,   -7,   31, 28,  2,  2 }, {    -26,   -8,   32, 28,  2,  2 }, {    -27,   -9,   32, 28,  2,  2 }, {    -28,  -10,   33, 28,  2,  2 },
    {    -29,  -11,   34, 28,  2,  2 }, {    -29,  -12,   34, 28,  2,  2 }, {    -30,  -13,   35, 27,  2,  2 }, {    -31,  -14,   36, 27,  2,  2 }, {    -32,  -15,   36, 27,  2,  2 },
    {    -32,  -16,   37, 27,  2,  2 }, {    -33,  -17,   37, 27,  2,  2 }, {    -34,  -18,   38, 27,  2,  2 }, {    -34,  -19,   39, 27,  2,  2 }, {    -35,  -20,   39, 27,  2,  2 },
    {    -36,  -21,   40, 27,  2,  2 }, {    -36,  -22,   41, 27,  2,  2 }, {    -37,  -23,   41, 27,  2,  2 }, {    -38,  -24,   42, 27,  2,  2 }, {    -38,  -25,   42, 27,  2,  2 },
    {    -39,  -26,   43, 26,  2,  2 }, {    -39,  -27,   44, 26,  2,  2 }, {    -40,  -28,   44, 26,  2,  2 }, {    -40,  -29,   45, 26,  2,  2 }, {    -41,  -30,   45, 26,  2,  2 },
    {    -41,  -31,   46, 26,  2,  2 }, {    -42,  -32,   46, 26,  2,  2 }, {    -42,  -33,   47, 26,  2,  2 }, {    -43,  -34,   48, 26,  2,  2 }, {    -43,  -35,   48, 26,  2,  2 },
    {    -43,  -36,   49, 26,  2,  2 }, {    -44,  -37,   49, 26,  2,  2 }, {    -44,  -38,   50, 26,  2,  2 }, {    -44,  -39,   50, 26,  2,  2 }, {    -45,  -40,   51, 25,  2,  2 },
    {    -45,  -41,   51, 25,  2,  2 }, {    -45,  -42,   52, 25,  2,  2 }, {    -45,  -43,   52, 25,  2,  2 }, {    -46,  -44,   53, 25,  2,  2 }, {    -46,  -45,   54, 25,  2,  2 },
    {    -46,  -46,   54, 25,  2,  2 }, {    -46,  -47,   55, 25,  2,  2 }, {    -46,  -48,   55, 25,  2,  2 }, {    -47,  -49,   55, 25,  2,  2 }, {    -47,  -50,   56, 25,  2,  2 },
    {    -47,  -51,   57, 25,  2,  2 }, {    -47,  -52,   57, 25,  2,  2 }, {    -47,  -53,   58, 25,  2,  2 }, {    -47,  -54,   58, 25,  2,  2 }, {    -48,  -55,   59, 25,  2,  2 },
    {    -48,  -56,   59, 24,  2,  2 }, {    -48,  -57,   60, 24,  2,  2 }, {    -48,  -58,   60, 24,  2,  2 }, {    -48,  -59,   61, 24,  2,  2 }, {    -48,  -60,   61, 24,  2,  2 },
    {    -48,  -61,   62, 24,  2,  2 }, {    -48,  -62,   62, 24,  2,  2 }, {    -48,  -63,   63, 24,  2,  2 }, {    -48,  -64,   64, 24,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95BC82, {
    {     16,    0,    0,  8,  2,  2 }, {     16,    1,    0,  8,  2,  2 }, {     16,    2,    0,  8,  2,  2 }, {     16,    3,    1,  8,  2,  2 }, {     16,    4,    1,  8,  2,  2 },
    {     16,    5,    2,  8,  2,  2 }, {     16,    6,    2,  8,  2,  2 }, {     16,    7,    3,  8,  2,  2 }, {     16,    8,    3,  7,  2,  2 }, {     15,    9,    4,  7,  2,  2 },
    {     15,   10,    4,  7,  2,  2 }, {     15,   11,    5,  7,  2,  2 }, {     15,   12,    5,  7,  2,  2 }, {     15,   13,    6,  7,  2,  2 }, {     15,   14,    6,  7,  2,  2 },
    {     14,   15,    7,  7,  2,  2 }, {     14,   16,    8,  7,  2,  2 }, {     14,   17,    8,  7,  2,  2 }, {     14,   18,    8,  7,  2,  2 }, {     14,   19,    9,  7,  2,  2 },
    {     13,   20,    9,  7,  2,  2 }, {     13,   21,   10,  7,  2,  2 }, {     13,   22,   11,  6,  2,  2 }, {     13,   23,   11,  6,  2,  2 }, {     12,   24,   12,  6,  2,  2 },
    {     12,   25,   12,  6,  2,  2 }, {     12,   26,   13,  6,  2,  2 }, {     11,   27,   13,  6,  2,  2 }, {     11,   28,   14,  6,  2,  2 }, {     11,   29,   14,  6,  2,  2 },
    {     10,   30,   15,  6,  2,  2 }, {     10,   31,   15,  6,  2,  2 }, {      9,   32,   16,  6,  2,  2 }, {      9,   33,   17,  6,  2,  2 }, {      8,   34,   17,  6,  2,  2 },
    {      8,   35,   18,  6,  2,  2 }, {      7,   36,   18,  6,  2,  2 }, {      7,   37,   19,  5,  2,  2 }, {      6,   38,   19,  5,  2,  2 }, {      6,   39,   20,  5,  2,  2 },
    {      5,   40,   21,  5,  2,  2 }, {      4,   41,   21,  5,  2,  2 }, {      4,   42,   22,  5,  2,  2 }, {      3,   43,   22,  5,  2,  2 }, {      2,   44,   23,  5,  2,  2 },
    {      2,   45,   24,  5,  2,  2 }, {      1,   46,   24,  5,  2,  2 }, {      0,   47,   25,  5,  2,  2 }, {      0,   48,   26,  5,  2,  2 }, {     -1,   49,   26,  5,  2,  2 },
    {     -2,   50,   27,  4,  2,  2 }, {     -3,   51,   27,  4,  2,  2 }, {     -3,   52,   28,  4,  2,  2 }, {     -4,   53,   29,  4,  2,  2 }, {     -5,   54,   29,  4,  2,  2 },
    {     -6,   55,   30,  4,  2,  2 }, {     -7,   56,   31,  4,  2,  2 }, {     -7,   57,   31,  4,  2,  2 }, {     -8,   58,   32,  4,  2,  2 }, {     -9,   59,   32,  4,  2,  2 },
    {    -10,   60,   33,  4,  2,  2 }, {    -11,   61,   34,  4,  2,  2 }, {    -12,   61,   34,  4,  2,  2 }, {    -13,   62,   35,  3,  2,  2 }, {    -14,   63,   36,  3,  2,  2 },
    {    -15,   64,   36,  3,  2,  2 }, {    -16,   64,   37,  3,  2,  2 }, {    -17,   65,   37,  3,  2,  2 }, {    -18,   66,   38,  3,  2,  2 }, {    -19,   66,   39,  3,  2,  2 },
    {    -20,   67,   39,  3,  2,  2 }, {    -21,   68,   40,  3,  2,  2 }, {    -22,   68,   41,  3,  2,  2 }, {    -23,   69,   41,  3,  2,  2 }, {    -24,   70,   42,  3,  2,  2 },
    {    -25,   70,   42,  3,  2,  2 }, {    -26,   71,   43,  2,  2,  2 }, {    -27,   71,   44,  2,  2,  2 }, {    -28,   72,   44,  2,  2,  2 }, {    -29,   72,   45,  2,  2,  2 },
    {    -30,   73,   45,  2,  2,  2 }, {    -31,   73,   46,  2,  2,  2 }, {    -32,   74,   46,  2,  2,  2 }, {    -33,   74,   47,  2,  2,  2 }, {    -34,   75,   48,  2,  2,  2 },
    {    -35,   75,   48,  2,  2,  2 }, {    -36,   75,   49,  2,  2,  2 }, {    -37,   76,   49,  2,  2,  2 }, {    -38,   76,   50,  2,  2,  2 }, {    -39,   76,   50,  2,  2,  2 },
    {    -40,   77,   51,  1,  2,  2 }, {    -41,   77,   51,  1,  2,  2 }, {    -42,   77,   52,  1,  2,  2 }, {    -43,   77,   52,  1,  2,  2 }, {    -44,   78,   53,  1,  2,  2 },
    {    -45,   78,   54,  1,  2,  2 }, {    -46,   78,   54,  1,  2,  2 }, {    -47,   78,   55,  1,  2,  2 }, {    -48,   78,   55,  1,  2,  2 }, {    -49,   79,   55,  1,  2,  2 },
    {    -50,   79,   56,  1,  2,  2 }, {    -51,   79,   57,  1,  2,  2 }, {    -52,   79,   57,  1,  2,  2 }, {    -53,   79,   58,  1,  2,  2 }, {    -54,   79,   58,  1,  2,  2 },
    {    -55,   80,   59,  1,  2,  2 }, {    -56,   80,   59,  0,  2,  2 }, {    -57,   80,   60,  0,  2,  2 }, {    -58,   80,   60,  0,  2,  2 }, {    -59,   80,   61,  0,  2,  2 },
    {    -60,   80,   61,  0,  2,  2 }, {    -61,   80,   62,  0,  2,  2 }, {    -62,   80,   62,  0,  2,  2 }, {    -63,   80,   63,  0,  2,  2 }, {    -64,   80,   64,  0,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95C08F, {
    {      0,   16,    0, 16,  2,  2 }, {      1,   16,    0, 16,  2,  2 }, {      2,   16,    0, 16,  2,  2 }, {      3,   16,    1, 16,  2,  2 }, {      4,   16,    1, 16,  2,  2 },
    {      5,   16,    2, 16,  2,  2 }, {      6,   16,    2, 16,  2,  2 }, {      7,   16,    3, 16,  2,  2 }, {      8,   16,    3, 15,  2,  2 }, {      9,   17,    4, 15,  2,  2 },
    {     10,   17,    5, 15,  2,  2 }, {     11,   17,    5, 15,  2,  2 }, {     12,   17,    5, 15,  2,  2 }, {     13,   17,    6, 15,  2,  2 }, {     14,   17,    6, 15,  2,  2 },
    {     15,   18,    7, 15,  2,  2 }, {     16,   18,    8, 15,  2,  2 }, {     17,   18,    8, 15,  2,  2 }, {     18,   18,    9, 15,  2,  2 }, {     19,   18,    9, 15,  2,  2 },
    {     20,   19,   10, 15,  2,  2 }, {     21,   19,   10, 15,  2,  2 }, {     22,   19,   11, 14,  2,  2 }, {     23,   19,   11, 14,  2,  2 }, {     24,   20,   12, 14,  2,  2 },
    {     25,   20,   12, 14,  2,  2 }, {     26,   20,   13, 14,  2,  2 }, {     27,   21,   13, 14,  2,  2 }, {     28,   21,   14, 14,  2,  2 }, {     29,   21,   14, 14,  2,  2 },
    {     30,   22,   15, 14,  2,  2 }, {     31,   22,   16, 14,  2,  2 }, {     32,   23,   16, 14,  2,  2 }, {     33,   23,   17, 14,  2,  2 }, {     34,   24,   17, 14,  2,  2 },
    {     35,   24,   18, 14,  2,  2 }, {     36,   25,   18, 14,  2,  2 }, {     37,   25,   19, 13,  2,  2 }, {     38,   26,   20, 13,  2,  2 }, {     39,   26,   20, 13,  2,  2 },
    {     40,   27,   21, 13,  2,  2 }, {     41,   28,   21, 13,  2,  2 }, {     42,   28,   22, 13,  2,  2 }, {     43,   29,   23, 13,  2,  2 }, {     44,   30,   23, 13,  2,  2 },
    {     45,   30,   24, 13,  2,  2 }, {     46,   31,   24, 13,  2,  2 }, {     47,   32,   25, 13,  2,  2 }, {     48,   32,   26, 13,  2,  2 }, {     49,   33,   26, 13,  2,  2 },
    {     50,   34,   27, 12,  2,  2 }, {     51,   35,   28, 12,  2,  2 }, {     52,   35,   28, 12,  2,  2 }, {     53,   36,   29, 12,  2,  2 }, {     54,   37,   29, 12,  2,  2 },
    {     55,   38,   30, 12,  2,  2 }, {     56,   39,   31, 12,  2,  2 }, {     57,   39,   32, 12,  2,  2 }, {     58,   40,   32, 12,  2,  2 }, {     59,   41,   33, 12,  2,  2 },
    {     60,   42,   33, 12,  2,  2 }, {     61,   43,   34, 12,  2,  2 }, {     61,   44,   35, 12,  2,  2 }, {     62,   45,   35, 11,  2,  2 }, {     63,   46,   36, 11,  2,  2 },
    {     64,   47,   37, 11,  2,  2 }, {     64,   48,   37, 11,  2,  2 }, {     65,   49,   38, 11,  2,  2 }, {     66,   50,   38, 11,  2,  2 }, {     66,   51,   39, 11,  2,  2 },
    {     67,   52,   40, 11,  2,  2 }, {     68,   53,   40, 11,  2,  2 }, {     68,   54,   41, 11,  2,  2 }, {     69,   55,   41, 11,  2,  2 }, {     70,   56,   42, 11,  2,  2 },
    {     70,   57,   43, 11,  2,  2 }, {     71,   58,   43, 10,  2,  2 }, {     71,   59,   44, 10,  2,  2 }, {     72,   60,   44, 10,  2,  2 }, {     72,   61,   45, 10,  2,  2 },
    {     73,   62,   46, 10,  2,  2 }, {     73,   63,   46, 10,  2,  2 }, {     74,   64,   47, 10,  2,  2 }, {     74,   65,   47, 10,  2,  2 }, {     75,   66,   48, 10,  2,  2 },
    {     75,   67,   49, 10,  2,  2 }, {     75,   68,   49, 10,  2,  2 }, {     76,   69,   50, 10,  2,  2 }, {     76,   70,   50, 10,  2,  2 }, {     76,   71,   51, 10,  2,  2 },
    {     77,   72,   51,  9,  2,  2 }, {     77,   73,   52,  9,  2,  2 }, {     77,   74,   52,  9,  2,  2 }, {     77,   75,   53,  9,  2,  2 }, {     78,   76,   53,  9,  2,  2 },
    {     78,   77,   54,  9,  2,  2 }, {     78,   78,   54,  9,  2,  2 }, {     78,   79,   55,  9,  2,  2 }, {     78,   80,   55,  9,  2,  2 }, {     79,   81,   56,  9,  2,  2 },
    {     79,   82,   57,  9,  2,  2 }, {     79,   83,   57,  9,  2,  2 }, {     79,   84,   58,  9,  2,  2 }, {     79,   85,   58,  9,  2,  2 }, {     79,   86,   58,  9,  2,  2 },
    {     80,   87,   59,  9,  2,  2 }, {     80,   88,   60,  8,  2,  2 }, {     80,   89,   60,  8,  2,  2 }, {     80,   90,   61,  8,  2,  2 }, {     80,   91,   61,  8,  2,  2 },
    {     80,   92,   62,  8,  2,  2 }, {     80,   93,   62,  8,  2,  2 }, {     80,   94,   63,  8,  2,  2 }, {     80,   95,   63,  8,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95C493, {
    {     16,   31,    0, 24,  2,  2 }, {     16,   30,    0, 24,  2,  2 }, {     16,   29,    1, 24,  2,  2 }, {     16,   28,    1, 24,  2,  2 }, {     16,   27,    2, 24,  2,  2 },
    {     16,   26,    2, 24,  2,  2 }, {     16,   25,    3, 24,  2,  2 }, {     16,   24,    3, 23,  2,  2 }, {     17,   23,    4, 23,  2,  2 }, {     17,   22,    5, 23,  2,  2 },
    {     17,   21,    5, 23,  2,  2 }, {     17,   20,    5, 23,  2,  2 }, {     17,   19,    6, 23,  2,  2 }, {     17,   18,    6, 23,  2,  2 }, {     18,   17,    7, 23,  2,  2 },
    {     18,   16,    8, 23,  2,  2 }, {     18,   15,    8, 23,  2,  2 }, {     18,   14,    9, 23,  2,  2 }, {     18,   13,    9, 23,  2,  2 }, {     19,   12,   10, 23,  2,  2 },
    {     19,   11,   10, 23,  2,  2 }, {     19,   10,   11, 22,  2,  2 }, {     19,    9,   11, 22,  2,  2 }, {     20,    8,   12, 22,  2,  2 }, {     20,    7,   12, 22,  2,  2 },
    {     20,    6,   13, 22,  2,  2 }, {     21,    5,   13, 22,  2,  2 }, {     21,    4,   14, 22,  2,  2 }, {     21,    3,   14, 22,  2,  2 }, {     22,    2,   15, 22,  2,  2 },
    {     22,    1,   16, 22,  2,  2 }, {     23,    0,   16, 22,  2,  2 }, {     23,   -1,   17, 22,  2,  2 }, {     24,   -2,   17, 22,  2,  2 }, {     24,   -3,   18, 22,  2,  2 },
    {     25,   -4,   18, 22,  2,  2 }, {     25,   -5,   19, 21,  2,  2 }, {     26,   -6,   20, 21,  2,  2 }, {     26,   -7,   20, 21,  2,  2 }, {     27,   -8,   21, 21,  2,  2 },
    {     28,   -9,   21, 21,  2,  2 }, {     28,  -10,   22, 21,  2,  2 }, {     29,  -11,   23, 21,  2,  2 }, {     30,  -12,   23, 21,  2,  2 }, {     30,  -13,   24, 21,  2,  2 },
    {     31,  -14,   24, 21,  2,  2 }, {     32,  -15,   25, 21,  2,  2 }, {     32,  -16,   26, 21,  2,  2 }, {     33,  -17,   26, 21,  2,  2 }, {     34,  -18,   27, 20,  2,  2 },
    {     35,  -19,   28, 20,  2,  2 }, {     35,  -20,   28, 20,  2,  2 }, {     36,  -21,   29, 20,  2,  2 }, {     37,  -22,   29, 20,  2,  2 }, {     38,  -23,   30, 20,  2,  2 },
    {     39,  -24,   31, 20,  2,  2 }, {     39,  -25,   32, 20,  2,  2 }, {     40,  -26,   32, 20,  2,  2 }, {     41,  -27,   33, 20,  2,  2 }, {     42,  -28,   33, 20,  2,  2 },
    {     43,  -29,   34, 20,  2,  2 }, {     44,  -29,   35, 20,  2,  2 }, {     45,  -30,   35, 19,  2,  2 }, {     46,  -31,   36, 19,  2,  2 }, {     47,  -32,   37, 19,  2,  2 },
    {     48,  -32,   37, 19,  2,  2 }, {     49,  -33,   38, 19,  2,  2 }, {     50,  -34,   38, 19,  2,  2 }, {     51,  -34,   39, 19,  2,  2 }, {     52,  -35,   40, 19,  2,  2 },
    {     53,  -36,   40, 19,  2,  2 }, {     54,  -36,   41, 19,  2,  2 }, {     55,  -37,   41, 19,  2,  2 }, {     56,  -38,   42, 19,  2,  2 }, {     57,  -38,   43, 19,  2,  2 },
    {     58,  -39,   43, 18,  2,  2 }, {     59,  -39,   44, 18,  2,  2 }, {     60,  -40,   44, 18,  2,  2 }, {     61,  -40,   45, 18,  2,  2 }, {     62,  -41,   46, 18,  2,  2 },
    {     63,  -41,   46, 18,  2,  2 }, {     64,  -42,   47, 18,  2,  2 }, {     65,  -42,   47, 18,  2,  2 }, {     66,  -43,   48, 18,  2,  2 }, {     67,  -43,   49, 18,  2,  2 },
    {     68,  -43,   49, 18,  2,  2 }, {     69,  -44,   50, 18,  2,  2 }, {     70,  -44,   50, 18,  2,  2 }, {     71,  -44,   51, 18,  2,  2 }, {     72,  -45,   51, 17,  2,  2 },
    {     73,  -45,   52, 17,  2,  2 }, {     74,  -45,   52, 17,  2,  2 }, {     75,  -45,   53, 17,  2,  2 }, {     76,  -46,   53, 17,  2,  2 }, {     77,  -46,   54, 17,  2,  2 },
    {     78,  -46,   54, 17,  2,  2 }, {     79,  -46,   55, 17,  2,  2 }, {     80,  -46,   55, 17,  2,  2 }, {     81,  -47,   56, 17,  2,  2 }, {     82,  -47,   57, 17,  2,  2 },
    {     83,  -47,   57, 17,  2,  2 }, {     84,  -47,   58, 17,  2,  2 }, {     85,  -47,   58, 17,  2,  2 }, {     86,  -47,   58, 17,  2,  2 }, {     87,  -48,   59, 17,  2,  2 },
    {     88,  -48,   60, 16,  2,  2 }, {     89,  -48,   60, 16,  2,  2 }, {     90,  -48,   61, 16,  2,  2 }, {     91,  -48,   61, 16,  2,  2 }, {     92,  -48,   62, 16,  2,  2 },
    {     93,  -48,   62, 16,  2,  2 }, {     94,  -48,   63, 16,  2,  2 }, {     95,  -48,   63, 16,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95C88E, {
    {     31,   16,    0,  0,  2,  4 }, {     30,   16,    0,  0,  2,  4 }, {     29,   16,    1,  0,  2,  4 }, {     28,   16,    1,  0,  2,  4 }, {     27,   16,    2,  0,  2,  4 },
    {     26,   16,    2,  0,  2,  4 }, {     25,   16,    3,  0,  2,  4 }, {     24,   16,    3,  1,  2,  4 }, {     23,   17,    4,  1,  2,  4 }, {     22,   17,    5,  1,  2,  4 },
    {     21,   17,    5,  1,  2,  4 }, {     20,   17,    5,  1,  2,  4 }, {     19,   17,    6,  1,  2,  4 }, {     18,   17,    6,  1,  2,  4 }, {     17,   18,    7,  1,  2,  4 },
    {     16,   18,    8,  1,  2,  4 }, {     15,   18,    8,  1,  2,  4 }, {     14,   18,    9,  1,  2,  4 }, {     13,   18,    9,  1,  2,  4 }, {     12,   19,   10,  1,  2,  4 },
    {     11,   19,   10,  1,  2,  4 }, {     10,   19,   11,  2,  2,  4 }, {      9,   19,   11,  2,  2,  4 }, {      8,   20,   12,  2,  2,  4 }, {      7,   20,   12,  2,  2,  4 },
    {      6,   20,   13,  2,  2,  4 }, {      5,   21,   13,  2,  2,  4 }, {      4,   21,   14,  2,  2,  4 }, {      3,   21,   14,  2,  2,  4 }, {      2,   22,   15,  2,  2,  4 },
    {      1,   22,   16,  2,  2,  4 }, {      0,   23,   16,  2,  2,  4 }, {     -1,   23,   17,  2,  2,  4 }, {     -2,   24,   17,  2,  2,  4 }, {     -3,   24,   18,  2,  2,  4 },
    {     -4,   25,   18,  2,  2,  4 }, {     -5,   25,   19,  3,  2,  4 }, {     -6,   26,   20,  3,  2,  4 }, {     -7,   26,   20,  3,  2,  4 }, {     -8,   27,   21,  3,  2,  4 },
    {     -9,   28,   21,  3,  2,  4 }, {    -10,   28,   22,  3,  2,  4 }, {    -11,   29,   23,  3,  2,  4 }, {    -12,   30,   23,  3,  2,  4 }, {    -13,   30,   24,  3,  2,  4 },
    {    -14,   31,   24,  3,  2,  4 }, {    -15,   32,   25,  3,  2,  4 }, {    -16,   32,   26,  3,  2,  4 }, {    -17,   33,   26,  3,  2,  4 }, {    -18,   34,   27,  4,  2,  4 },
    {    -19,   35,   28,  4,  2,  4 }, {    -20,   35,   28,  4,  2,  4 }, {    -21,   36,   29,  4,  2,  4 }, {    -22,   37,   29,  4,  2,  4 }, {    -23,   38,   30,  4,  2,  4 },
    {    -24,   39,   31,  4,  2,  4 }, {    -25,   39,   32,  4,  2,  4 }, {    -26,   40,   32,  4,  2,  4 }, {    -27,   41,   33,  4,  2,  4 }, {    -28,   42,   33,  4,  2,  4 },
    {    -29,   43,   34,  4,  2,  4 }, {    -29,   44,   35,  4,  2,  4 }, {    -30,   45,   35,  5,  2,  4 }, {    -31,   46,   36,  5,  2,  4 }, {    -32,   47,   37,  5,  2,  4 },
    {    -32,   48,   37,  5,  2,  4 }, {    -33,   49,   38,  5,  2,  4 }, {    -34,   50,   38,  5,  2,  4 }, {    -34,   51,   39,  5,  2,  4 }, {    -35,   52,   40,  5,  2,  4 },
    {    -36,   53,   40,  5,  2,  4 }, {    -36,   54,   41,  5,  2,  4 }, {    -37,   55,   41,  5,  2,  4 }, {    -38,   56,   42,  5,  2,  4 }, {    -38,   57,   43,  5,  2,  4 },
    {    -39,   58,   43,  6,  2,  4 }, {    -39,   59,   44,  6,  2,  4 }, {    -40,   60,   44,  6,  2,  4 }, {    -40,   61,   45,  6,  2,  4 }, {    -41,   62,   46,  6,  2,  4 },
    {    -41,   63,   46,  6,  2,  4 }, {    -42,   64,   47,  6,  2,  4 }, {    -42,   65,   47,  6,  2,  4 }, {    -43,   66,   48,  6,  2,  4 }, {    -43,   67,   49,  6,  2,  4 },
    {    -43,   68,   49,  6,  2,  4 }, {    -44,   69,   50,  6,  2,  4 }, {    -44,   70,   50,  6,  2,  4 }, {    -44,   71,   51,  6,  2,  4 }, {    -45,   72,   51,  7,  2,  4 },
    {    -45,   73,   52,  7,  2,  4 }, {    -45,   74,   52,  7,  2,  4 }, {    -45,   75,   53,  7,  2,  4 }, {    -46,   76,   53,  7,  2,  4 }, {    -46,   77,   54,  7,  2,  4 },
    {    -46,   78,   54,  7,  2,  4 }, {    -46,   79,   55,  7,  2,  4 }, {    -46,   80,   55,  7,  2,  4 }, {    -47,   81,   56,  7,  2,  4 }, {    -47,   82,   57,  7,  2,  4 },
    {    -47,   83,   57,  7,  2,  4 }, {    -47,   84,   58,  7,  2,  4 }, {    -47,   85,   58,  7,  2,  4 }, {    -47,   86,   58,  7,  2,  4 }, {    -48,   87,   59,  7,  2,  4 },
    {    -48,   88,   60,  8,  2,  4 }, {    -48,   89,   60,  8,  2,  4 }, {    -48,   90,   61,  8,  2,  4 }, {    -48,   91,   61,  8,  2,  4 }, {    -48,   92,   62,  8,  2,  4 },
    {    -48,   93,   62,  8,  2,  4 }, {    -48,   94,   63,  8,  2,  4 }, {    -48,   95,   63,  8,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95CC89, {
    {     16,    0,    0,  8,  2,  4 }, {     16,    1,    0,  8,  2,  4 }, {     16,    2,    0,  8,  2,  4 }, {     16,    3,    1,  8,  2,  4 }, {     16,    4,    1,  8,  2,  4 },
    {     16,    5,    2,  8,  2,  4 }, {     16,    6,    2,  8,  2,  4 }, {     16,    7,    3,  8,  2,  4 }, {     16,    8,    3,  9,  2,  4 }, {     17,    9,    4,  9,  2,  4 },
    {     17,   10,    5,  9,  2,  4 }, {     17,   11,    5,  9,  2,  4 }, {     17,   12,    5,  9,  2,  4 }, {     17,   13,    6,  9,  2,  4 }, {     17,   14,    6,  9,  2,  4 },
    {     18,   15,    7,  9,  2,  4 }, {     18,   16,    8,  9,  2,  4 }, {     18,   17,    8,  9,  2,  4 }, {     18,   18,    9,  9,  2,  4 }, {     18,   19,    9,  9,  2,  4 },
    {     19,   20,   10,  9,  2,  4 }, {     19,   21,   10,  9,  2,  4 }, {     19,   22,   11, 10,  2,  4 }, {     19,   23,   11, 10,  2,  4 }, {     20,   24,   12, 10,  2,  4 },
    {     20,   25,   12, 10,  2,  4 }, {     20,   26,   13, 10,  2,  4 }, {     21,   27,   13, 10,  2,  4 }, {     21,   28,   14, 10,  2,  4 }, {     21,   29,   14, 10,  2,  4 },
    {     22,   30,   15, 10,  2,  4 }, {     22,   31,   16, 10,  2,  4 }, {     23,   32,   16, 10,  2,  4 }, {     23,   33,   17, 10,  2,  4 }, {     24,   34,   17, 10,  2,  4 },
    {     24,   35,   18, 10,  2,  4 }, {     25,   36,   18, 10,  2,  4 }, {     25,   37,   19, 11,  2,  4 }, {     26,   38,   20, 11,  2,  4 }, {     26,   39,   20, 11,  2,  4 },
    {     27,   40,   21, 11,  2,  4 }, {     28,   41,   21, 11,  2,  4 }, {     28,   42,   22, 11,  2,  4 }, {     29,   43,   23, 11,  2,  4 }, {     30,   44,   23, 11,  2,  4 },
    {     30,   45,   24, 11,  2,  4 }, {     31,   46,   24, 11,  2,  4 }, {     32,   47,   25, 11,  2,  4 }, {     32,   48,   26, 11,  2,  4 }, {     33,   49,   26, 11,  2,  4 },
    {     34,   50,   27, 12,  2,  4 }, {     35,   51,   28, 12,  2,  4 }, {     35,   52,   28, 12,  2,  4 }, {     36,   53,   29, 12,  2,  4 }, {     37,   54,   29, 12,  2,  4 },
    {     38,   55,   30, 12,  2,  4 }, {     39,   56,   31, 12,  2,  4 }, {     39,   57,   32, 12,  2,  4 }, {     40,   58,   32, 12,  2,  4 }, {     41,   59,   33, 12,  2,  4 },
    {     42,   60,   33, 12,  2,  4 }, {     43,   61,   34, 12,  2,  4 }, {     44,   61,   35, 12,  2,  4 }, {     45,   62,   35, 13,  2,  4 }, {     46,   63,   36, 13,  2,  4 },
    {     47,   64,   37, 13,  2,  4 }, {     48,   64,   37, 13,  2,  4 }, {     49,   65,   38, 13,  2,  4 }, {     50,   66,   38, 13,  2,  4 }, {     51,   66,   39, 13,  2,  4 },
    {     52,   67,   40, 13,  2,  4 }, {     53,   68,   40, 13,  2,  4 }, {     54,   68,   41, 13,  2,  4 }, {     55,   69,   41, 13,  2,  4 }, {     56,   70,   42, 13,  2,  4 },
    {     57,   70,   43, 13,  2,  4 }, {     58,   71,   43, 14,  2,  4 }, {     59,   71,   44, 14,  2,  4 }, {     60,   72,   44, 14,  2,  4 }, {     61,   72,   45, 14,  2,  4 },
    {     62,   73,   46, 14,  2,  4 }, {     63,   73,   46, 14,  2,  4 }, {     64,   74,   47, 14,  2,  4 }, {     65,   74,   47, 14,  2,  4 }, {     66,   75,   48, 14,  2,  4 },
    {     67,   75,   49, 14,  2,  4 }, {     68,   75,   49, 14,  2,  4 }, {     69,   76,   50, 14,  2,  4 }, {     70,   76,   50, 14,  2,  4 }, {     71,   76,   51, 14,  2,  4 },
    {     72,   77,   51, 15,  2,  4 }, {     73,   77,   52, 15,  2,  4 }, {     74,   77,   52, 15,  2,  4 }, {     75,   77,   53, 15,  2,  4 }, {     76,   78,   53, 15,  2,  4 },
    {     77,   78,   54, 15,  2,  4 }, {     78,   78,   54, 15,  2,  4 }, {     79,   78,   55, 15,  2,  4 }, {     80,   78,   55, 15,  2,  4 }, {     81,   79,   56, 15,  2,  4 },
    {     82,   79,   57, 15,  2,  4 }, {     83,   79,   57, 15,  2,  4 }, {     84,   79,   58, 15,  2,  4 }, {     85,   79,   58, 15,  2,  4 }, {     86,   79,   58, 15,  2,  4 },
    {     87,   80,   59, 15,  2,  4 }, {     88,   80,   60, 16,  2,  4 }, {     89,   80,   60, 16,  2,  4 }, {     90,   80,   61, 16,  2,  4 }, {     91,   80,   61, 16,  2,  4 },
    {     92,   80,   62, 16,  2,  4 }, {     93,   80,   62, 16,  2,  4 }, {     94,   80,   63, 16,  2,  4 }, {     95,   80,   63, 16,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95D08D, {
    {      0,   16,    0, 16,  2,  4 }, {      1,   16,    0, 16,  2,  4 }, {      2,   16,    0, 16,  2,  4 }, {      3,   16,    1, 16,  2,  4 }, {      4,   16,    1, 16,  2,  4 },
    {      5,   16,    2, 16,  2,  4 }, {      6,   16,    2, 16,  2,  4 }, {      7,   16,    3, 16,  2,  4 }, {      8,   16,    3, 17,  2,  4 }, {      9,   15,    4, 17,  2,  4 },
    {     10,   15,    4, 17,  2,  4 }, {     11,   15,    5, 17,  2,  4 }, {     12,   15,    5, 17,  2,  4 }, {     13,   15,    6, 17,  2,  4 }, {     14,   15,    6, 17,  2,  4 },
    {     15,   14,    7, 17,  2,  4 }, {     16,   14,    8, 17,  2,  4 }, {     17,   14,    8, 17,  2,  4 }, {     18,   14,    8, 17,  2,  4 }, {     19,   14,    9, 17,  2,  4 },
    {     20,   13,    9, 17,  2,  4 }, {     21,   13,   10, 17,  2,  4 }, {     22,   13,   11, 18,  2,  4 }, {     23,   13,   11, 18,  2,  4 }, {     24,   12,   12, 18,  2,  4 },
    {     25,   12,   12, 18,  2,  4 }, {     26,   12,   13, 18,  2,  4 }, {     27,   11,   13, 18,  2,  4 }, {     28,   11,   14, 18,  2,  4 }, {     29,   11,   14, 18,  2,  4 },
    {     30,   10,   15, 18,  2,  4 }, {     31,   10,   15, 18,  2,  4 }, {     32,    9,   16, 18,  2,  4 }, {     33,    9,   17, 18,  2,  4 }, {     34,    8,   17, 18,  2,  4 },
    {     35,    8,   18, 18,  2,  4 }, {     36,    7,   18, 18,  2,  4 }, {     37,    7,   19, 19,  2,  4 }, {     38,    6,   19, 19,  2,  4 }, {     39,    6,   20, 19,  2,  4 },
    {     40,    5,   21, 19,  2,  4 }, {     41,    4,   21, 19,  2,  4 }, {     42,    4,   22, 19,  2,  4 }, {     43,    3,   22, 19,  2,  4 }, {     44,    2,   23, 19,  2,  4 },
    {     45,    2,   24, 19,  2,  4 }, {     46,    1,   24, 19,  2,  4 }, {     47,    0,   25, 19,  2,  4 }, {     48,    0,   26, 19,  2,  4 }, {     49,   -1,   26, 19,  2,  4 },
    {     50,   -2,   27, 20,  2,  4 }, {     51,   -3,   27, 20,  2,  4 }, {     52,   -3,   28, 20,  2,  4 }, {     53,   -4,   29, 20,  2,  4 }, {     54,   -5,   29, 20,  2,  4 },
    {     55,   -6,   30, 20,  2,  4 }, {     56,   -7,   31, 20,  2,  4 }, {     57,   -7,   31, 20,  2,  4 }, {     58,   -8,   32, 20,  2,  4 }, {     59,   -9,   32, 20,  2,  4 },
    {     60,  -10,   33, 20,  2,  4 }, {     61,  -11,   34, 20,  2,  4 }, {     61,  -12,   34, 20,  2,  4 }, {     62,  -13,   35, 21,  2,  4 }, {     63,  -14,   36, 21,  2,  4 },
    {     64,  -15,   36, 21,  2,  4 }, {     64,  -16,   37, 21,  2,  4 }, {     65,  -17,   37, 21,  2,  4 }, {     66,  -18,   38, 21,  2,  4 }, {     66,  -19,   39, 21,  2,  4 },
    {     67,  -20,   39, 21,  2,  4 }, {     68,  -21,   40, 21,  2,  4 }, {     68,  -22,   41, 21,  2,  4 }, {     69,  -23,   41, 21,  2,  4 }, {     70,  -24,   42, 21,  2,  4 },
    {     70,  -25,   42, 21,  2,  4 }, {     71,  -26,   43, 22,  2,  4 }, {     71,  -27,   44, 22,  2,  4 }, {     72,  -28,   44, 22,  2,  4 }, {     72,  -29,   45, 22,  2,  4 },
    {     73,  -30,   45, 22,  2,  4 }, {     73,  -31,   46, 22,  2,  4 }, {     74,  -32,   46, 22,  2,  4 }, {     74,  -33,   47, 22,  2,  4 }, {     75,  -34,   48, 22,  2,  4 },
    {     75,  -35,   48, 22,  2,  4 }, {     75,  -36,   49, 22,  2,  4 }, {     76,  -37,   49, 22,  2,  4 }, {     76,  -38,   50, 22,  2,  4 }, {     76,  -39,   50, 22,  2,  4 },
    {     77,  -40,   51, 23,  2,  4 }, {     77,  -41,   51, 23,  2,  4 }, {     77,  -42,   52, 23,  2,  4 }, {     77,  -43,   52, 23,  2,  4 }, {     78,  -44,   53, 23,  2,  4 },
    {     78,  -45,   54, 23,  2,  4 }, {     78,  -46,   54, 23,  2,  4 }, {     78,  -47,   55, 23,  2,  4 }, {     78,  -48,   55, 23,  2,  4 }, {     79,  -49,   55, 23,  2,  4 },
    {     79,  -50,   56, 23,  2,  4 }, {     79,  -51,   57, 23,  2,  4 }, {     79,  -52,   57, 23,  2,  4 }, {     79,  -53,   58, 23,  2,  4 }, {     79,  -54,   58, 23,  2,  4 },
    {     80,  -55,   59, 23,  2,  4 }, {     80,  -56,   59, 24,  2,  4 }, {     80,  -57,   60, 24,  2,  4 }, {     80,  -58,   60, 24,  2,  4 }, {     80,  -59,   61, 24,  2,  4 },
    {     80,  -60,   61, 24,  2,  4 }, {     80,  -61,   62, 24,  2,  4 }, {     80,  -62,   62, 24,  2,  4 }, {     80,  -63,   63, 24,  2,  4 }, {     80,  -64,   64, 24,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95D49A, {
    {     16,   31,    0, 24,  2,  4 }, {     16,   30,    0, 24,  2,  4 }, {     16,   29,    1, 24,  2,  4 }, {     16,   28,    1, 24,  2,  4 }, {     16,   27,    2, 24,  2,  4 },
    {     16,   26,    2, 24,  2,  4 }, {     16,   25,    3, 24,  2,  4 }, {     16,   24,    3, 25,  2,  4 }, {     15,   23,    4, 25,  2,  4 }, {     15,   22,    4, 25,  2,  4 },
    {     15,   21,    5, 25,  2,  4 }, {     15,   20,    5, 25,  2,  4 }, {     15,   19,    6, 25,  2,  4 }, {     15,   18,    6, 25,  2,  4 }, {     14,   17,    7, 25,  2,  4 },
    {     14,   16,    8, 25,  2,  4 }, {     14,   15,    8, 25,  2,  4 }, {     14,   14,    8, 25,  2,  4 }, {     14,   13,    9, 25,  2,  4 }, {     13,   12,    9, 25,  2,  4 },
    {     13,   11,   10, 25,  2,  4 }, {     13,   10,   11, 26,  2,  4 }, {     13,    9,   11, 26,  2,  4 }, {     12,    8,   12, 26,  2,  4 }, {     12,    7,   12, 26,  2,  4 },
    {     12,    6,   13, 26,  2,  4 }, {     11,    5,   13, 26,  2,  4 }, {     11,    4,   14, 26,  2,  4 }, {     11,    3,   14, 26,  2,  4 }, {     10,    2,   15, 26,  2,  4 },
    {     10,    1,   15, 26,  2,  4 }, {      9,    0,   16, 26,  2,  4 }, {      9,   -1,   17, 26,  2,  4 }, {      8,   -2,   17, 26,  2,  4 }, {      8,   -3,   18, 26,  2,  4 },
    {      7,   -4,   18, 26,  2,  4 }, {      7,   -5,   19, 27,  2,  4 }, {      6,   -6,   19, 27,  2,  4 }, {      6,   -7,   20, 27,  2,  4 }, {      5,   -8,   21, 27,  2,  4 },
    {      4,   -9,   21, 27,  2,  4 }, {      4,  -10,   22, 27,  2,  4 }, {      3,  -11,   22, 27,  2,  4 }, {      2,  -12,   23, 27,  2,  4 }, {      2,  -13,   24, 27,  2,  4 },
    {      1,  -14,   24, 27,  2,  4 }, {      0,  -15,   25, 27,  2,  4 }, {      0,  -16,   26, 27,  2,  4 }, {     -1,  -17,   26, 27,  2,  4 }, {     -2,  -18,   27, 28,  2,  4 },
    {     -3,  -19,   27, 28,  2,  4 }, {     -3,  -20,   28, 28,  2,  4 }, {     -4,  -21,   29, 28,  2,  4 }, {     -5,  -22,   29, 28,  2,  4 }, {     -6,  -23,   30, 28,  2,  4 },
    {     -7,  -24,   31, 28,  2,  4 }, {     -7,  -25,   32, 28,  2,  4 }, {     -8,  -26,   32, 28,  2,  4 }, {     -9,  -27,   33, 28,  2,  4 }, {    -10,  -28,   33, 28,  2,  4 },
    {    -11,  -29,   34, 28,  2,  4 }, {    -12,  -29,   35, 28,  2,  4 }, {    -13,  -30,   35, 29,  2,  4 }, {    -14,  -31,   36, 29,  2,  4 }, {    -15,  -32,   37, 29,  2,  4 },
    {    -16,  -32,   37, 29,  2,  4 }, {    -17,  -33,   38, 29,  2,  4 }, {    -18,  -34,   38, 29,  2,  4 }, {    -19,  -34,   39, 29,  2,  4 }, {    -20,  -35,   40, 29,  2,  4 },
    {    -21,  -36,   40, 29,  2,  4 }, {    -22,  -36,   41, 29,  2,  4 }, {    -23,  -37,   41, 29,  2,  4 }, {    -24,  -38,   42, 29,  2,  4 }, {    -25,  -38,   43, 29,  2,  4 },
    {    -26,  -39,   43, 30,  2,  4 }, {    -27,  -39,   44, 30,  2,  4 }, {    -28,  -40,   44, 30,  2,  4 }, {    -29,  -40,   45, 30,  2,  4 }, {    -30,  -41,   45, 30,  2,  4 },
    {    -31,  -41,   46, 30,  2,  4 }, {    -32,  -42,   47, 30,  2,  4 }, {    -33,  -42,   47, 30,  2,  4 }, {    -34,  -43,   48, 30,  2,  4 }, {    -35,  -43,   48, 30,  2,  4 },
    {    -36,  -43,   49, 30,  2,  4 }, {    -37,  -44,   49, 30,  2,  4 }, {    -38,  -44,   50, 30,  2,  4 }, {    -39,  -44,   51, 30,  2,  4 }, {    -40,  -45,   51, 31,  2,  4 },
    {    -41,  -45,   52, 31,  2,  4 }, {    -42,  -45,   52, 31,  2,  4 }, {    -43,  -45,   53, 31,  2,  4 }, {    -44,  -46,   53, 31,  2,  4 }, {    -45,  -46,   54, 31,  2,  4 },
    {    -46,  -46,   54, 31,  2,  4 }, {    -47,  -46,   55, 31,  2,  4 }, {    -48,  -46,   55, 31,  2,  4 }, {    -49,  -47,   56, 31,  2,  4 }, {    -50,  -47,   56, 31,  2,  4 },
    {    -51,  -47,   57, 31,  2,  4 }, {    -52,  -47,   57, 31,  2,  4 }, {    -53,  -47,   58, 31,  2,  4 }, {    -54,  -47,   58, 31,  2,  4 }, {    -55,  -48,   59, 31,  2,  4 },
    {    -56,  -48,   59,  0,  2,  4 }, {    -57,  -48,   60,  0,  2,  4 }, {    -58,  -48,   60,  0,  2,  4 }, {    -59,  -48,   61,  0,  2,  4 }, {    -60,  -48,   61,  0,  2,  4 },
    {    -61,  -48,   62,  0,  2,  4 }, {    -62,  -48,   62,  0,  2,  4 }, {    -63,  -48,   63,  0,  2,  4 }, {    -64,  -48,   64,  0,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95D89E, {
    {     31,   16,   15,  0,  6,  2 }, {     30,   16,   15,  0,  6,  2 }, {     29,   16,   14,  0,  6,  2 }, {     28,   16,   14,  0,  6,  2 }, {     27,   16,   13,  0,  6,  2 },
    {     26,   16,   13,  0,  6,  2 }, {     25,   16,   12,  0,  6,  2 }, {     24,   16,   12, 31,  6,  2 }, {     23,   15,   11, 31,  6,  2 }, {     22,   15,   11, 31,  6,  2 },
    {     21,   15,   10, 31,  6,  2 }, {     20,   15,   10, 31,  6,  2 }, {     19,   15,    9, 31,  6,  2 }, {     18,   15,    9, 31,  6,  2 }, {     17,   14,    8, 31,  6,  2 },
    {     16,   14,    7, 31,  6,  2 }, {     15,   14,    7, 31,  6,  2 }, {     14,   14,    7, 31,  6,  2 }, {     13,   14,    6, 31,  6,  2 }, {     12,   13,    6, 31,  6,  2 },
    {     11,   13,    5, 31,  6,  2 }, {     10,   13,    4, 30,  6,  2 }, {      9,   13,    4, 30,  6,  2 }, {      8,   12,    3, 30,  6,  2 }, {      7,   12,    3, 30,  6,  2 },
    {      6,   12,    2, 30,  6,  2 }, {      5,   11,    2, 30,  6,  2 }, {      4,   11,    1, 30,  6,  2 }, {      3,   11,    1, 30,  6,  2 }, {      2,   10,    0, 30,  6,  2 },
    {      1,   10,    0, 30,  6,  2 }, {      0,    9,   -1, 30,  6,  2 }, {     -1,    9,   -2, 30,  6,  2 }, {     -2,    8,   -2, 30,  6,  2 }, {     -3,    8,   -3, 30,  6,  2 },
    {     -4,    7,   -3, 30,  6,  2 }, {     -5,    7,   -4, 29,  6,  2 }, {     -6,    6,   -4, 29,  6,  2 }, {     -7,    6,   -5, 29,  6,  2 }, {     -8,    5,   -6, 29,  6,  2 },
    {     -9,    4,   -6, 29,  6,  2 }, {    -10,    4,   -7, 29,  6,  2 }, {    -11,    3,   -7, 29,  6,  2 }, {    -12,    2,   -8, 29,  6,  2 }, {    -13,    2,   -9, 29,  6,  2 },
    {    -14,    1,   -9, 29,  6,  2 }, {    -15,    0,  -10, 29,  6,  2 }, {    -16,    0,  -11, 29,  6,  2 }, {    -17,   -1,  -11, 29,  6,  2 }, {    -18,   -2,  -12, 28,  6,  2 },
    {    -19,   -3,  -12, 28,  6,  2 }, {    -20,   -3,  -13, 28,  6,  2 }, {    -21,   -4,  -14, 28,  6,  2 }, {    -22,   -5,  -14, 28,  6,  2 }, {    -23,   -6,  -15, 28,  6,  2 },
    {    -24,   -7,  -16, 28,  6,  2 }, {    -25,   -7,  -16, 28,  6,  2 }, {    -26,   -8,  -17, 28,  6,  2 }, {    -27,   -9,  -17, 28,  6,  2 }, {    -28,  -10,  -18, 28,  6,  2 },
    {    -29,  -11,  -19, 28,  6,  2 }, {    -29,  -12,  -19, 28,  6,  2 }, {    -30,  -13,  -20, 27,  6,  2 }, {    -31,  -14,  -21, 27,  6,  2 }, {    -32,  -15,  -21, 27,  6,  2 },
    {    -32,  -16,  -22, 27,  6,  2 }, {    -33,  -17,  -22, 27,  6,  2 }, {    -34,  -18,  -23, 27,  6,  2 }, {    -34,  -19,  -24, 27,  6,  2 }, {    -35,  -20,  -24, 27,  6,  2 },
    {    -36,  -21,  -25, 27,  6,  2 }, {    -36,  -22,  -26, 27,  6,  2 }, {    -37,  -23,  -26, 27,  6,  2 }, {    -38,  -24,  -27, 27,  6,  2 }, {    -38,  -25,  -27, 27,  6,  2 },
    {    -39,  -26,  -28, 26,  6,  2 }, {    -39,  -27,  -29, 26,  6,  2 }, {    -40,  -28,  -29, 26,  6,  2 }, {    -40,  -29,  -30, 26,  6,  2 }, {    -41,  -30,  -30, 26,  6,  2 },
    {    -41,  -31,  -31, 26,  6,  2 }, {    -42,  -32,  -31, 26,  6,  2 }, {    -42,  -33,  -32, 26,  6,  2 }, {    -43,  -34,  -33, 26,  6,  2 }, {    -43,  -35,  -33, 26,  6,  2 },
    {    -43,  -36,  -34, 26,  6,  2 }, {    -44,  -37,  -34, 26,  6,  2 }, {    -44,  -38,  -35, 26,  6,  2 }, {    -44,  -39,  -35, 26,  6,  2 }, {    -45,  -40,  -36, 25,  6,  2 },
    {    -45,  -41,  -36, 25,  6,  2 }, {    -45,  -42,  -37, 25,  6,  2 }, {    -45,  -43,  -37, 25,  6,  2 }, {    -46,  -44,  -38, 25,  6,  2 }, {    -46,  -45,  -39, 25,  6,  2 },
    {    -46,  -46,  -39, 25,  6,  2 }, {    -46,  -47,  -40, 25,  6,  2 }, {    -46,  -48,  -40, 25,  6,  2 }, {    -47,  -49,  -40, 25,  6,  2 }, {    -47,  -50,  -41, 25,  6,  2 },
    {    -47,  -51,  -42, 25,  6,  2 }, {    -47,  -52,  -42, 25,  6,  2 }, {    -47,  -53,  -43, 25,  6,  2 }, {    -47,  -54,  -43, 25,  6,  2 }, {    -48,  -55,  -44, 25,  6,  2 },
    {    -48,  -56,  -44, 24,  6,  2 }, {    -48,  -57,  -45, 24,  6,  2 }, {    -48,  -58,  -45, 24,  6,  2 }, {    -48,  -59,  -46, 24,  6,  2 }, {    -48,  -60,  -46, 24,  6,  2 },
    {    -48,  -61,  -47, 24,  6,  2 }, {    -48,  -62,  -47, 24,  6,  2 }, {    -48,  -63,  -48, 24,  6,  2 }, {    -48,  -64,  -49, 24,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95DCA2, {
    {     16,    0,   15,  8,  6,  2 }, {     16,    1,   15,  8,  6,  2 }, {     16,    2,   15,  8,  6,  2 }, {     16,    3,   14,  8,  6,  2 }, {     16,    4,   14,  8,  6,  2 },
    {     16,    5,   13,  8,  6,  2 }, {     16,    6,   13,  8,  6,  2 }, {     16,    7,   12,  8,  6,  2 }, {     16,    8,   12,  7,  6,  2 }, {     15,    9,   11,  7,  6,  2 },
    {     15,   10,   11,  7,  6,  2 }, {     15,   11,   10,  7,  6,  2 }, {     15,   12,   10,  7,  6,  2 }, {     15,   13,    9,  7,  6,  2 }, {     15,   14,    9,  7,  6,  2 },
    {     14,   15,    8,  7,  6,  2 }, {     14,   16,    7,  7,  6,  2 }, {     14,   17,    7,  7,  6,  2 }, {     14,   18,    7,  7,  6,  2 }, {     14,   19,    6,  7,  6,  2 },
    {     13,   20,    6,  7,  6,  2 }, {     13,   21,    5,  7,  6,  2 }, {     13,   22,    4,  6,  6,  2 }, {     13,   23,    4,  6,  6,  2 }, {     12,   24,    3,  6,  6,  2 },
    {     12,   25,    3,  6,  6,  2 }, {     12,   26,    2,  6,  6,  2 }, {     11,   27,    2,  6,  6,  2 }, {     11,   28,    1,  6,  6,  2 }, {     11,   29,    1,  6,  6,  2 },
    {     10,   30,    0,  6,  6,  2 }, {     10,   31,    0,  6,  6,  2 }, {      9,   32,   -1,  6,  6,  2 }, {      9,   33,   -2,  6,  6,  2 }, {      8,   34,   -2,  6,  6,  2 },
    {      8,   35,   -3,  6,  6,  2 }, {      7,   36,   -3,  6,  6,  2 }, {      7,   37,   -4,  5,  6,  2 }, {      6,   38,   -4,  5,  6,  2 }, {      6,   39,   -5,  5,  6,  2 },
    {      5,   40,   -6,  5,  6,  2 }, {      4,   41,   -6,  5,  6,  2 }, {      4,   42,   -7,  5,  6,  2 }, {      3,   43,   -7,  5,  6,  2 }, {      2,   44,   -8,  5,  6,  2 },
    {      2,   45,   -9,  5,  6,  2 }, {      1,   46,   -9,  5,  6,  2 }, {      0,   47,  -10,  5,  6,  2 }, {      0,   48,  -11,  5,  6,  2 }, {     -1,   49,  -11,  5,  6,  2 },
    {     -2,   50,  -12,  4,  6,  2 }, {     -3,   51,  -12,  4,  6,  2 }, {     -3,   52,  -13,  4,  6,  2 }, {     -4,   53,  -14,  4,  6,  2 }, {     -5,   54,  -14,  4,  6,  2 },
    {     -6,   55,  -15,  4,  6,  2 }, {     -7,   56,  -16,  4,  6,  2 }, {     -7,   57,  -16,  4,  6,  2 }, {     -8,   58,  -17,  4,  6,  2 }, {     -9,   59,  -17,  4,  6,  2 },
    {    -10,   60,  -18,  4,  6,  2 }, {    -11,   61,  -19,  4,  6,  2 }, {    -12,   61,  -19,  4,  6,  2 }, {    -13,   62,  -20,  3,  6,  2 }, {    -14,   63,  -21,  3,  6,  2 },
    {    -15,   64,  -21,  3,  6,  2 }, {    -16,   64,  -22,  3,  6,  2 }, {    -17,   65,  -22,  3,  6,  2 }, {    -18,   66,  -23,  3,  6,  2 }, {    -19,   66,  -24,  3,  6,  2 },
    {    -20,   67,  -24,  3,  6,  2 }, {    -21,   68,  -25,  3,  6,  2 }, {    -22,   68,  -26,  3,  6,  2 }, {    -23,   69,  -26,  3,  6,  2 }, {    -24,   70,  -27,  3,  6,  2 },
    {    -25,   70,  -27,  3,  6,  2 }, {    -26,   71,  -28,  2,  6,  2 }, {    -27,   71,  -29,  2,  6,  2 }, {    -28,   72,  -29,  2,  6,  2 }, {    -29,   72,  -30,  2,  6,  2 },
    {    -30,   73,  -30,  2,  6,  2 }, {    -31,   73,  -31,  2,  6,  2 }, {    -32,   74,  -31,  2,  6,  2 }, {    -33,   74,  -32,  2,  6,  2 }, {    -34,   75,  -33,  2,  6,  2 },
    {    -35,   75,  -33,  2,  6,  2 }, {    -36,   75,  -34,  2,  6,  2 }, {    -37,   76,  -34,  2,  6,  2 }, {    -38,   76,  -35,  2,  6,  2 }, {    -39,   76,  -35,  2,  6,  2 },
    {    -40,   77,  -36,  1,  6,  2 }, {    -41,   77,  -36,  1,  6,  2 }, {    -42,   77,  -37,  1,  6,  2 }, {    -43,   77,  -37,  1,  6,  2 }, {    -44,   78,  -38,  1,  6,  2 },
    {    -45,   78,  -39,  1,  6,  2 }, {    -46,   78,  -39,  1,  6,  2 }, {    -47,   78,  -40,  1,  6,  2 }, {    -48,   78,  -40,  1,  6,  2 }, {    -49,   79,  -40,  1,  6,  2 },
    {    -50,   79,  -41,  1,  6,  2 }, {    -51,   79,  -42,  1,  6,  2 }, {    -52,   79,  -42,  1,  6,  2 }, {    -53,   79,  -43,  1,  6,  2 }, {    -54,   79,  -43,  1,  6,  2 },
    {    -55,   80,  -44,  1,  6,  2 }, {    -56,   80,  -44,  0,  6,  2 }, {    -57,   80,  -45,  0,  6,  2 }, {    -58,   80,  -45,  0,  6,  2 }, {    -59,   80,  -46,  0,  6,  2 },
    {    -60,   80,  -46,  0,  6,  2 }, {    -61,   80,  -47,  0,  6,  2 }, {    -62,   80,  -47,  0,  6,  2 }, {    -63,   80,  -48,  0,  6,  2 }, {    -64,   80,  -49,  0,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95E0AF, {
    {      0,   16,   15, 16,  6,  2 }, {      1,   16,   15, 16,  6,  2 }, {      2,   16,   15, 16,  6,  2 }, {      3,   16,   14, 16,  6,  2 }, {      4,   16,   14, 16,  6,  2 },
    {      5,   16,   13, 16,  6,  2 }, {      6,   16,   13, 16,  6,  2 }, {      7,   16,   12, 16,  6,  2 }, {      8,   16,   12, 15,  6,  2 }, {      9,   17,   11, 15,  6,  2 },
    {     10,   17,   10, 15,  6,  2 }, {     11,   17,   10, 15,  6,  2 }, {     12,   17,   10, 15,  6,  2 }, {     13,   17,    9, 15,  6,  2 }, {     14,   17,    9, 15,  6,  2 },
    {     15,   18,    8, 15,  6,  2 }, {     16,   18,    7, 15,  6,  2 }, {     17,   18,    7, 15,  6,  2 }, {     18,   18,    6, 15,  6,  2 }, {     19,   18,    6, 15,  6,  2 },
    {     20,   19,    5, 15,  6,  2 }, {     21,   19,    5, 15,  6,  2 }, {     22,   19,    4, 14,  6,  2 }, {     23,   19,    4, 14,  6,  2 }, {     24,   20,    3, 14,  6,  2 },
    {     25,   20,    3, 14,  6,  2 }, {     26,   20,    2, 14,  6,  2 }, {     27,   21,    2, 14,  6,  2 }, {     28,   21,    1, 14,  6,  2 }, {     29,   21,    1, 14,  6,  2 },
    {     30,   22,    0, 14,  6,  2 }, {     31,   22,   -1, 14,  6,  2 }, {     32,   23,   -1, 14,  6,  2 }, {     33,   23,   -2, 14,  6,  2 }, {     34,   24,   -2, 14,  6,  2 },
    {     35,   24,   -3, 14,  6,  2 }, {     36,   25,   -3, 14,  6,  2 }, {     37,   25,   -4, 13,  6,  2 }, {     38,   26,   -5, 13,  6,  2 }, {     39,   26,   -5, 13,  6,  2 },
    {     40,   27,   -6, 13,  6,  2 }, {     41,   28,   -6, 13,  6,  2 }, {     42,   28,   -7, 13,  6,  2 }, {     43,   29,   -8, 13,  6,  2 }, {     44,   30,   -8, 13,  6,  2 },
    {     45,   30,   -9, 13,  6,  2 }, {     46,   31,   -9, 13,  6,  2 }, {     47,   32,  -10, 13,  6,  2 }, {     48,   32,  -11, 13,  6,  2 }, {     49,   33,  -11, 13,  6,  2 },
    {     50,   34,  -12, 12,  6,  2 }, {     51,   35,  -13, 12,  6,  2 }, {     52,   35,  -13, 12,  6,  2 }, {     53,   36,  -14, 12,  6,  2 }, {     54,   37,  -14, 12,  6,  2 },
    {     55,   38,  -15, 12,  6,  2 }, {     56,   39,  -16, 12,  6,  2 }, {     57,   39,  -17, 12,  6,  2 }, {     58,   40,  -17, 12,  6,  2 }, {     59,   41,  -18, 12,  6,  2 },
    {     60,   42,  -18, 12,  6,  2 }, {     61,   43,  -19, 12,  6,  2 }, {     61,   44,  -20, 12,  6,  2 }, {     62,   45,  -20, 11,  6,  2 }, {     63,   46,  -21, 11,  6,  2 },
    {     64,   47,  -22, 11,  6,  2 }, {     64,   48,  -22, 11,  6,  2 }, {     65,   49,  -23, 11,  6,  2 }, {     66,   50,  -23, 11,  6,  2 }, {     66,   51,  -24, 11,  6,  2 },
    {     67,   52,  -25, 11,  6,  2 }, {     68,   53,  -25, 11,  6,  2 }, {     68,   54,  -26, 11,  6,  2 }, {     69,   55,  -26, 11,  6,  2 }, {     70,   56,  -27, 11,  6,  2 },
    {     70,   57,  -28, 11,  6,  2 }, {     71,   58,  -28, 10,  6,  2 }, {     71,   59,  -29, 10,  6,  2 }, {     72,   60,  -29, 10,  6,  2 }, {     72,   61,  -30, 10,  6,  2 },
    {     73,   62,  -31, 10,  6,  2 }, {     73,   63,  -31, 10,  6,  2 }, {     74,   64,  -32, 10,  6,  2 }, {     74,   65,  -32, 10,  6,  2 }, {     75,   66,  -33, 10,  6,  2 },
    {     75,   67,  -34, 10,  6,  2 }, {     75,   68,  -34, 10,  6,  2 }, {     76,   69,  -35, 10,  6,  2 }, {     76,   70,  -35, 10,  6,  2 }, {     76,   71,  -36, 10,  6,  2 },
    {     77,   72,  -36,  9,  6,  2 }, {     77,   73,  -37,  9,  6,  2 }, {     77,   74,  -37,  9,  6,  2 }, {     77,   75,  -38,  9,  6,  2 }, {     78,   76,  -38,  9,  6,  2 },
    {     78,   77,  -39,  9,  6,  2 }, {     78,   78,  -39,  9,  6,  2 }, {     78,   79,  -40,  9,  6,  2 }, {     78,   80,  -40,  9,  6,  2 }, {     79,   81,  -41,  9,  6,  2 },
    {     79,   82,  -42,  9,  6,  2 }, {     79,   83,  -42,  9,  6,  2 }, {     79,   84,  -43,  9,  6,  2 }, {     79,   85,  -43,  9,  6,  2 }, {     79,   86,  -43,  9,  6,  2 },
    {     80,   87,  -44,  9,  6,  2 }, {     80,   88,  -45,  8,  6,  2 }, {     80,   89,  -45,  8,  6,  2 }, {     80,   90,  -46,  8,  6,  2 }, {     80,   91,  -46,  8,  6,  2 },
    {     80,   92,  -47,  8,  6,  2 }, {     80,   93,  -47,  8,  6,  2 }, {     80,   94,  -48,  8,  6,  2 }, {     80,   95,  -48,  8,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95E4B3, {
    {     16,   31,   15, 24,  6,  2 }, {     16,   30,   15, 24,  6,  2 }, {     16,   29,   14, 24,  6,  2 }, {     16,   28,   14, 24,  6,  2 }, {     16,   27,   13, 24,  6,  2 },
    {     16,   26,   13, 24,  6,  2 }, {     16,   25,   12, 24,  6,  2 }, {     16,   24,   12, 23,  6,  2 }, {     17,   23,   11, 23,  6,  2 }, {     17,   22,   10, 23,  6,  2 },
    {     17,   21,   10, 23,  6,  2 }, {     17,   20,   10, 23,  6,  2 }, {     17,   19,    9, 23,  6,  2 }, {     17,   18,    9, 23,  6,  2 }, {     18,   17,    8, 23,  6,  2 },
    {     18,   16,    7, 23,  6,  2 }, {     18,   15,    7, 23,  6,  2 }, {     18,   14,    6, 23,  6,  2 }, {     18,   13,    6, 23,  6,  2 }, {     19,   12,    5, 23,  6,  2 },
    {     19,   11,    5, 23,  6,  2 }, {     19,   10,    4, 22,  6,  2 }, {     19,    9,    4, 22,  6,  2 }, {     20,    8,    3, 22,  6,  2 }, {     20,    7,    3, 22,  6,  2 },
    {     20,    6,    2, 22,  6,  2 }, {     21,    5,    2, 22,  6,  2 }, {     21,    4,    1, 22,  6,  2 }, {     21,    3,    1, 22,  6,  2 }, {     22,    2,    0, 22,  6,  2 },
    {     22,    1,   -1, 22,  6,  2 }, {     23,    0,   -1, 22,  6,  2 }, {     23,   -1,   -2, 22,  6,  2 }, {     24,   -2,   -2, 22,  6,  2 }, {     24,   -3,   -3, 22,  6,  2 },
    {     25,   -4,   -3, 22,  6,  2 }, {     25,   -5,   -4, 21,  6,  2 }, {     26,   -6,   -5, 21,  6,  2 }, {     26,   -7,   -5, 21,  6,  2 }, {     27,   -8,   -6, 21,  6,  2 },
    {     28,   -9,   -6, 21,  6,  2 }, {     28,  -10,   -7, 21,  6,  2 }, {     29,  -11,   -8, 21,  6,  2 }, {     30,  -12,   -8, 21,  6,  2 }, {     30,  -13,   -9, 21,  6,  2 },
    {     31,  -14,   -9, 21,  6,  2 }, {     32,  -15,  -10, 21,  6,  2 }, {     32,  -16,  -11, 21,  6,  2 }, {     33,  -17,  -11, 21,  6,  2 }, {     34,  -18,  -12, 20,  6,  2 },
    {     35,  -19,  -13, 20,  6,  2 }, {     35,  -20,  -13, 20,  6,  2 }, {     36,  -21,  -14, 20,  6,  2 }, {     37,  -22,  -14, 20,  6,  2 }, {     38,  -23,  -15, 20,  6,  2 },
    {     39,  -24,  -16, 20,  6,  2 }, {     39,  -25,  -17, 20,  6,  2 }, {     40,  -26,  -17, 20,  6,  2 }, {     41,  -27,  -18, 20,  6,  2 }, {     42,  -28,  -18, 20,  6,  2 },
    {     43,  -29,  -19, 20,  6,  2 }, {     44,  -29,  -20, 20,  6,  2 }, {     45,  -30,  -20, 19,  6,  2 }, {     46,  -31,  -21, 19,  6,  2 }, {     47,  -32,  -22, 19,  6,  2 },
    {     48,  -32,  -22, 19,  6,  2 }, {     49,  -33,  -23, 19,  6,  2 }, {     50,  -34,  -23, 19,  6,  2 }, {     51,  -34,  -24, 19,  6,  2 }, {     52,  -35,  -25, 19,  6,  2 },
    {     53,  -36,  -25, 19,  6,  2 }, {     54,  -36,  -26, 19,  6,  2 }, {     55,  -37,  -26, 19,  6,  2 }, {     56,  -38,  -27, 19,  6,  2 }, {     57,  -38,  -28, 19,  6,  2 },
    {     58,  -39,  -28, 18,  6,  2 }, {     59,  -39,  -29, 18,  6,  2 }, {     60,  -40,  -29, 18,  6,  2 }, {     61,  -40,  -30, 18,  6,  2 }, {     62,  -41,  -31, 18,  6,  2 },
    {     63,  -41,  -31, 18,  6,  2 }, {     64,  -42,  -32, 18,  6,  2 }, {     65,  -42,  -32, 18,  6,  2 }, {     66,  -43,  -33, 18,  6,  2 }, {     67,  -43,  -34, 18,  6,  2 },
    {     68,  -43,  -34, 18,  6,  2 }, {     69,  -44,  -35, 18,  6,  2 }, {     70,  -44,  -35, 18,  6,  2 }, {     71,  -44,  -36, 18,  6,  2 }, {     72,  -45,  -36, 17,  6,  2 },
    {     73,  -45,  -37, 17,  6,  2 }, {     74,  -45,  -37, 17,  6,  2 }, {     75,  -45,  -38, 17,  6,  2 }, {     76,  -46,  -38, 17,  6,  2 }, {     77,  -46,  -39, 17,  6,  2 },
    {     78,  -46,  -39, 17,  6,  2 }, {     79,  -46,  -40, 17,  6,  2 }, {     80,  -46,  -40, 17,  6,  2 }, {     81,  -47,  -41, 17,  6,  2 }, {     82,  -47,  -42, 17,  6,  2 },
    {     83,  -47,  -42, 17,  6,  2 }, {     84,  -47,  -43, 17,  6,  2 }, {     85,  -47,  -43, 17,  6,  2 }, {     86,  -47,  -43, 17,  6,  2 }, {     87,  -48,  -44, 17,  6,  2 },
    {     88,  -48,  -45, 16,  6,  2 }, {     89,  -48,  -45, 16,  6,  2 }, {     90,  -48,  -46, 16,  6,  2 }, {     91,  -48,  -46, 16,  6,  2 }, {     92,  -48,  -47, 16,  6,  2 },
    {     93,  -48,  -47, 16,  6,  2 }, {     94,  -48,  -48, 16,  6,  2 }, {     95,  -48,  -48, 16,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95E8AE, {
    {     31,   16,   15,  0,  6,  4 }, {     30,   16,   15,  0,  6,  4 }, {     29,   16,   14,  0,  6,  4 }, {     28,   16,   14,  0,  6,  4 }, {     27,   16,   13,  0,  6,  4 },
    {     26,   16,   13,  0,  6,  4 }, {     25,   16,   12,  0,  6,  4 }, {     24,   16,   12,  1,  6,  4 }, {     23,   17,   11,  1,  6,  4 }, {     22,   17,   10,  1,  6,  4 },
    {     21,   17,   10,  1,  6,  4 }, {     20,   17,   10,  1,  6,  4 }, {     19,   17,    9,  1,  6,  4 }, {     18,   17,    9,  1,  6,  4 }, {     17,   18,    8,  1,  6,  4 },
    {     16,   18,    7,  1,  6,  4 }, {     15,   18,    7,  1,  6,  4 }, {     14,   18,    6,  1,  6,  4 }, {     13,   18,    6,  1,  6,  4 }, {     12,   19,    5,  1,  6,  4 },
    {     11,   19,    5,  1,  6,  4 }, {     10,   19,    4,  2,  6,  4 }, {      9,   19,    4,  2,  6,  4 }, {      8,   20,    3,  2,  6,  4 }, {      7,   20,    3,  2,  6,  4 },
    {      6,   20,    2,  2,  6,  4 }, {      5,   21,    2,  2,  6,  4 }, {      4,   21,    1,  2,  6,  4 }, {      3,   21,    1,  2,  6,  4 }, {      2,   22,    0,  2,  6,  4 },
    {      1,   22,   -1,  2,  6,  4 }, {      0,   23,   -1,  2,  6,  4 }, {     -1,   23,   -2,  2,  6,  4 }, {     -2,   24,   -2,  2,  6,  4 }, {     -3,   24,   -3,  2,  6,  4 },
    {     -4,   25,   -3,  2,  6,  4 }, {     -5,   25,   -4,  3,  6,  4 }, {     -6,   26,   -5,  3,  6,  4 }, {     -7,   26,   -5,  3,  6,  4 }, {     -8,   27,   -6,  3,  6,  4 },
    {     -9,   28,   -6,  3,  6,  4 }, {    -10,   28,   -7,  3,  6,  4 }, {    -11,   29,   -8,  3,  6,  4 }, {    -12,   30,   -8,  3,  6,  4 }, {    -13,   30,   -9,  3,  6,  4 },
    {    -14,   31,   -9,  3,  6,  4 }, {    -15,   32,  -10,  3,  6,  4 }, {    -16,   32,  -11,  3,  6,  4 }, {    -17,   33,  -11,  3,  6,  4 }, {    -18,   34,  -12,  4,  6,  4 },
    {    -19,   35,  -13,  4,  6,  4 }, {    -20,   35,  -13,  4,  6,  4 }, {    -21,   36,  -14,  4,  6,  4 }, {    -22,   37,  -14,  4,  6,  4 }, {    -23,   38,  -15,  4,  6,  4 },
    {    -24,   39,  -16,  4,  6,  4 }, {    -25,   39,  -17,  4,  6,  4 }, {    -26,   40,  -17,  4,  6,  4 }, {    -27,   41,  -18,  4,  6,  4 }, {    -28,   42,  -18,  4,  6,  4 },
    {    -29,   43,  -19,  4,  6,  4 }, {    -29,   44,  -20,  4,  6,  4 }, {    -30,   45,  -20,  5,  6,  4 }, {    -31,   46,  -21,  5,  6,  4 }, {    -32,   47,  -22,  5,  6,  4 },
    {    -32,   48,  -22,  5,  6,  4 }, {    -33,   49,  -23,  5,  6,  4 }, {    -34,   50,  -23,  5,  6,  4 }, {    -34,   51,  -24,  5,  6,  4 }, {    -35,   52,  -25,  5,  6,  4 },
    {    -36,   53,  -25,  5,  6,  4 }, {    -36,   54,  -26,  5,  6,  4 }, {    -37,   55,  -26,  5,  6,  4 }, {    -38,   56,  -27,  5,  6,  4 }, {    -38,   57,  -28,  5,  6,  4 },
    {    -39,   58,  -28,  6,  6,  4 }, {    -39,   59,  -29,  6,  6,  4 }, {    -40,   60,  -29,  6,  6,  4 }, {    -40,   61,  -30,  6,  6,  4 }, {    -41,   62,  -31,  6,  6,  4 },
    {    -41,   63,  -31,  6,  6,  4 }, {    -42,   64,  -32,  6,  6,  4 }, {    -42,   65,  -32,  6,  6,  4 }, {    -43,   66,  -33,  6,  6,  4 }, {    -43,   67,  -34,  6,  6,  4 },
    {    -43,   68,  -34,  6,  6,  4 }, {    -44,   69,  -35,  6,  6,  4 }, {    -44,   70,  -35,  6,  6,  4 }, {    -44,   71,  -36,  6,  6,  4 }, {    -45,   72,  -36,  7,  6,  4 },
    {    -45,   73,  -37,  7,  6,  4 }, {    -45,   74,  -37,  7,  6,  4 }, {    -45,   75,  -38,  7,  6,  4 }, {    -46,   76,  -38,  7,  6,  4 }, {    -46,   77,  -39,  7,  6,  4 },
    {    -46,   78,  -39,  7,  6,  4 }, {    -46,   79,  -40,  7,  6,  4 }, {    -46,   80,  -40,  7,  6,  4 }, {    -47,   81,  -41,  7,  6,  4 }, {    -47,   82,  -42,  7,  6,  4 },
    {    -47,   83,  -42,  7,  6,  4 }, {    -47,   84,  -43,  7,  6,  4 }, {    -47,   85,  -43,  7,  6,  4 }, {    -47,   86,  -43,  7,  6,  4 }, {    -48,   87,  -44,  7,  6,  4 },
    {    -48,   88,  -45,  8,  6,  4 }, {    -48,   89,  -45,  8,  6,  4 }, {    -48,   90,  -46,  8,  6,  4 }, {    -48,   91,  -46,  8,  6,  4 }, {    -48,   92,  -47,  8,  6,  4 },
    {    -48,   93,  -47,  8,  6,  4 }, {    -48,   94,  -48,  8,  6,  4 }, {    -48,   95,  -48,  8,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95ECA9, {
    {     16,    0,   15,  8,  6,  4 }, {     16,    1,   15,  8,  6,  4 }, {     16,    2,   15,  8,  6,  4 }, {     16,    3,   14,  8,  6,  4 }, {     16,    4,   14,  8,  6,  4 },
    {     16,    5,   13,  8,  6,  4 }, {     16,    6,   13,  8,  6,  4 }, {     16,    7,   12,  8,  6,  4 }, {     16,    8,   12,  9,  6,  4 }, {     17,    9,   11,  9,  6,  4 },
    {     17,   10,   10,  9,  6,  4 }, {     17,   11,   10,  9,  6,  4 }, {     17,   12,   10,  9,  6,  4 }, {     17,   13,    9,  9,  6,  4 }, {     17,   14,    9,  9,  6,  4 },
    {     18,   15,    8,  9,  6,  4 }, {     18,   16,    7,  9,  6,  4 }, {     18,   17,    7,  9,  6,  4 }, {     18,   18,    6,  9,  6,  4 }, {     18,   19,    6,  9,  6,  4 },
    {     19,   20,    5,  9,  6,  4 }, {     19,   21,    5,  9,  6,  4 }, {     19,   22,    4, 10,  6,  4 }, {     19,   23,    4, 10,  6,  4 }, {     20,   24,    3, 10,  6,  4 },
    {     20,   25,    3, 10,  6,  4 }, {     20,   26,    2, 10,  6,  4 }, {     21,   27,    2, 10,  6,  4 }, {     21,   28,    1, 10,  6,  4 }, {     21,   29,    1, 10,  6,  4 },
    {     22,   30,    0, 10,  6,  4 }, {     22,   31,   -1, 10,  6,  4 }, {     23,   32,   -1, 10,  6,  4 }, {     23,   33,   -2, 10,  6,  4 }, {     24,   34,   -2, 10,  6,  4 },
    {     24,   35,   -3, 10,  6,  4 }, {     25,   36,   -3, 10,  6,  4 }, {     25,   37,   -4, 11,  6,  4 }, {     26,   38,   -5, 11,  6,  4 }, {     26,   39,   -5, 11,  6,  4 },
    {     27,   40,   -6, 11,  6,  4 }, {     28,   41,   -6, 11,  6,  4 }, {     28,   42,   -7, 11,  6,  4 }, {     29,   43,   -8, 11,  6,  4 }, {     30,   44,   -8, 11,  6,  4 },
    {     30,   45,   -9, 11,  6,  4 }, {     31,   46,   -9, 11,  6,  4 }, {     32,   47,  -10, 11,  6,  4 }, {     32,   48,  -11, 11,  6,  4 }, {     33,   49,  -11, 11,  6,  4 },
    {     34,   50,  -12, 12,  6,  4 }, {     35,   51,  -13, 12,  6,  4 }, {     35,   52,  -13, 12,  6,  4 }, {     36,   53,  -14, 12,  6,  4 }, {     37,   54,  -14, 12,  6,  4 },
    {     38,   55,  -15, 12,  6,  4 }, {     39,   56,  -16, 12,  6,  4 }, {     39,   57,  -17, 12,  6,  4 }, {     40,   58,  -17, 12,  6,  4 }, {     41,   59,  -18, 12,  6,  4 },
    {     42,   60,  -18, 12,  6,  4 }, {     43,   61,  -19, 12,  6,  4 }, {     44,   61,  -20, 12,  6,  4 }, {     45,   62,  -20, 13,  6,  4 }, {     46,   63,  -21, 13,  6,  4 },
    {     47,   64,  -22, 13,  6,  4 }, {     48,   64,  -22, 13,  6,  4 }, {     49,   65,  -23, 13,  6,  4 }, {     50,   66,  -23, 13,  6,  4 }, {     51,   66,  -24, 13,  6,  4 },
    {     52,   67,  -25, 13,  6,  4 }, {     53,   68,  -25, 13,  6,  4 }, {     54,   68,  -26, 13,  6,  4 }, {     55,   69,  -26, 13,  6,  4 }, {     56,   70,  -27, 13,  6,  4 },
    {     57,   70,  -28, 13,  6,  4 }, {     58,   71,  -28, 14,  6,  4 }, {     59,   71,  -29, 14,  6,  4 }, {     60,   72,  -29, 14,  6,  4 }, {     61,   72,  -30, 14,  6,  4 },
    {     62,   73,  -31, 14,  6,  4 }, {     63,   73,  -31, 14,  6,  4 }, {     64,   74,  -32, 14,  6,  4 }, {     65,   74,  -32, 14,  6,  4 }, {     66,   75,  -33, 14,  6,  4 },
    {     67,   75,  -34, 14,  6,  4 }, {     68,   75,  -34, 14,  6,  4 }, {     69,   76,  -35, 14,  6,  4 }, {     70,   76,  -35, 14,  6,  4 }, {     71,   76,  -36, 14,  6,  4 },
    {     72,   77,  -36, 15,  6,  4 }, {     73,   77,  -37, 15,  6,  4 }, {     74,   77,  -37, 15,  6,  4 }, {     75,   77,  -38, 15,  6,  4 }, {     76,   78,  -38, 15,  6,  4 },
    {     77,   78,  -39, 15,  6,  4 }, {     78,   78,  -39, 15,  6,  4 }, {     79,   78,  -40, 15,  6,  4 }, {     80,   78,  -40, 15,  6,  4 }, {     81,   79,  -41, 15,  6,  4 },
    {     82,   79,  -42, 15,  6,  4 }, {     83,   79,  -42, 15,  6,  4 }, {     84,   79,  -43, 15,  6,  4 }, {     85,   79,  -43, 15,  6,  4 }, {     86,   79,  -43, 15,  6,  4 },
    {     87,   80,  -44, 15,  6,  4 }, {     88,   80,  -45, 16,  6,  4 }, {     89,   80,  -45, 16,  6,  4 }, {     90,   80,  -46, 16,  6,  4 }, {     91,   80,  -46, 16,  6,  4 },
    {     92,   80,  -47, 16,  6,  4 }, {     93,   80,  -47, 16,  6,  4 }, {     94,   80,  -48, 16,  6,  4 }, {     95,   80,  -48, 16,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95F0AD, {
    {      0,   16,   15, 16,  6,  4 }, {      1,   16,   15, 16,  6,  4 }, {      2,   16,   15, 16,  6,  4 }, {      3,   16,   14, 16,  6,  4 }, {      4,   16,   14, 16,  6,  4 },
    {      5,   16,   13, 16,  6,  4 }, {      6,   16,   13, 16,  6,  4 }, {      7,   16,   12, 16,  6,  4 }, {      8,   16,   12, 17,  6,  4 }, {      9,   15,   11, 17,  6,  4 },
    {     10,   15,   11, 17,  6,  4 }, {     11,   15,   10, 17,  6,  4 }, {     12,   15,   10, 17,  6,  4 }, {     13,   15,    9, 17,  6,  4 }, {     14,   15,    9, 17,  6,  4 },
    {     15,   14,    8, 17,  6,  4 }, {     16,   14,    7, 17,  6,  4 }, {     17,   14,    7, 17,  6,  4 }, {     18,   14,    7, 17,  6,  4 }, {     19,   14,    6, 17,  6,  4 },
    {     20,   13,    6, 17,  6,  4 }, {     21,   13,    5, 17,  6,  4 }, {     22,   13,    4, 18,  6,  4 }, {     23,   13,    4, 18,  6,  4 }, {     24,   12,    3, 18,  6,  4 },
    {     25,   12,    3, 18,  6,  4 }, {     26,   12,    2, 18,  6,  4 }, {     27,   11,    2, 18,  6,  4 }, {     28,   11,    1, 18,  6,  4 }, {     29,   11,    1, 18,  6,  4 },
    {     30,   10,    0, 18,  6,  4 }, {     31,   10,    0, 18,  6,  4 }, {     32,    9,   -1, 18,  6,  4 }, {     33,    9,   -2, 18,  6,  4 }, {     34,    8,   -2, 18,  6,  4 },
    {     35,    8,   -3, 18,  6,  4 }, {     36,    7,   -3, 18,  6,  4 }, {     37,    7,   -4, 19,  6,  4 }, {     38,    6,   -4, 19,  6,  4 }, {     39,    6,   -5, 19,  6,  4 },
    {     40,    5,   -6, 19,  6,  4 }, {     41,    4,   -6, 19,  6,  4 }, {     42,    4,   -7, 19,  6,  4 }, {     43,    3,   -7, 19,  6,  4 }, {     44,    2,   -8, 19,  6,  4 },
    {     45,    2,   -9, 19,  6,  4 }, {     46,    1,   -9, 19,  6,  4 }, {     47,    0,  -10, 19,  6,  4 }, {     48,    0,  -11, 19,  6,  4 }, {     49,   -1,  -11, 19,  6,  4 },
    {     50,   -2,  -12, 20,  6,  4 }, {     51,   -3,  -12, 20,  6,  4 }, {     52,   -3,  -13, 20,  6,  4 }, {     53,   -4,  -14, 20,  6,  4 }, {     54,   -5,  -14, 20,  6,  4 },
    {     55,   -6,  -15, 20,  6,  4 }, {     56,   -7,  -16, 20,  6,  4 }, {     57,   -7,  -16, 20,  6,  4 }, {     58,   -8,  -17, 20,  6,  4 }, {     59,   -9,  -17, 20,  6,  4 },
    {     60,  -10,  -18, 20,  6,  4 }, {     61,  -11,  -19, 20,  6,  4 }, {     61,  -12,  -19, 20,  6,  4 }, {     62,  -13,  -20, 21,  6,  4 }, {     63,  -14,  -21, 21,  6,  4 },
    {     64,  -15,  -21, 21,  6,  4 }, {     64,  -16,  -22, 21,  6,  4 }, {     65,  -17,  -22, 21,  6,  4 }, {     66,  -18,  -23, 21,  6,  4 }, {     66,  -19,  -24, 21,  6,  4 },
    {     67,  -20,  -24, 21,  6,  4 }, {     68,  -21,  -25, 21,  6,  4 }, {     68,  -22,  -26, 21,  6,  4 }, {     69,  -23,  -26, 21,  6,  4 }, {     70,  -24,  -27, 21,  6,  4 },
    {     70,  -25,  -27, 21,  6,  4 }, {     71,  -26,  -28, 22,  6,  4 }, {     71,  -27,  -29, 22,  6,  4 }, {     72,  -28,  -29, 22,  6,  4 }, {     72,  -29,  -30, 22,  6,  4 },
    {     73,  -30,  -30, 22,  6,  4 }, {     73,  -31,  -31, 22,  6,  4 }, {     74,  -32,  -31, 22,  6,  4 }, {     74,  -33,  -32, 22,  6,  4 }, {     75,  -34,  -33, 22,  6,  4 },
    {     75,  -35,  -33, 22,  6,  4 }, {     75,  -36,  -34, 22,  6,  4 }, {     76,  -37,  -34, 22,  6,  4 }, {     76,  -38,  -35, 22,  6,  4 }, {     76,  -39,  -35, 22,  6,  4 },
    {     77,  -40,  -36, 23,  6,  4 }, {     77,  -41,  -36, 23,  6,  4 }, {     77,  -42,  -37, 23,  6,  4 }, {     77,  -43,  -37, 23,  6,  4 }, {     78,  -44,  -38, 23,  6,  4 },
    {     78,  -45,  -39, 23,  6,  4 }, {     78,  -46,  -39, 23,  6,  4 }, {     78,  -47,  -40, 23,  6,  4 }, {     78,  -48,  -40, 23,  6,  4 }, {     79,  -49,  -40, 23,  6,  4 },
    {     79,  -50,  -41, 23,  6,  4 }, {     79,  -51,  -42, 23,  6,  4 }, {     79,  -52,  -42, 23,  6,  4 }, {     79,  -53,  -43, 23,  6,  4 }, {     79,  -54,  -43, 23,  6,  4 },
    {     80,  -55,  -44, 23,  6,  4 }, {     80,  -56,  -44, 24,  6,  4 }, {     80,  -57,  -45, 24,  6,  4 }, {     80,  -58,  -45, 24,  6,  4 }, {     80,  -59,  -46, 24,  6,  4 },
    {     80,  -60,  -46, 24,  6,  4 }, {     80,  -61,  -47, 24,  6,  4 }, {     80,  -62,  -47, 24,  6,  4 }, {     80,  -63,  -48, 24,  6,  4 }, {     80,  -64,  -49, 24,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95F4BA, {
    {     16,   31,   15, 24,  6,  4 }, {     16,   30,   15, 24,  6,  4 }, {     16,   29,   14, 24,  6,  4 }, {     16,   28,   14, 24,  6,  4 }, {     16,   27,   13, 24,  6,  4 },
    {     16,   26,   13, 24,  6,  4 }, {     16,   25,   12, 24,  6,  4 }, {     16,   24,   12, 25,  6,  4 }, {     15,   23,   11, 25,  6,  4 }, {     15,   22,   11, 25,  6,  4 },
    {     15,   21,   10, 25,  6,  4 }, {     15,   20,   10, 25,  6,  4 }, {     15,   19,    9, 25,  6,  4 }, {     15,   18,    9, 25,  6,  4 }, {     14,   17,    8, 25,  6,  4 },
    {     14,   16,    7, 25,  6,  4 }, {     14,   15,    7, 25,  6,  4 }, {     14,   14,    7, 25,  6,  4 }, {     14,   13,    6, 25,  6,  4 }, {     13,   12,    6, 25,  6,  4 },
    {     13,   11,    5, 25,  6,  4 }, {     13,   10,    4, 26,  6,  4 }, {     13,    9,    4, 26,  6,  4 }, {     12,    8,    3, 26,  6,  4 }, {     12,    7,    3, 26,  6,  4 },
    {     12,    6,    2, 26,  6,  4 }, {     11,    5,    2, 26,  6,  4 }, {     11,    4,    1, 26,  6,  4 }, {     11,    3,    1, 26,  6,  4 }, {     10,    2,    0, 26,  6,  4 },
    {     10,    1,    0, 26,  6,  4 }, {      9,    0,   -1, 26,  6,  4 }, {      9,   -1,   -2, 26,  6,  4 }, {      8,   -2,   -2, 26,  6,  4 }, {      8,   -3,   -3, 26,  6,  4 },
    {      7,   -4,   -3, 26,  6,  4 }, {      7,   -5,   -4, 27,  6,  4 }, {      6,   -6,   -4, 27,  6,  4 }, {      6,   -7,   -5, 27,  6,  4 }, {      5,   -8,   -6, 27,  6,  4 },
    {      4,   -9,   -6, 27,  6,  4 }, {      4,  -10,   -7, 27,  6,  4 }, {      3,  -11,   -7, 27,  6,  4 }, {      2,  -12,   -8, 27,  6,  4 }, {      2,  -13,   -9, 27,  6,  4 },
    {      1,  -14,   -9, 27,  6,  4 }, {      0,  -15,  -10, 27,  6,  4 }, {      0,  -16,  -11, 27,  6,  4 }, {     -1,  -17,  -11, 27,  6,  4 }, {     -2,  -18,  -12, 28,  6,  4 },
    {     -3,  -19,  -12, 28,  6,  4 }, {     -3,  -20,  -13, 28,  6,  4 }, {     -4,  -21,  -14, 28,  6,  4 }, {     -5,  -22,  -14, 28,  6,  4 }, {     -6,  -23,  -15, 28,  6,  4 },
    {     -7,  -24,  -16, 28,  6,  4 }, {     -7,  -25,  -16, 28,  6,  4 }, {     -8,  -26,  -17, 28,  6,  4 }, {     -9,  -27,  -17, 28,  6,  4 }, {    -10,  -28,  -18, 28,  6,  4 },
    {    -11,  -29,  -19, 28,  6,  4 }, {    -12,  -29,  -19, 28,  6,  4 }, {    -13,  -30,  -20, 29,  6,  4 }, {    -14,  -31,  -21, 29,  6,  4 }, {    -15,  -32,  -21, 29,  6,  4 },
    {    -16,  -32,  -22, 29,  6,  4 }, {    -17,  -33,  -22, 29,  6,  4 }, {    -18,  -34,  -23, 29,  6,  4 }, {    -19,  -34,  -24, 29,  6,  4 }, {    -20,  -35,  -24, 29,  6,  4 },
    {    -21,  -36,  -25, 29,  6,  4 }, {    -22,  -36,  -26, 29,  6,  4 }, {    -23,  -37,  -26, 29,  6,  4 }, {    -24,  -38,  -27, 29,  6,  4 }, {    -25,  -38,  -27, 29,  6,  4 },
    {    -26,  -39,  -28, 30,  6,  4 }, {    -27,  -39,  -29, 30,  6,  4 }, {    -28,  -40,  -29, 30,  6,  4 }, {    -29,  -40,  -30, 30,  6,  4 }, {    -30,  -41,  -30, 30,  6,  4 },
    {    -31,  -41,  -31, 30,  6,  4 }, {    -32,  -42,  -31, 30,  6,  4 }, {    -33,  -42,  -32, 30,  6,  4 }, {    -34,  -43,  -33, 30,  6,  4 }, {    -35,  -43,  -33, 30,  6,  4 },
    {    -36,  -43,  -34, 30,  6,  4 }, {    -37,  -44,  -34, 30,  6,  4 }, {    -38,  -44,  -35, 30,  6,  4 }, {    -39,  -44,  -35, 30,  6,  4 }, {    -40,  -45,  -36, 31,  6,  4 },
    {    -41,  -45,  -36, 31,  6,  4 }, {    -42,  -45,  -37, 31,  6,  4 }, {    -43,  -45,  -37, 31,  6,  4 }, {    -44,  -46,  -38, 31,  6,  4 }, {    -45,  -46,  -39, 31,  6,  4 },
    {    -46,  -46,  -39, 31,  6,  4 }, {    -47,  -46,  -40, 31,  6,  4 }, {    -48,  -46,  -40, 31,  6,  4 }, {    -49,  -47,  -40, 31,  6,  4 }, {    -50,  -47,  -41, 31,  6,  4 },
    {    -51,  -47,  -42, 31,  6,  4 }, {    -52,  -47,  -42, 31,  6,  4 }, {    -53,  -47,  -43, 31,  6,  4 }, {    -54,  -47,  -43, 31,  6,  4 }, {    -55,  -48,  -44, 31,  6,  4 },
    {    -56,  -48,  -44,  0,  6,  4 }, {    -57,  -48,  -45,  0,  6,  4 }, {    -58,  -48,  -45,  0,  6,  4 }, {    -59,  -48,  -46,  0,  6,  4 }, {    -60,  -48,  -46,  0,  6,  4 },
    {    -61,  -48,  -47,  0,  6,  4 }, {    -62,  -48,  -47,  0,  6,  4 }, {    -63,  -48,  -48,  0,  6,  4 }, {    -64,  -48,  -49,  0,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_961F1E, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    1,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    2,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    3,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    4,  0,  2,  0 }, {     23,   16,    4,  0,  2,  1 }, {     22,   16,    5,  0,  2,  1 },
    {     21,   16,    5,  0,  2,  1 }, {     20,   16,    6,  0,  2,  1 }, {     19,   16,    6,  0,  2,  1 }, {     18,   16,    7,  0,  2,  1 }, {     17,   16,    7,  0,  2,  1 },
    {     16,   16,    8,  0,  2,  1 }, {     15,   16,    8,  0,  2,  1 }, {     14,   16,    9,  0,  2,  1 }, {     13,   16,    9,  0,  2,  1 }, {     12,   16,   10,  0,  2,  1 },
    {     11,   16,   10,  0,  2,  1 }, {     10,   16,   11,  0,  2,  1 }, {      9,   16,   11,  0,  2,  1 }, {      8,   16,   12,  0,  2,  1 }, {      7,   16,   12,  0,  2,  2 },
    {      6,   16,   13,  0,  2,  2 }, {      5,   16,   13,  0,  2,  2 }, {      4,   16,   14,  0,  2,  2 }, {      3,   16,   14,  0,  2,  2 }, {      2,   16,   15,  0,  2,  2 },
    {      1,   16,   15,  0,  2,  2 }, {      0,   16,   16,  0,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_962040, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    2,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    3,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    4,  8,  2,  1 }, {     16,    9,    4,  8,  2,  1 },
    {     16,   10,    5,  8,  2,  1 }, {     16,   11,    5,  8,  2,  1 }, {     16,   12,    6,  8,  2,  1 }, {     16,   13,    6,  8,  2,  1 }, {     16,   14,    7,  8,  2,  1 },
    {     16,   15,    7,  8,  2,  1 }, {     16,   16,    8,  8,  2,  1 }, {     16,   17,    8,  8,  2,  1 }, {     16,   18,    9,  8,  2,  1 }, {     16,   19,    9,  8,  2,  1 },
    {     16,   20,   10,  8,  2,  1 }, {     16,   21,   10,  8,  2,  1 }, {     16,   22,   11,  8,  2,  1 }, {     16,   23,   11,  8,  2,  1 }, {     16,   24,   12,  8,  2,  2 },
    {     16,   25,   12,  8,  2,  2 }, {     16,   26,   13,  8,  2,  2 }, {     16,   27,   13,  8,  2,  2 }, {     16,   28,   14,  8,  2,  2 }, {     16,   29,   14,  8,  2,  2 },
    {     16,   30,   15,  8,  2,  2 }, {     16,   31,   15,  8,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_962162, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    2, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    3, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    4, 16,  2,  1 }, {      9,   16,    4, 16,  2,  1 },
    {     10,   16,    5, 16,  2,  1 }, {     11,   16,    5, 16,  2,  1 }, {     12,   16,    6, 16,  2,  1 }, {     13,   16,    6, 16,  2,  1 }, {     14,   16,    7, 16,  2,  1 },
    {     15,   16,    7, 16,  2,  1 }, {     16,   16,    8, 16,  2,  1 }, {     17,   16,    8, 16,  2,  1 }, {     18,   16,    9, 16,  2,  1 }, {     19,   16,    9, 16,  2,  1 },
    {     20,   16,   10, 16,  2,  1 }, {     21,   16,   10, 16,  2,  1 }, {     22,   16,   11, 16,  2,  1 }, {     23,   16,   11, 16,  2,  1 }, {     24,   16,   12, 16,  2,  2 },
    {     25,   16,   12, 16,  2,  2 }, {     26,   16,   13, 16,  2,  2 }, {     27,   16,   13, 16,  2,  2 }, {     28,   16,   14, 16,  2,  2 }, {     29,   16,   14, 16,  2,  2 },
    {     30,   16,   15, 16,  2,  2 }, {     31,   16,   15, 16,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_962284, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    1, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    2, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    3, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    4, 24,  2,  0 }, {     16,   23,    4, 24,  2,  1 }, {     16,   22,    5, 24,  2,  1 },
    {     16,   21,    5, 24,  2,  1 }, {     16,   20,    6, 24,  2,  1 }, {     16,   19,    6, 24,  2,  1 }, {     16,   18,    7, 24,  2,  1 }, {     16,   17,    7, 24,  2,  1 },
    {     16,   16,    8, 24,  2,  1 }, {     16,   15,    8, 24,  2,  1 }, {     16,   14,    9, 24,  2,  1 }, {     16,   13,    9, 24,  2,  1 }, {     16,   12,   10, 24,  2,  1 },
    {     16,   11,   10, 24,  2,  1 }, {     16,   10,   11, 24,  2,  1 }, {     16,    9,   11, 24,  2,  1 }, {     16,    8,   12, 24,  2,  1 }, {     16,    7,   12, 24,  2,  2 },
    {     16,    6,   13, 24,  2,  2 }, {     16,    5,   13, 24,  2,  2 }, {     16,    4,   14, 24,  2,  2 }, {     16,    3,   14, 24,  2,  2 }, {     16,    2,   15, 24,  2,  2 },
    {     16,    1,   15, 24,  2,  2 }, {     16,    0,   16, 24,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9623A6, {
    {     31,   16,    0,  0,  2,  0 }, {     30,   16,    1,  0,  2,  0 }, {     29,   16,    1,  0,  2,  0 }, {     28,   16,    2,  0,  2,  0 }, {     27,   16,    2,  0,  2,  0 },
    {     26,   16,    3,  0,  2,  0 }, {     25,   16,    3,  0,  2,  0 }, {     24,   16,    4,  0,  2,  0 }, {     23,   16,    4,  0,  2,  3 }, {     22,   16,    5,  0,  2,  3 },
    {     21,   16,    5,  0,  2,  3 }, {     20,   16,    6,  0,  2,  3 }, {     19,   16,    6,  0,  2,  3 }, {     18,   16,    7,  0,  2,  3 }, {     17,   16,    7,  0,  2,  3 },
    {     16,   16,    8,  0,  2,  3 }, {     15,   16,    8,  0,  2,  3 }, {     14,   16,    9,  0,  2,  3 }, {     13,   16,    9,  0,  2,  3 }, {     12,   16,   10,  0,  2,  3 },
    {     11,   16,   10,  0,  2,  3 }, {     10,   16,   11,  0,  2,  3 }, {      9,   16,   11,  0,  2,  3 }, {      8,   16,   12,  0,  2,  3 }, {      7,   16,   12,  0,  2,  4 },
    {      6,   16,   13,  0,  2,  4 }, {      5,   16,   13,  0,  2,  4 }, {      4,   16,   14,  0,  2,  4 }, {      3,   16,   14,  0,  2,  4 }, {      2,   16,   15,  0,  2,  4 },
    {      1,   16,   15,  0,  2,  4 }, {      0,   16,   16,  0,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9624C8, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    0,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    1,  8,  2,  0 }, {     16,    4,    2,  8,  2,  0 },
    {     16,    5,    2,  8,  2,  0 }, {     16,    6,    3,  8,  2,  0 }, {     16,    7,    3,  8,  2,  0 }, {     16,    8,    4,  8,  2,  3 }, {     16,    9,    4,  8,  2,  3 },
    {     16,   10,    5,  8,  2,  3 }, {     16,   11,    5,  8,  2,  3 }, {     16,   12,    6,  8,  2,  3 }, {     16,   13,    6,  8,  2,  3 }, {     16,   14,    7,  8,  2,  3 },
    {     16,   15,    7,  8,  2,  3 }, {     16,   16,    8,  8,  2,  3 }, {     16,   17,    8,  8,  2,  3 }, {     16,   18,    9,  8,  2,  3 }, {     16,   19,    9,  8,  2,  3 },
    {     16,   20,   10,  8,  2,  3 }, {     16,   21,   10,  8,  2,  3 }, {     16,   22,   11,  8,  2,  3 }, {     16,   23,   11,  8,  2,  3 }, {     16,   24,   12,  8,  2,  4 },
    {     16,   25,   12,  8,  2,  4 }, {     16,   26,   13,  8,  2,  4 }, {     16,   27,   13,  8,  2,  4 }, {     16,   28,   14,  8,  2,  4 }, {     16,   29,   14,  8,  2,  4 },
    {     16,   30,   15,  8,  2,  4 }, {     16,   31,   15,  8,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9625EA, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    0, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    1, 16,  2,  0 }, {      4,   16,    2, 16,  2,  0 },
    {      5,   16,    2, 16,  2,  0 }, {      6,   16,    3, 16,  2,  0 }, {      7,   16,    3, 16,  2,  0 }, {      8,   16,    4, 16,  2,  3 }, {      9,   16,    4, 16,  2,  3 },
    {     10,   16,    5, 16,  2,  3 }, {     11,   16,    5, 16,  2,  3 }, {     12,   16,    6, 16,  2,  3 }, {     13,   16,    6, 16,  2,  3 }, {     14,   16,    7, 16,  2,  3 },
    {     15,   16,    7, 16,  2,  3 }, {     16,   16,    8, 16,  2,  3 }, {     17,   16,    8, 16,  2,  3 }, {     18,   16,    9, 16,  2,  3 }, {     19,   16,    9, 16,  2,  3 },
    {     20,   16,   10, 16,  2,  3 }, {     21,   16,   10, 16,  2,  3 }, {     22,   16,   11, 16,  2,  3 }, {     23,   16,   11, 16,  2,  3 }, {     24,   16,   12, 16,  2,  4 },
    {     25,   16,   12, 16,  2,  4 }, {     26,   16,   13, 16,  2,  4 }, {     27,   16,   13, 16,  2,  4 }, {     28,   16,   14, 16,  2,  4 }, {     29,   16,   14, 16,  2,  4 },
    {     30,   16,   15, 16,  2,  4 }, {     31,   16,   15, 16,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96270C, {
    {     16,   31,    0, 24,  2,  0 }, {     16,   30,    1, 24,  2,  0 }, {     16,   29,    1, 24,  2,  0 }, {     16,   28,    2, 24,  2,  0 }, {     16,   27,    2, 24,  2,  0 },
    {     16,   26,    3, 24,  2,  0 }, {     16,   25,    3, 24,  2,  0 }, {     16,   24,    4, 24,  2,  0 }, {     16,   23,    4, 24,  2,  3 }, {     16,   22,    5, 24,  2,  3 },
    {     16,   21,    5, 24,  2,  3 }, {     16,   20,    6, 24,  2,  3 }, {     16,   19,    6, 24,  2,  3 }, {     16,   18,    7, 24,  2,  3 }, {     16,   17,    7, 24,  2,  3 },
    {     16,   16,    8, 24,  2,  3 }, {     16,   15,    8, 24,  2,  3 }, {     16,   14,    9, 24,  2,  3 }, {     16,   13,    9, 24,  2,  3 }, {     16,   12,   10, 24,  2,  3 },
    {     16,   11,   10, 24,  2,  3 }, {     16,   10,   11, 24,  2,  3 }, {     16,    9,   11, 24,  2,  3 }, {     16,    8,   12, 24,  2,  3 }, {     16,    7,   12, 24,  2,  4 },
    {     16,    6,   13, 24,  2,  4 }, {     16,    5,   13, 24,  2,  4 }, {     16,    4,   14, 24,  2,  4 }, {     16,    3,   14, 24,  2,  4 }, {     16,    2,   15, 24,  2,  4 },
    {     16,    1,   15, 24,  2,  4 }, {     16,    0,   16, 24,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96313E, {
    {     31,   16,    0,  0,  2,  2 }, {     30,   16,    1,  0,  2,  2 }, {     29,   16,    1,  0,  2,  2 }, {     28,   16,    2,  0,  2,  2 }, {     27,   16,    2,  0,  2,  2 },
    {     26,   16,    3,  0,  2,  2 }, {     25,   16,    3,  0,  2,  2 }, {     24,   16,    4,  0,  2,  2 }, {     23,   16,    4,  0,  2,  1 }, {     22,   16,    5,  0,  2,  1 },
    {     21,   16,    5,  0,  2,  1 }, {     20,   16,    6,  0,  2,  1 }, {     19,   16,    6,  0,  2,  1 }, {     18,   16,    7,  0,  2,  1 }, {     17,   16,    7,  0,  2,  1 },
    {     16,   16,    8,  0,  2,  1 }, {     15,   16,    8,  0,  2,  1 }, {     14,   16,    9,  0,  2,  1 }, {     13,   16,    9,  0,  2,  1 }, {     12,   16,   10,  0,  2,  1 },
    {     11,   16,   10,  0,  2,  1 }, {     10,   16,   11,  0,  2,  1 }, {      9,   16,   11,  0,  2,  1 }, {      8,   16,   12,  0,  2,  1 }, {      7,   16,   12,  0,  2,  0 },
    {      6,   16,   13,  0,  2,  0 }, {      5,   16,   13,  0,  2,  0 }, {      4,   16,   14,  0,  2,  0 }, {      3,   16,   14,  0,  2,  0 }, {      2,   16,   15,  0,  2,  0 },
    {      1,   16,   15,  0,  2,  0 }, {      0,   16,   16,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_963260, {
    {     16,    0,    0,  8,  2,  2 }, {     16,    1,    0,  8,  2,  2 }, {     16,    2,    1,  8,  2,  2 }, {     16,    3,    1,  8,  2,  2 }, {     16,    4,    2,  8,  2,  2 },
    {     16,    5,    2,  8,  2,  2 }, {     16,    6,    3,  8,  2,  2 }, {     16,    7,    3,  8,  2,  2 }, {     16,    8,    4,  8,  2,  1 }, {     16,    9,    4,  8,  2,  1 },
    {     16,   10,    5,  8,  2,  1 }, {     16,   11,    5,  8,  2,  1 }, {     16,   12,    6,  8,  2,  1 }, {     16,   13,    6,  8,  2,  1 }, {     16,   14,    7,  8,  2,  1 },
    {     16,   15,    7,  8,  2,  1 }, {     16,   16,    8,  8,  2,  1 }, {     16,   17,    8,  8,  2,  1 }, {     16,   18,    9,  8,  2,  1 }, {     16,   19,    9,  8,  2,  1 },
    {     16,   20,   10,  8,  2,  1 }, {     16,   21,   10,  8,  2,  1 }, {     16,   22,   11,  8,  2,  1 }, {     16,   23,   11,  8,  2,  1 }, {     16,   24,   12,  8,  2,  0 },
    {     16,   25,   12,  8,  2,  0 }, {     16,   26,   13,  8,  2,  0 }, {     16,   27,   13,  8,  2,  0 }, {     16,   28,   14,  8,  2,  0 }, {     16,   29,   14,  8,  2,  0 },
    {     16,   30,   15,  8,  2,  0 }, {     16,   31,   15,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_963382, {
    {      0,   16,    0, 16,  2,  2 }, {      1,   16,    0, 16,  2,  2 }, {      2,   16,    1, 16,  2,  2 }, {      3,   16,    1, 16,  2,  2 }, {      4,   16,    2, 16,  2,  2 },
    {      5,   16,    2, 16,  2,  2 }, {      6,   16,    3, 16,  2,  2 }, {      7,   16,    3, 16,  2,  2 }, {      8,   16,    4, 16,  2,  1 }, {      9,   16,    4, 16,  2,  1 },
    {     10,   16,    5, 16,  2,  1 }, {     11,   16,    5, 16,  2,  1 }, {     12,   16,    6, 16,  2,  1 }, {     13,   16,    6, 16,  2,  1 }, {     14,   16,    7, 16,  2,  1 },
    {     15,   16,    7, 16,  2,  1 }, {     16,   16,    8, 16,  2,  1 }, {     17,   16,    8, 16,  2,  1 }, {     18,   16,    9, 16,  2,  1 }, {     19,   16,    9, 16,  2,  1 },
    {     20,   16,   10, 16,  2,  1 }, {     21,   16,   10, 16,  2,  1 }, {     22,   16,   11, 16,  2,  1 }, {     23,   16,   11, 16,  2,  1 }, {     24,   16,   12, 16,  2,  0 },
    {     25,   16,   12, 16,  2,  0 }, {     26,   16,   13, 16,  2,  0 }, {     27,   16,   13, 16,  2,  0 }, {     28,   16,   14, 16,  2,  0 }, {     29,   16,   14, 16,  2,  0 },
    {     30,   16,   15, 16,  2,  0 }, {     31,   16,   15, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9634A4, {
    {     16,   31,    0, 24,  2,  2 }, {     16,   30,    1, 24,  2,  2 }, {     16,   29,    1, 24,  2,  2 }, {     16,   28,    2, 24,  2,  2 }, {     16,   27,    2, 24,  2,  2 },
    {     16,   26,    3, 24,  2,  2 }, {     16,   25,    3, 24,  2,  2 }, {     16,   24,    4, 24,  2,  2 }, {     16,   23,    4, 24,  2,  1 }, {     16,   22,    5, 24,  2,  1 },
    {     16,   21,    5, 24,  2,  1 }, {     16,   20,    6, 24,  2,  1 }, {     16,   19,    6, 24,  2,  1 }, {     16,   18,    7, 24,  2,  1 }, {     16,   17,    7, 24,  2,  1 },
    {     16,   16,    8, 24,  2,  1 }, {     16,   15,    8, 24,  2,  1 }, {     16,   14,    9, 24,  2,  1 }, {     16,   13,    9, 24,  2,  1 }, {     16,   12,   10, 24,  2,  1 },
    {     16,   11,   10, 24,  2,  1 }, {     16,   10,   11, 24,  2,  1 }, {     16,    9,   11, 24,  2,  1 }, {     16,    8,   12, 24,  2,  1 }, {     16,    7,   12, 24,  2,  0 },
    {     16,    6,   13, 24,  2,  0 }, {     16,    5,   13, 24,  2,  0 }, {     16,    4,   14, 24,  2,  0 }, {     16,    3,   14, 24,  2,  0 }, {     16,    2,   15, 24,  2,  0 },
    {     16,    1,   15, 24,  2,  0 }, {     16,    0,   16, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9635C6, {
    {     31,   16,    0,  0,  2,  4 }, {     30,   16,    1,  0,  2,  4 }, {     29,   16,    1,  0,  2,  4 }, {     28,   16,    2,  0,  2,  4 }, {     27,   16,    2,  0,  2,  4 },
    {     26,   16,    3,  0,  2,  4 }, {     25,   16,    3,  0,  2,  4 }, {     24,   16,    4,  0,  2,  4 }, {     23,   16,    4,  0,  2,  3 }, {     22,   16,    5,  0,  2,  3 },
    {     21,   16,    5,  0,  2,  3 }, {     20,   16,    6,  0,  2,  3 }, {     19,   16,    6,  0,  2,  3 }, {     18,   16,    7,  0,  2,  3 }, {     17,   16,    7,  0,  2,  3 },
    {     16,   16,    8,  0,  2,  3 }, {     15,   16,    8,  0,  2,  3 }, {     14,   16,    9,  0,  2,  3 }, {     13,   16,    9,  0,  2,  3 }, {     12,   16,   10,  0,  2,  3 },
    {     11,   16,   10,  0,  2,  3 }, {     10,   16,   11,  0,  2,  3 }, {      9,   16,   11,  0,  2,  3 }, {      8,   16,   12,  0,  2,  3 }, {      7,   16,   12,  0,  2,  0 },
    {      6,   16,   13,  0,  2,  0 }, {      5,   16,   13,  0,  2,  0 }, {      4,   16,   14,  0,  2,  0 }, {      3,   16,   14,  0,  2,  0 }, {      2,   16,   15,  0,  2,  0 },
    {      1,   16,   15,  0,  2,  0 }, {      0,   16,   16,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9636E8, {
    {     16,    0,    0,  8,  2,  4 }, {     16,    1,    0,  8,  2,  4 }, {     16,    2,    1,  8,  2,  4 }, {     16,    3,    1,  8,  2,  4 }, {     16,    4,    2,  8,  2,  4 },
    {     16,    5,    2,  8,  2,  4 }, {     16,    6,    3,  8,  2,  4 }, {     16,    7,    3,  8,  2,  4 }, {     16,    8,    4,  8,  2,  3 }, {     16,    9,    4,  8,  2,  3 },
    {     16,   10,    5,  8,  2,  3 }, {     16,   11,    5,  8,  2,  3 }, {     16,   12,    6,  8,  2,  3 }, {     16,   13,    6,  8,  2,  3 }, {     16,   14,    7,  8,  2,  3 },
    {     16,   15,    7,  8,  2,  3 }, {     16,   16,    8,  8,  2,  3 }, {     16,   17,    8,  8,  2,  3 }, {     16,   18,    9,  8,  2,  3 }, {     16,   19,    9,  8,  2,  3 },
    {     16,   20,   10,  8,  2,  3 }, {     16,   21,   10,  8,  2,  3 }, {     16,   22,   11,  8,  2,  3 }, {     16,   23,   11,  8,  2,  3 }, {     16,   24,   12,  8,  2,  0 },
    {     16,   25,   12,  8,  2,  0 }, {     16,   26,   13,  8,  2,  0 }, {     16,   27,   13,  8,  2,  0 }, {     16,   28,   14,  8,  2,  0 }, {     16,   29,   14,  8,  2,  0 },
    {     16,   30,   15,  8,  2,  0 }, {     16,   31,   15,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96380A, {
    {      0,   16,    0, 16,  2,  4 }, {      1,   16,    0, 16,  2,  4 }, {      2,   16,    1, 16,  2,  4 }, {      3,   16,    1, 16,  2,  4 }, {      4,   16,    2, 16,  2,  4 },
    {      5,   16,    2, 16,  2,  4 }, {      6,   16,    3, 16,  2,  4 }, {      7,   16,    3, 16,  2,  4 }, {      8,   16,    4, 16,  2,  3 }, {      9,   16,    4, 16,  2,  3 },
    {     10,   16,    5, 16,  2,  3 }, {     11,   16,    5, 16,  2,  3 }, {     12,   16,    6, 16,  2,  3 }, {     13,   16,    6, 16,  2,  3 }, {     14,   16,    7, 16,  2,  3 },
    {     15,   16,    7, 16,  2,  3 }, {     16,   16,    8, 16,  2,  3 }, {     17,   16,    8, 16,  2,  3 }, {     18,   16,    9, 16,  2,  3 }, {     19,   16,    9, 16,  2,  3 },
    {     20,   16,   10, 16,  2,  3 }, {     21,   16,   10, 16,  2,  3 }, {     22,   16,   11, 16,  2,  3 }, {     23,   16,   11, 16,  2,  3 }, {     24,   16,   12, 16,  2,  0 },
    {     25,   16,   12, 16,  2,  0 }, {     26,   16,   13, 16,  2,  0 }, {     27,   16,   13, 16,  2,  0 }, {     28,   16,   14, 16,  2,  0 }, {     29,   16,   14, 16,  2,  0 },
    {     30,   16,   15, 16,  2,  0 }, {     31,   16,   15, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96392C, {
    {     16,   31,    0, 24,  2,  4 }, {     16,   30,    1, 24,  2,  4 }, {     16,   29,    1, 24,  2,  4 }, {     16,   28,    2, 24,  2,  4 }, {     16,   27,    2, 24,  2,  4 },
    {     16,   26,    3, 24,  2,  4 }, {     16,   25,    3, 24,  2,  4 }, {     16,   24,    4, 24,  2,  4 }, {     16,   23,    4, 24,  2,  3 }, {     16,   22,    5, 24,  2,  3 },
    {     16,   21,    5, 24,  2,  3 }, {     16,   20,    6, 24,  2,  3 }, {     16,   19,    6, 24,  2,  3 }, {     16,   18,    7, 24,  2,  3 }, {     16,   17,    7, 24,  2,  3 },
    {     16,   16,    8, 24,  2,  3 }, {     16,   15,    8, 24,  2,  3 }, {     16,   14,    9, 24,  2,  3 }, {     16,   13,    9, 24,  2,  3 }, {     16,   12,   10, 24,  2,  3 },
    {     16,   11,   10, 24,  2,  3 }, {     16,   10,   11, 24,  2,  3 }, {     16,    9,   11, 24,  2,  3 }, {     16,    8,   12, 24,  2,  3 }, {     16,    7,   12, 24,  2,  0 },
    {     16,    6,   13, 24,  2,  0 }, {     16,    5,   13, 24,  2,  0 }, {     16,    4,   14, 24,  2,  0 }, {     16,    3,   14, 24,  2,  0 }, {     16,    2,   15, 24,  2,  0 },
    {     16,    1,   15, 24,  2,  0 }, {     16,    0,   16, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96282E, {
    {     31,   16,   15,  0,  6,  0 }, {     30,   16,   15,  0,  6,  0 }, {     29,   16,   14,  0,  6,  0 }, {     28,   16,   14,  0,  6,  0 }, {     27,   16,   13,  0,  6,  0 },
    {     26,   16,   13,  0,  6,  0 }, {     25,   16,   12,  0,  6,  0 }, {     24,   16,   12,  0,  6,  0 }, {     23,   16,   11,  0,  6,  1 }, {     22,   16,   11,  0,  6,  1 },
    {     21,   16,   10,  0,  6,  1 }, {     20,   16,   10,  0,  6,  1 }, {     19,   16,    9,  0,  6,  1 }, {     18,   16,    9,  0,  6,  1 }, {     17,   16,    8,  0,  6,  1 },
    {     16,   16,    8,  0,  6,  1 }, {     15,   16,    7,  0,  6,  1 }, {     14,   16,    7,  0,  6,  1 }, {     13,   16,    6,  0,  6,  1 }, {     12,   16,    6,  0,  6,  1 },
    {     11,   16,    5,  0,  6,  1 }, {     10,   16,    5,  0,  6,  1 }, {      9,   16,    4,  0,  6,  1 }, {      8,   16,    4,  0,  6,  1 }, {      7,   16,    3,  0,  6,  2 },
    {      6,   16,    3,  0,  6,  2 }, {      5,   16,    2,  0,  6,  2 }, {      4,   16,    2,  0,  6,  2 }, {      3,   16,    1,  0,  6,  2 }, {      2,   16,    1,  0,  6,  2 },
    {      1,   16,    0,  0,  6,  2 }, {      0,   16,    0,  0,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_962950, {
    {     16,    0,   15,  8,  6,  0 }, {     16,    1,   14,  8,  6,  0 }, {     16,    2,   14,  8,  6,  0 }, {     16,    3,   13,  8,  6,  0 }, {     16,    4,   13,  8,  6,  0 },
    {     16,    5,   12,  8,  6,  0 }, {     16,    6,   12,  8,  6,  0 }, {     16,    7,   11,  8,  6,  0 }, {     16,    8,   11,  8,  6,  1 }, {     16,    9,   10,  8,  6,  1 },
    {     16,   10,   10,  8,  6,  1 }, {     16,   11,    9,  8,  6,  1 }, {     16,   12,    9,  8,  6,  1 }, {     16,   13,    8,  8,  6,  1 }, {     16,   14,    8,  8,  6,  1 },
    {     16,   15,    7,  8,  6,  1 }, {     16,   16,    7,  8,  6,  1 }, {     16,   17,    6,  8,  6,  1 }, {     16,   18,    6,  8,  6,  1 }, {     16,   19,    5,  8,  6,  1 },
    {     16,   20,    5,  8,  6,  1 }, {     16,   21,    4,  8,  6,  1 }, {     16,   22,    4,  8,  6,  1 }, {     16,   23,    3,  8,  6,  1 }, {     16,   24,    3,  8,  6,  2 },
    {     16,   25,    2,  8,  6,  2 }, {     16,   26,    2,  8,  6,  2 }, {     16,   27,    1,  8,  6,  2 }, {     16,   28,    1,  8,  6,  2 }, {     16,   29,    0,  8,  6,  2 },
    {     16,   30,    0,  8,  6,  2 }, {     16,   31,   -1,  8,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_962A72, {
    {      0,   16,   15, 16,  6,  0 }, {      1,   16,   14, 16,  6,  0 }, {      2,   16,   14, 16,  6,  0 }, {      3,   16,   13, 16,  6,  0 }, {      4,   16,   13, 16,  6,  0 },
    {      5,   16,   12, 16,  6,  0 }, {      6,   16,   12, 16,  6,  0 }, {      7,   16,   11, 16,  6,  0 }, {      8,   16,   11, 16,  6,  1 }, {      9,   16,   10, 16,  6,  1 },
    {     10,   16,   10, 16,  6,  1 }, {     11,   16,    9, 16,  6,  1 }, {     12,   16,    9, 16,  6,  1 }, {     13,   16,    8, 16,  6,  1 }, {     14,   16,    8, 16,  6,  1 },
    {     15,   16,    7, 16,  6,  1 }, {     16,   16,    7, 16,  6,  1 }, {     17,   16,    6, 16,  6,  1 }, {     18,   16,    6, 16,  6,  1 }, {     19,   16,    5, 16,  6,  1 },
    {     20,   16,    5, 16,  6,  1 }, {     21,   16,    4, 16,  6,  1 }, {     22,   16,    4, 16,  6,  1 }, {     23,   16,    3, 16,  6,  1 }, {     24,   16,    3, 16,  6,  2 },
    {     25,   16,    2, 16,  6,  2 }, {     26,   16,    2, 16,  6,  2 }, {     27,   16,    1, 16,  6,  2 }, {     28,   16,    1, 16,  6,  2 }, {     29,   16,    0, 16,  6,  2 },
    {     30,   16,    0, 16,  6,  2 }, {     31,   16,   -1, 16,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_962B94, {
    {     16,   31,   15, 24,  6,  0 }, {     16,   30,   15, 24,  6,  0 }, {     16,   29,   14, 24,  6,  0 }, {     16,   28,   14, 24,  6,  0 }, {     16,   27,   13, 24,  6,  0 },
    {     16,   26,   13, 24,  6,  0 }, {     16,   25,   12, 24,  6,  0 }, {     16,   24,   12, 24,  6,  0 }, {     16,   23,   11, 24,  6,  1 }, {     16,   22,   11, 24,  6,  1 },
    {     16,   21,   10, 24,  6,  1 }, {     16,   20,   10, 24,  6,  1 }, {     16,   19,    9, 24,  6,  1 }, {     16,   18,    9, 24,  6,  1 }, {     16,   17,    8, 24,  6,  1 },
    {     16,   16,    8, 24,  6,  1 }, {     16,   15,    7, 24,  6,  1 }, {     16,   14,    7, 24,  6,  1 }, {     16,   13,    6, 24,  6,  1 }, {     16,   12,    6, 24,  6,  1 },
    {     16,   11,    5, 24,  6,  1 }, {     16,   10,    5, 24,  6,  1 }, {     16,    9,    4, 24,  6,  1 }, {     16,    8,    4, 24,  6,  1 }, {     16,    7,    3, 24,  6,  2 },
    {     16,    6,    3, 24,  6,  2 }, {     16,    5,    2, 24,  6,  2 }, {     16,    4,    2, 24,  6,  2 }, {     16,    3,    1, 24,  6,  2 }, {     16,    2,    1, 24,  6,  2 },
    {     16,    1,    0, 24,  6,  2 }, {     16,    0,    0, 24,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_962CB6, {
    {     31,   16,   15,  0,  6,  0 }, {     30,   16,   15,  0,  6,  0 }, {     29,   16,   14,  0,  6,  0 }, {     28,   16,   14,  0,  6,  0 }, {     27,   16,   13,  0,  6,  0 },
    {     26,   16,   13,  0,  6,  0 }, {     25,   16,   12,  0,  6,  0 }, {     24,   16,   12,  0,  6,  0 }, {     23,   16,   11,  0,  6,  3 }, {     22,   16,   11,  0,  6,  3 },
    {     21,   16,   10,  0,  6,  3 }, {     20,   16,   10,  0,  6,  3 }, {     19,   16,    9,  0,  6,  3 }, {     18,   16,    9,  0,  6,  3 }, {     17,   16,    8,  0,  6,  3 },
    {     16,   16,    8,  0,  6,  3 }, {     15,   16,    7,  0,  6,  3 }, {     14,   16,    7,  0,  6,  3 }, {     13,   16,    6,  0,  6,  3 }, {     12,   16,    6,  0,  6,  3 },
    {     11,   16,    5,  0,  6,  3 }, {     10,   16,    5,  0,  6,  3 }, {      9,   16,    4,  0,  6,  3 }, {      8,   16,    4,  0,  6,  3 }, {      7,   16,    3,  0,  6,  4 },
    {      6,   16,    3,  0,  6,  4 }, {      5,   16,    2,  0,  6,  4 }, {      4,   16,    2,  0,  6,  4 }, {      3,   16,    1,  0,  6,  4 }, {      2,   16,    1,  0,  6,  4 },
    {      1,   16,    0,  0,  6,  4 }, {      0,   16,    0,  0,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_962DD8, {
    {     16,    0,   15,  8,  6,  0 }, {     16,    1,   14,  8,  6,  0 }, {     16,    2,   14,  8,  6,  0 }, {     16,    3,   13,  8,  6,  0 }, {     16,    4,   13,  8,  6,  0 },
    {     16,    5,   12,  8,  6,  0 }, {     16,    6,   12,  8,  6,  0 }, {     16,    7,   11,  8,  6,  0 }, {     16,    8,   11,  8,  6,  3 }, {     16,    9,   10,  8,  6,  3 },
    {     16,   10,   10,  8,  6,  3 }, {     16,   11,    9,  8,  6,  3 }, {     16,   12,    9,  8,  6,  3 }, {     16,   13,    8,  8,  6,  3 }, {     16,   14,    8,  8,  6,  3 },
    {     16,   15,    7,  8,  6,  3 }, {     16,   16,    7,  8,  6,  3 }, {     16,   17,    6,  8,  6,  3 }, {     16,   18,    6,  8,  6,  3 }, {     16,   19,    5,  8,  6,  3 },
    {     16,   20,    5,  8,  6,  3 }, {     16,   21,    4,  8,  6,  3 }, {     16,   22,    4,  8,  6,  3 }, {     16,   23,    3,  8,  6,  3 }, {     16,   24,    3,  8,  6,  4 },
    {     16,   25,    2,  8,  6,  4 }, {     16,   26,    2,  8,  6,  4 }, {     16,   27,    1,  8,  6,  4 }, {     16,   28,    1,  8,  6,  4 }, {     16,   29,    0,  8,  6,  4 },
    {     16,   30,    0,  8,  6,  4 }, {     16,   31,   -1,  8,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_962EFA, {
    {      0,   16,   15, 16,  6,  0 }, {      1,   16,   14, 16,  6,  0 }, {      2,   16,   14, 16,  6,  0 }, {      3,   16,   13, 16,  6,  0 }, {      4,   16,   13, 16,  6,  0 },
    {      5,   16,   12, 16,  6,  0 }, {      6,   16,   12, 16,  6,  0 }, {      7,   16,   11, 16,  6,  0 }, {      8,   16,   11, 16,  6,  3 }, {      9,   16,   10, 16,  6,  3 },
    {     10,   16,   10, 16,  6,  3 }, {     11,   16,    9, 16,  6,  3 }, {     12,   16,    9, 16,  6,  3 }, {     13,   16,    8, 16,  6,  3 }, {     14,   16,    8, 16,  6,  3 },
    {     15,   16,    7, 16,  6,  3 }, {     16,   16,    7, 16,  6,  3 }, {     17,   16,    6, 16,  6,  3 }, {     18,   16,    6, 16,  6,  3 }, {     19,   16,    5, 16,  6,  3 },
    {     20,   16,    5, 16,  6,  3 }, {     21,   16,    4, 16,  6,  3 }, {     22,   16,    4, 16,  6,  3 }, {     23,   16,    3, 16,  6,  3 }, {     24,   16,    3, 16,  6,  4 },
    {     25,   16,    2, 16,  6,  4 }, {     26,   16,    2, 16,  6,  4 }, {     27,   16,    1, 16,  6,  4 }, {     28,   16,    1, 16,  6,  4 }, {     29,   16,    0, 16,  6,  4 },
    {     30,   16,    0, 16,  6,  4 }, {     31,   16,   -1, 16,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96301C, {
    {     16,   31,   15, 24,  6,  0 }, {     16,   30,   15, 24,  6,  0 }, {     16,   29,   14, 24,  6,  0 }, {     16,   28,   14, 24,  6,  0 }, {     16,   27,   13, 24,  6,  0 },
    {     16,   26,   13, 24,  6,  0 }, {     16,   25,   12, 24,  6,  0 }, {     16,   24,   12, 24,  6,  0 }, {     16,   23,   11, 24,  6,  3 }, {     16,   22,   11, 24,  6,  3 },
    {     16,   21,   10, 24,  6,  3 }, {     16,   20,   10, 24,  6,  3 }, {     16,   19,    9, 24,  6,  3 }, {     16,   18,    9, 24,  6,  3 }, {     16,   17,    8, 24,  6,  3 },
    {     16,   16,    8, 24,  6,  3 }, {     16,   15,    7, 24,  6,  3 }, {     16,   14,    7, 24,  6,  3 }, {     16,   13,    6, 24,  6,  3 }, {     16,   12,    6, 24,  6,  3 },
    {     16,   11,    5, 24,  6,  3 }, {     16,   10,    5, 24,  6,  3 }, {     16,    9,    4, 24,  6,  3 }, {     16,    8,    4, 24,  6,  3 }, {     16,    7,    3, 24,  6,  4 },
    {     16,    6,    3, 24,  6,  4 }, {     16,    5,    2, 24,  6,  4 }, {     16,    4,    2, 24,  6,  4 }, {     16,    3,    1, 24,  6,  4 }, {     16,    2,    1, 24,  6,  4 },
    {     16,    1,    0, 24,  6,  4 }, {     16,    0,    0, 24,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_963A4E, {
    {     31,   16,   15,  0,  6,  2 }, {     30,   16,   15,  0,  6,  2 }, {     29,   16,   14,  0,  6,  2 }, {     28,   16,   14,  0,  6,  2 }, {     27,   16,   13,  0,  6,  2 },
    {     26,   16,   13,  0,  6,  2 }, {     25,   16,   12,  0,  6,  2 }, {     24,   16,   12,  0,  6,  2 }, {     23,   16,   11,  0,  6,  1 }, {     22,   16,   11,  0,  6,  1 },
    {     21,   16,   10,  0,  6,  1 }, {     20,   16,   10,  0,  6,  1 }, {     19,   16,    9,  0,  6,  1 }, {     18,   16,    9,  0,  6,  1 }, {     17,   16,    8,  0,  6,  1 },
    {     16,   16,    8,  0,  6,  1 }, {     15,   16,    7,  0,  6,  1 }, {     14,   16,    7,  0,  6,  1 }, {     13,   16,    6,  0,  6,  1 }, {     12,   16,    6,  0,  6,  1 },
    {     11,   16,    5,  0,  6,  1 }, {     10,   16,    5,  0,  6,  1 }, {      9,   16,    4,  0,  6,  1 }, {      8,   16,    4,  0,  6,  1 }, {      7,   16,    3,  0,  6,  0 },
    {      6,   16,    3,  0,  6,  0 }, {      5,   16,    2,  0,  6,  0 }, {      4,   16,    2,  0,  6,  0 }, {      3,   16,    1,  0,  6,  0 }, {      2,   16,    1,  0,  6,  0 },
    {      1,   16,    0,  0,  6,  0 }, {      0,   16,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_963B70, {
    {     16,    0,   15,  8,  6,  2 }, {     16,    1,   14,  8,  6,  2 }, {     16,    2,   14,  8,  6,  2 }, {     16,    3,   13,  8,  6,  2 }, {     16,    4,   13,  8,  6,  2 },
    {     16,    5,   12,  8,  6,  2 }, {     16,    6,   12,  8,  6,  2 }, {     16,    7,   11,  8,  6,  2 }, {     16,    8,   11,  8,  6,  1 }, {     16,    9,   10,  8,  6,  1 },
    {     16,   10,   10,  8,  6,  1 }, {     16,   11,    9,  8,  6,  1 }, {     16,   12,    9,  8,  6,  1 }, {     16,   13,    8,  8,  6,  1 }, {     16,   14,    8,  8,  6,  1 },
    {     16,   15,    7,  8,  6,  1 }, {     16,   16,    7,  8,  6,  1 }, {     16,   17,    6,  8,  6,  1 }, {     16,   18,    6,  8,  6,  1 }, {     16,   19,    5,  8,  6,  1 },
    {     16,   20,    5,  8,  6,  1 }, {     16,   21,    4,  8,  6,  1 }, {     16,   22,    4,  8,  6,  1 }, {     16,   23,    3,  8,  6,  1 }, {     16,   24,    3,  8,  6,  0 },
    {     16,   25,    2,  8,  6,  0 }, {     16,   26,    2,  8,  6,  0 }, {     16,   27,    1,  8,  6,  0 }, {     16,   28,    1,  8,  6,  0 }, {     16,   29,    0,  8,  6,  0 },
    {     16,   30,    0,  8,  6,  0 }, {     16,   31,   -1,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_963C92, {
    {      0,   16,   15, 16,  6,  2 }, {      1,   16,   14, 16,  6,  2 }, {      2,   16,   14, 16,  6,  2 }, {      3,   16,   13, 16,  6,  2 }, {      4,   16,   13, 16,  6,  2 },
    {      5,   16,   12, 16,  6,  2 }, {      6,   16,   12, 16,  6,  2 }, {      7,   16,   11, 16,  6,  2 }, {      8,   16,   11, 16,  6,  1 }, {      9,   16,   10, 16,  6,  1 },
    {     10,   16,   10, 16,  6,  1 }, {     11,   16,    9, 16,  6,  1 }, {     12,   16,    9, 16,  6,  1 }, {     13,   16,    8, 16,  6,  1 }, {     14,   16,    8, 16,  6,  1 },
    {     15,   16,    7, 16,  6,  1 }, {     16,   16,    7, 16,  6,  1 }, {     17,   16,    6, 16,  6,  1 }, {     18,   16,    6, 16,  6,  1 }, {     19,   16,    5, 16,  6,  1 },
    {     20,   16,    5, 16,  6,  1 }, {     21,   16,    4, 16,  6,  1 }, {     22,   16,    4, 16,  6,  1 }, {     23,   16,    3, 16,  6,  1 }, {     24,   16,    3, 16,  6,  0 },
    {     25,   16,    2, 16,  6,  0 }, {     26,   16,    2, 16,  6,  0 }, {     27,   16,    1, 16,  6,  0 }, {     28,   16,    1, 16,  6,  0 }, {     29,   16,    0, 16,  6,  0 },
    {     30,   16,    0, 16,  6,  0 }, {     31,   16,   -1, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_963DB4, {
    {     16,   31,   15, 24,  6,  2 }, {     16,   30,   15, 24,  6,  2 }, {     16,   29,   14, 24,  6,  2 }, {     16,   28,   14, 24,  6,  2 }, {     16,   27,   13, 24,  6,  2 },
    {     16,   26,   13, 24,  6,  2 }, {     16,   25,   12, 24,  6,  2 }, {     16,   24,   12, 24,  6,  2 }, {     16,   23,   11, 24,  6,  1 }, {     16,   22,   11, 24,  6,  1 },
    {     16,   21,   10, 24,  6,  1 }, {     16,   20,   10, 24,  6,  1 }, {     16,   19,    9, 24,  6,  1 }, {     16,   18,    9, 24,  6,  1 }, {     16,   17,    8, 24,  6,  1 },
    {     16,   16,    8, 24,  6,  1 }, {     16,   15,    7, 24,  6,  1 }, {     16,   14,    7, 24,  6,  1 }, {     16,   13,    6, 24,  6,  1 }, {     16,   12,    6, 24,  6,  1 },
    {     16,   11,    5, 24,  6,  1 }, {     16,   10,    5, 24,  6,  1 }, {     16,    9,    4, 24,  6,  1 }, {     16,    8,    4, 24,  6,  1 }, {     16,    7,    3, 24,  6,  0 },
    {     16,    6,    3, 24,  6,  0 }, {     16,    5,    2, 24,  6,  0 }, {     16,    4,    2, 24,  6,  0 }, {     16,    3,    1, 24,  6,  0 }, {     16,    2,    1, 24,  6,  0 },
    {     16,    1,    0, 24,  6,  0 }, {     16,    0,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_963ED6, {
    {     31,   16,   15,  0,  6,  4 }, {     30,   16,   15,  0,  6,  4 }, {     29,   16,   14,  0,  6,  4 }, {     28,   16,   14,  0,  6,  4 }, {     27,   16,   13,  0,  6,  4 },
    {     26,   16,   13,  0,  6,  4 }, {     25,   16,   12,  0,  6,  4 }, {     24,   16,   12,  0,  6,  4 }, {     23,   16,   11,  0,  6,  3 }, {     22,   16,   11,  0,  6,  3 },
    {     21,   16,   10,  0,  6,  3 }, {     20,   16,   10,  0,  6,  3 }, {     19,   16,    9,  0,  6,  3 }, {     18,   16,    9,  0,  6,  3 }, {     17,   16,    8,  0,  6,  3 },
    {     16,   16,    8,  0,  6,  3 }, {     15,   16,    7,  0,  6,  3 }, {     14,   16,    7,  0,  6,  3 }, {     13,   16,    6,  0,  6,  3 }, {     12,   16,    6,  0,  6,  3 },
    {     11,   16,    5,  0,  6,  3 }, {     10,   16,    5,  0,  6,  3 }, {      9,   16,    4,  0,  6,  3 }, {      8,   16,    4,  0,  6,  3 }, {      7,   16,    3,  0,  6,  0 },
    {      6,   16,    3,  0,  6,  0 }, {      5,   16,    2,  0,  6,  0 }, {      4,   16,    2,  0,  6,  0 }, {      3,   16,    1,  0,  6,  0 }, {      2,   16,    1,  0,  6,  0 },
    {      1,   16,    0,  0,  6,  0 }, {      0,   16,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_963FF8, {
    {     16,    0,   15,  8,  6,  4 }, {     16,    1,   14,  8,  6,  4 }, {     16,    2,   14,  8,  6,  4 }, {     16,    3,   13,  8,  6,  4 }, {     16,    4,   13,  8,  6,  4 },
    {     16,    5,   12,  8,  6,  4 }, {     16,    6,   12,  8,  6,  4 }, {     16,    7,   11,  8,  6,  4 }, {     16,    8,   11,  8,  6,  3 }, {     16,    9,   10,  8,  6,  3 },
    {     16,   10,   10,  8,  6,  3 }, {     16,   11,    9,  8,  6,  3 }, {     16,   12,    9,  8,  6,  3 }, {     16,   13,    8,  8,  6,  3 }, {     16,   14,    8,  8,  6,  3 },
    {     16,   15,    7,  8,  6,  3 }, {     16,   16,    7,  8,  6,  3 }, {     16,   17,    6,  8,  6,  3 }, {     16,   18,    6,  8,  6,  3 }, {     16,   19,    5,  8,  6,  3 },
    {     16,   20,    5,  8,  6,  3 }, {     16,   21,    4,  8,  6,  3 }, {     16,   22,    4,  8,  6,  3 }, {     16,   23,    3,  8,  6,  3 }, {     16,   24,    3,  8,  6,  0 },
    {     16,   25,    2,  8,  6,  0 }, {     16,   26,    2,  8,  6,  0 }, {     16,   27,    1,  8,  6,  0 }, {     16,   28,    1,  8,  6,  0 }, {     16,   29,    0,  8,  6,  0 },
    {     16,   30,    0,  8,  6,  0 }, {     16,   31,   -1,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96411A, {
    {      0,   16,   15, 16,  6,  4 }, {      1,   16,   14, 16,  6,  4 }, {      2,   16,   14, 16,  6,  4 }, {      3,   16,   13, 16,  6,  4 }, {      4,   16,   13, 16,  6,  4 },
    {      5,   16,   12, 16,  6,  4 }, {      6,   16,   12, 16,  6,  4 }, {      7,   16,   11, 16,  6,  4 }, {      8,   16,   11, 16,  6,  3 }, {      9,   16,   10, 16,  6,  3 },
    {     10,   16,   10, 16,  6,  3 }, {     11,   16,    9, 16,  6,  3 }, {     12,   16,    9, 16,  6,  3 }, {     13,   16,    8, 16,  6,  3 }, {     14,   16,    8, 16,  6,  3 },
    {     15,   16,    7, 16,  6,  3 }, {     16,   16,    7, 16,  6,  3 }, {     17,   16,    6, 16,  6,  3 }, {     18,   16,    6, 16,  6,  3 }, {     19,   16,    5, 16,  6,  3 },
    {     20,   16,    5, 16,  6,  3 }, {     21,   16,    4, 16,  6,  3 }, {     22,   16,    4, 16,  6,  3 }, {     23,   16,    3, 16,  6,  3 }, {     24,   16,    3, 16,  6,  0 },
    {     25,   16,    2, 16,  6,  0 }, {     26,   16,    2, 16,  6,  0 }, {     27,   16,    1, 16,  6,  0 }, {     28,   16,    1, 16,  6,  0 }, {     29,   16,    0, 16,  6,  0 },
    {     30,   16,    0, 16,  6,  0 }, {     31,   16,   -1, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96423C, {
    {     16,   31,   15, 24,  6,  4 }, {     16,   30,   15, 24,  6,  4 }, {     16,   29,   14, 24,  6,  4 }, {     16,   28,   14, 24,  6,  4 }, {     16,   27,   13, 24,  6,  4 },
    {     16,   26,   13, 24,  6,  4 }, {     16,   25,   12, 24,  6,  4 }, {     16,   24,   12, 24,  6,  4 }, {     16,   23,   11, 24,  6,  3 }, {     16,   22,   11, 24,  6,  3 },
    {     16,   21,   10, 24,  6,  3 }, {     16,   20,   10, 24,  6,  3 }, {     16,   19,    9, 24,  6,  3 }, {     16,   18,    9, 24,  6,  3 }, {     16,   17,    8, 24,  6,  3 },
    {     16,   16,    8, 24,  6,  3 }, {     16,   15,    7, 24,  6,  3 }, {     16,   14,    7, 24,  6,  3 }, {     16,   13,    6, 24,  6,  3 }, {     16,   12,    6, 24,  6,  3 },
    {     16,   11,    5, 24,  6,  3 }, {     16,   10,    5, 24,  6,  3 }, {     16,    9,    4, 24,  6,  3 }, {     16,    8,    4, 24,  6,  3 }, {     16,    7,    3, 24,  6,  0 },
    {     16,    6,    3, 24,  6,  0 }, {     16,    5,    2, 24,  6,  0 }, {     16,    4,    2, 24,  6,  0 }, {     16,    3,    1, 24,  6,  0 }, {     16,    2,    1, 24,  6,  0 },
    {     16,    1,    0, 24,  6,  0 }, {     16,    0,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96435E, {
    {     31,   16,    0,  0,  0,  2 }, {     30,   16,    0,  0,  0,  2 }, {     29,   16,    0,  0,  0,  2 }, {     28,   16,    0,  0,  0,  2 }, {     27,   16,    0,  0,  0,  2 },
    {     26,   16,    0,  0,  0,  2 }, {     25,   16,    0,  0,  0,  2 }, {     24,   16,    0,  0,  0,  2 }, {     23,   16,    0,  0,  1,  2 }, {     22,   16,    0,  0,  1,  2 },
    {     21,   16,    1,  0,  1,  2 }, {     20,   16,    1,  0,  1,  2 }, {     19,   16,    1,  0,  1,  2 }, {     18,   16,    1,  0,  1,  2 }, {     17,   16,    1,  0,  1,  2 },
    {     16,   16,    1,  0,  1,  2 }, {     15,   16,    2,  0,  1,  2 }, {     14,   16,    2,  0,  1,  2 }, {     13,   16,    2,  0,  1,  2 }, {     12,   16,    2,  0,  1,  2 },
    {     11,   16,    3,  0,  1,  2 }, {     10,   16,    3,  0,  1,  2 }, {      9,   16,    3,  0,  1,  2 }, {      8,   16,    4,  0,  1,  2 }, {      7,   16,    4,  0,  2,  2 },
    {      6,   16,    5,  0,  2,  2 }, {      5,   16,    5,  0,  2,  2 }, {      4,   16,    6,  0,  2,  2 }, {      3,   16,    6,  0,  2,  2 }, {      2,   16,    7,  0,  2,  2 },
    {      1,   16,    7,  0,  2,  2 }, {      0,   16,    8,  0,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_964480, {
    {     16,    0,    0,  8,  0,  2 }, {     16,    1,    0,  8,  0,  2 }, {     16,    2,    0,  8,  0,  2 }, {     16,    3,    0,  8,  0,  2 }, {     16,    4,    0,  8,  0,  2 },
    {     16,    5,    0,  8,  0,  2 }, {     16,    6,    0,  8,  0,  2 }, {     16,    7,    0,  8,  0,  2 }, {     16,    8,    0,  8,  1,  2 }, {     16,    9,    0,  8,  1,  2 },
    {     16,   10,    1,  8,  1,  2 }, {     16,   11,    1,  8,  1,  2 }, {     16,   12,    1,  8,  1,  2 }, {     16,   13,    1,  8,  1,  2 }, {     16,   14,    1,  8,  1,  2 },
    {     16,   15,    1,  8,  1,  2 }, {     16,   16,    2,  8,  1,  2 }, {     16,   17,    2,  8,  1,  2 }, {     16,   18,    2,  8,  1,  2 }, {     16,   19,    2,  8,  1,  2 },
    {     16,   20,    3,  8,  1,  2 }, {     16,   21,    3,  8,  1,  2 }, {     16,   22,    3,  8,  1,  2 }, {     16,   23,    4,  8,  1,  2 }, {     16,   24,    4,  8,  2,  2 },
    {     16,   25,    4,  8,  2,  2 }, {     16,   26,    5,  8,  2,  2 }, {     16,   27,    5,  8,  2,  2 }, {     16,   28,    6,  8,  2,  2 }, {     16,   29,    6,  8,  2,  2 },
    {     16,   30,    7,  8,  2,  2 }, {     16,   31,    7,  8,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9645A2, {
    {      0,   16,    0, 16,  0,  2 }, {      1,   16,    0, 16,  0,  2 }, {      2,   16,    0, 16,  0,  2 }, {      3,   16,    0, 16,  0,  2 }, {      4,   16,    0, 16,  0,  2 },
    {      5,   16,    0, 16,  0,  2 }, {      6,   16,    0, 16,  0,  2 }, {      7,   16,    0, 16,  0,  2 }, {      8,   16,    0, 16,  1,  2 }, {      9,   16,    0, 16,  1,  2 },
    {     10,   16,    1, 16,  1,  2 }, {     11,   16,    1, 16,  1,  2 }, {     12,   16,    1, 16,  1,  2 }, {     13,   16,    1, 16,  1,  2 }, {     14,   16,    1, 16,  1,  2 },
    {     15,   16,    1, 16,  1,  2 }, {     16,   16,    2, 16,  1,  2 }, {     17,   16,    2, 16,  1,  2 }, {     18,   16,    2, 16,  1,  2 }, {     19,   16,    2, 16,  1,  2 },
    {     20,   16,    3, 16,  1,  2 }, {     21,   16,    3, 16,  1,  2 }, {     22,   16,    3, 16,  1,  2 }, {     23,   16,    4, 16,  1,  2 }, {     24,   16,    4, 16,  2,  2 },
    {     25,   16,    4, 16,  2,  2 }, {     26,   16,    5, 16,  2,  2 }, {     27,   16,    5, 16,  2,  2 }, {     28,   16,    6, 16,  2,  2 }, {     29,   16,    6, 16,  2,  2 },
    {     30,   16,    7, 16,  2,  2 }, {     31,   16,    7, 16,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9646C4, {
    {     16,   31,    0, 24,  0,  2 }, {     16,   30,    0, 24,  0,  2 }, {     16,   29,    0, 24,  0,  2 }, {     16,   28,    0, 24,  0,  2 }, {     16,   27,    0, 24,  0,  2 },
    {     16,   26,    0, 24,  0,  2 }, {     16,   25,    0, 24,  0,  2 }, {     16,   24,    0, 24,  0,  2 }, {     16,   23,    0, 24,  1,  2 }, {     16,   22,    0, 24,  1,  2 },
    {     16,   21,    1, 24,  1,  2 }, {     16,   20,    1, 24,  1,  2 }, {     16,   19,    1, 24,  1,  2 }, {     16,   18,    1, 24,  1,  2 }, {     16,   17,    1, 24,  1,  2 },
    {     16,   16,    1, 24,  1,  2 }, {     16,   15,    2, 24,  1,  2 }, {     16,   14,    2, 24,  1,  2 }, {     16,   13,    2, 24,  1,  2 }, {     16,   12,    2, 24,  1,  2 },
    {     16,   11,    3, 24,  1,  2 }, {     16,   10,    3, 24,  1,  2 }, {     16,    9,    3, 24,  1,  2 }, {     16,    8,    4, 24,  1,  2 }, {     16,    7,    4, 24,  2,  2 },
    {     16,    6,    5, 24,  2,  2 }, {     16,    5,    5, 24,  2,  2 }, {     16,    4,    6, 24,  2,  2 }, {     16,    3,    6, 24,  2,  2 }, {     16,    2,    7, 24,  2,  2 },
    {     16,    1,    7, 24,  2,  2 }, {     16,    0,    8, 24,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96557E, {
    {     31,   16,    0,  0,  0,  4 }, {     30,   16,    0,  0,  0,  4 }, {     29,   16,    0,  0,  0,  4 }, {     28,   16,    0,  0,  0,  4 }, {     27,   16,    0,  0,  0,  4 },
    {     26,   16,    0,  0,  0,  4 }, {     25,   16,    0,  0,  0,  4 }, {     24,   16,    0,  0,  0,  4 }, {     23,   16,    0,  0,  1,  4 }, {     22,   16,    0,  0,  1,  4 },
    {     21,   16,    1,  0,  1,  4 }, {     20,   16,    1,  0,  1,  4 }, {     19,   16,    1,  0,  1,  4 }, {     18,   16,    1,  0,  1,  4 }, {     17,   16,    1,  0,  1,  4 },
    {     16,   16,    1,  0,  1,  4 }, {     15,   16,    2,  0,  1,  4 }, {     14,   16,    2,  0,  1,  4 }, {     13,   16,    2,  0,  1,  4 }, {     12,   16,    2,  0,  1,  4 },
    {     11,   16,    3,  0,  1,  4 }, {     10,   16,    3,  0,  1,  4 }, {      9,   16,    3,  0,  1,  4 }, {      8,   16,    4,  0,  1,  4 }, {      7,   16,    4,  0,  2,  4 },
    {      6,   16,    5,  0,  2,  4 }, {      5,   16,    5,  0,  2,  4 }, {      4,   16,    6,  0,  2,  4 }, {      3,   16,    6,  0,  2,  4 }, {      2,   16,    7,  0,  2,  4 },
    {      1,   16,    7,  0,  2,  4 }, {      0,   16,    8,  0,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9656A0, {
    {     16,    0,    0,  8,  0,  4 }, {     16,    1,    0,  8,  0,  4 }, {     16,    2,    0,  8,  0,  4 }, {     16,    3,    0,  8,  0,  4 }, {     16,    4,    0,  8,  0,  4 },
    {     16,    5,    0,  8,  0,  4 }, {     16,    6,    0,  8,  0,  4 }, {     16,    7,    0,  8,  0,  4 }, {     16,    8,    0,  8,  1,  4 }, {     16,    9,    0,  8,  1,  4 },
    {     16,   10,    1,  8,  1,  4 }, {     16,   11,    1,  8,  1,  4 }, {     16,   12,    1,  8,  1,  4 }, {     16,   13,    1,  8,  1,  4 }, {     16,   14,    1,  8,  1,  4 },
    {     16,   15,    1,  8,  1,  4 }, {     16,   16,    2,  8,  1,  4 }, {     16,   17,    2,  8,  1,  4 }, {     16,   18,    2,  8,  1,  4 }, {     16,   19,    2,  8,  1,  4 },
    {     16,   20,    3,  8,  1,  4 }, {     16,   21,    3,  8,  1,  4 }, {     16,   22,    3,  8,  1,  4 }, {     16,   23,    4,  8,  1,  4 }, {     16,   24,    4,  8,  2,  4 },
    {     16,   25,    4,  8,  2,  4 }, {     16,   26,    5,  8,  2,  4 }, {     16,   27,    5,  8,  2,  4 }, {     16,   28,    6,  8,  2,  4 }, {     16,   29,    6,  8,  2,  4 },
    {     16,   30,    7,  8,  2,  4 }, {     16,   31,    7,  8,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9657C2, {
    {      0,   16,    0, 16,  0,  4 }, {      1,   16,    0, 16,  0,  4 }, {      2,   16,    0, 16,  0,  4 }, {      3,   16,    0, 16,  0,  4 }, {      4,   16,    0, 16,  0,  4 },
    {      5,   16,    0, 16,  0,  4 }, {      6,   16,    0, 16,  0,  4 }, {      7,   16,    0, 16,  0,  4 }, {      8,   16,    0, 16,  1,  4 }, {      9,   16,    0, 16,  1,  4 },
    {     10,   16,    1, 16,  1,  4 }, {     11,   16,    1, 16,  1,  4 }, {     12,   16,    1, 16,  1,  4 }, {     13,   16,    1, 16,  1,  4 }, {     14,   16,    1, 16,  1,  4 },
    {     15,   16,    1, 16,  1,  4 }, {     16,   16,    2, 16,  1,  4 }, {     17,   16,    2, 16,  1,  4 }, {     18,   16,    2, 16,  1,  4 }, {     19,   16,    2, 16,  1,  4 },
    {     20,   16,    3, 16,  1,  4 }, {     21,   16,    3, 16,  1,  4 }, {     22,   16,    3, 16,  1,  4 }, {     23,   16,    4, 16,  1,  4 }, {     24,   16,    4, 16,  2,  4 },
    {     25,   16,    4, 16,  2,  4 }, {     26,   16,    5, 16,  2,  4 }, {     27,   16,    5, 16,  2,  4 }, {     28,   16,    6, 16,  2,  4 }, {     29,   16,    6, 16,  2,  4 },
    {     30,   16,    7, 16,  2,  4 }, {     31,   16,    7, 16,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9658E4, {
    {     16,   31,    0, 24,  0,  4 }, {     16,   30,    0, 24,  0,  4 }, {     16,   29,    0, 24,  0,  4 }, {     16,   28,    0, 24,  0,  4 }, {     16,   27,    0, 24,  0,  4 },
    {     16,   26,    0, 24,  0,  4 }, {     16,   25,    0, 24,  0,  4 }, {     16,   24,    0, 24,  0,  4 }, {     16,   23,    0, 24,  1,  4 }, {     16,   22,    0, 24,  1,  4 },
    {     16,   21,    1, 24,  1,  4 }, {     16,   20,    1, 24,  1,  4 }, {     16,   19,    1, 24,  1,  4 }, {     16,   18,    1, 24,  1,  4 }, {     16,   17,    1, 24,  1,  4 },
    {     16,   16,    1, 24,  1,  4 }, {     16,   15,    2, 24,  1,  4 }, {     16,   14,    2, 24,  1,  4 }, {     16,   13,    2, 24,  1,  4 }, {     16,   12,    2, 24,  1,  4 },
    {     16,   11,    3, 24,  1,  4 }, {     16,   10,    3, 24,  1,  4 }, {     16,    9,    3, 24,  1,  4 }, {     16,    8,    4, 24,  1,  4 }, {     16,    7,    4, 24,  2,  4 },
    {     16,    6,    5, 24,  2,  4 }, {     16,    5,    5, 24,  2,  4 }, {     16,    4,    6, 24,  2,  4 }, {     16,    3,    6, 24,  2,  4 }, {     16,    2,    7, 24,  2,  4 },
    {     16,    1,    7, 24,  2,  4 }, {     16,    0,    8, 24,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9647E6, {
    {     31,   16,    0,  0,  2,  2 }, {     30,   16,    1,  0,  2,  2 }, {     29,   16,    1,  0,  2,  2 }, {     28,   16,    2,  0,  2,  2 }, {     27,   16,    2,  0,  2,  2 },
    {     26,   16,    3,  0,  2,  2 }, {     25,   16,    3,  0,  2,  2 }, {     24,   16,    3,  0,  2,  2 }, {     23,   16,    4,  0,  1,  2 }, {     22,   16,    4,  0,  1,  2 },
    {     21,   16,    4,  0,  1,  2 }, {     20,   16,    5,  0,  1,  2 }, {     19,   16,    5,  0,  1,  2 }, {     18,   16,    5,  0,  1,  2 }, {     17,   16,    6,  0,  1,  2 },
    {     16,   16,    6,  0,  1,  2 }, {     15,   16,    6,  0,  1,  2 }, {     14,   16,    6,  0,  1,  2 }, {     13,   16,    7,  0,  1,  2 }, {     12,   16,    7,  0,  1,  2 },
    {     11,   16,    7,  0,  1,  2 }, {     10,   16,    7,  0,  1,  2 }, {      9,   16,    7,  0,  0,  2 }, {      8,   16,    7,  0,  0,  2 }, {      7,   16,    8,  0,  0,  2 },
    {      6,   16,    8,  0,  0,  2 }, {      5,   16,    8,  0,  0,  2 }, {      4,   16,    8,  0,  0,  2 }, {      3,   16,    8,  0,  0,  2 }, {      2,   16,    8,  0,  0,  2 },
    {      1,   16,    8,  0,  0,  2 }, {      0,   16,    8,  0,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_964908, {
    {     16,    0,    0,  8,  2,  2 }, {     16,    1,    0,  8,  2,  2 }, {     16,    2,    1,  8,  2,  2 }, {     16,    3,    1,  8,  2,  2 }, {     16,    4,    2,  8,  2,  2 },
    {     16,    5,    2,  8,  2,  2 }, {     16,    6,    3,  8,  2,  2 }, {     16,    7,    3,  8,  2,  2 }, {     16,    8,    4,  8,  1,  2 }, {     16,    9,    4,  8,  1,  2 },
    {     16,   10,    4,  8,  1,  2 }, {     16,   11,    5,  8,  1,  2 }, {     16,   12,    5,  8,  1,  2 }, {     16,   13,    5,  8,  1,  2 }, {     16,   14,    6,  8,  1,  2 },
    {     16,   15,    6,  8,  1,  2 }, {     16,   16,    6,  8,  1,  2 }, {     16,   17,    6,  8,  1,  2 }, {     16,   18,    7,  8,  1,  2 }, {     16,   19,    7,  8,  1,  2 },
    {     16,   20,    7,  8,  1,  2 }, {     16,   21,    7,  8,  1,  2 }, {     16,   22,    7,  8,  0,  2 }, {     16,   23,    7,  8,  0,  2 }, {     16,   24,    8,  8,  0,  2 },
    {     16,   25,    8,  8,  0,  2 }, {     16,   26,    8,  8,  0,  2 }, {     16,   27,    8,  8,  0,  2 }, {     16,   28,    8,  8,  0,  2 }, {     16,   29,    8,  8,  0,  2 },
    {     16,   30,    8,  8,  0,  2 }, {     16,   31,    8,  8,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_964A2A, {
    {      0,   16,    0, 16,  2,  2 }, {      1,   16,    0, 16,  2,  2 }, {      2,   16,    1, 16,  2,  2 }, {      3,   16,    1, 16,  2,  2 }, {      4,   16,    2, 16,  2,  2 },
    {      5,   16,    2, 16,  2,  2 }, {      6,   16,    3, 16,  2,  2 }, {      7,   16,    3, 16,  2,  2 }, {      8,   16,    4, 16,  1,  2 }, {      9,   16,    4, 16,  1,  2 },
    {     10,   16,    4, 16,  1,  2 }, {     11,   16,    5, 16,  1,  2 }, {     12,   16,    5, 16,  1,  2 }, {     13,   16,    5, 16,  1,  2 }, {     14,   16,    6, 16,  1,  2 },
    {     15,   16,    6, 16,  1,  2 }, {     16,   16,    6, 16,  1,  2 }, {     17,   16,    6, 16,  1,  2 }, {     18,   16,    7, 16,  1,  2 }, {     19,   16,    7, 16,  1,  2 },
    {     20,   16,    7, 16,  1,  2 }, {     21,   16,    7, 16,  1,  2 }, {     22,   16,    7, 16,  0,  2 }, {     23,   16,    7, 16,  0,  2 }, {     24,   16,    8, 16,  0,  2 },
    {     25,   16,    8, 16,  0,  2 }, {     26,   16,    8, 16,  0,  2 }, {     27,   16,    8, 16,  0,  2 }, {     28,   16,    8, 16,  0,  2 }, {     29,   16,    8, 16,  0,  2 },
    {     30,   16,    8, 16,  0,  2 }, {     31,   16,    8, 16,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_964B4C, {
    {     16,   31,    0, 24,  2,  2 }, {     16,   30,    1, 24,  2,  2 }, {     16,   29,    1, 24,  2,  2 }, {     16,   28,    2, 24,  2,  2 }, {     16,   27,    2, 24,  2,  2 },
    {     16,   26,    3, 24,  2,  2 }, {     16,   25,    3, 24,  2,  2 }, {     16,   24,    3, 24,  2,  2 }, {     16,   23,    4, 24,  1,  2 }, {     16,   22,    4, 24,  1,  2 },
    {     16,   21,    4, 24,  1,  2 }, {     16,   20,    5, 24,  1,  2 }, {     16,   19,    5, 24,  1,  2 }, {     16,   18,    5, 24,  1,  2 }, {     16,   17,    6, 24,  1,  2 },
    {     16,   16,    6, 24,  1,  2 }, {     16,   15,    6, 24,  1,  2 }, {     16,   14,    6, 24,  1,  2 }, {     16,   13,    7, 24,  1,  2 }, {     16,   12,    7, 24,  1,  2 },
    {     16,   11,    7, 24,  1,  2 }, {     16,   10,    7, 24,  1,  2 }, {     16,    9,    7, 24,  0,  2 }, {     16,    8,    7, 24,  0,  2 }, {     16,    7,    8, 24,  0,  2 },
    {     16,    6,    8, 24,  0,  2 }, {     16,    5,    8, 24,  0,  2 }, {     16,    4,    8, 24,  0,  2 }, {     16,    3,    8, 24,  0,  2 }, {     16,    2,    8, 24,  0,  2 },
    {     16,    1,    8, 24,  0,  2 }, {     16,    0,    8, 24,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_965A06, {
    {     31,   16,    0,  0,  2,  4 }, {     30,   16,    1,  0,  2,  4 }, {     29,   16,    1,  0,  2,  4 }, {     28,   16,    2,  0,  2,  4 }, {     27,   16,    2,  0,  2,  4 },
    {     26,   16,    3,  0,  2,  4 }, {     25,   16,    3,  0,  2,  4 }, {     24,   16,    3,  0,  2,  4 }, {     23,   16,    4,  0,  1,  4 }, {     22,   16,    4,  0,  1,  4 },
    {     21,   16,    4,  0,  1,  4 }, {     20,   16,    5,  0,  1,  4 }, {     19,   16,    5,  0,  1,  4 }, {     18,   16,    5,  0,  1,  4 }, {     17,   16,    6,  0,  1,  4 },
    {     16,   16,    6,  0,  1,  4 }, {     15,   16,    6,  0,  1,  4 }, {     14,   16,    6,  0,  1,  4 }, {     13,   16,    7,  0,  1,  4 }, {     12,   16,    7,  0,  1,  4 },
    {     11,   16,    7,  0,  1,  4 }, {     10,   16,    7,  0,  1,  4 }, {      9,   16,    7,  0,  0,  4 }, {      8,   16,    7,  0,  0,  4 }, {      7,   16,    8,  0,  0,  4 },
    {      6,   16,    8,  0,  0,  4 }, {      5,   16,    8,  0,  0,  4 }, {      4,   16,    8,  0,  0,  4 }, {      3,   16,    8,  0,  0,  4 }, {      2,   16,    8,  0,  0,  4 },
    {      1,   16,    8,  0,  0,  4 }, {      0,   16,    8,  0,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_965B28, {
    {     16,    0,    0,  8,  2,  4 }, {     16,    1,    0,  8,  2,  4 }, {     16,    2,    1,  8,  2,  4 }, {     16,    3,    1,  8,  2,  4 }, {     16,    4,    2,  8,  2,  4 },
    {     16,    5,    2,  8,  2,  4 }, {     16,    6,    3,  8,  2,  4 }, {     16,    7,    3,  8,  2,  4 }, {     16,    8,    4,  8,  1,  4 }, {     16,    9,    4,  8,  1,  4 },
    {     16,   10,    4,  8,  1,  4 }, {     16,   11,    5,  8,  1,  4 }, {     16,   12,    5,  8,  1,  4 }, {     16,   13,    5,  8,  1,  4 }, {     16,   14,    6,  8,  1,  4 },
    {     16,   15,    6,  8,  1,  4 }, {     16,   16,    6,  8,  1,  4 }, {     16,   17,    6,  8,  1,  4 }, {     16,   18,    7,  8,  1,  4 }, {     16,   19,    7,  8,  1,  4 },
    {     16,   20,    7,  8,  1,  4 }, {     16,   21,    7,  8,  1,  4 }, {     16,   22,    7,  8,  0,  4 }, {     16,   23,    7,  8,  0,  4 }, {     16,   24,    8,  8,  0,  4 },
    {     16,   25,    8,  8,  0,  4 }, {     16,   26,    8,  8,  0,  4 }, {     16,   27,    8,  8,  0,  4 }, {     16,   28,    8,  8,  0,  4 }, {     16,   29,    8,  8,  0,  4 },
    {     16,   30,    8,  8,  0,  4 }, {     16,   31,    8,  8,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_965C4A, {
    {      0,   16,    0, 16,  2,  4 }, {      1,   16,    0, 16,  2,  4 }, {      2,   16,    1, 16,  2,  4 }, {      3,   16,    1, 16,  2,  4 }, {      4,   16,    2, 16,  2,  4 },
    {      5,   16,    2, 16,  2,  4 }, {      6,   16,    3, 16,  2,  4 }, {      7,   16,    3, 16,  2,  4 }, {      8,   16,    4, 16,  1,  4 }, {      9,   16,    4, 16,  1,  4 },
    {     10,   16,    4, 16,  1,  4 }, {     11,   16,    5, 16,  1,  4 }, {     12,   16,    5, 16,  1,  4 }, {     13,   16,    5, 16,  1,  4 }, {     14,   16,    6, 16,  1,  4 },
    {     15,   16,    6, 16,  1,  4 }, {     16,   16,    6, 16,  1,  4 }, {     17,   16,    6, 16,  1,  4 }, {     18,   16,    7, 16,  1,  4 }, {     19,   16,    7, 16,  1,  4 },
    {     20,   16,    7, 16,  1,  4 }, {     21,   16,    7, 16,  1,  4 }, {     22,   16,    7, 16,  0,  4 }, {     23,   16,    7, 16,  0,  4 }, {     24,   16,    8, 16,  0,  4 },
    {     25,   16,    8, 16,  0,  4 }, {     26,   16,    8, 16,  0,  4 }, {     27,   16,    8, 16,  0,  4 }, {     28,   16,    8, 16,  0,  4 }, {     29,   16,    8, 16,  0,  4 },
    {     30,   16,    8, 16,  0,  4 }, {     31,   16,    8, 16,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_965D6C, {
    {     16,   31,    0, 24,  2,  4 }, {     16,   30,    1, 24,  2,  4 }, {     16,   29,    1, 24,  2,  4 }, {     16,   28,    2, 24,  2,  4 }, {     16,   27,    2, 24,  2,  4 },
    {     16,   26,    3, 24,  2,  4 }, {     16,   25,    3, 24,  2,  4 }, {     16,   24,    3, 24,  2,  4 }, {     16,   23,    4, 24,  1,  4 }, {     16,   22,    4, 24,  1,  4 },
    {     16,   21,    4, 24,  1,  4 }, {     16,   20,    5, 24,  1,  4 }, {     16,   19,    5, 24,  1,  4 }, {     16,   18,    5, 24,  1,  4 }, {     16,   17,    6, 24,  1,  4 },
    {     16,   16,    6, 24,  1,  4 }, {     16,   15,    6, 24,  1,  4 }, {     16,   14,    6, 24,  1,  4 }, {     16,   13,    7, 24,  1,  4 }, {     16,   12,    7, 24,  1,  4 },
    {     16,   11,    7, 24,  1,  4 }, {     16,   10,    7, 24,  1,  4 }, {     16,    9,    7, 24,  0,  4 }, {     16,    8,    7, 24,  0,  4 }, {     16,    7,    8, 24,  0,  4 },
    {     16,    6,    8, 24,  0,  4 }, {     16,    5,    8, 24,  0,  4 }, {     16,    4,    8, 24,  0,  4 }, {     16,    3,    8, 24,  0,  4 }, {     16,    2,    8, 24,  0,  4 },
    {     16,    1,    8, 24,  0,  4 }, {     16,    0,    8, 24,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9650F6, {
    {     31,   16,    8,  0,  0,  2 }, {     30,   16,    8,  0,  0,  2 }, {     29,   16,    8,  0,  0,  2 }, {     28,   16,    8,  0,  0,  2 }, {     27,   16,    8,  0,  0,  2 },
    {     26,   16,    8,  0,  0,  2 }, {     25,   16,    8,  0,  0,  2 }, {     24,   16,    8,  0,  0,  2 }, {     23,   16,    7,  0,  5,  2 }, {     22,   16,    7,  0,  5,  2 },
    {     21,   16,    7,  0,  5,  2 }, {     20,   16,    7,  0,  5,  2 }, {     19,   16,    7,  0,  5,  2 }, {     18,   16,    7,  0,  5,  2 }, {     17,   16,    6,  0,  5,  2 },
    {     16,   16,    6,  0,  5,  2 }, {     15,   16,    6,  0,  5,  2 }, {     14,   16,    6,  0,  5,  2 }, {     13,   16,    5,  0,  5,  2 }, {     12,   16,    5,  0,  5,  2 },
    {     11,   16,    5,  0,  5,  2 }, {     10,   16,    4,  0,  5,  2 }, {      9,   16,    4,  0,  5,  2 }, {      8,   16,    4,  0,  5,  2 }, {      7,   16,    3,  0,  6,  2 },
    {      6,   16,    3,  0,  6,  2 }, {      5,   16,    2,  0,  6,  2 }, {      4,   16,    2,  0,  6,  2 }, {      3,   16,    1,  0,  6,  2 }, {      2,   16,    1,  0,  6,  2 },
    {      1,   16,    0,  0,  6,  2 }, {      0,   16,    0,  0,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_965218, {
    {     16,    0,    8,  8,  0,  2 }, {     16,    1,    8,  8,  0,  2 }, {     16,    2,    8,  8,  0,  2 }, {     16,    3,    8,  8,  0,  2 }, {     16,    4,    8,  8,  0,  2 },
    {     16,    5,    8,  8,  0,  2 }, {     16,    6,    8,  8,  0,  2 }, {     16,    7,    8,  8,  0,  2 }, {     16,    8,    7,  8,  5,  2 }, {     16,    9,    7,  8,  5,  2 },
    {     16,   10,    7,  8,  5,  2 }, {     16,   11,    7,  8,  5,  2 }, {     16,   12,    7,  8,  5,  2 }, {     16,   13,    7,  8,  5,  2 }, {     16,   14,    6,  8,  5,  2 },
    {     16,   15,    6,  8,  5,  2 }, {     16,   16,    6,  8,  5,  2 }, {     16,   17,    6,  8,  5,  2 }, {     16,   18,    5,  8,  5,  2 }, {     16,   19,    5,  8,  5,  2 },
    {     16,   20,    5,  8,  5,  2 }, {     16,   21,    4,  8,  5,  2 }, {     16,   22,    4,  8,  5,  2 }, {     16,   23,    4,  8,  5,  2 }, {     16,   24,    3,  8,  6,  2 },
    {     16,   25,    3,  8,  6,  2 }, {     16,   26,    3,  8,  6,  2 }, {     16,   27,    2,  8,  6,  2 }, {     16,   28,    2,  8,  6,  2 }, {     16,   29,    1,  8,  6,  2 },
    {     16,   30,    1,  8,  6,  2 }, {     16,   31,    0,  8,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96533A, {
    {      0,   16,    8, 16,  0,  2 }, {      1,   16,    8, 16,  0,  2 }, {      2,   16,    8, 16,  0,  2 }, {      3,   16,    8, 16,  0,  2 }, {      4,   16,    8, 16,  0,  2 },
    {      5,   16,    8, 16,  0,  2 }, {      6,   16,    8, 16,  0,  2 }, {      7,   16,    8, 16,  0,  2 }, {      8,   16,    7, 16,  5,  2 }, {      9,   16,    7, 16,  5,  2 },
    {     10,   16,    7, 16,  5,  2 }, {     11,   16,    7, 16,  5,  2 }, {     12,   16,    7, 16,  5,  2 }, {     13,   16,    7, 16,  5,  2 }, {     14,   16,    6, 16,  5,  2 },
    {     15,   16,    6, 16,  5,  2 }, {     16,   16,    6, 16,  5,  2 }, {     17,   16,    6, 16,  5,  2 }, {     18,   16,    5, 16,  5,  2 }, {     19,   16,    5, 16,  5,  2 },
    {     20,   16,    5, 16,  5,  2 }, {     21,   16,    4, 16,  5,  2 }, {     22,   16,    4, 16,  5,  2 }, {     23,   16,    4, 16,  5,  2 }, {     24,   16,    3, 16,  6,  2 },
    {     25,   16,    3, 16,  6,  2 }, {     26,   16,    3, 16,  6,  2 }, {     27,   16,    2, 16,  6,  2 }, {     28,   16,    2, 16,  6,  2 }, {     29,   16,    1, 16,  6,  2 },
    {     30,   16,    1, 16,  6,  2 }, {     31,   16,    0, 16,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96545C, {
    {     16,   31,    8, 24,  0,  2 }, {     16,   30,    8, 24,  0,  2 }, {     16,   29,    8, 24,  0,  2 }, {     16,   28,    8, 24,  0,  2 }, {     16,   27,    8, 24,  0,  2 },
    {     16,   26,    8, 24,  0,  2 }, {     16,   25,    8, 24,  0,  2 }, {     16,   24,    8, 24,  0,  2 }, {     16,   23,    7, 24,  5,  2 }, {     16,   22,    7, 24,  5,  2 },
    {     16,   21,    7, 24,  5,  2 }, {     16,   20,    7, 24,  5,  2 }, {     16,   19,    7, 24,  5,  2 }, {     16,   18,    7, 24,  5,  2 }, {     16,   17,    6, 24,  5,  2 },
    {     16,   16,    6, 24,  5,  2 }, {     16,   15,    6, 24,  5,  2 }, {     16,   14,    6, 24,  5,  2 }, {     16,   13,    5, 24,  5,  2 }, {     16,   12,    5, 24,  5,  2 },
    {     16,   11,    5, 24,  5,  2 }, {     16,   10,    4, 24,  5,  2 }, {     16,    9,    4, 24,  5,  2 }, {     16,    8,    4, 24,  5,  2 }, {     16,    7,    3, 24,  6,  2 },
    {     16,    6,    3, 24,  6,  2 }, {     16,    5,    2, 24,  6,  2 }, {     16,    4,    2, 24,  6,  2 }, {     16,    3,    1, 24,  6,  2 }, {     16,    2,    1, 24,  6,  2 },
    {     16,    1,    0, 24,  6,  2 }, {     16,    0,    0, 24,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_966316, {
    {     31,   16,    8,  0,  0,  4 }, {     30,   16,    8,  0,  0,  4 }, {     29,   16,    8,  0,  0,  4 }, {     28,   16,    8,  0,  0,  4 }, {     27,   16,    8,  0,  0,  4 },
    {     26,   16,    8,  0,  0,  4 }, {     25,   16,    8,  0,  0,  4 }, {     24,   16,    8,  0,  0,  4 }, {     23,   16,    7,  0,  5,  4 }, {     22,   16,    7,  0,  5,  4 },
    {     21,   16,    7,  0,  5,  4 }, {     20,   16,    7,  0,  5,  4 }, {     19,   16,    7,  0,  5,  4 }, {     18,   16,    7,  0,  5,  4 }, {     17,   16,    6,  0,  5,  4 },
    {     16,   16,    6,  0,  5,  4 }, {     15,   16,    6,  0,  5,  4 }, {     14,   16,    6,  0,  5,  4 }, {     13,   16,    5,  0,  5,  4 }, {     12,   16,    5,  0,  5,  4 },
    {     11,   16,    5,  0,  5,  4 }, {     10,   16,    4,  0,  5,  4 }, {      9,   16,    4,  0,  5,  4 }, {      8,   16,    4,  0,  5,  4 }, {      7,   16,    3,  0,  6,  4 },
    {      6,   16,    3,  0,  6,  4 }, {      5,   16,    2,  0,  6,  4 }, {      4,   16,    2,  0,  6,  4 }, {      3,   16,    1,  0,  6,  4 }, {      2,   16,    1,  0,  6,  4 },
    {      1,   16,    0,  0,  6,  4 }, {      0,   16,    0,  0,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_966438, {
    {     16,    0,    8,  8,  0,  4 }, {     16,    1,    8,  8,  0,  4 }, {     16,    2,    8,  8,  0,  4 }, {     16,    3,    8,  8,  0,  4 }, {     16,    4,    8,  8,  0,  4 },
    {     16,    5,    8,  8,  0,  4 }, {     16,    6,    8,  8,  0,  4 }, {     16,    7,    8,  8,  0,  4 }, {     16,    8,    7,  8,  5,  4 }, {     16,    9,    7,  8,  5,  4 },
    {     16,   10,    7,  8,  5,  4 }, {     16,   11,    7,  8,  5,  4 }, {     16,   12,    7,  8,  5,  4 }, {     16,   13,    7,  8,  5,  4 }, {     16,   14,    6,  8,  5,  4 },
    {     16,   15,    6,  8,  5,  4 }, {     16,   16,    6,  8,  5,  4 }, {     16,   17,    6,  8,  5,  4 }, {     16,   18,    5,  8,  5,  4 }, {     16,   19,    5,  8,  5,  4 },
    {     16,   20,    5,  8,  5,  4 }, {     16,   21,    4,  8,  5,  4 }, {     16,   22,    4,  8,  5,  4 }, {     16,   23,    4,  8,  5,  4 }, {     16,   24,    3,  8,  6,  4 },
    {     16,   25,    3,  8,  6,  4 }, {     16,   26,    3,  8,  6,  4 }, {     16,   27,    2,  8,  6,  4 }, {     16,   28,    2,  8,  6,  4 }, {     16,   29,    1,  8,  6,  4 },
    {     16,   30,    1,  8,  6,  4 }, {     16,   31,    0,  8,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96655A, {
    {      0,   16,    8, 16,  0,  4 }, {      1,   16,    8, 16,  0,  4 }, {      2,   16,    8, 16,  0,  4 }, {      3,   16,    8, 16,  0,  4 }, {      4,   16,    8, 16,  0,  4 },
    {      5,   16,    8, 16,  0,  4 }, {      6,   16,    8, 16,  0,  4 }, {      7,   16,    8, 16,  0,  4 }, {      8,   16,    7, 16,  5,  4 }, {      9,   16,    7, 16,  5,  4 },
    {     10,   16,    7, 16,  5,  4 }, {     11,   16,    7, 16,  5,  4 }, {     12,   16,    7, 16,  5,  4 }, {     13,   16,    7, 16,  5,  4 }, {     14,   16,    6, 16,  5,  4 },
    {     15,   16,    6, 16,  5,  4 }, {     16,   16,    6, 16,  5,  4 }, {     17,   16,    6, 16,  5,  4 }, {     18,   16,    5, 16,  5,  4 }, {     19,   16,    5, 16,  5,  4 },
    {     20,   16,    5, 16,  5,  4 }, {     21,   16,    4, 16,  5,  4 }, {     22,   16,    4, 16,  5,  4 }, {     23,   16,    4, 16,  5,  4 }, {     24,   16,    3, 16,  6,  4 },
    {     25,   16,    3, 16,  6,  4 }, {     26,   16,    3, 16,  6,  4 }, {     27,   16,    2, 16,  6,  4 }, {     28,   16,    2, 16,  6,  4 }, {     29,   16,    1, 16,  6,  4 },
    {     30,   16,    1, 16,  6,  4 }, {     31,   16,    0, 16,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96667C, {
    {     16,   31,    8, 24,  0,  4 }, {     16,   30,    8, 24,  0,  4 }, {     16,   29,    8, 24,  0,  4 }, {     16,   28,    8, 24,  0,  4 }, {     16,   27,    8, 24,  0,  4 },
    {     16,   26,    8, 24,  0,  4 }, {     16,   25,    8, 24,  0,  4 }, {     16,   24,    8, 24,  0,  4 }, {     16,   23,    7, 24,  5,  4 }, {     16,   22,    7, 24,  5,  4 },
    {     16,   21,    7, 24,  5,  4 }, {     16,   20,    7, 24,  5,  4 }, {     16,   19,    7, 24,  5,  4 }, {     16,   18,    7, 24,  5,  4 }, {     16,   17,    6, 24,  5,  4 },
    {     16,   16,    6, 24,  5,  4 }, {     16,   15,    6, 24,  5,  4 }, {     16,   14,    6, 24,  5,  4 }, {     16,   13,    5, 24,  5,  4 }, {     16,   12,    5, 24,  5,  4 },
    {     16,   11,    5, 24,  5,  4 }, {     16,   10,    4, 24,  5,  4 }, {     16,    9,    4, 24,  5,  4 }, {     16,    8,    4, 24,  5,  4 }, {     16,    7,    3, 24,  6,  4 },
    {     16,    6,    3, 24,  6,  4 }, {     16,    5,    2, 24,  6,  4 }, {     16,    4,    2, 24,  6,  4 }, {     16,    3,    1, 24,  6,  4 }, {     16,    2,    1, 24,  6,  4 },
    {     16,    1,    0, 24,  6,  4 }, {     16,    0,    0, 24,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_964C6E, {
    {     31,   16,    7,  0,  6,  2 }, {     30,   16,    7,  0,  6,  2 }, {     29,   16,    6,  0,  6,  2 }, {     28,   16,    6,  0,  6,  2 }, {     27,   16,    5,  0,  6,  2 },
    {     26,   16,    5,  0,  6,  2 }, {     25,   16,    4,  0,  6,  2 }, {     24,   16,    4,  0,  6,  2 }, {     23,   16,    4,  0,  5,  2 }, {     22,   16,    3,  0,  5,  2 },
    {     21,   16,    3,  0,  5,  2 }, {     20,   16,    3,  0,  5,  2 }, {     19,   16,    2,  0,  5,  2 }, {     18,   16,    2,  0,  5,  2 }, {     17,   16,    2,  0,  5,  2 },
    {     16,   16,    2,  0,  5,  2 }, {     15,   16,    1,  0,  5,  2 }, {     14,   16,    1,  0,  5,  2 }, {     13,   16,    1,  0,  5,  2 }, {     12,   16,    1,  0,  5,  2 },
    {     11,   16,    1,  0,  5,  2 }, {     10,   16,    1,  0,  5,  2 }, {      9,   16,    0,  0,  0,  2 }, {      8,   16,    0,  0,  0,  2 }, {      7,   16,    0,  0,  0,  2 },
    {      6,   16,    0,  0,  0,  2 }, {      5,   16,    0,  0,  0,  2 }, {      4,   16,    0,  0,  0,  2 }, {      3,   16,    0,  0,  0,  2 }, {      2,   16,    0,  0,  0,  2 },
    {      1,   16,    0,  0,  0,  2 }, {      0,   16,    0,  0,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_964D90, {
    {     16,    0,    8,  8,  6,  2 }, {     16,    1,    7,  8,  6,  2 }, {     16,    2,    7,  8,  6,  2 }, {     16,    3,    6,  8,  6,  2 }, {     16,    4,    6,  8,  6,  2 },
    {     16,    5,    5,  8,  6,  2 }, {     16,    6,    5,  8,  6,  2 }, {     16,    7,    4,  8,  6,  2 }, {     16,    8,    4,  8,  5,  2 }, {     16,    9,    3,  8,  5,  2 },
    {     16,   10,    3,  8,  5,  2 }, {     16,   11,    3,  8,  5,  2 }, {     16,   12,    2,  8,  5,  2 }, {     16,   13,    2,  8,  5,  2 }, {     16,   14,    2,  8,  5,  2 },
    {     16,   15,    2,  8,  5,  2 }, {     16,   16,    1,  8,  5,  2 }, {     16,   17,    1,  8,  5,  2 }, {     16,   18,    1,  8,  5,  2 }, {     16,   19,    1,  8,  5,  2 },
    {     16,   20,    1,  8,  5,  2 }, {     16,   21,    1,  8,  5,  2 }, {     16,   22,    0,  8,  0,  2 }, {     16,   23,    0,  8,  0,  2 }, {     16,   24,    0,  8,  0,  2 },
    {     16,   25,    0,  8,  0,  2 }, {     16,   26,    0,  8,  0,  2 }, {     16,   27,    0,  8,  0,  2 }, {     16,   28,    0,  8,  0,  2 }, {     16,   29,    0,  8,  0,  2 },
    {     16,   30,    0,  8,  0,  2 }, {     16,   31,    0,  8,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_964EB2, {
    {      0,   16,    8, 16,  6,  2 }, {      1,   16,    7, 16,  6,  2 }, {      2,   16,    7, 16,  6,  2 }, {      3,   16,    6, 16,  6,  2 }, {      4,   16,    6, 16,  6,  2 },
    {      5,   16,    5, 16,  6,  2 }, {      6,   16,    5, 16,  6,  2 }, {      7,   16,    4, 16,  6,  2 }, {      8,   16,    4, 16,  5,  2 }, {      9,   16,    3, 16,  5,  2 },
    {     10,   16,    3, 16,  5,  2 }, {     11,   16,    3, 16,  5,  2 }, {     12,   16,    2, 16,  5,  2 }, {     13,   16,    2, 16,  5,  2 }, {     14,   16,    2, 16,  5,  2 },
    {     15,   16,    2, 16,  5,  2 }, {     16,   16,    1, 16,  5,  2 }, {     17,   16,    1, 16,  5,  2 }, {     18,   16,    1, 16,  5,  2 }, {     19,   16,    1, 16,  5,  2 },
    {     20,   16,    1, 16,  5,  2 }, {     21,   16,    1, 16,  5,  2 }, {     22,   16,    0, 16,  0,  2 }, {     23,   16,    0, 16,  0,  2 }, {     24,   16,    0, 16,  0,  2 },
    {     25,   16,    0, 16,  0,  2 }, {     26,   16,    0, 16,  0,  2 }, {     27,   16,    0, 16,  0,  2 }, {     28,   16,    0, 16,  0,  2 }, {     29,   16,    0, 16,  0,  2 },
    {     30,   16,    0, 16,  0,  2 }, {     31,   16,    0, 16,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_964FD4, {
    {     16,   31,    7, 24,  6,  2 }, {     16,   30,    7, 24,  6,  2 }, {     16,   29,    6, 24,  6,  2 }, {     16,   28,    6, 24,  6,  2 }, {     16,   27,    5, 24,  6,  2 },
    {     16,   26,    5, 24,  6,  2 }, {     16,   25,    4, 24,  6,  2 }, {     16,   24,    4, 24,  6,  2 }, {     16,   23,    4, 24,  5,  2 }, {     16,   22,    3, 24,  5,  2 },
    {     16,   21,    3, 24,  5,  2 }, {     16,   20,    3, 24,  5,  2 }, {     16,   19,    2, 24,  5,  2 }, {     16,   18,    2, 24,  5,  2 }, {     16,   17,    2, 24,  5,  2 },
    {     16,   16,    2, 24,  5,  2 }, {     16,   15,    1, 24,  5,  2 }, {     16,   14,    1, 24,  5,  2 }, {     16,   13,    1, 24,  5,  2 }, {     16,   12,    1, 24,  5,  2 },
    {     16,   11,    1, 24,  5,  2 }, {     16,   10,    1, 24,  5,  2 }, {     16,    9,    0, 24,  0,  2 }, {     16,    8,    0, 24,  0,  2 }, {     16,    7,    0, 24,  0,  2 },
    {     16,    6,    0, 24,  0,  2 }, {     16,    5,    0, 24,  0,  2 }, {     16,    4,    0, 24,  0,  2 }, {     16,    3,    0, 24,  0,  2 }, {     16,    2,    0, 24,  0,  2 },
    {     16,    1,    0, 24,  0,  2 }, {     16,    0,    0, 24,  0,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_965E8E, {
    {     31,   16,    7,  0,  6,  4 }, {     30,   16,    7,  0,  6,  4 }, {     29,   16,    6,  0,  6,  4 }, {     28,   16,    6,  0,  6,  4 }, {     27,   16,    5,  0,  6,  4 },
    {     26,   16,    5,  0,  6,  4 }, {     25,   16,    4,  0,  6,  4 }, {     24,   16,    4,  0,  6,  4 }, {     23,   16,    4,  0,  5,  4 }, {     22,   16,    3,  0,  5,  4 },
    {     21,   16,    3,  0,  5,  4 }, {     20,   16,    3,  0,  5,  4 }, {     19,   16,    2,  0,  5,  4 }, {     18,   16,    2,  0,  5,  4 }, {     17,   16,    2,  0,  5,  4 },
    {     16,   16,    2,  0,  5,  4 }, {     15,   16,    1,  0,  5,  4 }, {     14,   16,    1,  0,  5,  4 }, {     13,   16,    1,  0,  5,  4 }, {     12,   16,    1,  0,  5,  4 },
    {     11,   16,    1,  0,  5,  4 }, {     10,   16,    1,  0,  5,  4 }, {      9,   16,    0,  0,  0,  4 }, {      8,   16,    0,  0,  0,  4 }, {      7,   16,    0,  0,  0,  4 },
    {      6,   16,    0,  0,  0,  4 }, {      5,   16,    0,  0,  0,  4 }, {      4,   16,    0,  0,  0,  4 }, {      3,   16,    0,  0,  0,  4 }, {      2,   16,    0,  0,  0,  4 },
    {      1,   16,    0,  0,  0,  4 }, {      0,   16,    0,  0,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_965FB0, {
    {     16,    0,    8,  8,  6,  4 }, {     16,    1,    7,  8,  6,  4 }, {     16,    2,    7,  8,  6,  4 }, {     16,    3,    6,  8,  6,  4 }, {     16,    4,    6,  8,  6,  4 },
    {     16,    5,    5,  8,  6,  4 }, {     16,    6,    5,  8,  6,  4 }, {     16,    7,    4,  8,  6,  4 }, {     16,    8,    4,  8,  5,  4 }, {     16,    9,    3,  8,  5,  4 },
    {     16,   10,    3,  8,  5,  4 }, {     16,   11,    3,  8,  5,  4 }, {     16,   12,    2,  8,  5,  4 }, {     16,   13,    2,  8,  5,  4 }, {     16,   14,    2,  8,  5,  4 },
    {     16,   15,    2,  8,  5,  4 }, {     16,   16,    1,  8,  5,  4 }, {     16,   17,    1,  8,  5,  4 }, {     16,   18,    1,  8,  5,  4 }, {     16,   19,    1,  8,  5,  4 },
    {     16,   20,    1,  8,  5,  4 }, {     16,   21,    1,  8,  5,  4 }, {     16,   22,    0,  8,  0,  4 }, {     16,   23,    0,  8,  0,  4 }, {     16,   24,    0,  8,  0,  4 },
    {     16,   25,    0,  8,  0,  4 }, {     16,   26,    0,  8,  0,  4 }, {     16,   27,    0,  8,  0,  4 }, {     16,   28,    0,  8,  0,  4 }, {     16,   29,    0,  8,  0,  4 },
    {     16,   30,    0,  8,  0,  4 }, {     16,   31,    0,  8,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9660D2, {
    {      0,   16,    8, 16,  6,  4 }, {      1,   16,    7, 16,  6,  4 }, {      2,   16,    7, 16,  6,  4 }, {      3,   16,    6, 16,  6,  4 }, {      4,   16,    6, 16,  6,  4 },
    {      5,   16,    5, 16,  6,  4 }, {      6,   16,    5, 16,  6,  4 }, {      7,   16,    4, 16,  6,  4 }, {      8,   16,    4, 16,  5,  4 }, {      9,   16,    3, 16,  5,  4 },
    {     10,   16,    3, 16,  5,  4 }, {     11,   16,    3, 16,  5,  4 }, {     12,   16,    2, 16,  5,  4 }, {     13,   16,    2, 16,  5,  4 }, {     14,   16,    2, 16,  5,  4 },
    {     15,   16,    2, 16,  5,  4 }, {     16,   16,    1, 16,  5,  4 }, {     17,   16,    1, 16,  5,  4 }, {     18,   16,    1, 16,  5,  4 }, {     19,   16,    1, 16,  5,  4 },
    {     20,   16,    1, 16,  5,  4 }, {     21,   16,    1, 16,  5,  4 }, {     22,   16,    0, 16,  0,  4 }, {     23,   16,    0, 16,  0,  4 }, {     24,   16,    0, 16,  0,  4 },
    {     25,   16,    0, 16,  0,  4 }, {     26,   16,    0, 16,  0,  4 }, {     27,   16,    0, 16,  0,  4 }, {     28,   16,    0, 16,  0,  4 }, {     29,   16,    0, 16,  0,  4 },
    {     30,   16,    0, 16,  0,  4 }, {     31,   16,    0, 16,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9661F4, {
    {     16,   31,    7, 24,  6,  4 }, {     16,   30,    7, 24,  6,  4 }, {     16,   29,    6, 24,  6,  4 }, {     16,   28,    6, 24,  6,  4 }, {     16,   27,    5, 24,  6,  4 },
    {     16,   26,    5, 24,  6,  4 }, {     16,   25,    4, 24,  6,  4 }, {     16,   24,    4, 24,  6,  4 }, {     16,   23,    4, 24,  5,  4 }, {     16,   22,    3, 24,  5,  4 },
    {     16,   21,    3, 24,  5,  4 }, {     16,   20,    3, 24,  5,  4 }, {     16,   19,    2, 24,  5,  4 }, {     16,   18,    2, 24,  5,  4 }, {     16,   17,    2, 24,  5,  4 },
    {     16,   16,    2, 24,  5,  4 }, {     16,   15,    1, 24,  5,  4 }, {     16,   14,    1, 24,  5,  4 }, {     16,   13,    1, 24,  5,  4 }, {     16,   12,    1, 24,  5,  4 },
    {     16,   11,    1, 24,  5,  4 }, {     16,   10,    1, 24,  5,  4 }, {     16,    9,    0, 24,  0,  4 }, {     16,    8,    0, 24,  0,  4 }, {     16,    7,    0, 24,  0,  4 },
    {     16,    6,    0, 24,  0,  4 }, {     16,    5,    0, 24,  0,  4 }, {     16,    4,    0, 24,  0,  4 }, {     16,    3,    0, 24,  0,  4 }, {     16,    2,    0, 24,  0,  4 },
    {     16,    1,    0, 24,  0,  4 }, {     16,    0,    0, 24,  0,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96679E, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  1,  1 }, {     22,   16,    0,  0,  1,  1 },
    {     21,   16,    1,  0,  1,  1 }, {     20,   16,    1,  0,  1,  1 }, {     19,   16,    1,  0,  1,  1 }, {     18,   16,    1,  0,  1,  1 }, {     17,   16,    1,  0,  1,  1 },
    {     16,   16,    1,  0,  1,  1 }, {     15,   16,    2,  0,  1,  1 }, {     14,   16,    2,  0,  1,  1 }, {     13,   16,    2,  0,  1,  1 }, {     12,   16,    2,  0,  1,  1 },
    {     11,   16,    3,  0,  1,  1 }, {     10,   16,    3,  0,  1,  1 }, {      9,   16,    3,  0,  1,  1 }, {      8,   16,    4,  0,  1,  1 }, {      7,   16,    4,  0,  2,  2 },
    {      6,   16,    4,  0,  2,  2 }, {      5,   16,    5,  0,  2,  2 }, {      4,   16,    5,  0,  2,  2 }, {      3,   16,    6,  0,  2,  2 }, {      2,   16,    6,  0,  2,  2 },
    {      1,   16,    7,  0,  2,  2 }, {      0,   16,    7,  0,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9668C0, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  1,  1 }, {     16,    9,    0,  8,  1,  1 },
    {     16,   10,    1,  8,  1,  1 }, {     16,   11,    1,  8,  1,  1 }, {     16,   12,    1,  8,  1,  1 }, {     16,   13,    1,  8,  1,  1 }, {     16,   14,    1,  8,  1,  1 },
    {     16,   15,    1,  8,  1,  1 }, {     16,   16,    2,  8,  1,  1 }, {     16,   17,    2,  8,  1,  1 }, {     16,   18,    2,  8,  1,  1 }, {     16,   19,    2,  8,  1,  1 },
    {     16,   20,    3,  8,  1,  1 }, {     16,   21,    3,  8,  1,  1 }, {     16,   22,    3,  8,  1,  1 }, {     16,   23,    4,  8,  1,  1 }, {     16,   24,    4,  8,  2,  2 },
    {     16,   25,    4,  8,  2,  2 }, {     16,   26,    5,  8,  2,  2 }, {     16,   27,    5,  8,  2,  2 }, {     16,   28,    6,  8,  2,  2 }, {     16,   29,    6,  8,  2,  2 },
    {     16,   30,    7,  8,  2,  2 }, {     16,   31,    7,  8,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9669E2, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  1,  1 }, {      9,   16,    0, 16,  1,  1 },
    {     10,   16,    1, 16,  1,  1 }, {     11,   16,    1, 16,  1,  1 }, {     12,   16,    1, 16,  1,  1 }, {     13,   16,    1, 16,  1,  1 }, {     14,   16,    1, 16,  1,  1 },
    {     15,   16,    1, 16,  1,  1 }, {     16,   16,    2, 16,  1,  1 }, {     17,   16,    2, 16,  1,  1 }, {     18,   16,    2, 16,  1,  1 }, {     19,   16,    2, 16,  1,  1 },
    {     20,   16,    3, 16,  1,  1 }, {     21,   16,    3, 16,  1,  1 }, {     22,   16,    3, 16,  1,  1 }, {     23,   16,    4, 16,  1,  1 }, {     24,   16,    4, 16,  2,  2 },
    {     25,   16,    4, 16,  2,  2 }, {     26,   16,    5, 16,  2,  2 }, {     27,   16,    5, 16,  2,  2 }, {     28,   16,    6, 16,  2,  2 }, {     29,   16,    6, 16,  2,  2 },
    {     30,   16,    7, 16,  2,  2 }, {     31,   16,    7, 16,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_966B04, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  1,  1 }, {     16,   22,    0, 24,  1,  1 },
    {     16,   21,    1, 24,  1,  1 }, {     16,   20,    1, 24,  1,  1 }, {     16,   19,    1, 24,  1,  1 }, {     16,   18,    1, 24,  1,  1 }, {     16,   17,    1, 24,  1,  1 },
    {     16,   16,    1, 24,  1,  1 }, {     16,   15,    2, 24,  1,  1 }, {     16,   14,    2, 24,  1,  1 }, {     16,   13,    2, 24,  1,  1 }, {     16,   12,    2, 24,  1,  1 },
    {     16,   11,    3, 24,  1,  1 }, {     16,   10,    3, 24,  1,  1 }, {     16,    9,    3, 24,  1,  1 }, {     16,    8,    4, 24,  1,  1 }, {     16,    7,    4, 24,  2,  2 },
    {     16,    6,    4, 24,  2,  2 }, {     16,    5,    5, 24,  2,  2 }, {     16,    4,    5, 24,  2,  2 }, {     16,    3,    6, 24,  2,  2 }, {     16,    2,    6, 24,  2,  2 },
    {     16,    1,    7, 24,  2,  2 }, {     16,    0,    7, 24,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_966C26, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  1,  3 }, {     22,   16,    0,  0,  1,  3 },
    {     21,   16,    1,  0,  1,  3 }, {     20,   16,    1,  0,  1,  3 }, {     19,   16,    1,  0,  1,  3 }, {     18,   16,    1,  0,  1,  3 }, {     17,   16,    1,  0,  1,  3 },
    {     16,   16,    1,  0,  1,  3 }, {     15,   16,    2,  0,  1,  3 }, {     14,   16,    2,  0,  1,  3 }, {     13,   16,    2,  0,  1,  3 }, {     12,   16,    2,  0,  1,  3 },
    {     11,   16,    3,  0,  1,  3 }, {     10,   16,    3,  0,  1,  3 }, {      9,   16,    3,  0,  1,  3 }, {      8,   16,    4,  0,  1,  3 }, {      7,   16,    4,  0,  2,  4 },
    {      6,   16,    4,  0,  2,  4 }, {      5,   16,    5,  0,  2,  4 }, {      4,   16,    5,  0,  2,  4 }, {      3,   16,    6,  0,  2,  4 }, {      2,   16,    6,  0,  2,  4 },
    {      1,   16,    7,  0,  2,  4 }, {      0,   16,    7,  0,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_966D48, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  1,  3 }, {     16,    9,    0,  8,  1,  3 },
    {     16,   10,    1,  8,  1,  3 }, {     16,   11,    1,  8,  1,  3 }, {     16,   12,    1,  8,  1,  3 }, {     16,   13,    1,  8,  1,  3 }, {     16,   14,    1,  8,  1,  3 },
    {     16,   15,    1,  8,  1,  3 }, {     16,   16,    2,  8,  1,  3 }, {     16,   17,    2,  8,  1,  3 }, {     16,   18,    2,  8,  1,  3 }, {     16,   19,    2,  8,  1,  3 },
    {     16,   20,    3,  8,  1,  3 }, {     16,   21,    3,  8,  1,  3 }, {     16,   22,    3,  8,  1,  3 }, {     16,   23,    4,  8,  1,  3 }, {     16,   24,    4,  8,  2,  4 },
    {     16,   25,    4,  8,  2,  4 }, {     16,   26,    5,  8,  2,  4 }, {     16,   27,    5,  8,  2,  4 }, {     16,   28,    6,  8,  2,  4 }, {     16,   29,    6,  8,  2,  4 },
    {     16,   30,    7,  8,  2,  4 }, {     16,   31,    7,  8,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_966E6A, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  1,  3 }, {      9,   16,    0, 16,  1,  3 },
    {     10,   16,    1, 16,  1,  3 }, {     11,   16,    1, 16,  1,  3 }, {     12,   16,    1, 16,  1,  3 }, {     13,   16,    1, 16,  1,  3 }, {     14,   16,    1, 16,  1,  3 },
    {     15,   16,    1, 16,  1,  3 }, {     16,   16,    2, 16,  1,  3 }, {     17,   16,    2, 16,  1,  3 }, {     18,   16,    2, 16,  1,  3 }, {     19,   16,    2, 16,  1,  3 },
    {     20,   16,    3, 16,  1,  3 }, {     21,   16,    3, 16,  1,  3 }, {     22,   16,    3, 16,  1,  3 }, {     23,   16,    4, 16,  1,  3 }, {     24,   16,    4, 16,  2,  4 },
    {     25,   16,    4, 16,  2,  4 }, {     26,   16,    5, 16,  2,  4 }, {     27,   16,    5, 16,  2,  4 }, {     28,   16,    6, 16,  2,  4 }, {     29,   16,    6, 16,  2,  4 },
    {     30,   16,    7, 16,  2,  4 }, {     31,   16,    7, 16,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_966F8C, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  1,  3 }, {     16,   22,    0, 24,  1,  3 },
    {     16,   21,    1, 24,  1,  3 }, {     16,   20,    1, 24,  1,  3 }, {     16,   19,    1, 24,  1,  3 }, {     16,   18,    1, 24,  1,  3 }, {     16,   17,    1, 24,  1,  3 },
    {     16,   16,    1, 24,  1,  3 }, {     16,   15,    2, 24,  1,  3 }, {     16,   14,    2, 24,  1,  3 }, {     16,   13,    2, 24,  1,  3 }, {     16,   12,    2, 24,  1,  3 },
    {     16,   11,    3, 24,  1,  3 }, {     16,   10,    3, 24,  1,  3 }, {     16,    9,    3, 24,  1,  3 }, {     16,    8,    4, 24,  1,  3 }, {     16,    7,    4, 24,  2,  4 },
    {     16,    6,    4, 24,  2,  4 }, {     16,    5,    5, 24,  2,  4 }, {     16,    4,    5, 24,  2,  4 }, {     16,    3,    6, 24,  2,  4 }, {     16,    2,    6, 24,  2,  4 },
    {     16,    1,    7, 24,  2,  4 }, {     16,    0,    7, 24,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9670AE, {
    {     31,   16,    0,  0,  2,  2 }, {     30,   16,    0,  0,  2,  2 }, {     29,   16,    1,  0,  2,  2 }, {     28,   16,    1,  0,  2,  2 }, {     27,   16,    2,  0,  2,  2 },
    {     26,   16,    2,  0,  2,  2 }, {     25,   16,    3,  0,  2,  2 }, {     24,   16,    3,  0,  2,  2 }, {     23,   16,    4,  0,  1,  1 }, {     22,   16,    4,  0,  1,  1 },
    {     21,   16,    4,  0,  1,  1 }, {     20,   16,    5,  0,  1,  1 }, {     19,   16,    5,  0,  1,  1 }, {     18,   16,    5,  0,  1,  1 }, {     17,   16,    6,  0,  1,  1 },
    {     16,   16,    6,  0,  1,  1 }, {     15,   16,    6,  0,  1,  1 }, {     14,   16,    6,  0,  1,  1 }, {     13,   16,    7,  0,  1,  1 }, {     12,   16,    7,  0,  1,  1 },
    {     11,   16,    7,  0,  1,  1 }, {     10,   16,    7,  0,  1,  1 }, {      9,   16,    7,  0,  0,  0 }, {      8,   16,    7,  0,  0,  0 }, {      7,   16,    8,  0,  0,  0 },
    {      6,   16,    8,  0,  0,  0 }, {      5,   16,    8,  0,  0,  0 }, {      4,   16,    8,  0,  0,  0 }, {      3,   16,    8,  0,  0,  0 }, {      2,   16,    8,  0,  0,  0 },
    {      1,   16,    8,  0,  0,  0 }, {      0,   16,    8,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9671E2, {
    {     16,    0,    0,  8,  2,  2 }, {     16,    1,    0,  8,  2,  2 }, {     16,    2,    1,  8,  2,  2 }, {     16,    3,    1,  8,  2,  2 }, {     16,    4,    2,  8,  2,  2 },
    {     16,    5,    2,  8,  2,  2 }, {     16,    6,    3,  8,  2,  2 }, {     16,    7,    3,  8,  2,  2 }, {     16,    8,    4,  8,  1,  1 }, {     16,    9,    4,  8,  1,  1 },
    {     16,   10,    4,  8,  1,  1 }, {     16,   11,    5,  8,  1,  1 }, {     16,   12,    5,  8,  1,  1 }, {     16,   13,    5,  8,  1,  1 }, {     16,   14,    6,  8,  1,  1 },
    {     16,   15,    6,  8,  1,  1 }, {     16,   16,    6,  8,  1,  1 }, {     16,   17,    6,  8,  1,  1 }, {     16,   18,    7,  8,  1,  1 }, {     16,   19,    7,  8,  1,  1 },
    {     16,   20,    7,  8,  1,  1 }, {     16,   21,    7,  8,  1,  1 }, {     16,   22,    7,  8,  0,  0 }, {     16,   23,    7,  8,  0,  0 }, {     16,   24,    8,  8,  0,  0 },
    {     16,   25,    8,  8,  0,  0 }, {     16,   26,    8,  8,  0,  0 }, {     16,   27,    8,  8,  0,  0 }, {     16,   28,    8,  8,  0,  0 }, {     16,   29,    8,  8,  0,  0 },
    {     16,   30,    8,  8,  0,  0 }, {     16,   31,    8,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_967316, {
    {      0,   16,    0, 16,  2,  2 }, {      1,   16,    0, 16,  2,  2 }, {      2,   16,    1, 16,  2,  2 }, {      3,   16,    1, 16,  2,  2 }, {      4,   16,    2, 16,  2,  2 },
    {      5,   16,    2, 16,  2,  2 }, {      6,   16,    3, 16,  2,  2 }, {      7,   16,    3, 16,  2,  2 }, {      8,   16,    4, 16,  1,  1 }, {      9,   16,    4, 16,  1,  1 },
    {     10,   16,    4, 16,  1,  1 }, {     11,   16,    5, 16,  1,  1 }, {     12,   16,    5, 16,  1,  1 }, {     13,   16,    5, 16,  1,  1 }, {     14,   16,    6, 16,  1,  1 },
    {     15,   16,    6, 16,  1,  1 }, {     16,   16,    6, 16,  1,  1 }, {     17,   16,    6, 16,  1,  1 }, {     18,   16,    7, 16,  1,  1 }, {     19,   16,    7, 16,  1,  1 },
    {     20,   16,    7, 16,  1,  1 }, {     21,   16,    7, 16,  1,  1 }, {     22,   16,    7, 16,  0,  0 }, {     23,   16,    7, 16,  0,  0 }, {     24,   16,    8, 16,  0,  0 },
    {     25,   16,    8, 16,  0,  0 }, {     26,   16,    8, 16,  0,  0 }, {     27,   16,    8, 16,  0,  0 }, {     28,   16,    8, 16,  0,  0 }, {     29,   16,    8, 16,  0,  0 },
    {     30,   16,    8, 16,  0,  0 }, {     31,   16,    8, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96744A, {
    {     16,   31,    0, 24,  2,  2 }, {     16,   30,    0, 24,  2,  2 }, {     16,   29,    1, 24,  2,  2 }, {     16,   28,    1, 24,  2,  2 }, {     16,   27,    2, 24,  2,  2 },
    {     16,   26,    2, 24,  2,  2 }, {     16,   25,    3, 24,  2,  2 }, {     16,   24,    3, 24,  2,  2 }, {     16,   23,    4, 24,  1,  1 }, {     16,   22,    4, 24,  1,  1 },
    {     16,   21,    4, 24,  1,  1 }, {     16,   20,    5, 24,  1,  1 }, {     16,   19,    5, 24,  1,  1 }, {     16,   18,    5, 24,  1,  1 }, {     16,   17,    6, 24,  1,  1 },
    {     16,   16,    6, 24,  1,  1 }, {     16,   15,    6, 24,  1,  1 }, {     16,   14,    6, 24,  1,  1 }, {     16,   13,    7, 24,  1,  1 }, {     16,   12,    7, 24,  1,  1 },
    {     16,   11,    7, 24,  1,  1 }, {     16,   10,    7, 24,  1,  1 }, {     16,    9,    7, 24,  0,  0 }, {     16,    8,    7, 24,  0,  0 }, {     16,    7,    8, 24,  0,  0 },
    {     16,    6,    8, 24,  0,  0 }, {     16,    5,    8, 24,  0,  0 }, {     16,    4,    8, 24,  0,  0 }, {     16,    3,    8, 24,  0,  0 }, {     16,    2,    8, 24,  0,  0 },
    {     16,    1,    8, 24,  0,  0 }, {     16,    0,    8, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96757E, {
    {     31,   16,    0,  0,  2,  4 }, {     30,   16,    0,  0,  2,  4 }, {     29,   16,    1,  0,  2,  4 }, {     28,   16,    1,  0,  2,  4 }, {     27,   16,    2,  0,  2,  4 },
    {     26,   16,    2,  0,  2,  4 }, {     25,   16,    3,  0,  2,  4 }, {     24,   16,    3,  0,  2,  4 }, {     23,   16,    4,  0,  1,  3 }, {     22,   16,    4,  0,  1,  3 },
    {     21,   16,    4,  0,  1,  3 }, {     20,   16,    5,  0,  1,  3 }, {     19,   16,    5,  0,  1,  3 }, {     18,   16,    5,  0,  1,  3 }, {     17,   16,    6,  0,  1,  3 },
    {     16,   16,    6,  0,  1,  3 }, {     15,   16,    6,  0,  1,  3 }, {     14,   16,    6,  0,  1,  3 }, {     13,   16,    7,  0,  1,  3 }, {     12,   16,    7,  0,  1,  3 },
    {     11,   16,    7,  0,  1,  3 }, {     10,   16,    7,  0,  1,  3 }, {      9,   16,    7,  0,  0,  0 }, {      8,   16,    7,  0,  0,  0 }, {      7,   16,    8,  0,  0,  0 },
    {      6,   16,    8,  0,  0,  0 }, {      5,   16,    8,  0,  0,  0 }, {      4,   16,    8,  0,  0,  0 }, {      3,   16,    8,  0,  0,  0 }, {      2,   16,    8,  0,  0,  0 },
    {      1,   16,    8,  0,  0,  0 }, {      0,   16,    8,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9676B2, {
    {     16,    0,    0,  8,  2,  4 }, {     16,    1,    0,  8,  2,  4 }, {     16,    2,    1,  8,  2,  4 }, {     16,    3,    1,  8,  2,  4 }, {     16,    4,    2,  8,  2,  4 },
    {     16,    5,    2,  8,  2,  4 }, {     16,    6,    3,  8,  2,  4 }, {     16,    7,    3,  8,  2,  4 }, {     16,    8,    4,  8,  1,  3 }, {     16,    9,    4,  8,  1,  3 },
    {     16,   10,    4,  8,  1,  3 }, {     16,   11,    5,  8,  1,  3 }, {     16,   12,    5,  8,  1,  3 }, {     16,   13,    5,  8,  1,  3 }, {     16,   14,    6,  8,  1,  3 },
    {     16,   15,    6,  8,  1,  3 }, {     16,   16,    6,  8,  1,  3 }, {     16,   17,    6,  8,  1,  3 }, {     16,   18,    7,  8,  1,  3 }, {     16,   19,    7,  8,  1,  3 },
    {     16,   20,    7,  8,  1,  3 }, {     16,   21,    7,  8,  1,  3 }, {     16,   22,    7,  8,  0,  0 }, {     16,   23,    7,  8,  0,  0 }, {     16,   24,    8,  8,  0,  0 },
    {     16,   25,    8,  8,  0,  0 }, {     16,   26,    8,  8,  0,  0 }, {     16,   27,    8,  8,  0,  0 }, {     16,   28,    8,  8,  0,  0 }, {     16,   29,    8,  8,  0,  0 },
    {     16,   30,    8,  8,  0,  0 }, {     16,   31,    8,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9677E6, {
    {      0,   16,    0, 16,  2,  4 }, {      1,   16,    0, 16,  2,  4 }, {      2,   16,    1, 16,  2,  4 }, {      3,   16,    1, 16,  2,  4 }, {      4,   16,    2, 16,  2,  4 },
    {      5,   16,    2, 16,  2,  4 }, {      6,   16,    3, 16,  2,  4 }, {      7,   16,    3, 16,  2,  4 }, {      8,   16,    4, 16,  1,  3 }, {      9,   16,    4, 16,  1,  3 },
    {     10,   16,    4, 16,  1,  3 }, {     11,   16,    5, 16,  1,  3 }, {     12,   16,    5, 16,  1,  3 }, {     13,   16,    5, 16,  1,  3 }, {     14,   16,    6, 16,  1,  3 },
    {     15,   16,    6, 16,  1,  3 }, {     16,   16,    6, 16,  1,  3 }, {     17,   16,    6, 16,  1,  3 }, {     18,   16,    7, 16,  1,  3 }, {     19,   16,    7, 16,  1,  3 },
    {     20,   16,    7, 16,  1,  3 }, {     21,   16,    7, 16,  1,  3 }, {     22,   16,    7, 16,  0,  0 }, {     23,   16,    7, 16,  0,  0 }, {     24,   16,    8, 16,  0,  0 },
    {     25,   16,    8, 16,  0,  0 }, {     26,   16,    8, 16,  0,  0 }, {     27,   16,    8, 16,  0,  0 }, {     28,   16,    8, 16,  0,  0 }, {     29,   16,    8, 16,  0,  0 },
    {     30,   16,    8, 16,  0,  0 }, {     31,   16,    8, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96791A, {
    {     16,   31,    0, 24,  2,  4 }, {     16,   30,    0, 24,  2,  4 }, {     16,   29,    1, 24,  2,  4 }, {     16,   28,    1, 24,  2,  4 }, {     16,   27,    2, 24,  2,  4 },
    {     16,   26,    2, 24,  2,  4 }, {     16,   25,    3, 24,  2,  4 }, {     16,   24,    3, 24,  2,  4 }, {     16,   23,    4, 24,  1,  3 }, {     16,   22,    4, 24,  1,  3 },
    {     16,   21,    4, 24,  1,  3 }, {     16,   20,    5, 24,  1,  3 }, {     16,   19,    5, 24,  1,  3 }, {     16,   18,    5, 24,  1,  3 }, {     16,   17,    6, 24,  1,  3 },
    {     16,   16,    6, 24,  1,  3 }, {     16,   15,    6, 24,  1,  3 }, {     16,   14,    6, 24,  1,  3 }, {     16,   13,    7, 24,  1,  3 }, {     16,   12,    7, 24,  1,  3 },
    {     16,   11,    7, 24,  1,  3 }, {     16,   10,    7, 24,  1,  3 }, {     16,    9,    7, 24,  0,  0 }, {     16,    8,    7, 24,  0,  0 }, {     16,    7,    8, 24,  0,  0 },
    {     16,    6,    8, 24,  0,  0 }, {     16,    5,    8, 24,  0,  0 }, {     16,    4,    8, 24,  0,  0 }, {     16,    3,    8, 24,  0,  0 }, {     16,    2,    8, 24,  0,  0 },
    {     16,    1,    8, 24,  0,  0 }, {     16,    0,    8, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96835E, {
    {     31,   16,    8,  0,  0,  0 }, {     30,   16,    8,  0,  0,  0 }, {     29,   16,    8,  0,  0,  0 }, {     28,   16,    8,  0,  0,  0 }, {     27,   16,    8,  0,  0,  0 },
    {     26,   16,    8,  0,  0,  0 }, {     25,   16,    8,  0,  0,  0 }, {     24,   16,    8,  0,  0,  0 }, {     23,   16,    7,  0,  5,  1 }, {     22,   16,    7,  0,  5,  1 },
    {     21,   16,    7,  0,  5,  1 }, {     20,   16,    7,  0,  5,  1 }, {     19,   16,    7,  0,  5,  1 }, {     18,   16,    7,  0,  5,  1 }, {     17,   16,    6,  0,  5,  1 },
    {     16,   16,    6,  0,  5,  1 }, {     15,   16,    6,  0,  5,  1 }, {     14,   16,    6,  0,  5,  1 }, {     13,   16,    5,  0,  5,  1 }, {     12,   16,    5,  0,  5,  1 },
    {     11,   16,    5,  0,  5,  1 }, {     10,   16,    4,  0,  5,  1 }, {      9,   16,    4,  0,  5,  1 }, {      8,   16,    4,  0,  5,  1 }, {      7,   16,    3,  0,  6,  2 },
    {      6,   16,    3,  0,  6,  2 }, {      5,   16,    2,  0,  6,  2 }, {      4,   16,    2,  0,  6,  2 }, {      3,   16,    1,  0,  6,  2 }, {      2,   16,    1,  0,  6,  2 },
    {      1,   16,    0,  0,  6,  2 }, {      0,   16,    0,  0,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_968480, {
    {     16,    0,    8,  8,  0,  0 }, {     16,    1,    8,  8,  0,  0 }, {     16,    2,    8,  8,  0,  0 }, {     16,    3,    8,  8,  0,  0 }, {     16,    4,    8,  8,  0,  0 },
    {     16,    5,    8,  8,  0,  0 }, {     16,    6,    8,  8,  0,  0 }, {     16,    7,    8,  8,  0,  0 }, {     16,    8,    7,  8,  5,  1 }, {     16,    9,    7,  8,  5,  1 },
    {     16,   10,    7,  8,  5,  1 }, {     16,   11,    7,  8,  5,  1 }, {     16,   12,    7,  8,  5,  1 }, {     16,   13,    7,  8,  5,  1 }, {     16,   14,    6,  8,  5,  1 },
    {     16,   15,    6,  8,  5,  1 }, {     16,   16,    6,  8,  5,  1 }, {     16,   17,    6,  8,  5,  1 }, {     16,   18,    5,  8,  5,  1 }, {     16,   19,    5,  8,  5,  1 },
    {     16,   20,    5,  8,  5,  1 }, {     16,   21,    4,  8,  5,  1 }, {     16,   22,    4,  8,  5,  1 }, {     16,   23,    4,  8,  5,  1 }, {     16,   24,    3,  8,  6,  2 },
    {     16,   25,    3,  8,  6,  2 }, {     16,   26,    2,  8,  6,  2 }, {     16,   27,    2,  8,  6,  2 }, {     16,   28,    1,  8,  6,  2 }, {     16,   29,    1,  8,  6,  2 },
    {     16,   30,    0,  8,  6,  2 }, {     16,   31,    0,  8,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9685A2, {
    {      0,   16,    8, 16,  0,  0 }, {      1,   16,    8, 16,  0,  0 }, {      2,   16,    8, 16,  0,  0 }, {      3,   16,    8, 16,  0,  0 }, {      4,   16,    8, 16,  0,  0 },
    {      5,   16,    8, 16,  0,  0 }, {      6,   16,    8, 16,  0,  0 }, {      7,   16,    8, 16,  0,  0 }, {      8,   16,    7, 16,  5,  1 }, {      9,   16,    7, 16,  5,  1 },
    {     10,   16,    7, 16,  5,  1 }, {     11,   16,    7, 16,  5,  1 }, {     12,   16,    7, 16,  5,  1 }, {     13,   16,    7, 16,  5,  1 }, {     14,   16,    6, 16,  5,  1 },
    {     15,   16,    6, 16,  5,  1 }, {     16,   16,    6, 16,  5,  1 }, {     17,   16,    6, 16,  5,  1 }, {     18,   16,    5, 16,  5,  1 }, {     19,   16,    5, 16,  5,  1 },
    {     20,   16,    5, 16,  5,  1 }, {     21,   16,    4, 16,  5,  1 }, {     22,   16,    4, 16,  5,  1 }, {     23,   16,    4, 16,  5,  1 }, {     24,   16,    3, 16,  6,  2 },
    {     25,   16,    3, 16,  6,  2 }, {     26,   16,    2, 16,  6,  2 }, {     27,   16,    2, 16,  6,  2 }, {     28,   16,    1, 16,  6,  2 }, {     29,   16,    1, 16,  6,  2 },
    {     30,   16,    0, 16,  6,  2 }, {     31,   16,    0, 16,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9686C4, {
    {     16,   31,    8, 24,  0,  0 }, {     16,   30,    8, 24,  0,  0 }, {     16,   29,    8, 24,  0,  0 }, {     16,   28,    8, 24,  0,  0 }, {     16,   27,    8, 24,  0,  0 },
    {     16,   26,    8, 24,  0,  0 }, {     16,   25,    8, 24,  0,  0 }, {     16,   24,    8, 24,  0,  0 }, {     16,   23,    7, 24,  5,  1 }, {     16,   22,    7, 24,  5,  1 },
    {     16,   21,    7, 24,  5,  1 }, {     16,   20,    7, 24,  5,  1 }, {     16,   19,    7, 24,  5,  1 }, {     16,   18,    7, 24,  5,  1 }, {     16,   17,    6, 24,  5,  1 },
    {     16,   16,    6, 24,  5,  1 }, {     16,   15,    6, 24,  5,  1 }, {     16,   14,    6, 24,  5,  1 }, {     16,   13,    5, 24,  5,  1 }, {     16,   12,    5, 24,  5,  1 },
    {     16,   11,    5, 24,  5,  1 }, {     16,   10,    4, 24,  5,  1 }, {     16,    9,    4, 24,  5,  1 }, {     16,    8,    4, 24,  5,  1 }, {     16,    7,    3, 24,  6,  2 },
    {     16,    6,    3, 24,  6,  2 }, {     16,    5,    2, 24,  6,  2 }, {     16,    4,    2, 24,  6,  2 }, {     16,    3,    1, 24,  6,  2 }, {     16,    2,    1, 24,  6,  2 },
    {     16,    1,    0, 24,  6,  2 }, {     16,    0,    0, 24,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9687E6, {
    {     31,   16,    8,  0,  0,  0 }, {     30,   16,    8,  0,  0,  0 }, {     29,   16,    8,  0,  0,  0 }, {     28,   16,    8,  0,  0,  0 }, {     27,   16,    8,  0,  0,  0 },
    {     26,   16,    8,  0,  0,  0 }, {     25,   16,    8,  0,  0,  0 }, {     24,   16,    8,  0,  0,  0 }, {     23,   16,    7,  0,  5,  3 }, {     22,   16,    7,  0,  5,  3 },
    {     21,   16,    7,  0,  5,  3 }, {     20,   16,    7,  0,  5,  3 }, {     19,   16,    7,  0,  5,  3 }, {     18,   16,    7,  0,  5,  3 }, {     17,   16,    6,  0,  5,  3 },
    {     16,   16,    6,  0,  5,  3 }, {     15,   16,    6,  0,  5,  3 }, {     14,   16,    6,  0,  5,  3 }, {     13,   16,    5,  0,  5,  3 }, {     12,   16,    5,  0,  5,  3 },
    {     11,   16,    5,  0,  5,  3 }, {     10,   16,    4,  0,  5,  3 }, {      9,   16,    4,  0,  5,  3 }, {      8,   16,    4,  0,  5,  3 }, {      7,   16,    3,  0,  6,  4 },
    {      6,   16,    3,  0,  6,  4 }, {      5,   16,    2,  0,  6,  4 }, {      4,   16,    2,  0,  6,  4 }, {      3,   16,    1,  0,  6,  4 }, {      2,   16,    1,  0,  6,  4 },
    {      1,   16,    0,  0,  6,  4 }, {      0,   16,    0,  0,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_968908, {
    {     16,    0,    8,  8,  0,  0 }, {     16,    1,    8,  8,  0,  0 }, {     16,    2,    8,  8,  0,  0 }, {     16,    3,    8,  8,  0,  0 }, {     16,    4,    8,  8,  0,  0 },
    {     16,    5,    8,  8,  0,  0 }, {     16,    6,    8,  8,  0,  0 }, {     16,    7,    8,  8,  0,  0 }, {     16,    8,    7,  8,  5,  3 }, {     16,    9,    7,  8,  5,  3 },
    {     16,   10,    7,  8,  5,  3 }, {     16,   11,    7,  8,  5,  3 }, {     16,   12,    7,  8,  5,  3 }, {     16,   13,    7,  8,  5,  3 }, {     16,   14,    6,  8,  5,  3 },
    {     16,   15,    6,  8,  5,  3 }, {     16,   16,    6,  8,  5,  3 }, {     16,   17,    6,  8,  5,  3 }, {     16,   18,    5,  8,  5,  3 }, {     16,   19,    5,  8,  5,  3 },
    {     16,   20,    5,  8,  5,  3 }, {     16,   21,    4,  8,  5,  3 }, {     16,   22,    4,  8,  5,  3 }, {     16,   23,    4,  8,  5,  3 }, {     16,   24,    3,  8,  6,  4 },
    {     16,   25,    3,  8,  6,  4 }, {     16,   26,    2,  8,  6,  4 }, {     16,   27,    2,  8,  6,  4 }, {     16,   28,    1,  8,  6,  4 }, {     16,   29,    1,  8,  6,  4 },
    {     16,   30,    0,  8,  6,  4 }, {     16,   31,    0,  8,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_968A2A, {
    {      0,   16,    8, 16,  0,  0 }, {      1,   16,    8, 16,  0,  0 }, {      2,   16,    8, 16,  0,  0 }, {      3,   16,    8, 16,  0,  0 }, {      4,   16,    8, 16,  0,  0 },
    {      5,   16,    8, 16,  0,  0 }, {      6,   16,    8, 16,  0,  0 }, {      7,   16,    8, 16,  0,  0 }, {      8,   16,    7, 16,  5,  3 }, {      9,   16,    7, 16,  5,  3 },
    {     10,   16,    7, 16,  5,  3 }, {     11,   16,    7, 16,  5,  3 }, {     12,   16,    7, 16,  5,  3 }, {     13,   16,    7, 16,  5,  3 }, {     14,   16,    6, 16,  5,  3 },
    {     15,   16,    6, 16,  5,  3 }, {     16,   16,    6, 16,  5,  3 }, {     17,   16,    6, 16,  5,  3 }, {     18,   16,    5, 16,  5,  3 }, {     19,   16,    5, 16,  5,  3 },
    {     20,   16,    5, 16,  5,  3 }, {     21,   16,    4, 16,  5,  3 }, {     22,   16,    4, 16,  5,  3 }, {     23,   16,    4, 16,  5,  3 }, {     24,   16,    3, 16,  6,  4 },
    {     25,   16,    3, 16,  6,  4 }, {     26,   16,    2, 16,  6,  4 }, {     27,   16,    2, 16,  6,  4 }, {     28,   16,    1, 16,  6,  4 }, {     29,   16,    1, 16,  6,  4 },
    {     30,   16,    0, 16,  6,  4 }, {     31,   16,    0, 16,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_968B4C, {
    {     16,   31,    8, 24,  0,  0 }, {     16,   30,    8, 24,  0,  0 }, {     16,   29,    8, 24,  0,  0 }, {     16,   28,    8, 24,  0,  0 }, {     16,   27,    8, 24,  0,  0 },
    {     16,   26,    8, 24,  0,  0 }, {     16,   25,    8, 24,  0,  0 }, {     16,   24,    8, 24,  0,  0 }, {     16,   23,    7, 24,  5,  3 }, {     16,   22,    7, 24,  5,  3 },
    {     16,   21,    7, 24,  5,  3 }, {     16,   20,    7, 24,  5,  3 }, {     16,   19,    7, 24,  5,  3 }, {     16,   18,    7, 24,  5,  3 }, {     16,   17,    6, 24,  5,  3 },
    {     16,   16,    6, 24,  5,  3 }, {     16,   15,    6, 24,  5,  3 }, {     16,   14,    6, 24,  5,  3 }, {     16,   13,    5, 24,  5,  3 }, {     16,   12,    5, 24,  5,  3 },
    {     16,   11,    5, 24,  5,  3 }, {     16,   10,    4, 24,  5,  3 }, {     16,    9,    4, 24,  5,  3 }, {     16,    8,    4, 24,  5,  3 }, {     16,    7,    3, 24,  6,  4 },
    {     16,    6,    3, 24,  6,  4 }, {     16,    5,    2, 24,  6,  4 }, {     16,    4,    2, 24,  6,  4 }, {     16,    3,    1, 24,  6,  4 }, {     16,    2,    1, 24,  6,  4 },
    {     16,    1,    0, 24,  6,  4 }, {     16,    0,    0, 24,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_967A4E, {
    {     31,   16,    7,  0,  6,  2 }, {     30,   16,    7,  0,  6,  2 }, {     29,   16,    6,  0,  6,  2 }, {     28,   16,    6,  0,  6,  2 }, {     27,   16,    5,  0,  6,  2 },
    {     26,   16,    5,  0,  6,  2 }, {     25,   16,    4,  0,  6,  2 }, {     24,   16,    4,  0,  6,  2 }, {     23,   16,    4,  0,  5,  1 }, {     22,   16,    3,  0,  5,  1 },
    {     21,   16,    3,  0,  5,  1 }, {     20,   16,    3,  0,  5,  1 }, {     19,   16,    2,  0,  5,  1 }, {     18,   16,    2,  0,  5,  1 }, {     17,   16,    2,  0,  5,  1 },
    {     16,   16,    2,  0,  5,  1 }, {     15,   16,    1,  0,  5,  1 }, {     14,   16,    1,  0,  5,  1 }, {     13,   16,    1,  0,  5,  1 }, {     12,   16,    1,  0,  5,  1 },
    {     11,   16,    1,  0,  5,  1 }, {     10,   16,    1,  0,  5,  1 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 },
    {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_967B70, {
    {     16,    0,    7,  8,  6,  2 }, {     16,    1,    7,  8,  6,  2 }, {     16,    2,    6,  8,  6,  2 }, {     16,    3,    6,  8,  6,  2 }, {     16,    4,    5,  8,  6,  2 },
    {     16,    5,    5,  8,  6,  2 }, {     16,    6,    4,  8,  6,  2 }, {     16,    7,    4,  8,  6,  2 }, {     16,    8,    4,  8,  5,  1 }, {     16,    9,    3,  8,  5,  1 },
    {     16,   10,    3,  8,  5,  1 }, {     16,   11,    3,  8,  5,  1 }, {     16,   12,    2,  8,  5,  1 }, {     16,   13,    2,  8,  5,  1 }, {     16,   14,    2,  8,  5,  1 },
    {     16,   15,    2,  8,  5,  1 }, {     16,   16,    1,  8,  5,  1 }, {     16,   17,    1,  8,  5,  1 }, {     16,   18,    1,  8,  5,  1 }, {     16,   19,    1,  8,  5,  1 },
    {     16,   20,    1,  8,  5,  1 }, {     16,   21,    1,  8,  5,  1 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   29,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_967C92, {
    {      0,   16,    7, 16,  6,  2 }, {      1,   16,    7, 16,  6,  2 }, {      2,   16,    6, 16,  6,  2 }, {      3,   16,    6, 16,  6,  2 }, {      4,   16,    5, 16,  6,  2 },
    {      5,   16,    5, 16,  6,  2 }, {      6,   16,    4, 16,  6,  2 }, {      7,   16,    4, 16,  6,  2 }, {      8,   16,    4, 16,  5,  1 }, {      9,   16,    3, 16,  5,  1 },
    {     10,   16,    3, 16,  5,  1 }, {     11,   16,    3, 16,  5,  1 }, {     12,   16,    2, 16,  5,  1 }, {     13,   16,    2, 16,  5,  1 }, {     14,   16,    2, 16,  5,  1 },
    {     15,   16,    2, 16,  5,  1 }, {     16,   16,    1, 16,  5,  1 }, {     17,   16,    1, 16,  5,  1 }, {     18,   16,    1, 16,  5,  1 }, {     19,   16,    1, 16,  5,  1 },
    {     20,   16,    1, 16,  5,  1 }, {     21,   16,    1, 16,  5,  1 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 },
    {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 }, {     29,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_967DB4, {
    {     16,   31,    7, 24,  6,  2 }, {     16,   30,    7, 24,  6,  2 }, {     16,   29,    6, 24,  6,  2 }, {     16,   28,    6, 24,  6,  2 }, {     16,   27,    5, 24,  6,  2 },
    {     16,   26,    5, 24,  6,  2 }, {     16,   25,    4, 24,  6,  2 }, {     16,   24,    4, 24,  6,  2 }, {     16,   23,    4, 24,  5,  1 }, {     16,   22,    3, 24,  5,  1 },
    {     16,   21,    3, 24,  5,  1 }, {     16,   20,    3, 24,  5,  1 }, {     16,   19,    2, 24,  5,  1 }, {     16,   18,    2, 24,  5,  1 }, {     16,   17,    2, 24,  5,  1 },
    {     16,   16,    2, 24,  5,  1 }, {     16,   15,    1, 24,  5,  1 }, {     16,   14,    1, 24,  5,  1 }, {     16,   13,    1, 24,  5,  1 }, {     16,   12,    1, 24,  5,  1 },
    {     16,   11,    1, 24,  5,  1 }, {     16,   10,    1, 24,  5,  1 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 }, {     16,    7,    0, 24,  0,  0 },
    {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_967ED6, {
    {     31,   16,    7,  0,  6,  4 }, {     30,   16,    7,  0,  6,  4 }, {     29,   16,    6,  0,  6,  4 }, {     28,   16,    6,  0,  6,  4 }, {     27,   16,    5,  0,  6,  4 },
    {     26,   16,    5,  0,  6,  4 }, {     25,   16,    4,  0,  6,  4 }, {     24,   16,    4,  0,  6,  4 }, {     23,   16,    4,  0,  5,  3 }, {     22,   16,    3,  0,  5,  3 },
    {     21,   16,    3,  0,  5,  3 }, {     20,   16,    3,  0,  5,  3 }, {     19,   16,    2,  0,  5,  3 }, {     18,   16,    2,  0,  5,  3 }, {     17,   16,    2,  0,  5,  3 },
    {     16,   16,    2,  0,  5,  3 }, {     15,   16,    1,  0,  5,  3 }, {     14,   16,    1,  0,  5,  3 }, {     13,   16,    1,  0,  5,  3 }, {     12,   16,    1,  0,  5,  3 },
    {     11,   16,    1,  0,  5,  3 }, {     10,   16,    1,  0,  5,  3 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 },
    {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_967FF8, {
    {     16,    0,    7,  8,  6,  4 }, {     16,    1,    7,  8,  6,  4 }, {     16,    2,    6,  8,  6,  4 }, {     16,    3,    6,  8,  6,  4 }, {     16,    4,    5,  8,  6,  4 },
    {     16,    5,    5,  8,  6,  4 }, {     16,    6,    4,  8,  6,  4 }, {     16,    7,    4,  8,  6,  4 }, {     16,    8,    4,  8,  5,  3 }, {     16,    9,    3,  8,  5,  3 },
    {     16,   10,    3,  8,  5,  3 }, {     16,   11,    3,  8,  5,  3 }, {     16,   12,    2,  8,  5,  3 }, {     16,   13,    2,  8,  5,  3 }, {     16,   14,    2,  8,  5,  3 },
    {     16,   15,    2,  8,  5,  3 }, {     16,   16,    1,  8,  5,  3 }, {     16,   17,    1,  8,  5,  3 }, {     16,   18,    1,  8,  5,  3 }, {     16,   19,    1,  8,  5,  3 },
    {     16,   20,    1,  8,  5,  3 }, {     16,   21,    1,  8,  5,  3 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   29,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96811A, {
    {      0,   16,    7, 16,  6,  4 }, {      1,   16,    7, 16,  6,  4 }, {      2,   16,    6, 16,  6,  4 }, {      3,   16,    6, 16,  6,  4 }, {      4,   16,    5, 16,  6,  4 },
    {      5,   16,    5, 16,  6,  4 }, {      6,   16,    4, 16,  6,  4 }, {      7,   16,    4, 16,  6,  4 }, {      8,   16,    4, 16,  5,  3 }, {      9,   16,    3, 16,  5,  3 },
    {     10,   16,    3, 16,  5,  3 }, {     11,   16,    3, 16,  5,  3 }, {     12,   16,    2, 16,  5,  3 }, {     13,   16,    2, 16,  5,  3 }, {     14,   16,    2, 16,  5,  3 },
    {     15,   16,    2, 16,  5,  3 }, {     16,   16,    1, 16,  5,  3 }, {     17,   16,    1, 16,  5,  3 }, {     18,   16,    1, 16,  5,  3 }, {     19,   16,    1, 16,  5,  3 },
    {     20,   16,    1, 16,  5,  3 }, {     21,   16,    1, 16,  5,  3 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 },
    {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 }, {     29,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96823C, {
    {     16,   31,    7, 24,  6,  4 }, {     16,   30,    7, 24,  6,  4 }, {     16,   29,    6, 24,  6,  4 }, {     16,   28,    6, 24,  6,  4 }, {     16,   27,    5, 24,  6,  4 },
    {     16,   26,    5, 24,  6,  4 }, {     16,   25,    4, 24,  6,  4 }, {     16,   24,    4, 24,  6,  4 }, {     16,   23,    4, 24,  5,  3 }, {     16,   22,    3, 24,  5,  3 },
    {     16,   21,    3, 24,  5,  3 }, {     16,   20,    3, 24,  5,  3 }, {     16,   19,    2, 24,  5,  3 }, {     16,   18,    2, 24,  5,  3 }, {     16,   17,    2, 24,  5,  3 },
    {     16,   16,    2, 24,  5,  3 }, {     16,   15,    1, 24,  5,  3 }, {     16,   14,    1, 24,  5,  3 }, {     16,   13,    1, 24,  5,  3 }, {     16,   12,    1, 24,  5,  3 },
    {     16,   11,    1, 24,  5,  3 }, {     16,   10,    1, 24,  5,  3 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 }, {     16,    7,    0, 24,  0,  0 },
    {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_969E8E, {
    {     16,   16,    0,  0, 10,  0 }, {     16,   16,    1,  0, 10,  0 }, {     16,   16,    2,  0, 10,  0 }, {     16,   16,    3,  0, 10,  0 }, {     16,   16,    4,  0, 10,  0 },
    {     16,   16,    5,  0, 10,  0 }, {     16,   16,    6, 31, 10,  0 }, {     16,   16,    7, 31, 10,  0 }, {     16,   16,    8, 31, 10,  0 }, {     16,   16,    9, 31, 10,  0 },
    {     16,   16,   10, 31, 10,  0 }, {     16,   16,   11, 31, 10,  0 }, {     16,   16,   12, 31, 10,  0 }, {     16,   16,   13, 31, 10,  0 }, {     16,   16,   14, 31, 10,  0 },
    {     16,   16,   15, 31, 10,  0 }, {     16,   16,   16, 31, 10,  0 }, {     16,   16,   17, 31, 10,  0 }, {     16,   16,   18, 30, 10,  0 }, {     16,   16,   19, 30, 10,  0 },
    {     16,   16,   20, 30, 10,  0 }, {     16,   16,   21, 30, 10,  0 }, {     16,   16,   22, 30, 10,  0 }, {     16,   16,   23, 30, 10,  0 }, {     16,   16,   24, 30, 10,  0 },
    {     16,   16,   25, 30, 10,  0 }, {     16,   16,   26, 30, 10,  0 }, {     16,   16,   27, 30, 10,  0 }, {     16,   16,   28, 30, 10,  0 }, {     16,   16,   29, 30, 10,  0 },
    {     16,   16,   30, 29, 10,  0 }, {     16,   16,   31, 29, 10,  0 }, {     16,   16,   32, 29, 10,  0 }, {     16,   16,   33, 29, 10,  0 }, {     16,   16,   34, 29, 10,  0 },
    {     16,   16,   35, 29, 10,  0 }, {     16,   16,   36, 29, 10,  0 }, {     16,   16,   37, 29, 10,  0 }, {     16,   16,   38, 29, 10,  0 }, {     16,   16,   39, 29, 10,  0 },
    {     16,   16,   40, 29, 10,  0 }, {     16,   16,   41, 29, 10,  0 }, {     16,   16,   42, 28, 10,  0 }, {     16,   16,   43, 28, 10,  0 }, {     16,   16,   44, 28, 10,  0 },
    {     16,   16,   45, 28, 10,  0 }, {     16,   16,   46, 28, 10,  0 }, {     16,   16,   47, 28, 10,  0 }, {     16,   16,   48, 28, 10,  0 }, {     16,   16,   49, 28, 10,  0 },
    {     16,   16,   50, 28, 10,  0 }, {     16,   16,   51, 28, 10,  0 }, {     16,   16,   52, 28, 10,  0 }, {     16,   16,   53, 28, 10,  0 }, {     16,   16,   54, 27, 10,  0 },
    {     16,   16,   55, 27, 10,  0 }, {     16,   16,   56, 27, 10,  0 }, {     16,   16,   57, 27, 10,  0 }, {     16,   16,   58, 27, 10,  0 }, {     16,   16,   59, 27, 10,  0 },
    {     16,   16,   60, 27, 10,  0 }, {     16,   16,   61, 27, 10,  0 }, {     16,   16,   62, 27, 10,  0 }, {     16,   16,   63, 27, 10,  0 }, {     16,   16,   64, 27, 10,  0 },
    {     16,   16,   65, 27, 10,  0 }, {     16,   16,   66, 26, 10,  0 }, {     16,   16,   67, 26, 10,  0 }, {     16,   16,   68, 26, 10,  0 }, {     16,   16,   69, 26, 10,  0 },
    {     16,   16,   70, 26, 10,  0 }, {     16,   16,   71, 26, 10,  0 }, {     16,   16,   72, 26, 10,  0 }, {     16,   16,   73, 26, 10,  0 }, {     16,   16,   74, 26, 10,  0 },
    {     16,   16,   75, 26, 10,  0 }, {     16,   16,   76, 26, 10,  0 }, {     16,   16,   77, 26, 10,  0 }, {     16,   16,   78, 25, 10,  0 }, {     16,   16,   79, 25, 10,  0 },
    {     16,   16,   80, 25, 10,  0 }, {     16,   16,   81, 25, 10,  0 }, {     16,   16,   82, 25, 10,  0 }, {     16,   16,   83, 25, 10,  0 }, {     16,   16,   84, 25, 10,  0 },
    {     16,   16,   85, 25, 10,  0 }, {     16,   16,   86, 25, 10,  0 }, {     16,   16,   87, 25, 10,  0 }, {     16,   16,   88, 25, 10,  0 }, {     16,   16,   89, 25, 10,  0 },
    {     16,   16,   90, 24, 10,  0 }, {     16,   16,   91, 24, 10,  0 }, {     16,   16,   92, 24, 10,  0 }, {     16,   16,   93, 24, 10,  0 }, {     16,   16,   94, 24, 10,  0 },
    {     16,   16,   95, 24, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96A1F0, {
    {     16,   16,    0,  8, 10,  0 }, {     16,   16,    1,  8, 10,  0 }, {     16,   16,    2,  8, 10,  0 }, {     16,   16,    3,  8, 10,  0 }, {     16,   16,    4,  8, 10,  0 },
    {     16,   16,    5,  8, 10,  0 }, {     16,   16,    6,  7, 10,  0 }, {     16,   16,    7,  7, 10,  0 }, {     16,   16,    8,  7, 10,  0 }, {     16,   16,    9,  7, 10,  0 },
    {     16,   16,   10,  7, 10,  0 }, {     16,   16,   11,  7, 10,  0 }, {     16,   16,   12,  7, 10,  0 }, {     16,   16,   13,  7, 10,  0 }, {     16,   16,   14,  7, 10,  0 },
    {     16,   16,   15,  7, 10,  0 }, {     16,   16,   16,  7, 10,  0 }, {     16,   16,   17,  7, 10,  0 }, {     16,   16,   18,  6, 10,  0 }, {     16,   16,   19,  6, 10,  0 },
    {     16,   16,   20,  6, 10,  0 }, {     16,   16,   21,  6, 10,  0 }, {     16,   16,   22,  6, 10,  0 }, {     16,   16,   23,  6, 10,  0 }, {     16,   16,   24,  6, 10,  0 },
    {     16,   16,   25,  6, 10,  0 }, {     16,   16,   26,  6, 10,  0 }, {     16,   16,   27,  6, 10,  0 }, {     16,   16,   28,  6, 10,  0 }, {     16,   16,   29,  6, 10,  0 },
    {     16,   16,   30,  5, 10,  0 }, {     16,   16,   31,  5, 10,  0 }, {     16,   16,   32,  5, 10,  0 }, {     16,   16,   33,  5, 10,  0 }, {     16,   16,   34,  5, 10,  0 },
    {     16,   16,   35,  5, 10,  0 }, {     16,   16,   36,  5, 10,  0 }, {     16,   16,   37,  5, 10,  0 }, {     16,   16,   38,  5, 10,  0 }, {     16,   16,   39,  5, 10,  0 },
    {     16,   16,   40,  5, 10,  0 }, {     16,   16,   41,  5, 10,  0 }, {     16,   16,   42,  4, 10,  0 }, {     16,   16,   43,  4, 10,  0 }, {     16,   16,   44,  4, 10,  0 },
    {     16,   16,   45,  4, 10,  0 }, {     16,   16,   46,  4, 10,  0 }, {     16,   16,   47,  4, 10,  0 }, {     16,   16,   48,  4, 10,  0 }, {     16,   16,   49,  4, 10,  0 },
    {     16,   16,   50,  4, 10,  0 }, {     16,   16,   51,  4, 10,  0 }, {     16,   16,   52,  4, 10,  0 }, {     16,   16,   53,  4, 10,  0 }, {     16,   16,   54,  3, 10,  0 },
    {     16,   16,   55,  3, 10,  0 }, {     16,   16,   56,  3, 10,  0 }, {     16,   16,   57,  3, 10,  0 }, {     16,   16,   58,  3, 10,  0 }, {     16,   16,   59,  3, 10,  0 },
    {     16,   16,   60,  3, 10,  0 }, {     16,   16,   61,  3, 10,  0 }, {     16,   16,   62,  3, 10,  0 }, {     16,   16,   63,  3, 10,  0 }, {     16,   16,   64,  3, 10,  0 },
    {     16,   16,   65,  3, 10,  0 }, {     16,   16,   66,  2, 10,  0 }, {     16,   16,   67,  2, 10,  0 }, {     16,   16,   68,  2, 10,  0 }, {     16,   16,   69,  2, 10,  0 },
    {     16,   16,   70,  2, 10,  0 }, {     16,   16,   71,  2, 10,  0 }, {     16,   16,   72,  2, 10,  0 }, {     16,   16,   73,  2, 10,  0 }, {     16,   16,   74,  2, 10,  0 },
    {     16,   16,   75,  2, 10,  0 }, {     16,   16,   76,  2, 10,  0 }, {     16,   16,   77,  2, 10,  0 }, {     16,   16,   78,  1, 10,  0 }, {     16,   16,   79,  1, 10,  0 },
    {     16,   16,   80,  1, 10,  0 }, {     16,   16,   81,  1, 10,  0 }, {     16,   16,   82,  1, 10,  0 }, {     16,   16,   83,  1, 10,  0 }, {     16,   16,   84,  1, 10,  0 },
    {     16,   16,   85,  1, 10,  0 }, {     16,   16,   86,  1, 10,  0 }, {     16,   16,   87,  1, 10,  0 }, {     16,   16,   88,  1, 10,  0 }, {     16,   16,   89,  1, 10,  0 },
    {     16,   16,   90,  0, 10,  0 }, {     16,   16,   91,  0, 10,  0 }, {     16,   16,   92,  0, 10,  0 }, {     16,   16,   93,  0, 10,  0 }, {     16,   16,   94,  0, 10,  0 },
    {     16,   16,   95,  0, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96A552, {
    {     16,   16,    0, 16, 10,  0 }, {     16,   16,    1, 16, 10,  0 }, {     16,   16,    2, 16, 10,  0 }, {     16,   16,    3, 16, 10,  0 }, {     16,   16,    4, 16, 10,  0 },
    {     16,   16,    5, 16, 10,  0 }, {     16,   16,    6, 15, 10,  0 }, {     16,   16,    7, 15, 10,  0 }, {     16,   16,    8, 15, 10,  0 }, {     16,   16,    9, 15, 10,  0 },
    {     16,   16,   10, 15, 10,  0 }, {     16,   16,   11, 15, 10,  0 }, {     16,   16,   12, 15, 10,  0 }, {     16,   16,   13, 15, 10,  0 }, {     16,   16,   14, 15, 10,  0 },
    {     16,   16,   15, 15, 10,  0 }, {     16,   16,   16, 15, 10,  0 }, {     16,   16,   17, 15, 10,  0 }, {     16,   16,   18, 14, 10,  0 }, {     16,   16,   19, 14, 10,  0 },
    {     16,   16,   20, 14, 10,  0 }, {     16,   16,   21, 14, 10,  0 }, {     16,   16,   22, 14, 10,  0 }, {     16,   16,   23, 14, 10,  0 }, {     16,   16,   24, 14, 10,  0 },
    {     16,   16,   25, 14, 10,  0 }, {     16,   16,   26, 14, 10,  0 }, {     16,   16,   27, 14, 10,  0 }, {     16,   16,   28, 14, 10,  0 }, {     16,   16,   29, 14, 10,  0 },
    {     16,   16,   30, 13, 10,  0 }, {     16,   16,   31, 13, 10,  0 }, {     16,   16,   32, 13, 10,  0 }, {     16,   16,   33, 13, 10,  0 }, {     16,   16,   34, 13, 10,  0 },
    {     16,   16,   35, 13, 10,  0 }, {     16,   16,   36, 13, 10,  0 }, {     16,   16,   37, 13, 10,  0 }, {     16,   16,   38, 13, 10,  0 }, {     16,   16,   39, 13, 10,  0 },
    {     16,   16,   40, 13, 10,  0 }, {     16,   16,   41, 13, 10,  0 }, {     16,   16,   42, 12, 10,  0 }, {     16,   16,   43, 12, 10,  0 }, {     16,   16,   44, 12, 10,  0 },
    {     16,   16,   45, 12, 10,  0 }, {     16,   16,   46, 12, 10,  0 }, {     16,   16,   47, 12, 10,  0 }, {     16,   16,   48, 12, 10,  0 }, {     16,   16,   49, 12, 10,  0 },
    {     16,   16,   50, 12, 10,  0 }, {     16,   16,   51, 12, 10,  0 }, {     16,   16,   52, 12, 10,  0 }, {     16,   16,   53, 12, 10,  0 }, {     16,   16,   54, 11, 10,  0 },
    {     16,   16,   55, 11, 10,  0 }, {     16,   16,   56, 11, 10,  0 }, {     16,   16,   57, 11, 10,  0 }, {     16,   16,   58, 11, 10,  0 }, {     16,   16,   59, 11, 10,  0 },
    {     16,   16,   60, 11, 10,  0 }, {     16,   16,   61, 11, 10,  0 }, {     16,   16,   62, 11, 10,  0 }, {     16,   16,   63, 11, 10,  0 }, {     16,   16,   64, 11, 10,  0 },
    {     16,   16,   65, 11, 10,  0 }, {     16,   16,   66, 10, 10,  0 }, {     16,   16,   67, 10, 10,  0 }, {     16,   16,   68, 10, 10,  0 }, {     16,   16,   69, 10, 10,  0 },
    {     16,   16,   70, 10, 10,  0 }, {     16,   16,   71, 10, 10,  0 }, {     16,   16,   72, 10, 10,  0 }, {     16,   16,   73, 10, 10,  0 }, {     16,   16,   74, 10, 10,  0 },
    {     16,   16,   75, 10, 10,  0 }, {     16,   16,   76, 10, 10,  0 }, {     16,   16,   77, 10, 10,  0 }, {     16,   16,   78,  9, 10,  0 }, {     16,   16,   79,  9, 10,  0 },
    {     16,   16,   80,  9, 10,  0 }, {     16,   16,   81,  9, 10,  0 }, {     16,   16,   82,  9, 10,  0 }, {     16,   16,   83,  9, 10,  0 }, {     16,   16,   84,  9, 10,  0 },
    {     16,   16,   85,  9, 10,  0 }, {     16,   16,   86,  9, 10,  0 }, {     16,   16,   87,  9, 10,  0 }, {     16,   16,   88,  9, 10,  0 }, {     16,   16,   89,  9, 10,  0 },
    {     16,   16,   90,  8, 10,  0 }, {     16,   16,   91,  8, 10,  0 }, {     16,   16,   92,  8, 10,  0 }, {     16,   16,   93,  8, 10,  0 }, {     16,   16,   94,  8, 10,  0 },
    {     16,   16,   95,  8, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96A8B4, {
    {     16,   16,    0, 24, 10,  0 }, {     16,   16,    1, 24, 10,  0 }, {     16,   16,    2, 24, 10,  0 }, {     16,   16,    3, 24, 10,  0 }, {     16,   16,    4, 24, 10,  0 },
    {     16,   16,    5, 24, 10,  0 }, {     16,   16,    6, 23, 10,  0 }, {     16,   16,    7, 23, 10,  0 }, {     16,   16,    8, 23, 10,  0 }, {     16,   16,    9, 23, 10,  0 },
    {     16,   16,   10, 23, 10,  0 }, {     16,   16,   11, 23, 10,  0 }, {     16,   16,   12, 23, 10,  0 }, {     16,   16,   13, 23, 10,  0 }, {     16,   16,   14, 23, 10,  0 },
    {     16,   16,   15, 23, 10,  0 }, {     16,   16,   16, 23, 10,  0 }, {     16,   16,   17, 23, 10,  0 }, {     16,   16,   18, 22, 10,  0 }, {     16,   16,   19, 22, 10,  0 },
    {     16,   16,   20, 22, 10,  0 }, {     16,   16,   21, 22, 10,  0 }, {     16,   16,   22, 22, 10,  0 }, {     16,   16,   23, 22, 10,  0 }, {     16,   16,   24, 22, 10,  0 },
    {     16,   16,   25, 22, 10,  0 }, {     16,   16,   26, 22, 10,  0 }, {     16,   16,   27, 22, 10,  0 }, {     16,   16,   28, 22, 10,  0 }, {     16,   16,   29, 22, 10,  0 },
    {     16,   16,   30, 21, 10,  0 }, {     16,   16,   31, 21, 10,  0 }, {     16,   16,   32, 21, 10,  0 }, {     16,   16,   33, 21, 10,  0 }, {     16,   16,   34, 21, 10,  0 },
    {     16,   16,   35, 21, 10,  0 }, {     16,   16,   36, 21, 10,  0 }, {     16,   16,   37, 21, 10,  0 }, {     16,   16,   38, 21, 10,  0 }, {     16,   16,   39, 21, 10,  0 },
    {     16,   16,   40, 21, 10,  0 }, {     16,   16,   41, 21, 10,  0 }, {     16,   16,   42, 20, 10,  0 }, {     16,   16,   43, 20, 10,  0 }, {     16,   16,   44, 20, 10,  0 },
    {     16,   16,   45, 20, 10,  0 }, {     16,   16,   46, 20, 10,  0 }, {     16,   16,   47, 20, 10,  0 }, {     16,   16,   48, 20, 10,  0 }, {     16,   16,   49, 20, 10,  0 },
    {     16,   16,   50, 20, 10,  0 }, {     16,   16,   51, 20, 10,  0 }, {     16,   16,   52, 20, 10,  0 }, {     16,   16,   53, 20, 10,  0 }, {     16,   16,   54, 19, 10,  0 },
    {     16,   16,   55, 19, 10,  0 }, {     16,   16,   56, 19, 10,  0 }, {     16,   16,   57, 19, 10,  0 }, {     16,   16,   58, 19, 10,  0 }, {     16,   16,   59, 19, 10,  0 },
    {     16,   16,   60, 19, 10,  0 }, {     16,   16,   61, 19, 10,  0 }, {     16,   16,   62, 19, 10,  0 }, {     16,   16,   63, 19, 10,  0 }, {     16,   16,   64, 19, 10,  0 },
    {     16,   16,   65, 19, 10,  0 }, {     16,   16,   66, 18, 10,  0 }, {     16,   16,   67, 18, 10,  0 }, {     16,   16,   68, 18, 10,  0 }, {     16,   16,   69, 18, 10,  0 },
    {     16,   16,   70, 18, 10,  0 }, {     16,   16,   71, 18, 10,  0 }, {     16,   16,   72, 18, 10,  0 }, {     16,   16,   73, 18, 10,  0 }, {     16,   16,   74, 18, 10,  0 },
    {     16,   16,   75, 18, 10,  0 }, {     16,   16,   76, 18, 10,  0 }, {     16,   16,   77, 18, 10,  0 }, {     16,   16,   78, 17, 10,  0 }, {     16,   16,   79, 17, 10,  0 },
    {     16,   16,   80, 17, 10,  0 }, {     16,   16,   81, 17, 10,  0 }, {     16,   16,   82, 17, 10,  0 }, {     16,   16,   83, 17, 10,  0 }, {     16,   16,   84, 17, 10,  0 },
    {     16,   16,   85, 17, 10,  0 }, {     16,   16,   86, 17, 10,  0 }, {     16,   16,   87, 17, 10,  0 }, {     16,   16,   88, 17, 10,  0 }, {     16,   16,   89, 17, 10,  0 },
    {     16,   16,   90, 16, 10,  0 }, {     16,   16,   91, 16, 10,  0 }, {     16,   16,   92, 16, 10,  0 }, {     16,   16,   93, 16, 10,  0 }, {     16,   16,   94, 16, 10,  0 },
    {     16,   16,   95, 16, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96B99E, {
    {     16,   16,    0,  0, 10,  0 }, {     16,   16,    1,  0, 10,  0 }, {     16,   16,    2,  0, 10,  0 }, {     16,   16,    3,  0, 10,  0 }, {     16,   16,    4,  0, 10,  0 },
    {     16,   16,    5,  0, 10,  0 }, {     16,   16,    6,  1, 10,  0 }, {     16,   16,    7,  1, 10,  0 }, {     16,   16,    8,  1, 10,  0 }, {     16,   16,    9,  1, 10,  0 },
    {     16,   16,   10,  1, 10,  0 }, {     16,   16,   11,  1, 10,  0 }, {     16,   16,   12,  1, 10,  0 }, {     16,   16,   13,  1, 10,  0 }, {     16,   16,   14,  1, 10,  0 },
    {     16,   16,   15,  1, 10,  0 }, {     16,   16,   16,  1, 10,  0 }, {     16,   16,   17,  1, 10,  0 }, {     16,   16,   18,  2, 10,  0 }, {     16,   16,   19,  2, 10,  0 },
    {     16,   16,   20,  2, 10,  0 }, {     16,   16,   21,  2, 10,  0 }, {     16,   16,   22,  2, 10,  0 }, {     16,   16,   23,  2, 10,  0 }, {     16,   16,   24,  2, 10,  0 },
    {     16,   16,   25,  2, 10,  0 }, {     16,   16,   26,  2, 10,  0 }, {     16,   16,   27,  2, 10,  0 }, {     16,   16,   28,  2, 10,  0 }, {     16,   16,   29,  2, 10,  0 },
    {     16,   16,   30,  3, 10,  0 }, {     16,   16,   31,  3, 10,  0 }, {     16,   16,   32,  3, 10,  0 }, {     16,   16,   33,  3, 10,  0 }, {     16,   16,   34,  3, 10,  0 },
    {     16,   16,   35,  3, 10,  0 }, {     16,   16,   36,  3, 10,  0 }, {     16,   16,   37,  3, 10,  0 }, {     16,   16,   38,  3, 10,  0 }, {     16,   16,   39,  3, 10,  0 },
    {     16,   16,   40,  3, 10,  0 }, {     16,   16,   41,  3, 10,  0 }, {     16,   16,   42,  4, 10,  0 }, {     16,   16,   43,  4, 10,  0 }, {     16,   16,   44,  4, 10,  0 },
    {     16,   16,   45,  4, 10,  0 }, {     16,   16,   46,  4, 10,  0 }, {     16,   16,   47,  4, 10,  0 }, {     16,   16,   48,  4, 10,  0 }, {     16,   16,   49,  4, 10,  0 },
    {     16,   16,   50,  4, 10,  0 }, {     16,   16,   51,  4, 10,  0 }, {     16,   16,   52,  4, 10,  0 }, {     16,   16,   53,  4, 10,  0 }, {     16,   16,   54,  5, 10,  0 },
    {     16,   16,   55,  5, 10,  0 }, {     16,   16,   56,  5, 10,  0 }, {     16,   16,   57,  5, 10,  0 }, {     16,   16,   58,  5, 10,  0 }, {     16,   16,   59,  5, 10,  0 },
    {     16,   16,   60,  5, 10,  0 }, {     16,   16,   61,  5, 10,  0 }, {     16,   16,   62,  5, 10,  0 }, {     16,   16,   63,  5, 10,  0 }, {     16,   16,   64,  5, 10,  0 },
    {     16,   16,   65,  5, 10,  0 }, {     16,   16,   66,  6, 10,  0 }, {     16,   16,   67,  6, 10,  0 }, {     16,   16,   68,  6, 10,  0 }, {     16,   16,   69,  6, 10,  0 },
    {     16,   16,   70,  6, 10,  0 }, {     16,   16,   71,  6, 10,  0 }, {     16,   16,   72,  6, 10,  0 }, {     16,   16,   73,  6, 10,  0 }, {     16,   16,   74,  6, 10,  0 },
    {     16,   16,   75,  6, 10,  0 }, {     16,   16,   76,  6, 10,  0 }, {     16,   16,   77,  6, 10,  0 }, {     16,   16,   78,  7, 10,  0 }, {     16,   16,   79,  7, 10,  0 },
    {     16,   16,   80,  7, 10,  0 }, {     16,   16,   81,  7, 10,  0 }, {     16,   16,   82,  7, 10,  0 }, {     16,   16,   83,  7, 10,  0 }, {     16,   16,   84,  7, 10,  0 },
    {     16,   16,   85,  7, 10,  0 }, {     16,   16,   86,  7, 10,  0 }, {     16,   16,   87,  7, 10,  0 }, {     16,   16,   88,  7, 10,  0 }, {     16,   16,   89,  7, 10,  0 },
    {     16,   16,   90,  8, 10,  0 }, {     16,   16,   91,  8, 10,  0 }, {     16,   16,   92,  8, 10,  0 }, {     16,   16,   93,  8, 10,  0 }, {     16,   16,   94,  8, 10,  0 },
    {     16,   16,   95,  8, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96BD00, {
    {     16,   16,    0,  8, 10,  0 }, {     16,   16,    1,  8, 10,  0 }, {     16,   16,    2,  8, 10,  0 }, {     16,   16,    3,  8, 10,  0 }, {     16,   16,    4,  8, 10,  0 },
    {     16,   16,    5,  8, 10,  0 }, {     16,   16,    6,  9, 10,  0 }, {     16,   16,    7,  9, 10,  0 }, {     16,   16,    8,  9, 10,  0 }, {     16,   16,    9,  9, 10,  0 },
    {     16,   16,   10,  9, 10,  0 }, {     16,   16,   11,  9, 10,  0 }, {     16,   16,   12,  9, 10,  0 }, {     16,   16,   13,  9, 10,  0 }, {     16,   16,   14,  9, 10,  0 },
    {     16,   16,   15,  9, 10,  0 }, {     16,   16,   16,  9, 10,  0 }, {     16,   16,   17,  9, 10,  0 }, {     16,   16,   18, 10, 10,  0 }, {     16,   16,   19, 10, 10,  0 },
    {     16,   16,   20, 10, 10,  0 }, {     16,   16,   21, 10, 10,  0 }, {     16,   16,   22, 10, 10,  0 }, {     16,   16,   23, 10, 10,  0 }, {     16,   16,   24, 10, 10,  0 },
    {     16,   16,   25, 10, 10,  0 }, {     16,   16,   26, 10, 10,  0 }, {     16,   16,   27, 10, 10,  0 }, {     16,   16,   28, 10, 10,  0 }, {     16,   16,   29, 10, 10,  0 },
    {     16,   16,   30, 11, 10,  0 }, {     16,   16,   31, 11, 10,  0 }, {     16,   16,   32, 11, 10,  0 }, {     16,   16,   33, 11, 10,  0 }, {     16,   16,   34, 11, 10,  0 },
    {     16,   16,   35, 11, 10,  0 }, {     16,   16,   36, 11, 10,  0 }, {     16,   16,   37, 11, 10,  0 }, {     16,   16,   38, 11, 10,  0 }, {     16,   16,   39, 11, 10,  0 },
    {     16,   16,   40, 11, 10,  0 }, {     16,   16,   41, 11, 10,  0 }, {     16,   16,   42, 12, 10,  0 }, {     16,   16,   43, 12, 10,  0 }, {     16,   16,   44, 12, 10,  0 },
    {     16,   16,   45, 12, 10,  0 }, {     16,   16,   46, 12, 10,  0 }, {     16,   16,   47, 12, 10,  0 }, {     16,   16,   48, 12, 10,  0 }, {     16,   16,   49, 12, 10,  0 },
    {     16,   16,   50, 12, 10,  0 }, {     16,   16,   51, 12, 10,  0 }, {     16,   16,   52, 12, 10,  0 }, {     16,   16,   53, 12, 10,  0 }, {     16,   16,   54, 13, 10,  0 },
    {     16,   16,   55, 13, 10,  0 }, {     16,   16,   56, 13, 10,  0 }, {     16,   16,   57, 13, 10,  0 }, {     16,   16,   58, 13, 10,  0 }, {     16,   16,   59, 13, 10,  0 },
    {     16,   16,   60, 13, 10,  0 }, {     16,   16,   61, 13, 10,  0 }, {     16,   16,   62, 13, 10,  0 }, {     16,   16,   63, 13, 10,  0 }, {     16,   16,   64, 13, 10,  0 },
    {     16,   16,   65, 13, 10,  0 }, {     16,   16,   66, 14, 10,  0 }, {     16,   16,   67, 14, 10,  0 }, {     16,   16,   68, 14, 10,  0 }, {     16,   16,   69, 14, 10,  0 },
    {     16,   16,   70, 14, 10,  0 }, {     16,   16,   71, 14, 10,  0 }, {     16,   16,   72, 14, 10,  0 }, {     16,   16,   73, 14, 10,  0 }, {     16,   16,   74, 14, 10,  0 },
    {     16,   16,   75, 14, 10,  0 }, {     16,   16,   76, 14, 10,  0 }, {     16,   16,   77, 14, 10,  0 }, {     16,   16,   78, 15, 10,  0 }, {     16,   16,   79, 15, 10,  0 },
    {     16,   16,   80, 15, 10,  0 }, {     16,   16,   81, 15, 10,  0 }, {     16,   16,   82, 15, 10,  0 }, {     16,   16,   83, 15, 10,  0 }, {     16,   16,   84, 15, 10,  0 },
    {     16,   16,   85, 15, 10,  0 }, {     16,   16,   86, 15, 10,  0 }, {     16,   16,   87, 15, 10,  0 }, {     16,   16,   88, 15, 10,  0 }, {     16,   16,   89, 15, 10,  0 },
    {     16,   16,   90, 16, 10,  0 }, {     16,   16,   91, 16, 10,  0 }, {     16,   16,   92, 16, 10,  0 }, {     16,   16,   93, 16, 10,  0 }, {     16,   16,   94, 16, 10,  0 },
    {     16,   16,   95, 16, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96C062, {
    {     16,   16,    0, 16, 10,  0 }, {     16,   16,    1, 16, 10,  0 }, {     16,   16,    2, 16, 10,  0 }, {     16,   16,    3, 16, 10,  0 }, {     16,   16,    4, 16, 10,  0 },
    {     16,   16,    5, 16, 10,  0 }, {     16,   16,    6, 17, 10,  0 }, {     16,   16,    7, 17, 10,  0 }, {     16,   16,    8, 17, 10,  0 }, {     16,   16,    9, 17, 10,  0 },
    {     16,   16,   10, 17, 10,  0 }, {     16,   16,   11, 17, 10,  0 }, {     16,   16,   12, 17, 10,  0 }, {     16,   16,   13, 17, 10,  0 }, {     16,   16,   14, 17, 10,  0 },
    {     16,   16,   15, 17, 10,  0 }, {     16,   16,   16, 17, 10,  0 }, {     16,   16,   17, 17, 10,  0 }, {     16,   16,   18, 18, 10,  0 }, {     16,   16,   19, 18, 10,  0 },
    {     16,   16,   20, 18, 10,  0 }, {     16,   16,   21, 18, 10,  0 }, {     16,   16,   22, 18, 10,  0 }, {     16,   16,   23, 18, 10,  0 }, {     16,   16,   24, 18, 10,  0 },
    {     16,   16,   25, 18, 10,  0 }, {     16,   16,   26, 18, 10,  0 }, {     16,   16,   27, 18, 10,  0 }, {     16,   16,   28, 18, 10,  0 }, {     16,   16,   29, 18, 10,  0 },
    {     16,   16,   30, 19, 10,  0 }, {     16,   16,   31, 19, 10,  0 }, {     16,   16,   32, 19, 10,  0 }, {     16,   16,   33, 19, 10,  0 }, {     16,   16,   34, 19, 10,  0 },
    {     16,   16,   35, 19, 10,  0 }, {     16,   16,   36, 19, 10,  0 }, {     16,   16,   37, 19, 10,  0 }, {     16,   16,   38, 19, 10,  0 }, {     16,   16,   39, 19, 10,  0 },
    {     16,   16,   40, 19, 10,  0 }, {     16,   16,   41, 19, 10,  0 }, {     16,   16,   42, 20, 10,  0 }, {     16,   16,   43, 20, 10,  0 }, {     16,   16,   44, 20, 10,  0 },
    {     16,   16,   45, 20, 10,  0 }, {     16,   16,   46, 20, 10,  0 }, {     16,   16,   47, 20, 10,  0 }, {     16,   16,   48, 20, 10,  0 }, {     16,   16,   49, 20, 10,  0 },
    {     16,   16,   50, 20, 10,  0 }, {     16,   16,   51, 20, 10,  0 }, {     16,   16,   52, 20, 10,  0 }, {     16,   16,   53, 20, 10,  0 }, {     16,   16,   54, 21, 10,  0 },
    {     16,   16,   55, 21, 10,  0 }, {     16,   16,   56, 21, 10,  0 }, {     16,   16,   57, 21, 10,  0 }, {     16,   16,   58, 21, 10,  0 }, {     16,   16,   59, 21, 10,  0 },
    {     16,   16,   60, 21, 10,  0 }, {     16,   16,   61, 21, 10,  0 }, {     16,   16,   62, 21, 10,  0 }, {     16,   16,   63, 21, 10,  0 }, {     16,   16,   64, 21, 10,  0 },
    {     16,   16,   65, 21, 10,  0 }, {     16,   16,   66, 22, 10,  0 }, {     16,   16,   67, 22, 10,  0 }, {     16,   16,   68, 22, 10,  0 }, {     16,   16,   69, 22, 10,  0 },
    {     16,   16,   70, 22, 10,  0 }, {     16,   16,   71, 22, 10,  0 }, {     16,   16,   72, 22, 10,  0 }, {     16,   16,   73, 22, 10,  0 }, {     16,   16,   74, 22, 10,  0 },
    {     16,   16,   75, 22, 10,  0 }, {     16,   16,   76, 22, 10,  0 }, {     16,   16,   77, 22, 10,  0 }, {     16,   16,   78, 23, 10,  0 }, {     16,   16,   79, 23, 10,  0 },
    {     16,   16,   80, 23, 10,  0 }, {     16,   16,   81, 23, 10,  0 }, {     16,   16,   82, 23, 10,  0 }, {     16,   16,   83, 23, 10,  0 }, {     16,   16,   84, 23, 10,  0 },
    {     16,   16,   85, 23, 10,  0 }, {     16,   16,   86, 23, 10,  0 }, {     16,   16,   87, 23, 10,  0 }, {     16,   16,   88, 23, 10,  0 }, {     16,   16,   89, 23, 10,  0 },
    {     16,   16,   90, 24, 10,  0 }, {     16,   16,   91, 24, 10,  0 }, {     16,   16,   92, 24, 10,  0 }, {     16,   16,   93, 24, 10,  0 }, {     16,   16,   94, 24, 10,  0 },
    {     16,   16,   95, 24, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96C3C4, {
    {     16,   16,    0, 24, 10,  0 }, {     16,   16,    1, 24, 10,  0 }, {     16,   16,    2, 24, 10,  0 }, {     16,   16,    3, 24, 10,  0 }, {     16,   16,    4, 24, 10,  0 },
    {     16,   16,    5, 24, 10,  0 }, {     16,   16,    6, 25, 10,  0 }, {     16,   16,    7, 25, 10,  0 }, {     16,   16,    8, 25, 10,  0 }, {     16,   16,    9, 25, 10,  0 },
    {     16,   16,   10, 25, 10,  0 }, {     16,   16,   11, 25, 10,  0 }, {     16,   16,   12, 25, 10,  0 }, {     16,   16,   13, 25, 10,  0 }, {     16,   16,   14, 25, 10,  0 },
    {     16,   16,   15, 25, 10,  0 }, {     16,   16,   16, 25, 10,  0 }, {     16,   16,   17, 25, 10,  0 }, {     16,   16,   18, 26, 10,  0 }, {     16,   16,   19, 26, 10,  0 },
    {     16,   16,   20, 26, 10,  0 }, {     16,   16,   21, 26, 10,  0 }, {     16,   16,   22, 26, 10,  0 }, {     16,   16,   23, 26, 10,  0 }, {     16,   16,   24, 26, 10,  0 },
    {     16,   16,   25, 26, 10,  0 }, {     16,   16,   26, 26, 10,  0 }, {     16,   16,   27, 26, 10,  0 }, {     16,   16,   28, 26, 10,  0 }, {     16,   16,   29, 26, 10,  0 },
    {     16,   16,   30, 27, 10,  0 }, {     16,   16,   31, 27, 10,  0 }, {     16,   16,   32, 27, 10,  0 }, {     16,   16,   33, 27, 10,  0 }, {     16,   16,   34, 27, 10,  0 },
    {     16,   16,   35, 27, 10,  0 }, {     16,   16,   36, 27, 10,  0 }, {     16,   16,   37, 27, 10,  0 }, {     16,   16,   38, 27, 10,  0 }, {     16,   16,   39, 27, 10,  0 },
    {     16,   16,   40, 27, 10,  0 }, {     16,   16,   41, 27, 10,  0 }, {     16,   16,   42, 28, 10,  0 }, {     16,   16,   43, 28, 10,  0 }, {     16,   16,   44, 28, 10,  0 },
    {     16,   16,   45, 28, 10,  0 }, {     16,   16,   46, 28, 10,  0 }, {     16,   16,   47, 28, 10,  0 }, {     16,   16,   48, 28, 10,  0 }, {     16,   16,   49, 28, 10,  0 },
    {     16,   16,   50, 28, 10,  0 }, {     16,   16,   51, 28, 10,  0 }, {     16,   16,   52, 28, 10,  0 }, {     16,   16,   53, 28, 10,  0 }, {     16,   16,   54, 29, 10,  0 },
    {     16,   16,   55, 29, 10,  0 }, {     16,   16,   56, 29, 10,  0 }, {     16,   16,   57, 29, 10,  0 }, {     16,   16,   58, 29, 10,  0 }, {     16,   16,   59, 29, 10,  0 },
    {     16,   16,   60, 29, 10,  0 }, {     16,   16,   61, 29, 10,  0 }, {     16,   16,   62, 29, 10,  0 }, {     16,   16,   63, 29, 10,  0 }, {     16,   16,   64, 29, 10,  0 },
    {     16,   16,   65, 29, 10,  0 }, {     16,   16,   66, 30, 10,  0 }, {     16,   16,   67, 30, 10,  0 }, {     16,   16,   68, 30, 10,  0 }, {     16,   16,   69, 30, 10,  0 },
    {     16,   16,   70, 30, 10,  0 }, {     16,   16,   71, 30, 10,  0 }, {     16,   16,   72, 30, 10,  0 }, {     16,   16,   73, 30, 10,  0 }, {     16,   16,   74, 30, 10,  0 },
    {     16,   16,   75, 30, 10,  0 }, {     16,   16,   76, 30, 10,  0 }, {     16,   16,   77, 30, 10,  0 }, {     16,   16,   78, 31, 10,  0 }, {     16,   16,   79, 31, 10,  0 },
    {     16,   16,   80, 31, 10,  0 }, {     16,   16,   81, 31, 10,  0 }, {     16,   16,   82, 31, 10,  0 }, {     16,   16,   83, 31, 10,  0 }, {     16,   16,   84, 31, 10,  0 },
    {     16,   16,   85, 31, 10,  0 }, {     16,   16,   86, 31, 10,  0 }, {     16,   16,   87, 31, 10,  0 }, {     16,   16,   88, 31, 10,  0 }, {     16,   16,   89, 31, 10,  0 },
    {     16,   16,   90,  0, 10,  0 }, {     16,   16,   91,  0, 10,  0 }, {     16,   16,   92,  0, 10,  0 }, {     16,   16,   93,  0, 10,  0 }, {     16,   16,   94,  0, 10,  0 },
    {     16,   16,   95,  0, 10,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96AC16, {
    {     16,   16,   95,  0, 18,  0 }, {     16,   16,   94,  0, 18,  0 }, {     16,   16,   93,  0, 18,  0 }, {     16,   16,   92,  0, 18,  0 }, {     16,   16,   91,  0, 18,  0 },
    {     16,   16,   90,  0, 18,  0 }, {     16,   16,   89, 31, 18,  0 }, {     16,   16,   88, 31, 18,  0 }, {     16,   16,   87, 31, 18,  0 }, {     16,   16,   86, 31, 18,  0 },
    {     16,   16,   85, 31, 18,  0 }, {     16,   16,   84, 31, 18,  0 }, {     16,   16,   83, 31, 18,  0 }, {     16,   16,   82, 31, 18,  0 }, {     16,   16,   81, 31, 18,  0 },
    {     16,   16,   80, 31, 18,  0 }, {     16,   16,   79, 31, 18,  0 }, {     16,   16,   78, 31, 18,  0 }, {     16,   16,   77, 30, 18,  0 }, {     16,   16,   76, 30, 18,  0 },
    {     16,   16,   75, 30, 18,  0 }, {     16,   16,   74, 30, 18,  0 }, {     16,   16,   73, 30, 18,  0 }, {     16,   16,   72, 30, 18,  0 }, {     16,   16,   71, 30, 18,  0 },
    {     16,   16,   70, 30, 18,  0 }, {     16,   16,   69, 30, 18,  0 }, {     16,   16,   68, 30, 18,  0 }, {     16,   16,   67, 30, 18,  0 }, {     16,   16,   66, 30, 18,  0 },
    {     16,   16,   65, 29, 18,  0 }, {     16,   16,   64, 29, 18,  0 }, {     16,   16,   63, 29, 18,  0 }, {     16,   16,   62, 29, 18,  0 }, {     16,   16,   61, 29, 18,  0 },
    {     16,   16,   60, 29, 18,  0 }, {     16,   16,   59, 29, 18,  0 }, {     16,   16,   58, 29, 18,  0 }, {     16,   16,   57, 29, 18,  0 }, {     16,   16,   56, 29, 18,  0 },
    {     16,   16,   55, 29, 18,  0 }, {     16,   16,   54, 29, 18,  0 }, {     16,   16,   53, 28, 18,  0 }, {     16,   16,   52, 28, 18,  0 }, {     16,   16,   51, 28, 18,  0 },
    {     16,   16,   50, 28, 18,  0 }, {     16,   16,   49, 28, 18,  0 }, {     16,   16,   48, 28, 18,  0 }, {     16,   16,   47, 28, 18,  0 }, {     16,   16,   46, 28, 18,  0 },
    {     16,   16,   45, 28, 18,  0 }, {     16,   16,   44, 28, 18,  0 }, {     16,   16,   43, 28, 18,  0 }, {     16,   16,   42, 28, 18,  0 }, {     16,   16,   41, 27, 18,  0 },
    {     16,   16,   40, 27, 18,  0 }, {     16,   16,   39, 27, 18,  0 }, {     16,   16,   38, 27, 18,  0 }, {     16,   16,   37, 27, 18,  0 }, {     16,   16,   36, 27, 18,  0 },
    {     16,   16,   35, 27, 18,  0 }, {     16,   16,   34, 27, 18,  0 }, {     16,   16,   33, 27, 18,  0 }, {     16,   16,   32, 27, 18,  0 }, {     16,   16,   31, 27, 18,  0 },
    {     16,   16,   30, 27, 18,  0 }, {     16,   16,   29, 26, 18,  0 }, {     16,   16,   28, 26, 18,  0 }, {     16,   16,   27, 26, 18,  0 }, {     16,   16,   26, 26, 18,  0 },
    {     16,   16,   25, 26, 18,  0 }, {     16,   16,   24, 26, 18,  0 }, {     16,   16,   23, 26, 18,  0 }, {     16,   16,   22, 26, 18,  0 }, {     16,   16,   21, 26, 18,  0 },
    {     16,   16,   20, 26, 18,  0 }, {     16,   16,   19, 26, 18,  0 }, {     16,   16,   18, 26, 18,  0 }, {     16,   16,   17, 25, 18,  0 }, {     16,   16,   16, 25, 18,  0 },
    {     16,   16,   15, 25, 18,  0 }, {     16,   16,   14, 25, 18,  0 }, {     16,   16,   13, 25, 18,  0 }, {     16,   16,   12, 25, 18,  0 }, {     16,   16,   11, 25, 18,  0 },
    {     16,   16,   10, 25, 18,  0 }, {     16,   16,    9, 25, 18,  0 }, {     16,   16,    8, 25, 18,  0 }, {     16,   16,    7, 25, 18,  0 }, {     16,   16,    6, 25, 18,  0 },
    {     16,   16,    5, 24, 18,  0 }, {     16,   16,    4, 24, 18,  0 }, {     16,   16,    3, 24, 18,  0 }, {     16,   16,    2, 24, 18,  0 }, {     16,   16,    1, 24, 18,  0 },
    {     16,   16,    0, 24, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96AF78, {
    {     16,   16,   95,  8, 18,  0 }, {     16,   16,   94,  8, 18,  0 }, {     16,   16,   93,  8, 18,  0 }, {     16,   16,   92,  8, 18,  0 }, {     16,   16,   91,  8, 18,  0 },
    {     16,   16,   90,  8, 18,  0 }, {     16,   16,   89,  7, 18,  0 }, {     16,   16,   88,  7, 18,  0 }, {     16,   16,   87,  7, 18,  0 }, {     16,   16,   86,  7, 18,  0 },
    {     16,   16,   85,  7, 18,  0 }, {     16,   16,   84,  7, 18,  0 }, {     16,   16,   83,  7, 18,  0 }, {     16,   16,   82,  7, 18,  0 }, {     16,   16,   81,  7, 18,  0 },
    {     16,   16,   80,  7, 18,  0 }, {     16,   16,   79,  7, 18,  0 }, {     16,   16,   78,  7, 18,  0 }, {     16,   16,   77,  6, 18,  0 }, {     16,   16,   76,  6, 18,  0 },
    {     16,   16,   75,  6, 18,  0 }, {     16,   16,   74,  6, 18,  0 }, {     16,   16,   73,  6, 18,  0 }, {     16,   16,   72,  6, 18,  0 }, {     16,   16,   71,  6, 18,  0 },
    {     16,   16,   70,  6, 18,  0 }, {     16,   16,   69,  6, 18,  0 }, {     16,   16,   68,  6, 18,  0 }, {     16,   16,   67,  6, 18,  0 }, {     16,   16,   66,  6, 18,  0 },
    {     16,   16,   65,  5, 18,  0 }, {     16,   16,   64,  5, 18,  0 }, {     16,   16,   63,  5, 18,  0 }, {     16,   16,   62,  5, 18,  0 }, {     16,   16,   61,  5, 18,  0 },
    {     16,   16,   60,  5, 18,  0 }, {     16,   16,   59,  5, 18,  0 }, {     16,   16,   58,  5, 18,  0 }, {     16,   16,   57,  5, 18,  0 }, {     16,   16,   56,  5, 18,  0 },
    {     16,   16,   55,  5, 18,  0 }, {     16,   16,   54,  5, 18,  0 }, {     16,   16,   53,  4, 18,  0 }, {     16,   16,   52,  4, 18,  0 }, {     16,   16,   51,  4, 18,  0 },
    {     16,   16,   50,  4, 18,  0 }, {     16,   16,   49,  4, 18,  0 }, {     16,   16,   48,  4, 18,  0 }, {     16,   16,   47,  4, 18,  0 }, {     16,   16,   46,  4, 18,  0 },
    {     16,   16,   45,  4, 18,  0 }, {     16,   16,   44,  4, 18,  0 }, {     16,   16,   43,  4, 18,  0 }, {     16,   16,   42,  4, 18,  0 }, {     16,   16,   41,  3, 18,  0 },
    {     16,   16,   40,  3, 18,  0 }, {     16,   16,   39,  3, 18,  0 }, {     16,   16,   38,  3, 18,  0 }, {     16,   16,   37,  3, 18,  0 }, {     16,   16,   36,  3, 18,  0 },
    {     16,   16,   35,  3, 18,  0 }, {     16,   16,   34,  3, 18,  0 }, {     16,   16,   33,  3, 18,  0 }, {     16,   16,   32,  3, 18,  0 }, {     16,   16,   31,  3, 18,  0 },
    {     16,   16,   30,  3, 18,  0 }, {     16,   16,   29,  2, 18,  0 }, {     16,   16,   28,  2, 18,  0 }, {     16,   16,   27,  2, 18,  0 }, {     16,   16,   26,  2, 18,  0 },
    {     16,   16,   25,  2, 18,  0 }, {     16,   16,   24,  2, 18,  0 }, {     16,   16,   23,  2, 18,  0 }, {     16,   16,   22,  2, 18,  0 }, {     16,   16,   21,  2, 18,  0 },
    {     16,   16,   20,  2, 18,  0 }, {     16,   16,   19,  2, 18,  0 }, {     16,   16,   18,  2, 18,  0 }, {     16,   16,   17,  1, 18,  0 }, {     16,   16,   16,  1, 18,  0 },
    {     16,   16,   15,  1, 18,  0 }, {     16,   16,   14,  1, 18,  0 }, {     16,   16,   13,  1, 18,  0 }, {     16,   16,   12,  1, 18,  0 }, {     16,   16,   11,  1, 18,  0 },
    {     16,   16,   10,  1, 18,  0 }, {     16,   16,    9,  1, 18,  0 }, {     16,   16,    8,  1, 18,  0 }, {     16,   16,    7,  1, 18,  0 }, {     16,   16,    6,  1, 18,  0 },
    {     16,   16,    5,  0, 18,  0 }, {     16,   16,    4,  0, 18,  0 }, {     16,   16,    3,  0, 18,  0 }, {     16,   16,    2,  0, 18,  0 }, {     16,   16,    1,  0, 18,  0 },
    {     16,   16,    0,  0, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96B2DA, {
    {     16,   16,   95, 16, 18,  0 }, {     16,   16,   94, 16, 18,  0 }, {     16,   16,   93, 16, 18,  0 }, {     16,   16,   92, 16, 18,  0 }, {     16,   16,   91, 16, 18,  0 },
    {     16,   16,   90, 16, 18,  0 }, {     16,   16,   89, 15, 18,  0 }, {     16,   16,   88, 15, 18,  0 }, {     16,   16,   87, 15, 18,  0 }, {     16,   16,   86, 15, 18,  0 },
    {     16,   16,   85, 15, 18,  0 }, {     16,   16,   84, 15, 18,  0 }, {     16,   16,   83, 15, 18,  0 }, {     16,   16,   82, 15, 18,  0 }, {     16,   16,   81, 15, 18,  0 },
    {     16,   16,   80, 15, 18,  0 }, {     16,   16,   79, 15, 18,  0 }, {     16,   16,   78, 15, 18,  0 }, {     16,   16,   77, 14, 18,  0 }, {     16,   16,   76, 14, 18,  0 },
    {     16,   16,   75, 14, 18,  0 }, {     16,   16,   74, 14, 18,  0 }, {     16,   16,   73, 14, 18,  0 }, {     16,   16,   72, 14, 18,  0 }, {     16,   16,   71, 14, 18,  0 },
    {     16,   16,   70, 14, 18,  0 }, {     16,   16,   69, 14, 18,  0 }, {     16,   16,   68, 14, 18,  0 }, {     16,   16,   67, 14, 18,  0 }, {     16,   16,   66, 14, 18,  0 },
    {     16,   16,   65, 13, 18,  0 }, {     16,   16,   64, 13, 18,  0 }, {     16,   16,   63, 13, 18,  0 }, {     16,   16,   62, 13, 18,  0 }, {     16,   16,   61, 13, 18,  0 },
    {     16,   16,   60, 13, 18,  0 }, {     16,   16,   59, 13, 18,  0 }, {     16,   16,   58, 13, 18,  0 }, {     16,   16,   57, 13, 18,  0 }, {     16,   16,   56, 13, 18,  0 },
    {     16,   16,   55, 13, 18,  0 }, {     16,   16,   54, 13, 18,  0 }, {     16,   16,   53, 12, 18,  0 }, {     16,   16,   52, 12, 18,  0 }, {     16,   16,   51, 12, 18,  0 },
    {     16,   16,   50, 12, 18,  0 }, {     16,   16,   49, 12, 18,  0 }, {     16,   16,   48, 12, 18,  0 }, {     16,   16,   47, 12, 18,  0 }, {     16,   16,   46, 12, 18,  0 },
    {     16,   16,   45, 12, 18,  0 }, {     16,   16,   44, 12, 18,  0 }, {     16,   16,   43, 12, 18,  0 }, {     16,   16,   42, 12, 18,  0 }, {     16,   16,   41, 11, 18,  0 },
    {     16,   16,   40, 11, 18,  0 }, {     16,   16,   39, 11, 18,  0 }, {     16,   16,   38, 11, 18,  0 }, {     16,   16,   37, 11, 18,  0 }, {     16,   16,   36, 11, 18,  0 },
    {     16,   16,   35, 11, 18,  0 }, {     16,   16,   34, 11, 18,  0 }, {     16,   16,   33, 11, 18,  0 }, {     16,   16,   32, 11, 18,  0 }, {     16,   16,   31, 11, 18,  0 },
    {     16,   16,   30, 11, 18,  0 }, {     16,   16,   29, 10, 18,  0 }, {     16,   16,   28, 10, 18,  0 }, {     16,   16,   27, 10, 18,  0 }, {     16,   16,   26, 10, 18,  0 },
    {     16,   16,   25, 10, 18,  0 }, {     16,   16,   24, 10, 18,  0 }, {     16,   16,   23, 10, 18,  0 }, {     16,   16,   22, 10, 18,  0 }, {     16,   16,   21, 10, 18,  0 },
    {     16,   16,   20, 10, 18,  0 }, {     16,   16,   19, 10, 18,  0 }, {     16,   16,   18, 10, 18,  0 }, {     16,   16,   17,  9, 18,  0 }, {     16,   16,   16,  9, 18,  0 },
    {     16,   16,   15,  9, 18,  0 }, {     16,   16,   14,  9, 18,  0 }, {     16,   16,   13,  9, 18,  0 }, {     16,   16,   12,  9, 18,  0 }, {     16,   16,   11,  9, 18,  0 },
    {     16,   16,   10,  9, 18,  0 }, {     16,   16,    9,  9, 18,  0 }, {     16,   16,    8,  9, 18,  0 }, {     16,   16,    7,  9, 18,  0 }, {     16,   16,    6,  9, 18,  0 },
    {     16,   16,    5,  8, 18,  0 }, {     16,   16,    4,  8, 18,  0 }, {     16,   16,    3,  8, 18,  0 }, {     16,   16,    2,  8, 18,  0 }, {     16,   16,    1,  8, 18,  0 },
    {     16,   16,    0,  8, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96B63C, {
    {     16,   16,   95, 24, 18,  0 }, {     16,   16,   94, 24, 18,  0 }, {     16,   16,   93, 24, 18,  0 }, {     16,   16,   92, 24, 18,  0 }, {     16,   16,   91, 24, 18,  0 },
    {     16,   16,   90, 24, 18,  0 }, {     16,   16,   89, 23, 18,  0 }, {     16,   16,   88, 23, 18,  0 }, {     16,   16,   87, 23, 18,  0 }, {     16,   16,   86, 23, 18,  0 },
    {     16,   16,   85, 23, 18,  0 }, {     16,   16,   84, 23, 18,  0 }, {     16,   16,   83, 23, 18,  0 }, {     16,   16,   82, 23, 18,  0 }, {     16,   16,   81, 23, 18,  0 },
    {     16,   16,   80, 23, 18,  0 }, {     16,   16,   79, 23, 18,  0 }, {     16,   16,   78, 23, 18,  0 }, {     16,   16,   77, 22, 18,  0 }, {     16,   16,   76, 22, 18,  0 },
    {     16,   16,   75, 22, 18,  0 }, {     16,   16,   74, 22, 18,  0 }, {     16,   16,   73, 22, 18,  0 }, {     16,   16,   72, 22, 18,  0 }, {     16,   16,   71, 22, 18,  0 },
    {     16,   16,   70, 22, 18,  0 }, {     16,   16,   69, 22, 18,  0 }, {     16,   16,   68, 22, 18,  0 }, {     16,   16,   67, 22, 18,  0 }, {     16,   16,   66, 22, 18,  0 },
    {     16,   16,   65, 21, 18,  0 }, {     16,   16,   64, 21, 18,  0 }, {     16,   16,   63, 21, 18,  0 }, {     16,   16,   62, 21, 18,  0 }, {     16,   16,   61, 21, 18,  0 },
    {     16,   16,   60, 21, 18,  0 }, {     16,   16,   59, 21, 18,  0 }, {     16,   16,   58, 21, 18,  0 }, {     16,   16,   57, 21, 18,  0 }, {     16,   16,   56, 21, 18,  0 },
    {     16,   16,   55, 21, 18,  0 }, {     16,   16,   54, 21, 18,  0 }, {     16,   16,   53, 20, 18,  0 }, {     16,   16,   52, 20, 18,  0 }, {     16,   16,   51, 20, 18,  0 },
    {     16,   16,   50, 20, 18,  0 }, {     16,   16,   49, 20, 18,  0 }, {     16,   16,   48, 20, 18,  0 }, {     16,   16,   47, 20, 18,  0 }, {     16,   16,   46, 20, 18,  0 },
    {     16,   16,   45, 20, 18,  0 }, {     16,   16,   44, 20, 18,  0 }, {     16,   16,   43, 20, 18,  0 }, {     16,   16,   42, 20, 18,  0 }, {     16,   16,   41, 19, 18,  0 },
    {     16,   16,   40, 19, 18,  0 }, {     16,   16,   39, 19, 18,  0 }, {     16,   16,   38, 19, 18,  0 }, {     16,   16,   37, 19, 18,  0 }, {     16,   16,   36, 19, 18,  0 },
    {     16,   16,   35, 19, 18,  0 }, {     16,   16,   34, 19, 18,  0 }, {     16,   16,   33, 19, 18,  0 }, {     16,   16,   32, 19, 18,  0 }, {     16,   16,   31, 19, 18,  0 },
    {     16,   16,   30, 19, 18,  0 }, {     16,   16,   29, 18, 18,  0 }, {     16,   16,   28, 18, 18,  0 }, {     16,   16,   27, 18, 18,  0 }, {     16,   16,   26, 18, 18,  0 },
    {     16,   16,   25, 18, 18,  0 }, {     16,   16,   24, 18, 18,  0 }, {     16,   16,   23, 18, 18,  0 }, {     16,   16,   22, 18, 18,  0 }, {     16,   16,   21, 18, 18,  0 },
    {     16,   16,   20, 18, 18,  0 }, {     16,   16,   19, 18, 18,  0 }, {     16,   16,   18, 18, 18,  0 }, {     16,   16,   17, 17, 18,  0 }, {     16,   16,   16, 17, 18,  0 },
    {     16,   16,   15, 17, 18,  0 }, {     16,   16,   14, 17, 18,  0 }, {     16,   16,   13, 17, 18,  0 }, {     16,   16,   12, 17, 18,  0 }, {     16,   16,   11, 17, 18,  0 },
    {     16,   16,   10, 17, 18,  0 }, {     16,   16,    9, 17, 18,  0 }, {     16,   16,    8, 17, 18,  0 }, {     16,   16,    7, 17, 18,  0 }, {     16,   16,    6, 17, 18,  0 },
    {     16,   16,    5, 16, 18,  0 }, {     16,   16,    4, 16, 18,  0 }, {     16,   16,    3, 16, 18,  0 }, {     16,   16,    2, 16, 18,  0 }, {     16,   16,    1, 16, 18,  0 },
    {     16,   16,    0, 16, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96C726, {
    {     16,   16,   95,  0, 18,  0 }, {     16,   16,   94,  0, 18,  0 }, {     16,   16,   93,  0, 18,  0 }, {     16,   16,   92,  0, 18,  0 }, {     16,   16,   91,  0, 18,  0 },
    {     16,   16,   90,  0, 18,  0 }, {     16,   16,   89,  1, 18,  0 }, {     16,   16,   88,  1, 18,  0 }, {     16,   16,   87,  1, 18,  0 }, {     16,   16,   86,  1, 18,  0 },
    {     16,   16,   85,  1, 18,  0 }, {     16,   16,   84,  1, 18,  0 }, {     16,   16,   83,  1, 18,  0 }, {     16,   16,   82,  1, 18,  0 }, {     16,   16,   81,  1, 18,  0 },
    {     16,   16,   80,  1, 18,  0 }, {     16,   16,   79,  1, 18,  0 }, {     16,   16,   78,  1, 18,  0 }, {     16,   16,   77,  2, 18,  0 }, {     16,   16,   76,  2, 18,  0 },
    {     16,   16,   75,  2, 18,  0 }, {     16,   16,   74,  2, 18,  0 }, {     16,   16,   73,  2, 18,  0 }, {     16,   16,   72,  2, 18,  0 }, {     16,   16,   71,  2, 18,  0 },
    {     16,   16,   70,  2, 18,  0 }, {     16,   16,   69,  2, 18,  0 }, {     16,   16,   68,  2, 18,  0 }, {     16,   16,   67,  2, 18,  0 }, {     16,   16,   66,  2, 18,  0 },
    {     16,   16,   65,  3, 18,  0 }, {     16,   16,   64,  3, 18,  0 }, {     16,   16,   63,  3, 18,  0 }, {     16,   16,   62,  3, 18,  0 }, {     16,   16,   61,  3, 18,  0 },
    {     16,   16,   60,  3, 18,  0 }, {     16,   16,   59,  3, 18,  0 }, {     16,   16,   58,  3, 18,  0 }, {     16,   16,   57,  3, 18,  0 }, {     16,   16,   56,  3, 18,  0 },
    {     16,   16,   55,  3, 18,  0 }, {     16,   16,   54,  3, 18,  0 }, {     16,   16,   53,  4, 18,  0 }, {     16,   16,   52,  4, 18,  0 }, {     16,   16,   51,  4, 18,  0 },
    {     16,   16,   50,  4, 18,  0 }, {     16,   16,   49,  4, 18,  0 }, {     16,   16,   48,  4, 18,  0 }, {     16,   16,   47,  4, 18,  0 }, {     16,   16,   46,  4, 18,  0 },
    {     16,   16,   45,  4, 18,  0 }, {     16,   16,   44,  4, 18,  0 }, {     16,   16,   43,  4, 18,  0 }, {     16,   16,   42,  4, 18,  0 }, {     16,   16,   41,  5, 18,  0 },
    {     16,   16,   40,  5, 18,  0 }, {     16,   16,   39,  5, 18,  0 }, {     16,   16,   38,  5, 18,  0 }, {     16,   16,   37,  5, 18,  0 }, {     16,   16,   36,  5, 18,  0 },
    {     16,   16,   35,  5, 18,  0 }, {     16,   16,   34,  5, 18,  0 }, {     16,   16,   33,  5, 18,  0 }, {     16,   16,   32,  5, 18,  0 }, {     16,   16,   31,  5, 18,  0 },
    {     16,   16,   30,  5, 18,  0 }, {     16,   16,   29,  6, 18,  0 }, {     16,   16,   28,  6, 18,  0 }, {     16,   16,   27,  6, 18,  0 }, {     16,   16,   26,  6, 18,  0 },
    {     16,   16,   25,  6, 18,  0 }, {     16,   16,   24,  6, 18,  0 }, {     16,   16,   23,  6, 18,  0 }, {     16,   16,   22,  6, 18,  0 }, {     16,   16,   21,  6, 18,  0 },
    {     16,   16,   20,  6, 18,  0 }, {     16,   16,   19,  6, 18,  0 }, {     16,   16,   18,  6, 18,  0 }, {     16,   16,   17,  7, 18,  0 }, {     16,   16,   16,  7, 18,  0 },
    {     16,   16,   15,  7, 18,  0 }, {     16,   16,   14,  7, 18,  0 }, {     16,   16,   13,  7, 18,  0 }, {     16,   16,   12,  7, 18,  0 }, {     16,   16,   11,  7, 18,  0 },
    {     16,   16,   10,  7, 18,  0 }, {     16,   16,    9,  7, 18,  0 }, {     16,   16,    8,  7, 18,  0 }, {     16,   16,    7,  7, 18,  0 }, {     16,   16,    6,  7, 18,  0 },
    {     16,   16,    5,  8, 18,  0 }, {     16,   16,    4,  8, 18,  0 }, {     16,   16,    3,  8, 18,  0 }, {     16,   16,    2,  8, 18,  0 }, {     16,   16,    1,  8, 18,  0 },
    {     16,   16,    0,  8, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96CA88, {
    {     16,   16,   95,  8, 18,  0 }, {     16,   16,   94,  8, 18,  0 }, {     16,   16,   93,  8, 18,  0 }, {     16,   16,   92,  8, 18,  0 }, {     16,   16,   91,  8, 18,  0 },
    {     16,   16,   90,  8, 18,  0 }, {     16,   16,   89,  9, 18,  0 }, {     16,   16,   88,  9, 18,  0 }, {     16,   16,   87,  9, 18,  0 }, {     16,   16,   86,  9, 18,  0 },
    {     16,   16,   85,  9, 18,  0 }, {     16,   16,   84,  9, 18,  0 }, {     16,   16,   83,  9, 18,  0 }, {     16,   16,   82,  9, 18,  0 }, {     16,   16,   81,  9, 18,  0 },
    {     16,   16,   80,  9, 18,  0 }, {     16,   16,   79,  9, 18,  0 }, {     16,   16,   78,  9, 18,  0 }, {     16,   16,   77, 10, 18,  0 }, {     16,   16,   76, 10, 18,  0 },
    {     16,   16,   75, 10, 18,  0 }, {     16,   16,   74, 10, 18,  0 }, {     16,   16,   73, 10, 18,  0 }, {     16,   16,   72, 10, 18,  0 }, {     16,   16,   71, 10, 18,  0 },
    {     16,   16,   70, 10, 18,  0 }, {     16,   16,   69, 10, 18,  0 }, {     16,   16,   68, 10, 18,  0 }, {     16,   16,   67, 10, 18,  0 }, {     16,   16,   66, 10, 18,  0 },
    {     16,   16,   65, 11, 18,  0 }, {     16,   16,   64, 11, 18,  0 }, {     16,   16,   63, 11, 18,  0 }, {     16,   16,   62, 11, 18,  0 }, {     16,   16,   61, 11, 18,  0 },
    {     16,   16,   60, 11, 18,  0 }, {     16,   16,   59, 11, 18,  0 }, {     16,   16,   58, 11, 18,  0 }, {     16,   16,   57, 11, 18,  0 }, {     16,   16,   56, 11, 18,  0 },
    {     16,   16,   55, 11, 18,  0 }, {     16,   16,   54, 11, 18,  0 }, {     16,   16,   53, 12, 18,  0 }, {     16,   16,   52, 12, 18,  0 }, {     16,   16,   51, 12, 18,  0 },
    {     16,   16,   50, 12, 18,  0 }, {     16,   16,   49, 12, 18,  0 }, {     16,   16,   48, 12, 18,  0 }, {     16,   16,   47, 12, 18,  0 }, {     16,   16,   46, 12, 18,  0 },
    {     16,   16,   45, 12, 18,  0 }, {     16,   16,   44, 12, 18,  0 }, {     16,   16,   43, 12, 18,  0 }, {     16,   16,   42, 12, 18,  0 }, {     16,   16,   41, 13, 18,  0 },
    {     16,   16,   40, 13, 18,  0 }, {     16,   16,   39, 13, 18,  0 }, {     16,   16,   38, 13, 18,  0 }, {     16,   16,   37, 13, 18,  0 }, {     16,   16,   36, 13, 18,  0 },
    {     16,   16,   35, 13, 18,  0 }, {     16,   16,   34, 13, 18,  0 }, {     16,   16,   33, 13, 18,  0 }, {     16,   16,   32, 13, 18,  0 }, {     16,   16,   31, 13, 18,  0 },
    {     16,   16,   30, 13, 18,  0 }, {     16,   16,   29, 14, 18,  0 }, {     16,   16,   28, 14, 18,  0 }, {     16,   16,   27, 14, 18,  0 }, {     16,   16,   26, 14, 18,  0 },
    {     16,   16,   25, 14, 18,  0 }, {     16,   16,   24, 14, 18,  0 }, {     16,   16,   23, 14, 18,  0 }, {     16,   16,   22, 14, 18,  0 }, {     16,   16,   21, 14, 18,  0 },
    {     16,   16,   20, 14, 18,  0 }, {     16,   16,   19, 14, 18,  0 }, {     16,   16,   18, 14, 18,  0 }, {     16,   16,   17, 15, 18,  0 }, {     16,   16,   16, 15, 18,  0 },
    {     16,   16,   15, 15, 18,  0 }, {     16,   16,   14, 15, 18,  0 }, {     16,   16,   13, 15, 18,  0 }, {     16,   16,   12, 15, 18,  0 }, {     16,   16,   11, 15, 18,  0 },
    {     16,   16,   10, 15, 18,  0 }, {     16,   16,    9, 15, 18,  0 }, {     16,   16,    8, 15, 18,  0 }, {     16,   16,    7, 15, 18,  0 }, {     16,   16,    6, 15, 18,  0 },
    {     16,   16,    5, 16, 18,  0 }, {     16,   16,    4, 16, 18,  0 }, {     16,   16,    3, 16, 18,  0 }, {     16,   16,    2, 16, 18,  0 }, {     16,   16,    1, 16, 18,  0 },
    {     16,   16,    0, 16, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96CDEA, {
    {     16,   16,   95, 16, 18,  0 }, {     16,   16,   94, 16, 18,  0 }, {     16,   16,   93, 16, 18,  0 }, {     16,   16,   92, 16, 18,  0 }, {     16,   16,   91, 16, 18,  0 },
    {     16,   16,   90, 16, 18,  0 }, {     16,   16,   89, 17, 18,  0 }, {     16,   16,   88, 17, 18,  0 }, {     16,   16,   87, 17, 18,  0 }, {     16,   16,   86, 17, 18,  0 },
    {     16,   16,   85, 17, 18,  0 }, {     16,   16,   84, 17, 18,  0 }, {     16,   16,   83, 17, 18,  0 }, {     16,   16,   82, 17, 18,  0 }, {     16,   16,   81, 17, 18,  0 },
    {     16,   16,   80, 17, 18,  0 }, {     16,   16,   79, 17, 18,  0 }, {     16,   16,   78, 17, 18,  0 }, {     16,   16,   77, 18, 18,  0 }, {     16,   16,   76, 18, 18,  0 },
    {     16,   16,   75, 18, 18,  0 }, {     16,   16,   74, 18, 18,  0 }, {     16,   16,   73, 18, 18,  0 }, {     16,   16,   72, 18, 18,  0 }, {     16,   16,   71, 18, 18,  0 },
    {     16,   16,   70, 18, 18,  0 }, {     16,   16,   69, 18, 18,  0 }, {     16,   16,   68, 18, 18,  0 }, {     16,   16,   67, 18, 18,  0 }, {     16,   16,   66, 18, 18,  0 },
    {     16,   16,   65, 19, 18,  0 }, {     16,   16,   64, 19, 18,  0 }, {     16,   16,   63, 19, 18,  0 }, {     16,   16,   62, 19, 18,  0 }, {     16,   16,   61, 19, 18,  0 },
    {     16,   16,   60, 19, 18,  0 }, {     16,   16,   59, 19, 18,  0 }, {     16,   16,   58, 19, 18,  0 }, {     16,   16,   57, 19, 18,  0 }, {     16,   16,   56, 19, 18,  0 },
    {     16,   16,   55, 19, 18,  0 }, {     16,   16,   54, 19, 18,  0 }, {     16,   16,   53, 20, 18,  0 }, {     16,   16,   52, 20, 18,  0 }, {     16,   16,   51, 20, 18,  0 },
    {     16,   16,   50, 20, 18,  0 }, {     16,   16,   49, 20, 18,  0 }, {     16,   16,   48, 20, 18,  0 }, {     16,   16,   47, 20, 18,  0 }, {     16,   16,   46, 20, 18,  0 },
    {     16,   16,   45, 20, 18,  0 }, {     16,   16,   44, 20, 18,  0 }, {     16,   16,   43, 20, 18,  0 }, {     16,   16,   42, 20, 18,  0 }, {     16,   16,   41, 21, 18,  0 },
    {     16,   16,   40, 21, 18,  0 }, {     16,   16,   39, 21, 18,  0 }, {     16,   16,   38, 21, 18,  0 }, {     16,   16,   37, 21, 18,  0 }, {     16,   16,   36, 21, 18,  0 },
    {     16,   16,   35, 21, 18,  0 }, {     16,   16,   34, 21, 18,  0 }, {     16,   16,   33, 21, 18,  0 }, {     16,   16,   32, 21, 18,  0 }, {     16,   16,   31, 21, 18,  0 },
    {     16,   16,   30, 21, 18,  0 }, {     16,   16,   29, 22, 18,  0 }, {     16,   16,   28, 22, 18,  0 }, {     16,   16,   27, 22, 18,  0 }, {     16,   16,   26, 22, 18,  0 },
    {     16,   16,   25, 22, 18,  0 }, {     16,   16,   24, 22, 18,  0 }, {     16,   16,   23, 22, 18,  0 }, {     16,   16,   22, 22, 18,  0 }, {     16,   16,   21, 22, 18,  0 },
    {     16,   16,   20, 22, 18,  0 }, {     16,   16,   19, 22, 18,  0 }, {     16,   16,   18, 22, 18,  0 }, {     16,   16,   17, 23, 18,  0 }, {     16,   16,   16, 23, 18,  0 },
    {     16,   16,   15, 23, 18,  0 }, {     16,   16,   14, 23, 18,  0 }, {     16,   16,   13, 23, 18,  0 }, {     16,   16,   12, 23, 18,  0 }, {     16,   16,   11, 23, 18,  0 },
    {     16,   16,   10, 23, 18,  0 }, {     16,   16,    9, 23, 18,  0 }, {     16,   16,    8, 23, 18,  0 }, {     16,   16,    7, 23, 18,  0 }, {     16,   16,    6, 23, 18,  0 },
    {     16,   16,    5, 24, 18,  0 }, {     16,   16,    4, 24, 18,  0 }, {     16,   16,    3, 24, 18,  0 }, {     16,   16,    2, 24, 18,  0 }, {     16,   16,    1, 24, 18,  0 },
    {     16,   16,    0, 24, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_96D14C, {
    {     16,   16,   95, 24, 18,  0 }, {     16,   16,   94, 24, 18,  0 }, {     16,   16,   93, 24, 18,  0 }, {     16,   16,   92, 24, 18,  0 }, {     16,   16,   91, 24, 18,  0 },
    {     16,   16,   90, 24, 18,  0 }, {     16,   16,   89, 25, 18,  0 }, {     16,   16,   88, 25, 18,  0 }, {     16,   16,   87, 25, 18,  0 }, {     16,   16,   86, 25, 18,  0 },
    {     16,   16,   85, 25, 18,  0 }, {     16,   16,   84, 25, 18,  0 }, {     16,   16,   83, 25, 18,  0 }, {     16,   16,   82, 25, 18,  0 }, {     16,   16,   81, 25, 18,  0 },
    {     16,   16,   80, 25, 18,  0 }, {     16,   16,   79, 25, 18,  0 }, {     16,   16,   78, 25, 18,  0 }, {     16,   16,   77, 26, 18,  0 }, {     16,   16,   76, 26, 18,  0 },
    {     16,   16,   75, 26, 18,  0 }, {     16,   16,   74, 26, 18,  0 }, {     16,   16,   73, 26, 18,  0 }, {     16,   16,   72, 26, 18,  0 }, {     16,   16,   71, 26, 18,  0 },
    {     16,   16,   70, 26, 18,  0 }, {     16,   16,   69, 26, 18,  0 }, {     16,   16,   68, 26, 18,  0 }, {     16,   16,   67, 26, 18,  0 }, {     16,   16,   66, 26, 18,  0 },
    {     16,   16,   65, 27, 18,  0 }, {     16,   16,   64, 27, 18,  0 }, {     16,   16,   63, 27, 18,  0 }, {     16,   16,   62, 27, 18,  0 }, {     16,   16,   61, 27, 18,  0 },
    {     16,   16,   60, 27, 18,  0 }, {     16,   16,   59, 27, 18,  0 }, {     16,   16,   58, 27, 18,  0 }, {     16,   16,   57, 27, 18,  0 }, {     16,   16,   56, 27, 18,  0 },
    {     16,   16,   55, 27, 18,  0 }, {     16,   16,   54, 27, 18,  0 }, {     16,   16,   53, 28, 18,  0 }, {     16,   16,   52, 28, 18,  0 }, {     16,   16,   51, 28, 18,  0 },
    {     16,   16,   50, 28, 18,  0 }, {     16,   16,   49, 28, 18,  0 }, {     16,   16,   48, 28, 18,  0 }, {     16,   16,   47, 28, 18,  0 }, {     16,   16,   46, 28, 18,  0 },
    {     16,   16,   45, 28, 18,  0 }, {     16,   16,   44, 28, 18,  0 }, {     16,   16,   43, 28, 18,  0 }, {     16,   16,   42, 28, 18,  0 }, {     16,   16,   41, 29, 18,  0 },
    {     16,   16,   40, 29, 18,  0 }, {     16,   16,   39, 29, 18,  0 }, {     16,   16,   38, 29, 18,  0 }, {     16,   16,   37, 29, 18,  0 }, {     16,   16,   36, 29, 18,  0 },
    {     16,   16,   35, 29, 18,  0 }, {     16,   16,   34, 29, 18,  0 }, {     16,   16,   33, 29, 18,  0 }, {     16,   16,   32, 29, 18,  0 }, {     16,   16,   31, 29, 18,  0 },
    {     16,   16,   30, 29, 18,  0 }, {     16,   16,   29, 30, 18,  0 }, {     16,   16,   28, 30, 18,  0 }, {     16,   16,   27, 30, 18,  0 }, {     16,   16,   26, 30, 18,  0 },
    {     16,   16,   25, 30, 18,  0 }, {     16,   16,   24, 30, 18,  0 }, {     16,   16,   23, 30, 18,  0 }, {     16,   16,   22, 30, 18,  0 }, {     16,   16,   21, 30, 18,  0 },
    {     16,   16,   20, 30, 18,  0 }, {     16,   16,   19, 30, 18,  0 }, {     16,   16,   18, 30, 18,  0 }, {     16,   16,   17, 31, 18,  0 }, {     16,   16,   16, 31, 18,  0 },
    {     16,   16,   15, 31, 18,  0 }, {     16,   16,   14, 31, 18,  0 }, {     16,   16,   13, 31, 18,  0 }, {     16,   16,   12, 31, 18,  0 }, {     16,   16,   11, 31, 18,  0 },
    {     16,   16,   10, 31, 18,  0 }, {     16,   16,    9, 31, 18,  0 }, {     16,   16,    8, 31, 18,  0 }, {     16,   16,    7, 31, 18,  0 }, {     16,   16,    6, 31, 18,  0 },
    {     16,   16,    5,  0, 18,  0 }, {     16,   16,    4,  0, 18,  0 }, {     16,   16,    3,  0, 18,  0 }, {     16,   16,    2,  0, 18,  0 }, {     16,   16,    1,  0, 18,  0 },
    {     16,   16,    0,  0, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9761F2, {
    {     16,   16,    0,  0, 10,  0 }, {     16,   16,    1,  0, 10,  0 }, {     16,   16,    2,  0, 10,  0 }, {     16,   16,    3,  0, 10,  0 }, {     16,   16,    4,  0, 10,  0 },
    {     16,   16,    5,  0, 10,  0 }, {     16,   16,    6,  0, 10,  0 }, {     16,   16,    7,  0, 10,  0 }, {     16,   16,    8,  0, 10,  0 }, {     16,   16,    9,  0, 10,  0 },
    {     16,   16,   10,  0, 10,  0 }, {     16,   16,   11,  0, 10,  0 }, {     16,   16,   12,  0, 10,  0 }, {     17,   16,   13,  0, 10,  0 }, {     17,   16,   14,  0, 10,  0 },
    {     17,   16,   15,  0, 10,  0 }, {     17,   16,   16,  0, 10,  0 }, {     17,   16,   17,  0, 10,  0 }, {     17,   16,   18,  0, 10,  0 }, {     17,   16,   19,  0, 10,  0 },
    {     17,   16,   20,  0, 10,  0 }, {     17,   16,   21,  0, 10,  0 }, {     18,   16,   22,  0, 11,  0 }, {     18,   16,   23,  0, 11,  0 }, {     18,   16,   24,  0, 11,  0 },
    {     18,   16,   25,  0, 11,  0 }, {     18,   16,   26,  0, 11,  0 }, {     18,   16,   27,  0, 11,  0 }, {     19,   16,   28,  0, 11,  0 }, {     19,   16,   29,  0, 11,  0 },
    {     19,   16,   30,  0, 11,  0 }, {     19,   16,   31,  0, 11,  0 }, {     19,   16,   32,  0, 11,  0 }, {     20,   16,   33,  0, 11,  0 }, {     20,   16,   34,  0, 11,  0 },
    {     20,   16,   35,  0, 11,  0 }, {     20,   16,   36,  0, 11,  0 }, {     21,   16,   37,  0, 11,  0 }, {     21,   16,   38,  0, 11,  0 }, {     21,   16,   39,  0, 11,  0 },
    {     21,   16,   40,  0, 11,  0 }, {     22,   16,   41,  0, 11,  0 }, {     22,   16,   42,  0, 11,  0 }, {     22,   16,   43,  0, 11,  0 }, {     22,   16,   44,  0, 11,  0 },
    {     23,   16,   45,  0, 11,  0 }, {     23,   16,   46,  0, 11,  0 }, {     23,   16,   47,  0, 11,  0 }, {     24,   16,   48,  0, 11,  0 }, {     24,   16,   49,  0, 11,  0 },
    {     24,   16,   50,  0, 11,  0 }, {     25,   16,   51,  0, 11,  0 }, {     25,   16,   52,  0, 11,  0 }, {     26,   16,   53,  0, 11,  0 }, {     26,   16,   54,  0, 11,  0 },
    {     26,   16,   55,  0, 11,  0 }, {     27,   16,   56,  0, 12,  0 }, {     27,   16,   57,  0, 12,  0 }, {     28,   16,   58,  0, 12,  0 }, {     28,   16,   59,  0, 12,  0 },
    {     29,   16,   60,  0, 12,  0 }, {     29,   16,   61,  0, 12,  0 }, {     29,   16,   62,  0, 12,  0 }, {     30,   16,   63,  0, 12,  0 }, {     30,   16,   64,  0, 12,  0 },
    {     31,   16,   65,  0, 12,  0 }, {     31,   16,   66,  0, 12,  0 }, {     32,   16,   67,  0, 12,  0 }, {     33,   16,   68,  0, 12,  0 }, {     33,   16,   69,  0, 12,  0 },
    {     34,   16,   70,  0, 12,  0 }, {     34,   16,   71,  0, 12,  0 }, {     35,   16,   72,  0, 12,  0 }, {     35,   16,   73,  0, 12,  0 }, {     36,   16,   74,  0, 12,  0 },
    {     37,   16,   75,  0, 12,  0 }, {     37,   16,   76,  0, 12,  0 }, {     38,   16,   77,  0, 12,  0 }, {     39,   16,   78,  0, 12,  0 }, {     40,   16,   79,  0, 12,  0 },
    {     40,   16,   80,  0, 12,  0 }, {     41,   16,   81,  0, 13,  0 }, {     42,   16,   82,  0, 13,  0 }, {     43,   16,   83,  0, 13,  0 }, {     43,   16,   84,  0, 13,  0 },
    {     44,   16,   85,  0, 13,  0 }, {     45,   16,   86,  0, 13,  0 }, {     46,   16,   87,  0, 13,  0 }, {     47,   16,   88,  0, 13,  0 }, {     48,   16,   89,  0, 13,  0 },
    {     49,   16,   90,  0, 13,  0 }, {     50,   16,   91,  0, 13,  0 }, {     51,   16,   92,  0, 13,  0 }, {     52,   16,   93,  0, 13,  0 }, {     53,   16,   94,  0, 13,  0 },
    {     54,   16,   95,  0, 13,  0 }, {     55,   16,   96,  0, 13,  0 }, {     56,   16,   97,  0, 13,  0 }, {     57,   16,   97,  0, 13,  0 }, {     58,   16,   98,  0, 13,  0 },
    {     59,   16,   99,  0, 13,  0 }, {     60,   16,  100,  0, 14,  0 }, {     61,   16,  100,  0, 14,  0 }, {     62,   16,  101,  0, 14,  0 }, {     63,   16,  101,  0, 14,  0 },
    {     64,   16,  102,  0, 14,  0 }, {     65,   16,  103,  0, 14,  0 }, {     66,   16,  103,  0, 14,  0 }, {     67,   16,  104,  0, 14,  0 }, {     68,   16,  104,  0, 14,  0 },
    {     69,   16,  105,  0, 14,  0 }, {     70,   16,  105,  0, 14,  0 }, {     71,   16,  106,  0, 14,  0 }, {     72,   16,  106,  0, 14,  0 }, {     73,   16,  107,  0, 14,  0 },
    {     74,   16,  107,  0, 14,  0 }, {     75,   16,  107,  0, 14,  0 }, {     76,   16,  108,  0, 15,  0 }, {     77,   16,  108,  0, 15,  0 }, {     78,   16,  108,  0, 15,  0 },
    {     79,   16,  109,  0, 15,  0 }, {     80,   16,  109,  0, 15,  0 }, {     81,   16,  109,  0, 15,  0 }, {     82,   16,  109,  0, 15,  0 }, {     83,   16,  110,  0, 15,  0 },
    {     84,   16,  110,  0, 15,  0 }, {     85,   16,  110,  0, 15,  0 }, {     86,   16,  110,  0, 15,  0 }, {     87,   16,  110,  0, 16,  0 }, {     88,   16,  111,  0, 16,  0 },
    {     89,   16,  111,  0, 16,  0 }, {     90,   16,  111,  0, 16,  0 }, {     91,   16,  111,  0, 16,  0 }, {     92,   16,  111,  0, 16,  0 }, {     93,   16,  111,  0, 16,  0 },
    {     94,   16,  111,  0, 16,  0 }, {     95,   16,  111,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9766C5, {
    {     16,   16,    0,  8, 10,  0 }, {     16,   16,    1,  8, 10,  0 }, {     16,   16,    2,  8, 10,  0 }, {     16,   16,    3,  8, 10,  0 }, {     16,   16,    4,  8, 10,  0 },
    {     16,   16,    5,  8, 10,  0 }, {     16,   16,    6,  8, 10,  0 }, {     16,   16,    7,  8, 10,  0 }, {     16,   16,    8,  8, 10,  0 }, {     16,   16,    9,  8, 10,  0 },
    {     16,   16,   10,  8, 10,  0 }, {     16,   16,   11,  8, 10,  0 }, {     16,   16,   12,  8, 10,  0 }, {     16,   15,   13,  8, 10,  0 }, {     16,   15,   14,  8, 10,  0 },
    {     16,   15,   15,  8, 10,  0 }, {     16,   15,   16,  8, 10,  0 }, {     16,   15,   17,  8, 10,  0 }, {     16,   15,   18,  8, 10,  0 }, {     16,   15,   19,  8, 10,  0 },
    {     16,   15,   20,  8, 10,  0 }, {     16,   15,   21,  8, 10,  0 }, {     16,   14,   22,  8, 11,  0 }, {     16,   14,   23,  8, 11,  0 }, {     16,   14,   24,  8, 11,  0 },
    {     16,   14,   25,  8, 11,  0 }, {     16,   14,   26,  8, 11,  0 }, {     16,   14,   27,  8, 11,  0 }, {     16,   13,   28,  8, 11,  0 }, {     16,   13,   29,  8, 11,  0 },
    {     16,   13,   30,  8, 11,  0 }, {     16,   13,   31,  8, 11,  0 }, {     16,   13,   32,  8, 11,  0 }, {     16,   12,   33,  8, 11,  0 }, {     16,   12,   34,  8, 11,  0 },
    {     16,   12,   35,  8, 11,  0 }, {     16,   12,   36,  8, 11,  0 }, {     16,   11,   37,  8, 11,  0 }, {     16,   11,   38,  8, 11,  0 }, {     16,   11,   39,  8, 11,  0 },
    {     16,   11,   40,  8, 11,  0 }, {     16,   10,   41,  8, 11,  0 }, {     16,   10,   42,  8, 11,  0 }, {     16,   10,   43,  8, 11,  0 }, {     16,   10,   44,  8, 11,  0 },
    {     16,    9,   45,  8, 11,  0 }, {     16,    9,   46,  8, 11,  0 }, {     16,    9,   47,  8, 11,  0 }, {     16,    8,   48,  8, 11,  0 }, {     16,    8,   49,  8, 11,  0 },
    {     16,    8,   50,  8, 11,  0 }, {     16,    7,   51,  8, 11,  0 }, {     16,    7,   52,  8, 11,  0 }, {     16,    6,   53,  8, 11,  0 }, {     16,    6,   54,  8, 11,  0 },
    {     16,    6,   55,  8, 11,  0 }, {     16,    5,   56,  8, 12,  0 }, {     16,    5,   57,  8, 12,  0 }, {     16,    4,   58,  8, 12,  0 }, {     16,    4,   59,  8, 12,  0 },
    {     16,    3,   60,  8, 12,  0 }, {     16,    3,   61,  8, 12,  0 }, {     16,    3,   62,  8, 12,  0 }, {     16,    2,   63,  8, 12,  0 }, {     16,    2,   64,  8, 12,  0 },
    {     16,    1,   65,  8, 12,  0 }, {     16,    1,   66,  8, 12,  0 }, {     16,    0,   67,  8, 12,  0 }, {     16,   -1,   68,  8, 12,  0 }, {     16,   -1,   69,  8, 12,  0 },
    {     16,   -2,   70,  8, 12,  0 }, {     16,   -2,   71,  8, 12,  0 }, {     16,   -3,   72,  8, 12,  0 }, {     16,   -3,   73,  8, 12,  0 }, {     16,   -4,   74,  8, 12,  0 },
    {     16,   -5,   75,  8, 12,  0 }, {     16,   -5,   76,  8, 12,  0 }, {     16,   -6,   77,  8, 12,  0 }, {     16,   -7,   78,  8, 12,  0 }, {     16,   -8,   79,  8, 12,  0 },
    {     16,   -8,   80,  8, 12,  0 }, {     16,   -9,   81,  8, 13,  0 }, {     16,  -10,   82,  8, 13,  0 }, {     16,  -11,   83,  8, 13,  0 }, {     16,  -11,   84,  8, 13,  0 },
    {     16,  -12,   85,  8, 13,  0 }, {     16,  -13,   86,  8, 13,  0 }, {     16,  -14,   87,  8, 13,  0 }, {     16,  -15,   88,  8, 13,  0 }, {     16,  -16,   89,  8, 13,  0 },
    {     16,  -17,   90,  8, 13,  0 }, {     16,  -18,   91,  8, 13,  0 }, {     16,  -19,   92,  8, 13,  0 }, {     16,  -20,   93,  8, 13,  0 }, {     16,  -21,   94,  8, 13,  0 },
    {     16,  -22,   95,  8, 13,  0 }, {     16,  -23,   96,  8, 13,  0 }, {     16,  -24,   97,  8, 13,  0 }, {     16,  -25,   97,  8, 13,  0 }, {     16,  -26,   98,  8, 13,  0 },
    {     16,  -27,   99,  8, 13,  0 }, {     16,  -28,  100,  8, 14,  0 }, {     16,  -29,  100,  8, 14,  0 }, {     16,  -30,  101,  8, 14,  0 }, {     16,  -31,  101,  8, 14,  0 },
    {     16,  -32,  102,  8, 14,  0 }, {     16,  -33,  103,  8, 14,  0 }, {     16,  -34,  103,  8, 14,  0 }, {     16,  -35,  104,  8, 14,  0 }, {     16,  -36,  104,  8, 14,  0 },
    {     16,  -37,  105,  8, 14,  0 }, {     16,  -38,  105,  8, 14,  0 }, {     16,  -39,  106,  8, 14,  0 }, {     16,  -40,  106,  8, 14,  0 }, {     16,  -41,  107,  8, 14,  0 },
    {     16,  -42,  107,  8, 14,  0 }, {     16,  -43,  107,  8, 14,  0 }, {     16,  -44,  108,  8, 15,  0 }, {     16,  -45,  108,  8, 15,  0 }, {     16,  -46,  108,  8, 15,  0 },
    {     16,  -47,  109,  8, 15,  0 }, {     16,  -48,  109,  8, 15,  0 }, {     16,  -49,  109,  8, 15,  0 }, {     16,  -50,  109,  8, 15,  0 }, {     16,  -51,  110,  8, 15,  0 },
    {     16,  -52,  110,  8, 15,  0 }, {     16,  -53,  110,  8, 15,  0 }, {     16,  -54,  110,  8, 15,  0 }, {     16,  -55,  110,  8, 16,  0 }, {     16,  -56,  111,  8, 16,  0 },
    {     16,  -57,  111,  8, 16,  0 }, {     16,  -58,  111,  8, 16,  0 }, {     16,  -59,  111,  8, 16,  0 }, {     16,  -60,  111,  8, 16,  0 }, {     16,  -61,  111,  8, 16,  0 },
    {     16,  -62,  111,  8, 16,  0 }, {     16,  -63,  111,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_976B98, {
    {     16,   16,    0, 16, 10,  0 }, {     16,   16,    1, 16, 10,  0 }, {     16,   16,    2, 16, 10,  0 }, {     16,   16,    3, 16, 10,  0 }, {     16,   16,    4, 16, 10,  0 },
    {     16,   16,    5, 16, 10,  0 }, {     16,   16,    6, 16, 10,  0 }, {     16,   16,    7, 16, 10,  0 }, {     16,   16,    8, 16, 10,  0 }, {     16,   16,    9, 16, 10,  0 },
    {     16,   16,   10, 16, 10,  0 }, {     16,   16,   11, 16, 10,  0 }, {     16,   16,   12, 16, 10,  0 }, {     15,   16,   13, 16, 10,  0 }, {     15,   16,   14, 16, 10,  0 },
    {     15,   16,   15, 16, 10,  0 }, {     15,   16,   16, 16, 10,  0 }, {     15,   16,   17, 16, 10,  0 }, {     15,   16,   18, 16, 10,  0 }, {     15,   16,   19, 16, 10,  0 },
    {     15,   16,   20, 16, 10,  0 }, {     15,   16,   21, 16, 10,  0 }, {     14,   16,   22, 16, 11,  0 }, {     14,   16,   23, 16, 11,  0 }, {     14,   16,   24, 16, 11,  0 },
    {     14,   16,   25, 16, 11,  0 }, {     14,   16,   26, 16, 11,  0 }, {     14,   16,   27, 16, 11,  0 }, {     13,   16,   28, 16, 11,  0 }, {     13,   16,   29, 16, 11,  0 },
    {     13,   16,   30, 16, 11,  0 }, {     13,   16,   31, 16, 11,  0 }, {     13,   16,   32, 16, 11,  0 }, {     12,   16,   33, 16, 11,  0 }, {     12,   16,   34, 16, 11,  0 },
    {     12,   16,   35, 16, 11,  0 }, {     12,   16,   36, 16, 11,  0 }, {     11,   16,   37, 16, 11,  0 }, {     11,   16,   38, 16, 11,  0 }, {     11,   16,   39, 16, 11,  0 },
    {     11,   16,   40, 16, 11,  0 }, {     10,   16,   41, 16, 11,  0 }, {     10,   16,   42, 16, 11,  0 }, {     10,   16,   43, 16, 11,  0 }, {     10,   16,   44, 16, 11,  0 },
    {      9,   16,   45, 16, 11,  0 }, {      9,   16,   46, 16, 11,  0 }, {      9,   16,   47, 16, 11,  0 }, {      8,   16,   48, 16, 11,  0 }, {      8,   16,   49, 16, 11,  0 },
    {      8,   16,   50, 16, 11,  0 }, {      7,   16,   51, 16, 11,  0 }, {      7,   16,   52, 16, 11,  0 }, {      6,   16,   53, 16, 11,  0 }, {      6,   16,   54, 16, 11,  0 },
    {      6,   16,   55, 16, 11,  0 }, {      5,   16,   56, 16, 12,  0 }, {      5,   16,   57, 16, 12,  0 }, {      4,   16,   58, 16, 12,  0 }, {      4,   16,   59, 16, 12,  0 },
    {      3,   16,   60, 16, 12,  0 }, {      3,   16,   61, 16, 12,  0 }, {      3,   16,   62, 16, 12,  0 }, {      2,   16,   63, 16, 12,  0 }, {      2,   16,   64, 16, 12,  0 },
    {      1,   16,   65, 16, 12,  0 }, {      1,   16,   66, 16, 12,  0 }, {      0,   16,   67, 16, 12,  0 }, {     -1,   16,   68, 16, 12,  0 }, {     -1,   16,   69, 16, 12,  0 },
    {     -2,   16,   70, 16, 12,  0 }, {     -2,   16,   71, 16, 12,  0 }, {     -3,   16,   72, 16, 12,  0 }, {     -3,   16,   73, 16, 12,  0 }, {     -4,   16,   74, 16, 12,  0 },
    {     -5,   16,   75, 16, 12,  0 }, {     -5,   16,   76, 16, 12,  0 }, {     -6,   16,   77, 16, 12,  0 }, {     -7,   16,   78, 16, 12,  0 }, {     -8,   16,   79, 16, 12,  0 },
    {     -8,   16,   80, 16, 12,  0 }, {     -9,   16,   81, 16, 13,  0 }, {    -10,   16,   82, 16, 13,  0 }, {    -11,   16,   83, 16, 13,  0 }, {    -11,   16,   84, 16, 13,  0 },
    {    -12,   16,   85, 16, 13,  0 }, {    -13,   16,   86, 16, 13,  0 }, {    -14,   16,   87, 16, 13,  0 }, {    -15,   16,   88, 16, 13,  0 }, {    -16,   16,   89, 16, 13,  0 },
    {    -17,   16,   90, 16, 13,  0 }, {    -18,   16,   91, 16, 13,  0 }, {    -19,   16,   92, 16, 13,  0 }, {    -20,   16,   93, 16, 13,  0 }, {    -21,   16,   94, 16, 13,  0 },
    {    -22,   16,   95, 16, 13,  0 }, {    -23,   16,   96, 16, 13,  0 }, {    -24,   16,   97, 16, 13,  0 }, {    -25,   16,   97, 16, 13,  0 }, {    -26,   16,   98, 16, 13,  0 },
    {    -27,   16,   99, 16, 13,  0 }, {    -28,   16,  100, 16, 14,  0 }, {    -29,   16,  100, 16, 14,  0 }, {    -30,   16,  101, 16, 14,  0 }, {    -31,   16,  101, 16, 14,  0 },
    {    -32,   16,  102, 16, 14,  0 }, {    -33,   16,  103, 16, 14,  0 }, {    -34,   16,  103, 16, 14,  0 }, {    -35,   16,  104, 16, 14,  0 }, {    -36,   16,  104, 16, 14,  0 },
    {    -37,   16,  105, 16, 14,  0 }, {    -38,   16,  105, 16, 14,  0 }, {    -39,   16,  106, 16, 14,  0 }, {    -40,   16,  106, 16, 14,  0 }, {    -41,   16,  107, 16, 14,  0 },
    {    -42,   16,  107, 16, 14,  0 }, {    -43,   16,  107, 16, 14,  0 }, {    -44,   16,  108, 16, 15,  0 }, {    -45,   16,  108, 16, 15,  0 }, {    -46,   16,  108, 16, 15,  0 },
    {    -47,   16,  109, 16, 15,  0 }, {    -48,   16,  109, 16, 15,  0 }, {    -49,   16,  109, 16, 15,  0 }, {    -50,   16,  109, 16, 15,  0 }, {    -51,   16,  110, 16, 15,  0 },
    {    -52,   16,  110, 16, 15,  0 }, {    -53,   16,  110, 16, 15,  0 }, {    -54,   16,  110, 16, 15,  0 }, {    -55,   16,  110, 16, 16,  0 }, {    -56,   16,  111, 16, 16,  0 },
    {    -57,   16,  111, 16, 16,  0 }, {    -58,   16,  111, 16, 16,  0 }, {    -59,   16,  111, 16, 16,  0 }, {    -60,   16,  111, 16, 16,  0 }, {    -61,   16,  111, 16, 16,  0 },
    {    -62,   16,  111, 16, 16,  0 }, {    -63,   16,  111, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_97706B, {
    {     16,   16,    0, 24, 10,  0 }, {     16,   16,    1, 24, 10,  0 }, {     16,   16,    2, 24, 10,  0 }, {     16,   16,    3, 24, 10,  0 }, {     16,   16,    4, 24, 10,  0 },
    {     16,   16,    5, 24, 10,  0 }, {     16,   16,    6, 24, 10,  0 }, {     16,   16,    7, 24, 10,  0 }, {     16,   16,    8, 24, 10,  0 }, {     16,   16,    9, 24, 10,  0 },
    {     16,   16,   10, 24, 10,  0 }, {     16,   16,   11, 24, 10,  0 }, {     16,   16,   12, 24, 10,  0 }, {     16,   17,   13, 24, 10,  0 }, {     16,   17,   14, 24, 10,  0 },
    {     16,   17,   15, 24, 10,  0 }, {     16,   17,   16, 24, 10,  0 }, {     16,   17,   17, 24, 10,  0 }, {     16,   17,   18, 24, 10,  0 }, {     16,   17,   19, 24, 10,  0 },
    {     16,   17,   20, 24, 10,  0 }, {     16,   17,   21, 24, 10,  0 }, {     16,   18,   22, 24, 11,  0 }, {     16,   18,   23, 24, 11,  0 }, {     16,   18,   24, 24, 11,  0 },
    {     16,   18,   25, 24, 11,  0 }, {     16,   18,   26, 24, 11,  0 }, {     16,   18,   27, 24, 11,  0 }, {     16,   19,   28, 24, 11,  0 }, {     16,   19,   29, 24, 11,  0 },
    {     16,   19,   30, 24, 11,  0 }, {     16,   19,   31, 24, 11,  0 }, {     16,   19,   32, 24, 11,  0 }, {     16,   20,   33, 24, 11,  0 }, {     16,   20,   34, 24, 11,  0 },
    {     16,   20,   35, 24, 11,  0 }, {     16,   20,   36, 24, 11,  0 }, {     16,   21,   37, 24, 11,  0 }, {     16,   21,   38, 24, 11,  0 }, {     16,   21,   39, 24, 11,  0 },
    {     16,   21,   40, 24, 11,  0 }, {     16,   22,   41, 24, 11,  0 }, {     16,   22,   42, 24, 11,  0 }, {     16,   22,   43, 24, 11,  0 }, {     16,   22,   44, 24, 11,  0 },
    {     16,   23,   45, 24, 11,  0 }, {     16,   23,   46, 24, 11,  0 }, {     16,   23,   47, 24, 11,  0 }, {     16,   24,   48, 24, 11,  0 }, {     16,   24,   49, 24, 11,  0 },
    {     16,   24,   50, 24, 11,  0 }, {     16,   25,   51, 24, 11,  0 }, {     16,   25,   52, 24, 11,  0 }, {     16,   26,   53, 24, 11,  0 }, {     16,   26,   54, 24, 11,  0 },
    {     16,   26,   55, 24, 11,  0 }, {     16,   27,   56, 24, 12,  0 }, {     16,   27,   57, 24, 12,  0 }, {     16,   28,   58, 24, 12,  0 }, {     16,   28,   59, 24, 12,  0 },
    {     16,   29,   60, 24, 12,  0 }, {     16,   29,   61, 24, 12,  0 }, {     16,   29,   62, 24, 12,  0 }, {     16,   30,   63, 24, 12,  0 }, {     16,   30,   64, 24, 12,  0 },
    {     16,   31,   65, 24, 12,  0 }, {     16,   31,   66, 24, 12,  0 }, {     16,   32,   67, 24, 12,  0 }, {     16,   33,   68, 24, 12,  0 }, {     16,   33,   69, 24, 12,  0 },
    {     16,   34,   70, 24, 12,  0 }, {     16,   34,   71, 24, 12,  0 }, {     16,   35,   72, 24, 12,  0 }, {     16,   35,   73, 24, 12,  0 }, {     16,   36,   74, 24, 12,  0 },
    {     16,   37,   75, 24, 12,  0 }, {     16,   37,   76, 24, 12,  0 }, {     16,   38,   77, 24, 12,  0 }, {     16,   39,   78, 24, 12,  0 }, {     16,   40,   79, 24, 12,  0 },
    {     16,   40,   80, 24, 12,  0 }, {     16,   41,   81, 24, 13,  0 }, {     16,   42,   82, 24, 13,  0 }, {     16,   43,   83, 24, 13,  0 }, {     16,   43,   84, 24, 13,  0 },
    {     16,   44,   85, 24, 13,  0 }, {     16,   45,   86, 24, 13,  0 }, {     16,   46,   87, 24, 13,  0 }, {     16,   47,   88, 24, 13,  0 }, {     16,   48,   89, 24, 13,  0 },
    {     16,   49,   90, 24, 13,  0 }, {     16,   50,   91, 24, 13,  0 }, {     16,   51,   92, 24, 13,  0 }, {     16,   52,   93, 24, 13,  0 }, {     16,   53,   94, 24, 13,  0 },
    {     16,   54,   95, 24, 13,  0 }, {     16,   55,   96, 24, 13,  0 }, {     16,   56,   97, 24, 13,  0 }, {     16,   57,   97, 24, 13,  0 }, {     16,   58,   98, 24, 13,  0 },
    {     16,   59,   99, 24, 13,  0 }, {     16,   60,  100, 24, 14,  0 }, {     16,   61,  100, 24, 14,  0 }, {     16,   62,  101, 24, 14,  0 }, {     16,   63,  101, 24, 14,  0 },
    {     16,   64,  102, 24, 14,  0 }, {     16,   65,  103, 24, 14,  0 }, {     16,   66,  103, 24, 14,  0 }, {     16,   67,  104, 24, 14,  0 }, {     16,   68,  104, 24, 14,  0 },
    {     16,   69,  105, 24, 14,  0 }, {     16,   70,  105, 24, 14,  0 }, {     16,   71,  106, 24, 14,  0 }, {     16,   72,  106, 24, 14,  0 }, {     16,   73,  107, 24, 14,  0 },
    {     16,   74,  107, 24, 14,  0 }, {     16,   75,  107, 24, 14,  0 }, {     16,   76,  108, 24, 15,  0 }, {     16,   77,  108, 24, 15,  0 }, {     16,   78,  108, 24, 15,  0 },
    {     16,   79,  109, 24, 15,  0 }, {     16,   80,  109, 24, 15,  0 }, {     16,   81,  109, 24, 15,  0 }, {     16,   82,  109, 24, 15,  0 }, {     16,   83,  110, 24, 15,  0 },
    {     16,   84,  110, 24, 15,  0 }, {     16,   85,  110, 24, 15,  0 }, {     16,   86,  110, 24, 15,  0 }, {     16,   87,  110, 24, 16,  0 }, {     16,   88,  111, 24, 16,  0 },
    {     16,   89,  111, 24, 16,  0 }, {     16,   90,  111, 24, 16,  0 }, {     16,   91,  111, 24, 16,  0 }, {     16,   92,  111, 24, 16,  0 }, {     16,   93,  111, 24, 16,  0 },
    {     16,   94,  111, 24, 16,  0 }, {     16,   95,  111, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_97753E, {
    {     31,   16,   32,  0,  0,  0 }, {     30,   16,   32,  0,  0,  0 }, {     29,   16,   32,  0,  0,  0 }, {     28,   16,   32,  0,  0,  0 }, {     27,   16,   32,  0,  0,  0 },
    {     26,   16,   32,  0,  0,  0 }, {     25,   16,   32,  0,  0,  0 }, {     24,   16,   32,  0,  5,  0 }, {     23,   16,   31,  0,  5,  0 }, {     22,   16,   31,  0,  5,  0 },
    {     21,   16,   31,  0,  5,  0 }, {     20,   16,   31,  0,  5,  0 }, {     19,   16,   31,  0,  5,  0 }, {     18,   16,   30,  0,  5,  0 }, {     17,   16,   30,  0,  5,  0 },
    {     16,   16,   30,  0,  5,  0 }, {     15,   16,   30,  0,  6,  0 }, {     14,   16,   29,  0,  6,  0 }, {     13,   16,   29,  0,  6,  0 }, {     12,   16,   29,  0,  6,  0 },
    {     11,   16,   28,  0,  6,  0 }, {     10,   16,   28,  0,  6,  0 }, {      9,   16,   28,  0,  6,  0 }, {      8,   16,   27,  0,  6,  0 }, {      7,   16,   27,  0,  6,  0 },
    {      6,   16,   26,  0,  6,  0 }, {      5,   16,   26,  0,  6,  0 }, {      4,   16,   25,  0,  6,  0 }, {      3,   16,   25,  0,  6,  0 }, {      2,   16,   24,  0,  6,  0 },
    {      1,   16,   24,  0,  6,  0 }, {      0,   16,   23,  0,  6,  0 }, {     -1,   16,   22,  0,  6,  0 }, {     -2,   16,   22,  0,  6,  0 }, {     -3,   16,   21,  0,  6,  0 },
    {     -4,   16,   21,  0,  6,  0 }, {     -5,   16,   20,  0,  7,  0 }, {     -6,   16,   19,  0,  7,  0 }, {     -7,   16,   18,  0,  7,  0 }, {     -8,   16,   18,  0,  7,  0 },
    {     -9,   16,   17,  0,  7,  0 }, {    -10,   16,   16,  0,  7,  0 }, {    -11,   16,   15,  0,  7,  0 }, {    -12,   16,   14,  0,  7,  0 }, {    -13,   16,   13,  0,  7,  0 },
    {    -14,   16,   12,  0,  7,  0 }, {    -15,   16,   11,  0,  7,  0 }, {    -16,   16,   10,  0,  7,  0 }, {    -17,   16,    9,  0,  7,  0 }, {    -18,   16,    8,  0,  7,  0 },
    {    -19,   16,    7,  0,  7,  0 }, {    -20,   16,    6,  0,  7,  0 }, {    -21,   16,    5,  0,  7,  0 }, {    -21,   16,    4,  0,  7,  0 }, {    -22,   16,    3,  0,  7,  0 },
    {    -23,   16,    2,  0,  7,  0 }, {    -24,   16,    1,  0,  8,  0 }, {    -24,   16,    0,  0,  8,  0 }, {    -25,   16,   -1,  0,  8,  0 }, {    -26,   16,   -2,  0,  8,  0 },
    {    -27,   16,   -3,  0,  8,  0 }, {    -27,   16,   -4,  0,  8,  0 }, {    -28,   16,   -5,  0,  8,  0 }, {    -29,   16,   -6,  0,  8,  0 }, {    -29,   16,   -7,  0,  8,  0 },
    {    -30,   16,   -8,  0,  8,  0 }, {    -30,   16,   -9,  0,  8,  0 }, {    -31,   16,  -10,  0,  8,  0 }, {    -31,   16,  -11,  0,  8,  0 }, {    -32,   16,  -12,  0,  8,  0 },
    {    -33,   16,  -13,  0,  8,  0 }, {    -33,   16,  -14,  0,  8,  0 }, {    -34,   16,  -15,  0,  8,  0 }, {    -34,   16,  -16,  0,  8,  0 }, {    -35,   16,  -17,  0,  8,  0 },
    {    -35,   16,  -18,  0,  8,  0 }, {    -35,   16,  -19,  0,  8,  0 }, {    -36,   16,  -20,  0,  8,  0 }, {    -36,   16,  -21,  0,  8,  0 }, {    -37,   16,  -22,  0,  8,  0 },
    {    -37,   16,  -23,  0,  8,  0 }, {    -38,   16,  -24,  0, 17,  0 }, {    -38,   16,  -25,  0, 17,  0 }, {    -38,   16,  -26,  0, 17,  0 }, {    -39,   16,  -27,  0, 17,  0 },
    {    -39,   16,  -28,  0, 17,  0 }, {    -40,   16,  -29,  0, 17,  0 }, {    -40,   16,  -30,  0, 17,  0 }, {    -40,   16,  -31,  0, 17,  0 }, {    -41,   16,  -32,  0, 17,  0 },
    {    -41,   16,  -33,  0, 17,  0 }, {    -41,   16,  -34,  0, 17,  0 }, {    -42,   16,  -35,  0, 17,  0 }, {    -42,   16,  -36,  0, 17,  0 }, {    -42,   16,  -37,  0, 17,  0 },
    {    -42,   16,  -38,  0, 17,  0 }, {    -43,   16,  -39,  0, 17,  0 }, {    -43,   16,  -40,  0, 17,  0 }, {    -43,   16,  -41,  0, 17,  0 }, {    -43,   16,  -42,  0, 17,  0 },
    {    -44,   16,  -43,  0, 17,  0 }, {    -44,   16,  -44,  0, 17,  0 }, {    -44,   16,  -45,  0, 17,  0 }, {    -44,   16,  -46,  0, 17,  0 }, {    -45,   16,  -47,  0, 17,  0 },
    {    -45,   16,  -48,  0, 17,  0 }, {    -45,   16,  -49,  0, 17,  0 }, {    -45,   16,  -50,  0, 17,  0 }, {    -45,   16,  -51,  0, 17,  0 }, {    -46,   16,  -52,  0, 17,  0 },
    {    -46,   16,  -53,  0, 17,  0 }, {    -46,   16,  -54,  0, 17,  0 }, {    -46,   16,  -55,  0, 17,  0 }, {    -46,   16,  -56,  0, 17,  0 }, {    -46,   16,  -57,  0, 17,  0 },
    {    -47,   16,  -58,  0, 17,  0 }, {    -47,   16,  -59,  0, 18,  0 }, {    -47,   16,  -60,  0, 18,  0 }, {    -47,   16,  -61,  0, 18,  0 }, {    -47,   16,  -62,  0, 18,  0 },
    {    -47,   16,  -63,  0, 18,  0 }, {    -47,   16,  -64,  0, 18,  0 }, {    -47,   16,  -65,  0, 18,  0 }, {    -47,   16,  -66,  0, 18,  0 }, {    -48,   16,  -67,  0, 18,  0 },
    {    -48,   16,  -68,  0, 18,  0 }, {    -48,   16,  -69,  0, 18,  0 }, {    -48,   16,  -70,  0, 18,  0 }, {    -48,   16,  -71,  0, 18,  0 }, {    -48,   16,  -72,  0, 18,  0 },
    {    -48,   16,  -73,  0, 18,  0 }, {    -48,   16,  -74,  0, 18,  0 }, {    -48,   16,  -75,  0, 18,  0 }, {    -48,   16,  -76,  0, 18,  0 }, {    -48,   16,  -77,  0, 18,  0 },
    {    -48,   16,  -78,  0, 18,  0 }, {    -48,   16,  -79,  0, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_977A11, {
    {     16,    0,   32,  8,  0,  0 }, {     16,    1,   32,  8,  0,  0 }, {     16,    2,   32,  8,  0,  0 }, {     16,    3,   32,  8,  0,  0 }, {     16,    4,   32,  8,  0,  0 },
    {     16,    5,   32,  8,  0,  0 }, {     16,    6,   32,  8,  0,  0 }, {     16,    7,   32,  8,  5,  0 }, {     16,    8,   31,  8,  5,  0 }, {     16,    9,   31,  8,  5,  0 },
    {     16,   10,   31,  8,  5,  0 }, {     16,   11,   31,  8,  5,  0 }, {     16,   12,   31,  8,  5,  0 }, {     16,   13,   30,  8,  5,  0 }, {     16,   14,   30,  8,  5,  0 },
    {     16,   15,   30,  8,  5,  0 }, {     16,   16,   30,  8,  6,  0 }, {     16,   17,   29,  8,  6,  0 }, {     16,   18,   29,  8,  6,  0 }, {     16,   19,   29,  8,  6,  0 },
    {     16,   20,   28,  8,  6,  0 }, {     16,   21,   28,  8,  6,  0 }, {     16,   22,   28,  8,  6,  0 }, {     16,   23,   27,  8,  6,  0 }, {     16,   24,   27,  8,  6,  0 },
    {     16,   25,   26,  8,  6,  0 }, {     16,   26,   26,  8,  6,  0 }, {     16,   27,   25,  8,  6,  0 }, {     16,   28,   25,  8,  6,  0 }, {     16,   29,   24,  8,  6,  0 },
    {     16,   30,   24,  8,  6,  0 }, {     16,   31,   23,  8,  6,  0 }, {     16,   32,   22,  8,  6,  0 }, {     16,   33,   22,  8,  6,  0 }, {     16,   34,   21,  8,  6,  0 },
    {     16,   35,   21,  8,  6,  0 }, {     16,   36,   20,  8,  7,  0 }, {     16,   37,   19,  8,  7,  0 }, {     16,   38,   18,  8,  7,  0 }, {     16,   39,   18,  8,  7,  0 },
    {     16,   40,   17,  8,  7,  0 }, {     16,   41,   16,  8,  7,  0 }, {     16,   42,   15,  8,  7,  0 }, {     16,   43,   14,  8,  7,  0 }, {     16,   44,   13,  8,  7,  0 },
    {     16,   45,   12,  8,  7,  0 }, {     16,   46,   11,  8,  7,  0 }, {     16,   47,   10,  8,  7,  0 }, {     16,   48,    9,  8,  7,  0 }, {     16,   49,    8,  8,  7,  0 },
    {     16,   50,    7,  8,  7,  0 }, {     16,   51,    6,  8,  7,  0 }, {     16,   52,    5,  8,  7,  0 }, {     16,   52,    4,  8,  7,  0 }, {     16,   53,    3,  8,  7,  0 },
    {     16,   54,    2,  8,  7,  0 }, {     16,   55,    1,  8,  8,  0 }, {     16,   55,    0,  8,  8,  0 }, {     16,   56,   -1,  8,  8,  0 }, {     16,   57,   -2,  8,  8,  0 },
    {     16,   58,   -3,  8,  8,  0 }, {     16,   58,   -4,  8,  8,  0 }, {     16,   59,   -5,  8,  8,  0 }, {     16,   60,   -6,  8,  8,  0 }, {     16,   60,   -7,  8,  8,  0 },
    {     16,   61,   -8,  8,  8,  0 }, {     16,   61,   -9,  8,  8,  0 }, {     16,   62,  -10,  8,  8,  0 }, {     16,   62,  -11,  8,  8,  0 }, {     16,   63,  -12,  8,  8,  0 },
    {     16,   64,  -13,  8,  8,  0 }, {     16,   64,  -14,  8,  8,  0 }, {     16,   65,  -15,  8,  8,  0 }, {     16,   65,  -16,  8,  8,  0 }, {     16,   66,  -17,  8,  8,  0 },
    {     16,   66,  -18,  8,  8,  0 }, {     16,   66,  -19,  8,  8,  0 }, {     16,   67,  -20,  8,  8,  0 }, {     16,   67,  -21,  8,  8,  0 }, {     16,   68,  -22,  8,  8,  0 },
    {     16,   68,  -23,  8,  8,  0 }, {     16,   69,  -24,  8, 17,  0 }, {     16,   69,  -25,  8, 17,  0 }, {     16,   69,  -26,  8, 17,  0 }, {     16,   70,  -27,  8, 17,  0 },
    {     16,   70,  -28,  8, 17,  0 }, {     16,   71,  -29,  8, 17,  0 }, {     16,   71,  -30,  8, 17,  0 }, {     16,   71,  -31,  8, 17,  0 }, {     16,   72,  -32,  8, 17,  0 },
    {     16,   72,  -33,  8, 17,  0 }, {     16,   72,  -34,  8, 17,  0 }, {     16,   73,  -35,  8, 17,  0 }, {     16,   73,  -36,  8, 17,  0 }, {     16,   73,  -37,  8, 17,  0 },
    {     16,   73,  -38,  8, 17,  0 }, {     16,   74,  -39,  8, 17,  0 }, {     16,   74,  -40,  8, 17,  0 }, {     16,   74,  -41,  8, 17,  0 }, {     16,   74,  -42,  8, 17,  0 },
    {     16,   75,  -43,  8, 17,  0 }, {     16,   75,  -44,  8, 17,  0 }, {     16,   75,  -45,  8, 17,  0 }, {     16,   75,  -46,  8, 17,  0 }, {     16,   76,  -47,  8, 17,  0 },
    {     16,   76,  -48,  8, 17,  0 }, {     16,   76,  -49,  8, 17,  0 }, {     16,   76,  -50,  8, 17,  0 }, {     16,   76,  -51,  8, 17,  0 }, {     16,   77,  -52,  8, 17,  0 },
    {     16,   77,  -53,  8, 17,  0 }, {     16,   77,  -54,  8, 17,  0 }, {     16,   77,  -55,  8, 17,  0 }, {     16,   77,  -56,  8, 17,  0 }, {     16,   77,  -57,  8, 17,  0 },
    {     16,   78,  -58,  8, 17,  0 }, {     16,   78,  -59,  8, 18,  0 }, {     16,   78,  -60,  8, 18,  0 }, {     16,   78,  -61,  8, 18,  0 }, {     16,   78,  -62,  8, 18,  0 },
    {     16,   78,  -63,  8, 18,  0 }, {     16,   78,  -64,  8, 18,  0 }, {     16,   78,  -65,  8, 18,  0 }, {     16,   78,  -66,  8, 18,  0 }, {     16,   79,  -67,  8, 18,  0 },
    {     16,   79,  -68,  8, 18,  0 }, {     16,   79,  -69,  8, 18,  0 }, {     16,   79,  -70,  8, 18,  0 }, {     16,   79,  -71,  8, 18,  0 }, {     16,   79,  -72,  8, 18,  0 },
    {     16,   79,  -73,  8, 18,  0 }, {     16,   79,  -74,  8, 18,  0 }, {     16,   79,  -75,  8, 18,  0 }, {     16,   79,  -76,  8, 18,  0 }, {     16,   79,  -77,  8, 18,  0 },
    {     16,   79,  -78,  8, 18,  0 }, {     16,   79,  -79,  8, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_977EE4, {
    {      0,   16,   32, 16,  0,  0 }, {      1,   16,   32, 16,  0,  0 }, {      2,   16,   32, 16,  0,  0 }, {      3,   16,   32, 16,  0,  0 }, {      4,   16,   32, 16,  0,  0 },
    {      5,   16,   32, 16,  0,  0 }, {      6,   16,   32, 16,  0,  0 }, {      7,   16,   32, 16,  5,  0 }, {      8,   16,   31, 16,  5,  0 }, {      9,   16,   31, 16,  5,  0 },
    {     10,   16,   31, 16,  5,  0 }, {     11,   16,   31, 16,  5,  0 }, {     12,   16,   31, 16,  5,  0 }, {     13,   16,   30, 16,  5,  0 }, {     14,   16,   30, 16,  5,  0 },
    {     15,   16,   30, 16,  5,  0 }, {     16,   16,   30, 16,  6,  0 }, {     17,   16,   29, 16,  6,  0 }, {     18,   16,   29, 16,  6,  0 }, {     19,   16,   29, 16,  6,  0 },
    {     20,   16,   28, 16,  6,  0 }, {     21,   16,   28, 16,  6,  0 }, {     22,   16,   28, 16,  6,  0 }, {     23,   16,   27, 16,  6,  0 }, {     24,   16,   27, 16,  6,  0 },
    {     25,   16,   26, 16,  6,  0 }, {     26,   16,   26, 16,  6,  0 }, {     27,   16,   25, 16,  6,  0 }, {     28,   16,   25, 16,  6,  0 }, {     29,   16,   24, 16,  6,  0 },
    {     30,   16,   24, 16,  6,  0 }, {     31,   16,   23, 16,  6,  0 }, {     32,   16,   22, 16,  6,  0 }, {     33,   16,   22, 16,  6,  0 }, {     34,   16,   21, 16,  6,  0 },
    {     35,   16,   21, 16,  6,  0 }, {     36,   16,   20, 16,  7,  0 }, {     37,   16,   19, 16,  7,  0 }, {     38,   16,   18, 16,  7,  0 }, {     39,   16,   18, 16,  7,  0 },
    {     40,   16,   17, 16,  7,  0 }, {     41,   16,   16, 16,  7,  0 }, {     42,   16,   15, 16,  7,  0 }, {     43,   16,   14, 16,  7,  0 }, {     44,   16,   13, 16,  7,  0 },
    {     45,   16,   12, 16,  7,  0 }, {     46,   16,   11, 16,  7,  0 }, {     47,   16,   10, 16,  7,  0 }, {     48,   16,    9, 16,  7,  0 }, {     49,   16,    8, 16,  7,  0 },
    {     50,   16,    7, 16,  7,  0 }, {     51,   16,    6, 16,  7,  0 }, {     52,   16,    5, 16,  7,  0 }, {     52,   16,    4, 16,  7,  0 }, {     53,   16,    3, 16,  7,  0 },
    {     54,   16,    2, 16,  7,  0 }, {     55,   16,    1, 16,  8,  0 }, {     55,   16,    0, 16,  8,  0 }, {     56,   16,   -1, 16,  8,  0 }, {     57,   16,   -2, 16,  8,  0 },
    {     58,   16,   -3, 16,  8,  0 }, {     58,   16,   -4, 16,  8,  0 }, {     59,   16,   -5, 16,  8,  0 }, {     60,   16,   -6, 16,  8,  0 }, {     60,   16,   -7, 16,  8,  0 },
    {     61,   16,   -8, 16,  8,  0 }, {     61,   16,   -9, 16,  8,  0 }, {     62,   16,  -10, 16,  8,  0 }, {     62,   16,  -11, 16,  8,  0 }, {     63,   16,  -12, 16,  8,  0 },
    {     64,   16,  -13, 16,  8,  0 }, {     64,   16,  -14, 16,  8,  0 }, {     65,   16,  -15, 16,  8,  0 }, {     65,   16,  -16, 16,  8,  0 }, {     66,   16,  -17, 16,  8,  0 },
    {     66,   16,  -18, 16,  8,  0 }, {     66,   16,  -19, 16,  8,  0 }, {     67,   16,  -20, 16,  8,  0 }, {     67,   16,  -21, 16,  8,  0 }, {     68,   16,  -22, 16,  8,  0 },
    {     68,   16,  -23, 16,  8,  0 }, {     69,   16,  -24, 16, 17,  0 }, {     69,   16,  -25, 16, 17,  0 }, {     69,   16,  -26, 16, 17,  0 }, {     70,   16,  -27, 16, 17,  0 },
    {     70,   16,  -28, 16, 17,  0 }, {     71,   16,  -29, 16, 17,  0 }, {     71,   16,  -30, 16, 17,  0 }, {     71,   16,  -31, 16, 17,  0 }, {     72,   16,  -32, 16, 17,  0 },
    {     72,   16,  -33, 16, 17,  0 }, {     72,   16,  -34, 16, 17,  0 }, {     73,   16,  -35, 16, 17,  0 }, {     73,   16,  -36, 16, 17,  0 }, {     73,   16,  -37, 16, 17,  0 },
    {     73,   16,  -38, 16, 17,  0 }, {     74,   16,  -39, 16, 17,  0 }, {     74,   16,  -40, 16, 17,  0 }, {     74,   16,  -41, 16, 17,  0 }, {     74,   16,  -42, 16, 17,  0 },
    {     75,   16,  -43, 16, 17,  0 }, {     75,   16,  -44, 16, 17,  0 }, {     75,   16,  -45, 16, 17,  0 }, {     75,   16,  -46, 16, 17,  0 }, {     76,   16,  -47, 16, 17,  0 },
    {     76,   16,  -48, 16, 17,  0 }, {     76,   16,  -49, 16, 17,  0 }, {     76,   16,  -50, 16, 17,  0 }, {     76,   16,  -51, 16, 17,  0 }, {     77,   16,  -52, 16, 17,  0 },
    {     77,   16,  -53, 16, 17,  0 }, {     77,   16,  -54, 16, 17,  0 }, {     77,   16,  -55, 16, 17,  0 }, {     77,   16,  -56, 16, 17,  0 }, {     77,   16,  -57, 16, 17,  0 },
    {     78,   16,  -58, 16, 17,  0 }, {     78,   16,  -59, 16, 18,  0 }, {     78,   16,  -60, 16, 18,  0 }, {     78,   16,  -61, 16, 18,  0 }, {     78,   16,  -62, 16, 18,  0 },
    {     78,   16,  -63, 16, 18,  0 }, {     78,   16,  -64, 16, 18,  0 }, {     78,   16,  -65, 16, 18,  0 }, {     78,   16,  -66, 16, 18,  0 }, {     79,   16,  -67, 16, 18,  0 },
    {     79,   16,  -68, 16, 18,  0 }, {     79,   16,  -69, 16, 18,  0 }, {     79,   16,  -70, 16, 18,  0 }, {     79,   16,  -71, 16, 18,  0 }, {     79,   16,  -72, 16, 18,  0 },
    {     79,   16,  -73, 16, 18,  0 }, {     79,   16,  -74, 16, 18,  0 }, {     79,   16,  -75, 16, 18,  0 }, {     79,   16,  -76, 16, 18,  0 }, {     79,   16,  -77, 16, 18,  0 },
    {     79,   16,  -78, 16, 18,  0 }, {     79,   16,  -79, 16, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9783B7, {
    {     16,   31,   32, 24,  0,  0 }, {     16,   30,   32, 24,  0,  0 }, {     16,   29,   32, 24,  0,  0 }, {     16,   28,   32, 24,  0,  0 }, {     16,   27,   32, 24,  0,  0 },
    {     16,   26,   32, 24,  0,  0 }, {     16,   25,   32, 24,  0,  0 }, {     16,   24,   32, 24,  5,  0 }, {     16,   23,   31, 24,  5,  0 }, {     16,   22,   31, 24,  5,  0 },
    {     16,   21,   31, 24,  5,  0 }, {     16,   20,   31, 24,  5,  0 }, {     16,   19,   31, 24,  5,  0 }, {     16,   18,   30, 24,  5,  0 }, {     16,   17,   30, 24,  5,  0 },
    {     16,   16,   30, 24,  5,  0 }, {     16,   15,   30, 24,  6,  0 }, {     16,   14,   29, 24,  6,  0 }, {     16,   13,   29, 24,  6,  0 }, {     16,   12,   29, 24,  6,  0 },
    {     16,   11,   28, 24,  6,  0 }, {     16,   10,   28, 24,  6,  0 }, {     16,    9,   28, 24,  6,  0 }, {     16,    8,   27, 24,  6,  0 }, {     16,    7,   27, 24,  6,  0 },
    {     16,    6,   26, 24,  6,  0 }, {     16,    5,   26, 24,  6,  0 }, {     16,    4,   25, 24,  6,  0 }, {     16,    3,   25, 24,  6,  0 }, {     16,    2,   24, 24,  6,  0 },
    {     16,    1,   24, 24,  6,  0 }, {     16,    0,   23, 24,  6,  0 }, {     16,   -1,   22, 24,  6,  0 }, {     16,   -2,   22, 24,  6,  0 }, {     16,   -3,   21, 24,  6,  0 },
    {     16,   -4,   21, 24,  6,  0 }, {     16,   -5,   20, 24,  7,  0 }, {     16,   -6,   19, 24,  7,  0 }, {     16,   -7,   18, 24,  7,  0 }, {     16,   -8,   18, 24,  7,  0 },
    {     16,   -9,   17, 24,  7,  0 }, {     16,  -10,   16, 24,  7,  0 }, {     16,  -11,   15, 24,  7,  0 }, {     16,  -12,   14, 24,  7,  0 }, {     16,  -13,   13, 24,  7,  0 },
    {     16,  -14,   12, 24,  7,  0 }, {     16,  -15,   11, 24,  7,  0 }, {     16,  -16,   10, 24,  7,  0 }, {     16,  -17,    9, 24,  7,  0 }, {     16,  -18,    8, 24,  7,  0 },
    {     16,  -19,    7, 24,  7,  0 }, {     16,  -20,    6, 24,  7,  0 }, {     16,  -21,    5, 24,  7,  0 }, {     16,  -21,    4, 24,  7,  0 }, {     16,  -22,    3, 24,  7,  0 },
    {     16,  -23,    2, 24,  7,  0 }, {     16,  -24,    1, 24,  8,  0 }, {     16,  -24,    0, 24,  8,  0 }, {     16,  -25,   -1, 24,  8,  0 }, {     16,  -26,   -2, 24,  8,  0 },
    {     16,  -27,   -3, 24,  8,  0 }, {     16,  -27,   -4, 24,  8,  0 }, {     16,  -28,   -5, 24,  8,  0 }, {     16,  -29,   -6, 24,  8,  0 }, {     16,  -29,   -7, 24,  8,  0 },
    {     16,  -30,   -8, 24,  8,  0 }, {     16,  -30,   -9, 24,  8,  0 }, {     16,  -31,  -10, 24,  8,  0 }, {     16,  -31,  -11, 24,  8,  0 }, {     16,  -32,  -12, 24,  8,  0 },
    {     16,  -33,  -13, 24,  8,  0 }, {     16,  -33,  -14, 24,  8,  0 }, {     16,  -34,  -15, 24,  8,  0 }, {     16,  -34,  -16, 24,  8,  0 }, {     16,  -35,  -17, 24,  8,  0 },
    {     16,  -35,  -18, 24,  8,  0 }, {     16,  -35,  -19, 24,  8,  0 }, {     16,  -36,  -20, 24,  8,  0 }, {     16,  -36,  -21, 24,  8,  0 }, {     16,  -37,  -22, 24,  8,  0 },
    {     16,  -37,  -23, 24,  8,  0 }, {     16,  -38,  -24, 24, 17,  0 }, {     16,  -38,  -25, 24, 17,  0 }, {     16,  -38,  -26, 24, 17,  0 }, {     16,  -39,  -27, 24, 17,  0 },
    {     16,  -39,  -28, 24, 17,  0 }, {     16,  -40,  -29, 24, 17,  0 }, {     16,  -40,  -30, 24, 17,  0 }, {     16,  -40,  -31, 24, 17,  0 }, {     16,  -41,  -32, 24, 17,  0 },
    {     16,  -41,  -33, 24, 17,  0 }, {     16,  -41,  -34, 24, 17,  0 }, {     16,  -42,  -35, 24, 17,  0 }, {     16,  -42,  -36, 24, 17,  0 }, {     16,  -42,  -37, 24, 17,  0 },
    {     16,  -42,  -38, 24, 17,  0 }, {     16,  -43,  -39, 24, 17,  0 }, {     16,  -43,  -40, 24, 17,  0 }, {     16,  -43,  -41, 24, 17,  0 }, {     16,  -43,  -42, 24, 17,  0 },
    {     16,  -44,  -43, 24, 17,  0 }, {     16,  -44,  -44, 24, 17,  0 }, {     16,  -44,  -45, 24, 17,  0 }, {     16,  -44,  -46, 24, 17,  0 }, {     16,  -45,  -47, 24, 17,  0 },
    {     16,  -45,  -48, 24, 17,  0 }, {     16,  -45,  -49, 24, 17,  0 }, {     16,  -45,  -50, 24, 17,  0 }, {     16,  -45,  -51, 24, 17,  0 }, {     16,  -46,  -52, 24, 17,  0 },
    {     16,  -46,  -53, 24, 17,  0 }, {     16,  -46,  -54, 24, 17,  0 }, {     16,  -46,  -55, 24, 17,  0 }, {     16,  -46,  -56, 24, 17,  0 }, {     16,  -46,  -57, 24, 17,  0 },
    {     16,  -47,  -58, 24, 17,  0 }, {     16,  -47,  -59, 24, 18,  0 }, {     16,  -47,  -60, 24, 18,  0 }, {     16,  -47,  -61, 24, 18,  0 }, {     16,  -47,  -62, 24, 18,  0 },
    {     16,  -47,  -63, 24, 18,  0 }, {     16,  -47,  -64, 24, 18,  0 }, {     16,  -47,  -65, 24, 18,  0 }, {     16,  -47,  -66, 24, 18,  0 }, {     16,  -48,  -67, 24, 18,  0 },
    {     16,  -48,  -68, 24, 18,  0 }, {     16,  -48,  -69, 24, 18,  0 }, {     16,  -48,  -70, 24, 18,  0 }, {     16,  -48,  -71, 24, 18,  0 }, {     16,  -48,  -72, 24, 18,  0 },
    {     16,  -48,  -73, 24, 18,  0 }, {     16,  -48,  -74, 24, 18,  0 }, {     16,  -48,  -75, 24, 18,  0 }, {     16,  -48,  -76, 24, 18,  0 }, {     16,  -48,  -77, 24, 18,  0 },
    {     16,  -48,  -78, 24, 18,  0 }, {     16,  -48,  -79, 24, 18,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_97888A, {
    {     16,   16,  -32,  0, 10,  0 }, {     16,   16,  -31,  0, 10,  0 }, {     16,   16,  -30,  0, 10,  0 }, {     16,   16,  -29,  0, 10,  0 }, {     16,   16,  -28,  0, 10,  0 },
    {     16,   16,  -27,  0, 10,  0 }, {     16,   16,  -26,  0, 10,  0 }, {     16,   16,  -25,  0, 10,  0 }, {     16,   16,  -24,  0, 10,  0 }, {     16,   16,  -23,  0, 10,  0 },
    {     16,   16,  -22,  0, 10,  0 }, {     16,   16,  -21,  0, 10,  0 }, {     16,   16,  -20,  0, 10,  0 }, {     17,   16,  -19,  0, 10,  0 }, {     17,   16,  -18,  0, 10,  0 },
    {     17,   16,  -17,  0, 10,  0 }, {     17,   16,  -16,  0, 10,  0 }, {     17,   16,  -15,  0, 10,  0 }, {     17,   16,  -14,  0, 10,  0 }, {     17,   16,  -13,  0, 10,  0 },
    {     17,   16,  -12,  0, 10,  0 }, {     17,   16,  -11,  0, 10,  0 }, {     18,   16,  -10,  0, 11,  0 }, {     18,   16,   -9,  0, 11,  0 }, {     18,   16,   -8,  0, 11,  0 },
    {     18,   16,   -7,  0, 11,  0 }, {     18,   16,   -6,  0, 11,  0 }, {     18,   16,   -5,  0, 11,  0 }, {     19,   16,   -4,  0, 11,  0 }, {     19,   16,   -3,  0, 11,  0 },
    {     19,   16,   -2,  0, 11,  0 }, {     19,   16,   -1,  0, 11,  0 }, {     19,   16,    0,  0, 11,  0 }, {     20,   16,    1,  0, 11,  0 }, {     20,   16,    2,  0, 11,  0 },
    {     20,   16,    3,  0, 11,  0 }, {     20,   16,    4,  0, 11,  0 }, {     21,   16,    5,  0, 11,  0 }, {     21,   16,    6,  0, 11,  0 }, {     21,   16,    7,  0, 11,  0 },
    {     21,   16,    8,  0, 11,  0 }, {     22,   16,    9,  0, 11,  0 }, {     22,   16,   10,  0, 11,  0 }, {     22,   16,   11,  0, 11,  0 }, {     22,   16,   12,  0, 11,  0 },
    {     23,   16,   13,  0, 11,  0 }, {     23,   16,   14,  0, 11,  0 }, {     23,   16,   15,  0, 11,  0 }, {     24,   16,   16,  0, 11,  0 }, {     24,   16,   17,  0, 11,  0 },
    {     24,   16,   18,  0, 11,  0 }, {     25,   16,   19,  0, 11,  0 }, {     25,   16,   20,  0, 11,  0 }, {     26,   16,   21,  0, 11,  0 }, {     26,   16,   22,  0, 11,  0 },
    {     26,   16,   23,  0, 11,  0 }, {     27,   16,   24,  0, 12,  0 }, {     27,   16,   25,  0, 12,  0 }, {     28,   16,   26,  0, 12,  0 }, {     28,   16,   27,  0, 12,  0 },
    {     29,   16,   28,  0, 12,  0 }, {     29,   16,   29,  0, 12,  0 }, {     29,   16,   30,  0, 12,  0 }, {     30,   16,   31,  0, 12,  0 }, {     30,   16,   32,  0, 12,  0 },
    {     31,   16,   33,  0, 12,  0 }, {     31,   16,   34,  0, 12,  0 }, {     32,   16,   35,  0, 12,  0 }, {     33,   16,   36,  0, 12,  0 }, {     33,   16,   37,  0, 12,  0 },
    {     34,   16,   38,  0, 12,  0 }, {     34,   16,   39,  0, 12,  0 }, {     35,   16,   40,  0, 12,  0 }, {     35,   16,   41,  0, 12,  0 }, {     36,   16,   42,  0, 12,  0 },
    {     37,   16,   43,  0, 12,  0 }, {     37,   16,   44,  0, 12,  0 }, {     38,   16,   45,  0, 12,  0 }, {     39,   16,   46,  0, 12,  0 }, {     40,   16,   47,  0, 12,  0 },
    {     40,   16,   48,  0, 12,  0 }, {     41,   16,   49,  0, 13,  0 }, {     42,   16,   50,  0, 13,  0 }, {     43,   16,   51,  0, 13,  0 }, {     43,   16,   52,  0, 13,  0 },
    {     44,   16,   53,  0, 13,  0 }, {     45,   16,   54,  0, 13,  0 }, {     46,   16,   55,  0, 13,  0 }, {     47,   16,   56,  0, 13,  0 }, {     48,   16,   57,  0, 13,  0 },
    {     49,   16,   58,  0, 13,  0 }, {     50,   16,   59,  0, 13,  0 }, {     51,   16,   60,  0, 13,  0 }, {     52,   16,   61,  0, 13,  0 }, {     53,   16,   62,  0, 13,  0 },
    {     54,   16,   63,  0, 13,  0 }, {     55,   16,   64,  0, 13,  0 }, {     56,   16,   65,  0, 13,  0 }, {     57,   16,   65,  0, 13,  0 }, {     58,   16,   66,  0, 13,  0 },
    {     59,   16,   67,  0, 13,  0 }, {     60,   16,   68,  0, 14,  0 }, {     61,   16,   68,  0, 14,  0 }, {     62,   16,   69,  0, 14,  0 }, {     63,   16,   69,  0, 14,  0 },
    {     64,   16,   70,  0, 14,  0 }, {     65,   16,   71,  0, 14,  0 }, {     66,   16,   71,  0, 14,  0 }, {     67,   16,   72,  0, 14,  0 }, {     68,   16,   72,  0, 14,  0 },
    {     69,   16,   73,  0, 14,  0 }, {     70,   16,   73,  0, 14,  0 }, {     71,   16,   74,  0, 14,  0 }, {     72,   16,   74,  0, 14,  0 }, {     73,   16,   75,  0, 14,  0 },
    {     74,   16,   75,  0, 14,  0 }, {     75,   16,   75,  0, 14,  0 }, {     76,   16,   76,  0, 15,  0 }, {     77,   16,   76,  0, 15,  0 }, {     78,   16,   76,  0, 15,  0 },
    {     79,   16,   77,  0, 15,  0 }, {     80,   16,   77,  0, 15,  0 }, {     81,   16,   77,  0, 15,  0 }, {     82,   16,   77,  0, 15,  0 }, {     83,   16,   78,  0, 15,  0 },
    {     84,   16,   78,  0, 15,  0 }, {     85,   16,   78,  0, 15,  0 }, {     86,   16,   78,  0, 15,  0 }, {     87,   16,   78,  0, 16,  0 }, {     88,   16,   79,  0, 16,  0 },
    {     89,   16,   79,  0, 16,  0 }, {     90,   16,   79,  0, 16,  0 }, {     91,   16,   79,  0, 16,  0 }, {     92,   16,   79,  0, 16,  0 }, {     93,   16,   79,  0, 16,  0 },
    {     94,   16,   79,  0, 16,  0 }, {     95,   16,   79,  0, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_978D5D, {
    {     16,   16,  -32,  8, 10,  0 }, {     16,   16,  -31,  8, 10,  0 }, {     16,   16,  -30,  8, 10,  0 }, {     16,   16,  -29,  8, 10,  0 }, {     16,   16,  -28,  8, 10,  0 },
    {     16,   16,  -27,  8, 10,  0 }, {     16,   16,  -26,  8, 10,  0 }, {     16,   16,  -25,  8, 10,  0 }, {     16,   16,  -24,  8, 10,  0 }, {     16,   16,  -23,  8, 10,  0 },
    {     16,   16,  -22,  8, 10,  0 }, {     16,   16,  -21,  8, 10,  0 }, {     16,   16,  -20,  8, 10,  0 }, {     16,   15,  -19,  8, 10,  0 }, {     16,   15,  -18,  8, 10,  0 },
    {     16,   15,  -17,  8, 10,  0 }, {     16,   15,  -16,  8, 10,  0 }, {     16,   15,  -15,  8, 10,  0 }, {     16,   15,  -14,  8, 10,  0 }, {     16,   15,  -13,  8, 10,  0 },
    {     16,   15,  -12,  8, 10,  0 }, {     16,   15,  -11,  8, 10,  0 }, {     16,   14,  -10,  8, 11,  0 }, {     16,   14,   -9,  8, 11,  0 }, {     16,   14,   -8,  8, 11,  0 },
    {     16,   14,   -7,  8, 11,  0 }, {     16,   14,   -6,  8, 11,  0 }, {     16,   14,   -5,  8, 11,  0 }, {     16,   13,   -4,  8, 11,  0 }, {     16,   13,   -3,  8, 11,  0 },
    {     16,   13,   -2,  8, 11,  0 }, {     16,   13,   -1,  8, 11,  0 }, {     16,   13,    0,  8, 11,  0 }, {     16,   12,    1,  8, 11,  0 }, {     16,   12,    2,  8, 11,  0 },
    {     16,   12,    3,  8, 11,  0 }, {     16,   12,    4,  8, 11,  0 }, {     16,   11,    5,  8, 11,  0 }, {     16,   11,    6,  8, 11,  0 }, {     16,   11,    7,  8, 11,  0 },
    {     16,   11,    8,  8, 11,  0 }, {     16,   10,    9,  8, 11,  0 }, {     16,   10,   10,  8, 11,  0 }, {     16,   10,   11,  8, 11,  0 }, {     16,   10,   12,  8, 11,  0 },
    {     16,    9,   13,  8, 11,  0 }, {     16,    9,   14,  8, 11,  0 }, {     16,    9,   15,  8, 11,  0 }, {     16,    8,   16,  8, 11,  0 }, {     16,    8,   17,  8, 11,  0 },
    {     16,    8,   18,  8, 11,  0 }, {     16,    7,   19,  8, 11,  0 }, {     16,    7,   20,  8, 11,  0 }, {     16,    6,   21,  8, 11,  0 }, {     16,    6,   22,  8, 11,  0 },
    {     16,    6,   23,  8, 11,  0 }, {     16,    5,   24,  8, 12,  0 }, {     16,    5,   25,  8, 12,  0 }, {     16,    4,   26,  8, 12,  0 }, {     16,    4,   27,  8, 12,  0 },
    {     16,    3,   28,  8, 12,  0 }, {     16,    3,   29,  8, 12,  0 }, {     16,    3,   30,  8, 12,  0 }, {     16,    2,   31,  8, 12,  0 }, {     16,    2,   32,  8, 12,  0 },
    {     16,    1,   33,  8, 12,  0 }, {     16,    1,   34,  8, 12,  0 }, {     16,    0,   35,  8, 12,  0 }, {     16,   -1,   36,  8, 12,  0 }, {     16,   -1,   37,  8, 12,  0 },
    {     16,   -2,   38,  8, 12,  0 }, {     16,   -2,   39,  8, 12,  0 }, {     16,   -3,   40,  8, 12,  0 }, {     16,   -3,   41,  8, 12,  0 }, {     16,   -4,   42,  8, 12,  0 },
    {     16,   -5,   43,  8, 12,  0 }, {     16,   -5,   44,  8, 12,  0 }, {     16,   -6,   45,  8, 12,  0 }, {     16,   -7,   46,  8, 12,  0 }, {     16,   -8,   47,  8, 12,  0 },
    {     16,   -8,   48,  8, 12,  0 }, {     16,   -9,   49,  8, 13,  0 }, {     16,  -10,   50,  8, 13,  0 }, {     16,  -11,   51,  8, 13,  0 }, {     16,  -11,   52,  8, 13,  0 },
    {     16,  -12,   53,  8, 13,  0 }, {     16,  -13,   54,  8, 13,  0 }, {     16,  -14,   55,  8, 13,  0 }, {     16,  -15,   56,  8, 13,  0 }, {     16,  -16,   57,  8, 13,  0 },
    {     16,  -17,   58,  8, 13,  0 }, {     16,  -18,   59,  8, 13,  0 }, {     16,  -19,   60,  8, 13,  0 }, {     16,  -20,   61,  8, 13,  0 }, {     16,  -21,   62,  8, 13,  0 },
    {     16,  -22,   63,  8, 13,  0 }, {     16,  -23,   64,  8, 13,  0 }, {     16,  -24,   65,  8, 13,  0 }, {     16,  -25,   65,  8, 13,  0 }, {     16,  -26,   66,  8, 13,  0 },
    {     16,  -27,   67,  8, 13,  0 }, {     16,  -28,   68,  8, 14,  0 }, {     16,  -29,   68,  8, 14,  0 }, {     16,  -30,   69,  8, 14,  0 }, {     16,  -31,   69,  8, 14,  0 },
    {     16,  -32,   70,  8, 14,  0 }, {     16,  -33,   71,  8, 14,  0 }, {     16,  -34,   71,  8, 14,  0 }, {     16,  -35,   72,  8, 14,  0 }, {     16,  -36,   72,  8, 14,  0 },
    {     16,  -37,   73,  8, 14,  0 }, {     16,  -38,   73,  8, 14,  0 }, {     16,  -39,   74,  8, 14,  0 }, {     16,  -40,   74,  8, 14,  0 }, {     16,  -41,   75,  8, 14,  0 },
    {     16,  -42,   75,  8, 14,  0 }, {     16,  -43,   75,  8, 14,  0 }, {     16,  -44,   76,  8, 15,  0 }, {     16,  -45,   76,  8, 15,  0 }, {     16,  -46,   76,  8, 15,  0 },
    {     16,  -47,   77,  8, 15,  0 }, {     16,  -48,   77,  8, 15,  0 }, {     16,  -49,   77,  8, 15,  0 }, {     16,  -50,   77,  8, 15,  0 }, {     16,  -51,   78,  8, 15,  0 },
    {     16,  -52,   78,  8, 15,  0 }, {     16,  -53,   78,  8, 15,  0 }, {     16,  -54,   78,  8, 15,  0 }, {     16,  -55,   78,  8, 16,  0 }, {     16,  -56,   79,  8, 16,  0 },
    {     16,  -57,   79,  8, 16,  0 }, {     16,  -58,   79,  8, 16,  0 }, {     16,  -59,   79,  8, 16,  0 }, {     16,  -60,   79,  8, 16,  0 }, {     16,  -61,   79,  8, 16,  0 },
    {     16,  -62,   79,  8, 16,  0 }, {     16,  -63,   79,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_979230, {
    {     16,   16,  -32, 16, 10,  0 }, {     16,   16,  -31, 16, 10,  0 }, {     16,   16,  -30, 16, 10,  0 }, {     16,   16,  -29, 16, 10,  0 }, {     16,   16,  -28, 16, 10,  0 },
    {     16,   16,  -27, 16, 10,  0 }, {     16,   16,  -26, 16, 10,  0 }, {     16,   16,  -25, 16, 10,  0 }, {     16,   16,  -24, 16, 10,  0 }, {     16,   16,  -23, 16, 10,  0 },
    {     16,   16,  -22, 16, 10,  0 }, {     16,   16,  -21, 16, 10,  0 }, {     16,   16,  -20, 16, 10,  0 }, {     15,   16,  -19, 16, 10,  0 }, {     15,   16,  -18, 16, 10,  0 },
    {     15,   16,  -17, 16, 10,  0 }, {     15,   16,  -16, 16, 10,  0 }, {     15,   16,  -15, 16, 10,  0 }, {     15,   16,  -14, 16, 10,  0 }, {     15,   16,  -13, 16, 10,  0 },
    {     15,   16,  -12, 16, 10,  0 }, {     15,   16,  -11, 16, 10,  0 }, {     14,   16,  -10, 16, 11,  0 }, {     14,   16,   -9, 16, 11,  0 }, {     14,   16,   -8, 16, 11,  0 },
    {     14,   16,   -7, 16, 11,  0 }, {     14,   16,   -6, 16, 11,  0 }, {     14,   16,   -5, 16, 11,  0 }, {     13,   16,   -4, 16, 11,  0 }, {     13,   16,   -3, 16, 11,  0 },
    {     13,   16,   -2, 16, 11,  0 }, {     13,   16,   -1, 16, 11,  0 }, {     13,   16,    0, 16, 11,  0 }, {     12,   16,    1, 16, 11,  0 }, {     12,   16,    2, 16, 11,  0 },
    {     12,   16,    3, 16, 11,  0 }, {     12,   16,    4, 16, 11,  0 }, {     11,   16,    5, 16, 11,  0 }, {     11,   16,    6, 16, 11,  0 }, {     11,   16,    7, 16, 11,  0 },
    {     11,   16,    8, 16, 11,  0 }, {     10,   16,    9, 16, 11,  0 }, {     10,   16,   10, 16, 11,  0 }, {     10,   16,   11, 16, 11,  0 }, {     10,   16,   12, 16, 11,  0 },
    {      9,   16,   13, 16, 11,  0 }, {      9,   16,   14, 16, 11,  0 }, {      9,   16,   15, 16, 11,  0 }, {      8,   16,   16, 16, 11,  0 }, {      8,   16,   17, 16, 11,  0 },
    {      8,   16,   18, 16, 11,  0 }, {      7,   16,   19, 16, 11,  0 }, {      7,   16,   20, 16, 11,  0 }, {      6,   16,   21, 16, 11,  0 }, {      6,   16,   22, 16, 11,  0 },
    {      6,   16,   23, 16, 11,  0 }, {      5,   16,   24, 16, 12,  0 }, {      5,   16,   25, 16, 12,  0 }, {      4,   16,   26, 16, 12,  0 }, {      4,   16,   27, 16, 12,  0 },
    {      3,   16,   28, 16, 12,  0 }, {      3,   16,   29, 16, 12,  0 }, {      3,   16,   30, 16, 12,  0 }, {      2,   16,   31, 16, 12,  0 }, {      2,   16,   32, 16, 12,  0 },
    {      1,   16,   33, 16, 12,  0 }, {      1,   16,   34, 16, 12,  0 }, {      0,   16,   35, 16, 12,  0 }, {     -1,   16,   36, 16, 12,  0 }, {     -1,   16,   37, 16, 12,  0 },
    {     -2,   16,   38, 16, 12,  0 }, {     -2,   16,   39, 16, 12,  0 }, {     -3,   16,   40, 16, 12,  0 }, {     -3,   16,   41, 16, 12,  0 }, {     -4,   16,   42, 16, 12,  0 },
    {     -5,   16,   43, 16, 12,  0 }, {     -5,   16,   44, 16, 12,  0 }, {     -6,   16,   45, 16, 12,  0 }, {     -7,   16,   46, 16, 12,  0 }, {     -8,   16,   47, 16, 12,  0 },
    {     -8,   16,   48, 16, 12,  0 }, {     -9,   16,   49, 16, 13,  0 }, {    -10,   16,   50, 16, 13,  0 }, {    -11,   16,   51, 16, 13,  0 }, {    -11,   16,   52, 16, 13,  0 },
    {    -12,   16,   53, 16, 13,  0 }, {    -13,   16,   54, 16, 13,  0 }, {    -14,   16,   55, 16, 13,  0 }, {    -15,   16,   56, 16, 13,  0 }, {    -16,   16,   57, 16, 13,  0 },
    {    -17,   16,   58, 16, 13,  0 }, {    -18,   16,   59, 16, 13,  0 }, {    -19,   16,   60, 16, 13,  0 }, {    -20,   16,   61, 16, 13,  0 }, {    -21,   16,   62, 16, 13,  0 },
    {    -22,   16,   63, 16, 13,  0 }, {    -23,   16,   64, 16, 13,  0 }, {    -24,   16,   65, 16, 13,  0 }, {    -25,   16,   65, 16, 13,  0 }, {    -26,   16,   66, 16, 13,  0 },
    {    -27,   16,   67, 16, 13,  0 }, {    -28,   16,   68, 16, 14,  0 }, {    -29,   16,   68, 16, 14,  0 }, {    -30,   16,   69, 16, 14,  0 }, {    -31,   16,   69, 16, 14,  0 },
    {    -32,   16,   70, 16, 14,  0 }, {    -33,   16,   71, 16, 14,  0 }, {    -34,   16,   71, 16, 14,  0 }, {    -35,   16,   72, 16, 14,  0 }, {    -36,   16,   72, 16, 14,  0 },
    {    -37,   16,   73, 16, 14,  0 }, {    -38,   16,   73, 16, 14,  0 }, {    -39,   16,   74, 16, 14,  0 }, {    -40,   16,   74, 16, 14,  0 }, {    -41,   16,   75, 16, 14,  0 },
    {    -42,   16,   75, 16, 14,  0 }, {    -43,   16,   75, 16, 14,  0 }, {    -44,   16,   76, 16, 15,  0 }, {    -45,   16,   76, 16, 15,  0 }, {    -46,   16,   76, 16, 15,  0 },
    {    -47,   16,   77, 16, 15,  0 }, {    -48,   16,   77, 16, 15,  0 }, {    -49,   16,   77, 16, 15,  0 }, {    -50,   16,   77, 16, 15,  0 }, {    -51,   16,   78, 16, 15,  0 },
    {    -52,   16,   78, 16, 15,  0 }, {    -53,   16,   78, 16, 15,  0 }, {    -54,   16,   78, 16, 15,  0 }, {    -55,   16,   78, 16, 16,  0 }, {    -56,   16,   79, 16, 16,  0 },
    {    -57,   16,   79, 16, 16,  0 }, {    -58,   16,   79, 16, 16,  0 }, {    -59,   16,   79, 16, 16,  0 }, {    -60,   16,   79, 16, 16,  0 }, {    -61,   16,   79, 16, 16,  0 },
    {    -62,   16,   79, 16, 16,  0 }, {    -63,   16,   79, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_979703, {
    {     16,   16,  -32, 24, 10,  0 }, {     16,   16,  -31, 24, 10,  0 }, {     16,   16,  -30, 24, 10,  0 }, {     16,   16,  -29, 24, 10,  0 }, {     16,   16,  -28, 24, 10,  0 },
    {     16,   16,  -27, 24, 10,  0 }, {     16,   16,  -26, 24, 10,  0 }, {     16,   16,  -25, 24, 10,  0 }, {     16,   16,  -24, 24, 10,  0 }, {     16,   16,  -23, 24, 10,  0 },
    {     16,   16,  -22, 24, 10,  0 }, {     16,   16,  -21, 24, 10,  0 }, {     16,   16,  -20, 24, 10,  0 }, {     16,   17,  -19, 24, 10,  0 }, {     16,   17,  -18, 24, 10,  0 },
    {     16,   17,  -17, 24, 10,  0 }, {     16,   17,  -16, 24, 10,  0 }, {     16,   17,  -15, 24, 10,  0 }, {     16,   17,  -14, 24, 10,  0 }, {     16,   17,  -13, 24, 10,  0 },
    {     16,   17,  -12, 24, 10,  0 }, {     16,   17,  -11, 24, 10,  0 }, {     16,   18,  -10, 24, 11,  0 }, {     16,   18,   -9, 24, 11,  0 }, {     16,   18,   -8, 24, 11,  0 },
    {     16,   18,   -7, 24, 11,  0 }, {     16,   18,   -6, 24, 11,  0 }, {     16,   18,   -5, 24, 11,  0 }, {     16,   19,   -4, 24, 11,  0 }, {     16,   19,   -3, 24, 11,  0 },
    {     16,   19,   -2, 24, 11,  0 }, {     16,   19,   -1, 24, 11,  0 }, {     16,   19,    0, 24, 11,  0 }, {     16,   20,    1, 24, 11,  0 }, {     16,   20,    2, 24, 11,  0 },
    {     16,   20,    3, 24, 11,  0 }, {     16,   20,    4, 24, 11,  0 }, {     16,   21,    5, 24, 11,  0 }, {     16,   21,    6, 24, 11,  0 }, {     16,   21,    7, 24, 11,  0 },
    {     16,   21,    8, 24, 11,  0 }, {     16,   22,    9, 24, 11,  0 }, {     16,   22,   10, 24, 11,  0 }, {     16,   22,   11, 24, 11,  0 }, {     16,   22,   12, 24, 11,  0 },
    {     16,   23,   13, 24, 11,  0 }, {     16,   23,   14, 24, 11,  0 }, {     16,   23,   15, 24, 11,  0 }, {     16,   24,   16, 24, 11,  0 }, {     16,   24,   17, 24, 11,  0 },
    {     16,   24,   18, 24, 11,  0 }, {     16,   25,   19, 24, 11,  0 }, {     16,   25,   20, 24, 11,  0 }, {     16,   26,   21, 24, 11,  0 }, {     16,   26,   22, 24, 11,  0 },
    {     16,   26,   23, 24, 11,  0 }, {     16,   27,   24, 24, 12,  0 }, {     16,   27,   25, 24, 12,  0 }, {     16,   28,   26, 24, 12,  0 }, {     16,   28,   27, 24, 12,  0 },
    {     16,   29,   28, 24, 12,  0 }, {     16,   29,   29, 24, 12,  0 }, {     16,   29,   30, 24, 12,  0 }, {     16,   30,   31, 24, 12,  0 }, {     16,   30,   32, 24, 12,  0 },
    {     16,   31,   33, 24, 12,  0 }, {     16,   31,   34, 24, 12,  0 }, {     16,   32,   35, 24, 12,  0 }, {     16,   33,   36, 24, 12,  0 }, {     16,   33,   37, 24, 12,  0 },
    {     16,   34,   38, 24, 12,  0 }, {     16,   34,   39, 24, 12,  0 }, {     16,   35,   40, 24, 12,  0 }, {     16,   35,   41, 24, 12,  0 }, {     16,   36,   42, 24, 12,  0 },
    {     16,   37,   43, 24, 12,  0 }, {     16,   37,   44, 24, 12,  0 }, {     16,   38,   45, 24, 12,  0 }, {     16,   39,   46, 24, 12,  0 }, {     16,   40,   47, 24, 12,  0 },
    {     16,   40,   48, 24, 12,  0 }, {     16,   41,   49, 24, 13,  0 }, {     16,   42,   50, 24, 13,  0 }, {     16,   43,   51, 24, 13,  0 }, {     16,   43,   52, 24, 13,  0 },
    {     16,   44,   53, 24, 13,  0 }, {     16,   45,   54, 24, 13,  0 }, {     16,   46,   55, 24, 13,  0 }, {     16,   47,   56, 24, 13,  0 }, {     16,   48,   57, 24, 13,  0 },
    {     16,   49,   58, 24, 13,  0 }, {     16,   50,   59, 24, 13,  0 }, {     16,   51,   60, 24, 13,  0 }, {     16,   52,   61, 24, 13,  0 }, {     16,   53,   62, 24, 13,  0 },
    {     16,   54,   63, 24, 13,  0 }, {     16,   55,   64, 24, 13,  0 }, {     16,   56,   65, 24, 13,  0 }, {     16,   57,   65, 24, 13,  0 }, {     16,   58,   66, 24, 13,  0 },
    {     16,   59,   67, 24, 13,  0 }, {     16,   60,   68, 24, 14,  0 }, {     16,   61,   68, 24, 14,  0 }, {     16,   62,   69, 24, 14,  0 }, {     16,   63,   69, 24, 14,  0 },
    {     16,   64,   70, 24, 14,  0 }, {     16,   65,   71, 24, 14,  0 }, {     16,   66,   71, 24, 14,  0 }, {     16,   67,   72, 24, 14,  0 }, {     16,   68,   72, 24, 14,  0 },
    {     16,   69,   73, 24, 14,  0 }, {     16,   70,   73, 24, 14,  0 }, {     16,   71,   74, 24, 14,  0 }, {     16,   72,   74, 24, 14,  0 }, {     16,   73,   75, 24, 14,  0 },
    {     16,   74,   75, 24, 14,  0 }, {     16,   75,   75, 24, 14,  0 }, {     16,   76,   76, 24, 15,  0 }, {     16,   77,   76, 24, 15,  0 }, {     16,   78,   76, 24, 15,  0 },
    {     16,   79,   77, 24, 15,  0 }, {     16,   80,   77, 24, 15,  0 }, {     16,   81,   77, 24, 15,  0 }, {     16,   82,   77, 24, 15,  0 }, {     16,   83,   78, 24, 15,  0 },
    {     16,   84,   78, 24, 15,  0 }, {     16,   85,   78, 24, 15,  0 }, {     16,   86,   78, 24, 15,  0 }, {     16,   87,   78, 24, 16,  0 }, {     16,   88,   79, 24, 16,  0 },
    {     16,   89,   79, 24, 16,  0 }, {     16,   90,   79, 24, 16,  0 }, {     16,   91,   79, 24, 16,  0 }, {     16,   92,   79, 24, 16,  0 }, {     16,   93,   79, 24, 16,  0 },
    {     16,   94,   79, 24, 16,  0 }, {     16,   95,   79, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CDBE2, {
    {     31,    6,    0,  0,  0,  0 }, {     30,    6,    0,  0,  0,  0 }, {     29,    6,    0,  0,  0,  0 }, {     28,    6,    0,  0,  0,  0 }, {     27,    6,    0,  0,  0,  0 },
    {     26,    6,    0,  0,  0,  0 }, {     25,    6,    0,  0,  0,  0 }, {     24,    6,    0,  0,  0,  0 }, {     23,    6,    0,  0,  0,  0 }, {     22,    6,    0,  0,  0,  0 },
    {     21,    6,    0,  0,  0,  0 }, {     20,    6,    0,  0,  0,  0 }, {     19,    6,    0,  0,  0,  0 }, {     18,    6,    0,  0,  0,  0 }, {     17,    6,    0,  0,  0,  0 },
    {     16,    6,    0,  0,  0,  0 }, {     15,    6,    0,  0,  0,  0 }, {     14,    6,    0,  0,  0,  0 }, {     13,    6,    0,  0,  0,  0 }, {     12,    6,    0,  0,  0,  0 },
    {     11,    6,    0,  0,  0,  0 }, {     10,    6,    0,  0,  0,  0 }, {      9,    6,    0,  0,  0,  0 }, {      8,    6,    0,  0,  0,  0 }, {      7,    6,    0,  0,  0,  0 },
    {      6,    6,    0,  0,  0,  0 }, {      5,    6,    0,  0,  0,  0 }, {      4,    6,    0,  0,  0,  0 }, {      3,    6,    0,  0,  0,  0 }, {      2,    6,    0,  0,  0,  0 },
    {      1,    6,    0,  0,  0,  0 }, {      0,    6,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CDD04, {
    {      6,    0,    0,  8,  0,  0 }, {      6,    1,    0,  8,  0,  0 }, {      6,    2,    0,  8,  0,  0 }, {      6,    3,    0,  8,  0,  0 }, {      6,    4,    0,  8,  0,  0 },
    {      6,    5,    0,  8,  0,  0 }, {      6,    6,    0,  8,  0,  0 }, {      6,    7,    0,  8,  0,  0 }, {      6,    8,    0,  8,  0,  0 }, {      6,    9,    0,  8,  0,  0 },
    {      6,   10,    0,  8,  0,  0 }, {      6,   11,    0,  8,  0,  0 }, {      6,   12,    0,  8,  0,  0 }, {      6,   13,    0,  8,  0,  0 }, {      6,   14,    0,  8,  0,  0 },
    {      6,   15,    0,  8,  0,  0 }, {      6,   16,    0,  8,  0,  0 }, {      6,   17,    0,  8,  0,  0 }, {      6,   18,    0,  8,  0,  0 }, {      6,   19,    0,  8,  0,  0 },
    {      6,   20,    0,  8,  0,  0 }, {      6,   21,    0,  8,  0,  0 }, {      6,   22,    0,  8,  0,  0 }, {      6,   23,    0,  8,  0,  0 }, {      6,   24,    0,  8,  0,  0 },
    {      6,   25,    0,  8,  0,  0 }, {      6,   26,    0,  8,  0,  0 }, {      6,   27,    0,  8,  0,  0 }, {      6,   28,    0,  8,  0,  0 }, {      6,   29,    0,  8,  0,  0 },
    {      6,   30,    0,  8,  0,  0 }, {      6,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CDE26, {
    {      0,   26,    0, 16,  0,  0 }, {      1,   26,    0, 16,  0,  0 }, {      2,   26,    0, 16,  0,  0 }, {      3,   26,    0, 16,  0,  0 }, {      4,   26,    0, 16,  0,  0 },
    {      5,   26,    0, 16,  0,  0 }, {      6,   26,    0, 16,  0,  0 }, {      7,   26,    0, 16,  0,  0 }, {      8,   26,    0, 16,  0,  0 }, {      9,   26,    0, 16,  0,  0 },
    {     10,   26,    0, 16,  0,  0 }, {     11,   26,    0, 16,  0,  0 }, {     12,   26,    0, 16,  0,  0 }, {     13,   26,    0, 16,  0,  0 }, {     14,   26,    0, 16,  0,  0 },
    {     15,   26,    0, 16,  0,  0 }, {     16,   26,    0, 16,  0,  0 }, {     17,   26,    0, 16,  0,  0 }, {     18,   26,    0, 16,  0,  0 }, {     19,   26,    0, 16,  0,  0 },
    {     20,   26,    0, 16,  0,  0 }, {     21,   26,    0, 16,  0,  0 }, {     22,   26,    0, 16,  0,  0 }, {     23,   26,    0, 16,  0,  0 }, {     24,   26,    0, 16,  0,  0 },
    {     25,   26,    0, 16,  0,  0 }, {     26,   26,    0, 16,  0,  0 }, {     27,   26,    0, 16,  0,  0 }, {     28,   26,    0, 16,  0,  0 }, {     29,   26,    0, 16,  0,  0 },
    {     30,   26,    0, 16,  0,  0 }, {     31,   26,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CDF48, {
    {     26,   31,    0, 24,  0,  0 }, {     26,   30,    0, 24,  0,  0 }, {     26,   29,    0, 24,  0,  0 }, {     26,   28,    0, 24,  0,  0 }, {     26,   27,    0, 24,  0,  0 },
    {     26,   26,    0, 24,  0,  0 }, {     26,   25,    0, 24,  0,  0 }, {     26,   24,    0, 24,  0,  0 }, {     26,   23,    0, 24,  0,  0 }, {     26,   22,    0, 24,  0,  0 },
    {     26,   21,    0, 24,  0,  0 }, {     26,   20,    0, 24,  0,  0 }, {     26,   19,    0, 24,  0,  0 }, {     26,   18,    0, 24,  0,  0 }, {     26,   17,    0, 24,  0,  0 },
    {     26,   16,    0, 24,  0,  0 }, {     26,   15,    0, 24,  0,  0 }, {     26,   14,    0, 24,  0,  0 }, {     26,   13,    0, 24,  0,  0 }, {     26,   12,    0, 24,  0,  0 },
    {     26,   11,    0, 24,  0,  0 }, {     26,   10,    0, 24,  0,  0 }, {     26,    9,    0, 24,  0,  0 }, {     26,    8,    0, 24,  0,  0 }, {     26,    7,    0, 24,  0,  0 },
    {     26,    6,    0, 24,  0,  0 }, {     26,    5,    0, 24,  0,  0 }, {     26,    4,    0, 24,  0,  0 }, {     26,    3,    0, 24,  0,  0 }, {     26,    2,    0, 24,  0,  0 },
    {     26,    1,    0, 24,  0,  0 }, {     26,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CFB6E, {
    {     31,    6,    0,  0,  2,  0 }, {     30,    6,    1,  0,  2,  0 }, {     29,    6,    1,  0,  2,  0 }, {     28,    6,    2,  0,  2,  0 }, {     27,    6,    2,  0,  2,  0 },
    {     26,    6,    3,  0,  2,  0 }, {     25,    6,    3,  0,  2,  0 }, {     24,    6,    4,  0,  2,  0 }, {     23,    6,    4,  0,  2,  0 }, {     22,    6,    5,  0,  2,  0 },
    {     21,    6,    5,  0,  2,  0 }, {     20,    6,    6,  0,  2,  0 }, {     19,    6,    6,  0,  2,  0 }, {     18,    6,    7,  0,  2,  0 }, {     17,    6,    7,  0,  2,  0 },
    {     16,    6,    8,  0,  2,  0 }, {     15,    6,    8,  0,  2,  0 }, {     14,    6,    9,  0,  2,  0 }, {     13,    6,    9,  0,  2,  0 }, {     12,    6,   10,  0,  2,  0 },
    {     11,    6,   10,  0,  2,  0 }, {     10,    6,   11,  0,  2,  0 }, {      9,    6,   11,  0,  2,  0 }, {      8,    6,   12,  0,  2,  0 }, {      7,    6,   12,  0,  2,  0 },
    {      6,    6,   13,  0,  2,  0 }, {      5,    6,   13,  0,  2,  0 }, {      4,    6,   14,  0,  2,  0 }, {      3,    6,   14,  0,  2,  0 }, {      2,    6,   15,  0,  2,  0 },
    {      1,    6,   15,  0,  2,  0 }, {      0,    6,   16,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CFC90, {
    {      6,    0,    0,  8,  2,  0 }, {      6,    1,    0,  8,  2,  0 }, {      6,    2,    1,  8,  2,  0 }, {      6,    3,    1,  8,  2,  0 }, {      6,    4,    2,  8,  2,  0 },
    {      6,    5,    2,  8,  2,  0 }, {      6,    6,    3,  8,  2,  0 }, {      6,    7,    3,  8,  2,  0 }, {      6,    8,    4,  8,  2,  0 }, {      6,    9,    4,  8,  2,  0 },
    {      6,   10,    5,  8,  2,  0 }, {      6,   11,    5,  8,  2,  0 }, {      6,   12,    6,  8,  2,  0 }, {      6,   13,    6,  8,  2,  0 }, {      6,   14,    7,  8,  2,  0 },
    {      6,   15,    7,  8,  2,  0 }, {      6,   16,    8,  8,  2,  0 }, {      6,   17,    8,  8,  2,  0 }, {      6,   18,    9,  8,  2,  0 }, {      6,   19,    9,  8,  2,  0 },
    {      6,   20,   10,  8,  2,  0 }, {      6,   21,   10,  8,  2,  0 }, {      6,   22,   11,  8,  2,  0 }, {      6,   23,   11,  8,  2,  0 }, {      6,   24,   12,  8,  2,  0 },
    {      6,   25,   12,  8,  2,  0 }, {      6,   26,   13,  8,  2,  0 }, {      6,   27,   13,  8,  2,  0 }, {      6,   28,   14,  8,  2,  0 }, {      6,   29,   14,  8,  2,  0 },
    {      6,   30,   15,  8,  2,  0 }, {      6,   31,   15,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CFDB2, {
    {      0,   26,    0, 16,  2,  0 }, {      1,   26,    0, 16,  2,  0 }, {      2,   26,    1, 16,  2,  0 }, {      3,   26,    1, 16,  2,  0 }, {      4,   26,    2, 16,  2,  0 },
    {      5,   26,    2, 16,  2,  0 }, {      6,   26,    3, 16,  2,  0 }, {      7,   26,    3, 16,  2,  0 }, {      8,   26,    4, 16,  2,  0 }, {      9,   26,    4, 16,  2,  0 },
    {     10,   26,    5, 16,  2,  0 }, {     11,   26,    5, 16,  2,  0 }, {     12,   26,    6, 16,  2,  0 }, {     13,   26,    6, 16,  2,  0 }, {     14,   26,    7, 16,  2,  0 },
    {     15,   26,    7, 16,  2,  0 }, {     16,   26,    8, 16,  2,  0 }, {     17,   26,    8, 16,  2,  0 }, {     18,   26,    9, 16,  2,  0 }, {     19,   26,    9, 16,  2,  0 },
    {     20,   26,   10, 16,  2,  0 }, {     21,   26,   10, 16,  2,  0 }, {     22,   26,   11, 16,  2,  0 }, {     23,   26,   11, 16,  2,  0 }, {     24,   26,   12, 16,  2,  0 },
    {     25,   26,   12, 16,  2,  0 }, {     26,   26,   13, 16,  2,  0 }, {     27,   26,   13, 16,  2,  0 }, {     28,   26,   14, 16,  2,  0 }, {     29,   26,   14, 16,  2,  0 },
    {     30,   26,   15, 16,  2,  0 }, {     31,   26,   15, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CFED4, {
    {     26,   31,    0, 24,  2,  0 }, {     26,   30,    1, 24,  2,  0 }, {     26,   29,    1, 24,  2,  0 }, {     26,   28,    2, 24,  2,  0 }, {     26,   27,    2, 24,  2,  0 },
    {     26,   26,    3, 24,  2,  0 }, {     26,   25,    3, 24,  2,  0 }, {     26,   24,    4, 24,  2,  0 }, {     26,   23,    4, 24,  2,  0 }, {     26,   22,    5, 24,  2,  0 },
    {     26,   21,    5, 24,  2,  0 }, {     26,   20,    6, 24,  2,  0 }, {     26,   19,    6, 24,  2,  0 }, {     26,   18,    7, 24,  2,  0 }, {     26,   17,    7, 24,  2,  0 },
    {     26,   16,    8, 24,  2,  0 }, {     26,   15,    8, 24,  2,  0 }, {     26,   14,    9, 24,  2,  0 }, {     26,   13,    9, 24,  2,  0 }, {     26,   12,   10, 24,  2,  0 },
    {     26,   11,   10, 24,  2,  0 }, {     26,   10,   11, 24,  2,  0 }, {     26,    9,   11, 24,  2,  0 }, {     26,    8,   12, 24,  2,  0 }, {     26,    7,   12, 24,  2,  0 },
    {     26,    6,   13, 24,  2,  0 }, {     26,    5,   13, 24,  2,  0 }, {     26,    4,   14, 24,  2,  0 }, {     26,    3,   14, 24,  2,  0 }, {     26,    2,   15, 24,  2,  0 },
    {     26,    1,   15, 24,  2,  0 }, {     26,    0,   16, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CE906, {
    {     31,    6,    0,  0,  0,  0 }, {     30,    6,    0,  0,  0,  0 }, {     29,    6,    0,  0,  0,  0 }, {     28,    6,    0,  0,  0,  0 }, {     27,    6,    0,  0,  0,  0 },
    {     26,    6,    0,  0,  0,  0 }, {     25,    6,    0,  0,  0,  0 }, {     24,    6,    0,  0,  0,  0 }, {     23,    6,    0,  0,  1,  0 }, {     22,    6,    0,  0,  1,  0 },
    {     21,    6,    1,  0,  1,  0 }, {     20,    6,    1,  0,  1,  0 }, {     19,    6,    1,  0,  1,  0 }, {     18,    6,    1,  0,  1,  0 }, {     17,    6,    1,  0,  1,  0 },
    {     16,    6,    1,  0,  1,  0 }, {     15,    6,    2,  0,  1,  0 }, {     14,    6,    2,  0,  1,  0 }, {     13,    6,    2,  0,  1,  0 }, {     12,    6,    2,  0,  1,  0 },
    {     11,    6,    3,  0,  1,  0 }, {     10,    6,    3,  0,  1,  0 }, {      9,    6,    3,  0,  1,  0 }, {      8,    6,    4,  0,  1,  0 }, {      7,    6,    4,  0,  2,  0 },
    {      6,    6,    5,  0,  2,  0 }, {      5,    6,    5,  0,  2,  0 }, {      4,    6,    6,  0,  2,  0 }, {      3,    6,    6,  0,  2,  0 }, {      2,    6,    7,  0,  2,  0 },
    {      1,    6,    7,  0,  2,  0 }, {      0,    6,    8,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CEA28, {
    {      6,    0,    0,  8,  0,  0 }, {      6,    1,    0,  8,  0,  0 }, {      6,    2,    0,  8,  0,  0 }, {      6,    3,    0,  8,  0,  0 }, {      6,    4,    0,  8,  0,  0 },
    {      6,    5,    0,  8,  0,  0 }, {      6,    6,    0,  8,  0,  0 }, {      6,    7,    0,  8,  0,  0 }, {      6,    8,    0,  8,  1,  0 }, {      6,    9,    0,  8,  1,  0 },
    {      6,   10,    1,  8,  1,  0 }, {      6,   11,    1,  8,  1,  0 }, {      6,   12,    1,  8,  1,  0 }, {      6,   13,    1,  8,  1,  0 }, {      6,   14,    1,  8,  1,  0 },
    {      6,   15,    1,  8,  1,  0 }, {      6,   16,    2,  8,  1,  0 }, {      6,   17,    2,  8,  1,  0 }, {      6,   18,    2,  8,  1,  0 }, {      6,   19,    2,  8,  1,  0 },
    {      6,   20,    3,  8,  1,  0 }, {      6,   21,    3,  8,  1,  0 }, {      6,   22,    3,  8,  1,  0 }, {      6,   23,    4,  8,  1,  0 }, {      6,   24,    4,  8,  2,  0 },
    {      6,   25,    4,  8,  2,  0 }, {      6,   26,    5,  8,  2,  0 }, {      6,   27,    5,  8,  2,  0 }, {      6,   28,    6,  8,  2,  0 }, {      6,   29,    6,  8,  2,  0 },
    {      6,   30,    7,  8,  2,  0 }, {      6,   31,    7,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CEB4A, {
    {      0,   26,    0, 16,  0,  0 }, {      1,   26,    0, 16,  0,  0 }, {      2,   26,    0, 16,  0,  0 }, {      3,   26,    0, 16,  0,  0 }, {      4,   26,    0, 16,  0,  0 },
    {      5,   26,    0, 16,  0,  0 }, {      6,   26,    0, 16,  0,  0 }, {      7,   26,    0, 16,  0,  0 }, {      8,   26,    0, 16,  1,  0 }, {      9,   26,    0, 16,  1,  0 },
    {     10,   26,    1, 16,  1,  0 }, {     11,   26,    1, 16,  1,  0 }, {     12,   26,    1, 16,  1,  0 }, {     13,   26,    1, 16,  1,  0 }, {     14,   26,    1, 16,  1,  0 },
    {     15,   26,    1, 16,  1,  0 }, {     16,   26,    2, 16,  1,  0 }, {     17,   26,    2, 16,  1,  0 }, {     18,   26,    2, 16,  1,  0 }, {     19,   26,    2, 16,  1,  0 },
    {     20,   26,    3, 16,  1,  0 }, {     21,   26,    3, 16,  1,  0 }, {     22,   26,    3, 16,  1,  0 }, {     23,   26,    4, 16,  1,  0 }, {     24,   26,    4, 16,  2,  0 },
    {     25,   26,    4, 16,  2,  0 }, {     26,   26,    5, 16,  2,  0 }, {     27,   26,    5, 16,  2,  0 }, {     28,   26,    6, 16,  2,  0 }, {     29,   26,    6, 16,  2,  0 },
    {     30,   26,    7, 16,  2,  0 }, {     31,   26,    7, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CEC6C, {
    {     26,   31,    0, 24,  0,  0 }, {     26,   30,    0, 24,  0,  0 }, {     26,   29,    0, 24,  0,  0 }, {     26,   28,    0, 24,  0,  0 }, {     26,   27,    0, 24,  0,  0 },
    {     26,   26,    0, 24,  0,  0 }, {     26,   25,    0, 24,  0,  0 }, {     26,   24,    0, 24,  0,  0 }, {     26,   23,    0, 24,  1,  0 }, {     26,   22,    0, 24,  1,  0 },
    {     26,   21,    1, 24,  1,  0 }, {     26,   20,    1, 24,  1,  0 }, {     26,   19,    1, 24,  1,  0 }, {     26,   18,    1, 24,  1,  0 }, {     26,   17,    1, 24,  1,  0 },
    {     26,   16,    1, 24,  1,  0 }, {     26,   15,    2, 24,  1,  0 }, {     26,   14,    2, 24,  1,  0 }, {     26,   13,    2, 24,  1,  0 }, {     26,   12,    2, 24,  1,  0 },
    {     26,   11,    3, 24,  1,  0 }, {     26,   10,    3, 24,  1,  0 }, {     26,    9,    3, 24,  1,  0 }, {     26,    8,    4, 24,  1,  0 }, {     26,    7,    4, 24,  2,  0 },
    {     26,    6,    5, 24,  2,  0 }, {     26,    5,    5, 24,  2,  0 }, {     26,    4,    6, 24,  2,  0 }, {     26,    3,    6, 24,  2,  0 }, {     26,    2,    7, 24,  2,  0 },
    {     26,    1,    7, 24,  2,  0 }, {     26,    0,    8, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CED8E, {
    {     31,    6,    0,  0,  2,  0 }, {     30,    6,    1,  0,  2,  0 }, {     29,    6,    1,  0,  2,  0 }, {     28,    6,    2,  0,  2,  0 }, {     27,    6,    2,  0,  2,  0 },
    {     26,    6,    3,  0,  2,  0 }, {     25,    6,    3,  0,  2,  0 }, {     24,    6,    3,  0,  2,  0 }, {     23,    6,    4,  0,  1,  0 }, {     22,    6,    4,  0,  1,  0 },
    {     21,    6,    4,  0,  1,  0 }, {     20,    6,    5,  0,  1,  0 }, {     19,    6,    5,  0,  1,  0 }, {     18,    6,    5,  0,  1,  0 }, {     17,    6,    6,  0,  1,  0 },
    {     16,    6,    6,  0,  1,  0 }, {     15,    6,    6,  0,  1,  0 }, {     14,    6,    6,  0,  1,  0 }, {     13,    6,    7,  0,  1,  0 }, {     12,    6,    7,  0,  1,  0 },
    {     11,    6,    7,  0,  1,  0 }, {     10,    6,    7,  0,  1,  0 }, {      9,    6,    7,  0,  0,  0 }, {      8,    6,    7,  0,  0,  0 }, {      7,    6,    8,  0,  0,  0 },
    {      6,    6,    8,  0,  0,  0 }, {      5,    6,    8,  0,  0,  0 }, {      4,    6,    8,  0,  0,  0 }, {      3,    6,    8,  0,  0,  0 }, {      2,    6,    8,  0,  0,  0 },
    {      1,    6,    8,  0,  0,  0 }, {      0,    6,    8,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CEEC2, {
    {      6,    0,    0,  8,  2,  0 }, {      6,    1,    0,  8,  2,  0 }, {      6,    2,    1,  8,  2,  0 }, {      6,    3,    1,  8,  2,  0 }, {      6,    4,    2,  8,  2,  0 },
    {      6,    5,    2,  8,  2,  0 }, {      6,    6,    3,  8,  2,  0 }, {      6,    7,    3,  8,  2,  0 }, {      6,    8,    4,  8,  1,  0 }, {      6,    9,    4,  8,  1,  0 },
    {      6,   10,    4,  8,  1,  0 }, {      6,   11,    5,  8,  1,  0 }, {      6,   12,    5,  8,  1,  0 }, {      6,   13,    5,  8,  1,  0 }, {      6,   14,    6,  8,  1,  0 },
    {      6,   15,    6,  8,  1,  0 }, {      6,   16,    6,  8,  1,  0 }, {      6,   17,    6,  8,  1,  0 }, {      6,   18,    7,  8,  1,  0 }, {      6,   19,    7,  8,  1,  0 },
    {      6,   20,    7,  8,  1,  0 }, {      6,   21,    7,  8,  1,  0 }, {      6,   22,    7,  8,  0,  0 }, {      6,   23,    7,  8,  0,  0 }, {      6,   24,    8,  8,  0,  0 },
    {      6,   25,    8,  8,  0,  0 }, {      6,   26,    8,  8,  0,  0 }, {      6,   27,    8,  8,  0,  0 }, {      6,   28,    8,  8,  0,  0 }, {      6,   29,    8,  8,  0,  0 },
    {      6,   30,    8,  8,  0,  0 }, {      6,   31,    8,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CEFF6, {
    {      0,   26,    0, 16,  2,  0 }, {      1,   26,    0, 16,  2,  0 }, {      2,   26,    1, 16,  2,  0 }, {      3,   26,    1, 16,  2,  0 }, {      4,   26,    2, 16,  2,  0 },
    {      5,   26,    2, 16,  2,  0 }, {      6,   26,    3, 16,  2,  0 }, {      7,   26,    3, 16,  2,  0 }, {      8,   26,    4, 16,  1,  0 }, {      9,   26,    4, 16,  1,  0 },
    {     10,   26,    4, 16,  1,  0 }, {     11,   26,    5, 16,  1,  0 }, {     12,   26,    5, 16,  1,  0 }, {     13,   26,    5, 16,  1,  0 }, {     14,   26,    6, 16,  1,  0 },
    {     15,   26,    6, 16,  1,  0 }, {     16,   26,    6, 16,  1,  0 }, {     17,   26,    6, 16,  1,  0 }, {     18,   26,    7, 16,  1,  0 }, {     19,   26,    7, 16,  1,  0 },
    {     20,   26,    7, 16,  1,  0 }, {     21,   26,    7, 16,  1,  0 }, {     22,   26,    7, 16,  0,  0 }, {     23,   26,    7, 16,  0,  0 }, {     24,   26,    8, 16,  0,  0 },
    {     25,   26,    8, 16,  0,  0 }, {     26,   26,    8, 16,  0,  0 }, {     27,   26,    8, 16,  0,  0 }, {     28,   26,    8, 16,  0,  0 }, {     29,   26,    8, 16,  0,  0 },
    {     30,   26,    8, 16,  0,  0 }, {     31,   26,    8, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CF12A, {
    {     26,   31,    0, 24,  2,  0 }, {     26,   30,    1, 24,  2,  0 }, {     26,   29,    1, 24,  2,  0 }, {     26,   28,    2, 24,  2,  0 }, {     26,   27,    2, 24,  2,  0 },
    {     26,   26,    3, 24,  2,  0 }, {     26,   25,    3, 24,  2,  0 }, {     26,   24,    3, 24,  2,  0 }, {     26,   23,    4, 24,  1,  0 }, {     26,   22,    4, 24,  1,  0 },
    {     26,   21,    4, 24,  1,  0 }, {     26,   20,    5, 24,  1,  0 }, {     26,   19,    5, 24,  1,  0 }, {     26,   18,    5, 24,  1,  0 }, {     26,   17,    6, 24,  1,  0 },
    {     26,   16,    6, 24,  1,  0 }, {     26,   15,    6, 24,  1,  0 }, {     26,   14,    6, 24,  1,  0 }, {     26,   13,    7, 24,  1,  0 }, {     26,   12,    7, 24,  1,  0 },
    {     26,   11,    7, 24,  1,  0 }, {     26,   10,    7, 24,  1,  0 }, {     26,    9,    7, 24,  0,  0 }, {     26,    8,    7, 24,  0,  0 }, {     26,    7,    8, 24,  0,  0 },
    {     26,    6,    8, 24,  0,  0 }, {     26,    5,    8, 24,  0,  0 }, {     26,    4,    8, 24,  0,  0 }, {     26,    3,    8, 24,  0,  0 }, {     26,    2,    8, 24,  0,  0 },
    {     26,    1,    8, 24,  0,  0 }, {     26,    0,    8, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CFFF6, {
    {     31,    6,   15,  0,  6,  0 }, {     30,    6,   15,  0,  6,  0 }, {     29,    6,   14,  0,  6,  0 }, {     28,    6,   14,  0,  6,  0 }, {     27,    6,   13,  0,  6,  0 },
    {     26,    6,   13,  0,  6,  0 }, {     25,    6,   12,  0,  6,  0 }, {     24,    6,   12,  0,  6,  0 }, {     23,    6,   11,  0,  6,  0 }, {     22,    6,   11,  0,  6,  0 },
    {     21,    6,   10,  0,  6,  0 }, {     20,    6,   10,  0,  6,  0 }, {     19,    6,    9,  0,  6,  0 }, {     18,    6,    9,  0,  6,  0 }, {     17,    6,    8,  0,  6,  0 },
    {     16,    6,    8,  0,  6,  0 }, {     15,    6,    7,  0,  6,  0 }, {     14,    6,    7,  0,  6,  0 }, {     13,    6,    6,  0,  6,  0 }, {     12,    6,    6,  0,  6,  0 },
    {     11,    6,    5,  0,  6,  0 }, {     10,    6,    5,  0,  6,  0 }, {      9,    6,    4,  0,  6,  0 }, {      8,    6,    4,  0,  6,  0 }, {      7,    6,    3,  0,  6,  0 },
    {      6,    6,    3,  0,  6,  0 }, {      5,    6,    2,  0,  6,  0 }, {      4,    6,    2,  0,  6,  0 }, {      3,    6,    1,  0,  6,  0 }, {      2,    6,    1,  0,  6,  0 },
    {      1,    6,    0,  0,  6,  0 }, {      0,    6,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D0118, {
    {      6,    0,   15,  8,  6,  0 }, {      6,    1,   14,  8,  6,  0 }, {      6,    2,   14,  8,  6,  0 }, {      6,    3,   13,  8,  6,  0 }, {      6,    4,   13,  8,  6,  0 },
    {      6,    5,   12,  8,  6,  0 }, {      6,    6,   12,  8,  6,  0 }, {      6,    7,   11,  8,  6,  0 }, {      6,    8,   11,  8,  6,  0 }, {      6,    9,   10,  8,  6,  0 },
    {      6,   10,   10,  8,  6,  0 }, {      6,   11,    9,  8,  6,  0 }, {      6,   12,    9,  8,  6,  0 }, {      6,   13,    8,  8,  6,  0 }, {      6,   14,    8,  8,  6,  0 },
    {      6,   15,    7,  8,  6,  0 }, {      6,   16,    7,  8,  6,  0 }, {      6,   17,    6,  8,  6,  0 }, {      6,   18,    6,  8,  6,  0 }, {      6,   19,    5,  8,  6,  0 },
    {      6,   20,    5,  8,  6,  0 }, {      6,   21,    4,  8,  6,  0 }, {      6,   22,    4,  8,  6,  0 }, {      6,   23,    3,  8,  6,  0 }, {      6,   24,    3,  8,  6,  0 },
    {      6,   25,    2,  8,  6,  0 }, {      6,   26,    2,  8,  6,  0 }, {      6,   27,    1,  8,  6,  0 }, {      6,   28,    1,  8,  6,  0 }, {      6,   29,    0,  8,  6,  0 },
    {      6,   30,    0,  8,  6,  0 }, {      6,   31,   -1,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D023A, {
    {      0,   26,   15, 16,  6,  0 }, {      1,   26,   14, 16,  6,  0 }, {      2,   26,   14, 16,  6,  0 }, {      3,   26,   13, 16,  6,  0 }, {      4,   26,   13, 16,  6,  0 },
    {      5,   26,   12, 16,  6,  0 }, {      6,   26,   12, 16,  6,  0 }, {      7,   26,   11, 16,  6,  0 }, {      8,   26,   11, 16,  6,  0 }, {      9,   26,   10, 16,  6,  0 },
    {     10,   26,   10, 16,  6,  0 }, {     11,   26,    9, 16,  6,  0 }, {     12,   26,    9, 16,  6,  0 }, {     13,   26,    8, 16,  6,  0 }, {     14,   26,    8, 16,  6,  0 },
    {     15,   26,    7, 16,  6,  0 }, {     16,   26,    7, 16,  6,  0 }, {     17,   26,    6, 16,  6,  0 }, {     18,   26,    6, 16,  6,  0 }, {     19,   26,    5, 16,  6,  0 },
    {     20,   26,    5, 16,  6,  0 }, {     21,   26,    4, 16,  6,  0 }, {     22,   26,    4, 16,  6,  0 }, {     23,   26,    3, 16,  6,  0 }, {     24,   26,    3, 16,  6,  0 },
    {     25,   26,    2, 16,  6,  0 }, {     26,   26,    2, 16,  6,  0 }, {     27,   26,    1, 16,  6,  0 }, {     28,   26,    1, 16,  6,  0 }, {     29,   26,    0, 16,  6,  0 },
    {     30,   26,    0, 16,  6,  0 }, {     31,   26,   -1, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8D035C, {
    {     26,   31,   15, 24,  6,  0 }, {     26,   30,   15, 24,  6,  0 }, {     26,   29,   14, 24,  6,  0 }, {     26,   28,   14, 24,  6,  0 }, {     26,   27,   13, 24,  6,  0 },
    {     26,   26,   13, 24,  6,  0 }, {     26,   25,   12, 24,  6,  0 }, {     26,   24,   12, 24,  6,  0 }, {     26,   23,   11, 24,  6,  0 }, {     26,   22,   11, 24,  6,  0 },
    {     26,   21,   10, 24,  6,  0 }, {     26,   20,   10, 24,  6,  0 }, {     26,   19,    9, 24,  6,  0 }, {     26,   18,    9, 24,  6,  0 }, {     26,   17,    8, 24,  6,  0 },
    {     26,   16,    8, 24,  6,  0 }, {     26,   15,    7, 24,  6,  0 }, {     26,   14,    7, 24,  6,  0 }, {     26,   13,    6, 24,  6,  0 }, {     26,   12,    6, 24,  6,  0 },
    {     26,   11,    5, 24,  6,  0 }, {     26,   10,    5, 24,  6,  0 }, {     26,    9,    4, 24,  6,  0 }, {     26,    8,    4, 24,  6,  0 }, {     26,    7,    3, 24,  6,  0 },
    {     26,    6,    3, 24,  6,  0 }, {     26,    5,    2, 24,  6,  0 }, {     26,    4,    2, 24,  6,  0 }, {     26,    3,    1, 24,  6,  0 }, {     26,    2,    1, 24,  6,  0 },
    {     26,    1,    0, 24,  6,  0 }, {     26,    0,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CF6E6, {
    {     31,    6,    8,  0,  0,  0 }, {     30,    6,    8,  0,  0,  0 }, {     29,    6,    8,  0,  0,  0 }, {     28,    6,    8,  0,  0,  0 }, {     27,    6,    8,  0,  0,  0 },
    {     26,    6,    8,  0,  0,  0 }, {     25,    6,    8,  0,  0,  0 }, {     24,    6,    8,  0,  0,  0 }, {     23,    6,    7,  0,  5,  0 }, {     22,    6,    7,  0,  5,  0 },
    {     21,    6,    7,  0,  5,  0 }, {     20,    6,    7,  0,  5,  0 }, {     19,    6,    7,  0,  5,  0 }, {     18,    6,    7,  0,  5,  0 }, {     17,    6,    6,  0,  5,  0 },
    {     16,    6,    6,  0,  5,  0 }, {     15,    6,    6,  0,  5,  0 }, {     14,    6,    6,  0,  5,  0 }, {     13,    6,    5,  0,  5,  0 }, {     12,    6,    5,  0,  5,  0 },
    {     11,    6,    5,  0,  5,  0 }, {     10,    6,    4,  0,  5,  0 }, {      9,    6,    4,  0,  5,  0 }, {      8,    6,    4,  0,  5,  0 }, {      7,    6,    3,  0,  6,  0 },
    {      6,    6,    3,  0,  6,  0 }, {      5,    6,    2,  0,  6,  0 }, {      4,    6,    2,  0,  6,  0 }, {      3,    6,    1,  0,  6,  0 }, {      2,    6,    1,  0,  6,  0 },
    {      1,    6,    0,  0,  6,  0 }, {      0,    6,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CF808, {
    {      6,    0,    8,  8,  0,  0 }, {      6,    1,    8,  8,  0,  0 }, {      6,    2,    8,  8,  0,  0 }, {      6,    3,    8,  8,  0,  0 }, {      6,    4,    8,  8,  0,  0 },
    {      6,    5,    8,  8,  0,  0 }, {      6,    6,    8,  8,  0,  0 }, {      6,    7,    8,  8,  0,  0 }, {      6,    8,    7,  8,  5,  0 }, {      6,    9,    7,  8,  5,  0 },
    {      6,   10,    7,  8,  5,  0 }, {      6,   11,    7,  8,  5,  0 }, {      6,   12,    7,  8,  5,  0 }, {      6,   13,    7,  8,  5,  0 }, {      6,   14,    6,  8,  5,  0 },
    {      6,   15,    6,  8,  5,  0 }, {      6,   16,    6,  8,  5,  0 }, {      6,   17,    6,  8,  5,  0 }, {      6,   18,    5,  8,  5,  0 }, {      6,   19,    5,  8,  5,  0 },
    {      6,   20,    5,  8,  5,  0 }, {      6,   21,    4,  8,  5,  0 }, {      6,   22,    4,  8,  5,  0 }, {      6,   23,    4,  8,  5,  0 }, {      6,   24,    3,  8,  6,  0 },
    {      6,   25,    3,  8,  6,  0 }, {      6,   26,    3,  8,  6,  0 }, {      6,   27,    2,  8,  6,  0 }, {      6,   28,    2,  8,  6,  0 }, {      6,   29,    1,  8,  6,  0 },
    {      6,   30,    1,  8,  6,  0 }, {      6,   31,    0,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CF92A, {
    {      0,   26,    8, 16,  0,  0 }, {      1,   26,    8, 16,  0,  0 }, {      2,   26,    8, 16,  0,  0 }, {      3,   26,    8, 16,  0,  0 }, {      4,   26,    8, 16,  0,  0 },
    {      5,   26,    8, 16,  0,  0 }, {      6,   26,    8, 16,  0,  0 }, {      7,   26,    8, 16,  0,  0 }, {      8,   26,    7, 16,  5,  0 }, {      9,   26,    7, 16,  5,  0 },
    {     10,   26,    7, 16,  5,  0 }, {     11,   26,    7, 16,  5,  0 }, {     12,   26,    7, 16,  5,  0 }, {     13,   26,    7, 16,  5,  0 }, {     14,   26,    6, 16,  5,  0 },
    {     15,   26,    6, 16,  5,  0 }, {     16,   26,    6, 16,  5,  0 }, {     17,   26,    6, 16,  5,  0 }, {     18,   26,    5, 16,  5,  0 }, {     19,   26,    5, 16,  5,  0 },
    {     20,   26,    5, 16,  5,  0 }, {     21,   26,    4, 16,  5,  0 }, {     22,   26,    4, 16,  5,  0 }, {     23,   26,    4, 16,  5,  0 }, {     24,   26,    3, 16,  6,  0 },
    {     25,   26,    3, 16,  6,  0 }, {     26,   26,    3, 16,  6,  0 }, {     27,   26,    2, 16,  6,  0 }, {     28,   26,    2, 16,  6,  0 }, {     29,   26,    1, 16,  6,  0 },
    {     30,   26,    1, 16,  6,  0 }, {     31,   26,    0, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CFA4C, {
    {     26,   31,    8, 24,  0,  0 }, {     26,   30,    8, 24,  0,  0 }, {     26,   29,    8, 24,  0,  0 }, {     26,   28,    8, 24,  0,  0 }, {     26,   27,    8, 24,  0,  0 },
    {     26,   26,    8, 24,  0,  0 }, {     26,   25,    8, 24,  0,  0 }, {     26,   24,    8, 24,  0,  0 }, {     26,   23,    7, 24,  5,  0 }, {     26,   22,    7, 24,  5,  0 },
    {     26,   21,    7, 24,  5,  0 }, {     26,   20,    7, 24,  5,  0 }, {     26,   19,    7, 24,  5,  0 }, {     26,   18,    7, 24,  5,  0 }, {     26,   17,    6, 24,  5,  0 },
    {     26,   16,    6, 24,  5,  0 }, {     26,   15,    6, 24,  5,  0 }, {     26,   14,    6, 24,  5,  0 }, {     26,   13,    5, 24,  5,  0 }, {     26,   12,    5, 24,  5,  0 },
    {     26,   11,    5, 24,  5,  0 }, {     26,   10,    4, 24,  5,  0 }, {     26,    9,    4, 24,  5,  0 }, {     26,    8,    4, 24,  5,  0 }, {     26,    7,    3, 24,  6,  0 },
    {     26,    6,    3, 24,  6,  0 }, {     26,    5,    2, 24,  6,  0 }, {     26,    4,    2, 24,  6,  0 }, {     26,    3,    1, 24,  6,  0 }, {     26,    2,    1, 24,  6,  0 },
    {     26,    1,    0, 24,  6,  0 }, {     26,    0,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CF25E, {
    {     31,    6,    7,  0,  6,  0 }, {     30,    6,    7,  0,  6,  0 }, {     29,    6,    6,  0,  6,  0 }, {     28,    6,    6,  0,  6,  0 }, {     27,    6,    5,  0,  6,  0 },
    {     26,    6,    5,  0,  6,  0 }, {     25,    6,    4,  0,  6,  0 }, {     24,    6,    4,  0,  6,  0 }, {     23,    6,    4,  0,  5,  0 }, {     22,    6,    3,  0,  5,  0 },
    {     21,    6,    3,  0,  5,  0 }, {     20,    6,    3,  0,  5,  0 }, {     19,    6,    2,  0,  5,  0 }, {     18,    6,    2,  0,  5,  0 }, {     17,    6,    2,  0,  5,  0 },
    {     16,    6,    2,  0,  5,  0 }, {     15,    6,    1,  0,  5,  0 }, {     14,    6,    1,  0,  5,  0 }, {     13,    6,    1,  0,  5,  0 }, {     12,    6,    1,  0,  5,  0 },
    {     11,    6,    1,  0,  5,  0 }, {     10,    6,    1,  0,  5,  0 }, {      9,    6,    0,  0,  0,  0 }, {      8,    6,    0,  0,  0,  0 }, {      7,    6,    0,  0,  0,  0 },
    {      6,    6,    0,  0,  0,  0 }, {      5,    6,    0,  0,  0,  0 }, {      4,    6,    0,  0,  0,  0 }, {      3,    6,    0,  0,  0,  0 }, {      2,    6,    0,  0,  0,  0 },
    {      1,    6,    0,  0,  0,  0 }, {      0,    6,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CF380, {
    {      6,    0,    8,  8,  6,  0 }, {      6,    1,    7,  8,  6,  0 }, {      6,    2,    7,  8,  6,  0 }, {      6,    3,    6,  8,  6,  0 }, {      6,    4,    6,  8,  6,  0 },
    {      6,    5,    5,  8,  6,  0 }, {      6,    6,    5,  8,  6,  0 }, {      6,    7,    4,  8,  6,  0 }, {      6,    8,    4,  8,  5,  0 }, {      6,    9,    3,  8,  5,  0 },
    {      6,   10,    3,  8,  5,  0 }, {      6,   11,    3,  8,  5,  0 }, {      6,   12,    2,  8,  5,  0 }, {      6,   13,    2,  8,  5,  0 }, {      6,   14,    2,  8,  5,  0 },
    {      6,   15,    2,  8,  5,  0 }, {      6,   16,    1,  8,  5,  0 }, {      6,   17,    1,  8,  5,  0 }, {      6,   18,    1,  8,  5,  0 }, {      6,   19,    1,  8,  5,  0 },
    {      6,   20,    1,  8,  5,  0 }, {      6,   21,    1,  8,  5,  0 }, {      6,   22,    0,  8,  0,  0 }, {      6,   23,    0,  8,  0,  0 }, {      6,   24,    0,  8,  0,  0 },
    {      6,   25,    0,  8,  0,  0 }, {      6,   26,    0,  8,  0,  0 }, {      6,   27,    0,  8,  0,  0 }, {      6,   28,    0,  8,  0,  0 }, {      6,   29,    0,  8,  0,  0 },
    {      6,   30,    0,  8,  0,  0 }, {      6,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CF4A2, {
    {      0,   26,    8, 16,  6,  0 }, {      1,   26,    7, 16,  6,  0 }, {      2,   26,    7, 16,  6,  0 }, {      3,   26,    6, 16,  6,  0 }, {      4,   26,    6, 16,  6,  0 },
    {      5,   26,    5, 16,  6,  0 }, {      6,   26,    5, 16,  6,  0 }, {      7,   26,    4, 16,  6,  0 }, {      8,   26,    4, 16,  5,  0 }, {      9,   26,    3, 16,  5,  0 },
    {     10,   26,    3, 16,  5,  0 }, {     11,   26,    3, 16,  5,  0 }, {     12,   26,    2, 16,  5,  0 }, {     13,   26,    2, 16,  5,  0 }, {     14,   26,    2, 16,  5,  0 },
    {     15,   26,    2, 16,  5,  0 }, {     16,   26,    1, 16,  5,  0 }, {     17,   26,    1, 16,  5,  0 }, {     18,   26,    1, 16,  5,  0 }, {     19,   26,    1, 16,  5,  0 },
    {     20,   26,    1, 16,  5,  0 }, {     21,   26,    1, 16,  5,  0 }, {     22,   26,    0, 16,  0,  0 }, {     23,   26,    0, 16,  0,  0 }, {     24,   26,    0, 16,  0,  0 },
    {     25,   26,    0, 16,  0,  0 }, {     26,   26,    0, 16,  0,  0 }, {     27,   26,    0, 16,  0,  0 }, {     28,   26,    0, 16,  0,  0 }, {     29,   26,    0, 16,  0,  0 },
    {     30,   26,    0, 16,  0,  0 }, {     31,   26,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CF5C4, {
    {     26,   31,    7, 24,  6,  0 }, {     26,   30,    7, 24,  6,  0 }, {     26,   29,    6, 24,  6,  0 }, {     26,   28,    6, 24,  6,  0 }, {     26,   27,    5, 24,  6,  0 },
    {     26,   26,    5, 24,  6,  0 }, {     26,   25,    4, 24,  6,  0 }, {     26,   24,    4, 24,  6,  0 }, {     26,   23,    4, 24,  5,  0 }, {     26,   22,    3, 24,  5,  0 },
    {     26,   21,    3, 24,  5,  0 }, {     26,   20,    3, 24,  5,  0 }, {     26,   19,    2, 24,  5,  0 }, {     26,   18,    2, 24,  5,  0 }, {     26,   17,    2, 24,  5,  0 },
    {     26,   16,    2, 24,  5,  0 }, {     26,   15,    1, 24,  5,  0 }, {     26,   14,    1, 24,  5,  0 }, {     26,   13,    1, 24,  5,  0 }, {     26,   12,    1, 24,  5,  0 },
    {     26,   11,    1, 24,  5,  0 }, {     26,   10,    1, 24,  5,  0 }, {     26,    9,    0, 24,  0,  0 }, {     26,    8,    0, 24,  0,  0 }, {     26,    7,    0, 24,  0,  0 },
    {     26,    6,    0, 24,  0,  0 }, {     26,    5,    0, 24,  0,  0 }, {     26,    4,    0, 24,  0,  0 }, {     26,    3,    0, 24,  0,  0 }, {     26,    2,    0, 24,  0,  0 },
    {     26,    1,    0, 24,  0,  0 }, {     26,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FD922, {
    {     31,    6,    0,  0,  0,  0 }, {     30,    6,    0, 30,  0,  0 }, {     29,    5,    0, 30,  0,  0 }, {     28,    5,    0, 28,  0,  0 }, {     27,    4,    0, 28,  0,  0 },
    {     27,    3,    0, 26,  0,  0 }, {     26,    2,    0, 26,  0,  0 }, {     26,    1,    0, 24,  0,  0 }, {     26,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FD975, {
    {      6,    0,    0,  8,  0,  0 }, {      6,    1,    0,  8,  0,  0 }, {      6,    2,    0,  6,  0,  0 }, {      5,    3,    0,  6,  0,  0 }, {      5,    4,    0,  4,  0,  0 },
    {      4,    5,    0,  4,  0,  0 }, {      3,    5,    0,  2,  0,  0 }, {      2,    6,    0,  2,  0,  0 }, {      1,    6,    0,  0,  0,  0 }, {      0,    6,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FD9D1, {
    {      0,   26,    0, 16,  0,  0 }, {      1,   26,    0, 16,  0,  0 }, {      2,   26,    0, 14,  0,  0 }, {      3,   27,    0, 14,  0,  0 }, {      4,   27,    0, 12,  0,  0 },
    {      5,   28,    0, 12,  0,  0 }, {      5,   29,    0, 10,  0,  0 }, {      6,   30,    0, 10,  0,  0 }, {      6,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FDA24, {
    {     26,   31,    0, 24,  0,  0 }, {     26,   30,    0, 22,  0,  0 }, {     27,   29,    0, 22,  0,  0 }, {     27,   28,    0, 20,  0,  0 }, {     28,   27,    0, 20,  0,  0 },
    {     29,   27,    0, 18,  0,  0 }, {     30,   26,    0, 18,  0,  0 }, {     31,   26,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FDA6E, {
    {     31,    6,    0,  0,  0,  0 }, {     30,    6,    0,  0,  0,  0 }, {     29,    6,    0,  0,  0,  0 }, {     28,    6,    0,  0,  0,  0 }, {     27,    6,    0,  0,  0,  0 },
    {     26,    7,    0,  1,  0,  0 }, {     25,    7,    0,  1,  0,  0 }, {     24,    7,    0,  1,  0,  0 }, {     23,    7,    0,  1,  0,  0 }, {     22,    8,    0,  2,  0,  0 },
    {     21,    8,    0,  2,  0,  0 }, {     20,    8,    0,  2,  0,  0 }, {     19,    9,    0,  3,  0,  0 }, {     18,    9,    0,  3,  0,  0 }, {     17,   10,    0,  3,  0,  0 },
    {     16,   11,    0,  3,  0,  0 }, {     15,   12,    0,  4,  0,  0 }, {     14,   13,    0,  4,  0,  0 }, {     13,   14,    0,  4,  0,  0 }, {     12,   15,    0,  4,  0,  0 },
    {     11,   16,    0,  5,  0,  0 }, {     10,   17,    0,  5,  0,  0 }, {      9,   18,    0,  5,  0,  0 }, {      9,   19,    0,  5,  0,  0 }, {      8,   20,    0,  6,  0,  0 },
    {      8,   21,    0,  6,  0,  0 }, {      8,   22,    0,  6,  0,  0 }, {      7,   23,    0,  7,  0,  0 }, {      7,   24,    0,  7,  0,  0 }, {      7,   25,    0,  7,  0,  0 },
    {      7,   26,    0,  7,  0,  0 }, {      6,   27,    0,  8,  0,  0 }, {      6,   28,    0,  8,  0,  0 }, {      6,   29,    0,  8,  0,  0 }, {      6,   30,    0,  8,  0,  0 },
    {      6,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FDBB4, {
    {      6,    0,    0,  8,  0,  0 }, {      6,    1,    0,  8,  0,  0 }, {      6,    2,    0,  8,  0,  0 }, {      6,    3,    0,  8,  0,  0 }, {      6,    4,    0,  8,  0,  0 },
    {      6,    5,    0,  8,  0,  0 }, {      7,    6,    0,  9,  0,  0 }, {      7,    7,    0,  9,  0,  0 }, {      7,    8,    0,  9,  0,  0 }, {      7,    9,    0,  9,  0,  0 },
    {      8,   10,    0, 10,  0,  0 }, {      8,   11,    0, 10,  0,  0 }, {      8,   12,    0, 10,  0,  0 }, {      9,   13,    0, 11,  0,  0 }, {      9,   14,    0, 11,  0,  0 },
    {     10,   15,    0, 11,  0,  0 }, {     11,   16,    0, 11,  0,  0 }, {     12,   17,    0, 12,  0,  0 }, {     13,   18,    0, 12,  0,  0 }, {     14,   19,    0, 12,  0,  0 },
    {     15,   20,    0, 12,  0,  0 }, {     16,   21,    0, 13,  0,  0 }, {     17,   22,    0, 13,  0,  0 }, {     18,   23,    0, 13,  0,  0 }, {     19,   23,    0, 13,  0,  0 },
    {     20,   24,    0, 14,  0,  0 }, {     21,   24,    0, 14,  0,  0 }, {     22,   24,    0, 14,  0,  0 }, {     23,   25,    0, 15,  0,  0 }, {     24,   25,    0, 15,  0,  0 },
    {     25,   25,    0, 15,  0,  0 }, {     26,   25,    0, 15,  0,  0 }, {     27,   26,    0, 16,  0,  0 }, {     28,   26,    0, 16,  0,  0 }, {     29,   26,    0, 16,  0,  0 },
    {     30,   26,    0, 16,  0,  0 }, {     31,   26,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FDD03, {
    {      0,   26,    0, 16,  0,  0 }, {      1,   26,    0, 16,  0,  0 }, {      2,   26,    0, 16,  0,  0 }, {      3,   26,    0, 16,  0,  0 }, {      4,   26,    0, 16,  0,  0 },
    {      5,   26,    0, 16,  0,  0 }, {      6,   25,    0, 17,  0,  0 }, {      7,   25,    0, 17,  0,  0 }, {      8,   25,    0, 17,  0,  0 }, {      9,   25,    0, 17,  0,  0 },
    {     10,   24,    0, 18,  0,  0 }, {     11,   24,    0, 18,  0,  0 }, {     12,   24,    0, 18,  0,  0 }, {     13,   23,    0, 19,  0,  0 }, {     14,   23,    0, 19,  0,  0 },
    {     15,   22,    0, 19,  0,  0 }, {     16,   21,    0, 19,  0,  0 }, {     17,   20,    0, 20,  0,  0 }, {     18,   19,    0, 20,  0,  0 }, {     19,   18,    0, 20,  0,  0 },
    {     20,   17,    0, 20,  0,  0 }, {     21,   16,    0, 21,  0,  0 }, {     22,   15,    0, 21,  0,  0 }, {     23,   14,    0, 21,  0,  0 }, {     23,   13,    0, 21,  0,  0 },
    {     24,   12,    0, 22,  0,  0 }, {     24,   11,    0, 22,  0,  0 }, {     24,   10,    0, 22,  0,  0 }, {     25,    9,    0, 23,  0,  0 }, {     25,    8,    0, 23,  0,  0 },
    {     25,    7,    0, 23,  0,  0 }, {     25,    6,    0, 23,  0,  0 }, {     26,    5,    0, 24,  0,  0 }, {     26,    4,    0, 24,  0,  0 }, {     26,    3,    0, 24,  0,  0 },
    {     26,    2,    0, 24,  0,  0 }, {     26,    1,    0, 24,  0,  0 }, {     26,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FDE5B, {
    {     26,   31,    0, 24,  0,  0 }, {     26,   30,    0, 24,  0,  0 }, {     26,   29,    0, 24,  0,  0 }, {     26,   28,    0, 24,  0,  0 }, {     26,   27,    0, 24,  0,  0 },
    {     25,   26,    0, 25,  0,  0 }, {     25,   25,    0, 25,  0,  0 }, {     25,   24,    0, 25,  0,  0 }, {     25,   23,    0, 25,  0,  0 }, {     24,   22,    0, 26,  0,  0 },
    {     24,   21,    0, 26,  0,  0 }, {     24,   20,    0, 26,  0,  0 }, {     23,   19,    0, 27,  0,  0 }, {     23,   18,    0, 27,  0,  0 }, {     22,   17,    0, 27,  0,  0 },
    {     21,   16,    0, 27,  0,  0 }, {     20,   15,    0, 28,  0,  0 }, {     19,   14,    0, 28,  0,  0 }, {     18,   13,    0, 28,  0,  0 }, {     17,   12,    0, 28,  0,  0 },
    {     16,   11,    0, 29,  0,  0 }, {     15,   10,    0, 29,  0,  0 }, {     14,    9,    0, 29,  0,  0 }, {     13,    9,    0, 29,  0,  0 }, {     12,    8,    0, 30,  0,  0 },
    {     11,    8,    0, 30,  0,  0 }, {     10,    8,    0, 30,  0,  0 }, {      9,    7,    0, 31,  0,  0 }, {      8,    7,    0, 31,  0,  0 }, {      7,    7,    0, 31,  0,  0 },
    {      6,    7,    0, 31,  0,  0 }, {      5,    6,    0,  0,  0,  0 }, {      4,    6,    0,  0,  0,  0 }, {      3,    6,    0,  0,  0,  0 }, {      2,    6,    0,  0,  0,  0 },
    {      1,    6,    0,  0,  0,  0 }, {      0,    6,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CE06A, {
    {     31,    6,    0,  0,  0,  0 }, {     30,    6,    0,  0,  0,  0 }, {     29,    6,    0,  0,  0,  0 }, {     28,    6,    0,  0,  0,  0 }, {     27,    6,    0,  0,  0,  0 },
    {     26,    6,    0,  0,  0,  0 }, {     25,    6,    0,  0,  0,  0 }, {     24,    6,    0,  0,  0,  0 }, {     23,    6,    0,  0,  0,  0 }, {     22,    6,    0,  0,  0,  0 },
    {     21,    6,    0,  0,  0,  0 }, {     20,    6,    0,  0,  0,  0 }, {     19,    6,    0,  0,  0,  0 }, {     18,    6,    0,  0,  0,  0 }, {     17,    6,    0,  0,  0,  0 },
    {     16,    6,    0,  0,  0,  0 }, {     15,    6,    0,  0,  0,  0 }, {     14,    6,    0,  1,  0,  0 }, {     13,    6,    0,  1,  0,  0 }, {     12,    7,    0,  2,  0,  0 },
    {     11,    7,    0,  2,  0,  0 }, {     10,    8,    0,  3,  0,  0 }, {      9,    8,    0,  3,  0,  0 }, {      8,    9,    0,  4,  0,  0 }, {      7,   10,    0,  5,  0,  0 },
    {      7,   11,    0,  5,  0,  0 }, {      6,   12,    0,  6,  0,  0 }, {      6,   13,    0,  6,  0,  0 }, {      6,   14,    0,  7,  0,  0 }, {      6,   15,    0,  7,  0,  0 },
    {      6,   16,    0,  8,  0,  0 }, {      6,   17,    0,  9,  0,  0 }, {      6,   18,    0,  9,  0,  0 }, {      6,   19,    0, 10,  0,  0 }, {      6,   20,    0, 10,  0,  0 },
    {      7,   21,    0, 11,  0,  0 }, {      7,   22,    0, 11,  0,  0 }, {      8,   23,    0, 12,  0,  0 }, {      9,   24,    0, 13,  0,  0 }, {     10,   24,    0, 13,  0,  0 },
    {     11,   25,    0, 14,  0,  0 }, {     12,   25,    0, 14,  0,  0 }, {     13,   26,    0, 15,  0,  0 }, {     14,   26,    0, 15,  0,  0 }, {     15,   26,    0, 16,  0,  0 },
    {     16,   26,    0, 16,  0,  0 }, {     17,   26,    0, 16,  0,  0 }, {     18,   26,    0, 16,  0,  0 }, {     19,   26,    0, 16,  0,  0 }, {     20,   26,    0, 16,  0,  0 },
    {     21,   26,    0, 16,  0,  0 }, {     22,   26,    0, 16,  0,  0 }, {     23,   26,    0, 16,  0,  0 }, {     24,   26,    0, 16,  0,  0 }, {     25,   26,    0, 16,  0,  0 },
    {     26,   26,    0, 16,  0,  0 }, {     27,   26,    0, 16,  0,  0 }, {     28,   26,    0, 16,  0,  0 }, {     29,   26,    0, 16,  0,  0 }, {     30,   26,    0, 16,  0,  0 },
    {     31,   26,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CE291, {
    {      6,    0,    0,  8,  0,  0 }, {      6,    1,    0,  8,  0,  0 }, {      6,    2,    0,  8,  0,  0 }, {      6,    3,    0,  8,  0,  0 }, {      6,    4,    0,  8,  0,  0 },
    {      6,    5,    0,  8,  0,  0 }, {      6,    6,    0,  8,  0,  0 }, {      6,    7,    0,  8,  0,  0 }, {      6,    8,    0,  8,  0,  0 }, {      6,    9,    0,  8,  0,  0 },
    {      6,   10,    0,  8,  0,  0 }, {      6,   11,    0,  8,  0,  0 }, {      6,   12,    0,  8,  0,  0 }, {      6,   13,    0,  8,  0,  0 }, {      6,   14,    0,  8,  0,  0 },
    {      6,   15,    0,  8,  0,  0 }, {      6,   16,    0,  8,  0,  0 }, {      6,   17,    0,  9,  0,  0 }, {      6,   18,    0,  9,  0,  0 }, {      7,   19,    0, 10,  0,  0 },
    {      7,   20,    0, 10,  0,  0 }, {      8,   21,    0, 11,  0,  0 }, {      8,   22,    0, 11,  0,  0 }, {      9,   23,    0, 12,  0,  0 }, {     10,   24,    0, 13,  0,  0 },
    {     11,   24,    0, 13,  0,  0 }, {     12,   25,    0, 14,  0,  0 }, {     13,   25,    0, 14,  0,  0 }, {     14,   25,    0, 15,  0,  0 }, {     15,   25,    0, 15,  0,  0 },
    {     16,   25,    0, 16,  0,  0 }, {     17,   25,    0, 17,  0,  0 }, {     18,   25,    0, 17,  0,  0 }, {     19,   25,    0, 18,  0,  0 }, {     20,   25,    0, 18,  0,  0 },
    {     21,   24,    0, 19,  0,  0 }, {     22,   24,    0, 19,  0,  0 }, {     23,   23,    0, 20,  0,  0 }, {     24,   22,    0, 21,  0,  0 }, {     24,   21,    0, 21,  0,  0 },
    {     25,   20,    0, 22,  0,  0 }, {     25,   19,    0, 22,  0,  0 }, {     26,   18,    0, 23,  0,  0 }, {     26,   17,    0, 23,  0,  0 }, {     26,   16,    0, 24,  0,  0 },
    {     26,   15,    0, 24,  0,  0 }, {     26,   14,    0, 24,  0,  0 }, {     26,   13,    0, 24,  0,  0 }, {     26,   12,    0, 24,  0,  0 }, {     26,   11,    0, 24,  0,  0 },
    {     26,   10,    0, 24,  0,  0 }, {     26,    9,    0, 24,  0,  0 }, {     26,    8,    0, 24,  0,  0 }, {     26,    7,    0, 24,  0,  0 }, {     26,    6,    0, 24,  0,  0 },
    {     26,    5,    0, 24,  0,  0 }, {     26,    4,    0, 24,  0,  0 }, {     26,    3,    0, 24,  0,  0 }, {     26,    2,    0, 24,  0,  0 }, {     26,    1,    0, 24,  0,  0 },
    {     26,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CE4B8, {
    {      0,   26,    0, 16,  0,  0 }, {      1,   26,    0, 16,  0,  0 }, {      2,   26,    0, 16,  0,  0 }, {      3,   26,    0, 16,  0,  0 }, {      4,   26,    0, 16,  0,  0 },
    {      5,   26,    0, 16,  0,  0 }, {      6,   26,    0, 16,  0,  0 }, {      7,   26,    0, 16,  0,  0 }, {      8,   26,    0, 16,  0,  0 }, {      9,   26,    0, 16,  0,  0 },
    {     10,   26,    0, 16,  0,  0 }, {     11,   26,    0, 16,  0,  0 }, {     12,   26,    0, 16,  0,  0 }, {     13,   26,    0, 16,  0,  0 }, {     14,   26,    0, 16,  0,  0 },
    {     15,   26,    0, 16,  0,  0 }, {     16,   26,    0, 16,  0,  0 }, {     17,   26,    0, 17,  0,  0 }, {     18,   26,    0, 17,  0,  0 }, {     19,   25,    0, 18,  0,  0 },
    {     20,   25,    0, 18,  0,  0 }, {     21,   24,    0, 19,  0,  0 }, {     22,   24,    0, 19,  0,  0 }, {     23,   23,    0, 20,  0,  0 }, {     24,   22,    0, 21,  0,  0 },
    {     24,   21,    0, 21,  0,  0 }, {     25,   20,    0, 22,  0,  0 }, {     25,   19,    0, 22,  0,  0 }, {     25,   18,    0, 23,  0,  0 }, {     25,   17,    0, 23,  0,  0 },
    {     25,   16,    0, 24,  0,  0 }, {     25,   15,    0, 25,  0,  0 }, {     25,   14,    0, 25,  0,  0 }, {     25,   13,    0, 26,  0,  0 }, {     25,   12,    0, 26,  0,  0 },
    {     24,   11,    0, 27,  0,  0 }, {     24,   10,    0, 27,  0,  0 }, {     23,    9,    0, 28,  0,  0 }, {     22,    8,    0, 29,  0,  0 }, {     21,    8,    0, 29,  0,  0 },
    {     20,    7,    0, 30,  0,  0 }, {     19,    7,    0, 30,  0,  0 }, {     18,    6,    0, 31,  0,  0 }, {     17,    6,    0, 31,  0,  0 }, {     16,    6,    0,  0,  0,  0 },
    {     15,    6,    0,  0,  0,  0 }, {     14,    6,    0,  0,  0,  0 }, {     13,    6,    0,  0,  0,  0 }, {     12,    6,    0,  0,  0,  0 }, {     11,    6,    0,  0,  0,  0 },
    {     10,    6,    0,  0,  0,  0 }, {      9,    6,    0,  0,  0,  0 }, {      8,    6,    0,  0,  0,  0 }, {      7,    6,    0,  0,  0,  0 }, {      6,    6,    0,  0,  0,  0 },
    {      5,    6,    0,  0,  0,  0 }, {      4,    6,    0,  0,  0,  0 }, {      3,    6,    0,  0,  0,  0 }, {      2,    6,    0,  0,  0,  0 }, {      1,    6,    0,  0,  0,  0 },
    {      0,    6,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8CE6DF, {
    {     26,   31,    0, 24,  0,  0 }, {     26,   30,    0, 24,  0,  0 }, {     26,   29,    0, 24,  0,  0 }, {     26,   28,    0, 24,  0,  0 }, {     26,   27,    0, 24,  0,  0 },
    {     26,   26,    0, 24,  0,  0 }, {     26,   25,    0, 24,  0,  0 }, {     26,   24,    0, 24,  0,  0 }, {     26,   23,    0, 24,  0,  0 }, {     26,   22,    0, 24,  0,  0 },
    {     26,   21,    0, 24,  0,  0 }, {     26,   20,    0, 24,  0,  0 }, {     26,   19,    0, 24,  0,  0 }, {     26,   18,    0, 24,  0,  0 }, {     26,   17,    0, 24,  0,  0 },
    {     26,   16,    0, 24,  0,  0 }, {     26,   15,    0, 24,  0,  0 }, {     26,   14,    0, 25,  0,  0 }, {     26,   13,    0, 25,  0,  0 }, {     25,   12,    0, 26,  0,  0 },
    {     25,   11,    0, 26,  0,  0 }, {     24,   10,    0, 27,  0,  0 }, {     24,    9,    0, 27,  0,  0 }, {     23,    8,    0, 28,  0,  0 }, {     22,    7,    0, 29,  0,  0 },
    {     21,    7,    0, 29,  0,  0 }, {     20,    6,    0, 30,  0,  0 }, {     19,    6,    0, 30,  0,  0 }, {     18,    6,    0, 31,  0,  0 }, {     17,    6,    0, 31,  0,  0 },
    {     16,    6,    0,  0,  0,  0 }, {     15,    6,    0,  1,  0,  0 }, {     14,    6,    0,  1,  0,  0 }, {     13,    6,    0,  2,  0,  0 }, {     12,    6,    0,  2,  0,  0 },
    {     11,    7,    0,  3,  0,  0 }, {     10,    7,    0,  3,  0,  0 }, {      9,    8,    0,  4,  0,  0 }, {      8,    9,    0,  5,  0,  0 }, {      8,   10,    0,  5,  0,  0 },
    {      7,   11,    0,  6,  0,  0 }, {      7,   12,    0,  6,  0,  0 }, {      6,   13,    0,  7,  0,  0 }, {      6,   14,    0,  7,  0,  0 }, {      6,   15,    0,  8,  0,  0 },
    {      6,   16,    0,  8,  0,  0 }, {      6,   17,    0,  8,  0,  0 }, {      6,   18,    0,  8,  0,  0 }, {      6,   19,    0,  8,  0,  0 }, {      6,   20,    0,  8,  0,  0 },
    {      6,   21,    0,  8,  0,  0 }, {      6,   22,    0,  8,  0,  0 }, {      6,   23,    0,  8,  0,  0 }, {      6,   24,    0,  8,  0,  0 }, {      6,   25,    0,  8,  0,  0 },
    {      6,   26,    0,  8,  0,  0 }, {      6,   27,    0,  8,  0,  0 }, {      6,   28,    0,  8,  0,  0 }, {      6,   29,    0,  8,  0,  0 }, {      6,   30,    0,  8,  0,  0 },
    {      6,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FF2DA, {
    {     31,    9,    0,  0,  0,  0 }, {     30,    9,    0,  0,  0,  0 }, {     29,    9,    0,  0,  0,  0 }, {     28,    9,    0,  0,  0,  0 }, {     27,    9,    0,  0,  0,  0 },
    {     26,    9,    0,  0,  0,  0 }, {     25,    9,    0,  0,  0,  0 }, {     24,    9,    0,  0,  0,  0 }, {     23,    9,    0,  0,  0,  0 }, {     22,    9,    0,  0,  0,  0 },
    {     21,    9,    0,  0,  0,  0 }, {     20,    9,    0,  0,  0,  0 }, {     19,    9,    0,  0,  0,  0 }, {     18,    9,    0,  0,  0,  0 }, {     17,    9,    0,  0,  0,  0 },
    {     16,    9,    0,  0,  0,  0 }, {     15,    9,    0,  0,  0,  0 }, {     14,    9,    0,  0,  0,  0 }, {     13,    9,    0,  0,  0,  0 }, {     12,    9,    0,  0,  0,  0 },
    {     11,    9,    0,  0,  0,  0 }, {     10,    9,    0,  0,  0,  0 }, {      9,    9,    0,  0,  0,  0 }, {      8,    9,    0,  0,  0,  0 }, {      7,    9,    0,  0,  0,  0 },
    {      6,    9,    0,  0,  0,  0 }, {      5,    9,    0,  0,  0,  0 }, {      4,    9,    0,  0,  0,  0 }, {      3,    9,    0,  0,  0,  0 }, {      2,    9,    0,  0,  0,  0 },
    {      1,    9,    0,  0,  0,  0 }, {      0,    9,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FF3FC, {
    {      9,    0,    0,  8,  0,  0 }, {      9,    1,    0,  8,  0,  0 }, {      9,    2,    0,  8,  0,  0 }, {      9,    3,    0,  8,  0,  0 }, {      9,    4,    0,  8,  0,  0 },
    {      9,    5,    0,  8,  0,  0 }, {      9,    6,    0,  8,  0,  0 }, {      9,    7,    0,  8,  0,  0 }, {      9,    8,    0,  8,  0,  0 }, {      9,    9,    0,  8,  0,  0 },
    {      9,   10,    0,  8,  0,  0 }, {      9,   11,    0,  8,  0,  0 }, {      9,   12,    0,  8,  0,  0 }, {      9,   13,    0,  8,  0,  0 }, {      9,   14,    0,  8,  0,  0 },
    {      9,   15,    0,  8,  0,  0 }, {      9,   16,    0,  8,  0,  0 }, {      9,   17,    0,  8,  0,  0 }, {      9,   18,    0,  8,  0,  0 }, {      9,   19,    0,  8,  0,  0 },
    {      9,   20,    0,  8,  0,  0 }, {      9,   21,    0,  8,  0,  0 }, {      9,   22,    0,  8,  0,  0 }, {      9,   23,    0,  8,  0,  0 }, {      9,   24,    0,  8,  0,  0 },
    {      9,   25,    0,  8,  0,  0 }, {      9,   26,    0,  8,  0,  0 }, {      9,   27,    0,  8,  0,  0 }, {      9,   28,    0,  8,  0,  0 }, {      9,   29,    0,  8,  0,  0 },
    {      9,   30,    0,  8,  0,  0 }, {      9,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FF51E, {
    {      0,   23,    0, 16,  0,  0 }, {      1,   23,    0, 16,  0,  0 }, {      2,   23,    0, 16,  0,  0 }, {      3,   23,    0, 16,  0,  0 }, {      4,   23,    0, 16,  0,  0 },
    {      5,   23,    0, 16,  0,  0 }, {      6,   23,    0, 16,  0,  0 }, {      7,   23,    0, 16,  0,  0 }, {      8,   23,    0, 16,  0,  0 }, {      9,   23,    0, 16,  0,  0 },
    {     10,   23,    0, 16,  0,  0 }, {     11,   23,    0, 16,  0,  0 }, {     12,   23,    0, 16,  0,  0 }, {     13,   23,    0, 16,  0,  0 }, {     14,   23,    0, 16,  0,  0 },
    {     15,   23,    0, 16,  0,  0 }, {     16,   23,    0, 16,  0,  0 }, {     17,   23,    0, 16,  0,  0 }, {     18,   23,    0, 16,  0,  0 }, {     19,   23,    0, 16,  0,  0 },
    {     20,   23,    0, 16,  0,  0 }, {     21,   23,    0, 16,  0,  0 }, {     22,   23,    0, 16,  0,  0 }, {     23,   23,    0, 16,  0,  0 }, {     24,   23,    0, 16,  0,  0 },
    {     25,   23,    0, 16,  0,  0 }, {     26,   23,    0, 16,  0,  0 }, {     27,   23,    0, 16,  0,  0 }, {     28,   23,    0, 16,  0,  0 }, {     29,   23,    0, 16,  0,  0 },
    {     30,   23,    0, 16,  0,  0 }, {     31,   23,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FF640, {
    {     23,   31,    0, 24,  0,  0 }, {     23,   30,    0, 24,  0,  0 }, {     23,   29,    0, 24,  0,  0 }, {     23,   28,    0, 24,  0,  0 }, {     23,   27,    0, 24,  0,  0 },
    {     23,   26,    0, 24,  0,  0 }, {     23,   25,    0, 24,  0,  0 }, {     23,   24,    0, 24,  0,  0 }, {     23,   23,    0, 24,  0,  0 }, {     23,   22,    0, 24,  0,  0 },
    {     23,   21,    0, 24,  0,  0 }, {     23,   20,    0, 24,  0,  0 }, {     23,   19,    0, 24,  0,  0 }, {     23,   18,    0, 24,  0,  0 }, {     23,   17,    0, 24,  0,  0 },
    {     23,   16,    0, 24,  0,  0 }, {     23,   15,    0, 24,  0,  0 }, {     23,   14,    0, 24,  0,  0 }, {     23,   13,    0, 24,  0,  0 }, {     23,   12,    0, 24,  0,  0 },
    {     23,   11,    0, 24,  0,  0 }, {     23,   10,    0, 24,  0,  0 }, {     23,    9,    0, 24,  0,  0 }, {     23,    8,    0, 24,  0,  0 }, {     23,    7,    0, 24,  0,  0 },
    {     23,    6,    0, 24,  0,  0 }, {     23,    5,    0, 24,  0,  0 }, {     23,    4,    0, 24,  0,  0 }, {     23,    3,    0, 24,  0,  0 }, {     23,    2,    0, 24,  0,  0 },
    {     23,    1,    0, 24,  0,  0 }, {     23,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_900E52, {
    {     31,    9,    0,  0,  2,  0 }, {     30,    9,    0,  0,  2,  0 }, {     29,    9,    1,  0,  2,  0 }, {     28,    9,    1,  0,  2,  0 }, {     27,    9,    2,  0,  2,  0 },
    {     26,    9,    2,  0,  2,  0 }, {     25,    9,    3,  0,  2,  0 }, {     24,    9,    3,  0,  2,  0 }, {     23,    9,    4,  0,  2,  0 }, {     22,    9,    4,  0,  2,  0 },
    {     21,    9,    5,  0,  2,  0 }, {     20,    9,    5,  0,  2,  0 }, {     19,    9,    6,  0,  2,  0 }, {     18,    9,    6,  0,  2,  0 }, {     17,    9,    7,  0,  2,  0 },
    {     16,    9,    7,  0,  2,  0 }, {     15,    9,    8,  0,  2,  0 }, {     14,    9,    8,  0,  2,  0 }, {     13,    9,    9,  0,  2,  0 }, {     12,    9,    9,  0,  2,  0 },
    {     11,    9,   10,  0,  2,  0 }, {     10,    9,   10,  0,  2,  0 }, {      9,    9,   11,  0,  2,  0 }, {      8,    9,   11,  0,  2,  0 }, {      7,    9,   12,  0,  2,  0 },
    {      6,    9,   12,  0,  2,  0 }, {      5,    9,   13,  0,  2,  0 }, {      4,    9,   13,  0,  2,  0 }, {      3,    9,   14,  0,  2,  0 }, {      2,    9,   14,  0,  2,  0 },
    {      1,    9,   15,  0,  2,  0 }, {      0,    9,   15,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_900F74, {
    {      9,    0,    0,  8,  2,  0 }, {      9,    1,    1,  8,  2,  0 }, {      9,    2,    1,  8,  2,  0 }, {      9,    3,    2,  8,  2,  0 }, {      9,    4,    2,  8,  2,  0 },
    {      9,    5,    3,  8,  2,  0 }, {      9,    6,    3,  8,  2,  0 }, {      9,    7,    4,  8,  2,  0 }, {      9,    8,    4,  8,  2,  0 }, {      9,    9,    5,  8,  2,  0 },
    {      9,   10,    5,  8,  2,  0 }, {      9,   11,    6,  8,  2,  0 }, {      9,   12,    6,  8,  2,  0 }, {      9,   13,    7,  8,  2,  0 }, {      9,   14,    7,  8,  2,  0 },
    {      9,   15,    8,  8,  2,  0 }, {      9,   16,    8,  8,  2,  0 }, {      9,   17,    9,  8,  2,  0 }, {      9,   18,    9,  8,  2,  0 }, {      9,   19,   10,  8,  2,  0 },
    {      9,   20,   10,  8,  2,  0 }, {      9,   21,   11,  8,  2,  0 }, {      9,   22,   11,  8,  2,  0 }, {      9,   23,   12,  8,  2,  0 }, {      9,   24,   12,  8,  2,  0 },
    {      9,   25,   13,  8,  2,  0 }, {      9,   26,   13,  8,  2,  0 }, {      9,   27,   14,  8,  2,  0 }, {      9,   28,   14,  8,  2,  0 }, {      9,   29,   15,  8,  2,  0 },
    {      9,   30,   15,  8,  2,  0 }, {      9,   31,   16,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_901096, {
    {      0,   23,    0, 16,  2,  0 }, {      1,   23,    1, 16,  2,  0 }, {      2,   23,    1, 16,  2,  0 }, {      3,   23,    2, 16,  2,  0 }, {      4,   23,    2, 16,  2,  0 },
    {      5,   23,    3, 16,  2,  0 }, {      6,   23,    3, 16,  2,  0 }, {      7,   23,    4, 16,  2,  0 }, {      8,   23,    4, 16,  2,  0 }, {      9,   23,    5, 16,  2,  0 },
    {     10,   23,    5, 16,  2,  0 }, {     11,   23,    6, 16,  2,  0 }, {     12,   23,    6, 16,  2,  0 }, {     13,   23,    7, 16,  2,  0 }, {     14,   23,    7, 16,  2,  0 },
    {     15,   23,    8, 16,  2,  0 }, {     16,   23,    8, 16,  2,  0 }, {     17,   23,    9, 16,  2,  0 }, {     18,   23,    9, 16,  2,  0 }, {     19,   23,   10, 16,  2,  0 },
    {     20,   23,   10, 16,  2,  0 }, {     21,   23,   11, 16,  2,  0 }, {     22,   23,   11, 16,  2,  0 }, {     23,   23,   12, 16,  2,  0 }, {     24,   23,   12, 16,  2,  0 },
    {     25,   23,   13, 16,  2,  0 }, {     26,   23,   13, 16,  2,  0 }, {     27,   23,   14, 16,  2,  0 }, {     28,   23,   14, 16,  2,  0 }, {     29,   23,   15, 16,  2,  0 },
    {     30,   23,   15, 16,  2,  0 }, {     31,   23,   16, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9011B8, {
    {     23,   31,    0, 24,  2,  0 }, {     23,   30,    0, 24,  2,  0 }, {     23,   29,    1, 24,  2,  0 }, {     23,   28,    1, 24,  2,  0 }, {     23,   27,    2, 24,  2,  0 },
    {     23,   26,    2, 24,  2,  0 }, {     23,   25,    3, 24,  2,  0 }, {     23,   24,    3, 24,  2,  0 }, {     23,   23,    4, 24,  2,  0 }, {     23,   22,    4, 24,  2,  0 },
    {     23,   21,    5, 24,  2,  0 }, {     23,   20,    5, 24,  2,  0 }, {     23,   19,    6, 24,  2,  0 }, {     23,   18,    6, 24,  2,  0 }, {     23,   17,    7, 24,  2,  0 },
    {     23,   16,    7, 24,  2,  0 }, {     23,   15,    8, 24,  2,  0 }, {     23,   14,    8, 24,  2,  0 }, {     23,   13,    9, 24,  2,  0 }, {     23,   12,    9, 24,  2,  0 },
    {     23,   11,   10, 24,  2,  0 }, {     23,   10,   10, 24,  2,  0 }, {     23,    9,   11, 24,  2,  0 }, {     23,    8,   11, 24,  2,  0 }, {     23,    7,   12, 24,  2,  0 },
    {     23,    6,   12, 24,  2,  0 }, {     23,    5,   13, 24,  2,  0 }, {     23,    4,   13, 24,  2,  0 }, {     23,    3,   14, 24,  2,  0 }, {     23,    2,   14, 24,  2,  0 },
    {     23,    1,   15, 24,  2,  0 }, {     23,    0,   15, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FFBEA, {
    {     31,    9,    0,  0,  0,  0 }, {     30,    9,    0,  0,  0,  0 }, {     29,    9,    0,  0,  0,  0 }, {     28,    9,    0,  0,  0,  0 }, {     27,    9,    0,  0,  0,  0 },
    {     26,    9,    0,  0,  0,  0 }, {     25,    9,    0,  0,  0,  0 }, {     24,    9,    0,  0,  0,  0 }, {     23,    9,    0,  0,  1,  0 }, {     22,    9,    0,  0,  1,  0 },
    {     21,    9,    1,  0,  1,  0 }, {     20,    9,    1,  0,  1,  0 }, {     19,    9,    1,  0,  1,  0 }, {     18,    9,    1,  0,  1,  0 }, {     17,    9,    1,  0,  1,  0 },
    {     16,    9,    1,  0,  1,  0 }, {     15,    9,    2,  0,  1,  0 }, {     14,    9,    2,  0,  1,  0 }, {     13,    9,    2,  0,  1,  0 }, {     12,    9,    2,  0,  1,  0 },
    {     11,    9,    3,  0,  1,  0 }, {     10,    9,    3,  0,  1,  0 }, {      9,    9,    3,  0,  1,  0 }, {      8,    9,    4,  0,  1,  0 }, {      7,    9,    4,  0,  2,  0 },
    {      6,    9,    5,  0,  2,  0 }, {      5,    9,    5,  0,  2,  0 }, {      4,    9,    6,  0,  2,  0 }, {      3,    9,    6,  0,  2,  0 }, {      2,    9,    7,  0,  2,  0 },
    {      1,    9,    7,  0,  2,  0 }, {      0,    9,    8,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FFD0C, {
    {      9,    0,    0,  8,  0,  0 }, {      9,    1,    0,  8,  0,  0 }, {      9,    2,    0,  8,  0,  0 }, {      9,    3,    0,  8,  0,  0 }, {      9,    4,    0,  8,  0,  0 },
    {      9,    5,    0,  8,  0,  0 }, {      9,    6,    0,  8,  0,  0 }, {      9,    7,    0,  8,  0,  0 }, {      9,    8,    0,  8,  1,  0 }, {      9,    9,    0,  8,  1,  0 },
    {      9,   10,    1,  8,  1,  0 }, {      9,   11,    1,  8,  1,  0 }, {      9,   12,    1,  8,  1,  0 }, {      9,   13,    1,  8,  1,  0 }, {      9,   14,    1,  8,  1,  0 },
    {      9,   15,    1,  8,  1,  0 }, {      9,   16,    2,  8,  1,  0 }, {      9,   17,    2,  8,  1,  0 }, {      9,   18,    2,  8,  1,  0 }, {      9,   19,    2,  8,  1,  0 },
    {      9,   20,    3,  8,  1,  0 }, {      9,   21,    3,  8,  1,  0 }, {      9,   22,    3,  8,  1,  0 }, {      9,   23,    4,  8,  1,  0 }, {      9,   24,    4,  8,  2,  0 },
    {      9,   25,    4,  8,  2,  0 }, {      9,   26,    5,  8,  2,  0 }, {      9,   27,    5,  8,  2,  0 }, {      9,   28,    6,  8,  2,  0 }, {      9,   29,    6,  8,  2,  0 },
    {      9,   30,    7,  8,  2,  0 }, {      9,   31,    7,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FFE2E, {
    {      0,   23,    0, 16,  0,  0 }, {      1,   23,    0, 16,  0,  0 }, {      2,   23,    0, 16,  0,  0 }, {      3,   23,    0, 16,  0,  0 }, {      4,   23,    0, 16,  0,  0 },
    {      5,   23,    0, 16,  0,  0 }, {      6,   23,    0, 16,  0,  0 }, {      7,   23,    0, 16,  0,  0 }, {      8,   23,    0, 16,  1,  0 }, {      9,   23,    0, 16,  1,  0 },
    {     10,   23,    1, 16,  1,  0 }, {     11,   23,    1, 16,  1,  0 }, {     12,   23,    1, 16,  1,  0 }, {     13,   23,    1, 16,  1,  0 }, {     14,   23,    1, 16,  1,  0 },
    {     15,   23,    1, 16,  1,  0 }, {     16,   23,    2, 16,  1,  0 }, {     17,   23,    2, 16,  1,  0 }, {     18,   23,    2, 16,  1,  0 }, {     19,   23,    2, 16,  1,  0 },
    {     20,   23,    3, 16,  1,  0 }, {     21,   23,    3, 16,  1,  0 }, {     22,   23,    3, 16,  1,  0 }, {     23,   23,    4, 16,  1,  0 }, {     24,   23,    4, 16,  2,  0 },
    {     25,   23,    4, 16,  2,  0 }, {     26,   23,    5, 16,  2,  0 }, {     27,   23,    5, 16,  2,  0 }, {     28,   23,    6, 16,  2,  0 }, {     29,   23,    6, 16,  2,  0 },
    {     30,   23,    7, 16,  2,  0 }, {     31,   23,    7, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FFF50, {
    {     23,   31,    0, 24,  0,  0 }, {     23,   30,    0, 24,  0,  0 }, {     23,   29,    0, 24,  0,  0 }, {     23,   28,    0, 24,  0,  0 }, {     23,   27,    0, 24,  0,  0 },
    {     23,   26,    0, 24,  0,  0 }, {     23,   25,    0, 24,  0,  0 }, {     23,   24,    0, 24,  0,  0 }, {     23,   23,    0, 24,  1,  0 }, {     23,   22,    0, 24,  1,  0 },
    {     23,   21,    1, 24,  1,  0 }, {     23,   20,    1, 24,  1,  0 }, {     23,   19,    1, 24,  1,  0 }, {     23,   18,    1, 24,  1,  0 }, {     23,   17,    1, 24,  1,  0 },
    {     23,   16,    1, 24,  1,  0 }, {     23,   15,    2, 24,  1,  0 }, {     23,   14,    2, 24,  1,  0 }, {     23,   13,    2, 24,  1,  0 }, {     23,   12,    2, 24,  1,  0 },
    {     23,   11,    3, 24,  1,  0 }, {     23,   10,    3, 24,  1,  0 }, {     23,    9,    3, 24,  1,  0 }, {     23,    8,    4, 24,  1,  0 }, {     23,    7,    4, 24,  2,  0 },
    {     23,    6,    5, 24,  2,  0 }, {     23,    5,    5, 24,  2,  0 }, {     23,    4,    6, 24,  2,  0 }, {     23,    3,    6, 24,  2,  0 }, {     23,    2,    7, 24,  2,  0 },
    {     23,    1,    7, 24,  2,  0 }, {     23,    0,    8, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_900072, {
    {     31,    9,    0,  0,  2,  0 }, {     30,    9,    1,  0,  2,  0 }, {     29,    9,    1,  0,  2,  0 }, {     28,    9,    2,  0,  2,  0 }, {     27,    9,    2,  0,  2,  0 },
    {     26,    9,    3,  0,  2,  0 }, {     25,    9,    3,  0,  2,  0 }, {     24,    9,    3,  0,  2,  0 }, {     23,    9,    4,  0,  1,  0 }, {     22,    9,    4,  0,  1,  0 },
    {     21,    9,    4,  0,  1,  0 }, {     20,    9,    5,  0,  1,  0 }, {     19,    9,    5,  0,  1,  0 }, {     18,    9,    5,  0,  1,  0 }, {     17,    9,    6,  0,  1,  0 },
    {     16,    9,    6,  0,  1,  0 }, {     15,    9,    6,  0,  1,  0 }, {     14,    9,    6,  0,  1,  0 }, {     13,    9,    7,  0,  1,  0 }, {     12,    9,    7,  0,  1,  0 },
    {     11,    9,    7,  0,  1,  0 }, {     10,    9,    7,  0,  1,  0 }, {      9,    9,    7,  0,  0,  0 }, {      8,    9,    7,  0,  0,  0 }, {      7,    9,    8,  0,  0,  0 },
    {      6,    9,    8,  0,  0,  0 }, {      5,    9,    8,  0,  0,  0 }, {      4,    9,    8,  0,  0,  0 }, {      3,    9,    8,  0,  0,  0 }, {      2,    9,    8,  0,  0,  0 },
    {      1,    9,    8,  0,  0,  0 }, {      0,    9,    8,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9001A6, {
    {      9,    0,    0,  8,  2,  0 }, {      9,    1,    0,  8,  2,  0 }, {      9,    2,    1,  8,  2,  0 }, {      9,    3,    1,  8,  2,  0 }, {      9,    4,    2,  8,  2,  0 },
    {      9,    5,    2,  8,  2,  0 }, {      9,    6,    3,  8,  2,  0 }, {      9,    7,    3,  8,  2,  0 }, {      9,    8,    4,  8,  1,  0 }, {      9,    9,    4,  8,  1,  0 },
    {      9,   10,    4,  8,  1,  0 }, {      9,   11,    5,  8,  1,  0 }, {      9,   12,    5,  8,  1,  0 }, {      9,   13,    5,  8,  1,  0 }, {      9,   14,    6,  8,  1,  0 },
    {      9,   15,    6,  8,  1,  0 }, {      9,   16,    6,  8,  1,  0 }, {      9,   17,    6,  8,  1,  0 }, {      9,   18,    7,  8,  1,  0 }, {      9,   19,    7,  8,  1,  0 },
    {      9,   20,    7,  8,  1,  0 }, {      9,   21,    7,  8,  1,  0 }, {      9,   22,    7,  8,  0,  0 }, {      9,   23,    7,  8,  0,  0 }, {      9,   24,    8,  8,  0,  0 },
    {      9,   25,    8,  8,  0,  0 }, {      9,   26,    8,  8,  0,  0 }, {      9,   27,    8,  8,  0,  0 }, {      9,   28,    8,  8,  0,  0 }, {      9,   29,    8,  8,  0,  0 },
    {      9,   30,    8,  8,  0,  0 }, {      9,   31,    8,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9002DA, {
    {      0,   23,    0, 16,  2,  0 }, {      1,   23,    0, 16,  2,  0 }, {      2,   23,    1, 16,  2,  0 }, {      3,   23,    1, 16,  2,  0 }, {      4,   23,    2, 16,  2,  0 },
    {      5,   23,    2, 16,  2,  0 }, {      6,   23,    3, 16,  2,  0 }, {      7,   23,    3, 16,  2,  0 }, {      8,   23,    4, 16,  1,  0 }, {      9,   23,    4, 16,  1,  0 },
    {     10,   23,    4, 16,  1,  0 }, {     11,   23,    5, 16,  1,  0 }, {     12,   23,    5, 16,  1,  0 }, {     13,   23,    5, 16,  1,  0 }, {     14,   23,    6, 16,  1,  0 },
    {     15,   23,    6, 16,  1,  0 }, {     16,   23,    6, 16,  1,  0 }, {     17,   23,    6, 16,  1,  0 }, {     18,   23,    7, 16,  1,  0 }, {     19,   23,    7, 16,  1,  0 },
    {     20,   23,    7, 16,  1,  0 }, {     21,   23,    7, 16,  1,  0 }, {     22,   23,    7, 16,  0,  0 }, {     23,   23,    7, 16,  0,  0 }, {     24,   23,    8, 16,  0,  0 },
    {     25,   23,    8, 16,  0,  0 }, {     26,   23,    8, 16,  0,  0 }, {     27,   23,    8, 16,  0,  0 }, {     28,   23,    8, 16,  0,  0 }, {     29,   23,    8, 16,  0,  0 },
    {     30,   23,    8, 16,  0,  0 }, {     31,   23,    8, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90040E, {
    {     23,   31,    0, 24,  2,  0 }, {     23,   30,    1, 24,  2,  0 }, {     23,   29,    1, 24,  2,  0 }, {     23,   28,    2, 24,  2,  0 }, {     23,   27,    2, 24,  2,  0 },
    {     23,   26,    3, 24,  2,  0 }, {     23,   25,    3, 24,  2,  0 }, {     23,   24,    3, 24,  2,  0 }, {     23,   23,    4, 24,  1,  0 }, {     23,   22,    4, 24,  1,  0 },
    {     23,   21,    4, 24,  1,  0 }, {     23,   20,    5, 24,  1,  0 }, {     23,   19,    5, 24,  1,  0 }, {     23,   18,    5, 24,  1,  0 }, {     23,   17,    6, 24,  1,  0 },
    {     23,   16,    6, 24,  1,  0 }, {     23,   15,    6, 24,  1,  0 }, {     23,   14,    6, 24,  1,  0 }, {     23,   13,    7, 24,  1,  0 }, {     23,   12,    7, 24,  1,  0 },
    {     23,   11,    7, 24,  1,  0 }, {     23,   10,    7, 24,  1,  0 }, {     23,    9,    7, 24,  0,  0 }, {     23,    8,    7, 24,  0,  0 }, {     23,    7,    8, 24,  0,  0 },
    {     23,    6,    8, 24,  0,  0 }, {     23,    5,    8, 24,  0,  0 }, {     23,    4,    8, 24,  0,  0 }, {     23,    3,    8, 24,  0,  0 }, {     23,    2,    8, 24,  0,  0 },
    {     23,    1,    8, 24,  0,  0 }, {     23,    0,    8, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9012DA, {
    {     31,    9,   15,  0,  6,  0 }, {     30,    9,   14,  0,  6,  0 }, {     29,    9,   14,  0,  6,  0 }, {     28,    9,   13,  0,  6,  0 }, {     27,    9,   13,  0,  6,  0 },
    {     26,    9,   12,  0,  6,  0 }, {     25,    9,   12,  0,  6,  0 }, {     24,    9,   11,  0,  6,  0 }, {     23,    9,   11,  0,  6,  0 }, {     22,    9,   10,  0,  6,  0 },
    {     21,    9,   10,  0,  6,  0 }, {     20,    9,    9,  0,  6,  0 }, {     19,    9,    9,  0,  6,  0 }, {     18,    9,    8,  0,  6,  0 }, {     17,    9,    8,  0,  6,  0 },
    {     16,    9,    7,  0,  6,  0 }, {     15,    9,    7,  0,  6,  0 }, {     14,    9,    6,  0,  6,  0 }, {     13,    9,    6,  0,  6,  0 }, {     12,    9,    5,  0,  6,  0 },
    {     11,    9,    5,  0,  6,  0 }, {     10,    9,    4,  0,  6,  0 }, {      9,    9,    4,  0,  6,  0 }, {      8,    9,    3,  0,  6,  0 }, {      7,    9,    3,  0,  6,  0 },
    {      6,    9,    2,  0,  6,  0 }, {      5,    9,    2,  0,  6,  0 }, {      4,    9,    1,  0,  6,  0 }, {      3,    9,    1,  0,  6,  0 }, {      2,    9,    0,  0,  6,  0 },
    {      1,    9,    0,  0,  6,  0 }, {      0,    9,   -1,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9013FC, {
    {      9,    0,   15,  8,  6,  0 }, {      9,    1,   15,  8,  6,  0 }, {      9,    2,   14,  8,  6,  0 }, {      9,    3,   14,  8,  6,  0 }, {      9,    4,   13,  8,  6,  0 },
    {      9,    5,   13,  8,  6,  0 }, {      9,    6,   12,  8,  6,  0 }, {      9,    7,   12,  8,  6,  0 }, {      9,    8,   11,  8,  6,  0 }, {      9,    9,   11,  8,  6,  0 },
    {      9,   10,   10,  8,  6,  0 }, {      9,   11,   10,  8,  6,  0 }, {      9,   12,    9,  8,  6,  0 }, {      9,   13,    9,  8,  6,  0 }, {      9,   14,    8,  8,  6,  0 },
    {      9,   15,    8,  8,  6,  0 }, {      9,   16,    7,  8,  6,  0 }, {      9,   17,    7,  8,  6,  0 }, {      9,   18,    6,  8,  6,  0 }, {      9,   19,    6,  8,  6,  0 },
    {      9,   20,    5,  8,  6,  0 }, {      9,   21,    5,  8,  6,  0 }, {      9,   22,    4,  8,  6,  0 }, {      9,   23,    4,  8,  6,  0 }, {      9,   24,    3,  8,  6,  0 },
    {      9,   25,    3,  8,  6,  0 }, {      9,   26,    2,  8,  6,  0 }, {      9,   27,    2,  8,  6,  0 }, {      9,   28,    1,  8,  6,  0 }, {      9,   29,    1,  8,  6,  0 },
    {      9,   30,    0,  8,  6,  0 }, {      9,   31,    0,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90151E, {
    {      0,   23,   15, 16,  6,  0 }, {      1,   23,   15, 16,  6,  0 }, {      2,   23,   14, 16,  6,  0 }, {      3,   23,   14, 16,  6,  0 }, {      4,   23,   13, 16,  6,  0 },
    {      5,   23,   13, 16,  6,  0 }, {      6,   23,   12, 16,  6,  0 }, {      7,   23,   12, 16,  6,  0 }, {      8,   23,   11, 16,  6,  0 }, {      9,   23,   11, 16,  6,  0 },
    {     10,   23,   10, 16,  6,  0 }, {     11,   23,   10, 16,  6,  0 }, {     12,   23,    9, 16,  6,  0 }, {     13,   23,    9, 16,  6,  0 }, {     14,   23,    8, 16,  6,  0 },
    {     15,   23,    8, 16,  6,  0 }, {     16,   23,    7, 16,  6,  0 }, {     17,   23,    7, 16,  6,  0 }, {     18,   23,    6, 16,  6,  0 }, {     19,   23,    6, 16,  6,  0 },
    {     20,   23,    5, 16,  6,  0 }, {     21,   23,    5, 16,  6,  0 }, {     22,   23,    4, 16,  6,  0 }, {     23,   23,    4, 16,  6,  0 }, {     24,   23,    3, 16,  6,  0 },
    {     25,   23,    3, 16,  6,  0 }, {     26,   23,    2, 16,  6,  0 }, {     27,   23,    2, 16,  6,  0 }, {     28,   23,    1, 16,  6,  0 }, {     29,   23,    1, 16,  6,  0 },
    {     30,   23,    0, 16,  6,  0 }, {     31,   23,    0, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_901640, {
    {     23,   31,   15, 24,  6,  0 }, {     23,   30,   14, 24,  6,  0 }, {     23,   29,   14, 24,  6,  0 }, {     23,   28,   13, 24,  6,  0 }, {     23,   27,   13, 24,  6,  0 },
    {     23,   26,   12, 24,  6,  0 }, {     23,   25,   12, 24,  6,  0 }, {     23,   24,   11, 24,  6,  0 }, {     23,   23,   11, 24,  6,  0 }, {     23,   22,   10, 24,  6,  0 },
    {     23,   21,   10, 24,  6,  0 }, {     23,   20,    9, 24,  6,  0 }, {     23,   19,    9, 24,  6,  0 }, {     23,   18,    8, 24,  6,  0 }, {     23,   17,    8, 24,  6,  0 },
    {     23,   16,    7, 24,  6,  0 }, {     23,   15,    7, 24,  6,  0 }, {     23,   14,    6, 24,  6,  0 }, {     23,   13,    6, 24,  6,  0 }, {     23,   12,    5, 24,  6,  0 },
    {     23,   11,    5, 24,  6,  0 }, {     23,   10,    4, 24,  6,  0 }, {     23,    9,    4, 24,  6,  0 }, {     23,    8,    3, 24,  6,  0 }, {     23,    7,    3, 24,  6,  0 },
    {     23,    6,    2, 24,  6,  0 }, {     23,    5,    2, 24,  6,  0 }, {     23,    4,    1, 24,  6,  0 }, {     23,    3,    1, 24,  6,  0 }, {     23,    2,    0, 24,  6,  0 },
    {     23,    1,    0, 24,  6,  0 }, {     23,    0,   -1, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9009CA, {
    {     31,    9,    8,  0,  0,  0 }, {     30,    9,    8,  0,  0,  0 }, {     29,    9,    8,  0,  0,  0 }, {     28,    9,    8,  0,  0,  0 }, {     27,    9,    8,  0,  0,  0 },
    {     26,    9,    8,  0,  0,  0 }, {     25,    9,    8,  0,  0,  0 }, {     24,    9,    8,  0,  0,  0 }, {     23,    9,    7,  0,  5,  0 }, {     22,    9,    7,  0,  5,  0 },
    {     21,    9,    7,  0,  5,  0 }, {     20,    9,    7,  0,  5,  0 }, {     19,    9,    7,  0,  5,  0 }, {     18,    9,    7,  0,  5,  0 }, {     17,    9,    6,  0,  5,  0 },
    {     16,    9,    6,  0,  5,  0 }, {     15,    9,    6,  0,  5,  0 }, {     14,    9,    6,  0,  5,  0 }, {     13,    9,    5,  0,  5,  0 }, {     12,    9,    5,  0,  5,  0 },
    {     11,    9,    5,  0,  5,  0 }, {     10,    9,    4,  0,  5,  0 }, {      9,    9,    4,  0,  5,  0 }, {      8,    9,    4,  0,  5,  0 }, {      7,    9,    3,  0,  6,  0 },
    {      6,    9,    3,  0,  6,  0 }, {      5,    9,    2,  0,  6,  0 }, {      4,    9,    2,  0,  6,  0 }, {      3,    9,    1,  0,  6,  0 }, {      2,    9,    1,  0,  6,  0 },
    {      1,    9,    0,  0,  6,  0 }, {      0,    9,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_900AEC, {
    {      9,    0,    8,  8,  0,  0 }, {      9,    1,    8,  8,  0,  0 }, {      9,    2,    8,  8,  0,  0 }, {      9,    3,    8,  8,  0,  0 }, {      9,    4,    8,  8,  0,  0 },
    {      9,    5,    8,  8,  0,  0 }, {      9,    6,    8,  8,  0,  0 }, {      9,    7,    8,  8,  0,  0 }, {      9,    8,    7,  8,  5,  0 }, {      9,    9,    7,  8,  5,  0 },
    {      9,   10,    7,  8,  5,  0 }, {      9,   11,    7,  8,  5,  0 }, {      9,   12,    7,  8,  5,  0 }, {      9,   13,    7,  8,  5,  0 }, {      9,   14,    6,  8,  5,  0 },
    {      9,   15,    6,  8,  5,  0 }, {      9,   16,    6,  8,  5,  0 }, {      9,   17,    6,  8,  5,  0 }, {      9,   18,    5,  8,  5,  0 }, {      9,   19,    5,  8,  5,  0 },
    {      9,   20,    5,  8,  5,  0 }, {      9,   21,    4,  8,  5,  0 }, {      9,   22,    4,  8,  5,  0 }, {      9,   23,    4,  8,  5,  0 }, {      9,   24,    3,  8,  6,  0 },
    {      9,   25,    3,  8,  6,  0 }, {      9,   26,    3,  8,  6,  0 }, {      9,   27,    2,  8,  6,  0 }, {      9,   28,    2,  8,  6,  0 }, {      9,   29,    1,  8,  6,  0 },
    {      9,   30,    1,  8,  6,  0 }, {      9,   31,    0,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_900C0E, {
    {      0,   23,    8, 16,  0,  0 }, {      1,   23,    8, 16,  0,  0 }, {      2,   23,    8, 16,  0,  0 }, {      3,   23,    8, 16,  0,  0 }, {      4,   23,    8, 16,  0,  0 },
    {      5,   23,    8, 16,  0,  0 }, {      6,   23,    8, 16,  0,  0 }, {      7,   23,    8, 16,  0,  0 }, {      8,   23,    7, 16,  5,  0 }, {      9,   23,    7, 16,  5,  0 },
    {     10,   23,    7, 16,  5,  0 }, {     11,   23,    7, 16,  5,  0 }, {     12,   23,    7, 16,  5,  0 }, {     13,   23,    7, 16,  5,  0 }, {     14,   23,    6, 16,  5,  0 },
    {     15,   23,    6, 16,  5,  0 }, {     16,   23,    6, 16,  5,  0 }, {     17,   23,    6, 16,  5,  0 }, {     18,   23,    5, 16,  5,  0 }, {     19,   23,    5, 16,  5,  0 },
    {     20,   23,    5, 16,  5,  0 }, {     21,   23,    4, 16,  5,  0 }, {     22,   23,    4, 16,  5,  0 }, {     23,   23,    4, 16,  5,  0 }, {     24,   23,    3, 16,  6,  0 },
    {     25,   23,    3, 16,  6,  0 }, {     26,   23,    3, 16,  6,  0 }, {     27,   23,    2, 16,  6,  0 }, {     28,   23,    2, 16,  6,  0 }, {     29,   23,    1, 16,  6,  0 },
    {     30,   23,    1, 16,  6,  0 }, {     31,   23,    0, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_900D30, {
    {     23,   31,    8, 24,  0,  0 }, {     23,   30,    8, 24,  0,  0 }, {     23,   29,    8, 24,  0,  0 }, {     23,   28,    8, 24,  0,  0 }, {     23,   27,    8, 24,  0,  0 },
    {     23,   26,    8, 24,  0,  0 }, {     23,   25,    8, 24,  0,  0 }, {     23,   24,    8, 24,  0,  0 }, {     23,   23,    7, 24,  5,  0 }, {     23,   22,    7, 24,  5,  0 },
    {     23,   21,    7, 24,  5,  0 }, {     23,   20,    7, 24,  5,  0 }, {     23,   19,    7, 24,  5,  0 }, {     23,   18,    7, 24,  5,  0 }, {     23,   17,    6, 24,  5,  0 },
    {     23,   16,    6, 24,  5,  0 }, {     23,   15,    6, 24,  5,  0 }, {     23,   14,    6, 24,  5,  0 }, {     23,   13,    5, 24,  5,  0 }, {     23,   12,    5, 24,  5,  0 },
    {     23,   11,    5, 24,  5,  0 }, {     23,   10,    4, 24,  5,  0 }, {     23,    9,    4, 24,  5,  0 }, {     23,    8,    4, 24,  5,  0 }, {     23,    7,    3, 24,  6,  0 },
    {     23,    6,    3, 24,  6,  0 }, {     23,    5,    2, 24,  6,  0 }, {     23,    4,    2, 24,  6,  0 }, {     23,    3,    1, 24,  6,  0 }, {     23,    2,    1, 24,  6,  0 },
    {     23,    1,    0, 24,  6,  0 }, {     23,    0,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_900542, {
    {     31,    9,    7,  0,  6,  0 }, {     30,    9,    7,  0,  6,  0 }, {     29,    9,    6,  0,  6,  0 }, {     28,    9,    6,  0,  6,  0 }, {     27,    9,    5,  0,  6,  0 },
    {     26,    9,    5,  0,  6,  0 }, {     25,    9,    4,  0,  6,  0 }, {     24,    9,    4,  0,  6,  0 }, {     23,    9,    4,  0,  5,  0 }, {     22,    9,    3,  0,  5,  0 },
    {     21,    9,    3,  0,  5,  0 }, {     20,    9,    3,  0,  5,  0 }, {     19,    9,    2,  0,  5,  0 }, {     18,    9,    2,  0,  5,  0 }, {     17,    9,    2,  0,  5,  0 },
    {     16,    9,    2,  0,  5,  0 }, {     15,    9,    1,  0,  5,  0 }, {     14,    9,    1,  0,  5,  0 }, {     13,    9,    1,  0,  5,  0 }, {     12,    9,    1,  0,  5,  0 },
    {     11,    9,    1,  0,  5,  0 }, {     10,    9,    1,  0,  5,  0 }, {      9,    9,    0,  0,  0,  0 }, {      8,    9,    0,  0,  0,  0 }, {      7,    9,    0,  0,  0,  0 },
    {      6,    9,    0,  0,  0,  0 }, {      5,    9,    0,  0,  0,  0 }, {      4,    9,    0,  0,  0,  0 }, {      3,    9,    0,  0,  0,  0 }, {      2,    9,    0,  0,  0,  0 },
    {      1,    9,    0,  0,  0,  0 }, {      0,    9,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_900664, {
    {      9,    0,    8,  8,  6,  0 }, {      9,    1,    7,  8,  6,  0 }, {      9,    2,    7,  8,  6,  0 }, {      9,    3,    6,  8,  6,  0 }, {      9,    4,    6,  8,  6,  0 },
    {      9,    5,    5,  8,  6,  0 }, {      9,    6,    5,  8,  6,  0 }, {      9,    7,    4,  8,  6,  0 }, {      9,    8,    4,  8,  5,  0 }, {      9,    9,    3,  8,  5,  0 },
    {      9,   10,    3,  8,  5,  0 }, {      9,   11,    3,  8,  5,  0 }, {      9,   12,    2,  8,  5,  0 }, {      9,   13,    2,  8,  5,  0 }, {      9,   14,    2,  8,  5,  0 },
    {      9,   15,    2,  8,  5,  0 }, {      9,   16,    1,  8,  5,  0 }, {      9,   17,    1,  8,  5,  0 }, {      9,   18,    1,  8,  5,  0 }, {      9,   19,    1,  8,  5,  0 },
    {      9,   20,    1,  8,  5,  0 }, {      9,   21,    1,  8,  5,  0 }, {      9,   22,    0,  8,  0,  0 }, {      9,   23,    0,  8,  0,  0 }, {      9,   24,    0,  8,  0,  0 },
    {      9,   25,    0,  8,  0,  0 }, {      9,   26,    0,  8,  0,  0 }, {      9,   27,    0,  8,  0,  0 }, {      9,   28,    0,  8,  0,  0 }, {      9,   29,    0,  8,  0,  0 },
    {      9,   30,    0,  8,  0,  0 }, {      9,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_900786, {
    {      0,   23,    8, 16,  6,  0 }, {      1,   23,    7, 16,  6,  0 }, {      2,   23,    7, 16,  6,  0 }, {      3,   23,    6, 16,  6,  0 }, {      4,   23,    6, 16,  6,  0 },
    {      5,   23,    5, 16,  6,  0 }, {      6,   23,    5, 16,  6,  0 }, {      7,   23,    4, 16,  6,  0 }, {      8,   23,    4, 16,  5,  0 }, {      9,   23,    3, 16,  5,  0 },
    {     10,   23,    3, 16,  5,  0 }, {     11,   23,    3, 16,  5,  0 }, {     12,   23,    2, 16,  5,  0 }, {     13,   23,    2, 16,  5,  0 }, {     14,   23,    2, 16,  5,  0 },
    {     15,   23,    2, 16,  5,  0 }, {     16,   23,    1, 16,  5,  0 }, {     17,   23,    1, 16,  5,  0 }, {     18,   23,    1, 16,  5,  0 }, {     19,   23,    1, 16,  5,  0 },
    {     20,   23,    1, 16,  5,  0 }, {     21,   23,    1, 16,  5,  0 }, {     22,   23,    0, 16,  0,  0 }, {     23,   23,    0, 16,  0,  0 }, {     24,   23,    0, 16,  0,  0 },
    {     25,   23,    0, 16,  0,  0 }, {     26,   23,    0, 16,  0,  0 }, {     27,   23,    0, 16,  0,  0 }, {     28,   23,    0, 16,  0,  0 }, {     29,   23,    0, 16,  0,  0 },
    {     30,   23,    0, 16,  0,  0 }, {     31,   23,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9008A8, {
    {     23,   31,    7, 24,  6,  0 }, {     23,   30,    7, 24,  6,  0 }, {     23,   29,    6, 24,  6,  0 }, {     23,   28,    6, 24,  6,  0 }, {     23,   27,    5, 24,  6,  0 },
    {     23,   26,    5, 24,  6,  0 }, {     23,   25,    4, 24,  6,  0 }, {     23,   24,    4, 24,  6,  0 }, {     23,   23,    4, 24,  5,  0 }, {     23,   22,    3, 24,  5,  0 },
    {     23,   21,    3, 24,  5,  0 }, {     23,   20,    3, 24,  5,  0 }, {     23,   19,    2, 24,  5,  0 }, {     23,   18,    2, 24,  5,  0 }, {     23,   17,    2, 24,  5,  0 },
    {     23,   16,    2, 24,  5,  0 }, {     23,   15,    1, 24,  5,  0 }, {     23,   14,    1, 24,  5,  0 }, {     23,   13,    1, 24,  5,  0 }, {     23,   12,    1, 24,  5,  0 },
    {     23,   11,    1, 24,  5,  0 }, {     23,   10,    1, 24,  5,  0 }, {     23,    9,    0, 24,  0,  0 }, {     23,    8,    0, 24,  0,  0 }, {     23,    7,    0, 24,  0,  0 },
    {     23,    6,    0, 24,  0,  0 }, {     23,    5,    0, 24,  0,  0 }, {     23,    4,    0, 24,  0,  0 }, {     23,    3,    0, 24,  0,  0 }, {     23,    2,    0, 24,  0,  0 },
    {     23,    1,    0, 24,  0,  0 }, {     23,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_901C05, {
    {     31,    9,    0,  0,  0,  0 }, {     30,    9,    0, 31,  0,  0 }, {     29,    9,    0, 31,  0,  0 }, {     28,    8,    0, 30,  0,  0 }, {     27,    8,    0, 30,  0,  0 },
    {     26,    7,    0, 28,  0,  0 }, {     25,    6,    0, 28,  0,  0 }, {     24,    5,    0, 26,  0,  0 }, {     24,    4,    0, 26,  0,  0 }, {     23,    3,    0, 25,  0,  0 },
    {     23,    2,    0, 25,  0,  0 }, {     23,    1,    0, 24,  0,  0 }, {     23,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_901C7C, {
    {      9,    0,    0,  8,  0,  0 }, {      9,    1,    0,  8,  0,  0 }, {      9,    2,    0,  7,  0,  0 }, {      9,    3,    0,  7,  0,  0 }, {      8,    4,    0,  6,  0,  0 },
    {      8,    5,    0,  6,  0,  0 }, {      7,    6,    0,  4,  0,  0 }, {      6,    7,    0,  4,  0,  0 }, {      5,    8,    0,  2,  0,  0 }, {      4,    8,    0,  2,  0,  0 },
    {      3,    9,    0,  1,  0,  0 }, {      2,    9,    0,  1,  0,  0 }, {      1,    9,    0,  0,  0,  0 }, {      0,    9,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_901CFC, {
    {      0,   23,    0, 16,  0,  0 }, {      1,   23,    0, 16,  0,  0 }, {      2,   23,    0, 15,  0,  0 }, {      3,   23,    0, 15,  0,  0 }, {      4,   24,    0, 14,  0,  0 },
    {      5,   24,    0, 14,  0,  0 }, {      6,   25,    0, 12,  0,  0 }, {      7,   26,    0, 12,  0,  0 }, {      8,   27,    0, 10,  0,  0 }, {      8,   28,    0, 10,  0,  0 },
    {      9,   29,    0,  9,  0,  0 }, {      9,   30,    0,  9,  0,  0 }, {      9,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_901D73, {
    {     23,   31,    0, 24,  0,  0 }, {     23,   30,    0, 23,  0,  0 }, {     23,   29,    0, 23,  0,  0 }, {     24,   28,    0, 22,  0,  0 }, {     24,   27,    0, 22,  0,  0 },
    {     25,   26,    0, 20,  0,  0 }, {     26,   25,    0, 20,  0,  0 }, {     27,   24,    0, 18,  0,  0 }, {     28,   24,    0, 18,  0,  0 }, {     29,   23,    0, 17,  0,  0 },
    {     30,   23,    0, 17,  0,  0 }, {     31,   23,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_901762, {
    {     31,    9,    0,  0,  0,  0 }, {     30,    9,    0,  0,  0,  0 }, {     29,    9,    0,  0,  0,  0 }, {     28,    9,    0,  1,  0,  0 }, {     27,    9,    0,  1,  0,  0 },
    {     26,   10,    0,  1,  0,  0 }, {     25,   10,    0,  1,  0,  0 }, {     24,   10,    0,  2,  0,  0 }, {     23,   11,    0,  2,  0,  0 }, {     22,   11,    0,  2,  0,  0 },
    {     21,   11,    0,  2,  0,  0 }, {     20,   12,    0,  3,  0,  0 }, {     19,   12,    0,  3,  0,  0 }, {     18,   13,    0,  3,  0,  0 }, {     17,   14,    0,  3,  0,  0 },
    {     16,   15,    0,  4,  0,  0 }, {     15,   16,    0,  4,  0,  0 }, {     14,   17,    0,  5,  0,  0 }, {     13,   18,    0,  5,  0,  0 }, {     12,   19,    0,  5,  0,  0 },
    {     12,   20,    0,  5,  0,  0 }, {     11,   21,    0,  6,  0,  0 }, {     11,   22,    0,  6,  0,  0 }, {     11,   23,    0,  6,  0,  0 }, {     10,   24,    0,  6,  0,  0 },
    {     10,   25,    0,  7,  0,  0 }, {     10,   26,    0,  7,  0,  0 }, {      9,   27,    0,  7,  0,  0 }, {      9,   28,    0,  7,  0,  0 }, {      9,   29,    0,  8,  0,  0 },
    {      9,   30,    0,  8,  0,  0 }, {      9,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_901884, {
    {      9,    0,    0,  8,  0,  0 }, {      9,    1,    0,  8,  0,  0 }, {      9,    2,    0,  8,  0,  0 }, {      9,    3,    0,  8,  0,  0 }, {      9,    4,    0,  9,  0,  0 },
    {      9,    5,    0,  9,  0,  0 }, {     10,    6,    0,  9,  0,  0 }, {     10,    7,    0,  9,  0,  0 }, {     10,    8,    0, 10,  0,  0 }, {     11,    9,    0, 10,  0,  0 },
    {     11,   10,    0, 10,  0,  0 }, {     11,   11,    0, 10,  0,  0 }, {     12,   12,    0, 11,  0,  0 }, {     12,   13,    0, 11,  0,  0 }, {     13,   14,    0, 11,  0,  0 },
    {     14,   15,    0, 11,  0,  0 }, {     15,   16,    0, 12,  0,  0 }, {     16,   17,    0, 12,  0,  0 }, {     17,   18,    0, 13,  0,  0 }, {     18,   19,    0, 13,  0,  0 },
    {     19,   20,    0, 13,  0,  0 }, {     20,   20,    0, 13,  0,  0 }, {     21,   21,    0, 14,  0,  0 }, {     22,   21,    0, 14,  0,  0 }, {     23,   21,    0, 14,  0,  0 },
    {     24,   22,    0, 14,  0,  0 }, {     25,   22,    0, 15,  0,  0 }, {     26,   22,    0, 15,  0,  0 }, {     27,   23,    0, 15,  0,  0 }, {     28,   23,    0, 15,  0,  0 },
    {     29,   23,    0, 16,  0,  0 }, {     30,   23,    0, 16,  0,  0 }, {     31,   23,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9019AF, {
    {      0,   23,    0, 16,  0,  0 }, {      1,   23,    0, 16,  0,  0 }, {      2,   23,    0, 16,  0,  0 }, {      3,   23,    0, 16,  0,  0 }, {      4,   23,    0, 17,  0,  0 },
    {      5,   23,    0, 17,  0,  0 }, {      6,   22,    0, 17,  0,  0 }, {      7,   22,    0, 17,  0,  0 }, {      8,   22,    0, 18,  0,  0 }, {      9,   21,    0, 18,  0,  0 },
    {     10,   21,    0, 18,  0,  0 }, {     11,   21,    0, 18,  0,  0 }, {     12,   20,    0, 19,  0,  0 }, {     13,   20,    0, 19,  0,  0 }, {     14,   19,    0, 19,  0,  0 },
    {     15,   18,    0, 19,  0,  0 }, {     16,   17,    0, 20,  0,  0 }, {     17,   16,    0, 20,  0,  0 }, {     18,   15,    0, 21,  0,  0 }, {     19,   14,    0, 21,  0,  0 },
    {     20,   13,    0, 21,  0,  0 }, {     20,   12,    0, 21,  0,  0 }, {     21,   11,    0, 22,  0,  0 }, {     21,   10,    0, 22,  0,  0 }, {     21,    9,    0, 22,  0,  0 },
    {     22,    8,    0, 22,  0,  0 }, {     22,    7,    0, 23,  0,  0 }, {     22,    6,    0, 23,  0,  0 }, {     23,    5,    0, 23,  0,  0 }, {     23,    4,    0, 23,  0,  0 },
    {     23,    3,    0, 24,  0,  0 }, {     23,    2,    0, 24,  0,  0 }, {     23,    1,    0, 24,  0,  0 }, {     23,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_901AE3, {
    {     23,   31,    0, 24,  0,  0 }, {     23,   30,    0, 24,  0,  0 }, {     23,   29,    0, 25,  0,  0 }, {     23,   28,    0, 25,  0,  0 }, {     22,   27,    0, 25,  0,  0 },
    {     22,   26,    0, 25,  0,  0 }, {     22,   25,    0, 26,  0,  0 }, {     21,   24,    0, 26,  0,  0 }, {     21,   23,    0, 26,  0,  0 }, {     21,   22,    0, 26,  0,  0 },
    {     20,   21,    0, 27,  0,  0 }, {     20,   20,    0, 27,  0,  0 }, {     19,   19,    0, 27,  0,  0 }, {     18,   18,    0, 27,  0,  0 }, {     17,   17,    0, 28,  0,  0 },
    {     16,   16,    0, 28,  0,  0 }, {     15,   15,    0, 29,  0,  0 }, {     14,   14,    0, 29,  0,  0 }, {     13,   13,    0, 29,  0,  0 }, {     12,   12,    0, 29,  0,  0 },
    {     11,   12,    0, 30,  0,  0 }, {     10,   11,    0, 30,  0,  0 }, {      9,   11,    0, 30,  0,  0 }, {      8,   11,    0, 30,  0,  0 }, {      7,   10,    0, 31,  0,  0 },
    {      6,   10,    0, 31,  0,  0 }, {      5,   10,    0, 31,  0,  0 }, {      4,    9,    0, 31,  0,  0 }, {      3,    9,    0,  0,  0,  0 }, {      2,    9,    0,  0,  0,  0 },
    {      1,    9,    0,  0,  0,  0 }, {      0,    9,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_901DE1, {
    {     31,   23,    0,  0,  0,  0 }, {     30,   23,    0,  0,  0,  0 }, {     29,   23,    0,  0,  0,  0 }, {     28,   23,    0,  0,  0,  0 }, {     27,   23,    0,  0,  0,  0 },
    {     26,   23,    0,  0,  0,  0 }, {     25,   23,    0,  0,  0,  0 }, {     24,   23,    0,  0,  0,  0 }, {     23,   23,    0,  0,  0,  0 }, {     22,   23,    0,  0,  0,  0 },
    {     21,   23,    0,  0,  0,  0 }, {     20,   23,    0,  0,  0,  0 }, {     19,   23,    0,  0,  0,  0 }, {     18,   23,    0,  0,  0,  0 }, {     17,   23,    0,  0,  0,  0 },
    {     16,   23,    0,  0,  0,  0 }, {     15,   23,    0,  0,  0,  0 }, {     14,   23,    0,  0,  0,  0 }, {     13,   23,    0,  0,  0,  0 }, {     12,   23,    0,  0,  0,  0 },
    {     11,   23,    0,  0,  0,  0 }, {     10,   23,    0,  0,  0,  0 }, {      9,   23,    0,  0,  0,  0 }, {      8,   23,    0,  0,  0,  0 }, {      7,   23,    0,  0,  0,  0 },
    {      6,   23,    0,  0,  0,  0 }, {      5,   23,    0,  0,  0,  0 }, {      4,   23,    0,  0,  0,  0 }, {      3,   23,    0,  0,  0,  0 }, {      2,   23,    0,  0,  0,  0 },
    {      1,   23,    0,  0,  0,  0 }, {      0,   23,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_901F03, {
    {     23,    0,    0,  8,  0,  0 }, {     23,    1,    0,  8,  0,  0 }, {     23,    2,    0,  8,  0,  0 }, {     23,    3,    0,  8,  0,  0 }, {     23,    4,    0,  8,  0,  0 },
    {     23,    5,    0,  8,  0,  0 }, {     23,    6,    0,  8,  0,  0 }, {     23,    7,    0,  8,  0,  0 }, {     23,    8,    0,  8,  0,  0 }, {     23,    9,    0,  8,  0,  0 },
    {     23,   10,    0,  8,  0,  0 }, {     23,   11,    0,  8,  0,  0 }, {     23,   12,    0,  8,  0,  0 }, {     23,   13,    0,  8,  0,  0 }, {     23,   14,    0,  8,  0,  0 },
    {     23,   15,    0,  8,  0,  0 }, {     23,   16,    0,  8,  0,  0 }, {     23,   17,    0,  8,  0,  0 }, {     23,   18,    0,  8,  0,  0 }, {     23,   19,    0,  8,  0,  0 },
    {     23,   20,    0,  8,  0,  0 }, {     23,   21,    0,  8,  0,  0 }, {     23,   22,    0,  8,  0,  0 }, {     23,   23,    0,  8,  0,  0 }, {     23,   24,    0,  8,  0,  0 },
    {     23,   25,    0,  8,  0,  0 }, {     23,   26,    0,  8,  0,  0 }, {     23,   27,    0,  8,  0,  0 }, {     23,   28,    0,  8,  0,  0 }, {     23,   29,    0,  8,  0,  0 },
    {     23,   30,    0,  8,  0,  0 }, {     23,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_902025, {
    {      0,    9,    0, 16,  0,  0 }, {      1,    9,    0, 16,  0,  0 }, {      2,    9,    0, 16,  0,  0 }, {      3,    9,    0, 16,  0,  0 }, {      4,    9,    0, 16,  0,  0 },
    {      5,    9,    0, 16,  0,  0 }, {      6,    9,    0, 16,  0,  0 }, {      7,    9,    0, 16,  0,  0 }, {      8,    9,    0, 16,  0,  0 }, {      9,    9,    0, 16,  0,  0 },
    {     10,    9,    0, 16,  0,  0 }, {     11,    9,    0, 16,  0,  0 }, {     12,    9,    0, 16,  0,  0 }, {     13,    9,    0, 16,  0,  0 }, {     14,    9,    0, 16,  0,  0 },
    {     15,    9,    0, 16,  0,  0 }, {     16,    9,    0, 16,  0,  0 }, {     17,    9,    0, 16,  0,  0 }, {     18,    9,    0, 16,  0,  0 }, {     19,    9,    0, 16,  0,  0 },
    {     20,    9,    0, 16,  0,  0 }, {     21,    9,    0, 16,  0,  0 }, {     22,    9,    0, 16,  0,  0 }, {     23,    9,    0, 16,  0,  0 }, {     24,    9,    0, 16,  0,  0 },
    {     25,    9,    0, 16,  0,  0 }, {     26,    9,    0, 16,  0,  0 }, {     27,    9,    0, 16,  0,  0 }, {     28,    9,    0, 16,  0,  0 }, {     29,    9,    0, 16,  0,  0 },
    {     30,    9,    0, 16,  0,  0 }, {     31,    9,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_902147, {
    {      9,   31,    0, 24,  0,  0 }, {      9,   30,    0, 24,  0,  0 }, {      9,   29,    0, 24,  0,  0 }, {      9,   28,    0, 24,  0,  0 }, {      9,   27,    0, 24,  0,  0 },
    {      9,   26,    0, 24,  0,  0 }, {      9,   25,    0, 24,  0,  0 }, {      9,   24,    0, 24,  0,  0 }, {      9,   23,    0, 24,  0,  0 }, {      9,   22,    0, 24,  0,  0 },
    {      9,   21,    0, 24,  0,  0 }, {      9,   20,    0, 24,  0,  0 }, {      9,   19,    0, 24,  0,  0 }, {      9,   18,    0, 24,  0,  0 }, {      9,   17,    0, 24,  0,  0 },
    {      9,   16,    0, 24,  0,  0 }, {      9,   15,    0, 24,  0,  0 }, {      9,   14,    0, 24,  0,  0 }, {      9,   13,    0, 24,  0,  0 }, {      9,   12,    0, 24,  0,  0 },
    {      9,   11,    0, 24,  0,  0 }, {      9,   10,    0, 24,  0,  0 }, {      9,    9,    0, 24,  0,  0 }, {      9,    8,    0, 24,  0,  0 }, {      9,    7,    0, 24,  0,  0 },
    {      9,    6,    0, 24,  0,  0 }, {      9,    5,    0, 24,  0,  0 }, {      9,    4,    0, 24,  0,  0 }, {      9,    3,    0, 24,  0,  0 }, {      9,    2,    0, 24,  0,  0 },
    {      9,    1,    0, 24,  0,  0 }, {      9,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9034D1, {
    {     31,   23,    0,  0,  2,  0 }, {     30,   23,    0,  0,  2,  0 }, {     29,   23,    1,  0,  2,  0 }, {     28,   23,    1,  0,  2,  0 }, {     27,   23,    2,  0,  2,  0 },
    {     26,   23,    2,  0,  2,  0 }, {     25,   23,    3,  0,  2,  0 }, {     24,   23,    3,  0,  2,  0 }, {     23,   23,    4,  0,  2,  0 }, {     22,   23,    4,  0,  2,  0 },
    {     21,   23,    5,  0,  2,  0 }, {     20,   23,    5,  0,  2,  0 }, {     19,   23,    6,  0,  2,  0 }, {     18,   23,    6,  0,  2,  0 }, {     17,   23,    7,  0,  2,  0 },
    {     16,   23,    7,  0,  2,  0 }, {     15,   23,    8,  0,  2,  0 }, {     14,   23,    8,  0,  2,  0 }, {     13,   23,    9,  0,  2,  0 }, {     12,   23,    9,  0,  2,  0 },
    {     11,   23,   10,  0,  2,  0 }, {     10,   23,   10,  0,  2,  0 }, {      9,   23,   11,  0,  2,  0 }, {      8,   23,   11,  0,  2,  0 }, {      7,   23,   12,  0,  2,  0 },
    {      6,   23,   12,  0,  2,  0 }, {      5,   23,   13,  0,  2,  0 }, {      4,   23,   13,  0,  2,  0 }, {      3,   23,   14,  0,  2,  0 }, {      2,   23,   14,  0,  2,  0 },
    {      1,   23,   15,  0,  2,  0 }, {      0,   23,   15,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9035F3, {
    {     23,    0,    0,  8,  2,  0 }, {     23,    1,    1,  8,  2,  0 }, {     23,    2,    1,  8,  2,  0 }, {     23,    3,    2,  8,  2,  0 }, {     23,    4,    2,  8,  2,  0 },
    {     23,    5,    3,  8,  2,  0 }, {     23,    6,    3,  8,  2,  0 }, {     23,    7,    4,  8,  2,  0 }, {     23,    8,    4,  8,  2,  0 }, {     23,    9,    5,  8,  2,  0 },
    {     23,   10,    5,  8,  2,  0 }, {     23,   11,    6,  8,  2,  0 }, {     23,   12,    6,  8,  2,  0 }, {     23,   13,    7,  8,  2,  0 }, {     23,   14,    7,  8,  2,  0 },
    {     23,   15,    8,  8,  2,  0 }, {     23,   16,    8,  8,  2,  0 }, {     23,   17,    9,  8,  2,  0 }, {     23,   18,    9,  8,  2,  0 }, {     23,   19,   10,  8,  2,  0 },
    {     23,   20,   10,  8,  2,  0 }, {     23,   21,   11,  8,  2,  0 }, {     23,   22,   11,  8,  2,  0 }, {     23,   23,   12,  8,  2,  0 }, {     23,   24,   12,  8,  2,  0 },
    {     23,   25,   13,  8,  2,  0 }, {     23,   26,   13,  8,  2,  0 }, {     23,   27,   14,  8,  2,  0 }, {     23,   28,   14,  8,  2,  0 }, {     23,   29,   15,  8,  2,  0 },
    {     23,   30,   15,  8,  2,  0 }, {     23,   31,   16,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_903715, {
    {      0,    9,    0, 16,  2,  0 }, {      1,    9,    1, 16,  2,  0 }, {      2,    9,    1, 16,  2,  0 }, {      3,    9,    2, 16,  2,  0 }, {      4,    9,    2, 16,  2,  0 },
    {      5,    9,    3, 16,  2,  0 }, {      6,    9,    3, 16,  2,  0 }, {      7,    9,    4, 16,  2,  0 }, {      8,    9,    4, 16,  2,  0 }, {      9,    9,    5, 16,  2,  0 },
    {     10,    9,    5, 16,  2,  0 }, {     11,    9,    6, 16,  2,  0 }, {     12,    9,    6, 16,  2,  0 }, {     13,    9,    7, 16,  2,  0 }, {     14,    9,    7, 16,  2,  0 },
    {     15,    9,    8, 16,  2,  0 }, {     16,    9,    8, 16,  2,  0 }, {     17,    9,    9, 16,  2,  0 }, {     18,    9,    9, 16,  2,  0 }, {     19,    9,   10, 16,  2,  0 },
    {     20,    9,   10, 16,  2,  0 }, {     21,    9,   11, 16,  2,  0 }, {     22,    9,   11, 16,  2,  0 }, {     23,    9,   12, 16,  2,  0 }, {     24,    9,   12, 16,  2,  0 },
    {     25,    9,   13, 16,  2,  0 }, {     26,    9,   13, 16,  2,  0 }, {     27,    9,   14, 16,  2,  0 }, {     28,    9,   14, 16,  2,  0 }, {     29,    9,   15, 16,  2,  0 },
    {     30,    9,   15, 16,  2,  0 }, {     31,    9,   16, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_903837, {
    {      9,   31,    0, 24,  2,  0 }, {      9,   30,    0, 24,  2,  0 }, {      9,   29,    1, 24,  2,  0 }, {      9,   28,    1, 24,  2,  0 }, {      9,   27,    2, 24,  2,  0 },
    {      9,   26,    2, 24,  2,  0 }, {      9,   25,    3, 24,  2,  0 }, {      9,   24,    3, 24,  2,  0 }, {      9,   23,    4, 24,  2,  0 }, {      9,   22,    4, 24,  2,  0 },
    {      9,   21,    5, 24,  2,  0 }, {      9,   20,    5, 24,  2,  0 }, {      9,   19,    6, 24,  2,  0 }, {      9,   18,    6, 24,  2,  0 }, {      9,   17,    7, 24,  2,  0 },
    {      9,   16,    7, 24,  2,  0 }, {      9,   15,    8, 24,  2,  0 }, {      9,   14,    8, 24,  2,  0 }, {      9,   13,    9, 24,  2,  0 }, {      9,   12,    9, 24,  2,  0 },
    {      9,   11,   10, 24,  2,  0 }, {      9,   10,   10, 24,  2,  0 }, {      9,    9,   11, 24,  2,  0 }, {      9,    8,   11, 24,  2,  0 }, {      9,    7,   12, 24,  2,  0 },
    {      9,    6,   12, 24,  2,  0 }, {      9,    5,   13, 24,  2,  0 }, {      9,    4,   13, 24,  2,  0 }, {      9,    3,   14, 24,  2,  0 }, {      9,    2,   14, 24,  2,  0 },
    {      9,    1,   15, 24,  2,  0 }, {      9,    0,   15, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_902269, {
    {     31,   23,    0,  0,  0,  0 }, {     30,   23,    0,  0,  0,  0 }, {     29,   23,    0,  0,  0,  0 }, {     28,   23,    0,  0,  0,  0 }, {     27,   23,    0,  0,  0,  0 },
    {     26,   23,    0,  0,  0,  0 }, {     25,   23,    0,  0,  0,  0 }, {     24,   23,    0,  0,  0,  0 }, {     23,   23,    0,  0,  1,  0 }, {     22,   23,    0,  0,  1,  0 },
    {     21,   23,    1,  0,  1,  0 }, {     20,   23,    1,  0,  1,  0 }, {     19,   23,    1,  0,  1,  0 }, {     18,   23,    1,  0,  1,  0 }, {     17,   23,    1,  0,  1,  0 },
    {     16,   23,    1,  0,  1,  0 }, {     15,   23,    2,  0,  1,  0 }, {     14,   23,    2,  0,  1,  0 }, {     13,   23,    2,  0,  1,  0 }, {     12,   23,    2,  0,  1,  0 },
    {     11,   23,    3,  0,  1,  0 }, {     10,   23,    3,  0,  1,  0 }, {      9,   23,    3,  0,  1,  0 }, {      8,   23,    4,  0,  1,  0 }, {      7,   23,    4,  0,  2,  0 },
    {      6,   23,    5,  0,  2,  0 }, {      5,   23,    5,  0,  2,  0 }, {      4,   23,    6,  0,  2,  0 }, {      3,   23,    6,  0,  2,  0 }, {      2,   23,    7,  0,  2,  0 },
    {      1,   23,    7,  0,  2,  0 }, {      0,   23,    8,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90238B, {
    {     23,    0,    0,  8,  0,  0 }, {     23,    1,    0,  8,  0,  0 }, {     23,    2,    0,  8,  0,  0 }, {     23,    3,    0,  8,  0,  0 }, {     23,    4,    0,  8,  0,  0 },
    {     23,    5,    0,  8,  0,  0 }, {     23,    6,    0,  8,  0,  0 }, {     23,    7,    0,  8,  0,  0 }, {     23,    8,    0,  8,  1,  0 }, {     23,    9,    0,  8,  1,  0 },
    {     23,   10,    1,  8,  1,  0 }, {     23,   11,    1,  8,  1,  0 }, {     23,   12,    1,  8,  1,  0 }, {     23,   13,    1,  8,  1,  0 }, {     23,   14,    1,  8,  1,  0 },
    {     23,   15,    1,  8,  1,  0 }, {     23,   16,    2,  8,  1,  0 }, {     23,   17,    2,  8,  1,  0 }, {     23,   18,    2,  8,  1,  0 }, {     23,   19,    2,  8,  1,  0 },
    {     23,   20,    3,  8,  1,  0 }, {     23,   21,    3,  8,  1,  0 }, {     23,   22,    3,  8,  1,  0 }, {     23,   23,    4,  8,  1,  0 }, {     23,   24,    4,  8,  2,  0 },
    {     23,   25,    4,  8,  2,  0 }, {     23,   26,    5,  8,  2,  0 }, {     23,   27,    5,  8,  2,  0 }, {     23,   28,    6,  8,  2,  0 }, {     23,   29,    6,  8,  2,  0 },
    {     23,   30,    7,  8,  2,  0 }, {     23,   31,    7,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9024AD, {
    {      0,    9,    0, 16,  0,  0 }, {      1,    9,    0, 16,  0,  0 }, {      2,    9,    0, 16,  0,  0 }, {      3,    9,    0, 16,  0,  0 }, {      4,    9,    0, 16,  0,  0 },
    {      5,    9,    0, 16,  0,  0 }, {      6,    9,    0, 16,  0,  0 }, {      7,    9,    0, 16,  0,  0 }, {      8,    9,    0, 16,  1,  0 }, {      9,    9,    0, 16,  1,  0 },
    {     10,    9,    1, 16,  1,  0 }, {     11,    9,    1, 16,  1,  0 }, {     12,    9,    1, 16,  1,  0 }, {     13,    9,    1, 16,  1,  0 }, {     14,    9,    1, 16,  1,  0 },
    {     15,    9,    1, 16,  1,  0 }, {     16,    9,    2, 16,  1,  0 }, {     17,    9,    2, 16,  1,  0 }, {     18,    9,    2, 16,  1,  0 }, {     19,    9,    2, 16,  1,  0 },
    {     20,    9,    3, 16,  1,  0 }, {     21,    9,    3, 16,  1,  0 }, {     22,    9,    3, 16,  1,  0 }, {     23,    9,    4, 16,  1,  0 }, {     24,    9,    4, 16,  2,  0 },
    {     25,    9,    4, 16,  2,  0 }, {     26,    9,    5, 16,  2,  0 }, {     27,    9,    5, 16,  2,  0 }, {     28,    9,    6, 16,  2,  0 }, {     29,    9,    6, 16,  2,  0 },
    {     30,    9,    7, 16,  2,  0 }, {     31,    9,    7, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9025CF, {
    {      9,   31,    0, 24,  0,  0 }, {      9,   30,    0, 24,  0,  0 }, {      9,   29,    0, 24,  0,  0 }, {      9,   28,    0, 24,  0,  0 }, {      9,   27,    0, 24,  0,  0 },
    {      9,   26,    0, 24,  0,  0 }, {      9,   25,    0, 24,  0,  0 }, {      9,   24,    0, 24,  0,  0 }, {      9,   23,    0, 24,  1,  0 }, {      9,   22,    0, 24,  1,  0 },
    {      9,   21,    1, 24,  1,  0 }, {      9,   20,    1, 24,  1,  0 }, {      9,   19,    1, 24,  1,  0 }, {      9,   18,    1, 24,  1,  0 }, {      9,   17,    1, 24,  1,  0 },
    {      9,   16,    1, 24,  1,  0 }, {      9,   15,    2, 24,  1,  0 }, {      9,   14,    2, 24,  1,  0 }, {      9,   13,    2, 24,  1,  0 }, {      9,   12,    2, 24,  1,  0 },
    {      9,   11,    3, 24,  1,  0 }, {      9,   10,    3, 24,  1,  0 }, {      9,    9,    3, 24,  1,  0 }, {      9,    8,    4, 24,  1,  0 }, {      9,    7,    4, 24,  2,  0 },
    {      9,    6,    5, 24,  2,  0 }, {      9,    5,    5, 24,  2,  0 }, {      9,    4,    6, 24,  2,  0 }, {      9,    3,    6, 24,  2,  0 }, {      9,    2,    7, 24,  2,  0 },
    {      9,    1,    7, 24,  2,  0 }, {      9,    0,    8, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9026F1, {
    {     31,   23,    0,  0,  2,  0 }, {     30,   23,    1,  0,  2,  0 }, {     29,   23,    1,  0,  2,  0 }, {     28,   23,    2,  0,  2,  0 }, {     27,   23,    2,  0,  2,  0 },
    {     26,   23,    3,  0,  2,  0 }, {     25,   23,    3,  0,  2,  0 }, {     24,   23,    3,  0,  2,  0 }, {     23,   23,    4,  0,  1,  0 }, {     22,   23,    4,  0,  1,  0 },
    {     21,   23,    4,  0,  1,  0 }, {     20,   23,    5,  0,  1,  0 }, {     19,   23,    5,  0,  1,  0 }, {     18,   23,    5,  0,  1,  0 }, {     17,   23,    6,  0,  1,  0 },
    {     16,   23,    6,  0,  1,  0 }, {     15,   23,    6,  0,  1,  0 }, {     14,   23,    6,  0,  1,  0 }, {     13,   23,    7,  0,  1,  0 }, {     12,   23,    7,  0,  1,  0 },
    {     11,   23,    7,  0,  1,  0 }, {     10,   23,    7,  0,  1,  0 }, {      9,   23,    7,  0,  0,  0 }, {      8,   23,    7,  0,  0,  0 }, {      7,   23,    8,  0,  0,  0 },
    {      6,   23,    8,  0,  0,  0 }, {      5,   23,    8,  0,  0,  0 }, {      4,   23,    8,  0,  0,  0 }, {      3,   23,    8,  0,  0,  0 }, {      2,   23,    8,  0,  0,  0 },
    {      1,   23,    8,  0,  0,  0 }, {      0,   23,    8,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_902825, {
    {     23,    0,    0,  8,  2,  0 }, {     23,    1,    0,  8,  2,  0 }, {     23,    2,    1,  8,  2,  0 }, {     23,    3,    1,  8,  2,  0 }, {     23,    4,    2,  8,  2,  0 },
    {     23,    5,    2,  8,  2,  0 }, {     23,    6,    3,  8,  2,  0 }, {     23,    7,    3,  8,  2,  0 }, {     23,    8,    4,  8,  1,  0 }, {     23,    9,    4,  8,  1,  0 },
    {     23,   10,    4,  8,  1,  0 }, {     23,   11,    5,  8,  1,  0 }, {     23,   12,    5,  8,  1,  0 }, {     23,   13,    5,  8,  1,  0 }, {     23,   14,    6,  8,  1,  0 },
    {     23,   15,    6,  8,  1,  0 }, {     23,   16,    6,  8,  1,  0 }, {     23,   17,    6,  8,  1,  0 }, {     23,   18,    7,  8,  1,  0 }, {     23,   19,    7,  8,  1,  0 },
    {     23,   20,    7,  8,  1,  0 }, {     23,   21,    7,  8,  1,  0 }, {     23,   22,    7,  8,  0,  0 }, {     23,   23,    7,  8,  0,  0 }, {     23,   24,    8,  8,  0,  0 },
    {     23,   25,    8,  8,  0,  0 }, {     23,   26,    8,  8,  0,  0 }, {     23,   27,    8,  8,  0,  0 }, {     23,   28,    8,  8,  0,  0 }, {     23,   29,    8,  8,  0,  0 },
    {     23,   30,    8,  8,  0,  0 }, {     23,   31,    8,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_902959, {
    {      0,    9,    0, 16,  2,  0 }, {      1,    9,    0, 16,  2,  0 }, {      2,    9,    1, 16,  2,  0 }, {      3,    9,    1, 16,  2,  0 }, {      4,    9,    2, 16,  2,  0 },
    {      5,    9,    2, 16,  2,  0 }, {      6,    9,    3, 16,  2,  0 }, {      7,    9,    3, 16,  2,  0 }, {      8,    9,    4, 16,  1,  0 }, {      9,    9,    4, 16,  1,  0 },
    {     10,    9,    4, 16,  1,  0 }, {     11,    9,    5, 16,  1,  0 }, {     12,    9,    5, 16,  1,  0 }, {     13,    9,    5, 16,  1,  0 }, {     14,    9,    6, 16,  1,  0 },
    {     15,    9,    6, 16,  1,  0 }, {     16,    9,    6, 16,  1,  0 }, {     17,    9,    6, 16,  1,  0 }, {     18,    9,    7, 16,  1,  0 }, {     19,    9,    7, 16,  1,  0 },
    {     20,    9,    7, 16,  1,  0 }, {     21,    9,    7, 16,  1,  0 }, {     22,    9,    7, 16,  0,  0 }, {     23,    9,    7, 16,  0,  0 }, {     24,    9,    8, 16,  0,  0 },
    {     25,    9,    8, 16,  0,  0 }, {     26,    9,    8, 16,  0,  0 }, {     27,    9,    8, 16,  0,  0 }, {     28,    9,    8, 16,  0,  0 }, {     29,    9,    8, 16,  0,  0 },
    {     30,    9,    8, 16,  0,  0 }, {     31,    9,    8, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_902A8D, {
    {      9,   31,    0, 24,  2,  0 }, {      9,   30,    1, 24,  2,  0 }, {      9,   29,    1, 24,  2,  0 }, {      9,   28,    2, 24,  2,  0 }, {      9,   27,    2, 24,  2,  0 },
    {      9,   26,    3, 24,  2,  0 }, {      9,   25,    3, 24,  2,  0 }, {      9,   24,    3, 24,  2,  0 }, {      9,   23,    4, 24,  1,  0 }, {      9,   22,    4, 24,  1,  0 },
    {      9,   21,    4, 24,  1,  0 }, {      9,   20,    5, 24,  1,  0 }, {      9,   19,    5, 24,  1,  0 }, {      9,   18,    5, 24,  1,  0 }, {      9,   17,    6, 24,  1,  0 },
    {      9,   16,    6, 24,  1,  0 }, {      9,   15,    6, 24,  1,  0 }, {      9,   14,    6, 24,  1,  0 }, {      9,   13,    7, 24,  1,  0 }, {      9,   12,    7, 24,  1,  0 },
    {      9,   11,    7, 24,  1,  0 }, {      9,   10,    7, 24,  1,  0 }, {      9,    9,    7, 24,  0,  0 }, {      9,    8,    7, 24,  0,  0 }, {      9,    7,    8, 24,  0,  0 },
    {      9,    6,    8, 24,  0,  0 }, {      9,    5,    8, 24,  0,  0 }, {      9,    4,    8, 24,  0,  0 }, {      9,    3,    8, 24,  0,  0 }, {      9,    2,    8, 24,  0,  0 },
    {      9,    1,    8, 24,  0,  0 }, {      9,    0,    8, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_903959, {
    {     31,   23,   15,  0,  6,  0 }, {     30,   23,   14,  0,  6,  0 }, {     29,   23,   14,  0,  6,  0 }, {     28,   23,   13,  0,  6,  0 }, {     27,   23,   13,  0,  6,  0 },
    {     26,   23,   12,  0,  6,  0 }, {     25,   23,   12,  0,  6,  0 }, {     24,   23,   11,  0,  6,  0 }, {     23,   23,   11,  0,  6,  0 }, {     22,   23,   10,  0,  6,  0 },
    {     21,   23,   10,  0,  6,  0 }, {     20,   23,    9,  0,  6,  0 }, {     19,   23,    9,  0,  6,  0 }, {     18,   23,    8,  0,  6,  0 }, {     17,   23,    8,  0,  6,  0 },
    {     16,   23,    7,  0,  6,  0 }, {     15,   23,    7,  0,  6,  0 }, {     14,   23,    6,  0,  6,  0 }, {     13,   23,    6,  0,  6,  0 }, {     12,   23,    5,  0,  6,  0 },
    {     11,   23,    5,  0,  6,  0 }, {     10,   23,    4,  0,  6,  0 }, {      9,   23,    4,  0,  6,  0 }, {      8,   23,    3,  0,  6,  0 }, {      7,   23,    3,  0,  6,  0 },
    {      6,   23,    2,  0,  6,  0 }, {      5,   23,    2,  0,  6,  0 }, {      4,   23,    1,  0,  6,  0 }, {      3,   23,    1,  0,  6,  0 }, {      2,   23,    0,  0,  6,  0 },
    {      1,   23,    0,  0,  6,  0 }, {      0,   23,   -1,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_903A7B, {
    {     23,    0,   15,  8,  6,  0 }, {     23,    1,   15,  8,  6,  0 }, {     23,    2,   14,  8,  6,  0 }, {     23,    3,   14,  8,  6,  0 }, {     23,    4,   13,  8,  6,  0 },
    {     23,    5,   13,  8,  6,  0 }, {     23,    6,   12,  8,  6,  0 }, {     23,    7,   12,  8,  6,  0 }, {     23,    8,   11,  8,  6,  0 }, {     23,    9,   11,  8,  6,  0 },
    {     23,   10,   10,  8,  6,  0 }, {     23,   11,   10,  8,  6,  0 }, {     23,   12,    9,  8,  6,  0 }, {     23,   13,    9,  8,  6,  0 }, {     23,   14,    8,  8,  6,  0 },
    {     23,   15,    8,  8,  6,  0 }, {     23,   16,    7,  8,  6,  0 }, {     23,   17,    7,  8,  6,  0 }, {     23,   18,    6,  8,  6,  0 }, {     23,   19,    6,  8,  6,  0 },
    {     23,   20,    5,  8,  6,  0 }, {     23,   21,    5,  8,  6,  0 }, {     23,   22,    4,  8,  6,  0 }, {     23,   23,    4,  8,  6,  0 }, {     23,   24,    3,  8,  6,  0 },
    {     23,   25,    3,  8,  6,  0 }, {     23,   26,    2,  8,  6,  0 }, {     23,   27,    2,  8,  6,  0 }, {     23,   28,    1,  8,  6,  0 }, {     23,   29,    1,  8,  6,  0 },
    {     23,   30,    0,  8,  6,  0 }, {     23,   31,    0,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_903B9D, {
    {      0,    9,   15, 16,  6,  0 }, {      1,    9,   15, 16,  6,  0 }, {      2,    9,   14, 16,  6,  0 }, {      3,    9,   14, 16,  6,  0 }, {      4,    9,   13, 16,  6,  0 },
    {      5,    9,   13, 16,  6,  0 }, {      6,    9,   12, 16,  6,  0 }, {      7,    9,   12, 16,  6,  0 }, {      8,    9,   11, 16,  6,  0 }, {      9,    9,   11, 16,  6,  0 },
    {     10,    9,   10, 16,  6,  0 }, {     11,    9,   10, 16,  6,  0 }, {     12,    9,    9, 16,  6,  0 }, {     13,    9,    9, 16,  6,  0 }, {     14,    9,    8, 16,  6,  0 },
    {     15,    9,    8, 16,  6,  0 }, {     16,    9,    7, 16,  6,  0 }, {     17,    9,    7, 16,  6,  0 }, {     18,    9,    6, 16,  6,  0 }, {     19,    9,    6, 16,  6,  0 },
    {     20,    9,    5, 16,  6,  0 }, {     21,    9,    5, 16,  6,  0 }, {     22,    9,    4, 16,  6,  0 }, {     23,    9,    4, 16,  6,  0 }, {     24,    9,    3, 16,  6,  0 },
    {     25,    9,    3, 16,  6,  0 }, {     26,    9,    2, 16,  6,  0 }, {     27,    9,    2, 16,  6,  0 }, {     28,    9,    1, 16,  6,  0 }, {     29,    9,    1, 16,  6,  0 },
    {     30,    9,    0, 16,  6,  0 }, {     31,    9,    0, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_903CBF, {
    {      9,   31,   15, 24,  6,  0 }, {      9,   30,   14, 24,  6,  0 }, {      9,   29,   14, 24,  6,  0 }, {      9,   28,   13, 24,  6,  0 }, {      9,   27,   13, 24,  6,  0 },
    {      9,   26,   12, 24,  6,  0 }, {      9,   25,   12, 24,  6,  0 }, {      9,   24,   11, 24,  6,  0 }, {      9,   23,   11, 24,  6,  0 }, {      9,   22,   10, 24,  6,  0 },
    {      9,   21,   10, 24,  6,  0 }, {      9,   20,    9, 24,  6,  0 }, {      9,   19,    9, 24,  6,  0 }, {      9,   18,    8, 24,  6,  0 }, {      9,   17,    8, 24,  6,  0 },
    {      9,   16,    7, 24,  6,  0 }, {      9,   15,    7, 24,  6,  0 }, {      9,   14,    6, 24,  6,  0 }, {      9,   13,    6, 24,  6,  0 }, {      9,   12,    5, 24,  6,  0 },
    {      9,   11,    5, 24,  6,  0 }, {      9,   10,    4, 24,  6,  0 }, {      9,    9,    4, 24,  6,  0 }, {      9,    8,    3, 24,  6,  0 }, {      9,    7,    3, 24,  6,  0 },
    {      9,    6,    2, 24,  6,  0 }, {      9,    5,    2, 24,  6,  0 }, {      9,    4,    1, 24,  6,  0 }, {      9,    3,    1, 24,  6,  0 }, {      9,    2,    0, 24,  6,  0 },
    {      9,    1,    0, 24,  6,  0 }, {      9,    0,   -1, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_903049, {
    {     31,   23,    8,  0,  0,  0 }, {     30,   23,    8,  0,  0,  0 }, {     29,   23,    8,  0,  0,  0 }, {     28,   23,    8,  0,  0,  0 }, {     27,   23,    8,  0,  0,  0 },
    {     26,   23,    8,  0,  0,  0 }, {     25,   23,    8,  0,  0,  0 }, {     24,   23,    8,  0,  0,  0 }, {     23,   23,    7,  0,  5,  0 }, {     22,   23,    7,  0,  5,  0 },
    {     21,   23,    7,  0,  5,  0 }, {     20,   23,    7,  0,  5,  0 }, {     19,   23,    7,  0,  5,  0 }, {     18,   23,    7,  0,  5,  0 }, {     17,   23,    6,  0,  5,  0 },
    {     16,   23,    6,  0,  5,  0 }, {     15,   23,    6,  0,  5,  0 }, {     14,   23,    6,  0,  5,  0 }, {     13,   23,    5,  0,  5,  0 }, {     12,   23,    5,  0,  5,  0 },
    {     11,   23,    5,  0,  5,  0 }, {     10,   23,    4,  0,  5,  0 }, {      9,   23,    4,  0,  5,  0 }, {      8,   23,    4,  0,  5,  0 }, {      7,   23,    3,  0,  6,  0 },
    {      6,   23,    3,  0,  6,  0 }, {      5,   23,    2,  0,  6,  0 }, {      4,   23,    2,  0,  6,  0 }, {      3,   23,    1,  0,  6,  0 }, {      2,   23,    1,  0,  6,  0 },
    {      1,   23,    0,  0,  6,  0 }, {      0,   23,    0,  0,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90316B, {
    {     23,    0,    8,  8,  0,  0 }, {     23,    1,    8,  8,  0,  0 }, {     23,    2,    8,  8,  0,  0 }, {     23,    3,    8,  8,  0,  0 }, {     23,    4,    8,  8,  0,  0 },
    {     23,    5,    8,  8,  0,  0 }, {     23,    6,    8,  8,  0,  0 }, {     23,    7,    8,  8,  0,  0 }, {     23,    8,    7,  8,  5,  0 }, {     23,    9,    7,  8,  5,  0 },
    {     23,   10,    7,  8,  5,  0 }, {     23,   11,    7,  8,  5,  0 }, {     23,   12,    7,  8,  5,  0 }, {     23,   13,    7,  8,  5,  0 }, {     23,   14,    6,  8,  5,  0 },
    {     23,   15,    6,  8,  5,  0 }, {     23,   16,    6,  8,  5,  0 }, {     23,   17,    6,  8,  5,  0 }, {     23,   18,    5,  8,  5,  0 }, {     23,   19,    5,  8,  5,  0 },
    {     23,   20,    5,  8,  5,  0 }, {     23,   21,    4,  8,  5,  0 }, {     23,   22,    4,  8,  5,  0 }, {     23,   23,    4,  8,  5,  0 }, {     23,   24,    3,  8,  6,  0 },
    {     23,   25,    3,  8,  6,  0 }, {     23,   26,    3,  8,  6,  0 }, {     23,   27,    2,  8,  6,  0 }, {     23,   28,    2,  8,  6,  0 }, {     23,   29,    1,  8,  6,  0 },
    {     23,   30,    1,  8,  6,  0 }, {     23,   31,    0,  8,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_90328D, {
    {      0,    9,    8, 16,  0,  0 }, {      1,    9,    8, 16,  0,  0 }, {      2,    9,    8, 16,  0,  0 }, {      3,    9,    8, 16,  0,  0 }, {      4,    9,    8, 16,  0,  0 },
    {      5,    9,    8, 16,  0,  0 }, {      6,    9,    8, 16,  0,  0 }, {      7,    9,    8, 16,  0,  0 }, {      8,    9,    7, 16,  5,  0 }, {      9,    9,    7, 16,  5,  0 },
    {     10,    9,    7, 16,  5,  0 }, {     11,    9,    7, 16,  5,  0 }, {     12,    9,    7, 16,  5,  0 }, {     13,    9,    7, 16,  5,  0 }, {     14,    9,    6, 16,  5,  0 },
    {     15,    9,    6, 16,  5,  0 }, {     16,    9,    6, 16,  5,  0 }, {     17,    9,    6, 16,  5,  0 }, {     18,    9,    5, 16,  5,  0 }, {     19,    9,    5, 16,  5,  0 },
    {     20,    9,    5, 16,  5,  0 }, {     21,    9,    4, 16,  5,  0 }, {     22,    9,    4, 16,  5,  0 }, {     23,    9,    4, 16,  5,  0 }, {     24,    9,    3, 16,  6,  0 },
    {     25,    9,    3, 16,  6,  0 }, {     26,    9,    3, 16,  6,  0 }, {     27,    9,    2, 16,  6,  0 }, {     28,    9,    2, 16,  6,  0 }, {     29,    9,    1, 16,  6,  0 },
    {     30,    9,    1, 16,  6,  0 }, {     31,    9,    0, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9033AF, {
    {      9,   31,    8, 24,  0,  0 }, {      9,   30,    8, 24,  0,  0 }, {      9,   29,    8, 24,  0,  0 }, {      9,   28,    8, 24,  0,  0 }, {      9,   27,    8, 24,  0,  0 },
    {      9,   26,    8, 24,  0,  0 }, {      9,   25,    8, 24,  0,  0 }, {      9,   24,    8, 24,  0,  0 }, {      9,   23,    7, 24,  5,  0 }, {      9,   22,    7, 24,  5,  0 },
    {      9,   21,    7, 24,  5,  0 }, {      9,   20,    7, 24,  5,  0 }, {      9,   19,    7, 24,  5,  0 }, {      9,   18,    7, 24,  5,  0 }, {      9,   17,    6, 24,  5,  0 },
    {      9,   16,    6, 24,  5,  0 }, {      9,   15,    6, 24,  5,  0 }, {      9,   14,    6, 24,  5,  0 }, {      9,   13,    5, 24,  5,  0 }, {      9,   12,    5, 24,  5,  0 },
    {      9,   11,    5, 24,  5,  0 }, {      9,   10,    4, 24,  5,  0 }, {      9,    9,    4, 24,  5,  0 }, {      9,    8,    4, 24,  5,  0 }, {      9,    7,    3, 24,  6,  0 },
    {      9,    6,    3, 24,  6,  0 }, {      9,    5,    2, 24,  6,  0 }, {      9,    4,    2, 24,  6,  0 }, {      9,    3,    1, 24,  6,  0 }, {      9,    2,    1, 24,  6,  0 },
    {      9,    1,    0, 24,  6,  0 }, {      9,    0,    0, 24,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_902BC1, {
    {     31,   23,    7,  0,  6,  0 }, {     30,   23,    7,  0,  6,  0 }, {     29,   23,    6,  0,  6,  0 }, {     28,   23,    6,  0,  6,  0 }, {     27,   23,    5,  0,  6,  0 },
    {     26,   23,    5,  0,  6,  0 }, {     25,   23,    4,  0,  6,  0 }, {     24,   23,    4,  0,  6,  0 }, {     23,   23,    4,  0,  5,  0 }, {     22,   23,    3,  0,  5,  0 },
    {     21,   23,    3,  0,  5,  0 }, {     20,   23,    3,  0,  5,  0 }, {     19,   23,    2,  0,  5,  0 }, {     18,   23,    2,  0,  5,  0 }, {     17,   23,    2,  0,  5,  0 },
    {     16,   23,    2,  0,  5,  0 }, {     15,   23,    1,  0,  5,  0 }, {     14,   23,    1,  0,  5,  0 }, {     13,   23,    1,  0,  5,  0 }, {     12,   23,    1,  0,  5,  0 },
    {     11,   23,    1,  0,  5,  0 }, {     10,   23,    1,  0,  5,  0 }, {      9,   23,    0,  0,  0,  0 }, {      8,   23,    0,  0,  0,  0 }, {      7,   23,    0,  0,  0,  0 },
    {      6,   23,    0,  0,  0,  0 }, {      5,   23,    0,  0,  0,  0 }, {      4,   23,    0,  0,  0,  0 }, {      3,   23,    0,  0,  0,  0 }, {      2,   23,    0,  0,  0,  0 },
    {      1,   23,    0,  0,  0,  0 }, {      0,   23,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_902CE3, {
    {     23,    0,    8,  8,  6,  0 }, {     23,    1,    7,  8,  6,  0 }, {     23,    2,    7,  8,  6,  0 }, {     23,    3,    6,  8,  6,  0 }, {     23,    4,    6,  8,  6,  0 },
    {     23,    5,    5,  8,  6,  0 }, {     23,    6,    5,  8,  6,  0 }, {     23,    7,    4,  8,  6,  0 }, {     23,    8,    4,  8,  5,  0 }, {     23,    9,    3,  8,  5,  0 },
    {     23,   10,    3,  8,  5,  0 }, {     23,   11,    3,  8,  5,  0 }, {     23,   12,    2,  8,  5,  0 }, {     23,   13,    2,  8,  5,  0 }, {     23,   14,    2,  8,  5,  0 },
    {     23,   15,    2,  8,  5,  0 }, {     23,   16,    1,  8,  5,  0 }, {     23,   17,    1,  8,  5,  0 }, {     23,   18,    1,  8,  5,  0 }, {     23,   19,    1,  8,  5,  0 },
    {     23,   20,    1,  8,  5,  0 }, {     23,   21,    1,  8,  5,  0 }, {     23,   22,    0,  8,  0,  0 }, {     23,   23,    0,  8,  0,  0 }, {     23,   24,    0,  8,  0,  0 },
    {     23,   25,    0,  8,  0,  0 }, {     23,   26,    0,  8,  0,  0 }, {     23,   27,    0,  8,  0,  0 }, {     23,   28,    0,  8,  0,  0 }, {     23,   29,    0,  8,  0,  0 },
    {     23,   30,    0,  8,  0,  0 }, {     23,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_902E05, {
    {      0,    9,    8, 16,  6,  0 }, {      1,    9,    7, 16,  6,  0 }, {      2,    9,    7, 16,  6,  0 }, {      3,    9,    6, 16,  6,  0 }, {      4,    9,    6, 16,  6,  0 },
    {      5,    9,    5, 16,  6,  0 }, {      6,    9,    5, 16,  6,  0 }, {      7,    9,    4, 16,  6,  0 }, {      8,    9,    4, 16,  5,  0 }, {      9,    9,    3, 16,  5,  0 },
    {     10,    9,    3, 16,  5,  0 }, {     11,    9,    3, 16,  5,  0 }, {     12,    9,    2, 16,  5,  0 }, {     13,    9,    2, 16,  5,  0 }, {     14,    9,    2, 16,  5,  0 },
    {     15,    9,    2, 16,  5,  0 }, {     16,    9,    1, 16,  5,  0 }, {     17,    9,    1, 16,  5,  0 }, {     18,    9,    1, 16,  5,  0 }, {     19,    9,    1, 16,  5,  0 },
    {     20,    9,    1, 16,  5,  0 }, {     21,    9,    1, 16,  5,  0 }, {     22,    9,    0, 16,  0,  0 }, {     23,    9,    0, 16,  0,  0 }, {     24,    9,    0, 16,  0,  0 },
    {     25,    9,    0, 16,  0,  0 }, {     26,    9,    0, 16,  0,  0 }, {     27,    9,    0, 16,  0,  0 }, {     28,    9,    0, 16,  0,  0 }, {     29,    9,    0, 16,  0,  0 },
    {     30,    9,    0, 16,  0,  0 }, {     31,    9,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_902F27, {
    {      9,   31,    7, 24,  6,  0 }, {      9,   30,    7, 24,  6,  0 }, {      9,   29,    6, 24,  6,  0 }, {      9,   28,    6, 24,  6,  0 }, {      9,   27,    5, 24,  6,  0 },
    {      9,   26,    5, 24,  6,  0 }, {      9,   25,    4, 24,  6,  0 }, {      9,   24,    4, 24,  6,  0 }, {      9,   23,    4, 24,  5,  0 }, {      9,   22,    3, 24,  5,  0 },
    {      9,   21,    3, 24,  5,  0 }, {      9,   20,    3, 24,  5,  0 }, {      9,   19,    2, 24,  5,  0 }, {      9,   18,    2, 24,  5,  0 }, {      9,   17,    2, 24,  5,  0 },
    {      9,   16,    2, 24,  5,  0 }, {      9,   15,    1, 24,  5,  0 }, {      9,   14,    1, 24,  5,  0 }, {      9,   13,    1, 24,  5,  0 }, {      9,   12,    1, 24,  5,  0 },
    {      9,   11,    1, 24,  5,  0 }, {      9,   10,    1, 24,  5,  0 }, {      9,    9,    0, 24,  0,  0 }, {      9,    8,    0, 24,  0,  0 }, {      9,    7,    0, 24,  0,  0 },
    {      9,    6,    0, 24,  0,  0 }, {      9,    5,    0, 24,  0,  0 }, {      9,    4,    0, 24,  0,  0 }, {      9,    3,    0, 24,  0,  0 }, {      9,    2,    0, 24,  0,  0 },
    {      9,    1,    0, 24,  0,  0 }, {      9,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_903DE1, {
    {     31,   23,    0,  0,  0,  0 }, {     30,   23,    0,  0,  0,  0 }, {     29,   23,    0,  0,  0,  0 }, {     28,   23,    0, 31,  0,  0 }, {     27,   23,    0, 31,  0,  0 },
    {     26,   22,    0, 31,  0,  0 }, {     25,   22,    0, 31,  0,  0 }, {     24,   22,    0, 30,  0,  0 }, {     23,   21,    0, 30,  0,  0 }, {     22,   21,    0, 30,  0,  0 },
    {     21,   21,    0, 30,  0,  0 }, {     20,   20,    0, 29,  0,  0 }, {     19,   20,    0, 29,  0,  0 }, {     18,   19,    0, 29,  0,  0 }, {     17,   18,    0, 29,  0,  0 },
    {     16,   17,    0, 28,  0,  0 }, {     15,   16,    0, 28,  0,  0 }, {     14,   15,    0, 27,  0,  0 }, {     13,   14,    0, 27,  0,  0 }, {     12,   13,    0, 27,  0,  0 },
    {     12,   12,    0, 27,  0,  0 }, {     11,   11,    0, 26,  0,  0 }, {     11,   10,    0, 26,  0,  0 }, {     11,    9,    0, 26,  0,  0 }, {     10,    8,    0, 26,  0,  0 },
    {     10,    7,    0, 25,  0,  0 }, {     10,    6,    0, 25,  0,  0 }, {      9,    5,    0, 25,  0,  0 }, {      9,    4,    0, 25,  0,  0 }, {      9,    3,    0, 24,  0,  0 },
    {      9,    2,    0, 24,  0,  0 }, {      9,    1,    0, 24,  0,  0 }, {      9,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_903F0C, {
    {     23,    0,    0,  8,  0,  0 }, {     23,    1,    0,  8,  0,  0 }, {     23,    2,    0,  8,  0,  0 }, {     23,    3,    0,  8,  0,  0 }, {     23,    4,    0,  7,  0,  0 },
    {     23,    5,    0,  7,  0,  0 }, {     22,    6,    0,  7,  0,  0 }, {     22,    7,    0,  7,  0,  0 }, {     22,    8,    0,  6,  0,  0 }, {     21,    9,    0,  6,  0,  0 },
    {     21,   10,    0,  6,  0,  0 }, {     21,   11,    0,  6,  0,  0 }, {     20,   12,    0,  5,  0,  0 }, {     20,   13,    0,  5,  0,  0 }, {     19,   14,    0,  5,  0,  0 },
    {     18,   15,    0,  5,  0,  0 }, {     17,   16,    0,  4,  0,  0 }, {     16,   17,    0,  4,  0,  0 }, {     15,   18,    0,  3,  0,  0 }, {     14,   19,    0,  3,  0,  0 },
    {     13,   20,    0,  3,  0,  0 }, {     12,   20,    0,  3,  0,  0 }, {     11,   21,    0,  2,  0,  0 }, {     10,   21,    0,  2,  0,  0 }, {      9,   21,    0,  2,  0,  0 },
    {      8,   22,    0,  2,  0,  0 }, {      7,   22,    0,  1,  0,  0 }, {      6,   22,    0,  1,  0,  0 }, {      5,   23,    0,  1,  0,  0 }, {      4,   23,    0,  1,  0,  0 },
    {      3,   23,    0,  0,  0,  0 }, {      2,   23,    0,  0,  0,  0 }, {      1,   23,    0,  0,  0,  0 }, {      0,   23,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_904040, {
    {      0,    9,    0, 16,  0,  0 }, {      1,    9,    0, 16,  0,  0 }, {      2,    9,    0, 16,  0,  0 }, {      3,    9,    0, 16,  0,  0 }, {      4,    9,    0, 15,  0,  0 },
    {      5,   10,    0, 15,  0,  0 }, {      6,   10,    0, 15,  0,  0 }, {      7,   10,    0, 15,  0,  0 }, {      8,   11,    0, 14,  0,  0 }, {      9,   11,    0, 14,  0,  0 },
    {     10,   11,    0, 14,  0,  0 }, {     11,   12,    0, 14,  0,  0 }, {     12,   12,    0, 13,  0,  0 }, {     13,   13,    0, 13,  0,  0 }, {     14,   14,    0, 13,  0,  0 },
    {     15,   15,    0, 13,  0,  0 }, {     16,   16,    0, 12,  0,  0 }, {     17,   17,    0, 12,  0,  0 }, {     18,   18,    0, 11,  0,  0 }, {     19,   19,    0, 11,  0,  0 },
    {     20,   20,    0, 11,  0,  0 }, {     20,   21,    0, 11,  0,  0 }, {     21,   22,    0, 10,  0,  0 }, {     21,   23,    0, 10,  0,  0 }, {     21,   24,    0, 10,  0,  0 },
    {     22,   25,    0, 10,  0,  0 }, {     22,   26,    0,  9,  0,  0 }, {     22,   27,    0,  9,  0,  0 }, {     23,   28,    0,  9,  0,  0 }, {     23,   29,    0,  9,  0,  0 },
    {     23,   30,    0,  8,  0,  0 }, {     23,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_904162, {
    {      9,   31,    0, 24,  0,  0 }, {      9,   30,    0, 24,  0,  0 }, {      9,   29,    0, 24,  0,  0 }, {      9,   28,    0, 23,  0,  0 }, {      9,   27,    0, 23,  0,  0 },
    {     10,   26,    0, 23,  0,  0 }, {     10,   25,    0, 23,  0,  0 }, {     10,   24,    0, 22,  0,  0 }, {     11,   23,    0, 22,  0,  0 }, {     11,   22,    0, 22,  0,  0 },
    {     11,   21,    0, 22,  0,  0 }, {     12,   20,    0, 21,  0,  0 }, {     12,   19,    0, 21,  0,  0 }, {     13,   18,    0, 21,  0,  0 }, {     14,   17,    0, 21,  0,  0 },
    {     15,   16,    0, 20,  0,  0 }, {     16,   15,    0, 20,  0,  0 }, {     17,   14,    0, 19,  0,  0 }, {     18,   13,    0, 19,  0,  0 }, {     19,   12,    0, 19,  0,  0 },
    {     20,   12,    0, 19,  0,  0 }, {     21,   11,    0, 18,  0,  0 }, {     22,   11,    0, 18,  0,  0 }, {     23,   11,    0, 18,  0,  0 }, {     24,   10,    0, 18,  0,  0 },
    {     25,   10,    0, 17,  0,  0 }, {     26,   10,    0, 17,  0,  0 }, {     27,    9,    0, 17,  0,  0 }, {     28,    9,    0, 17,  0,  0 }, {     29,    9,    0, 16,  0,  0 },
    {     30,    9,    0, 16,  0,  0 }, {     31,    9,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_904284, {
    {     31,   23,    0,  0,  0,  0 }, {     30,   23,    0,  1,  0,  0 }, {     29,   23,    0,  1,  0,  0 }, {     28,   24,    0,  2,  0,  0 }, {     27,   24,    0,  2,  0,  0 },
    {     26,   25,    0,  4,  0,  0 }, {     25,   26,    0,  4,  0,  0 }, {     24,   27,    0,  6,  0,  0 }, {     24,   28,    0,  6,  0,  0 }, {     23,   29,    0,  7,  0,  0 },
    {     23,   30,    0,  7,  0,  0 }, {     23,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9042F2, {
    {     23,    0,    0,  8,  0,  0 }, {     23,    1,    0,  8,  0,  0 }, {     23,    2,    0,  9,  0,  0 }, {     23,    3,    0,  9,  0,  0 }, {     24,    4,    0, 10,  0,  0 },
    {     24,    5,    0, 10,  0,  0 }, {     25,    6,    0, 12,  0,  0 }, {     26,    7,    0, 12,  0,  0 }, {     27,    8,    0, 14,  0,  0 }, {     28,    8,    0, 14,  0,  0 },
    {     29,    9,    0, 15,  0,  0 }, {     30,    9,    0, 15,  0,  0 }, {     31,    9,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_904369, {
    {      0,    9,    0, 16,  0,  0 }, {      1,    9,    0, 16,  0,  0 }, {      2,    9,    0, 17,  0,  0 }, {      3,    9,    0, 17,  0,  0 }, {      4,    8,    0, 18,  0,  0 },
    {      5,    8,    0, 18,  0,  0 }, {      6,    7,    0, 20,  0,  0 }, {      7,    6,    0, 20,  0,  0 }, {      8,    5,    0, 22,  0,  0 }, {      8,    4,    0, 22,  0,  0 },
    {      9,    3,    0, 23,  0,  0 }, {      9,    2,    0, 23,  0,  0 }, {      9,    1,    0, 24,  0,  0 }, {      9,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9043E9, {
    {      9,   31,    0, 24,  0,  0 }, {      9,   30,    0, 25,  0,  0 }, {      9,   29,    0, 25,  0,  0 }, {      8,   28,    0, 26,  0,  0 }, {      8,   27,    0, 26,  0,  0 },
    {      7,   26,    0, 28,  0,  0 }, {      6,   25,    0, 28,  0,  0 }, {      5,   24,    0, 30,  0,  0 }, {      4,   24,    0, 30,  0,  0 }, {      3,   23,    0, 31,  0,  0 },
    {      2,   23,    0, 31,  0,  0 }, {      1,   23,    0,  0,  0,  0 }, {      0,   23,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FF762, {
    {     31,    9,    0,  0,  0,  0 }, {     30,    9,    0,  0,  0,  0 }, {     29,    9,    0,  0,  0,  0 }, {     28,    9,    0,  0,  0,  0 }, {     27,   10,    0,  2,  0,  0 },
    {     26,   10,    0,  2,  0,  0 }, {     25,   10,    0,  2,  0,  0 }, {     24,   11,    0,  2,  0,  0 }, {     23,   11,    0,  2,  0,  0 }, {     22,   12,    0,  2,  0,  0 },
    {     21,   12,    0,  2,  0,  0 }, {     20,   13,    0,  2,  0,  0 }, {     19,   14,    0,  2,  0,  0 }, {     18,   14,    0,  2,  0,  0 }, {     17,   15,    0,  2,  0,  0 },
    {     16,   16,    0,  2,  0,  0 }, {     15,   16,    0,  2,  0,  0 }, {     14,   17,    0,  2,  0,  0 }, {     13,   18,    0,  2,  0,  0 }, {     12,   18,    0,  2,  0,  0 },
    {     11,   19,    0,  2,  0,  0 }, {     10,   20,    0,  2,  0,  0 }, {      9,   20,    0,  2,  0,  0 }, {      8,   21,    0,  2,  0,  0 }, {      7,   21,    0,  2,  0,  0 },
    {      6,   22,    0,  2,  0,  0 }, {      5,   22,    0,  2,  0,  0 }, {      4,   22,    0,  2,  0,  0 }, {      3,   23,    0,  0,  0,  0 }, {      2,   23,    0,  0,  0,  0 },
    {      1,   23,    0,  0,  0,  0 }, {      0,   23,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FF884, {
    {      9,    0,    0,  8,  0,  0 }, {      9,    1,    0,  8,  0,  0 }, {      9,    2,    0,  8,  0,  0 }, {      9,    3,    0,  8,  0,  0 }, {     10,    4,    0, 10,  0,  0 },
    {     10,    5,    0, 10,  0,  0 }, {     10,    6,    0, 10,  0,  0 }, {     11,    7,    0, 10,  0,  0 }, {     11,    8,    0, 10,  0,  0 }, {     12,    9,    0, 10,  0,  0 },
    {     12,   10,    0, 10,  0,  0 }, {     13,   11,    0, 10,  0,  0 }, {     14,   12,    0, 10,  0,  0 }, {     14,   13,    0, 10,  0,  0 }, {     15,   14,    0, 10,  0,  0 },
    {     16,   15,    0, 10,  0,  0 }, {     16,   16,    0, 10,  0,  0 }, {     17,   17,    0, 10,  0,  0 }, {     18,   18,    0, 10,  0,  0 }, {     18,   19,    0, 10,  0,  0 },
    {     19,   20,    0, 10,  0,  0 }, {     20,   21,    0, 10,  0,  0 }, {     20,   22,    0, 10,  0,  0 }, {     21,   23,    0, 10,  0,  0 }, {     21,   24,    0, 10,  0,  0 },
    {     22,   25,    0, 10,  0,  0 }, {     22,   26,    0, 10,  0,  0 }, {     22,   27,    0, 10,  0,  0 }, {     23,   28,    0,  8,  0,  0 }, {     23,   29,    0,  8,  0,  0 },
    {     23,   30,    0,  8,  0,  0 }, {     23,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FF9A6, {
    {      0,   23,    0, 16,  0,  0 }, {      1,   23,    0, 16,  0,  0 }, {      2,   23,    0, 16,  0,  0 }, {      3,   23,    0, 16,  0,  0 }, {      4,   22,    0, 18,  0,  0 },
    {      5,   22,    0, 18,  0,  0 }, {      6,   22,    0, 18,  0,  0 }, {      7,   21,    0, 18,  0,  0 }, {      8,   21,    0, 18,  0,  0 }, {      9,   20,    0, 18,  0,  0 },
    {     10,   20,    0, 18,  0,  0 }, {     11,   19,    0, 18,  0,  0 }, {     12,   18,    0, 18,  0,  0 }, {     13,   18,    0, 18,  0,  0 }, {     14,   17,    0, 18,  0,  0 },
    {     15,   16,    0, 18,  0,  0 }, {     16,   16,    0, 18,  0,  0 }, {     17,   15,    0, 18,  0,  0 }, {     18,   14,    0, 18,  0,  0 }, {     19,   14,    0, 18,  0,  0 },
    {     20,   13,    0, 18,  0,  0 }, {     21,   12,    0, 18,  0,  0 }, {     22,   12,    0, 18,  0,  0 }, {     23,   11,    0, 18,  0,  0 }, {     24,   11,    0, 18,  0,  0 },
    {     25,   10,    0, 18,  0,  0 }, {     26,   10,    0, 18,  0,  0 }, {     27,   10,    0, 18,  0,  0 }, {     28,    9,    0, 16,  0,  0 }, {     29,    9,    0, 16,  0,  0 },
    {     30,    9,    0, 16,  0,  0 }, {     31,    9,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_8FFAC8, {
    {     23,   31,    0, 24,  0,  0 }, {     23,   30,    0, 24,  0,  0 }, {     23,   29,    0, 24,  0,  0 }, {     23,   28,    0, 24,  0,  0 }, {     22,   27,    0, 26,  0,  0 },
    {     22,   26,    0, 26,  0,  0 }, {     22,   25,    0, 26,  0,  0 }, {     21,   24,    0, 26,  0,  0 }, {     21,   23,    0, 26,  0,  0 }, {     20,   22,    0, 26,  0,  0 },
    {     20,   21,    0, 26,  0,  0 }, {     19,   20,    0, 26,  0,  0 }, {     18,   19,    0, 26,  0,  0 }, {     18,   18,    0, 26,  0,  0 }, {     17,   17,    0, 26,  0,  0 },
    {     16,   16,    0, 26,  0,  0 }, {     16,   15,    0, 26,  0,  0 }, {     15,   14,    0, 26,  0,  0 }, {     14,   13,    0, 26,  0,  0 }, {     14,   12,    0, 26,  0,  0 },
    {     13,   11,    0, 26,  0,  0 }, {     12,   10,    0, 26,  0,  0 }, {     12,    9,    0, 26,  0,  0 }, {     11,    8,    0, 26,  0,  0 }, {     11,    7,    0, 26,  0,  0 },
    {     10,    6,    0, 26,  0,  0 }, {     10,    5,    0, 26,  0,  0 }, {     10,    4,    0, 26,  0,  0 }, {      9,    3,    0, 24,  0,  0 }, {      9,    2,    0, 24,  0,  0 },
    {      9,    1,    0, 24,  0,  0 }, {      9,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_904460, {
    {     31,   23,    0,  0,  0,  0 }, {     30,   23,    0,  0,  0,  0 }, {     29,   23,    0,  0,  0,  0 }, {     28,   23,    0,  0,  0,  0 }, {     27,   22,    0, 30,  0,  0 },
    {     26,   22,    0, 30,  0,  0 }, {     25,   22,    0, 30,  0,  0 }, {     24,   21,    0, 30,  0,  0 }, {     23,   21,    0, 30,  0,  0 }, {     22,   20,    0, 30,  0,  0 },
    {     21,   20,    0, 30,  0,  0 }, {     20,   19,    0, 30,  0,  0 }, {     19,   18,    0, 30,  0,  0 }, {     18,   18,    0, 30,  0,  0 }, {     17,   17,    0, 30,  0,  0 },
    {     16,   16,    0, 30,  0,  0 }, {     15,   16,    0, 30,  0,  0 }, {     14,   15,    0, 30,  0,  0 }, {     13,   14,    0, 30,  0,  0 }, {     12,   14,    0, 30,  0,  0 },
    {     11,   13,    0, 30,  0,  0 }, {     10,   12,    0, 30,  0,  0 }, {      9,   12,    0, 30,  0,  0 }, {      8,   11,    0, 30,  0,  0 }, {      7,   11,    0, 30,  0,  0 },
    {      6,   10,    0, 30,  0,  0 }, {      5,   10,    0, 30,  0,  0 }, {      4,   10,    0, 30,  0,  0 }, {      3,    9,    0,  0,  0,  0 }, {      2,    9,    0,  0,  0,  0 },
    {      1,    9,    0,  0,  0,  0 }, {      0,    9,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_904582, {
    {     23,    0,    0,  8,  0,  0 }, {     23,    1,    0,  8,  0,  0 }, {     23,    2,    0,  8,  0,  0 }, {     23,    3,    0,  8,  0,  0 }, {     22,    4,    0,  6,  0,  0 },
    {     22,    5,    0,  6,  0,  0 }, {     22,    6,    0,  6,  0,  0 }, {     21,    7,    0,  6,  0,  0 }, {     21,    8,    0,  6,  0,  0 }, {     20,    9,    0,  6,  0,  0 },
    {     20,   10,    0,  6,  0,  0 }, {     19,   11,    0,  6,  0,  0 }, {     18,   12,    0,  6,  0,  0 }, {     18,   13,    0,  6,  0,  0 }, {     17,   14,    0,  6,  0,  0 },
    {     16,   15,    0,  6,  0,  0 }, {     16,   16,    0,  6,  0,  0 }, {     15,   17,    0,  6,  0,  0 }, {     14,   18,    0,  6,  0,  0 }, {     14,   19,    0,  6,  0,  0 },
    {     13,   20,    0,  6,  0,  0 }, {     12,   21,    0,  6,  0,  0 }, {     12,   22,    0,  6,  0,  0 }, {     11,   23,    0,  6,  0,  0 }, {     11,   24,    0,  6,  0,  0 },
    {     10,   25,    0,  6,  0,  0 }, {     10,   26,    0,  6,  0,  0 }, {     10,   27,    0,  6,  0,  0 }, {      9,   28,    0,  8,  0,  0 }, {      9,   29,    0,  8,  0,  0 },
    {      9,   30,    0,  8,  0,  0 }, {      9,   31,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9046A4, {
    {      0,    9,    0, 16,  0,  0 }, {      1,    9,    0, 16,  0,  0 }, {      2,    9,    0, 16,  0,  0 }, {      3,    9,    0, 16,  0,  0 }, {      4,   10,    0, 14,  0,  0 },
    {      5,   10,    0, 14,  0,  0 }, {      6,   10,    0, 14,  0,  0 }, {      7,   11,    0, 14,  0,  0 }, {      8,   11,    0, 14,  0,  0 }, {      9,   12,    0, 14,  0,  0 },
    {     10,   12,    0, 14,  0,  0 }, {     11,   13,    0, 14,  0,  0 }, {     12,   14,    0, 14,  0,  0 }, {     13,   14,    0, 14,  0,  0 }, {     14,   15,    0, 14,  0,  0 },
    {     15,   16,    0, 14,  0,  0 }, {     16,   16,    0, 14,  0,  0 }, {     17,   17,    0, 14,  0,  0 }, {     18,   18,    0, 14,  0,  0 }, {     19,   18,    0, 14,  0,  0 },
    {     20,   19,    0, 14,  0,  0 }, {     21,   20,    0, 14,  0,  0 }, {     22,   20,    0, 14,  0,  0 }, {     23,   21,    0, 14,  0,  0 }, {     24,   21,    0, 14,  0,  0 },
    {     25,   22,    0, 14,  0,  0 }, {     26,   22,    0, 14,  0,  0 }, {     27,   22,    0, 14,  0,  0 }, {     28,   23,    0, 16,  0,  0 }, {     29,   23,    0, 16,  0,  0 },
    {     30,   23,    0, 16,  0,  0 }, {     31,   23,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9047C6, {
    {      9,   31,    0, 24,  0,  0 }, {      9,   30,    0, 24,  0,  0 }, {      9,   29,    0, 24,  0,  0 }, {      9,   28,    0, 24,  0,  0 }, {     10,   27,    0, 22,  0,  0 },
    {     10,   26,    0, 22,  0,  0 }, {     10,   25,    0, 22,  0,  0 }, {     11,   24,    0, 22,  0,  0 }, {     11,   23,    0, 22,  0,  0 }, {     12,   22,    0, 22,  0,  0 },
    {     12,   21,    0, 22,  0,  0 }, {     13,   20,    0, 22,  0,  0 }, {     14,   19,    0, 22,  0,  0 }, {     14,   18,    0, 22,  0,  0 }, {     15,   17,    0, 22,  0,  0 },
    {     16,   16,    0, 22,  0,  0 }, {     16,   15,    0, 22,  0,  0 }, {     17,   14,    0, 22,  0,  0 }, {     18,   13,    0, 22,  0,  0 }, {     18,   12,    0, 22,  0,  0 },
    {     19,   11,    0, 22,  0,  0 }, {     20,   10,    0, 22,  0,  0 }, {     20,    9,    0, 22,  0,  0 }, {     21,    8,    0, 22,  0,  0 }, {     21,    7,    0, 22,  0,  0 },
    {     22,    6,    0, 22,  0,  0 }, {     22,    5,    0, 22,  0,  0 }, {     22,    4,    0, 22,  0,  0 }, {     23,    3,    0, 24,  0,  0 }, {     23,    2,    0, 24,  0,  0 },
    {     23,    1,    0, 24,  0,  0 }, {     23,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938212, {
    {     30,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     26,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     20,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 }, {     16,   16,    0,  0,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 },
    {     10,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      6,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9382A4, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 },
    {     16,   20,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938336, {
    {      0,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     14,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     18,   16,    0, 16,  0,  0 },
    {     20,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9383C8, {
    {     16,   30,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   26,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   20,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 }, {     16,   16,    0, 24,  0,  0 }, {     16,   14,    0, 24,  0,  0 }, {     16,   12,    0, 24,  0,  0 },
    {     16,   10,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 }, {     16,    6,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938D7A, {
    {     30,   16,    1,  0,  0,  0 }, {     28,   16,    2,  0,  0,  0 }, {     26,   16,    3,  0,  0,  0 }, {     24,   16,    4,  0,  0,  0 }, {     22,   16,    5,  0,  0,  0 },
    {     20,   16,    6,  0,  0,  0 }, {     18,   16,    7,  0,  0,  0 }, {     16,   16,    8,  0,  0,  0 }, {     14,   16,    9,  0,  0,  0 }, {     12,   16,   10,  0,  0,  0 },
    {     10,   16,   11,  0,  0,  0 }, {      8,   16,   12,  0,  0,  0 }, {      6,   16,   13,  0,  0,  0 }, {      4,   16,   14,  0,  0,  0 }, {      2,   16,   15,  0,  0,  0 },
    {      0,   16,   16,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938E0C, {
    {     16,    0,    1,  8,  0,  0 }, {     16,    2,    2,  8,  0,  0 }, {     16,    4,    3,  8,  0,  0 }, {     16,    6,    4,  8,  0,  0 }, {     16,    8,    5,  8,  0,  0 },
    {     16,   10,    6,  8,  0,  0 }, {     16,   12,    7,  8,  0,  0 }, {     16,   14,    8,  8,  0,  0 }, {     16,   16,    9,  8,  0,  0 }, {     16,   18,   10,  8,  0,  0 },
    {     16,   20,   11,  8,  0,  0 }, {     16,   22,   12,  8,  0,  0 }, {     16,   24,   13,  8,  0,  0 }, {     16,   26,   14,  8,  0,  0 }, {     16,   28,   15,  8,  0,  0 },
    {     16,   30,   16,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938E9E, {
    {      0,   16,    1, 16,  0,  0 }, {      2,   16,    2, 16,  0,  0 }, {      4,   16,    3, 16,  0,  0 }, {      6,   16,    4, 16,  0,  0 }, {      8,   16,    5, 16,  0,  0 },
    {     10,   16,    6, 16,  0,  0 }, {     12,   16,    7, 16,  0,  0 }, {     14,   16,    8, 16,  0,  0 }, {     16,   16,    9, 16,  0,  0 }, {     18,   16,   10, 16,  0,  0 },
    {     20,   16,   11, 16,  0,  0 }, {     22,   16,   12, 16,  0,  0 }, {     24,   16,   13, 16,  0,  0 }, {     26,   16,   14, 16,  0,  0 }, {     28,   16,   15, 16,  0,  0 },
    {     30,   16,   16, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938F30, {
    {     16,   30,    1, 24,  0,  0 }, {     16,   28,    2, 24,  0,  0 }, {     16,   26,    3, 24,  0,  0 }, {     16,   24,    4, 24,  0,  0 }, {     16,   22,    5, 24,  0,  0 },
    {     16,   20,    6, 24,  0,  0 }, {     16,   18,    7, 24,  0,  0 }, {     16,   16,    8, 24,  0,  0 }, {     16,   14,    9, 24,  0,  0 }, {     16,   12,   10, 24,  0,  0 },
    {     16,   10,   11, 24,  0,  0 }, {     16,    8,   12, 24,  0,  0 }, {     16,    6,   13, 24,  0,  0 }, {     16,    4,   14, 24,  0,  0 }, {     16,    2,   15, 24,  0,  0 },
    {     16,    0,   16, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93845A, {
    {     30,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     26,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     20,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 }, {     16,   16,    0,  0,  0,  0 }, {     14,   16,    1,  0,  0,  0 }, {     12,   16,    2,  0,  0,  0 },
    {     10,   16,    3,  0,  0,  0 }, {      8,   16,    4,  0,  0,  0 }, {      6,   16,    5,  0,  0,  0 }, {      4,   16,    6,  0,  0,  0 }, {      2,   16,    7,  0,  0,  0 },
    {      0,   16,    8,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9384EC, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 }, {     16,   16,    1,  8,  0,  0 }, {     16,   18,    2,  8,  0,  0 },
    {     16,   20,    3,  8,  0,  0 }, {     16,   22,    4,  8,  0,  0 }, {     16,   24,    5,  8,  0,  0 }, {     16,   26,    6,  8,  0,  0 }, {     16,   28,    7,  8,  0,  0 },
    {     16,   30,    8,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93857E, {
    {      0,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     14,   16,    0, 16,  0,  0 }, {     16,   16,    1, 16,  0,  0 }, {     18,   16,    2, 16,  0,  0 },
    {     20,   16,    3, 16,  0,  0 }, {     22,   16,    4, 16,  0,  0 }, {     24,   16,    5, 16,  0,  0 }, {     26,   16,    6, 16,  0,  0 }, {     28,   16,    7, 16,  0,  0 },
    {     30,   16,    8, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938610, {
    {     16,   30,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   26,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   20,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 }, {     16,   16,    0, 24,  0,  0 }, {     16,   14,    1, 24,  0,  0 }, {     16,   12,    2, 24,  0,  0 },
    {     16,   10,    3, 24,  0,  0 }, {     16,    8,    4, 24,  0,  0 }, {     16,    6,    5, 24,  0,  0 }, {     16,    4,    6, 24,  0,  0 }, {     16,    2,    7, 24,  0,  0 },
    {     16,    0,    8, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9386A2, {
    {     30,   16,    1,  0,  0,  0 }, {     28,   16,    2,  0,  0,  0 }, {     26,   16,    3,  0,  0,  0 }, {     24,   16,    4,  0,  0,  0 }, {     22,   16,    5,  0,  0,  0 },
    {     20,   16,    6,  0,  0,  0 }, {     18,   16,    7,  0,  0,  0 }, {     16,   16,    8,  0,  0,  0 }, {     14,   16,    8,  0,  0,  0 }, {     12,   16,    8,  0,  0,  0 },
    {     10,   16,    8,  0,  0,  0 }, {      8,   16,    8,  0,  0,  0 }, {      6,   16,    8,  0,  0,  0 }, {      4,   16,    8,  0,  0,  0 }, {      2,   16,    8,  0,  0,  0 },
    {      0,   16,    8,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938734, {
    {     16,    0,    1,  8,  0,  0 }, {     16,    2,    2,  8,  0,  0 }, {     16,    4,    3,  8,  0,  0 }, {     16,    6,    4,  8,  0,  0 }, {     16,    8,    5,  8,  0,  0 },
    {     16,   10,    6,  8,  0,  0 }, {     16,   12,    7,  8,  0,  0 }, {     16,   14,    8,  8,  0,  0 }, {     16,   16,    8,  8,  0,  0 }, {     16,   18,    8,  8,  0,  0 },
    {     16,   20,    8,  8,  0,  0 }, {     16,   22,    8,  8,  0,  0 }, {     16,   24,    8,  8,  0,  0 }, {     16,   26,    8,  8,  0,  0 }, {     16,   28,    8,  8,  0,  0 },
    {     16,   30,    8,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9387C6, {
    {      0,   16,    1, 16,  0,  0 }, {      2,   16,    2, 16,  0,  0 }, {      4,   16,    3, 16,  0,  0 }, {      6,   16,    4, 16,  0,  0 }, {      8,   16,    5, 16,  0,  0 },
    {     10,   16,    6, 16,  0,  0 }, {     12,   16,    7, 16,  0,  0 }, {     14,   16,    8, 16,  0,  0 }, {     16,   16,    8, 16,  0,  0 }, {     18,   16,    8, 16,  0,  0 },
    {     20,   16,    8, 16,  0,  0 }, {     22,   16,    8, 16,  0,  0 }, {     24,   16,    8, 16,  0,  0 }, {     26,   16,    8, 16,  0,  0 }, {     28,   16,    8, 16,  0,  0 },
    {     30,   16,    8, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938858, {
    {     16,   30,    1, 24,  0,  0 }, {     16,   28,    2, 24,  0,  0 }, {     16,   26,    3, 24,  0,  0 }, {     16,   24,    4, 24,  0,  0 }, {     16,   22,    5, 24,  0,  0 },
    {     16,   20,    6, 24,  0,  0 }, {     16,   18,    7, 24,  0,  0 }, {     16,   16,    8, 24,  0,  0 }, {     16,   14,    8, 24,  0,  0 }, {     16,   12,    8, 24,  0,  0 },
    {     16,   10,    8, 24,  0,  0 }, {     16,    8,    8, 24,  0,  0 }, {     16,    6,    8, 24,  0,  0 }, {     16,    4,    8, 24,  0,  0 }, {     16,    2,    8, 24,  0,  0 },
    {     16,    0,    8, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938FC2, {
    {     30,   16,   16,  0,  0,  0 }, {     28,   16,   15,  0,  0,  0 }, {     26,   16,   14,  0,  0,  0 }, {     24,   16,   13,  0,  0,  0 }, {     22,   16,   12,  0,  0,  0 },
    {     20,   16,   11,  0,  0,  0 }, {     18,   16,   10,  0,  0,  0 }, {     16,   16,    9,  0,  0,  0 }, {     14,   16,    8,  0,  0,  0 }, {     12,   16,    7,  0,  0,  0 },
    {     10,   16,    6,  0,  0,  0 }, {      8,   16,    5,  0,  0,  0 }, {      6,   16,    4,  0,  0,  0 }, {      4,   16,    3,  0,  0,  0 }, {      2,   16,    2,  0,  0,  0 },
    {      0,   16,    1,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_939054, {
    {     16,    0,   16,  8,  0,  0 }, {     16,    2,   15,  8,  0,  0 }, {     16,    4,   14,  8,  0,  0 }, {     16,    6,   13,  8,  0,  0 }, {     16,    8,   12,  8,  0,  0 },
    {     16,   10,   11,  8,  0,  0 }, {     16,   12,   10,  8,  0,  0 }, {     16,   14,    9,  8,  0,  0 }, {     16,   16,    8,  8,  0,  0 }, {     16,   18,    7,  8,  0,  0 },
    {     16,   20,    6,  8,  0,  0 }, {     16,   22,    5,  8,  0,  0 }, {     16,   24,    4,  8,  0,  0 }, {     16,   26,    3,  8,  0,  0 }, {     16,   28,    2,  8,  0,  0 },
    {     16,   30,    1,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9390E6, {
    {      0,   16,   16, 16,  0,  0 }, {      2,   16,   15, 16,  0,  0 }, {      4,   16,   14, 16,  0,  0 }, {      6,   16,   13, 16,  0,  0 }, {      8,   16,   12, 16,  0,  0 },
    {     10,   16,   11, 16,  0,  0 }, {     12,   16,   10, 16,  0,  0 }, {     14,   16,    9, 16,  0,  0 }, {     16,   16,    8, 16,  0,  0 }, {     18,   16,    7, 16,  0,  0 },
    {     20,   16,    6, 16,  0,  0 }, {     22,   16,    5, 16,  0,  0 }, {     24,   16,    4, 16,  0,  0 }, {     26,   16,    3, 16,  0,  0 }, {     28,   16,    2, 16,  0,  0 },
    {     30,   16,    1, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_939178, {
    {     16,   30,   16, 24,  0,  0 }, {     16,   28,   15, 24,  0,  0 }, {     16,   26,   14, 24,  0,  0 }, {     16,   24,   13, 24,  0,  0 }, {     16,   22,   12, 24,  0,  0 },
    {     16,   20,   11, 24,  0,  0 }, {     16,   18,   10, 24,  0,  0 }, {     16,   16,    9, 24,  0,  0 }, {     16,   14,    8, 24,  0,  0 }, {     16,   12,    7, 24,  0,  0 },
    {     16,   10,    6, 24,  0,  0 }, {     16,    8,    5, 24,  0,  0 }, {     16,    6,    4, 24,  0,  0 }, {     16,    4,    3, 24,  0,  0 }, {     16,    2,    2, 24,  0,  0 },
    {     16,    0,    1, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938B32, {
    {     30,   16,    8,  0,  0,  0 }, {     28,   16,    8,  0,  0,  0 }, {     26,   16,    8,  0,  0,  0 }, {     24,   16,    8,  0,  0,  0 }, {     22,   16,    8,  0,  0,  0 },
    {     20,   16,    8,  0,  0,  0 }, {     18,   16,    8,  0,  0,  0 }, {     16,   16,    8,  0,  0,  0 }, {     14,   16,    8,  0,  0,  0 }, {     12,   16,    7,  0,  0,  0 },
    {     10,   16,    6,  0,  0,  0 }, {      8,   16,    5,  0,  0,  0 }, {      6,   16,    4,  0,  0,  0 }, {      4,   16,    3,  0,  0,  0 }, {      2,   16,    2,  0,  0,  0 },
    {      0,   16,    1,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938BC4, {
    {     16,    0,    8,  8,  0,  0 }, {     16,    2,    8,  8,  0,  0 }, {     16,    4,    8,  8,  0,  0 }, {     16,    6,    8,  8,  0,  0 }, {     16,    8,    8,  8,  0,  0 },
    {     16,   10,    8,  8,  0,  0 }, {     16,   12,    8,  8,  0,  0 }, {     16,   14,    8,  8,  0,  0 }, {     16,   16,    8,  8,  0,  0 }, {     16,   18,    7,  8,  0,  0 },
    {     16,   20,    6,  8,  0,  0 }, {     16,   22,    5,  8,  0,  0 }, {     16,   24,    4,  8,  0,  0 }, {     16,   26,    3,  8,  0,  0 }, {     16,   28,    2,  8,  0,  0 },
    {     16,   30,    1,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938C56, {
    {      0,   16,    8, 16,  0,  0 }, {      2,   16,    8, 16,  0,  0 }, {      4,   16,    8, 16,  0,  0 }, {      6,   16,    8, 16,  0,  0 }, {      8,   16,    8, 16,  0,  0 },
    {     10,   16,    8, 16,  0,  0 }, {     12,   16,    8, 16,  0,  0 }, {     14,   16,    8, 16,  0,  0 }, {     16,   16,    8, 16,  0,  0 }, {     18,   16,    7, 16,  0,  0 },
    {     20,   16,    6, 16,  0,  0 }, {     22,   16,    5, 16,  0,  0 }, {     24,   16,    4, 16,  0,  0 }, {     26,   16,    3, 16,  0,  0 }, {     28,   16,    2, 16,  0,  0 },
    {     30,   16,    1, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938CE8, {
    {     16,   30,    8, 24,  0,  0 }, {     16,   28,    8, 24,  0,  0 }, {     16,   26,    8, 24,  0,  0 }, {     16,   24,    8, 24,  0,  0 }, {     16,   22,    8, 24,  0,  0 },
    {     16,   20,    8, 24,  0,  0 }, {     16,   18,    8, 24,  0,  0 }, {     16,   16,    8, 24,  0,  0 }, {     16,   14,    8, 24,  0,  0 }, {     16,   12,    7, 24,  0,  0 },
    {     16,   10,    6, 24,  0,  0 }, {     16,    8,    5, 24,  0,  0 }, {     16,    6,    4, 24,  0,  0 }, {     16,    4,    3, 24,  0,  0 }, {     16,    2,    2, 24,  0,  0 },
    {     16,    0,    1, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9388EA, {
    {     30,   16,    8,  0,  0,  0 }, {     28,   16,    7,  0,  0,  0 }, {     26,   16,    6,  0,  0,  0 }, {     24,   16,    5,  0,  0,  0 }, {     22,   16,    4,  0,  0,  0 },
    {     20,   16,    3,  0,  0,  0 }, {     18,   16,    2,  0,  0,  0 }, {     16,   16,    1,  0,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 },
    {     10,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      6,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93897C, {
    {     16,    0,    8,  8,  0,  0 }, {     16,    2,    7,  8,  0,  0 }, {     16,    4,    6,  8,  0,  0 }, {     16,    6,    5,  8,  0,  0 }, {     16,    8,    4,  8,  0,  0 },
    {     16,   10,    3,  8,  0,  0 }, {     16,   12,    2,  8,  0,  0 }, {     16,   14,    1,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 },
    {     16,   20,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938A0E, {
    {      0,   16,    8, 16,  0,  0 }, {      2,   16,    7, 16,  0,  0 }, {      4,   16,    6, 16,  0,  0 }, {      6,   16,    5, 16,  0,  0 }, {      8,   16,    4, 16,  0,  0 },
    {     10,   16,    3, 16,  0,  0 }, {     12,   16,    2, 16,  0,  0 }, {     14,   16,    1, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     18,   16,    0, 16,  0,  0 },
    {     20,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_938AA0, {
    {     16,   30,    8, 24,  0,  0 }, {     16,   28,    7, 24,  0,  0 }, {     16,   26,    6, 24,  0,  0 }, {     16,   24,    5, 24,  0,  0 }, {     16,   22,    4, 24,  0,  0 },
    {     16,   20,    3, 24,  0,  0 }, {     16,   18,    2, 24,  0,  0 }, {     16,   16,    1, 24,  0,  0 }, {     16,   14,    0, 24,  0,  0 }, {     16,   12,    0, 24,  0,  0 },
    {     16,   10,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 }, {     16,    6,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93920A, {
    {     30,   16,    0,  0,  0,  0 }, {     26,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 },
    {     18,   16,    0,  0,  0,  0 }, {     16,   16,    0,  0,  0,  0 }, {     16,   14,    0, 24,  0,  0 }, {     16,   12,    0, 24,  0,  0 }, {     16,   10,    0, 24,  0,  0 },
    {     16,    8,    0, 24,  0,  0 }, {     16,    6,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_939293, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     14,   16,    0,  0,  0,  0 },
    {     12,   16,    0,  0,  0,  0 }, {     10,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      6,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 },
    {      2,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93932E, {
    {      0,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     14,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     16,   18,    0,  8,  0,  0 },
    {     16,   20,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9393C0, {
    {     16,   30,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   26,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   20,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 }, {     16,   16,    0, 24,  0,  0 }, {     18,   16,    0, 16,  0,  0 }, {     20,   16,    0, 16,  0,  0 },
    {     22,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 }, {     30,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_939449, {
    {     30,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     26,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     20,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 }, {     16,   16,    0,  0,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 },
    {     16,   22,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9394D2, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     18,   16,    0, 16,  0,  0 },
    {     20,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_939564, {
    {      0,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     14,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     16,   14,    0, 24,  0,  0 },
    {     16,   12,    0, 24,  0,  0 }, {     16,   10,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 }, {     16,    6,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 },
    {     16,    2,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9395FF, {
    {     16,   30,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   26,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   20,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 }, {     16,   16,    0, 24,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 },
    {     10,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      6,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      0,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_939691, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     15,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 },
    {      5,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -3,   16,    0,  0,  0,  0 },
    {     -5,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, {    -11,   16,    0,  0,  0,  0 }, {    -13,   16,    0,  0,  0,  0 },
    {    -15,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {    -15,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    MINI_GOLF_STATE(Unk6),              {    -17,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -23,   16,    0,  0,  0,  0 },
    {    -25,   16,    0,  0,  0,  0 }, {    -27,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93C082, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     16,   34,    0,  8,  0,  0 },
    {     16,   36,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, {     16,   42,    0,  8,  0,  0 }, {     16,   44,    0,  8,  0,  0 },
    {     16,   46,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     16,   46,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    MINI_GOLF_STATE(Unk6),              {     16,   48,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   54,    0,  8,  0,  0 },
    {     16,   56,    0,  8,  0,  0 }, {     16,   58,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93EA73, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 }, {     14,   15,    0, 16,  0,  0 },
    {     16,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 }, {     20,   15,    0, 16,  0,  0 }, {     22,   15,    0, 16,  0,  0 }, {     24,   15,    0, 16,  0,  0 },
    {     26,   15,    0, 16,  0,  0 }, {     28,   15,    0, 16,  0,  0 }, {     30,   15,    0, 16,  0,  0 }, {     32,   15,    0, 16,  0,  0 }, {     34,   15,    0, 16,  0,  0 },
    {     36,   15,    0, 16,  0,  0 }, {     38,   15,    0, 16,  0,  0 }, {     40,   15,    0, 16,  0,  0 }, {     42,   15,    0, 16,  0,  0 }, {     44,   15,    0, 16,  0,  0 },
    {     46,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     46,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    MINI_GOLF_STATE(Unk6),              {     48,   15,    0, 16,  0,  0 }, {     50,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 }, {     54,   15,    0, 16,  0,  0 },
    {     56,   15,    0, 16,  0,  0 }, {     58,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_941464, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 }, {     15,   17,    0, 24,  0,  0 },
    {     15,   15,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 }, {     15,   11,    0, 24,  0,  0 }, {     15,    9,    0, 24,  0,  0 }, {     15,    7,    0, 24,  0,  0 },
    {     15,    5,    0, 24,  0,  0 }, {     15,    3,    0, 24,  0,  0 }, {     15,    1,    0, 24,  0,  0 }, {     15,   -1,    0, 24,  0,  0 }, {     15,   -3,    0, 24,  0,  0 },
    {     15,   -5,    0, 24,  0,  0 }, {     15,   -7,    0, 24,  0,  0 }, {     15,   -9,    0, 24,  0,  0 }, {     15,  -11,    0, 24,  0,  0 }, {     15,  -13,    0, 24,  0,  0 },
    {     15,  -15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     15,  -15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    MINI_GOLF_STATE(Unk6),              {     15,  -17,    0, 24,  0,  0 }, {     15,  -19,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 }, {     15,  -23,    0, 24,  0,  0 },
    {     15,  -25,    0, 24,  0,  0 }, {     15,  -27,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93A46E, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     15,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 },
    {      5,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -3,   16,    0,  0,  0,  0 },
    {     -5,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, {    -11,   16,    0,  0,  0,  0 }, {    -13,   16,    0,  0,  0,  0 },
    {    -15,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -23,   16,    0,  0,  0,  0 },
    {    -25,   16,    0,  0,  0,  0 }, {    -27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {    -27,   16,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -27,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93CE5F, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     16,   34,    0,  8,  0,  0 },
    {     16,   36,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, {     16,   42,    0,  8,  0,  0 }, {     16,   44,    0,  8,  0,  0 },
    {     16,   46,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   54,    0,  8,  0,  0 },
    {     16,   56,    0,  8,  0,  0 }, {     16,   58,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     16,   58,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     16,   58,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93F850, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 }, {     14,   15,    0, 16,  0,  0 },
    {     16,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 }, {     20,   15,    0, 16,  0,  0 }, {     22,   15,    0, 16,  0,  0 }, {     24,   15,    0, 16,  0,  0 },
    {     26,   15,    0, 16,  0,  0 }, {     28,   15,    0, 16,  0,  0 }, {     30,   15,    0, 16,  0,  0 }, {     32,   15,    0, 16,  0,  0 }, {     34,   15,    0, 16,  0,  0 },
    {     36,   15,    0, 16,  0,  0 }, {     38,   15,    0, 16,  0,  0 }, {     40,   15,    0, 16,  0,  0 }, {     42,   15,    0, 16,  0,  0 }, {     44,   15,    0, 16,  0,  0 },
    {     46,   15,    0, 16,  0,  0 }, {     48,   15,    0, 16,  0,  0 }, {     50,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 }, {     54,   15,    0, 16,  0,  0 },
    {     56,   15,    0, 16,  0,  0 }, {     58,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     58,   15,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     58,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_942241, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 }, {     15,   17,    0, 24,  0,  0 },
    {     15,   15,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 }, {     15,   11,    0, 24,  0,  0 }, {     15,    9,    0, 24,  0,  0 }, {     15,    7,    0, 24,  0,  0 },
    {     15,    5,    0, 24,  0,  0 }, {     15,    3,    0, 24,  0,  0 }, {     15,    1,    0, 24,  0,  0 }, {     15,   -1,    0, 24,  0,  0 }, {     15,   -3,    0, 24,  0,  0 },
    {     15,   -5,    0, 24,  0,  0 }, {     15,   -7,    0, 24,  0,  0 }, {     15,   -9,    0, 24,  0,  0 }, {     15,  -11,    0, 24,  0,  0 }, {     15,  -13,    0, 24,  0,  0 },
    {     15,  -15,    0, 24,  0,  0 }, {     15,  -17,    0, 24,  0,  0 }, {     15,  -19,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 }, {     15,  -23,    0, 24,  0,  0 },
    {     15,  -25,    0, 24,  0,  0 }, {     15,  -27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     15,  -27,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     15,  -27,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93B2AE, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     15,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {      9,   16,    5,  0,  0,  0 }, {      7,   16,    5,  0,  0,  0 },
    {      5,   16,    5,  0,  0,  0 }, {      3,   16,    5,  0,  0,  0 }, {      1,   16,    5,  0,  0,  0 }, {     -1,   16,    5,  0,  0,  0 }, {     -3,   16,    5,  0,  0,  0 },
    {     -5,   16,    5,  0,  0,  0 }, {     -7,   16,    5,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, {    -11,   16,    0,  0,  0,  0 }, {    -13,   16,    0,  0,  0,  0 },
    {    -15,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -23,   16,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {    -23,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),
    {    -23,   16,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 }, {    -27,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93DC9F, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   22,    5,  8,  0,  0 }, {     16,   24,    5,  8,  0,  0 },
    {     16,   26,    5,  8,  0,  0 }, {     16,   28,    5,  8,  0,  0 }, {     16,   30,    5,  8,  0,  0 }, {     16,   32,    5,  8,  0,  0 }, {     16,   34,    5,  8,  0,  0 },
    {     16,   36,    5,  8,  0,  0 }, {     16,   38,    5,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, {     16,   42,    0,  8,  0,  0 }, {     16,   44,    0,  8,  0,  0 },
    {     16,   46,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   54,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     16,   54,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),
    {     16,   54,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 }, {     16,   58,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_940690, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 }, {     14,   15,    0, 16,  0,  0 },
    {     16,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 }, {     20,   15,    0, 16,  0,  0 }, {     22,   15,    5, 16,  0,  0 }, {     24,   15,    5, 16,  0,  0 },
    {     26,   15,    5, 16,  0,  0 }, {     28,   15,    5, 16,  0,  0 }, {     30,   15,    5, 16,  0,  0 }, {     32,   15,    5, 16,  0,  0 }, {     34,   15,    5, 16,  0,  0 },
    {     36,   15,    5, 16,  0,  0 }, {     38,   15,    5, 16,  0,  0 }, {     40,   15,    0, 16,  0,  0 }, {     42,   15,    0, 16,  0,  0 }, {     44,   15,    0, 16,  0,  0 },
    {     46,   15,    0, 16,  0,  0 }, {     48,   15,    0, 16,  0,  0 }, {     50,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 }, {     54,   15,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     54,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),
    {     54,   15,    0, 16,  0,  0 }, {     56,   15,    0, 16,  0,  0 }, {     58,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_943081, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 }, {     15,   17,    0, 24,  0,  0 },
    {     15,   15,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 }, {     15,   11,    0, 24,  0,  0 }, {     15,    9,    5, 24,  0,  0 }, {     15,    7,    5, 24,  0,  0 },
    {     15,    5,    5, 24,  0,  0 }, {     15,    3,    5, 24,  0,  0 }, {     15,    1,    5, 24,  0,  0 }, {     15,   -1,    5, 24,  0,  0 }, {     15,   -3,    5, 24,  0,  0 },
    {     15,   -5,    5, 24,  0,  0 }, {     15,   -7,    5, 24,  0,  0 }, {     15,   -9,    0, 24,  0,  0 }, {     15,  -11,    0, 24,  0,  0 }, {     15,  -13,    0, 24,  0,  0 },
    {     15,  -15,    0, 24,  0,  0 }, {     15,  -17,    0, 24,  0,  0 }, {     15,  -19,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 }, {     15,  -23,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     15,  -23,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),
    {     15,  -23,    0, 24,  0,  0 }, {     15,  -25,    0, 24,  0,  0 }, {     15,  -27,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_943E56, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     15,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 },
    {      5,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -3,   16,    0,  0,  0,  0 },
    {     -3,   18,    0,  8,  0,  0 }, {     -3,   20,    0,  8,  0,  0 }, {     -3,   22,    0,  8,  0,  0 }, {     -3,   24,    0,  8,  0,  0 }, {     -3,   26,    0,  8,  0,  0 },
    {     -3,   28,    0,  8,  0,  0 }, {     -3,   30,    0,  8,  0,  0 }, {     -3,   32,    0,  8,  0,  0 }, {     -3,   34,    0,  8,  0,  0 }, {     -3,   36,    0,  8,  0,  0 },
    {     -3,   38,    0,  8,  0,  0 }, {     -3,   40,    0,  8,  0,  0 }, {     -3,   42,    0,  8,  0,  0 }, {     -3,   44,    0,  8,  0,  0 }, {     -3,   46,    0,  8,  0,  0 },
    {     -3,   48,    0,  8,  0,  0 }, {     -5,   48,    0,  0,  0,  0 }, {     -7,   48,    0,  0,  0,  0 }, {     -9,   48,    0,  0,  0,  0 }, {    -11,   48,    0,  0,  0,  0 },
    {    -13,   48,    0,  0,  0,  0 }, {    -15,   48,    0,  0,  0,  0 }, {    -17,   48,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {    -17,   49,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -17,   48,    0,  8,  0,  0 }, {    -17,   50,    0,  8,  0,  0 },
    {    -17,   52,    0,  8,  0,  0 }, {    -17,   54,    0,  8,  0,  0 }, {    -17,   56,    0,  8,  0,  0 }, {    -17,   58,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {    -17,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_946B14, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     16,   34,    0,  8,  0,  0 },
    {     18,   34,    0, 16,  0,  0 }, {     20,   34,    0, 16,  0,  0 }, {     22,   34,    0, 16,  0,  0 }, {     24,   34,    0, 16,  0,  0 }, {     26,   34,    0, 16,  0,  0 },
    {     28,   34,    0, 16,  0,  0 }, {     30,   34,    0, 16,  0,  0 }, {     32,   34,    0, 16,  0,  0 }, {     34,   34,    0, 16,  0,  0 }, {     36,   34,    0, 16,  0,  0 },
    {     38,   34,    0, 16,  0,  0 }, {     40,   34,    0, 16,  0,  0 }, {     42,   34,    0, 16,  0,  0 }, {     44,   34,    0, 16,  0,  0 }, {     46,   34,    0, 16,  0,  0 },
    {     48,   34,    0, 16,  0,  0 }, {     48,   36,    0,  8,  0,  0 }, {     48,   38,    0,  8,  0,  0 }, {     48,   40,    0,  8,  0,  0 }, {     48,   42,    0,  8,  0,  0 },
    {     48,   44,    0,  8,  0,  0 }, {     48,   46,    0,  8,  0,  0 }, {     48,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     49,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     48,   48,    0, 16,  0,  0 }, {     50,   48,    0, 16,  0,  0 },
    {     52,   48,    0, 16,  0,  0 }, {     54,   48,    0, 16,  0,  0 }, {     56,   48,    0, 16,  0,  0 }, {     58,   48,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {     60,   48,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9497D2, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 }, {     14,   15,    0, 16,  0,  0 },
    {     16,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 }, {     20,   15,    0, 16,  0,  0 }, {     22,   15,    0, 16,  0,  0 }, {     24,   15,    0, 16,  0,  0 },
    {     26,   15,    0, 16,  0,  0 }, {     28,   15,    0, 16,  0,  0 }, {     30,   15,    0, 16,  0,  0 }, {     32,   15,    0, 16,  0,  0 }, {     34,   15,    0, 16,  0,  0 },
    {     34,   13,    0, 24,  0,  0 }, {     34,   11,    0, 24,  0,  0 }, {     34,    9,    0, 24,  0,  0 }, {     34,    7,    0, 24,  0,  0 }, {     34,    5,    0, 24,  0,  0 },
    {     34,    3,    0, 24,  0,  0 }, {     34,    1,    0, 24,  0,  0 }, {     34,   -1,    0, 24,  0,  0 }, {     34,   -3,    0, 24,  0,  0 }, {     34,   -5,    0, 24,  0,  0 },
    {     34,   -7,    0, 24,  0,  0 }, {     34,   -9,    0, 24,  0,  0 }, {     34,  -11,    0, 24,  0,  0 }, {     34,  -13,    0, 24,  0,  0 }, {     34,  -15,    0, 24,  0,  0 },
    {     34,  -17,    0, 24,  0,  0 }, {     36,  -17,    0, 16,  0,  0 }, {     38,  -17,    0, 16,  0,  0 }, {     40,  -17,    0, 16,  0,  0 }, {     42,  -17,    0, 16,  0,  0 },
    {     44,  -17,    0, 16,  0,  0 }, {     46,  -17,    0, 16,  0,  0 }, {     48,  -17,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     48,  -18,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     48,  -17,    0, 24,  0,  0 }, {     48,  -19,    0, 24,  0,  0 },
    {     48,  -21,    0, 24,  0,  0 }, {     48,  -23,    0, 24,  0,  0 }, {     48,  -25,    0, 24,  0,  0 }, {     48,  -27,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {     48,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94C490, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 }, {     15,   17,    0, 24,  0,  0 },
    {     15,   15,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 }, {     15,   11,    0, 24,  0,  0 }, {     15,    9,    0, 24,  0,  0 }, {     15,    7,    0, 24,  0,  0 },
    {     15,    5,    0, 24,  0,  0 }, {     15,    3,    0, 24,  0,  0 }, {     15,    1,    0, 24,  0,  0 }, {     15,   -1,    0, 24,  0,  0 }, {     15,   -3,    0, 24,  0,  0 },
    {     13,   -3,    0,  0,  0,  0 }, {     11,   -3,    0,  0,  0,  0 }, {      9,   -3,    0,  0,  0,  0 }, {      7,   -3,    0,  0,  0,  0 }, {      5,   -3,    0,  0,  0,  0 },
    {      3,   -3,    0,  0,  0,  0 }, {      1,   -3,    0,  0,  0,  0 }, {     -1,   -3,    0,  0,  0,  0 }, {     -3,   -3,    0,  0,  0,  0 }, {     -5,   -3,    0,  0,  0,  0 },
    {     -7,   -3,    0,  0,  0,  0 }, {     -9,   -3,    0,  0,  0,  0 }, {    -11,   -3,    0,  0,  0,  0 }, {    -13,   -3,    0,  0,  0,  0 }, {    -15,   -3,    0,  0,  0,  0 },
    {    -17,   -3,    0,  0,  0,  0 }, {    -17,   -5,    0, 24,  0,  0 }, {    -17,   -7,    0, 24,  0,  0 }, {    -17,   -9,    0, 24,  0,  0 }, {    -17,  -11,    0, 24,  0,  0 },
    {    -17,  -13,    0, 24,  0,  0 }, {    -17,  -15,    0, 24,  0,  0 }, {    -17,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {    -18,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -17,  -17,    0,  0,  0,  0 }, {    -19,  -17,    0,  0,  0,  0 },
    {    -21,  -17,    0,  0,  0,  0 }, {    -23,  -17,    0,  0,  0,  0 }, {    -25,  -17,    0,  0,  0,  0 }, {    -27,  -17,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {    -29,  -17,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9454B5, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     15,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 },
    {      5,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -3,   16,    0,  0,  0,  0 },
    {     -3,   14,    0, 24,  0,  0 }, {     -3,   12,    0, 24,  0,  0 }, {     -3,   10,    0, 24,  0,  0 }, {     -3,    8,    0, 24,  0,  0 }, {     -3,    6,    0, 24,  0,  0 },
    {     -3,    4,    0, 24,  0,  0 }, {     -3,    2,    0, 24,  0,  0 }, {     -3,    0,    0, 24,  0,  0 }, {     -3,   -2,    0, 24,  0,  0 }, {     -3,   -4,    0, 24,  0,  0 },
    {     -3,   -6,    0, 24,  0,  0 }, {     -3,   -8,    0, 24,  0,  0 }, {     -3,  -10,    0, 24,  0,  0 }, {     -3,  -12,    0, 24,  0,  0 }, {     -3,  -14,    0, 24,  0,  0 },
    {     -3,  -16,    0, 24,  0,  0 }, {     -5,  -16,    0,  0,  0,  0 }, {     -7,  -16,    0,  0,  0,  0 }, {     -9,  -16,    0,  0,  0,  0 }, {    -11,  -16,    0,  0,  0,  0 },
    {    -13,  -16,    0,  0,  0,  0 }, {    -15,  -16,    0,  0,  0,  0 }, {    -17,  -16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {    -17,  -17,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -17,  -16,    0, 24,  0,  0 }, {    -17,  -18,    0, 24,  0,  0 },
    {    -17,  -20,    0, 24,  0,  0 }, {    -17,  -22,    0, 24,  0,  0 }, {    -17,  -24,    0, 24,  0,  0 }, {    -17,  -26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {    -17,  -28,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_948173, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     16,   34,    0,  8,  0,  0 },
    {     14,   34,    0,  0,  0,  0 }, {     12,   34,    0,  0,  0,  0 }, {     10,   34,    0,  0,  0,  0 }, {      8,   34,    0,  0,  0,  0 }, {      6,   34,    0,  0,  0,  0 },
    {      4,   34,    0,  0,  0,  0 }, {      2,   34,    0,  0,  0,  0 }, {      0,   34,    0,  0,  0,  0 }, {     -2,   34,    0,  0,  0,  0 }, {     -4,   34,    0,  0,  0,  0 },
    {     -6,   34,    0,  0,  0,  0 }, {     -8,   34,    0,  0,  0,  0 }, {    -10,   34,    0,  0,  0,  0 }, {    -12,   34,    0,  0,  0,  0 }, {    -14,   34,    0,  0,  0,  0 },
    {    -16,   34,    0,  0,  0,  0 }, {    -16,   36,    0,  8,  0,  0 }, {    -16,   38,    0,  8,  0,  0 }, {    -16,   40,    0,  8,  0,  0 }, {    -16,   42,    0,  8,  0,  0 },
    {    -16,   44,    0,  8,  0,  0 }, {    -16,   46,    0,  8,  0,  0 }, {    -16,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {    -17,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -16,   48,    0,  0,  0,  0 }, {    -18,   48,    0,  0,  0,  0 },
    {    -20,   48,    0,  0,  0,  0 }, {    -22,   48,    0,  0,  0,  0 }, {    -24,   48,    0,  0,  0,  0 }, {    -26,   48,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {    -28,   48,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94AE31, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 }, {     14,   15,    0, 16,  0,  0 },
    {     16,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 }, {     20,   15,    0, 16,  0,  0 }, {     22,   15,    0, 16,  0,  0 }, {     24,   15,    0, 16,  0,  0 },
    {     26,   15,    0, 16,  0,  0 }, {     28,   15,    0, 16,  0,  0 }, {     30,   15,    0, 16,  0,  0 }, {     32,   15,    0, 16,  0,  0 }, {     34,   15,    0, 16,  0,  0 },
    {     34,   17,    0,  8,  0,  0 }, {     34,   19,    0,  8,  0,  0 }, {     34,   21,    0,  8,  0,  0 }, {     34,   23,    0,  8,  0,  0 }, {     34,   25,    0,  8,  0,  0 },
    {     34,   27,    0,  8,  0,  0 }, {     34,   29,    0,  8,  0,  0 }, {     34,   31,    0,  8,  0,  0 }, {     34,   33,    0,  8,  0,  0 }, {     34,   35,    0,  8,  0,  0 },
    {     34,   37,    0,  8,  0,  0 }, {     34,   39,    0,  8,  0,  0 }, {     34,   41,    0,  8,  0,  0 }, {     34,   43,    0,  8,  0,  0 }, {     34,   45,    0,  8,  0,  0 },
    {     34,   47,    0,  8,  0,  0 }, {     36,   47,    0, 16,  0,  0 }, {     38,   47,    0, 16,  0,  0 }, {     40,   47,    0, 16,  0,  0 }, {     42,   47,    0, 16,  0,  0 },
    {     44,   47,    0, 16,  0,  0 }, {     46,   47,    0, 16,  0,  0 }, {     48,   47,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     48,   48,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     48,   47,    0,  8,  0,  0 }, {     48,   49,    0,  8,  0,  0 },
    {     48,   51,    0,  8,  0,  0 }, {     48,   53,    0,  8,  0,  0 }, {     48,   55,    0,  8,  0,  0 }, {     48,   57,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {     48,   59,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94DAEF, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(Jump),          MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 }, {     15,   17,    0, 24,  0,  0 },
    {     15,   15,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 }, {     15,   11,    0, 24,  0,  0 }, {     15,    9,    0, 24,  0,  0 }, {     15,    7,    0, 24,  0,  0 },
    {     15,    5,    0, 24,  0,  0 }, {     15,    3,    0, 24,  0,  0 }, {     15,    1,    0, 24,  0,  0 }, {     15,   -1,    0, 24,  0,  0 }, {     15,   -3,    0, 24,  0,  0 },
    {     17,   -3,    0, 16,  0,  0 }, {     19,   -3,    0, 16,  0,  0 }, {     21,   -3,    0, 16,  0,  0 }, {     23,   -3,    0, 16,  0,  0 }, {     25,   -3,    0, 16,  0,  0 },
    {     27,   -3,    0, 16,  0,  0 }, {     29,   -3,    0, 16,  0,  0 }, {     31,   -3,    0, 16,  0,  0 }, {     33,   -3,    0, 16,  0,  0 }, {     35,   -3,    0, 16,  0,  0 },
    {     37,   -3,    0, 16,  0,  0 }, {     39,   -3,    0, 16,  0,  0 }, {     41,   -3,    0, 16,  0,  0 }, {     43,   -3,    0, 16,  0,  0 }, {     45,   -3,    0, 16,  0,  0 },
    {     47,   -3,    0, 16,  0,  0 }, {     47,   -5,    0, 24,  0,  0 }, {     47,   -7,    0, 24,  0,  0 }, {     47,   -9,    0, 24,  0,  0 }, {     47,  -11,    0, 24,  0,  0 },
    {     47,  -13,    0, 24,  0,  0 }, {     47,  -15,    0, 24,  0,  0 }, {     47,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     48,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     47,  -17,    0, 16,  0,  0 }, {     49,  -17,    0, 16,  0,  0 },
    {     51,  -17,    0, 16,  0,  0 }, {     53,  -17,    0, 16,  0,  0 }, {     55,  -17,    0, 16,  0,  0 }, {     57,  -17,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {     59,  -17,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9398A6, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     25,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 },
    {     16,   16,    0,  0,  0,  0 }, {     13,   17,    0,  0,  0,  0 }, {     10,   17,    0,  0,  0,  0 }, {      8,   17,    0,  0,  0,  0 }, {      6,   17,    0,  0,  0,  0 },
    {      4,   17,    0,  0,  0,  0 }, {      2,   17,    0,  0,  0,  0 }, {      0,   18,    0,  0,  0,  0 }, {     -2,   18,    0,  0,  0,  0 }, {     -4,   18,    0,  0,  0,  0 },
    {     -6,   18,    0,  0,  0,  0 }, {     -8,   18,    0,  0,  0,  0 }, {    -10,   18,    0,  0,  0,  0 }, {    -12,   18,    0,  0,  0,  0 }, {    -14,   19,    0,  0,  0,  0 },
    {    -16,   19,    0,  0,  0,  0 }, {    -18,   19,    0,  0,  0,  0 }, {    -20,   19,    0,  0,  0,  0 }, {    -22,   19,    0,  0,  0,  0 }, {    -24,   19,    0,  0,  0,  0 },
    {    -26,   19,    0,  0,  0,  0 }, {    -28,   20,    0,  0,  0,  0 }, {    -30,   20,    0,  0,  0,  0 }, {    -29,   20,    0,  0,  0,  0 }, {    -28,   20,    0,  0,  0,  0 },
    {    -27,   20,    0,  0,  0,  0 }, {    -26,   19,    0,  0,  0,  0 }, {    -25,   19,    0,  0,  0,  0 }, {    -24,   19,    0,  0,  0,  0 }, {    -23,   18,    0,  0,  0,  0 },
    {    -22,   18,    0,  0,  0,  0 }, {    -21,   18,    0,  0,  0,  0 }, {    -20,   17,    0,  0,  0,  0 }, {    -19,   17,    0,  0,  0,  0 }, {    -18,   17,    0,  0,  0,  0 },
    {    -17,   16,    0,  0,  0,  0 }, {    -16,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {    -29,   16,    0,  0,  0,  0 },
    MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93C297, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    6,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 },
    {     16,   15,    0,  8,  0,  0 }, {     17,   18,    0,  8,  0,  0 }, {     17,   21,    0,  8,  0,  0 }, {     17,   23,    0,  8,  0,  0 }, {     17,   25,    0,  8,  0,  0 },
    {     17,   27,    0,  8,  0,  0 }, {     17,   29,    0,  8,  0,  0 }, {     18,   31,    0,  8,  0,  0 }, {     18,   33,    0,  8,  0,  0 }, {     18,   35,    0,  8,  0,  0 },
    {     18,   37,    0,  8,  0,  0 }, {     18,   39,    0,  8,  0,  0 }, {     18,   41,    0,  8,  0,  0 }, {     18,   43,    0,  8,  0,  0 }, {     19,   45,    0,  8,  0,  0 },
    {     19,   47,    0,  8,  0,  0 }, {     19,   49,    0,  8,  0,  0 }, {     19,   51,    0,  8,  0,  0 }, {     19,   53,    0,  8,  0,  0 }, {     19,   55,    0,  8,  0,  0 },
    {     19,   57,    0,  8,  0,  0 }, {     20,   59,    0,  8,  0,  0 }, {     20,   61,    0,  8,  0,  0 }, {     20,   60,    0,  8,  0,  0 }, {     20,   59,    0,  8,  0,  0 },
    {     20,   58,    0,  8,  0,  0 }, {     19,   57,    0,  8,  0,  0 }, {     19,   56,    0,  8,  0,  0 }, {     19,   55,    0,  8,  0,  0 }, {     18,   54,    0,  8,  0,  0 },
    {     18,   53,    0,  8,  0,  0 }, {     18,   52,    0,  8,  0,  0 }, {     17,   51,    0,  8,  0,  0 }, {     17,   50,    0,  8,  0,  0 }, {     17,   49,    0,  8,  0,  0 },
    {     16,   48,    0,  8,  0,  0 }, {     16,   47,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     16,   60,    0,  8,  0,  0 },
    MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93EC88, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      6,   15,    0, 16,  0,  0 }, {      9,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 },
    {     15,   15,    0, 16,  0,  0 }, {     18,   14,    0, 16,  0,  0 }, {     21,   14,    0, 16,  0,  0 }, {     23,   14,    0, 16,  0,  0 }, {     25,   14,    0, 16,  0,  0 },
    {     27,   14,    0, 16,  0,  0 }, {     29,   14,    0, 16,  0,  0 }, {     31,   13,    0, 16,  0,  0 }, {     33,   13,    0, 16,  0,  0 }, {     35,   13,    0, 16,  0,  0 },
    {     37,   13,    0, 16,  0,  0 }, {     39,   13,    0, 16,  0,  0 }, {     41,   13,    0, 16,  0,  0 }, {     43,   13,    0, 16,  0,  0 }, {     45,   12,    0, 16,  0,  0 },
    {     47,   12,    0, 16,  0,  0 }, {     49,   12,    0, 16,  0,  0 }, {     51,   12,    0, 16,  0,  0 }, {     53,   12,    0, 16,  0,  0 }, {     55,   12,    0, 16,  0,  0 },
    {     57,   12,    0, 16,  0,  0 }, {     59,   11,    0, 16,  0,  0 }, {     61,   11,    0, 16,  0,  0 }, {     60,   11,    0, 16,  0,  0 }, {     59,   11,    0, 16,  0,  0 },
    {     58,   11,    0, 16,  0,  0 }, {     57,   12,    0, 16,  0,  0 }, {     56,   12,    0, 16,  0,  0 }, {     55,   12,    0, 16,  0,  0 }, {     54,   13,    0, 16,  0,  0 },
    {     53,   13,    0, 16,  0,  0 }, {     52,   13,    0, 16,  0,  0 }, {     51,   14,    0, 16,  0,  0 }, {     50,   14,    0, 16,  0,  0 }, {     49,   14,    0, 16,  0,  0 },
    {     48,   15,    0, 16,  0,  0 }, {     47,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     60,   15,    0, 16,  0,  0 },
    MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_941679, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   25,    0, 24,  0,  0 }, {     15,   22,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 },
    {     15,   16,    0, 24,  0,  0 }, {     14,   13,    0, 24,  0,  0 }, {     14,   10,    0, 24,  0,  0 }, {     14,    8,    0, 24,  0,  0 }, {     14,    6,    0, 24,  0,  0 },
    {     14,    4,    0, 24,  0,  0 }, {     14,    2,    0, 24,  0,  0 }, {     13,    0,    0, 24,  0,  0 }, {     13,   -2,    0, 24,  0,  0 }, {     13,   -4,    0, 24,  0,  0 },
    {     13,   -6,    0, 24,  0,  0 }, {     13,   -8,    0, 24,  0,  0 }, {     13,  -10,    0, 24,  0,  0 }, {     13,  -12,    0, 24,  0,  0 }, {     12,  -14,    0, 24,  0,  0 },
    {     12,  -16,    0, 24,  0,  0 }, {     12,  -18,    0, 24,  0,  0 }, {     12,  -20,    0, 24,  0,  0 }, {     12,  -22,    0, 24,  0,  0 }, {     12,  -24,    0, 24,  0,  0 },
    {     12,  -26,    0, 24,  0,  0 }, {     11,  -28,    0, 24,  0,  0 }, {     11,  -30,    0, 24,  0,  0 }, {     11,  -29,    0, 24,  0,  0 }, {     11,  -28,    0, 24,  0,  0 },
    {     11,  -27,    0, 24,  0,  0 }, {     12,  -26,    0, 24,  0,  0 }, {     12,  -25,    0, 24,  0,  0 }, {     12,  -24,    0, 24,  0,  0 }, {     13,  -23,    0, 24,  0,  0 },
    {     13,  -22,    0, 24,  0,  0 }, {     13,  -21,    0, 24,  0,  0 }, {     14,  -20,    0, 24,  0,  0 }, {     14,  -19,    0, 24,  0,  0 }, {     14,  -18,    0, 24,  0,  0 },
    {     15,  -17,    0, 24,  0,  0 }, {     15,  -16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     15,  -29,    0, 24,  0,  0 },
    MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93A68C, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     25,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 }, {     19,   15,    0,  0,  0,  0 },
    {     16,   15,    0,  0,  0,  0 }, {     13,   14,    0,  0,  0,  0 }, {     10,   14,    0,  0,  0,  0 }, {      7,   13,    0,  0,  0,  0 }, {      4,   13,    0,  0,  0,  0 },
    {      1,   12,    0,  0,  0,  0 }, {     -2,   12,    0,  0,  0,  0 }, {     -2,   15,    0,  0,  0,  0 }, {     -2,   18,    0,  0,  0,  0 }, {     -2,   21,    0,  0,  0,  0 },
    {     -2,   24,    0,  0,  0,  0 }, {     -2,   26,    0,  0,  0,  0 }, {     -4,   26,    0,  0,  0,  0 }, {     -6,   26,    0,  0,  0,  0 }, {     -8,   26,    0,  0,  0,  0 },
    {    -10,   26,    0,  0,  0,  0 }, {    -11,   25,    0,  0,  0,  0 }, {    -11,   23,    0,  0,  0,  0 }, {    -11,   21,    0,  0,  0,  0 }, {    -11,   19,    0,  0,  0,  0 },
    {    -10,   17,    0,  0,  0,  0 }, {    -10,   15,    0,  0,  0,  0 }, {    -10,   13,    0,  0,  0,  0 }, {    -12,   13,    0,  0,  0,  0 }, {    -14,   13,    0,  0,  0,  0 },
    {    -16,   13,    0,  0,  0,  0 }, {    -18,   13,    0,  0,  0,  0 }, {    -20,   14,    0,  0,  0,  0 }, {    -22,   14,    0,  0,  0,  0 }, {    -23,   14,    0,  0,  0,  0 },
    {    -24,   14,    0,  0,  0,  0 }, {    -25,   14,    0,  0,  0,  0 }, {    -26,   14,    0,  0,  0,  0 }, {    -27,   14,    0,  0,  0,  0 }, {    -28,   14,    0,  0,  0,  0 },
    {    -29,   14,    0,  0,  0,  0 }, {    -30,   14,    0,  0,  0,  0 }, {    -31,   14,    0,  0,  0,  0 }, {    -30,   14,    0,  0,  0,  0 }, {    -29,   14,    0,  0,  0,  0 },
    {    -28,   15,    0,  0,  0,  0 }, {    -27,   15,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {    -29,   16,    0,  0,  0,  0 },
    MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93D07D, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    6,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 }, {     15,   12,    0,  8,  0,  0 },
    {     15,   15,    0,  8,  0,  0 }, {     14,   18,    0,  8,  0,  0 }, {     14,   21,    0,  8,  0,  0 }, {     13,   24,    0,  8,  0,  0 }, {     13,   27,    0,  8,  0,  0 },
    {     12,   30,    0,  8,  0,  0 }, {     12,   33,    0,  8,  0,  0 }, {     15,   33,    0,  8,  0,  0 }, {     18,   33,    0,  8,  0,  0 }, {     21,   33,    0,  8,  0,  0 },
    {     24,   33,    0,  8,  0,  0 }, {     26,   33,    0,  8,  0,  0 }, {     26,   35,    0,  8,  0,  0 }, {     26,   37,    0,  8,  0,  0 }, {     26,   39,    0,  8,  0,  0 },
    {     26,   41,    0,  8,  0,  0 }, {     25,   42,    0,  8,  0,  0 }, {     23,   42,    0,  8,  0,  0 }, {     21,   42,    0,  8,  0,  0 }, {     19,   42,    0,  8,  0,  0 },
    {     17,   41,    0,  8,  0,  0 }, {     15,   41,    0,  8,  0,  0 }, {     13,   41,    0,  8,  0,  0 }, {     13,   43,    0,  8,  0,  0 }, {     13,   45,    0,  8,  0,  0 },
    {     13,   47,    0,  8,  0,  0 }, {     13,   49,    0,  8,  0,  0 }, {     14,   51,    0,  8,  0,  0 }, {     14,   53,    0,  8,  0,  0 }, {     14,   54,    0,  8,  0,  0 },
    {     14,   55,    0,  8,  0,  0 }, {     14,   56,    0,  8,  0,  0 }, {     14,   57,    0,  8,  0,  0 }, {     14,   58,    0,  8,  0,  0 }, {     14,   59,    0,  8,  0,  0 },
    {     14,   60,    0,  8,  0,  0 }, {     14,   61,    0,  8,  0,  0 }, {     14,   62,    0,  8,  0,  0 }, {     14,   61,    0,  8,  0,  0 }, {     14,   60,    0,  8,  0,  0 },
    {     15,   59,    0,  8,  0,  0 }, {     15,   58,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     16,   60,    0,  8,  0,  0 },
    MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93FA6E, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      6,   15,    0, 16,  0,  0 }, {      9,   15,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 },
    {     15,   16,    0, 16,  0,  0 }, {     18,   17,    0, 16,  0,  0 }, {     21,   17,    0, 16,  0,  0 }, {     24,   18,    0, 16,  0,  0 }, {     27,   18,    0, 16,  0,  0 },
    {     30,   19,    0, 16,  0,  0 }, {     33,   19,    0, 16,  0,  0 }, {     33,   16,    0, 16,  0,  0 }, {     33,   13,    0, 16,  0,  0 }, {     33,   10,    0, 16,  0,  0 },
    {     33,    7,    0, 16,  0,  0 }, {     33,    5,    0, 16,  0,  0 }, {     35,    5,    0, 16,  0,  0 }, {     37,    5,    0, 16,  0,  0 }, {     39,    5,    0, 16,  0,  0 },
    {     41,    5,    0, 16,  0,  0 }, {     42,    6,    0, 16,  0,  0 }, {     42,    8,    0, 16,  0,  0 }, {     42,   10,    0, 16,  0,  0 }, {     42,   12,    0, 16,  0,  0 },
    {     41,   14,    0, 16,  0,  0 }, {     41,   16,    0, 16,  0,  0 }, {     41,   18,    0, 16,  0,  0 }, {     43,   18,    0, 16,  0,  0 }, {     45,   18,    0, 16,  0,  0 },
    {     47,   18,    0, 16,  0,  0 }, {     49,   18,    0, 16,  0,  0 }, {     51,   17,    0, 16,  0,  0 }, {     53,   17,    0, 16,  0,  0 }, {     54,   17,    0, 16,  0,  0 },
    {     55,   17,    0, 16,  0,  0 }, {     56,   17,    0, 16,  0,  0 }, {     57,   17,    0, 16,  0,  0 }, {     58,   17,    0, 16,  0,  0 }, {     59,   17,    0, 16,  0,  0 },
    {     60,   17,    0, 16,  0,  0 }, {     61,   17,    0, 16,  0,  0 }, {     62,   17,    0, 16,  0,  0 }, {     61,   17,    0, 16,  0,  0 }, {     60,   17,    0, 16,  0,  0 },
    {     59,   16,    0, 16,  0,  0 }, {     58,   16,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     60,   15,    0, 16,  0,  0 },
    MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94245F, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   25,    0, 24,  0,  0 }, {     15,   22,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 },
    {     16,   16,    0, 24,  0,  0 }, {     17,   13,    0, 24,  0,  0 }, {     17,   10,    0, 24,  0,  0 }, {     18,    7,    0, 24,  0,  0 }, {     18,    4,    0, 24,  0,  0 },
    {     19,    1,    0, 24,  0,  0 }, {     19,   -2,    0, 24,  0,  0 }, {     16,   -2,    0, 24,  0,  0 }, {     13,   -2,    0, 24,  0,  0 }, {     10,   -2,    0, 24,  0,  0 },
    {      7,   -2,    0, 24,  0,  0 }, {      5,   -2,    0, 24,  0,  0 }, {      5,   -4,    0, 24,  0,  0 }, {      5,   -6,    0, 24,  0,  0 }, {      5,   -8,    0, 24,  0,  0 },
    {      5,  -10,    0, 24,  0,  0 }, {      6,  -11,    0, 24,  0,  0 }, {      8,  -11,    0, 24,  0,  0 }, {     10,  -11,    0, 24,  0,  0 }, {     12,  -11,    0, 24,  0,  0 },
    {     14,  -10,    0, 24,  0,  0 }, {     16,  -10,    0, 24,  0,  0 }, {     18,  -10,    0, 24,  0,  0 }, {     18,  -12,    0, 24,  0,  0 }, {     18,  -14,    0, 24,  0,  0 },
    {     18,  -16,    0, 24,  0,  0 }, {     18,  -18,    0, 24,  0,  0 }, {     17,  -20,    0, 24,  0,  0 }, {     17,  -22,    0, 24,  0,  0 }, {     17,  -23,    0, 24,  0,  0 },
    {     17,  -24,    0, 24,  0,  0 }, {     17,  -25,    0, 24,  0,  0 }, {     17,  -26,    0, 24,  0,  0 }, {     17,  -27,    0, 24,  0,  0 }, {     17,  -28,    0, 24,  0,  0 },
    {     17,  -29,    0, 24,  0,  0 }, {     17,  -30,    0, 24,  0,  0 }, {     17,  -31,    0, 24,  0,  0 }, {     17,  -30,    0, 24,  0,  0 }, {     17,  -29,    0, 24,  0,  0 },
    {     16,  -28,    0, 24,  0,  0 }, {     16,  -27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     15,  -29,    0, 24,  0,  0 },
    MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93B4CC, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     24,   16,    0,  0,  0,  0 }, {     21,   17,    0,  0,  0,  0 }, {     18,   18,    0,  0,  0,  0 },
    {     15,   19,    0,  0,  0,  0 }, {     12,   19,    0,  0,  0,  0 }, {     10,   20,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {      7,   20,    0,  0,  0,  0 },
    {      5,   19,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {     -1,   17,    0,  0,  0,  0 }, {     -3,   16,    0,  0,  0,  0 },
    {     -5,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     -8,   16,    0,  0,  0,  0 }, {    -10,   16,    0,  0,  0,  0 },
    {    -12,   16,    0,  0,  0,  0 }, {    -14,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, {    -16,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 },
    {    -18,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 }, {    -20,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -22,   16,    0,  0,  0,  0 },
    {    -23,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {    -29,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93DEBD, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    7,    0,  8,  0,  0 }, {     17,   10,    0,  8,  0,  0 }, {     18,   13,    0,  8,  0,  0 },
    {     19,   16,    0,  8,  0,  0 }, {     19,   19,    0,  8,  0,  0 }, {     20,   21,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     20,   24,    0,  8,  0,  0 },
    {     19,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, {     17,   32,    0,  8,  0,  0 }, {     16,   34,    0,  8,  0,  0 },
    {     16,   36,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     16,   39,    0,  8,  0,  0 }, {     16,   41,    0,  8,  0,  0 },
    {     16,   43,    0,  8,  0,  0 }, {     16,   45,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, {     16,   47,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 },
    {     16,   49,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 }, {     16,   51,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   53,    0,  8,  0,  0 },
    {     16,   54,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     16,   60,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9408AE, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      7,   15,    0, 16,  0,  0 }, {     10,   14,    0, 16,  0,  0 }, {     13,   13,    0, 16,  0,  0 },
    {     16,   12,    0, 16,  0,  0 }, {     19,   12,    0, 16,  0,  0 }, {     21,   11,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     24,   11,    0, 16,  0,  0 },
    {     26,   12,    0, 16,  0,  0 }, {     28,   15,    0, 16,  0,  0 }, {     30,   15,    0, 16,  0,  0 }, {     32,   14,    0, 16,  0,  0 }, {     34,   15,    0, 16,  0,  0 },
    {     36,   15,    0, 16,  0,  0 }, {     38,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     39,   15,    0, 16,  0,  0 }, {     41,   15,    0, 16,  0,  0 },
    {     43,   15,    0, 16,  0,  0 }, {     45,   15,    0, 16,  0,  0 }, {     46,   15,    0, 16,  0,  0 }, {     47,   15,    0, 16,  0,  0 }, {     48,   15,    0, 16,  0,  0 },
    {     49,   15,    0, 16,  0,  0 }, {     50,   15,    0, 16,  0,  0 }, {     51,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 }, {     53,   15,    0, 16,  0,  0 },
    {     54,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     60,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94329F, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   24,    0, 24,  0,  0 }, {     14,   21,    0, 24,  0,  0 }, {     13,   18,    0, 24,  0,  0 },
    {     12,   15,    0, 24,  0,  0 }, {     12,   12,    0, 24,  0,  0 }, {     11,   10,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     11,    7,    0, 24,  0,  0 },
    {     12,    5,    0, 24,  0,  0 }, {     15,    3,    0, 24,  0,  0 }, {     15,    1,    0, 24,  0,  0 }, {     14,   -1,    0, 24,  0,  0 }, {     15,   -3,    0, 24,  0,  0 },
    {     15,   -5,    0, 24,  0,  0 }, {     15,   -7,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     15,   -8,    0, 24,  0,  0 }, {     15,  -10,    0, 24,  0,  0 },
    {     15,  -12,    0, 24,  0,  0 }, {     15,  -14,    0, 24,  0,  0 }, {     15,  -15,    0, 24,  0,  0 }, {     15,  -16,    0, 24,  0,  0 }, {     15,  -17,    0, 24,  0,  0 },
    {     15,  -18,    0, 24,  0,  0 }, {     15,  -19,    0, 24,  0,  0 }, {     15,  -20,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 }, {     15,  -22,    0, 24,  0,  0 },
    {     15,  -23,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     15,  -29,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_944104, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     24,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 },
    {     15,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      6,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 },
    {      0,   16,    0,  0,  0,  0 }, {     -3,   16,    0,  0,  0,  0 }, {     -6,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -12,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {    -18,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 },
    {    -24,   16,    0,  0,  0,  0 }, {    -25,   15,    0,  0,  0,  0 }, {    -26,   13,    0,  0,  0,  0 }, {    -27,   11,    0,  0,  0,  0 }, {    -28,    9,    0,  0,  0,  0 },
    {    -26,    7,    0,  0,  0,  0 }, {    -24,    5,    1,  0,  0,  0 }, {    -22,    3,    1,  0,  0,  0 }, {    -20,    2,    1,  0,  0,  0 }, {    -18,    2,    1,  0,  0,  0 },
    {    -16,    3,    2,  0,  0,  0 }, {    -14,    3,    2,  0,  0,  0 }, {    -14,    5,    2,  0,  0,  0 }, {    -13,    7,    2,  0,  0,  0 }, {    -12,    9,    3,  0,  0,  0 },
    {    -12,   11,    3,  0,  0,  0 }, {    -11,   13,    3,  0,  0,  0 }, {    -12,   15,    3,  0,  0,  0 }, {    -12,   17,    3,  0,  0,  0 }, {    -12,   19,    3,  0,  0,  0 },
    {    -13,   21,    3,  0,  0,  0 }, {    -13,   23,    3,  0,  0,  0 }, {    -13,   25,    3,  0,  0,  0 }, {    -14,   27,    3,  0,  0,  0 }, {    -14,   29,    3,  0,  0,  0 },
    {    -14,   30,    3,  0,  0,  0 }, {    -14,   31,    3,  0,  0,  0 }, {    -15,   32,    3,  0,  0,  0 }, {    -15,   33,    3,  0,  0,  0 }, {    -15,   34,    3,  0,  0,  0 },
    {    -15,   35,    3,  0,  0,  0 }, {    -15,   36,    3,  0,  0,  0 }, {    -15,   38,    0,  0,  0,  0 }, {    -16,   40,    0,  0,  0,  0 }, {    -16,   41,    0,  0,  0,  0 },
    {    -16,   42,    0,  0,  0,  0 }, {    -16,   43,    0,  0,  0,  0 }, {    -16,   44,    0,  0,  0,  0 }, {    -16,   45,    0,  0,  0,  0 }, {    -17,   46,    0,  0,  0,  0 },
    {    -17,   47,    0,  0,  0,  0 }, {    -17,   48,    0,  0,  0,  0 }, {    -17,   49,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {    -17,   60,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {    -17,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_946DC2, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    7,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 },
    {     16,   16,    0,  8,  0,  0 }, {     16,   19,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   25,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 },
    {     16,   31,    0,  8,  0,  0 }, {     16,   34,    0,  8,  0,  0 }, {     16,   37,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     16,   43,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     16,   49,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 },
    {     16,   55,    0,  8,  0,  0 }, {     15,   56,    0,  8,  0,  0 }, {     13,   57,    0,  8,  0,  0 }, {     11,   58,    0,  8,  0,  0 }, {      9,   59,    0,  8,  0,  0 },
    {      7,   57,    0,  8,  0,  0 }, {      5,   55,    1,  8,  0,  0 }, {      3,   53,    1,  8,  0,  0 }, {      2,   51,    1,  8,  0,  0 }, {      2,   49,    1,  8,  0,  0 },
    {      3,   47,    2,  8,  0,  0 }, {      3,   45,    2,  8,  0,  0 }, {      5,   45,    2,  8,  0,  0 }, {      7,   44,    2,  8,  0,  0 }, {      9,   43,    3,  8,  0,  0 },
    {     11,   43,    3,  8,  0,  0 }, {     13,   42,    3,  8,  0,  0 }, {     15,   43,    3,  8,  0,  0 }, {     17,   43,    3,  8,  0,  0 }, {     19,   43,    3,  8,  0,  0 },
    {     21,   44,    3,  8,  0,  0 }, {     23,   44,    3,  8,  0,  0 }, {     25,   44,    3,  8,  0,  0 }, {     27,   45,    3,  8,  0,  0 }, {     29,   45,    3,  8,  0,  0 },
    {     30,   45,    3,  8,  0,  0 }, {     31,   45,    3,  8,  0,  0 }, {     32,   46,    3,  8,  0,  0 }, {     33,   46,    3,  8,  0,  0 }, {     34,   46,    3,  8,  0,  0 },
    {     35,   46,    3,  8,  0,  0 }, {     36,   46,    3,  8,  0,  0 }, {     38,   46,    0,  8,  0,  0 }, {     40,   47,    0,  8,  0,  0 }, {     41,   47,    0,  8,  0,  0 },
    {     42,   47,    0,  8,  0,  0 }, {     43,   47,    0,  8,  0,  0 }, {     44,   47,    0,  8,  0,  0 }, {     45,   47,    0,  8,  0,  0 }, {     46,   48,    0,  8,  0,  0 },
    {     47,   48,    0,  8,  0,  0 }, {     48,   48,    0,  8,  0,  0 }, {     49,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {     60,   48,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     60,   48,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_949A80, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      7,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     13,   15,    0, 16,  0,  0 },
    {     16,   15,    0, 16,  0,  0 }, {     19,   15,    0, 16,  0,  0 }, {     22,   15,    0, 16,  0,  0 }, {     25,   15,    0, 16,  0,  0 }, {     28,   15,    0, 16,  0,  0 },
    {     31,   15,    0, 16,  0,  0 }, {     34,   15,    0, 16,  0,  0 }, {     37,   15,    0, 16,  0,  0 }, {     40,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     43,   15,    0, 16,  0,  0 }, {     46,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     49,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 },
    {     55,   15,    0, 16,  0,  0 }, {     56,   16,    0, 16,  0,  0 }, {     57,   18,    0, 16,  0,  0 }, {     58,   20,    0, 16,  0,  0 }, {     59,   22,    0, 16,  0,  0 },
    {     57,   24,    0, 16,  0,  0 }, {     55,   26,    1, 16,  0,  0 }, {     53,   28,    1, 16,  0,  0 }, {     51,   29,    1, 16,  0,  0 }, {     49,   29,    1, 16,  0,  0 },
    {     47,   28,    2, 16,  0,  0 }, {     45,   28,    2, 16,  0,  0 }, {     45,   26,    2, 16,  0,  0 }, {     44,   24,    2, 16,  0,  0 }, {     43,   22,    3, 16,  0,  0 },
    {     43,   20,    3, 16,  0,  0 }, {     42,   18,    3, 16,  0,  0 }, {     43,   16,    3, 16,  0,  0 }, {     43,   14,    3, 16,  0,  0 }, {     43,   12,    3, 16,  0,  0 },
    {     44,   10,    3, 16,  0,  0 }, {     44,    8,    3, 16,  0,  0 }, {     44,    6,    3, 16,  0,  0 }, {     45,    4,    3, 16,  0,  0 }, {     45,    2,    3, 16,  0,  0 },
    {     45,    1,    3, 16,  0,  0 }, {     45,    0,    3, 16,  0,  0 }, {     46,   -1,    3, 16,  0,  0 }, {     46,   -2,    3, 16,  0,  0 }, {     46,   -3,    3, 16,  0,  0 },
    {     46,   -4,    3, 16,  0,  0 }, {     46,   -5,    3, 16,  0,  0 }, {     46,   -7,    0, 16,  0,  0 }, {     47,   -9,    0, 16,  0,  0 }, {     47,  -10,    0, 16,  0,  0 },
    {     47,  -11,    0, 16,  0,  0 }, {     47,  -12,    0, 16,  0,  0 }, {     47,  -13,    0, 16,  0,  0 }, {     47,  -14,    0, 16,  0,  0 }, {     48,  -15,    0, 16,  0,  0 },
    {     48,  -16,    0, 16,  0,  0 }, {     48,  -17,    0, 16,  0,  0 }, {     48,  -18,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {     48,  -29,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     48,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94C73E, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   24,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   18,    0, 24,  0,  0 },
    {     15,   15,    0, 24,  0,  0 }, {     15,   12,    0, 24,  0,  0 }, {     15,    9,    0, 24,  0,  0 }, {     15,    6,    0, 24,  0,  0 }, {     15,    3,    0, 24,  0,  0 },
    {     15,    0,    0, 24,  0,  0 }, {     15,   -3,    0, 24,  0,  0 }, {     15,   -6,    0, 24,  0,  0 }, {     15,   -9,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     15,  -12,    0, 24,  0,  0 }, {     15,  -15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     15,  -18,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 },
    {     15,  -24,    0, 24,  0,  0 }, {     16,  -25,    0, 24,  0,  0 }, {     18,  -26,    0, 24,  0,  0 }, {     20,  -27,    0, 24,  0,  0 }, {     22,  -28,    0, 24,  0,  0 },
    {     24,  -26,    0, 24,  0,  0 }, {     26,  -24,    1, 24,  0,  0 }, {     28,  -22,    1, 24,  0,  0 }, {     29,  -20,    1, 24,  0,  0 }, {     29,  -18,    1, 24,  0,  0 },
    {     28,  -16,    2, 24,  0,  0 }, {     28,  -14,    2, 24,  0,  0 }, {     26,  -14,    2, 24,  0,  0 }, {     24,  -13,    2, 24,  0,  0 }, {     22,  -12,    3, 24,  0,  0 },
    {     20,  -12,    3, 24,  0,  0 }, {     18,  -11,    3, 24,  0,  0 }, {     16,  -12,    3, 24,  0,  0 }, {     14,  -12,    3, 24,  0,  0 }, {     12,  -12,    3, 24,  0,  0 },
    {     10,  -13,    3, 24,  0,  0 }, {      8,  -13,    3, 24,  0,  0 }, {      6,  -13,    3, 24,  0,  0 }, {      4,  -14,    3, 24,  0,  0 }, {      2,  -14,    3, 24,  0,  0 },
    {      1,  -14,    3, 24,  0,  0 }, {      0,  -14,    3, 24,  0,  0 }, {     -1,  -15,    3, 24,  0,  0 }, {     -2,  -15,    3, 24,  0,  0 }, {     -3,  -15,    3, 24,  0,  0 },
    {     -4,  -15,    3, 24,  0,  0 }, {     -5,  -15,    3, 24,  0,  0 }, {     -7,  -15,    0, 24,  0,  0 }, {     -9,  -16,    0, 24,  0,  0 }, {    -10,  -16,    0, 24,  0,  0 },
    {    -11,  -16,    0, 24,  0,  0 }, {    -12,  -16,    0, 24,  0,  0 }, {    -13,  -16,    0, 24,  0,  0 }, {    -14,  -16,    0, 24,  0,  0 }, {    -15,  -17,    0, 24,  0,  0 },
    {    -16,  -17,    0, 24,  0,  0 }, {    -17,  -17,    0, 24,  0,  0 }, {    -18,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {    -29,  -17,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {    -29,  -17,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_945763, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     24,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 },
    {     15,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      6,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 },
    {      0,   16,    0,  0,  0,  0 }, {     -3,   16,    0,  0,  0,  0 }, {     -6,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -12,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {    -18,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 },
    {    -24,   16,    0,  0,  0,  0 }, {    -25,   17,    0,  0,  0,  0 }, {    -26,   19,    0,  0,  0,  0 }, {    -27,   21,    0,  0,  0,  0 }, {    -28,   23,    0,  0,  0,  0 },
    {    -26,   25,    0,  0,  0,  0 }, {    -24,   27,    1,  0,  0,  0 }, {    -22,   29,    1,  0,  0,  0 }, {    -20,   30,    1,  0,  0,  0 }, {    -18,   30,    1,  0,  0,  0 },
    {    -16,   29,    2,  0,  0,  0 }, {    -14,   29,    2,  0,  0,  0 }, {    -14,   27,    2,  0,  0,  0 }, {    -13,   25,    2,  0,  0,  0 }, {    -12,   23,    3,  0,  0,  0 },
    {    -12,   21,    3,  0,  0,  0 }, {    -11,   19,    3,  0,  0,  0 }, {    -12,   17,    3,  0,  0,  0 }, {    -12,   15,    3,  0,  0,  0 }, {    -12,   13,    3,  0,  0,  0 },
    {    -13,   11,    3,  0,  0,  0 }, {    -13,    9,    3,  0,  0,  0 }, {    -13,    7,    3,  0,  0,  0 }, {    -14,    5,    3,  0,  0,  0 }, {    -14,    3,    3,  0,  0,  0 },
    {    -14,    2,    3,  0,  0,  0 }, {    -14,    1,    3,  0,  0,  0 }, {    -15,    0,    3,  0,  0,  0 }, {    -15,   -1,    3,  0,  0,  0 }, {    -15,   -2,    3,  0,  0,  0 },
    {    -15,   -3,    3,  0,  0,  0 }, {    -15,   -4,    3,  0,  0,  0 }, {    -15,   -6,    0,  0,  0,  0 }, {    -16,   -8,    0,  0,  0,  0 }, {    -16,   -9,    0,  0,  0,  0 },
    {    -16,  -10,    0,  0,  0,  0 }, {    -16,  -11,    0,  0,  0,  0 }, {    -16,  -12,    0,  0,  0,  0 }, {    -16,  -13,    0,  0,  0,  0 }, {    -17,  -14,    0,  0,  0,  0 },
    {    -17,  -15,    0,  0,  0,  0 }, {    -17,  -16,    0,  0,  0,  0 }, {    -17,  -17,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {    -17,  -28,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {    -17,  -28,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_948421, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    7,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 },
    {     16,   16,    0,  8,  0,  0 }, {     16,   19,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   25,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 },
    {     16,   31,    0,  8,  0,  0 }, {     16,   34,    0,  8,  0,  0 }, {     16,   37,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     16,   43,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     16,   49,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 },
    {     16,   55,    0,  8,  0,  0 }, {     17,   56,    0,  8,  0,  0 }, {     19,   57,    0,  8,  0,  0 }, {     21,   58,    0,  8,  0,  0 }, {     23,   59,    0,  8,  0,  0 },
    {     25,   57,    0,  8,  0,  0 }, {     27,   55,    1,  8,  0,  0 }, {     29,   53,    1,  8,  0,  0 }, {     30,   51,    1,  8,  0,  0 }, {     30,   49,    1,  8,  0,  0 },
    {     29,   47,    2,  8,  0,  0 }, {     29,   45,    2,  8,  0,  0 }, {     27,   45,    2,  8,  0,  0 }, {     25,   44,    2,  8,  0,  0 }, {     23,   43,    3,  8,  0,  0 },
    {     21,   43,    3,  8,  0,  0 }, {     19,   42,    3,  8,  0,  0 }, {     17,   43,    3,  8,  0,  0 }, {     15,   43,    3,  8,  0,  0 }, {     13,   43,    3,  8,  0,  0 },
    {     11,   44,    3,  8,  0,  0 }, {      9,   44,    3,  8,  0,  0 }, {      7,   44,    3,  8,  0,  0 }, {      5,   45,    3,  8,  0,  0 }, {      3,   45,    3,  8,  0,  0 },
    {      2,   45,    3,  8,  0,  0 }, {      1,   45,    3,  8,  0,  0 }, {      0,   46,    3,  8,  0,  0 }, {     -1,   46,    3,  8,  0,  0 }, {     -2,   46,    3,  8,  0,  0 },
    {     -3,   46,    3,  8,  0,  0 }, {     -4,   46,    3,  8,  0,  0 }, {     -6,   46,    0,  8,  0,  0 }, {     -8,   47,    0,  8,  0,  0 }, {     -9,   47,    0,  8,  0,  0 },
    {    -10,   47,    0,  8,  0,  0 }, {    -11,   47,    0,  8,  0,  0 }, {    -12,   47,    0,  8,  0,  0 }, {    -13,   47,    0,  8,  0,  0 }, {    -14,   48,    0,  8,  0,  0 },
    {    -15,   48,    0,  8,  0,  0 }, {    -16,   48,    0,  8,  0,  0 }, {    -17,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {    -28,   48,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {    -28,   48,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94B0DF, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      7,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     13,   15,    0, 16,  0,  0 },
    {     16,   15,    0, 16,  0,  0 }, {     19,   15,    0, 16,  0,  0 }, {     22,   15,    0, 16,  0,  0 }, {     25,   15,    0, 16,  0,  0 }, {     28,   15,    0, 16,  0,  0 },
    {     31,   15,    0, 16,  0,  0 }, {     34,   15,    0, 16,  0,  0 }, {     37,   15,    0, 16,  0,  0 }, {     40,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     43,   15,    0, 16,  0,  0 }, {     46,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     49,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 },
    {     55,   15,    0, 16,  0,  0 }, {     56,   14,    0, 16,  0,  0 }, {     57,   12,    0, 16,  0,  0 }, {     58,   10,    0, 16,  0,  0 }, {     59,    8,    0, 16,  0,  0 },
    {     57,    6,    0, 16,  0,  0 }, {     55,    4,    1, 16,  0,  0 }, {     53,    2,    1, 16,  0,  0 }, {     51,    1,    1, 16,  0,  0 }, {     49,    1,    1, 16,  0,  0 },
    {     47,    2,    2, 16,  0,  0 }, {     45,    2,    2, 16,  0,  0 }, {     45,    4,    2, 16,  0,  0 }, {     44,    6,    2, 16,  0,  0 }, {     43,    8,    3, 16,  0,  0 },
    {     43,   10,    3, 16,  0,  0 }, {     42,   12,    3, 16,  0,  0 }, {     43,   14,    3, 16,  0,  0 }, {     43,   16,    3, 16,  0,  0 }, {     43,   18,    3, 16,  0,  0 },
    {     44,   20,    3, 16,  0,  0 }, {     44,   22,    3, 16,  0,  0 }, {     44,   24,    3, 16,  0,  0 }, {     45,   26,    3, 16,  0,  0 }, {     45,   28,    3, 16,  0,  0 },
    {     45,   29,    3, 16,  0,  0 }, {     45,   30,    3, 16,  0,  0 }, {     46,   31,    3, 16,  0,  0 }, {     46,   32,    3, 16,  0,  0 }, {     46,   33,    3, 16,  0,  0 },
    {     46,   34,    3, 16,  0,  0 }, {     46,   35,    3, 16,  0,  0 }, {     46,   37,    0, 16,  0,  0 }, {     47,   39,    0, 16,  0,  0 }, {     47,   40,    0, 16,  0,  0 },
    {     47,   41,    0, 16,  0,  0 }, {     47,   42,    0, 16,  0,  0 }, {     47,   43,    0, 16,  0,  0 }, {     47,   44,    0, 16,  0,  0 }, {     48,   45,    0, 16,  0,  0 },
    {     48,   46,    0, 16,  0,  0 }, {     48,   47,    0, 16,  0,  0 }, {     48,   48,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {     48,   59,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     48,   59,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94DD9D, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   24,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   18,    0, 24,  0,  0 },
    {     15,   15,    0, 24,  0,  0 }, {     15,   12,    0, 24,  0,  0 }, {     15,    9,    0, 24,  0,  0 }, {     15,    6,    0, 24,  0,  0 }, {     15,    3,    0, 24,  0,  0 },
    {     15,    0,    0, 24,  0,  0 }, {     15,   -3,    0, 24,  0,  0 }, {     15,   -6,    0, 24,  0,  0 }, {     15,   -9,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     15,  -12,    0, 24,  0,  0 }, {     15,  -15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     15,  -18,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 },
    {     15,  -24,    0, 24,  0,  0 }, {     14,  -25,    0, 24,  0,  0 }, {     12,  -26,    0, 24,  0,  0 }, {     10,  -27,    0, 24,  0,  0 }, {      8,  -28,    0, 24,  0,  0 },
    {      6,  -26,    0, 24,  0,  0 }, {      4,  -24,    1, 24,  0,  0 }, {      2,  -22,    1, 24,  0,  0 }, {      1,  -20,    1, 24,  0,  0 }, {      1,  -18,    1, 24,  0,  0 },
    {      2,  -16,    2, 24,  0,  0 }, {      2,  -14,    2, 24,  0,  0 }, {      4,  -14,    2, 24,  0,  0 }, {      6,  -13,    2, 24,  0,  0 }, {      8,  -12,    3, 24,  0,  0 },
    {     10,  -12,    3, 24,  0,  0 }, {     12,  -11,    3, 24,  0,  0 }, {     14,  -12,    3, 24,  0,  0 }, {     16,  -12,    3, 24,  0,  0 }, {     18,  -12,    3, 24,  0,  0 },
    {     20,  -13,    3, 24,  0,  0 }, {     22,  -13,    3, 24,  0,  0 }, {     24,  -13,    3, 24,  0,  0 }, {     26,  -14,    3, 24,  0,  0 }, {     28,  -14,    3, 24,  0,  0 },
    {     29,  -14,    3, 24,  0,  0 }, {     30,  -14,    3, 24,  0,  0 }, {     31,  -15,    3, 24,  0,  0 }, {     32,  -15,    3, 24,  0,  0 }, {     33,  -15,    3, 24,  0,  0 },
    {     34,  -15,    3, 24,  0,  0 }, {     35,  -15,    3, 24,  0,  0 }, {     37,  -15,    0, 24,  0,  0 }, {     39,  -16,    0, 24,  0,  0 }, {     40,  -16,    0, 24,  0,  0 },
    {     41,  -16,    0, 24,  0,  0 }, {     42,  -16,    0, 24,  0,  0 }, {     43,  -16,    0, 24,  0,  0 }, {     44,  -16,    0, 24,  0,  0 }, {     45,  -17,    0, 24,  0,  0 },
    {     46,  -17,    0, 24,  0,  0 }, {     47,  -17,    0, 24,  0,  0 }, {     48,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {     59,  -17,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     59,  -17,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_939A85, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 },
    {     18,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 },
    {      7,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      3,   16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      3,   16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {      3,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      3,   16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {      1,   16,    0,  0,  0,  0 },
    {     -1,   16,    0,  0,  0,  0 }, {     -3,   16,    0,  0,  0,  0 }, {     -5,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 },
    {    -11,   16,    0,  0,  0,  0 }, {    -13,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {    -15,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -17,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 },
    {    -21,   16,    0,  0,  0,  0 }, {    -23,   16,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 }, {    -27,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93C476, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 },
    {     16,   13,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 },
    {     16,   24,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   28,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,   28,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     16,   28,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,   28,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     16,   30,    0,  8,  0,  0 },
    {     16,   32,    0,  8,  0,  0 }, {     16,   34,    0,  8,  0,  0 }, {     16,   36,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 },
    {     16,   42,    0,  8,  0,  0 }, {     16,   44,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     16,   46,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     16,   48,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 },
    {     16,   52,    0,  8,  0,  0 }, {     16,   54,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 }, {     16,   58,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93EE67, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 },
    {     13,   15,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 }, {     20,   15,    0, 16,  0,  0 }, {     22,   15,    0, 16,  0,  0 },
    {     24,   15,    0, 16,  0,  0 }, {     26,   15,    0, 16,  0,  0 }, {     28,   15,    0, 16,  0,  0 }, {     28,   15,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     28,   15,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     28,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     28,   15,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     30,   15,    0, 16,  0,  0 },
    {     32,   15,    0, 16,  0,  0 }, {     34,   15,    0, 16,  0,  0 }, {     36,   15,    0, 16,  0,  0 }, {     38,   15,    0, 16,  0,  0 }, {     40,   15,    0, 16,  0,  0 },
    {     42,   15,    0, 16,  0,  0 }, {     44,   15,    0, 16,  0,  0 }, {     46,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     46,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     48,   15,    0, 16,  0,  0 }, {     50,   15,    0, 16,  0,  0 },
    {     52,   15,    0, 16,  0,  0 }, {     54,   15,    0, 16,  0,  0 }, {     56,   15,    0, 16,  0,  0 }, {     58,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_941858, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 },
    {     15,   18,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 }, {     15,   11,    0, 24,  0,  0 }, {     15,    9,    0, 24,  0,  0 },
    {     15,    7,    0, 24,  0,  0 }, {     15,    5,    0, 24,  0,  0 }, {     15,    3,    0, 24,  0,  0 }, {     15,    3,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,    3,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     15,    3,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,    3,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     15,    1,    0, 24,  0,  0 },
    {     15,   -1,    0, 24,  0,  0 }, {     15,   -3,    0, 24,  0,  0 }, {     15,   -5,    0, 24,  0,  0 }, {     15,   -7,    0, 24,  0,  0 }, {     15,   -9,    0, 24,  0,  0 },
    {     15,  -11,    0, 24,  0,  0 }, {     15,  -13,    0, 24,  0,  0 }, {     15,  -15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     15,  -15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     15,  -17,    0, 24,  0,  0 }, {     15,  -19,    0, 24,  0,  0 },
    {     15,  -21,    0, 24,  0,  0 }, {     15,  -23,    0, 24,  0,  0 }, {     15,  -25,    0, 24,  0,  0 }, {     15,  -27,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93A898, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 },
    {     17,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 },
    {      7,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      2,   16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {      2,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      2,   16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     -1,   16,    0,  0,  0,  0 },
    {     -3,   16,    0,  0,  0,  0 }, {     -5,   16,    0,  0,  0,  0 }, {     -5,   18,    0,  8,  0,  0 }, {     -5,   20,    0,  8,  0,  0 }, {     -5,   22,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     -4,   22,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     -4,   22,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     -4,   22,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     -5,   20,    0, 24,  0,  0 }, {     -5,   18,    0, 24,  0,  0 }, {     -5,   16,    0, 24,  0,  0 }, {     -7,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 },
    {    -11,   16,    0,  0,  0,  0 }, {    -13,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 },
    {    -21,   16,    0,  0,  0,  0 }, {    -23,   16,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {    -27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -27,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93D289, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 },
    {     16,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 },
    {     16,   24,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,   29,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     16,   29,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,   29,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     16,   32,    0,  8,  0,  0 },
    {     16,   34,    0,  8,  0,  0 }, {     16,   36,    0,  8,  0,  0 }, {     18,   36,    0, 16,  0,  0 }, {     20,   36,    0, 16,  0,  0 }, {     22,   36,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     22,   35,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     22,   35,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     22,   35,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     20,   36,    0,  0,  0,  0 }, {     18,   36,    0,  0,  0,  0 }, {     16,   36,    0,  0,  0,  0 }, {     16,   38,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 },
    {     16,   42,    0,  8,  0,  0 }, {     16,   44,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 },
    {     16,   52,    0,  8,  0,  0 }, {     16,   54,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     16,   58,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     16,   58,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93FC7A, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 },
    {     14,   15,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 }, {     20,   15,    0, 16,  0,  0 }, {     22,   15,    0, 16,  0,  0 },
    {     24,   15,    0, 16,  0,  0 }, {     26,   15,    0, 16,  0,  0 }, {     28,   15,    0, 16,  0,  0 }, {     30,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     29,   15,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     29,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     29,   15,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     32,   15,    0, 16,  0,  0 },
    {     34,   15,    0, 16,  0,  0 }, {     36,   15,    0, 16,  0,  0 }, {     36,   13,    0, 24,  0,  0 }, {     36,   11,    0, 24,  0,  0 }, {     36,    9,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     35,    9,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     35,    9,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     35,    9,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     36,   11,    0,  8,  0,  0 }, {     36,   13,    0,  8,  0,  0 }, {     36,   15,    0,  8,  0,  0 }, {     38,   15,    0, 16,  0,  0 }, {     40,   15,    0, 16,  0,  0 },
    {     42,   15,    0, 16,  0,  0 }, {     44,   15,    0, 16,  0,  0 }, {     46,   15,    0, 16,  0,  0 }, {     48,   15,    0, 16,  0,  0 }, {     50,   15,    0, 16,  0,  0 },
    {     52,   15,    0, 16,  0,  0 }, {     54,   15,    0, 16,  0,  0 }, {     56,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     58,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     58,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94266B, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 },
    {     15,   17,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 }, {     15,   11,    0, 24,  0,  0 }, {     15,    9,    0, 24,  0,  0 },
    {     15,    7,    0, 24,  0,  0 }, {     15,    5,    0, 24,  0,  0 }, {     15,    3,    0, 24,  0,  0 }, {     15,    1,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,    2,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     15,    2,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,    2,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     15,   -1,    0, 24,  0,  0 },
    {     15,   -3,    0, 24,  0,  0 }, {     15,   -5,    0, 24,  0,  0 }, {     13,   -5,    0,  0,  0,  0 }, {     11,   -5,    0,  0,  0,  0 }, {      9,   -5,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      9,   -4,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {      9,   -4,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      9,   -4,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     11,   -5,    0, 16,  0,  0 }, {     13,   -5,    0, 16,  0,  0 }, {     15,   -5,    0, 16,  0,  0 }, {     15,   -7,    0, 24,  0,  0 }, {     15,   -9,    0, 24,  0,  0 },
    {     15,  -11,    0, 24,  0,  0 }, {     15,  -13,    0, 24,  0,  0 }, {     15,  -15,    0, 24,  0,  0 }, {     15,  -17,    0, 24,  0,  0 }, {     15,  -19,    0, 24,  0,  0 },
    {     15,  -21,    0, 24,  0,  0 }, {     15,  -23,    0, 24,  0,  0 }, {     15,  -25,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     15,  -27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     15,  -27,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),
    {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93B648, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 },
    {     17,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {      9,   16,    5,  0,  0,  0 },
    {      7,   16,    5,  0,  0,  0 }, {      5,   16,    5,  0,  0,  0 }, {      3,   16,    5,  0,  0,  0 }, {      1,   16,    5,  0,  0,  0 }, {     -1,   16,    5,  0,  0,  0 },
    {     -3,   16,    5,  0,  0,  0 }, {     -5,   16,    5,  0,  0,  0 }, {     -7,   16,    5,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, {    -11,   16,    0,  0,  0,  0 },
    {    -13,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 },
    {    -23,   16,    0,  0,  0,  0 }, {    -23,   14,    0, 24,  0,  0 }, {    -23,   12,    0, 24,  0,  0 }, {    -23,   10,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {    -23,   10,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {    -23,   10,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {    -23,   10,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {    -23,   10,    0,  8,  0,  0 },
    {    -23,   12,    0,  8,  0,  0 }, {    -23,   14,    0,  8,  0,  0 }, {    -23,   16,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {    -23,   16,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -23,   16,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 },
    {    -27,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93E039, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 },
    {     16,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   22,    5,  8,  0,  0 },
    {     16,   24,    5,  8,  0,  0 }, {     16,   26,    5,  8,  0,  0 }, {     16,   28,    5,  8,  0,  0 }, {     16,   30,    5,  8,  0,  0 }, {     16,   32,    5,  8,  0,  0 },
    {     16,   34,    5,  8,  0,  0 }, {     16,   36,    5,  8,  0,  0 }, {     16,   38,    5,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, {     16,   42,    0,  8,  0,  0 },
    {     16,   44,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 },
    {     16,   54,    0,  8,  0,  0 }, {     14,   54,    0,  0,  0,  0 }, {     12,   54,    0,  0,  0,  0 }, {     10,   54,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     10,   54,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     10,   54,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     10,   54,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     10,   54,    0, 16,  0,  0 },
    {     12,   54,    0, 16,  0,  0 }, {     14,   54,    0, 16,  0,  0 }, {     16,   54,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     16,   54,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     16,   54,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 },
    {     16,   58,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_940A2A, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 },
    {     14,   15,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 }, {     20,   15,    0, 16,  0,  0 }, {     22,   15,    5, 16,  0,  0 },
    {     24,   15,    5, 16,  0,  0 }, {     26,   15,    5, 16,  0,  0 }, {     28,   15,    5, 16,  0,  0 }, {     30,   15,    5, 16,  0,  0 }, {     32,   15,    5, 16,  0,  0 },
    {     34,   15,    5, 16,  0,  0 }, {     36,   15,    5, 16,  0,  0 }, {     38,   15,    5, 16,  0,  0 }, {     40,   15,    0, 16,  0,  0 }, {     42,   15,    0, 16,  0,  0 },
    {     44,   15,    0, 16,  0,  0 }, {     46,   15,    0, 16,  0,  0 }, {     48,   15,    0, 16,  0,  0 }, {     50,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 },
    {     54,   15,    0, 16,  0,  0 }, {     54,   17,    0,  8,  0,  0 }, {     54,   19,    0,  8,  0,  0 }, {     54,   21,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     54,   21,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     54,   21,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     54,   21,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     54,   21,    0, 24,  0,  0 },
    {     54,   19,    0, 24,  0,  0 }, {     54,   17,    0, 24,  0,  0 }, {     54,   15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     54,   15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     54,   15,    0, 16,  0,  0 }, {     56,   15,    0, 16,  0,  0 },
    {     58,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94341B, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 },
    {     15,   17,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 }, {     15,   11,    0, 24,  0,  0 }, {     15,    9,    5, 24,  0,  0 },
    {     15,    7,    5, 24,  0,  0 }, {     15,    5,    5, 24,  0,  0 }, {     15,    3,    5, 24,  0,  0 }, {     15,    1,    5, 24,  0,  0 }, {     15,   -1,    5, 24,  0,  0 },
    {     15,   -3,    5, 24,  0,  0 }, {     15,   -5,    5, 24,  0,  0 }, {     15,   -7,    5, 24,  0,  0 }, {     15,   -9,    0, 24,  0,  0 }, {     15,  -11,    0, 24,  0,  0 },
    {     15,  -13,    0, 24,  0,  0 }, {     15,  -15,    0, 24,  0,  0 }, {     15,  -17,    0, 24,  0,  0 }, {     15,  -19,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 },
    {     15,  -23,    0, 24,  0,  0 }, {     17,  -23,    0, 16,  0,  0 }, {     19,  -23,    0, 16,  0,  0 }, {     21,  -23,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     21,  -23,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     21,  -23,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     21,  -23,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     21,  -23,    0,  0,  0,  0 },
    {     19,  -23,    0,  0,  0,  0 }, {     17,  -23,    0,  0,  0,  0 }, {     15,  -23,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     15,  -23,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     15,  -23,    0, 24,  0,  0 }, {     15,  -25,    0, 24,  0,  0 },
    {     15,  -27,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9443A0, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 },
    {     17,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     15,   18,    0,  8,  0,  0 }, {     15,   20,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   20,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     15,   20,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   20,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     13,   20,    0,  0,  0,  0 },
    {     11,   20,    0,  0,  0,  0 }, {      9,   20,    0,  0,  0,  0 }, {      7,   20,    0,  0,  0,  0 }, {      5,   20,    0,  0,  0,  0 }, {      3,   20,    0,  0,  0,  0 },
    {      1,   20,    0,  0,  0,  0 }, {     -1,   20,    0,  0,  0,  0 }, {     -3,   20,    0,  0,  0,  0 }, {     -3,   22,    0,  8,  0,  0 }, {     -3,   24,    0,  8,  0,  0 },
    {     -3,   26,    0,  8,  0,  0 }, {     -3,   28,    0,  8,  0,  0 }, {     -3,   30,    0,  8,  0,  0 }, {     -3,   32,    0,  8,  0,  0 }, {     -3,   34,    0,  8,  0,  0 },
    {     -3,   36,    0,  8,  0,  0 }, {     -3,   38,    0,  8,  0,  0 }, {     -3,   40,    0,  8,  0,  0 }, {     -3,   42,    0,  8,  0,  0 }, {     -5,   42,    0,  0,  0,  0 },
    {     -7,   42,    0,  0,  0,  0 }, {     -9,   42,    0,  0,  0,  0 }, {    -11,   42,    0,  0,  0,  0 }, {    -13,   42,    0,  0,  0,  0 }, {    -15,   42,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {    -16,   41,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {    -16,   41,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {    -16,   41,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -17,   43,    0,  8,  0,  0 }, {    -17,   45,    0,  8,  0,  0 }, {    -17,   47,    0,  8,  0,  0 }, {    -17,   49,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {    -17,   49,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -17,   48,    0,  8,  0,  0 },
    {    -17,   50,    0,  8,  0,  0 }, {    -17,   52,    0,  8,  0,  0 }, {    -17,   54,    0,  8,  0,  0 }, {    -17,   56,    0,  8,  0,  0 }, {    -17,   58,    0,  8,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {    -17,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94705E, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 },
    {     16,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     18,   16,    0, 16,  0,  0 }, {     20,   16,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     20,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     20,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     20,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     20,   18,    0,  8,  0,  0 },
    {     20,   20,    0,  8,  0,  0 }, {     20,   22,    0,  8,  0,  0 }, {     20,   24,    0,  8,  0,  0 }, {     20,   26,    0,  8,  0,  0 }, {     20,   28,    0,  8,  0,  0 },
    {     20,   30,    0,  8,  0,  0 }, {     20,   32,    0,  8,  0,  0 }, {     20,   34,    0,  8,  0,  0 }, {     22,   34,    0, 16,  0,  0 }, {     24,   34,    0, 16,  0,  0 },
    {     26,   34,    0, 16,  0,  0 }, {     28,   34,    0, 16,  0,  0 }, {     30,   34,    0, 16,  0,  0 }, {     32,   34,    0, 16,  0,  0 }, {     34,   34,    0, 16,  0,  0 },
    {     36,   34,    0, 16,  0,  0 }, {     38,   34,    0, 16,  0,  0 }, {     40,   34,    0, 16,  0,  0 }, {     42,   34,    0, 16,  0,  0 }, {     42,   36,    0,  8,  0,  0 },
    {     42,   38,    0,  8,  0,  0 }, {     42,   40,    0,  8,  0,  0 }, {     42,   42,    0,  8,  0,  0 }, {     42,   44,    0,  8,  0,  0 }, {     42,   46,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     41,   47,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     41,   47,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     41,   47,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     43,   48,    0, 16,  0,  0 }, {     45,   48,    0, 16,  0,  0 }, {     47,   48,    0, 16,  0,  0 }, {     49,   48,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {     49,   48,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     48,   48,    0, 16,  0,  0 },
    {     50,   48,    0, 16,  0,  0 }, {     52,   48,    0, 16,  0,  0 }, {     54,   48,    0, 16,  0,  0 }, {     56,   48,    0, 16,  0,  0 }, {     58,   48,    0, 16,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {     60,   48,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_949D1C, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 },
    {     14,   15,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     16,   13,    0, 24,  0,  0 }, {     16,   11,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,   11,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     16,   11,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,   11,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     18,   11,    0, 16,  0,  0 },
    {     20,   11,    0, 16,  0,  0 }, {     22,   11,    0, 16,  0,  0 }, {     24,   11,    0, 16,  0,  0 }, {     26,   11,    0, 16,  0,  0 }, {     28,   11,    0, 16,  0,  0 },
    {     30,   11,    0, 16,  0,  0 }, {     32,   11,    0, 16,  0,  0 }, {     34,   11,    0, 16,  0,  0 }, {     34,    9,    0, 24,  0,  0 }, {     34,    7,    0, 24,  0,  0 },
    {     34,    5,    0, 24,  0,  0 }, {     34,    3,    0, 24,  0,  0 }, {     34,    1,    0, 24,  0,  0 }, {     34,   -1,    0, 24,  0,  0 }, {     34,   -3,    0, 24,  0,  0 },
    {     34,   -5,    0, 24,  0,  0 }, {     34,   -7,    0, 24,  0,  0 }, {     34,   -9,    0, 24,  0,  0 }, {     34,  -11,    0, 24,  0,  0 }, {     36,  -11,    0, 16,  0,  0 },
    {     38,  -11,    0, 16,  0,  0 }, {     40,  -11,    0, 16,  0,  0 }, {     42,  -11,    0, 16,  0,  0 }, {     44,  -11,    0, 16,  0,  0 }, {     46,  -11,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     47,  -10,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     47,  -10,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     47,  -10,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     48,  -12,    0, 24,  0,  0 }, {     48,  -14,    0, 24,  0,  0 }, {     48,  -16,    0, 24,  0,  0 }, {     48,  -18,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {     48,  -18,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     48,  -17,    0, 24,  0,  0 },
    {     48,  -19,    0, 24,  0,  0 }, {     48,  -21,    0, 24,  0,  0 }, {     48,  -23,    0, 24,  0,  0 }, {     48,  -25,    0, 24,  0,  0 }, {     48,  -27,    0, 24,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {     48,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94C9DA, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 },
    {     15,   17,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     13,   15,    0,  0,  0,  0 }, {     11,   15,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     11,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     11,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     11,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     11,   13,    0, 24,  0,  0 },
    {     11,   11,    0, 24,  0,  0 }, {     11,    9,    0, 24,  0,  0 }, {     11,    7,    0, 24,  0,  0 }, {     11,    5,    0, 24,  0,  0 }, {     11,    3,    0, 24,  0,  0 },
    {     11,    1,    0, 24,  0,  0 }, {     11,   -1,    0, 24,  0,  0 }, {     11,   -3,    0, 24,  0,  0 }, {      9,   -3,    0,  0,  0,  0 }, {      7,   -3,    0,  0,  0,  0 },
    {      5,   -3,    0,  0,  0,  0 }, {      3,   -3,    0,  0,  0,  0 }, {      1,   -3,    0,  0,  0,  0 }, {     -1,   -3,    0,  0,  0,  0 }, {     -3,   -3,    0,  0,  0,  0 },
    {     -5,   -3,    0,  0,  0,  0 }, {     -7,   -3,    0,  0,  0,  0 }, {     -9,   -3,    0,  0,  0,  0 }, {    -11,   -3,    0,  0,  0,  0 }, {    -11,   -5,    0, 24,  0,  0 },
    {    -11,   -7,    0, 24,  0,  0 }, {    -11,   -9,    0, 24,  0,  0 }, {    -11,  -11,    0, 24,  0,  0 }, {    -11,  -13,    0, 24,  0,  0 }, {    -11,  -15,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {    -10,  -16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {    -10,  -16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {    -10,  -16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -12,  -17,    0,  0,  0,  0 }, {    -14,  -17,    0,  0,  0,  0 }, {    -16,  -17,    0,  0,  0,  0 }, {    -18,  -17,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {    -18,  -17,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -17,  -17,    0,  0,  0,  0 },
    {    -19,  -17,    0,  0,  0,  0 }, {    -21,  -17,    0,  0,  0,  0 }, {    -23,  -17,    0,  0,  0,  0 }, {    -25,  -17,    0,  0,  0,  0 }, {    -27,  -17,    0,  0,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {    -29,  -17,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9459FF, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 },
    {     17,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     15,   14,    0,  8,  0,  0 }, {     15,   12,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   12,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     15,   12,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   12,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     13,   12,    0,  0,  0,  0 },
    {     11,   12,    0,  0,  0,  0 }, {      9,   12,    0,  0,  0,  0 }, {      7,   12,    0,  0,  0,  0 }, {      5,   12,    0,  0,  0,  0 }, {      3,   12,    0,  0,  0,  0 },
    {      1,   12,    0,  0,  0,  0 }, {     -1,   12,    0,  0,  0,  0 }, {     -3,   12,    0,  0,  0,  0 }, {     -3,   10,    0, 24,  0,  0 }, {     -3,    8,    0, 24,  0,  0 },
    {     -3,    6,    0, 24,  0,  0 }, {     -3,    4,    0, 24,  0,  0 }, {     -3,    2,    0, 24,  0,  0 }, {     -3,    0,    0, 24,  0,  0 }, {     -3,   -2,    0, 24,  0,  0 },
    {     -3,   -4,    0, 24,  0,  0 }, {     -3,   -6,    0, 24,  0,  0 }, {     -3,   -8,    0, 24,  0,  0 }, {     -3,  -10,    0, 24,  0,  0 }, {     -5,  -10,    0,  0,  0,  0 },
    {     -7,  -10,    0,  0,  0,  0 }, {     -9,  -10,    0,  0,  0,  0 }, {    -11,  -10,    0,  0,  0,  0 }, {    -13,  -10,    0,  0,  0,  0 }, {    -15,  -10,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {    -16,   -9,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {    -16,   -9,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {    -16,   -9,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -17,  -11,    0, 24,  0,  0 }, {    -17,  -13,    0, 24,  0,  0 }, {    -17,  -15,    0, 24,  0,  0 }, {    -17,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {    -17,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -17,  -16,    0, 24,  0,  0 },
    {    -17,  -18,    0, 24,  0,  0 }, {    -17,  -20,    0, 24,  0,  0 }, {    -17,  -22,    0, 24,  0,  0 }, {    -17,  -24,    0, 24,  0,  0 }, {    -17,  -26,    0, 24,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {    -17,  -28,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9486BD, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 },
    {     16,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     14,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     12,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     12,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     12,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     12,   18,    0,  8,  0,  0 },
    {     12,   20,    0,  8,  0,  0 }, {     12,   22,    0,  8,  0,  0 }, {     12,   24,    0,  8,  0,  0 }, {     12,   26,    0,  8,  0,  0 }, {     12,   28,    0,  8,  0,  0 },
    {     12,   30,    0,  8,  0,  0 }, {     12,   32,    0,  8,  0,  0 }, {     12,   34,    0,  8,  0,  0 }, {     10,   34,    0,  0,  0,  0 }, {      8,   34,    0,  0,  0,  0 },
    {      6,   34,    0,  0,  0,  0 }, {      4,   34,    0,  0,  0,  0 }, {      2,   34,    0,  0,  0,  0 }, {      0,   34,    0,  0,  0,  0 }, {     -2,   34,    0,  0,  0,  0 },
    {     -4,   34,    0,  0,  0,  0 }, {     -6,   34,    0,  0,  0,  0 }, {     -8,   34,    0,  0,  0,  0 }, {    -10,   34,    0,  0,  0,  0 }, {    -10,   36,    0,  8,  0,  0 },
    {    -10,   38,    0,  8,  0,  0 }, {    -10,   40,    0,  8,  0,  0 }, {    -10,   42,    0,  8,  0,  0 }, {    -10,   44,    0,  8,  0,  0 }, {    -10,   46,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     -9,   47,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     -9,   47,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     -9,   47,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -11,   48,    0,  0,  0,  0 }, {    -13,   48,    0,  0,  0,  0 }, {    -15,   48,    0,  0,  0,  0 }, {    -17,   48,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {    -17,   48,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -16,   48,    0,  0,  0,  0 },
    {    -18,   48,    0,  0,  0,  0 }, {    -20,   48,    0,  0,  0,  0 }, {    -22,   48,    0,  0,  0,  0 }, {    -24,   48,    0,  0,  0,  0 }, {    -26,   48,    0,  0,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {    -28,   48,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94B37B, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 },
    {     14,   15,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     16,   17,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,   19,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     16,   19,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,   19,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     18,   19,    0, 16,  0,  0 },
    {     20,   19,    0, 16,  0,  0 }, {     22,   19,    0, 16,  0,  0 }, {     24,   19,    0, 16,  0,  0 }, {     26,   19,    0, 16,  0,  0 }, {     28,   19,    0, 16,  0,  0 },
    {     30,   19,    0, 16,  0,  0 }, {     32,   19,    0, 16,  0,  0 }, {     34,   19,    0, 16,  0,  0 }, {     34,   21,    0,  8,  0,  0 }, {     34,   23,    0,  8,  0,  0 },
    {     34,   25,    0,  8,  0,  0 }, {     34,   27,    0,  8,  0,  0 }, {     34,   29,    0,  8,  0,  0 }, {     34,   31,    0,  8,  0,  0 }, {     34,   33,    0,  8,  0,  0 },
    {     34,   35,    0,  8,  0,  0 }, {     34,   37,    0,  8,  0,  0 }, {     34,   39,    0,  8,  0,  0 }, {     34,   41,    0,  8,  0,  0 }, {     36,   41,    0, 16,  0,  0 },
    {     38,   41,    0, 16,  0,  0 }, {     40,   41,    0, 16,  0,  0 }, {     42,   41,    0, 16,  0,  0 }, {     44,   41,    0, 16,  0,  0 }, {     46,   41,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     47,   40,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     47,   40,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     47,   40,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     48,   42,    0,  8,  0,  0 }, {     48,   44,    0,  8,  0,  0 }, {     48,   46,    0,  8,  0,  0 }, {     48,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {     48,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     48,   47,    0,  8,  0,  0 },
    {     48,   49,    0,  8,  0,  0 }, {     48,   51,    0,  8,  0,  0 }, {     48,   53,    0,  8,  0,  0 }, {     48,   55,    0,  8,  0,  0 }, {     48,   57,    0,  8,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {     48,   59,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94E039, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 },
    {     15,   17,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     17,   15,    0,  0,  0,  0 }, {     19,   15,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     19,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     19,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     19,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     19,   13,    0, 24,  0,  0 },
    {     19,   11,    0, 24,  0,  0 }, {     19,    9,    0, 24,  0,  0 }, {     19,    7,    0, 24,  0,  0 }, {     19,    5,    0, 24,  0,  0 }, {     19,    3,    0, 24,  0,  0 },
    {     19,    1,    0, 24,  0,  0 }, {     19,   -1,    0, 24,  0,  0 }, {     19,   -3,    0, 24,  0,  0 }, {     21,   -3,    0, 16,  0,  0 }, {     23,   -3,    0, 16,  0,  0 },
    {     25,   -3,    0, 16,  0,  0 }, {     27,   -3,    0, 16,  0,  0 }, {     29,   -3,    0, 16,  0,  0 }, {     31,   -3,    0, 16,  0,  0 }, {     33,   -3,    0, 16,  0,  0 },
    {     35,   -3,    0, 16,  0,  0 }, {     37,   -3,    0, 16,  0,  0 }, {     39,   -3,    0, 16,  0,  0 }, {     41,   -3,    0, 16,  0,  0 }, {     41,   -5,    0, 24,  0,  0 },
    {     41,   -7,    0, 24,  0,  0 }, {     41,   -9,    0, 24,  0,  0 }, {     41,  -11,    0, 24,  0,  0 }, {     41,  -13,    0, 24,  0,  0 }, {     41,  -15,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     40,  -16,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     40,  -16,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     40,  -16,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     42,  -17,    0, 16,  0,  0 }, {     44,  -17,    0, 16,  0,  0 }, {     46,  -17,    0, 16,  0,  0 }, {     48,  -17,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {     48,  -17,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     47,  -17,    0, 16,  0,  0 },
    {     49,  -17,    0, 16,  0,  0 }, {     51,  -17,    0, 16,  0,  0 }, {     53,  -17,    0, 16,  0,  0 }, {     55,  -17,    0, 16,  0,  0 }, {     57,  -17,    0, 16,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {     59,  -17,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_939CD9, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 },
    {     19,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 }, {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 },
    {     14,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {     10,   16,    0,  0,  0,  0 },
    {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 }, {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 },
    {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -3,   16,    0,  0,  0,  0 }, {     -4,   16,    0,  0,  0,  0 }, {     -5,   16,    0,  0,  0,  0 },
    {     -6,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 }, {     -8,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, {    -10,   16,    0,  0,  0,  0 },
    {    -11,   16,    0,  0,  0,  0 }, {    -12,   16,    0,  0,  0,  0 }, {    -13,   16,    0,  0,  0,  0 }, {    -14,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 },
    {    -16,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {    -29,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93C6CA, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 },
    {     16,   12,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 }, {     16,   15,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 },
    {     16,   17,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   19,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   21,    0,  8,  0,  0 },
    {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 }, {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 },
    {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     16,   29,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     16,   34,    0,  8,  0,  0 }, {     16,   35,    0,  8,  0,  0 }, {     16,   36,    0,  8,  0,  0 },
    {     16,   37,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 }, {     16,   39,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, {     16,   41,    0,  8,  0,  0 },
    {     16,   42,    0,  8,  0,  0 }, {     16,   43,    0,  8,  0,  0 }, {     16,   44,    0,  8,  0,  0 }, {     16,   45,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 },
    {     16,   47,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     16,   60,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93F0BB, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 },
    {     12,   15,    0, 16,  0,  0 }, {     13,   15,    0, 16,  0,  0 }, {     14,   15,    0, 16,  0,  0 }, {     15,   15,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 },
    {     17,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 }, {     19,   15,    0, 16,  0,  0 }, {     20,   15,    0, 16,  0,  0 }, {     21,   15,    0, 16,  0,  0 },
    {     22,   15,    0, 16,  0,  0 }, {     23,   15,    0, 16,  0,  0 }, {     24,   15,    0, 16,  0,  0 }, {     25,   15,    0, 16,  0,  0 }, {     26,   15,    0, 16,  0,  0 },
    {     27,   15,    0, 16,  0,  0 }, {     28,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     29,   15,    0, 16,  0,  0 },
    {     30,   15,    0, 16,  0,  0 }, {     32,   15,    0, 16,  0,  0 }, {     34,   15,    0, 16,  0,  0 }, {     35,   15,    0, 16,  0,  0 }, {     36,   15,    0, 16,  0,  0 },
    {     37,   15,    0, 16,  0,  0 }, {     38,   15,    0, 16,  0,  0 }, {     39,   15,    0, 16,  0,  0 }, {     40,   15,    0, 16,  0,  0 }, {     41,   15,    0, 16,  0,  0 },
    {     42,   15,    0, 16,  0,  0 }, {     43,   15,    0, 16,  0,  0 }, {     44,   15,    0, 16,  0,  0 }, {     45,   15,    0, 16,  0,  0 }, {     46,   15,    0, 16,  0,  0 },
    {     47,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     60,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_941AAC, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 },
    {     15,   19,    0, 24,  0,  0 }, {     15,   18,    0, 24,  0,  0 }, {     15,   17,    0, 24,  0,  0 }, {     15,   16,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 },
    {     15,   14,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 }, {     15,   12,    0, 24,  0,  0 }, {     15,   11,    0, 24,  0,  0 }, {     15,   10,    0, 24,  0,  0 },
    {     15,    9,    0, 24,  0,  0 }, {     15,    8,    0, 24,  0,  0 }, {     15,    7,    0, 24,  0,  0 }, {     15,    6,    0, 24,  0,  0 }, {     15,    5,    0, 24,  0,  0 },
    {     15,    4,    0, 24,  0,  0 }, {     15,    3,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     15,    2,    0, 24,  0,  0 },
    {     15,    1,    0, 24,  0,  0 }, {     15,   -1,    0, 24,  0,  0 }, {     15,   -3,    0, 24,  0,  0 }, {     15,   -4,    0, 24,  0,  0 }, {     15,   -5,    0, 24,  0,  0 },
    {     15,   -6,    0, 24,  0,  0 }, {     15,   -7,    0, 24,  0,  0 }, {     15,   -8,    0, 24,  0,  0 }, {     15,   -9,    0, 24,  0,  0 }, {     15,  -10,    0, 24,  0,  0 },
    {     15,  -11,    0, 24,  0,  0 }, {     15,  -12,    0, 24,  0,  0 }, {     15,  -13,    0, 24,  0,  0 }, {     15,  -14,    0, 24,  0,  0 }, {     15,  -15,    0, 24,  0,  0 },
    {     15,  -16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     15,  -29,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93AB73, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     25,   16,    0,  0,  0,  0 }, {     22,   15,    0,  0,  0,  0 }, {     20,   15,    0,  0,  0,  0 },
    {     18,   15,    0,  0,  0,  0 }, {     16,   14,    0,  0,  0,  0 }, {     14,   14,    0,  0,  0,  0 }, {     12,   13,    0,  0,  0,  0 }, {     10,   13,    0,  0,  0,  0 },
    {      8,   13,    0,  0,  0,  0 }, {      6,   12,    0,  0,  0,  0 }, {      4,   12,    0,  0,  0,  0 }, {      2,   11,    0,  0,  0,  0 }, {      1,   11,    0,  0,  0,  0 },
    {      0,   11,    0,  0,  0,  0 }, {      0,   12,    0,  0,  0,  0 }, {      0,   13,    0,  0,  0,  0 }, {      0,   14,    0,  0,  0,  0 }, {      1,   15,    0,  0,  0,  0 },
    MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {      1,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -3,   16,    0,  0,  0,  0 },
    {     -4,   16,    0,  0,  0,  0 }, {     -5,   16,    0,  0,  0,  0 }, {     -5,   17,    0,  0,  0,  0 }, {     -5,   18,    0,  0,  0,  0 }, {     -5,   19,    0,  0,  0,  0 },
    {     -5,   20,    0,  0,  0,  0 }, {     -5,   21,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     -5,   22,    0,  0,  0,  0 },
    {     -7,   22,    0,  0,  0,  0 }, {     -9,   21,    0,  0,  0,  0 }, {    -11,   21,    0,  0,  0,  0 }, {    -13,   20,    0,  0,  0,  0 }, {    -15,   20,    0,  0,  0,  0 },
    {    -16,   20,    0,  0,  0,  0 }, {    -17,   19,    0,  0,  0,  0 }, {    -18,   19,    0,  0,  0,  0 }, {    -19,   18,    0,  0,  0,  0 }, {    -20,   18,    0,  0,  0,  0 },
    {    -21,   18,    0,  0,  0,  0 }, {    -22,   17,    0,  0,  0,  0 }, {    -23,   17,    0,  0,  0,  0 }, {    -24,   17,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 },
    {    -26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {    -29,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93D564, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    6,    0,  8,  0,  0 }, {     15,    9,    0,  8,  0,  0 }, {     15,   11,    0,  8,  0,  0 },
    {     15,   13,    0,  8,  0,  0 }, {     14,   15,    0,  8,  0,  0 }, {     14,   17,    0,  8,  0,  0 }, {     13,   19,    0,  8,  0,  0 }, {     13,   21,    0,  8,  0,  0 },
    {     13,   23,    0,  8,  0,  0 }, {     12,   25,    0,  8,  0,  0 }, {     12,   27,    0,  8,  0,  0 }, {     11,   29,    0,  8,  0,  0 }, {     11,   30,    0,  8,  0,  0 },
    {     11,   31,    0,  8,  0,  0 }, {     12,   31,    0,  8,  0,  0 }, {     13,   31,    0,  8,  0,  0 }, {     14,   31,    0,  8,  0,  0 }, {     15,   30,    0,  8,  0,  0 },
    MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     16,   30,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     16,   34,    0,  8,  0,  0 },
    {     16,   35,    0,  8,  0,  0 }, {     16,   36,    0,  8,  0,  0 }, {     17,   36,    0,  8,  0,  0 }, {     18,   36,    0,  8,  0,  0 }, {     19,   36,    0,  8,  0,  0 },
    {     20,   36,    0,  8,  0,  0 }, {     21,   36,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     22,   36,    0,  8,  0,  0 },
    {     22,   38,    0,  8,  0,  0 }, {     21,   40,    0,  8,  0,  0 }, {     21,   42,    0,  8,  0,  0 }, {     20,   44,    0,  8,  0,  0 }, {     20,   46,    0,  8,  0,  0 },
    {     20,   47,    0,  8,  0,  0 }, {     19,   48,    0,  8,  0,  0 }, {     19,   49,    0,  8,  0,  0 }, {     18,   50,    0,  8,  0,  0 }, {     18,   51,    0,  8,  0,  0 },
    {     18,   52,    0,  8,  0,  0 }, {     17,   53,    0,  8,  0,  0 }, {     17,   54,    0,  8,  0,  0 }, {     17,   55,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 },
    {     16,   57,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     16,   60,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93FF55, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      6,   15,    0, 16,  0,  0 }, {      9,   16,    0, 16,  0,  0 }, {     11,   16,    0, 16,  0,  0 },
    {     13,   16,    0, 16,  0,  0 }, {     15,   17,    0, 16,  0,  0 }, {     17,   17,    0, 16,  0,  0 }, {     19,   18,    0, 16,  0,  0 }, {     21,   18,    0, 16,  0,  0 },
    {     23,   18,    0, 16,  0,  0 }, {     25,   19,    0, 16,  0,  0 }, {     27,   19,    0, 16,  0,  0 }, {     29,   20,    0, 16,  0,  0 }, {     30,   20,    0, 16,  0,  0 },
    {     31,   20,    0, 16,  0,  0 }, {     31,   19,    0, 16,  0,  0 }, {     31,   18,    0, 16,  0,  0 }, {     31,   17,    0, 16,  0,  0 }, {     30,   16,    0, 16,  0,  0 },
    MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     30,   15,    0, 16,  0,  0 }, {     32,   15,    0, 16,  0,  0 }, {     34,   15,    0, 16,  0,  0 },
    {     35,   15,    0, 16,  0,  0 }, {     36,   15,    0, 16,  0,  0 }, {     36,   14,    0, 16,  0,  0 }, {     36,   13,    0, 16,  0,  0 }, {     36,   12,    0, 16,  0,  0 },
    {     36,   11,    0, 16,  0,  0 }, {     36,   10,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     36,    9,    0, 16,  0,  0 },
    {     38,    9,    0, 16,  0,  0 }, {     40,   10,    0, 16,  0,  0 }, {     42,   10,    0, 16,  0,  0 }, {     44,   11,    0, 16,  0,  0 }, {     46,   11,    0, 16,  0,  0 },
    {     47,   11,    0, 16,  0,  0 }, {     48,   12,    0, 16,  0,  0 }, {     49,   12,    0, 16,  0,  0 }, {     50,   13,    0, 16,  0,  0 }, {     51,   13,    0, 16,  0,  0 },
    {     52,   13,    0, 16,  0,  0 }, {     53,   14,    0, 16,  0,  0 }, {     54,   14,    0, 16,  0,  0 }, {     55,   14,    0, 16,  0,  0 }, {     56,   15,    0, 16,  0,  0 },
    {     57,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     60,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_942946, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   25,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 }, {     16,   20,    0, 24,  0,  0 },
    {     16,   18,    0, 24,  0,  0 }, {     17,   16,    0, 24,  0,  0 }, {     17,   14,    0, 24,  0,  0 }, {     18,   12,    0, 24,  0,  0 }, {     18,   10,    0, 24,  0,  0 },
    {     18,    8,    0, 24,  0,  0 }, {     19,    6,    0, 24,  0,  0 }, {     19,    4,    0, 24,  0,  0 }, {     20,    2,    0, 24,  0,  0 }, {     20,    1,    0, 24,  0,  0 },
    {     20,    0,    0, 24,  0,  0 }, {     19,    0,    0, 24,  0,  0 }, {     18,    0,    0, 24,  0,  0 }, {     17,    0,    0, 24,  0,  0 }, {     16,    1,    0, 24,  0,  0 },
    MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     15,    1,    0, 24,  0,  0 }, {     15,   -1,    0, 24,  0,  0 }, {     15,   -3,    0, 24,  0,  0 },
    {     15,   -4,    0, 24,  0,  0 }, {     15,   -5,    0, 24,  0,  0 }, {     14,   -5,    0, 24,  0,  0 }, {     13,   -5,    0, 24,  0,  0 }, {     12,   -5,    0, 24,  0,  0 },
    {     11,   -5,    0, 24,  0,  0 }, {     10,   -5,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {      9,   -5,    0, 24,  0,  0 },
    {      9,   -7,    0, 24,  0,  0 }, {     10,   -9,    0, 24,  0,  0 }, {     10,  -11,    0, 24,  0,  0 }, {     11,  -13,    0, 24,  0,  0 }, {     11,  -15,    0, 24,  0,  0 },
    {     11,  -16,    0, 24,  0,  0 }, {     12,  -17,    0, 24,  0,  0 }, {     12,  -18,    0, 24,  0,  0 }, {     13,  -19,    0, 24,  0,  0 }, {     13,  -20,    0, 24,  0,  0 },
    {     13,  -21,    0, 24,  0,  0 }, {     14,  -22,    0, 24,  0,  0 }, {     14,  -23,    0, 24,  0,  0 }, {     14,  -24,    0, 24,  0,  0 }, {     15,  -25,    0, 24,  0,  0 },
    {     15,  -26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     15,  -29,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93B8DB, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     24,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 },
    {     15,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {      7,   15,    0,  0,  0,  0 }, {      5,   15,    0,  0,  0,  0 }, {      3,   14,    0,  0,  0,  0 }, {      1,   13,    0,  0,  0,  0 }, {     -1,   13,    0,  0,  0,  0 },
    {     -3,   12,    0,  0,  0,  0 }, {     -5,   12,    0,  0,  0,  0 }, {     -7,   11,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     -8,   11,    0,  0,  0,  0 },
    {     -9,   11,    0,  0,  0,  0 }, {    -10,   11,    0,  0,  0,  0 }, {    -11,   11,    0,  0,  0,  0 }, {    -12,   11,    0,  0,  0,  0 }, {    -13,   11,    0,  0,  0,  0 },
    {    -14,   11,    0,  0,  0,  0 }, {    -15,   11,    0,  0,  0,  0 }, {    -16,   11,    0,  0,  0,  0 }, {    -17,   11,    0,  0,  0,  0 }, {    -18,   11,    0,  0,  0,  0 },
    {    -19,   11,    0,  0,  0,  0 }, {    -20,   11,    0,  0,  0,  0 }, {    -21,   11,    0,  0,  0,  0 }, {    -22,   11,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {    -23,   11,    0,  0,  0,  0 }, {    -23,   12,    0,  0,  0,  0 }, {    -23,   13,    0,  0,  0,  0 }, {    -23,   14,    0,  0,  0,  0 },
    {    -23,   15,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {    -29,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93E2CC, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    7,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 },
    {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     15,   24,    0,  8,  0,  0 }, {     15,   26,    0,  8,  0,  0 }, {     14,   28,    0,  8,  0,  0 }, {     13,   30,    0,  8,  0,  0 }, {     13,   32,    0,  8,  0,  0 },
    {     12,   34,    0,  8,  0,  0 }, {     12,   36,    0,  8,  0,  0 }, {     11,   38,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     11,   39,    0,  8,  0,  0 },
    {     11,   40,    0,  8,  0,  0 }, {     11,   41,    0,  8,  0,  0 }, {     11,   42,    0,  8,  0,  0 }, {     11,   43,    0,  8,  0,  0 }, {     11,   44,    0,  8,  0,  0 },
    {     11,   45,    0,  8,  0,  0 }, {     11,   46,    0,  8,  0,  0 }, {     11,   47,    0,  8,  0,  0 }, {     11,   48,    0,  8,  0,  0 }, {     11,   49,    0,  8,  0,  0 },
    {     11,   50,    0,  8,  0,  0 }, {     11,   51,    0,  8,  0,  0 }, {     11,   52,    0,  8,  0,  0 }, {     11,   53,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     11,   54,    0,  8,  0,  0 }, {     12,   54,    0,  8,  0,  0 }, {     13,   54,    0,  8,  0,  0 }, {     14,   54,    0,  8,  0,  0 },
    {     15,   54,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     16,   60,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_940CBD, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      7,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     13,   15,    0, 16,  0,  0 },
    {     16,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 }, {     20,   15,    0, 16,  0,  0 }, {     22,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     24,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     28,   17,    0, 16,  0,  0 }, {     30,   18,    0, 16,  0,  0 }, {     32,   18,    0, 16,  0,  0 },
    {     34,   19,    0, 16,  0,  0 }, {     36,   19,    0, 16,  0,  0 }, {     38,   20,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     39,   20,    0, 16,  0,  0 },
    {     40,   20,    0, 16,  0,  0 }, {     41,   20,    0, 16,  0,  0 }, {     42,   20,    0, 16,  0,  0 }, {     43,   20,    0, 16,  0,  0 }, {     44,   20,    0, 16,  0,  0 },
    {     45,   20,    0, 16,  0,  0 }, {     46,   20,    0, 16,  0,  0 }, {     47,   20,    0, 16,  0,  0 }, {     48,   20,    0, 16,  0,  0 }, {     49,   20,    0, 16,  0,  0 },
    {     50,   20,    0, 16,  0,  0 }, {     51,   20,    0, 16,  0,  0 }, {     52,   20,    0, 16,  0,  0 }, {     53,   20,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     54,   20,    0, 16,  0,  0 }, {     54,   19,    0, 16,  0,  0 }, {     54,   18,    0, 16,  0,  0 }, {     54,   17,    0, 16,  0,  0 },
    {     54,   16,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     60,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9436AE, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   24,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   18,    0, 24,  0,  0 },
    {     15,   15,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 }, {     15,   11,    0, 24,  0,  0 }, {     15,    9,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     16,    7,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     17,    3,    0, 24,  0,  0 }, {     18,    1,    0, 24,  0,  0 }, {     18,   -1,    0, 24,  0,  0 },
    {     19,   -3,    0, 24,  0,  0 }, {     19,   -5,    0, 24,  0,  0 }, {     20,   -7,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     20,   -8,    0, 24,  0,  0 },
    {     20,   -9,    0, 24,  0,  0 }, {     20,  -10,    0, 24,  0,  0 }, {     20,  -11,    0, 24,  0,  0 }, {     20,  -12,    0, 24,  0,  0 }, {     20,  -13,    0, 24,  0,  0 },
    {     20,  -14,    0, 24,  0,  0 }, {     20,  -15,    0, 24,  0,  0 }, {     20,  -16,    0, 24,  0,  0 }, {     20,  -17,    0, 24,  0,  0 }, {     20,  -18,    0, 24,  0,  0 },
    {     20,  -19,    0, 24,  0,  0 }, {     20,  -20,    0, 24,  0,  0 }, {     20,  -21,    0, 24,  0,  0 }, {     20,  -22,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     20,  -23,    0, 24,  0,  0 }, {     19,  -23,    0, 24,  0,  0 }, {     18,  -23,    0, 24,  0,  0 }, {     17,  -23,    0, 24,  0,  0 },
    {     16,  -23,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     15,  -29,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9446DE, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     24,   16,    0,  0,  0,  0 }, {     21,   17,    0,  0,  0,  0 }, {     19,   17,    0,  0,  0,  0 },
    {     17,   17,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     13,   18,    0,  0,  0,  0 }, {     11,   18,    0,  0,  0,  0 }, {      9,   18,    0,  0,  0,  0 },
    {      7,   18,    0,  0,  0,  0 }, {      5,   18,    0,  0,  0,  0 }, {      4,   18,    0,  0,  0,  0 }, {      3,   19,    0,  0,  0,  0 }, {      2,   19,    0,  0,  0,  0 },
    {      1,   19,    0,  0,  0,  0 }, {      0,   19,    0,  0,  0,  0 }, {     -1,   19,    0,  0,  0,  0 }, {     -2,   19,    0,  0,  0,  0 }, {     -1,   19,    0,  0,  0,  0 },
    {      0,   19,    0,  0,  0,  0 }, {      1,   19,    0,  0,  0,  0 }, {      2,   19,    0,  0,  0,  0 }, {      3,   19,    0,  0,  0,  0 }, {      4,   19,    0,  0,  0,  0 },
    {      5,   19,    0,  0,  0,  0 }, {      6,   20,    0,  0,  0,  0 }, {      7,   20,    0,  0,  0,  0 }, {      8,   20,    0,  0,  0,  0 }, {      9,   20,    0,  0,  0,  0 },
    {     10,   20,    0,  0,  0,  0 }, {     11,   20,    0,  0,  0,  0 }, {     12,   20,    0,  0,  0,  0 }, {     13,   20,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     14,   20,    0,  0,  0,  0 }, {     12,   20,    0,  0,  0,  0 }, {      9,   20,    0,  0,  0,  0 }, {      6,   20,    0,  0,  0,  0 },
    {      3,   20,    0,  0,  0,  0 }, {      0,   20,    0,  0,  0,  0 }, {     -3,   20,    0,  0,  0,  0 }, {     -6,   20,    0,  0,  0,  0 }, {     -9,   20,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {    -12,   20,    0,  0,  0,  0 }, {    -15,   20,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {    -18,   16,    0,  0,  0,  0 },
    {    -21,   16,    0,  0,  0,  0 }, {    -24,   16,    0,  0,  0,  0 }, {    -25,   15,    0,  0,  0,  0 }, {    -26,   13,    0,  0,  0,  0 }, {    -27,   11,    0,  0,  0,  0 },
    {    -28,    9,    0,  0,  0,  0 }, {    -26,    7,    0,  0,  0,  0 }, {    -24,    5,    1,  0,  0,  0 }, {    -22,    3,    1,  0,  0,  0 }, {    -20,    2,    1,  0,  0,  0 },
    {    -18,    2,    1,  0,  0,  0 }, {    -16,    3,    2,  0,  0,  0 }, {    -14,    3,    2,  0,  0,  0 }, {    -14,    5,    2,  0,  0,  0 }, {    -13,    7,    2,  0,  0,  0 },
    {    -12,    9,    3,  0,  0,  0 }, {    -12,   11,    3,  0,  0,  0 }, {    -11,   13,    3,  0,  0,  0 }, {    -12,   15,    3,  0,  0,  0 }, {    -12,   17,    3,  0,  0,  0 },
    {    -12,   19,    3,  0,  0,  0 }, {    -13,   21,    3,  0,  0,  0 }, {    -13,   23,    3,  0,  0,  0 }, {    -13,   25,    3,  0,  0,  0 }, {    -14,   27,    3,  0,  0,  0 },
    {    -14,   29,    3,  0,  0,  0 }, {    -14,   30,    3,  0,  0,  0 }, {    -14,   31,    3,  0,  0,  0 }, {    -15,   32,    3,  0,  0,  0 }, {    -15,   33,    3,  0,  0,  0 },
    {    -15,   34,    3,  0,  0,  0 }, {    -15,   35,    3,  0,  0,  0 }, {    -15,   36,    3,  0,  0,  0 }, {    -15,   38,    0,  0,  0,  0 }, {    -16,   40,    0,  0,  0,  0 },
    {    -16,   41,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {    -16,   42,    0,  0,  0,  0 }, {    -16,   43,    0,  0,  0,  0 },
    {    -16,   44,    0,  0,  0,  0 }, {    -16,   45,    0,  0,  0,  0 }, {    -17,   46,    0,  0,  0,  0 }, {    -17,   47,    0,  0,  0,  0 }, {    -17,   48,    0,  0,  0,  0 },
    {    -17,   49,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {    -17,   60,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {    -17,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94739C, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    7,    0,  8,  0,  0 }, {     17,   10,    0,  8,  0,  0 }, {     17,   12,    0,  8,  0,  0 },
    {     17,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     18,   18,    0,  8,  0,  0 }, {     18,   20,    0,  8,  0,  0 }, {     18,   22,    0,  8,  0,  0 },
    {     18,   24,    0,  8,  0,  0 }, {     18,   26,    0,  8,  0,  0 }, {     18,   27,    0,  8,  0,  0 }, {     19,   28,    0,  8,  0,  0 }, {     19,   29,    0,  8,  0,  0 },
    {     19,   30,    0,  8,  0,  0 }, {     19,   31,    0,  8,  0,  0 }, {     19,   32,    0,  8,  0,  0 }, {     19,   33,    0,  8,  0,  0 }, {     19,   32,    0,  8,  0,  0 },
    {     19,   31,    0,  8,  0,  0 }, {     19,   30,    0,  8,  0,  0 }, {     19,   29,    0,  8,  0,  0 }, {     19,   28,    0,  8,  0,  0 }, {     19,   27,    0,  8,  0,  0 },
    {     19,   26,    0,  8,  0,  0 }, {     20,   25,    0,  8,  0,  0 }, {     20,   24,    0,  8,  0,  0 }, {     20,   23,    0,  8,  0,  0 }, {     20,   22,    0,  8,  0,  0 },
    {     20,   21,    0,  8,  0,  0 }, {     20,   20,    0,  8,  0,  0 }, {     20,   19,    0,  8,  0,  0 }, {     20,   18,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     20,   17,    0,  8,  0,  0 }, {     20,   19,    0,  8,  0,  0 }, {     20,   22,    0,  8,  0,  0 }, {     20,   25,    0,  8,  0,  0 },
    {     20,   28,    0,  8,  0,  0 }, {     20,   31,    0,  8,  0,  0 }, {     20,   34,    0,  8,  0,  0 }, {     20,   37,    0,  8,  0,  0 }, {     20,   40,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     20,   43,    0,  8,  0,  0 }, {     20,   46,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     16,   49,    0,  8,  0,  0 },
    {     16,   52,    0,  8,  0,  0 }, {     16,   55,    0,  8,  0,  0 }, {     15,   56,    0,  8,  0,  0 }, {     13,   57,    0,  8,  0,  0 }, {     11,   58,    0,  8,  0,  0 },
    {      9,   59,    0,  8,  0,  0 }, {      7,   57,    0,  8,  0,  0 }, {      5,   55,    1,  8,  0,  0 }, {      3,   53,    1,  8,  0,  0 }, {      2,   51,    1,  8,  0,  0 },
    {      2,   49,    1,  8,  0,  0 }, {      3,   47,    2,  8,  0,  0 }, {      3,   45,    2,  8,  0,  0 }, {      5,   45,    2,  8,  0,  0 }, {      7,   44,    2,  8,  0,  0 },
    {      9,   43,    3,  8,  0,  0 }, {     11,   43,    3,  8,  0,  0 }, {     13,   42,    3,  8,  0,  0 }, {     15,   43,    3,  8,  0,  0 }, {     17,   43,    3,  8,  0,  0 },
    {     19,   43,    3,  8,  0,  0 }, {     21,   44,    3,  8,  0,  0 }, {     23,   44,    3,  8,  0,  0 }, {     25,   44,    3,  8,  0,  0 }, {     27,   45,    3,  8,  0,  0 },
    {     29,   45,    3,  8,  0,  0 }, {     30,   45,    3,  8,  0,  0 }, {     31,   45,    3,  8,  0,  0 }, {     32,   46,    3,  8,  0,  0 }, {     33,   46,    3,  8,  0,  0 },
    {     34,   46,    3,  8,  0,  0 }, {     35,   46,    3,  8,  0,  0 }, {     36,   46,    3,  8,  0,  0 }, {     38,   46,    0,  8,  0,  0 }, {     40,   47,    0,  8,  0,  0 },
    {     41,   47,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     42,   47,    0,  8,  0,  0 }, {     43,   47,    0,  8,  0,  0 },
    {     44,   47,    0,  8,  0,  0 }, {     45,   47,    0,  8,  0,  0 }, {     46,   48,    0,  8,  0,  0 }, {     47,   48,    0,  8,  0,  0 }, {     48,   48,    0,  8,  0,  0 },
    {     49,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     60,   48,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     60,   48,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94A05A, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      7,   15,    0, 16,  0,  0 }, {     10,   14,    0, 16,  0,  0 }, {     12,   14,    0, 16,  0,  0 },
    {     14,   14,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     18,   13,    0, 16,  0,  0 }, {     20,   13,    0, 16,  0,  0 }, {     22,   13,    0, 16,  0,  0 },
    {     24,   13,    0, 16,  0,  0 }, {     26,   13,    0, 16,  0,  0 }, {     27,   13,    0, 16,  0,  0 }, {     28,   12,    0, 16,  0,  0 }, {     29,   12,    0, 16,  0,  0 },
    {     30,   12,    0, 16,  0,  0 }, {     31,   12,    0, 16,  0,  0 }, {     32,   12,    0, 16,  0,  0 }, {     33,   12,    0, 16,  0,  0 }, {     32,   12,    0, 16,  0,  0 },
    {     31,   12,    0, 16,  0,  0 }, {     30,   12,    0, 16,  0,  0 }, {     29,   12,    0, 16,  0,  0 }, {     28,   12,    0, 16,  0,  0 }, {     27,   12,    0, 16,  0,  0 },
    {     26,   12,    0, 16,  0,  0 }, {     25,   11,    0, 16,  0,  0 }, {     24,   11,    0, 16,  0,  0 }, {     23,   11,    0, 16,  0,  0 }, {     22,   11,    0, 16,  0,  0 },
    {     21,   11,    0, 16,  0,  0 }, {     20,   11,    0, 16,  0,  0 }, {     19,   11,    0, 16,  0,  0 }, {     18,   11,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     17,   11,    0, 16,  0,  0 }, {     19,   11,    0, 16,  0,  0 }, {     22,   11,    0, 16,  0,  0 }, {     25,   11,    0, 16,  0,  0 },
    {     28,   11,    0, 16,  0,  0 }, {     31,   11,    0, 16,  0,  0 }, {     34,   11,    0, 16,  0,  0 }, {     37,   11,    0, 16,  0,  0 }, {     40,   11,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     43,   11,    0, 16,  0,  0 }, {     46,   11,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     49,   15,    0, 16,  0,  0 },
    {     52,   15,    0, 16,  0,  0 }, {     55,   15,    0, 16,  0,  0 }, {     56,   16,    0, 16,  0,  0 }, {     57,   18,    0, 16,  0,  0 }, {     58,   20,    0, 16,  0,  0 },
    {     59,   22,    0, 16,  0,  0 }, {     57,   24,    0, 16,  0,  0 }, {     55,   26,    1, 16,  0,  0 }, {     53,   28,    1, 16,  0,  0 }, {     51,   29,    1, 16,  0,  0 },
    {     49,   29,    1, 16,  0,  0 }, {     47,   28,    2, 16,  0,  0 }, {     45,   28,    2, 16,  0,  0 }, {     45,   26,    2, 16,  0,  0 }, {     44,   24,    2, 16,  0,  0 },
    {     43,   22,    3, 16,  0,  0 }, {     43,   20,    3, 16,  0,  0 }, {     42,   18,    3, 16,  0,  0 }, {     43,   16,    3, 16,  0,  0 }, {     43,   14,    3, 16,  0,  0 },
    {     43,   12,    3, 16,  0,  0 }, {     44,   10,    3, 16,  0,  0 }, {     44,    8,    3, 16,  0,  0 }, {     44,    6,    3, 16,  0,  0 }, {     45,    4,    3, 16,  0,  0 },
    {     45,    2,    3, 16,  0,  0 }, {     45,    1,    3, 16,  0,  0 }, {     45,    0,    3, 16,  0,  0 }, {     46,   -1,    3, 16,  0,  0 }, {     46,   -2,    3, 16,  0,  0 },
    {     46,   -3,    3, 16,  0,  0 }, {     46,   -4,    3, 16,  0,  0 }, {     46,   -5,    3, 16,  0,  0 }, {     46,   -7,    0, 16,  0,  0 }, {     47,   -9,    0, 16,  0,  0 },
    {     47,  -10,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     47,  -11,    0, 16,  0,  0 }, {     47,  -12,    0, 16,  0,  0 },
    {     47,  -13,    0, 16,  0,  0 }, {     47,  -14,    0, 16,  0,  0 }, {     48,  -15,    0, 16,  0,  0 }, {     48,  -16,    0, 16,  0,  0 }, {     48,  -17,    0, 16,  0,  0 },
    {     48,  -18,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     48,  -29,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     48,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94CD18, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   24,    0, 24,  0,  0 }, {     14,   21,    0, 24,  0,  0 }, {     14,   19,    0, 24,  0,  0 },
    {     14,   17,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     13,   13,    0, 24,  0,  0 }, {     13,   11,    0, 24,  0,  0 }, {     13,    9,    0, 24,  0,  0 },
    {     13,    7,    0, 24,  0,  0 }, {     13,    5,    0, 24,  0,  0 }, {     13,    4,    0, 24,  0,  0 }, {     12,    3,    0, 24,  0,  0 }, {     12,    2,    0, 24,  0,  0 },
    {     12,    1,    0, 24,  0,  0 }, {     12,    0,    0, 24,  0,  0 }, {     12,   -1,    0, 24,  0,  0 }, {     12,   -2,    0, 24,  0,  0 }, {     12,   -1,    0, 24,  0,  0 },
    {     12,    0,    0, 24,  0,  0 }, {     12,    1,    0, 24,  0,  0 }, {     12,    2,    0, 24,  0,  0 }, {     12,    3,    0, 24,  0,  0 }, {     12,    4,    0, 24,  0,  0 },
    {     12,    5,    0, 24,  0,  0 }, {     11,    6,    0, 24,  0,  0 }, {     11,    7,    0, 24,  0,  0 }, {     11,    8,    0, 24,  0,  0 }, {     11,    9,    0, 24,  0,  0 },
    {     11,   10,    0, 24,  0,  0 }, {     11,   11,    0, 24,  0,  0 }, {     11,   12,    0, 24,  0,  0 }, {     11,   13,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     11,   14,    0, 24,  0,  0 }, {     11,   12,    0, 24,  0,  0 }, {     11,    9,    0, 24,  0,  0 }, {     11,    6,    0, 24,  0,  0 },
    {     11,    3,    0, 24,  0,  0 }, {     11,    0,    0, 24,  0,  0 }, {     11,   -3,    0, 24,  0,  0 }, {     11,   -6,    0, 24,  0,  0 }, {     11,   -9,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     11,  -12,    0, 24,  0,  0 }, {     11,  -15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     15,  -18,    0, 24,  0,  0 },
    {     15,  -21,    0, 24,  0,  0 }, {     15,  -24,    0, 24,  0,  0 }, {     16,  -25,    0, 24,  0,  0 }, {     18,  -26,    0, 24,  0,  0 }, {     20,  -27,    0, 24,  0,  0 },
    {     22,  -28,    0, 24,  0,  0 }, {     24,  -26,    0, 24,  0,  0 }, {     26,  -24,    1, 24,  0,  0 }, {     28,  -22,    1, 24,  0,  0 }, {     29,  -20,    1, 24,  0,  0 },
    {     29,  -18,    1, 24,  0,  0 }, {     28,  -16,    2, 24,  0,  0 }, {     28,  -14,    2, 24,  0,  0 }, {     26,  -14,    2, 24,  0,  0 }, {     24,  -13,    2, 24,  0,  0 },
    {     22,  -12,    3, 24,  0,  0 }, {     20,  -12,    3, 24,  0,  0 }, {     18,  -11,    3, 24,  0,  0 }, {     16,  -12,    3, 24,  0,  0 }, {     14,  -12,    3, 24,  0,  0 },
    {     12,  -12,    3, 24,  0,  0 }, {     10,  -13,    3, 24,  0,  0 }, {      8,  -13,    3, 24,  0,  0 }, {      6,  -13,    3, 24,  0,  0 }, {      4,  -14,    3, 24,  0,  0 },
    {      2,  -14,    3, 24,  0,  0 }, {      1,  -14,    3, 24,  0,  0 }, {      0,  -14,    3, 24,  0,  0 }, {     -1,  -15,    3, 24,  0,  0 }, {     -2,  -15,    3, 24,  0,  0 },
    {     -3,  -15,    3, 24,  0,  0 }, {     -4,  -15,    3, 24,  0,  0 }, {     -5,  -15,    3, 24,  0,  0 }, {     -7,  -15,    0, 24,  0,  0 }, {     -9,  -16,    0, 24,  0,  0 },
    {    -10,  -16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {    -11,  -16,    0, 24,  0,  0 }, {    -12,  -16,    0, 24,  0,  0 },
    {    -13,  -16,    0, 24,  0,  0 }, {    -14,  -16,    0, 24,  0,  0 }, {    -15,  -17,    0, 24,  0,  0 }, {    -16,  -17,    0, 24,  0,  0 }, {    -17,  -17,    0, 24,  0,  0 },
    {    -18,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {    -29,  -17,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {    -29,  -17,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_945D3D, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     24,   16,    0,  0,  0,  0 }, {     21,   15,    0,  0,  0,  0 }, {     19,   15,    0,  0,  0,  0 },
    {     17,   15,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     13,   14,    0,  0,  0,  0 }, {     11,   14,    0,  0,  0,  0 }, {      9,   14,    0,  0,  0,  0 },
    {      7,   14,    0,  0,  0,  0 }, {      5,   14,    0,  0,  0,  0 }, {      4,   14,    0,  0,  0,  0 }, {      3,   13,    0,  0,  0,  0 }, {      2,   13,    0,  0,  0,  0 },
    {      1,   13,    0,  0,  0,  0 }, {      0,   13,    0,  0,  0,  0 }, {     -1,   13,    0,  0,  0,  0 }, {     -2,   13,    0,  0,  0,  0 }, {     -1,   13,    0,  0,  0,  0 },
    {      0,   13,    0,  0,  0,  0 }, {      1,   13,    0,  0,  0,  0 }, {      2,   13,    0,  0,  0,  0 }, {      3,   13,    0,  0,  0,  0 }, {      4,   13,    0,  0,  0,  0 },
    {      5,   13,    0,  0,  0,  0 }, {      6,   12,    0,  0,  0,  0 }, {      7,   12,    0,  0,  0,  0 }, {      8,   12,    0,  0,  0,  0 }, {      9,   12,    0,  0,  0,  0 },
    {     10,   12,    0,  0,  0,  0 }, {     11,   12,    0,  0,  0,  0 }, {     12,   12,    0,  0,  0,  0 }, {     13,   12,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     14,   12,    0,  0,  0,  0 }, {     12,   12,    0,  0,  0,  0 }, {      9,   12,    0,  0,  0,  0 }, {      6,   12,    0,  0,  0,  0 },
    {      3,   12,    0,  0,  0,  0 }, {      0,   12,    0,  0,  0,  0 }, {     -3,   12,    0,  0,  0,  0 }, {     -6,   12,    0,  0,  0,  0 }, {     -9,   12,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {    -12,   12,    0,  0,  0,  0 }, {    -15,   12,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {    -18,   16,    0,  0,  0,  0 },
    {    -21,   16,    0,  0,  0,  0 }, {    -24,   16,    0,  0,  0,  0 }, {    -25,   17,    0,  0,  0,  0 }, {    -26,   19,    0,  0,  0,  0 }, {    -27,   21,    0,  0,  0,  0 },
    {    -28,   23,    0,  0,  0,  0 }, {    -26,   25,    0,  0,  0,  0 }, {    -24,   27,    1,  0,  0,  0 }, {    -22,   29,    1,  0,  0,  0 }, {    -20,   30,    1,  0,  0,  0 },
    {    -18,   30,    1,  0,  0,  0 }, {    -16,   29,    2,  0,  0,  0 }, {    -14,   29,    2,  0,  0,  0 }, {    -14,   27,    2,  0,  0,  0 }, {    -13,   25,    2,  0,  0,  0 },
    {    -12,   23,    3,  0,  0,  0 }, {    -12,   21,    3,  0,  0,  0 }, {    -11,   19,    3,  0,  0,  0 }, {    -12,   17,    3,  0,  0,  0 }, {    -12,   15,    3,  0,  0,  0 },
    {    -12,   13,    3,  0,  0,  0 }, {    -13,   11,    3,  0,  0,  0 }, {    -13,    9,    3,  0,  0,  0 }, {    -13,    7,    3,  0,  0,  0 }, {    -14,    5,    3,  0,  0,  0 },
    {    -14,    3,    3,  0,  0,  0 }, {    -14,    2,    3,  0,  0,  0 }, {    -14,    1,    3,  0,  0,  0 }, {    -15,    0,    3,  0,  0,  0 }, {    -15,   -1,    3,  0,  0,  0 },
    {    -15,   -2,    3,  0,  0,  0 }, {    -15,   -3,    3,  0,  0,  0 }, {    -15,   -4,    3,  0,  0,  0 }, {    -15,   -6,    0,  0,  0,  0 }, {    -16,   -8,    0,  0,  0,  0 },
    {    -16,   -9,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {    -16,  -10,    0,  0,  0,  0 }, {    -16,  -11,    0,  0,  0,  0 },
    {    -16,  -12,    0,  0,  0,  0 }, {    -16,  -13,    0,  0,  0,  0 }, {    -17,  -14,    0,  0,  0,  0 }, {    -17,  -15,    0,  0,  0,  0 }, {    -17,  -16,    0,  0,  0,  0 },
    {    -17,  -17,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {    -17,  -28,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {    -17,  -28,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9489FB, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    7,    0,  8,  0,  0 }, {     15,   10,    0,  8,  0,  0 }, {     15,   12,    0,  8,  0,  0 },
    {     15,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     14,   18,    0,  8,  0,  0 }, {     14,   20,    0,  8,  0,  0 }, {     14,   22,    0,  8,  0,  0 },
    {     14,   24,    0,  8,  0,  0 }, {     14,   26,    0,  8,  0,  0 }, {     14,   27,    0,  8,  0,  0 }, {     13,   28,    0,  8,  0,  0 }, {     13,   29,    0,  8,  0,  0 },
    {     13,   30,    0,  8,  0,  0 }, {     13,   31,    0,  8,  0,  0 }, {     13,   32,    0,  8,  0,  0 }, {     13,   33,    0,  8,  0,  0 }, {     13,   32,    0,  8,  0,  0 },
    {     13,   31,    0,  8,  0,  0 }, {     13,   30,    0,  8,  0,  0 }, {     13,   29,    0,  8,  0,  0 }, {     13,   28,    0,  8,  0,  0 }, {     13,   27,    0,  8,  0,  0 },
    {     13,   26,    0,  8,  0,  0 }, {     12,   25,    0,  8,  0,  0 }, {     12,   24,    0,  8,  0,  0 }, {     12,   23,    0,  8,  0,  0 }, {     12,   22,    0,  8,  0,  0 },
    {     12,   21,    0,  8,  0,  0 }, {     12,   20,    0,  8,  0,  0 }, {     12,   19,    0,  8,  0,  0 }, {     12,   18,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     12,   17,    0,  8,  0,  0 }, {     12,   19,    0,  8,  0,  0 }, {     12,   22,    0,  8,  0,  0 }, {     12,   25,    0,  8,  0,  0 },
    {     12,   28,    0,  8,  0,  0 }, {     12,   31,    0,  8,  0,  0 }, {     12,   34,    0,  8,  0,  0 }, {     12,   37,    0,  8,  0,  0 }, {     12,   40,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     12,   43,    0,  8,  0,  0 }, {     12,   46,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     16,   49,    0,  8,  0,  0 },
    {     16,   52,    0,  8,  0,  0 }, {     16,   55,    0,  8,  0,  0 }, {     17,   56,    0,  8,  0,  0 }, {     19,   57,    0,  8,  0,  0 }, {     21,   58,    0,  8,  0,  0 },
    {     23,   59,    0,  8,  0,  0 }, {     25,   57,    0,  8,  0,  0 }, {     27,   55,    1,  8,  0,  0 }, {     29,   53,    1,  8,  0,  0 }, {     30,   51,    1,  8,  0,  0 },
    {     30,   49,    1,  8,  0,  0 }, {     29,   47,    2,  8,  0,  0 }, {     29,   45,    2,  8,  0,  0 }, {     27,   45,    2,  8,  0,  0 }, {     25,   44,    2,  8,  0,  0 },
    {     23,   43,    3,  8,  0,  0 }, {     21,   43,    3,  8,  0,  0 }, {     19,   42,    3,  8,  0,  0 }, {     17,   43,    3,  8,  0,  0 }, {     15,   43,    3,  8,  0,  0 },
    {     13,   43,    3,  8,  0,  0 }, {     11,   44,    3,  8,  0,  0 }, {      9,   44,    3,  8,  0,  0 }, {      7,   44,    3,  8,  0,  0 }, {      5,   45,    3,  8,  0,  0 },
    {      3,   45,    3,  8,  0,  0 }, {      2,   45,    3,  8,  0,  0 }, {      1,   45,    3,  8,  0,  0 }, {      0,   46,    3,  8,  0,  0 }, {     -1,   46,    3,  8,  0,  0 },
    {     -2,   46,    3,  8,  0,  0 }, {     -3,   46,    3,  8,  0,  0 }, {     -4,   46,    3,  8,  0,  0 }, {     -6,   46,    0,  8,  0,  0 }, {     -8,   47,    0,  8,  0,  0 },
    {     -9,   47,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {    -10,   47,    0,  8,  0,  0 }, {    -11,   47,    0,  8,  0,  0 },
    {    -12,   47,    0,  8,  0,  0 }, {    -13,   47,    0,  8,  0,  0 }, {    -14,   48,    0,  8,  0,  0 }, {    -15,   48,    0,  8,  0,  0 }, {    -16,   48,    0,  8,  0,  0 },
    {    -17,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {    -28,   48,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {    -28,   48,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94B6B9, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      7,   15,    0, 16,  0,  0 }, {     10,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 },
    {     14,   16,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     18,   17,    0, 16,  0,  0 }, {     20,   17,    0, 16,  0,  0 }, {     22,   17,    0, 16,  0,  0 },
    {     24,   17,    0, 16,  0,  0 }, {     26,   17,    0, 16,  0,  0 }, {     27,   17,    0, 16,  0,  0 }, {     28,   18,    0, 16,  0,  0 }, {     29,   18,    0, 16,  0,  0 },
    {     30,   18,    0, 16,  0,  0 }, {     31,   18,    0, 16,  0,  0 }, {     32,   18,    0, 16,  0,  0 }, {     33,   18,    0, 16,  0,  0 }, {     32,   18,    0, 16,  0,  0 },
    {     31,   18,    0, 16,  0,  0 }, {     30,   18,    0, 16,  0,  0 }, {     29,   18,    0, 16,  0,  0 }, {     28,   18,    0, 16,  0,  0 }, {     27,   18,    0, 16,  0,  0 },
    {     26,   18,    0, 16,  0,  0 }, {     25,   19,    0, 16,  0,  0 }, {     24,   19,    0, 16,  0,  0 }, {     23,   19,    0, 16,  0,  0 }, {     22,   19,    0, 16,  0,  0 },
    {     21,   19,    0, 16,  0,  0 }, {     20,   19,    0, 16,  0,  0 }, {     19,   19,    0, 16,  0,  0 }, {     18,   19,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     17,   19,    0, 16,  0,  0 }, {     19,   19,    0, 16,  0,  0 }, {     22,   19,    0, 16,  0,  0 }, {     25,   19,    0, 16,  0,  0 },
    {     28,   19,    0, 16,  0,  0 }, {     31,   19,    0, 16,  0,  0 }, {     34,   19,    0, 16,  0,  0 }, {     37,   19,    0, 16,  0,  0 }, {     40,   19,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     43,   19,    0, 16,  0,  0 }, {     46,   19,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     49,   15,    0, 16,  0,  0 },
    {     52,   15,    0, 16,  0,  0 }, {     55,   15,    0, 16,  0,  0 }, {     56,   14,    0, 16,  0,  0 }, {     57,   12,    0, 16,  0,  0 }, {     58,   10,    0, 16,  0,  0 },
    {     59,    8,    0, 16,  0,  0 }, {     57,    6,    0, 16,  0,  0 }, {     55,    4,    1, 16,  0,  0 }, {     53,    2,    1, 16,  0,  0 }, {     51,    1,    1, 16,  0,  0 },
    {     49,    1,    1, 16,  0,  0 }, {     47,    2,    2, 16,  0,  0 }, {     45,    2,    2, 16,  0,  0 }, {     45,    4,    2, 16,  0,  0 }, {     44,    6,    2, 16,  0,  0 },
    {     43,    8,    3, 16,  0,  0 }, {     43,   10,    3, 16,  0,  0 }, {     42,   12,    3, 16,  0,  0 }, {     43,   14,    3, 16,  0,  0 }, {     43,   16,    3, 16,  0,  0 },
    {     43,   18,    3, 16,  0,  0 }, {     44,   20,    3, 16,  0,  0 }, {     44,   22,    3, 16,  0,  0 }, {     44,   24,    3, 16,  0,  0 }, {     45,   26,    3, 16,  0,  0 },
    {     45,   28,    3, 16,  0,  0 }, {     45,   29,    3, 16,  0,  0 }, {     45,   30,    3, 16,  0,  0 }, {     46,   31,    3, 16,  0,  0 }, {     46,   32,    3, 16,  0,  0 },
    {     46,   33,    3, 16,  0,  0 }, {     46,   34,    3, 16,  0,  0 }, {     46,   35,    3, 16,  0,  0 }, {     46,   37,    0, 16,  0,  0 }, {     47,   39,    0, 16,  0,  0 },
    {     47,   40,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     47,   41,    0, 16,  0,  0 }, {     47,   42,    0, 16,  0,  0 },
    {     47,   43,    0, 16,  0,  0 }, {     47,   44,    0, 16,  0,  0 }, {     48,   45,    0, 16,  0,  0 }, {     48,   46,    0, 16,  0,  0 }, {     48,   47,    0, 16,  0,  0 },
    {     48,   48,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     48,   59,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     48,   59,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94E377, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   24,    0, 24,  0,  0 }, {     16,   21,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 },
    {     16,   17,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     17,   13,    0, 24,  0,  0 }, {     17,   11,    0, 24,  0,  0 }, {     17,    9,    0, 24,  0,  0 },
    {     17,    7,    0, 24,  0,  0 }, {     17,    5,    0, 24,  0,  0 }, {     17,    4,    0, 24,  0,  0 }, {     18,    3,    0, 24,  0,  0 }, {     18,    2,    0, 24,  0,  0 },
    {     18,    1,    0, 24,  0,  0 }, {     18,    0,    0, 24,  0,  0 }, {     18,   -1,    0, 24,  0,  0 }, {     18,   -2,    0, 24,  0,  0 }, {     18,   -1,    0, 24,  0,  0 },
    {     18,    0,    0, 24,  0,  0 }, {     18,    1,    0, 24,  0,  0 }, {     18,    2,    0, 24,  0,  0 }, {     18,    3,    0, 24,  0,  0 }, {     18,    4,    0, 24,  0,  0 },
    {     18,    5,    0, 24,  0,  0 }, {     19,    6,    0, 24,  0,  0 }, {     19,    7,    0, 24,  0,  0 }, {     19,    8,    0, 24,  0,  0 }, {     19,    9,    0, 24,  0,  0 },
    {     19,   10,    0, 24,  0,  0 }, {     19,   11,    0, 24,  0,  0 }, {     19,   12,    0, 24,  0,  0 }, {     19,   13,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     19,   14,    0, 24,  0,  0 }, {     19,   12,    0, 24,  0,  0 }, {     19,    9,    0, 24,  0,  0 }, {     19,    6,    0, 24,  0,  0 },
    {     19,    3,    0, 24,  0,  0 }, {     19,    0,    0, 24,  0,  0 }, {     19,   -3,    0, 24,  0,  0 }, {     19,   -6,    0, 24,  0,  0 }, {     19,   -9,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     19,  -12,    0, 24,  0,  0 }, {     19,  -15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     15,  -18,    0, 24,  0,  0 },
    {     15,  -21,    0, 24,  0,  0 }, {     15,  -24,    0, 24,  0,  0 }, {     14,  -25,    0, 24,  0,  0 }, {     12,  -26,    0, 24,  0,  0 }, {     10,  -27,    0, 24,  0,  0 },
    {      8,  -28,    0, 24,  0,  0 }, {      6,  -26,    0, 24,  0,  0 }, {      4,  -24,    1, 24,  0,  0 }, {      2,  -22,    1, 24,  0,  0 }, {      1,  -20,    1, 24,  0,  0 },
    {      1,  -18,    1, 24,  0,  0 }, {      2,  -16,    2, 24,  0,  0 }, {      2,  -14,    2, 24,  0,  0 }, {      4,  -14,    2, 24,  0,  0 }, {      6,  -13,    2, 24,  0,  0 },
    {      8,  -12,    3, 24,  0,  0 }, {     10,  -12,    3, 24,  0,  0 }, {     12,  -11,    3, 24,  0,  0 }, {     14,  -12,    3, 24,  0,  0 }, {     16,  -12,    3, 24,  0,  0 },
    {     18,  -12,    3, 24,  0,  0 }, {     20,  -13,    3, 24,  0,  0 }, {     22,  -13,    3, 24,  0,  0 }, {     24,  -13,    3, 24,  0,  0 }, {     26,  -14,    3, 24,  0,  0 },
    {     28,  -14,    3, 24,  0,  0 }, {     29,  -14,    3, 24,  0,  0 }, {     30,  -14,    3, 24,  0,  0 }, {     31,  -15,    3, 24,  0,  0 }, {     32,  -15,    3, 24,  0,  0 },
    {     33,  -15,    3, 24,  0,  0 }, {     34,  -15,    3, 24,  0,  0 }, {     35,  -15,    3, 24,  0,  0 }, {     37,  -15,    0, 24,  0,  0 }, {     39,  -16,    0, 24,  0,  0 },
    {     40,  -16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     41,  -16,    0, 24,  0,  0 }, {     42,  -16,    0, 24,  0,  0 },
    {     43,  -16,    0, 24,  0,  0 }, {     44,  -16,    0, 24,  0,  0 }, {     45,  -17,    0, 24,  0,  0 }, {     46,  -17,    0, 24,  0,  0 }, {     47,  -17,    0, 24,  0,  0 },
    {     48,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     59,  -17,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     59,  -17,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_939EAF, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 },
    {     18,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 },
    {      7,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 },
    {     -3,   16,    0,  0,  0,  0 }, {     -5,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, {     -9,   14,    0, 24,  0,  0 },
    {     -9,   12,    0, 24,  0,  0 }, {     -9,   11,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),
    {     -9,   11,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     -9,   11,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),
    {     -9,   11,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     -9,   12,    0,  0,  0,  0 }, {    -11,   12,    0,  0,  0,  0 }, {    -13,   12,    0,  0,  0,  0 },
    {    -15,   12,    0,  0,  0,  0 }, {    -17,   12,    0,  0,  0,  0 }, {    -19,   12,    0,  0,  0,  0 }, {    -21,   12,    0,  0,  0,  0 }, {    -23,   12,    0,  0,  0,  0 },
    {    -25,   12,    0,  0,  0,  0 }, {    -25,   14,    0,  8,  0,  0 }, {    -25,   16,    0,  8,  0,  0 }, {    -25,   18,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {    -25,   18,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {    -25,   18,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {    -25,   18,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {    -23,   18,    0, 16,  0,  0 },
    {    -21,   18,    0, 16,  0,  0 }, {    -19,   18,    0, 16,  0,  0 }, {    -17,   18,    0, 16,  0,  0 }, {    -15,   18,    0, 16,  0,  0 }, {    -15,   16,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {    -15,   16,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),
    {    -17,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -23,   16,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 },
    {    -27,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93C8A0, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 },
    {     16,   13,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 },
    {     16,   24,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 },
    {     16,   34,    0,  8,  0,  0 }, {     16,   36,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, {     14,   40,    0,  0,  0,  0 },
    {     12,   40,    0,  0,  0,  0 }, {     11,   40,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),
    {     11,   40,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     11,   40,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),
    {     11,   40,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     12,   40,    0,  8,  0,  0 }, {     12,   42,    0,  8,  0,  0 }, {     12,   44,    0,  8,  0,  0 },
    {     12,   46,    0,  8,  0,  0 }, {     12,   48,    0,  8,  0,  0 }, {     12,   50,    0,  8,  0,  0 }, {     12,   52,    0,  8,  0,  0 }, {     12,   54,    0,  8,  0,  0 },
    {     12,   56,    0,  8,  0,  0 }, {     14,   56,    0, 16,  0,  0 }, {     16,   56,    0, 16,  0,  0 }, {     18,   56,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     18,   56,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     18,   56,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     18,   56,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     18,   54,    0, 24,  0,  0 },
    {     18,   52,    0, 24,  0,  0 }, {     18,   50,    0, 24,  0,  0 }, {     18,   48,    0, 24,  0,  0 }, {     18,   46,    0, 24,  0,  0 }, {     16,   46,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     16,   46,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),
    {     16,   48,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   54,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 },
    {     16,   58,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93F291, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 },
    {     13,   15,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 }, {     20,   15,    0, 16,  0,  0 }, {     22,   15,    0, 16,  0,  0 },
    {     24,   15,    0, 16,  0,  0 }, {     26,   15,    0, 16,  0,  0 }, {     28,   15,    0, 16,  0,  0 }, {     30,   15,    0, 16,  0,  0 }, {     32,   15,    0, 16,  0,  0 },
    {     34,   15,    0, 16,  0,  0 }, {     36,   15,    0, 16,  0,  0 }, {     38,   15,    0, 16,  0,  0 }, {     40,   15,    0, 16,  0,  0 }, {     40,   17,    0,  8,  0,  0 },
    {     40,   19,    0,  8,  0,  0 }, {     40,   20,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),
    {     40,   20,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     40,   20,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),
    {     40,   20,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     40,   19,    0, 16,  0,  0 }, {     42,   19,    0, 16,  0,  0 }, {     44,   19,    0, 16,  0,  0 },
    {     46,   19,    0, 16,  0,  0 }, {     48,   19,    0, 16,  0,  0 }, {     50,   19,    0, 16,  0,  0 }, {     52,   19,    0, 16,  0,  0 }, {     54,   19,    0, 16,  0,  0 },
    {     56,   19,    0, 16,  0,  0 }, {     56,   17,    0, 24,  0,  0 }, {     56,   15,    0, 24,  0,  0 }, {     56,   13,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     56,   13,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     56,   13,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     56,   13,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     54,   13,    0,  0,  0,  0 },
    {     52,   13,    0,  0,  0,  0 }, {     50,   13,    0,  0,  0,  0 }, {     48,   13,    0,  0,  0,  0 }, {     46,   13,    0,  0,  0,  0 }, {     46,   15,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     46,   15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),
    {     48,   15,    0, 16,  0,  0 }, {     50,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 }, {     54,   15,    0, 16,  0,  0 }, {     56,   15,    0, 16,  0,  0 },
    {     58,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_941C82, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 },
    {     15,   18,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 }, {     15,   11,    0, 24,  0,  0 }, {     15,    9,    0, 24,  0,  0 },
    {     15,    7,    0, 24,  0,  0 }, {     15,    5,    0, 24,  0,  0 }, {     15,    3,    0, 24,  0,  0 }, {     15,    1,    0, 24,  0,  0 }, {     15,   -1,    0, 24,  0,  0 },
    {     15,   -3,    0, 24,  0,  0 }, {     15,   -5,    0, 24,  0,  0 }, {     15,   -7,    0, 24,  0,  0 }, {     15,   -9,    0, 24,  0,  0 }, {     17,   -9,    0, 16,  0,  0 },
    {     19,   -9,    0, 16,  0,  0 }, {     20,   -9,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),
    {     20,   -9,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     20,   -9,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),
    {     20,   -9,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     19,   -9,    0, 24,  0,  0 }, {     19,  -11,    0, 24,  0,  0 }, {     19,  -13,    0, 24,  0,  0 },
    {     19,  -15,    0, 24,  0,  0 }, {     19,  -17,    0, 24,  0,  0 }, {     19,  -19,    0, 24,  0,  0 }, {     19,  -21,    0, 24,  0,  0 }, {     19,  -23,    0, 24,  0,  0 },
    {     19,  -25,    0, 24,  0,  0 }, {     17,  -25,    0,  0,  0,  0 }, {     15,  -25,    0,  0,  0,  0 }, {     13,  -25,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     13,  -25,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     13,  -25,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     13,  -25,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     13,  -23,    0,  8,  0,  0 },
    {     13,  -21,    0,  8,  0,  0 }, {     13,  -19,    0,  8,  0,  0 }, {     13,  -17,    0,  8,  0,  0 }, {     13,  -15,    0,  8,  0,  0 }, {     15,  -15,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     15,  -15,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),
    {     15,  -17,    0, 24,  0,  0 }, {     15,  -19,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 }, {     15,  -23,    0, 24,  0,  0 }, {     15,  -25,    0, 24,  0,  0 },
    {     15,  -27,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93ADA3, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 },
    {     17,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 },
    {      7,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 },
    {     -3,   16,    0,  0,  0,  0 }, {     -5,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, {    -11,   16,    0,  0,  0,  0 },
    {    -13,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 }, {    -19,   14,    0, 24,  0,  0 },
    {    -19,   12,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {    -19,   12,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {    -19,   12,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {    -19,   12,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {    -19,   14,    0,  8,  0,  0 }, {    -19,   16,    0,  8,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -23,   16,    0,  0,  0,  0 },
    {    -25,   16,    0,  0,  0,  0 }, {    -27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {    -27,   16,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -27,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93D794, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 },
    {     16,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 },
    {     16,   24,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 },
    {     16,   34,    0,  8,  0,  0 }, {     16,   36,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, {     16,   42,    0,  8,  0,  0 },
    {     16,   44,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 }, {     14,   50,    0,  0,  0,  0 },
    {     12,   50,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     12,   50,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     12,   50,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     12,   50,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     14,   50,    0, 16,  0,  0 }, {     16,   50,    0, 16,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   54,    0,  8,  0,  0 },
    {     16,   56,    0,  8,  0,  0 }, {     16,   58,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     16,   58,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     16,   58,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_940185, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 },
    {     14,   15,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 }, {     20,   15,    0, 16,  0,  0 }, {     22,   15,    0, 16,  0,  0 },
    {     24,   15,    0, 16,  0,  0 }, {     26,   15,    0, 16,  0,  0 }, {     28,   15,    0, 16,  0,  0 }, {     30,   15,    0, 16,  0,  0 }, {     32,   15,    0, 16,  0,  0 },
    {     34,   15,    0, 16,  0,  0 }, {     36,   15,    0, 16,  0,  0 }, {     38,   15,    0, 16,  0,  0 }, {     40,   15,    0, 16,  0,  0 }, {     42,   15,    0, 16,  0,  0 },
    {     44,   15,    0, 16,  0,  0 }, {     46,   15,    0, 16,  0,  0 }, {     48,   15,    0, 16,  0,  0 }, {     50,   15,    0, 16,  0,  0 }, {     50,   17,    0,  8,  0,  0 },
    {     50,   19,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     50,   19,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     50,   19,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     50,   19,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     50,   17,    0, 24,  0,  0 }, {     50,   15,    0, 24,  0,  0 }, {     52,   15,    0, 16,  0,  0 }, {     54,   15,    0, 16,  0,  0 },
    {     56,   15,    0, 16,  0,  0 }, {     58,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     58,   15,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     58,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_942B76, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 },
    {     15,   17,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 }, {     15,   11,    0, 24,  0,  0 }, {     15,    9,    0, 24,  0,  0 },
    {     15,    7,    0, 24,  0,  0 }, {     15,    5,    0, 24,  0,  0 }, {     15,    3,    0, 24,  0,  0 }, {     15,    1,    0, 24,  0,  0 }, {     15,   -1,    0, 24,  0,  0 },
    {     15,   -3,    0, 24,  0,  0 }, {     15,   -5,    0, 24,  0,  0 }, {     15,   -7,    0, 24,  0,  0 }, {     15,   -9,    0, 24,  0,  0 }, {     15,  -11,    0, 24,  0,  0 },
    {     15,  -13,    0, 24,  0,  0 }, {     15,  -15,    0, 24,  0,  0 }, {     15,  -17,    0, 24,  0,  0 }, {     15,  -19,    0, 24,  0,  0 }, {     17,  -19,    0, 16,  0,  0 },
    {     19,  -19,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     19,  -19,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     19,  -19,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     19,  -19,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     17,  -19,    0,  0,  0,  0 }, {     15,  -19,    0,  0,  0,  0 }, {     15,  -21,    0, 24,  0,  0 }, {     15,  -23,    0, 24,  0,  0 },
    {     15,  -25,    0, 24,  0,  0 }, {     15,  -27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),              {     15,  -27,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     15,  -27,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93BAB1, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 },
    {     20,   14,    0, 24,  0,  0 }, {     20,   12,    0, 24,  0,  0 }, {     20,   11,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),
    MINI_GOLF_STATE(Unk3),              {     20,   11,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     20,   11,    0, 24,  0,  0 },
    MINI_GOLF_STATE(Unk2),              {     20,   11,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     19,   12,    0,  8,  0,  0 }, {     19,   14,    0,  8,  0,  0 },
    {     19,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 },
    {     11,   16,    0,  0,  0,  0 }, {      9,   16,    5,  0,  0,  0 }, {      7,   16,    5,  0,  0,  0 }, {      5,   16,    5,  0,  0,  0 }, {      3,   16,    5,  0,  0,  0 },
    {      1,   16,    5,  0,  0,  0 }, {     -1,   16,    5,  0,  0,  0 }, {     -3,   16,    5,  0,  0,  0 }, {     -5,   16,    5,  0,  0,  0 }, {     -7,   16,    5,  0,  0,  0 },
    {     -9,   16,    0,  0,  0,  0 }, {    -11,   16,    0,  0,  0,  0 }, {    -13,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 },
    {    -19,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -23,   16,    0,  0,  0,  0 }, {    -23,   18,    0,  8,  0,  0 }, {    -23,   20,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {    -23,   21,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {    -23,   21,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {    -23,   21,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -23,   20,    0, 24,  0,  0 }, {    -23,   18,    0, 24,  0,  0 }, {    -23,   16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {    -23,   16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -23,   16,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 },
    {    -27,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93E4A2, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  8,  0,  0 },
    {     14,   11,    0,  0,  0,  0 }, {     12,   11,    0,  0,  0,  0 }, {     11,   11,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),
    MINI_GOLF_STATE(Unk3),              {     11,   11,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     11,   11,    0,  0,  0,  0 },
    MINI_GOLF_STATE(Unk2),              {     11,   11,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     12,   12,    0, 16,  0,  0 }, {     14,   12,    0, 16,  0,  0 },
    {     16,   12,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 },
    {     16,   20,    0,  8,  0,  0 }, {     16,   22,    5,  8,  0,  0 }, {     16,   24,    5,  8,  0,  0 }, {     16,   26,    5,  8,  0,  0 }, {     16,   28,    5,  8,  0,  0 },
    {     16,   30,    5,  8,  0,  0 }, {     16,   32,    5,  8,  0,  0 }, {     16,   34,    5,  8,  0,  0 }, {     16,   36,    5,  8,  0,  0 }, {     16,   38,    5,  8,  0,  0 },
    {     16,   40,    0,  8,  0,  0 }, {     16,   42,    0,  8,  0,  0 }, {     16,   44,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 },
    {     16,   50,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   54,    0,  8,  0,  0 }, {     18,   54,    0, 16,  0,  0 }, {     20,   54,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     21,   54,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     21,   54,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     21,   54,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     20,   54,    0,  0,  0,  0 }, {     18,   54,    0,  0,  0,  0 }, {     16,   54,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     16,   54,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     16,   54,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 },
    {     16,   58,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_940E93, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     11,   15,    0, 16,  0,  0 },
    {     11,   17,    0,  8,  0,  0 }, {     11,   19,    0,  8,  0,  0 }, {     11,   20,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),
    MINI_GOLF_STATE(Unk3),              {     11,   20,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     11,   20,    0,  8,  0,  0 },
    MINI_GOLF_STATE(Unk2),              {     11,   20,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     12,   19,    0, 24,  0,  0 }, {     12,   17,    0, 24,  0,  0 },
    {     12,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 }, {     14,   15,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     18,   15,    0, 16,  0,  0 },
    {     20,   15,    0, 16,  0,  0 }, {     22,   15,    5, 16,  0,  0 }, {     24,   15,    5, 16,  0,  0 }, {     26,   15,    5, 16,  0,  0 }, {     28,   15,    5, 16,  0,  0 },
    {     30,   15,    5, 16,  0,  0 }, {     32,   15,    5, 16,  0,  0 }, {     34,   15,    5, 16,  0,  0 }, {     36,   15,    5, 16,  0,  0 }, {     38,   15,    5, 16,  0,  0 },
    {     40,   15,    0, 16,  0,  0 }, {     42,   15,    0, 16,  0,  0 }, {     44,   15,    0, 16,  0,  0 }, {     46,   15,    0, 16,  0,  0 }, {     48,   15,    0, 16,  0,  0 },
    {     50,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 }, {     54,   15,    0, 16,  0,  0 }, {     54,   13,    0, 24,  0,  0 }, {     54,   11,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     54,   10,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     54,   10,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     54,   10,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     54,   11,    0,  8,  0,  0 }, {     54,   13,    0,  8,  0,  0 }, {     54,   15,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     54,   15,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     54,   15,    0, 16,  0,  0 }, {     56,   15,    0, 16,  0,  0 },
    {     58,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_943884, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   20,    0, 24,  0,  0 },
    {     17,   20,    0, 16,  0,  0 }, {     19,   20,    0, 16,  0,  0 }, {     20,   20,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),
    MINI_GOLF_STATE(Unk3),              {     20,   20,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     20,   20,    0, 16,  0,  0 },
    MINI_GOLF_STATE(Unk2),              {     20,   20,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     19,   19,    0,  0,  0,  0 }, {     17,   19,    0,  0,  0,  0 },
    {     15,   19,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 }, {     15,   17,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     15,   13,    0, 24,  0,  0 },
    {     15,   11,    0, 24,  0,  0 }, {     15,    9,    5, 24,  0,  0 }, {     15,    7,    5, 24,  0,  0 }, {     15,    5,    5, 24,  0,  0 }, {     15,    3,    5, 24,  0,  0 },
    {     15,    1,    5, 24,  0,  0 }, {     15,   -1,    5, 24,  0,  0 }, {     15,   -3,    5, 24,  0,  0 }, {     15,   -5,    5, 24,  0,  0 }, {     15,   -7,    5, 24,  0,  0 },
    {     15,   -9,    0, 24,  0,  0 }, {     15,  -11,    0, 24,  0,  0 }, {     15,  -13,    0, 24,  0,  0 }, {     15,  -15,    0, 24,  0,  0 }, {     15,  -17,    0, 24,  0,  0 },
    {     15,  -19,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 }, {     15,  -23,    0, 24,  0,  0 }, {     13,  -23,    0,  0,  0,  0 }, {     11,  -23,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     10,  -23,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     10,  -23,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     10,  -23,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     11,  -23,    0, 16,  0,  0 }, {     13,  -23,    0, 16,  0,  0 }, {     15,  -23,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),    MINI_GOLF_STATE(Unk5),
    {     15,  -23,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     15,  -23,    0, 24,  0,  0 }, {     15,  -25,    0, 24,  0,  0 },
    {     15,  -27,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_944AA3, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 },
    {     17,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     15,   18,    0,  8,  0,  0 }, {     15,   20,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   20,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     15,   20,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   20,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   20,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     15,   20,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   20,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     13,   20,    0,  0,  0,  0 },
    {     11,   20,    0,  0,  0,  0 }, {      9,   20,    0,  0,  0,  0 }, {      7,   20,    0,  0,  0,  0 }, {      5,   20,    0,  0,  0,  0 }, {      3,   20,    0,  0,  0,  0 },
    {      1,   20,    0,  0,  0,  0 }, {     -1,   20,    0,  0,  0,  0 }, {     -3,   20,    0,  0,  0,  0 }, {     -3,   22,    0,  8,  0,  0 }, {     -3,   24,    0,  8,  0,  0 },
    {     -3,   26,    0,  8,  0,  0 }, {     -3,   28,    0,  8,  0,  0 }, {     -3,   30,    0,  8,  0,  0 }, {     -3,   32,    0,  8,  0,  0 }, {     -3,   34,    0,  8,  0,  0 },
    {     -3,   36,    0,  8,  0,  0 }, {     -3,   38,    0,  8,  0,  0 }, {     -3,   40,    0,  8,  0,  0 }, {     -3,   42,    0,  8,  0,  0 }, {     -5,   42,    0,  0,  0,  0 },
    {     -7,   42,    0,  0,  0,  0 }, {     -9,   42,    0,  0,  0,  0 }, {    -11,   42,    0,  0,  0,  0 }, {    -13,   42,    0,  0,  0,  0 }, {    -15,   42,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {    -16,   41,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {    -16,   41,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {    -16,   41,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -17,   43,    0,  8,  0,  0 }, {    -17,   45,    0,  8,  0,  0 }, {    -17,   47,    0,  8,  0,  0 }, {    -17,   49,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {    -17,   49,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -17,   48,    0,  8,  0,  0 },
    {    -17,   50,    0,  8,  0,  0 }, {    -17,   52,    0,  8,  0,  0 }, {    -17,   54,    0,  8,  0,  0 }, {    -17,   56,    0,  8,  0,  0 }, {    -17,   58,    0,  8,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {    -17,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_947761, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 },
    {     16,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     18,   16,    0, 16,  0,  0 }, {     20,   16,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     20,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     20,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     20,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     20,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     20,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     20,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     20,   18,    0,  8,  0,  0 },
    {     20,   20,    0,  8,  0,  0 }, {     20,   22,    0,  8,  0,  0 }, {     20,   24,    0,  8,  0,  0 }, {     20,   26,    0,  8,  0,  0 }, {     20,   28,    0,  8,  0,  0 },
    {     20,   30,    0,  8,  0,  0 }, {     20,   32,    0,  8,  0,  0 }, {     20,   34,    0,  8,  0,  0 }, {     22,   34,    0, 16,  0,  0 }, {     24,   34,    0, 16,  0,  0 },
    {     26,   34,    0, 16,  0,  0 }, {     28,   34,    0, 16,  0,  0 }, {     30,   34,    0, 16,  0,  0 }, {     32,   34,    0, 16,  0,  0 }, {     34,   34,    0, 16,  0,  0 },
    {     36,   34,    0, 16,  0,  0 }, {     38,   34,    0, 16,  0,  0 }, {     40,   34,    0, 16,  0,  0 }, {     42,   34,    0, 16,  0,  0 }, {     42,   36,    0,  8,  0,  0 },
    {     42,   38,    0,  8,  0,  0 }, {     42,   40,    0,  8,  0,  0 }, {     42,   42,    0,  8,  0,  0 }, {     42,   44,    0,  8,  0,  0 }, {     42,   46,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     41,   47,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     41,   47,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     41,   47,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     43,   48,    0, 16,  0,  0 }, {     45,   48,    0, 16,  0,  0 }, {     47,   48,    0, 16,  0,  0 }, {     49,   48,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {     49,   48,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     48,   48,    0, 16,  0,  0 },
    {     50,   48,    0, 16,  0,  0 }, {     52,   48,    0, 16,  0,  0 }, {     54,   48,    0, 16,  0,  0 }, {     56,   48,    0, 16,  0,  0 }, {     58,   48,    0, 16,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {     60,   48,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94A41F, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 },
    {     14,   15,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     16,   13,    0, 24,  0,  0 }, {     16,   11,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,   11,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     16,   11,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,   11,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,   11,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     16,   11,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,   11,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     18,   11,    0, 16,  0,  0 },
    {     20,   11,    0, 16,  0,  0 }, {     22,   11,    0, 16,  0,  0 }, {     24,   11,    0, 16,  0,  0 }, {     26,   11,    0, 16,  0,  0 }, {     28,   11,    0, 16,  0,  0 },
    {     30,   11,    0, 16,  0,  0 }, {     32,   11,    0, 16,  0,  0 }, {     34,   11,    0, 16,  0,  0 }, {     34,    9,    0, 24,  0,  0 }, {     34,    7,    0, 24,  0,  0 },
    {     34,    5,    0, 24,  0,  0 }, {     34,    3,    0, 24,  0,  0 }, {     34,    1,    0, 24,  0,  0 }, {     34,   -1,    0, 24,  0,  0 }, {     34,   -3,    0, 24,  0,  0 },
    {     34,   -5,    0, 24,  0,  0 }, {     34,   -7,    0, 24,  0,  0 }, {     34,   -9,    0, 24,  0,  0 }, {     34,  -11,    0, 24,  0,  0 }, {     36,  -11,    0, 16,  0,  0 },
    {     38,  -11,    0, 16,  0,  0 }, {     40,  -11,    0, 16,  0,  0 }, {     42,  -11,    0, 16,  0,  0 }, {     44,  -11,    0, 16,  0,  0 }, {     46,  -11,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     47,  -10,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     47,  -10,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     47,  -10,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     48,  -12,    0, 24,  0,  0 }, {     48,  -14,    0, 24,  0,  0 }, {     48,  -16,    0, 24,  0,  0 }, {     48,  -18,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {     48,  -18,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     48,  -17,    0, 24,  0,  0 },
    {     48,  -19,    0, 24,  0,  0 }, {     48,  -21,    0, 24,  0,  0 }, {     48,  -23,    0, 24,  0,  0 }, {     48,  -25,    0, 24,  0,  0 }, {     48,  -27,    0, 24,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {     48,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94D0DD, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 },
    {     15,   17,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     13,   15,    0,  0,  0,  0 }, {     11,   15,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     11,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     11,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     11,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     11,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     11,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     11,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     11,   13,    0, 24,  0,  0 },
    {     11,   11,    0, 24,  0,  0 }, {     11,    9,    0, 24,  0,  0 }, {     11,    7,    0, 24,  0,  0 }, {     11,    5,    0, 24,  0,  0 }, {     11,    3,    0, 24,  0,  0 },
    {     11,    1,    0, 24,  0,  0 }, {     11,   -1,    0, 24,  0,  0 }, {     11,   -3,    0, 24,  0,  0 }, {      9,   -3,    0,  0,  0,  0 }, {      7,   -3,    0,  0,  0,  0 },
    {      5,   -3,    0,  0,  0,  0 }, {      3,   -3,    0,  0,  0,  0 }, {      1,   -3,    0,  0,  0,  0 }, {     -1,   -3,    0,  0,  0,  0 }, {     -3,   -3,    0,  0,  0,  0 },
    {     -5,   -3,    0,  0,  0,  0 }, {     -7,   -3,    0,  0,  0,  0 }, {     -9,   -3,    0,  0,  0,  0 }, {    -11,   -3,    0,  0,  0,  0 }, {    -11,   -5,    0, 24,  0,  0 },
    {    -11,   -7,    0, 24,  0,  0 }, {    -11,   -9,    0, 24,  0,  0 }, {    -11,  -11,    0, 24,  0,  0 }, {    -11,  -13,    0, 24,  0,  0 }, {    -11,  -15,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {    -10,  -16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {    -10,  -16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {    -10,  -16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -12,  -17,    0,  0,  0,  0 }, {    -14,  -17,    0,  0,  0,  0 }, {    -16,  -17,    0,  0,  0,  0 }, {    -18,  -17,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {    -18,  -17,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -17,  -17,    0,  0,  0,  0 },
    {    -19,  -17,    0,  0,  0,  0 }, {    -21,  -17,    0,  0,  0,  0 }, {    -23,  -17,    0,  0,  0,  0 }, {    -25,  -17,    0,  0,  0,  0 }, {    -27,  -17,    0,  0,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {    -29,  -17,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_946102, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     27,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     27,   16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     27,   16,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     25,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 },
    {     17,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     15,   14,    0, 24,  0,  0 }, {     15,   12,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   12,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     15,   12,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   12,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   12,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     15,   12,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   12,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     13,   12,    0,  0,  0,  0 },
    {     11,   12,    0,  0,  0,  0 }, {      9,   12,    0,  0,  0,  0 }, {      7,   12,    0,  0,  0,  0 }, {      5,   12,    0,  0,  0,  0 }, {      3,   12,    0,  0,  0,  0 },
    {      1,   12,    0,  0,  0,  0 }, {     -1,   12,    0,  0,  0,  0 }, {     -3,   12,    0,  0,  0,  0 }, {     -3,   10,    0, 24,  0,  0 }, {     -3,    8,    0, 24,  0,  0 },
    {     -3,    6,    0, 24,  0,  0 }, {     -3,    4,    0, 24,  0,  0 }, {     -3,    2,    0, 24,  0,  0 }, {     -3,    0,    0, 24,  0,  0 }, {     -3,   -2,    0, 24,  0,  0 },
    {     -3,   -4,    0, 24,  0,  0 }, {     -3,   -6,    0, 24,  0,  0 }, {     -3,   -8,    0, 24,  0,  0 }, {     -3,  -10,    0, 24,  0,  0 }, {     -5,  -10,    0,  0,  0,  0 },
    {     -7,  -10,    0,  0,  0,  0 }, {     -9,  -10,    0,  0,  0,  0 }, {    -11,  -10,    0,  0,  0,  0 }, {    -13,  -10,    0,  0,  0,  0 }, {    -15,  -10,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {    -16,   -9,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {    -16,   -9,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {    -16,   -9,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -17,  -11,    0, 24,  0,  0 }, {    -17,  -13,    0, 24,  0,  0 }, {    -17,  -15,    0, 24,  0,  0 }, {    -17,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {    -17,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -17,  -16,    0, 24,  0,  0 },
    {    -17,  -18,    0, 24,  0,  0 }, {    -17,  -20,    0, 24,  0,  0 }, {    -17,  -22,    0, 24,  0,  0 }, {    -17,  -24,    0, 24,  0,  0 }, {    -17,  -26,    0, 24,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {    -17,  -28,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_948DC0, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     16,    4,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     16,    4,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    4,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     16,    6,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 },
    {     16,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     12,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     12,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     12,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     12,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     12,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     12,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     12,   18,    0,  8,  0,  0 },
    {     12,   20,    0,  8,  0,  0 }, {     12,   22,    0,  8,  0,  0 }, {     12,   24,    0,  8,  0,  0 }, {     12,   26,    0,  8,  0,  0 }, {     12,   28,    0,  8,  0,  0 },
    {     12,   30,    0,  8,  0,  0 }, {     12,   32,    0,  8,  0,  0 }, {     12,   34,    0,  8,  0,  0 }, {     10,   34,    0,  0,  0,  0 }, {      8,   34,    0,  0,  0,  0 },
    {      6,   34,    0,  0,  0,  0 }, {      4,   34,    0,  0,  0,  0 }, {      2,   34,    0,  0,  0,  0 }, {      0,   34,    0,  0,  0,  0 }, {     -2,   34,    0,  0,  0,  0 },
    {     -4,   34,    0,  0,  0,  0 }, {     -6,   34,    0,  0,  0,  0 }, {     -8,   34,    0,  0,  0,  0 }, {    -10,   34,    0,  0,  0,  0 }, {    -10,   36,    0,  8,  0,  0 },
    {    -10,   38,    0,  8,  0,  0 }, {    -10,   40,    0,  8,  0,  0 }, {    -10,   42,    0,  8,  0,  0 }, {    -10,   44,    0,  8,  0,  0 }, {    -10,   46,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     -9,   47,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     -9,   47,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     -9,   47,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -11,   48,    0,  0,  0,  0 }, {    -13,   48,    0,  0,  0,  0 }, {    -15,   48,    0,  0,  0,  0 }, {    -17,   48,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {    -17,   48,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {    -16,   48,    0,  0,  0,  0 },
    {    -18,   48,    0,  0,  0,  0 }, {    -20,   48,    0,  0,  0,  0 }, {    -22,   48,    0,  0,  0,  0 }, {    -24,   48,    0,  0,  0,  0 }, {    -26,   48,    0,  0,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {    -28,   48,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94BA7E, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, {      2,   15,    0, 16,  0,  0 }, {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {      4,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {      4,   15,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      4,   15,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {      6,   15,    0, 16,  0,  0 }, {      8,   15,    0, 16,  0,  0 }, {     10,   15,    0, 16,  0,  0 }, {     12,   15,    0, 16,  0,  0 },
    {     14,   15,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     16,   17,    0,  8,  0,  0 }, {     16,   19,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,   19,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     16,   19,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,   19,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     16,   19,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     16,   19,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,   19,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     18,   19,    0, 16,  0,  0 },
    {     20,   19,    0, 16,  0,  0 }, {     22,   19,    0, 16,  0,  0 }, {     24,   19,    0, 16,  0,  0 }, {     26,   19,    0, 16,  0,  0 }, {     28,   19,    0, 16,  0,  0 },
    {     30,   19,    0, 16,  0,  0 }, {     32,   19,    0, 16,  0,  0 }, {     34,   19,    0, 16,  0,  0 }, {     34,   21,    0,  8,  0,  0 }, {     34,   23,    0,  8,  0,  0 },
    {     34,   25,    0,  8,  0,  0 }, {     34,   27,    0,  8,  0,  0 }, {     34,   29,    0,  8,  0,  0 }, {     34,   31,    0,  8,  0,  0 }, {     34,   33,    0,  8,  0,  0 },
    {     34,   35,    0,  8,  0,  0 }, {     34,   37,    0,  8,  0,  0 }, {     34,   39,    0,  8,  0,  0 }, {     34,   41,    0,  8,  0,  0 }, {     36,   41,    0, 16,  0,  0 },
    {     38,   41,    0, 16,  0,  0 }, {     40,   41,    0, 16,  0,  0 }, {     42,   41,    0, 16,  0,  0 }, {     44,   41,    0, 16,  0,  0 }, {     46,   41,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     47,   40,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     47,   40,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     47,   40,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     48,   42,    0,  8,  0,  0 }, {     48,   44,    0,  8,  0,  0 }, {     48,   46,    0,  8,  0,  0 }, {     48,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {     48,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     48,   47,    0,  8,  0,  0 },
    {     48,   49,    0,  8,  0,  0 }, {     48,   51,    0,  8,  0,  0 }, {     48,   53,    0,  8,  0,  0 }, {     48,   55,    0,  8,  0,  0 }, {     48,   57,    0,  8,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {     48,   59,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94E73C, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, {     15,   29,    0, 24,  0,  0 }, {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallUp),   MINI_GOLF_STATE(Unk5),
    {     15,   27,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),              {     15,   27,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   27,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     15,   25,    0, 24,  0,  0 }, {     15,   23,    0, 24,  0,  0 }, {     15,   21,    0, 24,  0,  0 }, {     15,   19,    0, 24,  0,  0 },
    {     15,   17,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     17,   15,    0, 16,  0,  0 }, {     19,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     19,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     19,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     19,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_ANIMATION(SwingLeft),
    MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     19,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),      MINI_GOLF_STATE(Unk5),
    {     19,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     19,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     19,   13,    0, 24,  0,  0 },
    {     19,   11,    0, 24,  0,  0 }, {     19,    9,    0, 24,  0,  0 }, {     19,    7,    0, 24,  0,  0 }, {     19,    5,    0, 24,  0,  0 }, {     19,    3,    0, 24,  0,  0 },
    {     19,    1,    0, 24,  0,  0 }, {     19,   -1,    0, 24,  0,  0 }, {     19,   -3,    0, 24,  0,  0 }, {     21,   -3,    0, 16,  0,  0 }, {     23,   -3,    0, 16,  0,  0 },
    {     25,   -3,    0, 16,  0,  0 }, {     27,   -3,    0, 16,  0,  0 }, {     29,   -3,    0, 16,  0,  0 }, {     31,   -3,    0, 16,  0,  0 }, {     33,   -3,    0, 16,  0,  0 },
    {     35,   -3,    0, 16,  0,  0 }, {     37,   -3,    0, 16,  0,  0 }, {     39,   -3,    0, 16,  0,  0 }, {     41,   -3,    0, 16,  0,  0 }, {     41,   -5,    0, 24,  0,  0 },
    {     41,   -7,    0, 24,  0,  0 }, {     41,   -9,    0, 24,  0,  0 }, {     41,  -11,    0, 24,  0,  0 }, {     41,  -13,    0, 24,  0,  0 }, {     41,  -15,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(SwingLeft),     MINI_GOLF_STATE(Unk5),              MINI_GOLF_STATE(Unk3),              {     40,  -16,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PuttLeft),
    MINI_GOLF_STATE(Unk5),              {     40,  -16,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     40,  -16,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     42,  -17,    0, 16,  0,  0 }, {     44,  -17,    0, 16,  0,  0 }, {     46,  -17,    0, 16,  0,  0 }, {     48,  -17,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PickupBall),
    MINI_GOLF_STATE(Unk5),              {     48,  -17,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk6),              {     47,  -17,    0, 16,  0,  0 },
    {     49,  -17,    0, 16,  0,  0 }, {     51,  -17,    0, 16,  0,  0 }, {     53,  -17,    0, 16,  0,  0 }, {     55,  -17,    0, 16,  0,  0 }, {     57,  -17,    0, 16,  0,  0 },
    MINI_GOLF_STATE(Unk3),              {     59,  -17,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93A1F6, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     25,   16,    0,  0,  0,  0 }, {     23,   15,    0,  0,  0,  0 }, {     21,   15,    0,  0,  0,  0 },
    {     19,   14,    0,  0,  0,  0 }, {     17,   13,    0,  0,  0,  0 }, {     15,   13,    0,  0,  0,  0 }, {     14,   13,    0,  0,  0,  0 }, {     13,   12,    0,  0,  0,  0 },
    {     12,   12,    0,  0,  0,  0 }, {     11,   12,    0,  0,  0,  0 }, {     10,   11,    0,  0,  0,  0 }, {      9,   11,    0,  0,  0,  0 }, {      8,   11,    0,  0,  0,  0 },
    {      7,   10,    0,  0,  0,  0 }, {      6,   10,    0,  0,  0,  0 }, {      5,   10,    0,  0,  0,  0 }, {      4,    9,    0,  0,  0,  0 }, {      3,    9,    0,  0,  0,  0 },
    {      2,    9,    0,  0,  0,  0 }, {      1,    8,    0,  0,  0,  0 }, {      0,    8,    0,  0,  0,  0 }, {      0,    8,    0,  0,  0,  0 }, {     -1,    9,    0,  0,  0,  0 },
    {     -2,    9,    0,  0,  0,  0 }, {     -3,    9,    0,  0,  0,  0 }, {     -4,   10,    0,  0,  0,  0 }, {     -5,   10,    0,  0,  0,  0 }, {     -6,   10,    0,  0,  0,  0 },
    {     -7,   11,    0,  0,  0,  0 }, {     -8,   11,    0,  0,  0,  0 }, {     -9,   11,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {    -10,   11,    0,  0,  0,  0 }, {    -11,   11,    0,  0,  0,  0 }, {    -13,   12,    0,  0,  0,  0 }, {    -14,   13,    0,  0,  0,  0 }, {    -15,   13,    0,  0,  0,  0 },
    {    -16,   14,    0,  0,  0,  0 }, {    -17,   14,    0,  0,  0,  0 }, {    -18,   15,    0,  0,  0,  0 }, {    -19,   15,    0,  0,  0,  0 }, {    -20,   16,    0,  0,  0,  0 },
    {    -21,   16,    0,  0,  0,  0 }, {    -22,   17,    0,  0,  0,  0 }, {    -23,   17,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {    -24,   18,    0,  0,  0,  0 }, {    -23,   18,    0,  0,  0,  0 }, {    -22,   18,    0,  0,  0,  0 }, {    -21,   18,    0,  0,  0,  0 }, {    -20,   18,    0,  0,  0,  0 },
    {    -19,   18,    0,  0,  0,  0 }, {    -18,   18,    0,  0,  0,  0 }, {    -17,   18,    0,  0,  0,  0 }, {    -16,   18,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    MINI_GOLF_STATE(Unk2),              {    -29,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93CBE7, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    6,    0,  8,  0,  0 }, {     15,    8,    0,  8,  0,  0 }, {     15,   10,    0,  8,  0,  0 },
    {     14,   12,    0,  8,  0,  0 }, {     13,   14,    0,  8,  0,  0 }, {     13,   16,    0,  8,  0,  0 }, {     13,   17,    0,  8,  0,  0 }, {     12,   18,    0,  8,  0,  0 },
    {     12,   19,    0,  8,  0,  0 }, {     12,   20,    0,  8,  0,  0 }, {     11,   21,    0,  8,  0,  0 }, {     11,   22,    0,  8,  0,  0 }, {     11,   23,    0,  8,  0,  0 },
    {     10,   24,    0,  8,  0,  0 }, {     10,   25,    0,  8,  0,  0 }, {     10,   26,    0,  8,  0,  0 }, {      9,   27,    0,  8,  0,  0 }, {      9,   28,    0,  8,  0,  0 },
    {      9,   29,    0,  8,  0,  0 }, {      8,   30,    0,  8,  0,  0 }, {      8,   31,    0,  8,  0,  0 }, {      8,   31,    0,  8,  0,  0 }, {      9,   32,    0,  8,  0,  0 },
    {      9,   33,    0,  8,  0,  0 }, {      9,   34,    0,  8,  0,  0 }, {     10,   35,    0,  8,  0,  0 }, {     10,   36,    0,  8,  0,  0 }, {     10,   37,    0,  8,  0,  0 },
    {     11,   38,    0,  8,  0,  0 }, {     11,   39,    0,  8,  0,  0 }, {     11,   40,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     11,   41,    0,  8,  0,  0 }, {     11,   42,    0,  8,  0,  0 }, {     12,   44,    0,  8,  0,  0 }, {     13,   45,    0,  8,  0,  0 }, {     13,   46,    0,  8,  0,  0 },
    {     14,   47,    0,  8,  0,  0 }, {     14,   48,    0,  8,  0,  0 }, {     15,   49,    0,  8,  0,  0 }, {     15,   50,    0,  8,  0,  0 }, {     16,   51,    0,  8,  0,  0 },
    {     16,   52,    0,  8,  0,  0 }, {     17,   53,    0,  8,  0,  0 }, {     17,   54,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     18,   55,    0,  8,  0,  0 }, {     18,   54,    0,  8,  0,  0 }, {     18,   53,    0,  8,  0,  0 }, {     18,   52,    0,  8,  0,  0 }, {     18,   51,    0,  8,  0,  0 },
    {     18,   50,    0,  8,  0,  0 }, {     18,   49,    0,  8,  0,  0 }, {     18,   48,    0,  8,  0,  0 }, {     18,   47,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    MINI_GOLF_STATE(Unk2),              {     16,   60,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93F5D8, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      6,   15,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 }, {     10,   16,    0, 16,  0,  0 },
    {     12,   17,    0, 16,  0,  0 }, {     14,   18,    0, 16,  0,  0 }, {     16,   18,    0, 16,  0,  0 }, {     17,   18,    0, 16,  0,  0 }, {     18,   19,    0, 16,  0,  0 },
    {     19,   19,    0, 16,  0,  0 }, {     20,   19,    0, 16,  0,  0 }, {     21,   20,    0, 16,  0,  0 }, {     22,   20,    0, 16,  0,  0 }, {     23,   20,    0, 16,  0,  0 },
    {     24,   21,    0, 16,  0,  0 }, {     25,   21,    0, 16,  0,  0 }, {     26,   21,    0, 16,  0,  0 }, {     27,   22,    0, 16,  0,  0 }, {     28,   22,    0, 16,  0,  0 },
    {     29,   22,    0, 16,  0,  0 }, {     30,   23,    0, 16,  0,  0 }, {     31,   23,    0, 16,  0,  0 }, {     31,   23,    0, 16,  0,  0 }, {     32,   22,    0, 16,  0,  0 },
    {     33,   22,    0, 16,  0,  0 }, {     34,   22,    0, 16,  0,  0 }, {     35,   21,    0, 16,  0,  0 }, {     36,   21,    0, 16,  0,  0 }, {     37,   21,    0, 16,  0,  0 },
    {     38,   20,    0, 16,  0,  0 }, {     39,   20,    0, 16,  0,  0 }, {     40,   20,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     41,   20,    0, 16,  0,  0 }, {     42,   20,    0, 16,  0,  0 }, {     44,   19,    0, 16,  0,  0 }, {     45,   18,    0, 16,  0,  0 }, {     46,   18,    0, 16,  0,  0 },
    {     47,   17,    0, 16,  0,  0 }, {     48,   17,    0, 16,  0,  0 }, {     49,   16,    0, 16,  0,  0 }, {     50,   16,    0, 16,  0,  0 }, {     51,   15,    0, 16,  0,  0 },
    {     52,   15,    0, 16,  0,  0 }, {     53,   14,    0, 16,  0,  0 }, {     54,   14,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     55,   13,    0, 16,  0,  0 }, {     54,   13,    0, 16,  0,  0 }, {     53,   13,    0, 16,  0,  0 }, {     52,   13,    0, 16,  0,  0 }, {     51,   13,    0, 16,  0,  0 },
    {     50,   13,    0, 16,  0,  0 }, {     49,   13,    0, 16,  0,  0 }, {     48,   13,    0, 16,  0,  0 }, {     47,   13,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    MINI_GOLF_STATE(Unk2),              {     60,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_941FC9, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   25,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 }, {     16,   21,    0, 24,  0,  0 },
    {     17,   19,    0, 24,  0,  0 }, {     18,   17,    0, 24,  0,  0 }, {     18,   15,    0, 24,  0,  0 }, {     18,   14,    0, 24,  0,  0 }, {     19,   13,    0, 24,  0,  0 },
    {     19,   12,    0, 24,  0,  0 }, {     19,   11,    0, 24,  0,  0 }, {     20,   10,    0, 24,  0,  0 }, {     20,    9,    0, 24,  0,  0 }, {     20,    8,    0, 24,  0,  0 },
    {     21,    7,    0, 24,  0,  0 }, {     21,    6,    0, 24,  0,  0 }, {     21,    5,    0, 24,  0,  0 }, {     22,    4,    0, 24,  0,  0 }, {     22,    3,    0, 24,  0,  0 },
    {     22,    2,    0, 24,  0,  0 }, {     23,    1,    0, 24,  0,  0 }, {     23,    0,    0, 24,  0,  0 }, {     23,    0,    0, 24,  0,  0 }, {     22,   -1,    0, 24,  0,  0 },
    {     22,   -2,    0, 24,  0,  0 }, {     22,   -3,    0, 24,  0,  0 }, {     21,   -4,    0, 24,  0,  0 }, {     21,   -5,    0, 24,  0,  0 }, {     21,   -6,    0, 24,  0,  0 },
    {     20,   -7,    0, 24,  0,  0 }, {     20,   -8,    0, 24,  0,  0 }, {     20,   -9,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     20,  -10,    0, 24,  0,  0 }, {     20,  -11,    0, 24,  0,  0 }, {     19,  -13,    0, 24,  0,  0 }, {     18,  -14,    0, 24,  0,  0 }, {     18,  -15,    0, 24,  0,  0 },
    {     17,  -16,    0, 24,  0,  0 }, {     17,  -17,    0, 24,  0,  0 }, {     16,  -18,    0, 24,  0,  0 }, {     16,  -19,    0, 24,  0,  0 }, {     15,  -20,    0, 24,  0,  0 },
    {     15,  -21,    0, 24,  0,  0 }, {     14,  -22,    0, 24,  0,  0 }, {     14,  -23,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     13,  -24,    0, 24,  0,  0 }, {     13,  -23,    0, 24,  0,  0 }, {     13,  -22,    0, 24,  0,  0 }, {     13,  -21,    0, 24,  0,  0 }, {     13,  -20,    0, 24,  0,  0 },
    {     13,  -19,    0, 24,  0,  0 }, {     13,  -18,    0, 24,  0,  0 }, {     13,  -17,    0, 24,  0,  0 }, {     13,  -16,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    MINI_GOLF_STATE(Unk2),              {     15,  -29,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93B01B, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     25,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 }, {     19,   15,    0,  0,  0,  0 },
    {     16,   15,    0,  0,  0,  0 }, {     13,   14,    0,  0,  0,  0 }, {     10,   14,    0,  0,  0,  0 }, {      7,   13,    0,  0,  0,  0 }, {      4,   13,    0,  0,  0,  0 },
    {      1,   12,    0,  0,  0,  0 }, {     -2,   12,    0,  0,  0,  0 }, {     -2,   15,    0,  0,  0,  0 }, {     -2,   18,    0,  0,  0,  0 }, {     -2,   21,    0,  0,  0,  0 },
    {     -2,   24,    0,  0,  0,  0 }, {     -2,   26,    0,  0,  0,  0 }, {     -4,   26,    0,  0,  0,  0 }, {     -6,   26,    0,  0,  0,  0 }, {     -8,   26,    0,  0,  0,  0 },
    {    -10,   26,    0,  0,  0,  0 }, {    -11,   25,    0,  0,  0,  0 }, {    -11,   23,    0,  0,  0,  0 }, {    -11,   21,    0,  0,  0,  0 }, {    -11,   19,    0,  0,  0,  0 },
    {    -10,   17,    0,  0,  0,  0 }, {    -10,   15,    0,  0,  0,  0 }, {    -10,   13,    0,  0,  0,  0 }, {    -12,   13,    0,  0,  0,  0 }, {    -14,   13,    0,  0,  0,  0 },
    {    -16,   13,    0,  0,  0,  0 }, {    -18,   13,    0,  0,  0,  0 }, {    -20,   14,    0,  0,  0,  0 }, {    -22,   14,    0,  0,  0,  0 }, {    -23,   14,    0,  0,  0,  0 },
    {    -24,   14,    0,  0,  0,  0 }, {    -25,   14,    0,  0,  0,  0 }, {    -26,   14,    0,  0,  0,  0 }, {    -27,   14,    0,  0,  0,  0 }, {    -28,   14,    0,  0,  0,  0 },
    {    -29,   14,    0,  0,  0,  0 }, {    -30,   14,    0,  0,  0,  0 }, {    -31,   14,    0,  0,  0,  0 }, {    -30,   14,    0,  0,  0,  0 }, {    -29,   14,    0,  0,  0,  0 },
    {    -28,   14,    0,  0,  0,  0 }, {    -27,   13,    0,  0,  0,  0 }, {    -26,   13,    0,  0,  0,  0 }, {    -25,   13,    0,  0,  0,  0 }, {    -24,   13,    0,  0,  0,  0 },
    {    -23,   13,    0,  0,  0,  0 }, {    -22,   12,    0,  0,  0,  0 }, {    -21,   12,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {    -20,   12,    0,  0,  0,  0 }, {    -21,   12,    0,  0,  0,  0 }, {    -22,   13,    0,  0,  0,  0 }, {    -23,   14,    0,  0,  0,  0 }, {    -24,   14,    0,  0,  0,  0 },
    {    -25,   15,    0,  0,  0,  0 }, {    -26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {    -29,   16,    0,  0,  0,  0 },
    MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93DA0C, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    6,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 }, {     15,   12,    0,  8,  0,  0 },
    {     15,   15,    0,  8,  0,  0 }, {     14,   18,    0,  8,  0,  0 }, {     14,   21,    0,  8,  0,  0 }, {     13,   24,    0,  8,  0,  0 }, {     13,   27,    0,  8,  0,  0 },
    {     12,   30,    0,  8,  0,  0 }, {     12,   33,    0,  8,  0,  0 }, {     15,   33,    0,  8,  0,  0 }, {     18,   33,    0,  8,  0,  0 }, {     21,   33,    0,  8,  0,  0 },
    {     24,   33,    0,  8,  0,  0 }, {     26,   33,    0,  8,  0,  0 }, {     26,   35,    0,  8,  0,  0 }, {     26,   37,    0,  8,  0,  0 }, {     26,   39,    0,  8,  0,  0 },
    {     26,   41,    0,  8,  0,  0 }, {     25,   42,    0,  8,  0,  0 }, {     23,   42,    0,  8,  0,  0 }, {     21,   42,    0,  8,  0,  0 }, {     19,   42,    0,  8,  0,  0 },
    {     17,   41,    0,  8,  0,  0 }, {     15,   41,    0,  8,  0,  0 }, {     13,   41,    0,  8,  0,  0 }, {     13,   43,    0,  8,  0,  0 }, {     13,   45,    0,  8,  0,  0 },
    {     13,   47,    0,  8,  0,  0 }, {     13,   49,    0,  8,  0,  0 }, {     14,   51,    0,  8,  0,  0 }, {     14,   53,    0,  8,  0,  0 }, {     14,   54,    0,  8,  0,  0 },
    {     14,   55,    0,  8,  0,  0 }, {     14,   56,    0,  8,  0,  0 }, {     14,   57,    0,  8,  0,  0 }, {     14,   58,    0,  8,  0,  0 }, {     14,   59,    0,  8,  0,  0 },
    {     14,   60,    0,  8,  0,  0 }, {     14,   61,    0,  8,  0,  0 }, {     14,   62,    0,  8,  0,  0 }, {     14,   61,    0,  8,  0,  0 }, {     14,   60,    0,  8,  0,  0 },
    {     14,   59,    0,  8,  0,  0 }, {     13,   58,    0,  8,  0,  0 }, {     13,   57,    0,  8,  0,  0 }, {     13,   56,    0,  8,  0,  0 }, {     13,   55,    0,  8,  0,  0 },
    {     13,   54,    0,  8,  0,  0 }, {     12,   53,    0,  8,  0,  0 }, {     12,   52,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     12,   51,    0,  8,  0,  0 }, {     12,   52,    0,  8,  0,  0 }, {     13,   53,    0,  8,  0,  0 }, {     14,   54,    0,  8,  0,  0 }, {     14,   55,    0,  8,  0,  0 },
    {     15,   56,    0,  8,  0,  0 }, {     16,   57,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     16,   60,    0,  8,  0,  0 },
    MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9403FD, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      6,   15,    0, 16,  0,  0 }, {      9,   15,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 },
    {     15,   16,    0, 16,  0,  0 }, {     18,   17,    0, 16,  0,  0 }, {     21,   17,    0, 16,  0,  0 }, {     24,   18,    0, 16,  0,  0 }, {     27,   18,    0, 16,  0,  0 },
    {     30,   19,    0, 16,  0,  0 }, {     33,   19,    0, 16,  0,  0 }, {     33,   16,    0, 16,  0,  0 }, {     33,   13,    0, 16,  0,  0 }, {     33,   10,    0, 16,  0,  0 },
    {     33,    7,    0, 16,  0,  0 }, {     33,    5,    0, 16,  0,  0 }, {     35,    5,    0, 16,  0,  0 }, {     37,    5,    0, 16,  0,  0 }, {     39,    5,    0, 16,  0,  0 },
    {     41,    5,    0, 16,  0,  0 }, {     42,    6,    0, 16,  0,  0 }, {     42,    8,    0, 16,  0,  0 }, {     42,   10,    0, 16,  0,  0 }, {     42,   12,    0, 16,  0,  0 },
    {     41,   14,    0, 16,  0,  0 }, {     41,   16,    0, 16,  0,  0 }, {     41,   18,    0, 16,  0,  0 }, {     43,   18,    0, 16,  0,  0 }, {     45,   18,    0, 16,  0,  0 },
    {     47,   18,    0, 16,  0,  0 }, {     49,   18,    0, 16,  0,  0 }, {     51,   17,    0, 16,  0,  0 }, {     53,   17,    0, 16,  0,  0 }, {     54,   17,    0, 16,  0,  0 },
    {     55,   17,    0, 16,  0,  0 }, {     56,   17,    0, 16,  0,  0 }, {     57,   17,    0, 16,  0,  0 }, {     58,   17,    0, 16,  0,  0 }, {     59,   17,    0, 16,  0,  0 },
    {     60,   17,    0, 16,  0,  0 }, {     61,   17,    0, 16,  0,  0 }, {     62,   17,    0, 16,  0,  0 }, {     61,   17,    0, 16,  0,  0 }, {     60,   17,    0, 16,  0,  0 },
    {     59,   17,    0, 16,  0,  0 }, {     58,   18,    0, 16,  0,  0 }, {     57,   18,    0, 16,  0,  0 }, {     56,   18,    0, 16,  0,  0 }, {     55,   18,    0, 16,  0,  0 },
    {     54,   18,    0, 16,  0,  0 }, {     53,   19,    0, 16,  0,  0 }, {     52,   19,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     51,   19,    0, 16,  0,  0 }, {     52,   19,    0, 16,  0,  0 }, {     53,   18,    0, 16,  0,  0 }, {     54,   17,    0, 16,  0,  0 }, {     55,   17,    0, 16,  0,  0 },
    {     56,   16,    0, 16,  0,  0 }, {     57,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     60,   15,    0, 16,  0,  0 },
    MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_942DEE, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   25,    0, 24,  0,  0 }, {     15,   22,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 },
    {     16,   16,    0, 24,  0,  0 }, {     17,   13,    0, 24,  0,  0 }, {     17,   10,    0, 24,  0,  0 }, {     18,    7,    0, 24,  0,  0 }, {     18,    4,    0, 24,  0,  0 },
    {     19,    1,    0, 24,  0,  0 }, {     19,   -2,    0, 24,  0,  0 }, {     16,   -2,    0, 24,  0,  0 }, {     13,   -2,    0, 24,  0,  0 }, {     10,   -2,    0, 24,  0,  0 },
    {      7,   -2,    0, 24,  0,  0 }, {      5,   -2,    0, 24,  0,  0 }, {      5,   -4,    0, 24,  0,  0 }, {      5,   -6,    0, 24,  0,  0 }, {      5,   -8,    0, 24,  0,  0 },
    {      5,  -10,    0, 24,  0,  0 }, {      6,  -11,    0, 24,  0,  0 }, {      8,  -11,    0, 24,  0,  0 }, {     10,  -11,    0, 24,  0,  0 }, {     12,  -11,    0, 24,  0,  0 },
    {     14,  -10,    0, 24,  0,  0 }, {     16,  -10,    0, 24,  0,  0 }, {     18,  -10,    0, 24,  0,  0 }, {     18,  -12,    0, 24,  0,  0 }, {     18,  -14,    0, 24,  0,  0 },
    {     18,  -16,    0, 24,  0,  0 }, {     18,  -18,    0, 24,  0,  0 }, {     17,  -20,    0, 24,  0,  0 }, {     17,  -22,    0, 24,  0,  0 }, {     17,  -23,    0, 24,  0,  0 },
    {     17,  -24,    0, 24,  0,  0 }, {     17,  -25,    0, 24,  0,  0 }, {     17,  -26,    0, 24,  0,  0 }, {     17,  -27,    0, 24,  0,  0 }, {     17,  -28,    0, 24,  0,  0 },
    {     17,  -29,    0, 24,  0,  0 }, {     17,  -30,    0, 24,  0,  0 }, {     17,  -31,    0, 24,  0,  0 }, {     17,  -30,    0, 24,  0,  0 }, {     17,  -29,    0, 24,  0,  0 },
    {     17,  -28,    0, 24,  0,  0 }, {     18,  -27,    0, 24,  0,  0 }, {     18,  -26,    0, 24,  0,  0 }, {     18,  -25,    0, 24,  0,  0 }, {     18,  -24,    0, 24,  0,  0 },
    {     18,  -23,    0, 24,  0,  0 }, {     19,  -22,    0, 24,  0,  0 }, {     19,  -21,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     19,  -20,    0, 24,  0,  0 }, {     19,  -21,    0, 24,  0,  0 }, {     18,  -22,    0, 24,  0,  0 }, {     17,  -23,    0, 24,  0,  0 }, {     17,  -24,    0, 24,  0,  0 },
    {     16,  -25,    0, 24,  0,  0 }, {     15,  -26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     15,  -29,    0, 24,  0,  0 },
    MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93BDCB, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     24,   16,    0,  0,  0,  0 }, {     21,   15,    0,  0,  0,  0 }, {     18,   14,    0,  0,  0,  0 },
    {     16,   14,    0,  0,  0,  0 }, {     14,   14,    0,  0,  0,  0 }, {     12,   13,    0,  0,  0,  0 }, {     10,   13,    0,  0,  0,  0 }, {      9,   13,    0,  0,  0,  0 },
    {     11,   12,    0,  0,  0,  0 }, {     12,   12,    0,  0,  0,  0 }, {     13,   12,    0,  0,  0,  0 }, {     14,   12,    0,  0,  0,  0 }, {     15,   12,    0,  0,  0,  0 },
    {     16,   12,    0,  0,  0,  0 }, {     17,   11,    0,  0,  0,  0 }, {     18,   11,    0,  0,  0,  0 }, {     19,   11,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     20,   11,    0,  0,  0,  0 }, {     18,   11,    0,  0,  0,  0 }, {     16,   11,    0,  0,  0,  0 }, {     14,   11,    0,  0,  0,  0 },
    {     12,   11,    0,  0,  0,  0 }, {     10,   11,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {      7,   12,    0,  0,  0,  0 }, {      5,   13,    0,  0,  0,  0 },
    {      3,   14,    0,  0,  0,  0 }, {      1,   15,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -3,   17,    0,  0,  0,  0 }, {     -5,   18,    0,  0,  0,  0 },
    {     -7,   20,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     -9,   20,    0,  0,  0,  0 }, {    -11,   20,    0,  0,  0,  0 }, {    -13,   20,    0,  0,  0,  0 },
    {    -15,   20,    0,  0,  0,  0 }, {    -17,   20,    0,  0,  0,  0 }, {    -19,   20,    0,  0,  0,  0 }, {    -21,   20,    0,  0,  0,  0 }, {    -22,   20,    0,  0,  0,  0 },
    {    -23,   20,    0,  0,  0,  0 }, {    -24,   20,    0,  0,  0,  0 }, {    -25,   20,    0,  0,  0,  0 }, {    -26,   20,    0,  0,  0,  0 }, {    -27,   20,    0,  0,  0,  0 },
    {    -28,   20,    0,  0,  0,  0 }, {    -29,   20,    0,  0,  0,  0 }, {    -30,   20,    0,  0,  0,  0 }, {    -29,   20,    0,  0,  0,  0 }, {    -28,   20,    0,  0,  0,  0 },
    {    -27,   20,    0,  0,  0,  0 }, {    -26,   20,    0,  0,  0,  0 }, {    -25,   20,    0,  0,  0,  0 }, {    -24,   20,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {    -23,   20,    0,  0,  0,  0 }, {    -23,   19,    0,  0,  0,  0 }, {    -23,   18,    0,  0,  0,  0 }, {    -23,   17,    0,  0,  0,  0 },
    {    -23,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {    -29,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {    -29,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_93E7BC, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    7,    0,  8,  0,  0 }, {     15,   10,    0,  8,  0,  0 }, {     14,   13,    0,  8,  0,  0 },
    {     14,   15,    0,  8,  0,  0 }, {     14,   17,    0,  8,  0,  0 }, {     13,   19,    0,  8,  0,  0 }, {     13,   21,    0,  8,  0,  0 }, {     13,   22,    0,  8,  0,  0 },
    {     12,   20,    0,  8,  0,  0 }, {     12,   19,    0,  8,  0,  0 }, {     12,   18,    0,  8,  0,  0 }, {     12,   17,    0,  8,  0,  0 }, {     12,   16,    0,  8,  0,  0 },
    {     12,   15,    0,  8,  0,  0 }, {     11,   14,    0,  8,  0,  0 }, {     11,   13,    0,  8,  0,  0 }, {     11,   12,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     11,   11,    0,  8,  0,  0 }, {     11,   13,    0,  8,  0,  0 }, {     11,   15,    0,  8,  0,  0 }, {     11,   17,    0,  8,  0,  0 },
    {     11,   19,    0,  8,  0,  0 }, {     11,   21,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     12,   24,    0,  8,  0,  0 }, {     13,   26,    0,  8,  0,  0 },
    {     14,   28,    0,  8,  0,  0 }, {     15,   30,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     17,   34,    0,  8,  0,  0 }, {     18,   36,    0,  8,  0,  0 },
    {     20,   38,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     20,   40,    0,  8,  0,  0 }, {     20,   42,    0,  8,  0,  0 }, {     20,   44,    0,  8,  0,  0 },
    {     20,   46,    0,  8,  0,  0 }, {     20,   48,    0,  8,  0,  0 }, {     20,   50,    0,  8,  0,  0 }, {     20,   52,    0,  8,  0,  0 }, {     20,   53,    0,  8,  0,  0 },
    {     20,   54,    0,  8,  0,  0 }, {     20,   55,    0,  8,  0,  0 }, {     20,   56,    0,  8,  0,  0 }, {     20,   57,    0,  8,  0,  0 }, {     20,   58,    0,  8,  0,  0 },
    {     20,   59,    0,  8,  0,  0 }, {     20,   60,    0,  8,  0,  0 }, {     20,   61,    0,  8,  0,  0 }, {     20,   60,    0,  8,  0,  0 }, {     20,   59,    0,  8,  0,  0 },
    {     20,   58,    0,  8,  0,  0 }, {     20,   57,    0,  8,  0,  0 }, {     20,   56,    0,  8,  0,  0 }, {     20,   55,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     20,   54,    0,  8,  0,  0 }, {     19,   54,    0,  8,  0,  0 }, {     18,   54,    0,  8,  0,  0 }, {     17,   54,    0,  8,  0,  0 },
    {     16,   54,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     16,   60,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     16,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9411AD, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      7,   15,    0, 16,  0,  0 }, {     10,   16,    0, 16,  0,  0 }, {     13,   17,    0, 16,  0,  0 },
    {     15,   17,    0, 16,  0,  0 }, {     17,   17,    0, 16,  0,  0 }, {     19,   18,    0, 16,  0,  0 }, {     21,   18,    0, 16,  0,  0 }, {     22,   18,    0, 16,  0,  0 },
    {     20,   19,    0, 16,  0,  0 }, {     19,   19,    0, 16,  0,  0 }, {     18,   19,    0, 16,  0,  0 }, {     17,   19,    0, 16,  0,  0 }, {     16,   19,    0, 16,  0,  0 },
    {     15,   19,    0, 16,  0,  0 }, {     14,   20,    0, 16,  0,  0 }, {     13,   20,    0, 16,  0,  0 }, {     12,   20,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     11,   20,    0, 16,  0,  0 }, {     13,   20,    0, 16,  0,  0 }, {     15,   20,    0, 16,  0,  0 }, {     17,   20,    0, 16,  0,  0 },
    {     19,   20,    0, 16,  0,  0 }, {     21,   20,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     24,   19,    0, 16,  0,  0 }, {     26,   18,    0, 16,  0,  0 },
    {     28,   17,    0, 16,  0,  0 }, {     30,   16,    0, 16,  0,  0 }, {     32,   15,    0, 16,  0,  0 }, {     34,   14,    0, 16,  0,  0 }, {     36,   13,    0, 16,  0,  0 },
    {     38,   11,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     40,   11,    0, 16,  0,  0 }, {     42,   11,    0, 16,  0,  0 }, {     44,   11,    0, 16,  0,  0 },
    {     46,   11,    0, 16,  0,  0 }, {     48,   11,    0, 16,  0,  0 }, {     50,   11,    0, 16,  0,  0 }, {     52,   11,    0, 16,  0,  0 }, {     53,   11,    0, 16,  0,  0 },
    {     54,   11,    0, 16,  0,  0 }, {     55,   11,    0, 16,  0,  0 }, {     56,   11,    0, 16,  0,  0 }, {     57,   11,    0, 16,  0,  0 }, {     58,   11,    0, 16,  0,  0 },
    {     59,   11,    0, 16,  0,  0 }, {     60,   11,    0, 16,  0,  0 }, {     61,   11,    0, 16,  0,  0 }, {     60,   11,    0, 16,  0,  0 }, {     59,   11,    0, 16,  0,  0 },
    {     58,   11,    0, 16,  0,  0 }, {     57,   11,    0, 16,  0,  0 }, {     56,   11,    0, 16,  0,  0 }, {     55,   11,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     54,   11,    0, 16,  0,  0 }, {     54,   12,    0, 16,  0,  0 }, {     54,   13,    0, 16,  0,  0 }, {     54,   14,    0, 16,  0,  0 },
    {     54,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     60,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     60,   15,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_943B9E, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   24,    0, 24,  0,  0 }, {     16,   21,    0, 24,  0,  0 }, {     17,   18,    0, 24,  0,  0 },
    {     17,   16,    0, 24,  0,  0 }, {     17,   14,    0, 24,  0,  0 }, {     18,   12,    0, 24,  0,  0 }, {     18,   10,    0, 24,  0,  0 }, {     18,    9,    0, 24,  0,  0 },
    {     19,   11,    0, 24,  0,  0 }, {     19,   12,    0, 24,  0,  0 }, {     19,   13,    0, 24,  0,  0 }, {     19,   14,    0, 24,  0,  0 }, {     19,   15,    0, 24,  0,  0 },
    {     19,   16,    0, 24,  0,  0 }, {     20,   17,    0, 24,  0,  0 }, {     20,   18,    0, 24,  0,  0 }, {     20,   19,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     20,   20,    0, 24,  0,  0 }, {     20,   18,    0, 24,  0,  0 }, {     20,   16,    0, 24,  0,  0 }, {     20,   14,    0, 24,  0,  0 },
    {     20,   12,    0, 24,  0,  0 }, {     20,   10,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     19,    7,    0, 24,  0,  0 }, {     18,    5,    0, 24,  0,  0 },
    {     17,    3,    0, 24,  0,  0 }, {     16,    1,    0, 24,  0,  0 }, {     15,   -1,    0, 24,  0,  0 }, {     14,   -3,    0, 24,  0,  0 }, {     13,   -5,    0, 24,  0,  0 },
    {     11,   -7,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     11,   -9,    0, 24,  0,  0 }, {     11,  -11,    0, 24,  0,  0 }, {     11,  -13,    0, 24,  0,  0 },
    {     11,  -15,    0, 24,  0,  0 }, {     11,  -17,    0, 24,  0,  0 }, {     11,  -19,    0, 24,  0,  0 }, {     11,  -21,    0, 24,  0,  0 }, {     11,  -22,    0, 24,  0,  0 },
    {     11,  -23,    0, 24,  0,  0 }, {     11,  -24,    0, 24,  0,  0 }, {     11,  -25,    0, 24,  0,  0 }, {     11,  -26,    0, 24,  0,  0 }, {     11,  -27,    0, 24,  0,  0 },
    {     11,  -28,    0, 24,  0,  0 }, {     11,  -29,    0, 24,  0,  0 }, {     11,  -30,    0, 24,  0,  0 }, {     11,  -29,    0, 24,  0,  0 }, {     11,  -28,    0, 24,  0,  0 },
    {     11,  -27,    0, 24,  0,  0 }, {     11,  -26,    0, 24,  0,  0 }, {     11,  -25,    0, 24,  0,  0 }, {     11,  -24,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     11,  -23,    0, 24,  0,  0 }, {     12,  -23,    0, 24,  0,  0 }, {     13,  -23,    0, 24,  0,  0 }, {     14,  -23,    0, 24,  0,  0 },
    {     15,  -23,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),              {     15,  -29,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk6),
    MINI_GOLF_STATE(Unk3),              {     15,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_944E3B, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     24,   16,    0,  0,  0,  0 }, {     21,   17,    0,  0,  0,  0 }, {     19,   17,    0,  0,  0,  0 },
    {     17,   17,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     13,   18,    0,  0,  0,  0 }, {     11,   18,    0,  0,  0,  0 }, {      9,   18,    0,  0,  0,  0 },
    {      7,   18,    0,  0,  0,  0 }, {      5,   18,    0,  0,  0,  0 }, {      4,   18,    0,  0,  0,  0 }, {      3,   19,    0,  0,  0,  0 }, {      2,   19,    0,  0,  0,  0 },
    {      1,   19,    0,  0,  0,  0 }, {      0,   19,    0,  0,  0,  0 }, {     -1,   19,    0,  0,  0,  0 }, {     -2,   19,    0,  0,  0,  0 }, {     -1,   19,    0,  0,  0,  0 },
    {      0,   19,    0,  0,  0,  0 }, {      1,   19,    0,  0,  0,  0 }, {      2,   19,    0,  0,  0,  0 }, {      3,   19,    0,  0,  0,  0 }, {      4,   19,    0,  0,  0,  0 },
    {      5,   19,    0,  0,  0,  0 }, {      6,   20,    0,  0,  0,  0 }, {      7,   20,    0,  0,  0,  0 }, {      8,   20,    0,  0,  0,  0 }, {      9,   20,    0,  0,  0,  0 },
    {     10,   20,    0,  0,  0,  0 }, {     11,   20,    0,  0,  0,  0 }, {     12,   20,    0,  0,  0,  0 }, {     13,   20,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     14,   20,    0,  0,  0,  0 }, {     12,   20,    0,  0,  0,  0 }, {      9,   20,    0,  0,  0,  0 }, {      6,   20,    0,  0,  0,  0 },
    {      3,   20,    0,  0,  0,  0 }, {      0,   20,    0,  0,  0,  0 }, {     -3,   20,    0,  0,  0,  0 }, {     -6,   20,    0,  0,  0,  0 }, {     -9,   20,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {    -12,   20,    0,  0,  0,  0 }, {    -15,   20,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {    -18,   16,    0,  0,  0,  0 },
    {    -21,   16,    0,  0,  0,  0 }, {    -24,   16,    0,  0,  0,  0 }, {    -25,   15,    0,  0,  0,  0 }, {    -26,   13,    0,  0,  0,  0 }, {    -27,   11,    0,  0,  0,  0 },
    {    -28,    9,    0,  0,  0,  0 }, {    -26,    7,    0,  0,  0,  0 }, {    -25,    6,    0,  0,  0,  0 }, {    -24,    5,    1,  0,  0,  0 }, {    -23,    4,    1,  0,  0,  0 },
    {    -22,    3,    1,  0,  0,  0 }, {    -21,    2,    1,  0,  0,  0 }, {    -20,    2,    1,  0,  0,  0 }, {    -19,    2,    1,  0,  0,  0 }, {    -18,    2,    1,  0,  0,  0 },
    {    -17,    2,    1,  0,  0,  0 }, {    -17,    2,    1,  0,  0,  0 }, {    -17,    2,    1,  0,  0,  0 }, {    -18,    2,    1,  0,  0,  0 }, {    -19,    2,    1,  0,  0,  0 },
    {    -20,    2,    1,  0,  0,  0 }, {    -21,    2,    1,  0,  0,  0 }, {    -22,    3,    1,  0,  0,  0 }, {    -23,    4,    1,  0,  0,  0 }, {    -24,    5,    1,  0,  0,  0 },
    {    -25,    6,    0,  0,  0,  0 }, {    -26,    7,    0,  0,  0,  0 }, {    -28,    9,    0,  0,  0,  0 }, {    -27,   11,    0,  0,  0,  0 }, {    -26,   13,    0,  0,  0,  0 },
    {    -25,   15,    0,  0,  0,  0 }, {    -24,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -18,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -15,   20,    0,  0,  0,  0 }, {    -12,   20,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     -9,   20,    0,  0,  0,  0 }, {     -8,   20,    0,  0,  0,  0 },
    {     -7,   20,    0,  0,  0,  0 }, {     -6,   20,    0,  0,  0,  0 }, {     -5,   20,    0,  0,  0,  0 }, {     -4,   20,    0,  0,  0,  0 }, {     -3,   20,    0,  0,  0,  0 },
    {     -2,   20,    0,  0,  0,  0 }, {     -1,   20,    0,  0,  0,  0 }, {      0,   20,    0,  0,  0,  0 }, {      1,   20,    0,  0,  0,  0 }, {      2,   20,    0,  0,  0,  0 },
    {      3,   20,    0,  0,  0,  0 }, {      4,   20,    0,  0,  0,  0 }, {      5,   20,    0,  0,  0,  0 }, {      6,   20,    0,  0,  0,  0 }, {      7,   20,    0,  0,  0,  0 },
    {      8,   20,    0,  0,  0,  0 }, {      9,   20,    0,  0,  0,  0 }, {     10,   20,    0,  0,  0,  0 }, {     11,   20,    0,  0,  0,  0 }, {     12,   20,    0,  0,  0,  0 },
    {     13,   20,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     14,   20,    0,  0,  0,  0 }, {     12,   20,    0,  0,  0,  0 },
    {      9,   20,    0,  0,  0,  0 }, {      6,   20,    0,  0,  0,  0 }, {      3,   20,    0,  0,  0,  0 }, {      0,   20,    0,  0,  0,  0 }, {     -3,   20,    0,  0,  0,  0 },
    {     -6,   20,    0,  0,  0,  0 }, {     -9,   20,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {    -12,   20,    0,  0,  0,  0 }, {    -15,   20,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PlaceBallDown), {    -18,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -24,   16,    0,  0,  0,  0 }, {    -25,   15,    0,  0,  0,  0 },
    {    -26,   13,    0,  0,  0,  0 }, {    -27,   11,    0,  0,  0,  0 }, {    -28,    9,    0,  0,  0,  0 }, {    -26,    7,    0,  0,  0,  0 }, {    -24,    5,    1,  0,  0,  0 },
    {    -22,    3,    1,  0,  0,  0 }, {    -20,    2,    1,  0,  0,  0 }, {    -18,    2,    1,  0,  0,  0 }, {    -16,    3,    2,  0,  0,  0 }, {    -14,    3,    2,  0,  0,  0 },
    {    -14,    5,    2,  0,  0,  0 }, {    -13,    7,    2,  0,  0,  0 }, {    -12,    9,    3,  0,  0,  0 }, {    -12,   11,    3,  0,  0,  0 }, {    -11,   13,    3,  0,  0,  0 },
    {    -12,   15,    3,  0,  0,  0 }, {    -12,   17,    3,  0,  0,  0 }, {    -12,   19,    3,  0,  0,  0 }, {    -13,   21,    3,  0,  0,  0 }, {    -13,   23,    3,  0,  0,  0 },
    {    -13,   25,    3,  0,  0,  0 }, {    -14,   27,    3,  0,  0,  0 }, {    -14,   29,    3,  0,  0,  0 }, {    -14,   30,    3,  0,  0,  0 }, {    -14,   31,    3,  0,  0,  0 },
    {    -15,   32,    3,  0,  0,  0 }, {    -15,   33,    3,  0,  0,  0 }, {    -15,   34,    3,  0,  0,  0 }, {    -15,   35,    3,  0,  0,  0 }, {    -15,   36,    3,  0,  0,  0 },
    {    -15,   38,    0,  0,  0,  0 }, {    -16,   40,    0,  0,  0,  0 }, {    -16,   41,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {    -16,   42,    0,  0,  0,  0 }, {    -16,   43,    0,  0,  0,  0 }, {    -16,   44,    0,  0,  0,  0 }, {    -16,   45,    0,  0,  0,  0 }, {    -17,   46,    0,  0,  0,  0 },
    {    -17,   47,    0,  0,  0,  0 }, {    -17,   48,    0,  0,  0,  0 }, {    -17,   49,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {    -17,   60,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {    -17,   60,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_947AF9, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    7,    0,  8,  0,  0 }, {     17,   10,    0,  8,  0,  0 }, {     17,   12,    0,  8,  0,  0 },
    {     17,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     18,   18,    0,  8,  0,  0 }, {     18,   20,    0,  8,  0,  0 }, {     18,   22,    0,  8,  0,  0 },
    {     18,   24,    0,  8,  0,  0 }, {     18,   26,    0,  8,  0,  0 }, {     18,   27,    0,  8,  0,  0 }, {     19,   28,    0,  8,  0,  0 }, {     19,   29,    0,  8,  0,  0 },
    {     19,   30,    0,  8,  0,  0 }, {     19,   31,    0,  8,  0,  0 }, {     19,   32,    0,  8,  0,  0 }, {     19,   33,    0,  8,  0,  0 }, {     19,   32,    0,  8,  0,  0 },
    {     19,   31,    0,  8,  0,  0 }, {     19,   30,    0,  8,  0,  0 }, {     19,   29,    0,  8,  0,  0 }, {     19,   28,    0,  8,  0,  0 }, {     19,   27,    0,  8,  0,  0 },
    {     19,   26,    0,  8,  0,  0 }, {     20,   25,    0,  8,  0,  0 }, {     20,   24,    0,  8,  0,  0 }, {     20,   23,    0,  8,  0,  0 }, {     20,   22,    0,  8,  0,  0 },
    {     20,   21,    0,  8,  0,  0 }, {     20,   20,    0,  8,  0,  0 }, {     20,   19,    0,  8,  0,  0 }, {     20,   18,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     20,   17,    0,  8,  0,  0 }, {     20,   19,    0,  8,  0,  0 }, {     20,   22,    0,  8,  0,  0 }, {     20,   25,    0,  8,  0,  0 },
    {     20,   28,    0,  8,  0,  0 }, {     20,   31,    0,  8,  0,  0 }, {     20,   34,    0,  8,  0,  0 }, {     20,   37,    0,  8,  0,  0 }, {     20,   40,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     20,   43,    0,  8,  0,  0 }, {     20,   46,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     16,   49,    0,  8,  0,  0 },
    {     16,   52,    0,  8,  0,  0 }, {     16,   55,    0,  8,  0,  0 }, {     15,   56,    0,  8,  0,  0 }, {     13,   57,    0,  8,  0,  0 }, {     11,   58,    0,  8,  0,  0 },
    {      9,   59,    0,  8,  0,  0 }, {      7,   57,    0,  8,  0,  0 }, {      6,   56,    0,  8,  0,  0 }, {      5,   55,    1,  8,  0,  0 }, {      4,   54,    1,  8,  0,  0 },
    {      3,   53,    1,  8,  0,  0 }, {      2,   52,    1,  8,  0,  0 }, {      2,   51,    1,  8,  0,  0 }, {      2,   50,    1,  8,  0,  0 }, {      2,   49,    1,  8,  0,  0 },
    {      2,   48,    1,  8,  0,  0 }, {      2,   48,    1,  8,  0,  0 }, {      2,   48,    1,  8,  0,  0 }, {      2,   49,    1,  8,  0,  0 }, {      2,   50,    1,  8,  0,  0 },
    {      2,   51,    1,  8,  0,  0 }, {      2,   52,    1,  8,  0,  0 }, {      3,   53,    1,  8,  0,  0 }, {      4,   54,    1,  8,  0,  0 }, {      5,   55,    1,  8,  0,  0 },
    {      6,   56,    0,  8,  0,  0 }, {      7,   57,    0,  8,  0,  0 }, {      9,   59,    0,  8,  0,  0 }, {     11,   58,    0,  8,  0,  0 }, {     13,   57,    0,  8,  0,  0 },
    {     15,   56,    0,  8,  0,  0 }, {     16,   55,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   49,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     20,   46,    0,  8,  0,  0 }, {     20,   43,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     20,   40,    0,  8,  0,  0 }, {     20,   39,    0,  8,  0,  0 },
    {     20,   38,    0,  8,  0,  0 }, {     20,   37,    0,  8,  0,  0 }, {     20,   36,    0,  8,  0,  0 }, {     20,   35,    0,  8,  0,  0 }, {     20,   34,    0,  8,  0,  0 },
    {     20,   33,    0,  8,  0,  0 }, {     20,   32,    0,  8,  0,  0 }, {     20,   31,    0,  8,  0,  0 }, {     20,   30,    0,  8,  0,  0 }, {     20,   29,    0,  8,  0,  0 },
    {     20,   28,    0,  8,  0,  0 }, {     20,   27,    0,  8,  0,  0 }, {     20,   26,    0,  8,  0,  0 }, {     20,   25,    0,  8,  0,  0 }, {     20,   24,    0,  8,  0,  0 },
    {     20,   23,    0,  8,  0,  0 }, {     20,   22,    0,  8,  0,  0 }, {     20,   21,    0,  8,  0,  0 }, {     20,   20,    0,  8,  0,  0 }, {     20,   19,    0,  8,  0,  0 },
    {     20,   18,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     20,   17,    0,  8,  0,  0 }, {     20,   19,    0,  8,  0,  0 },
    {     20,   22,    0,  8,  0,  0 }, {     20,   25,    0,  8,  0,  0 }, {     20,   28,    0,  8,  0,  0 }, {     20,   31,    0,  8,  0,  0 }, {     20,   34,    0,  8,  0,  0 },
    {     20,   37,    0,  8,  0,  0 }, {     20,   40,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     20,   43,    0,  8,  0,  0 }, {     20,   46,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PlaceBallDown), {     16,   49,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   55,    0,  8,  0,  0 }, {     15,   56,    0,  8,  0,  0 },
    {     13,   57,    0,  8,  0,  0 }, {     11,   58,    0,  8,  0,  0 }, {      9,   59,    0,  8,  0,  0 }, {      7,   57,    0,  8,  0,  0 }, {      5,   55,    1,  8,  0,  0 },
    {      3,   53,    1,  8,  0,  0 }, {      2,   51,    1,  8,  0,  0 }, {      2,   49,    1,  8,  0,  0 }, {      3,   47,    2,  8,  0,  0 }, {      3,   45,    2,  8,  0,  0 },
    {      5,   45,    2,  8,  0,  0 }, {      7,   44,    2,  8,  0,  0 }, {      9,   43,    3,  8,  0,  0 }, {     11,   43,    3,  8,  0,  0 }, {     13,   42,    3,  8,  0,  0 },
    {     15,   43,    3,  8,  0,  0 }, {     17,   43,    3,  8,  0,  0 }, {     19,   43,    3,  8,  0,  0 }, {     21,   44,    3,  8,  0,  0 }, {     23,   44,    3,  8,  0,  0 },
    {     25,   44,    3,  8,  0,  0 }, {     27,   45,    3,  8,  0,  0 }, {     29,   45,    3,  8,  0,  0 }, {     30,   45,    3,  8,  0,  0 }, {     31,   45,    3,  8,  0,  0 },
    {     32,   46,    3,  8,  0,  0 }, {     33,   46,    3,  8,  0,  0 }, {     34,   46,    3,  8,  0,  0 }, {     35,   46,    3,  8,  0,  0 }, {     36,   46,    3,  8,  0,  0 },
    {     38,   46,    0,  8,  0,  0 }, {     40,   47,    0,  8,  0,  0 }, {     41,   47,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     42,   47,    0,  8,  0,  0 }, {     43,   47,    0,  8,  0,  0 }, {     44,   47,    0,  8,  0,  0 }, {     45,   47,    0,  8,  0,  0 }, {     46,   48,    0,  8,  0,  0 },
    {     47,   48,    0,  8,  0,  0 }, {     48,   48,    0,  8,  0,  0 }, {     49,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {     60,   48,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     60,   48,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94A7B7, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      7,   15,    0, 16,  0,  0 }, {     10,   14,    0, 16,  0,  0 }, {     12,   14,    0, 16,  0,  0 },
    {     14,   14,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     18,   13,    0, 16,  0,  0 }, {     20,   13,    0, 16,  0,  0 }, {     22,   13,    0, 16,  0,  0 },
    {     24,   13,    0, 16,  0,  0 }, {     26,   13,    0, 16,  0,  0 }, {     27,   13,    0, 16,  0,  0 }, {     28,   12,    0, 16,  0,  0 }, {     29,   12,    0, 16,  0,  0 },
    {     30,   12,    0, 16,  0,  0 }, {     31,   12,    0, 16,  0,  0 }, {     32,   12,    0, 16,  0,  0 }, {     33,   12,    0, 16,  0,  0 }, {     32,   12,    0, 16,  0,  0 },
    {     31,   12,    0, 16,  0,  0 }, {     30,   12,    0, 16,  0,  0 }, {     29,   12,    0, 16,  0,  0 }, {     28,   12,    0, 16,  0,  0 }, {     27,   12,    0, 16,  0,  0 },
    {     26,   12,    0, 16,  0,  0 }, {     25,   11,    0, 16,  0,  0 }, {     24,   11,    0, 16,  0,  0 }, {     23,   11,    0, 16,  0,  0 }, {     22,   11,    0, 16,  0,  0 },
    {     21,   11,    0, 16,  0,  0 }, {     20,   11,    0, 16,  0,  0 }, {     19,   11,    0, 16,  0,  0 }, {     18,   11,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     17,   11,    0, 16,  0,  0 }, {     19,   11,    0, 16,  0,  0 }, {     22,   11,    0, 16,  0,  0 }, {     25,   11,    0, 16,  0,  0 },
    {     28,   11,    0, 16,  0,  0 }, {     31,   11,    0, 16,  0,  0 }, {     34,   11,    0, 16,  0,  0 }, {     37,   11,    0, 16,  0,  0 }, {     40,   11,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     43,   11,    0, 16,  0,  0 }, {     46,   11,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     49,   15,    0, 16,  0,  0 },
    {     52,   15,    0, 16,  0,  0 }, {     55,   15,    0, 16,  0,  0 }, {     56,   16,    0, 16,  0,  0 }, {     57,   18,    0, 16,  0,  0 }, {     58,   20,    0, 16,  0,  0 },
    {     59,   22,    0, 16,  0,  0 }, {     57,   24,    0, 16,  0,  0 }, {     56,   25,    0, 16,  0,  0 }, {     55,   26,    1, 16,  0,  0 }, {     54,   27,    1, 16,  0,  0 },
    {     53,   28,    1, 16,  0,  0 }, {     52,   29,    1, 16,  0,  0 }, {     51,   29,    1, 16,  0,  0 }, {     50,   29,    1, 16,  0,  0 }, {     49,   29,    1, 16,  0,  0 },
    {     48,   29,    1, 16,  0,  0 }, {     48,   29,    1, 16,  0,  0 }, {     48,   29,    1, 16,  0,  0 }, {     49,   29,    1, 16,  0,  0 }, {     50,   29,    1, 16,  0,  0 },
    {     51,   29,    1, 16,  0,  0 }, {     52,   29,    1, 16,  0,  0 }, {     53,   28,    1, 16,  0,  0 }, {     54,   27,    1, 16,  0,  0 }, {     55,   26,    1, 16,  0,  0 },
    {     56,   25,    0, 16,  0,  0 }, {     57,   24,    0, 16,  0,  0 }, {     59,   22,    0, 16,  0,  0 }, {     58,   20,    0, 16,  0,  0 }, {     57,   18,    0, 16,  0,  0 },
    {     56,   16,    0, 16,  0,  0 }, {     55,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 }, {     49,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     46,   11,    0, 16,  0,  0 }, {     43,   11,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     40,   11,    0, 16,  0,  0 }, {     39,   11,    0, 16,  0,  0 },
    {     38,   11,    0, 16,  0,  0 }, {     37,   11,    0, 16,  0,  0 }, {     36,   11,    0, 16,  0,  0 }, {     35,   11,    0, 16,  0,  0 }, {     34,   11,    0, 16,  0,  0 },
    {     33,   11,    0, 16,  0,  0 }, {     32,   11,    0, 16,  0,  0 }, {     31,   11,    0, 16,  0,  0 }, {     30,   11,    0, 16,  0,  0 }, {     29,   11,    0, 16,  0,  0 },
    {     28,   11,    0, 16,  0,  0 }, {     27,   11,    0, 16,  0,  0 }, {     26,   11,    0, 16,  0,  0 }, {     25,   11,    0, 16,  0,  0 }, {     24,   11,    0, 16,  0,  0 },
    {     23,   11,    0, 16,  0,  0 }, {     22,   11,    0, 16,  0,  0 }, {     21,   11,    0, 16,  0,  0 }, {     20,   11,    0, 16,  0,  0 }, {     19,   11,    0, 16,  0,  0 },
    {     18,   11,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     17,   11,    0, 16,  0,  0 }, {     19,   11,    0, 16,  0,  0 },
    {     22,   11,    0, 16,  0,  0 }, {     25,   11,    0, 16,  0,  0 }, {     28,   11,    0, 16,  0,  0 }, {     31,   11,    0, 16,  0,  0 }, {     34,   11,    0, 16,  0,  0 },
    {     37,   11,    0, 16,  0,  0 }, {     40,   11,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     43,   11,    0, 16,  0,  0 }, {     46,   11,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PlaceBallDown), {     49,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 }, {     55,   15,    0, 16,  0,  0 }, {     56,   16,    0, 16,  0,  0 },
    {     57,   18,    0, 16,  0,  0 }, {     58,   20,    0, 16,  0,  0 }, {     59,   22,    0, 16,  0,  0 }, {     57,   24,    0, 16,  0,  0 }, {     55,   26,    1, 16,  0,  0 },
    {     53,   28,    1, 16,  0,  0 }, {     51,   29,    1, 16,  0,  0 }, {     49,   29,    1, 16,  0,  0 }, {     47,   28,    2, 16,  0,  0 }, {     45,   28,    2, 16,  0,  0 },
    {     45,   26,    2, 16,  0,  0 }, {     44,   24,    2, 16,  0,  0 }, {     43,   22,    3, 16,  0,  0 }, {     43,   20,    3, 16,  0,  0 }, {     42,   18,    3, 16,  0,  0 },
    {     43,   16,    3, 16,  0,  0 }, {     43,   14,    3, 16,  0,  0 }, {     43,   12,    3, 16,  0,  0 }, {     44,   10,    3, 16,  0,  0 }, {     44,    8,    3, 16,  0,  0 },
    {     44,    6,    3, 16,  0,  0 }, {     45,    4,    3, 16,  0,  0 }, {     45,    2,    3, 16,  0,  0 }, {     45,    1,    3, 16,  0,  0 }, {     45,    0,    3, 16,  0,  0 },
    {     46,   -1,    3, 16,  0,  0 }, {     46,   -2,    3, 16,  0,  0 }, {     46,   -3,    3, 16,  0,  0 }, {     46,   -4,    3, 16,  0,  0 }, {     46,   -5,    3, 16,  0,  0 },
    {     46,   -7,    0, 16,  0,  0 }, {     47,   -9,    0, 16,  0,  0 }, {     47,  -10,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     47,  -11,    0, 16,  0,  0 }, {     47,  -12,    0, 16,  0,  0 }, {     47,  -13,    0, 16,  0,  0 }, {     47,  -14,    0, 16,  0,  0 }, {     48,  -15,    0, 16,  0,  0 },
    {     48,  -16,    0, 16,  0,  0 }, {     48,  -17,    0, 16,  0,  0 }, {     48,  -18,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {     48,  -29,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     48,  -29,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94D475, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   24,    0, 24,  0,  0 }, {     14,   21,    0, 24,  0,  0 }, {     14,   19,    0, 24,  0,  0 },
    {     14,   17,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     13,   13,    0, 24,  0,  0 }, {     13,   11,    0, 24,  0,  0 }, {     13,    9,    0, 24,  0,  0 },
    {     13,    7,    0, 24,  0,  0 }, {     13,    5,    0, 24,  0,  0 }, {     13,    4,    0, 24,  0,  0 }, {     12,    3,    0, 24,  0,  0 }, {     12,    2,    0, 24,  0,  0 },
    {     12,    1,    0, 24,  0,  0 }, {     12,    0,    0, 24,  0,  0 }, {     12,   -1,    0, 24,  0,  0 }, {     12,   -2,    0, 24,  0,  0 }, {     12,   -1,    0, 24,  0,  0 },
    {     12,    0,    0, 24,  0,  0 }, {     12,    1,    0, 24,  0,  0 }, {     12,    2,    0, 24,  0,  0 }, {     12,    3,    0, 24,  0,  0 }, {     12,    4,    0, 24,  0,  0 },
    {     12,    5,    0, 24,  0,  0 }, {     11,    6,    0, 24,  0,  0 }, {     11,    7,    0, 24,  0,  0 }, {     11,    8,    0, 24,  0,  0 }, {     11,    9,    0, 24,  0,  0 },
    {     11,   10,    0, 24,  0,  0 }, {     11,   11,    0, 24,  0,  0 }, {     11,   12,    0, 24,  0,  0 }, {     11,   13,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     11,   14,    0, 24,  0,  0 }, {     11,   12,    0, 24,  0,  0 }, {     11,    9,    0, 24,  0,  0 }, {     11,    6,    0, 24,  0,  0 },
    {     11,    3,    0, 24,  0,  0 }, {     11,    0,    0, 24,  0,  0 }, {     11,   -3,    0, 24,  0,  0 }, {     11,   -6,    0, 24,  0,  0 }, {     11,   -9,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     11,  -12,    0, 24,  0,  0 }, {     11,  -15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     15,  -18,    0, 24,  0,  0 },
    {     15,  -21,    0, 24,  0,  0 }, {     15,  -24,    0, 24,  0,  0 }, {     16,  -25,    0, 24,  0,  0 }, {     18,  -26,    0, 24,  0,  0 }, {     20,  -27,    0, 24,  0,  0 },
    {     22,  -28,    0, 24,  0,  0 }, {     24,  -26,    0, 24,  0,  0 }, {     25,  -25,    0, 24,  0,  0 }, {     26,  -24,    1, 24,  0,  0 }, {     27,  -23,    1, 24,  0,  0 },
    {     28,  -22,    1, 24,  0,  0 }, {     29,  -21,    1, 24,  0,  0 }, {     29,  -20,    1, 24,  0,  0 }, {     29,  -19,    1, 24,  0,  0 }, {     29,  -18,    1, 24,  0,  0 },
    {     29,  -17,    1, 24,  0,  0 }, {     29,  -17,    1, 24,  0,  0 }, {     29,  -17,    1, 24,  0,  0 }, {     29,  -18,    1, 24,  0,  0 }, {     29,  -19,    1, 24,  0,  0 },
    {     29,  -20,    1, 24,  0,  0 }, {     29,  -21,    1, 24,  0,  0 }, {     28,  -22,    1, 24,  0,  0 }, {     27,  -23,    1, 24,  0,  0 }, {     26,  -24,    1, 24,  0,  0 },
    {     25,  -25,    0, 24,  0,  0 }, {     24,  -26,    0, 24,  0,  0 }, {     22,  -28,    0, 24,  0,  0 }, {     20,  -27,    0, 24,  0,  0 }, {     18,  -26,    0, 24,  0,  0 },
    {     16,  -25,    0, 24,  0,  0 }, {     15,  -24,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 }, {     15,  -18,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     11,  -15,    0, 24,  0,  0 }, {     11,  -12,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     11,   -9,    0, 24,  0,  0 }, {     11,   -8,    0, 24,  0,  0 },
    {     11,   -7,    0, 24,  0,  0 }, {     11,   -6,    0, 24,  0,  0 }, {     11,   -5,    0, 24,  0,  0 }, {     11,   -4,    0, 24,  0,  0 }, {     11,   -3,    0, 24,  0,  0 },
    {     11,   -2,    0, 24,  0,  0 }, {     11,   -1,    0, 24,  0,  0 }, {     11,    0,    0, 24,  0,  0 }, {     11,    1,    0, 24,  0,  0 }, {     11,    2,    0, 24,  0,  0 },
    {     11,    3,    0, 24,  0,  0 }, {     11,    4,    0, 24,  0,  0 }, {     11,    5,    0, 24,  0,  0 }, {     11,    6,    0, 24,  0,  0 }, {     11,    7,    0, 24,  0,  0 },
    {     11,    8,    0, 24,  0,  0 }, {     11,    9,    0, 24,  0,  0 }, {     11,   10,    0, 24,  0,  0 }, {     11,   11,    0, 24,  0,  0 }, {     11,   12,    0, 24,  0,  0 },
    {     11,   13,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     11,   14,    0, 24,  0,  0 }, {     11,   12,    0, 24,  0,  0 },
    {     11,    9,    0, 24,  0,  0 }, {     11,    6,    0, 24,  0,  0 }, {     11,    3,    0, 24,  0,  0 }, {     11,    0,    0, 24,  0,  0 }, {     11,   -3,    0, 24,  0,  0 },
    {     11,   -6,    0, 24,  0,  0 }, {     11,   -9,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     11,  -12,    0, 24,  0,  0 }, {     11,  -15,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PlaceBallDown), {     15,  -18,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 }, {     15,  -24,    0, 24,  0,  0 }, {     16,  -25,    0, 24,  0,  0 },
    {     18,  -26,    0, 24,  0,  0 }, {     20,  -27,    0, 24,  0,  0 }, {     22,  -28,    0, 24,  0,  0 }, {     24,  -26,    0, 24,  0,  0 }, {     26,  -24,    1, 24,  0,  0 },
    {     28,  -22,    1, 24,  0,  0 }, {     29,  -20,    1, 24,  0,  0 }, {     29,  -18,    1, 24,  0,  0 }, {     28,  -16,    2, 24,  0,  0 }, {     28,  -14,    2, 24,  0,  0 },
    {     26,  -14,    2, 24,  0,  0 }, {     24,  -13,    2, 24,  0,  0 }, {     22,  -12,    3, 24,  0,  0 }, {     20,  -12,    3, 24,  0,  0 }, {     18,  -11,    3, 24,  0,  0 },
    {     16,  -12,    3, 24,  0,  0 }, {     14,  -12,    3, 24,  0,  0 }, {     12,  -12,    3, 24,  0,  0 }, {     10,  -13,    3, 24,  0,  0 }, {      8,  -13,    3, 24,  0,  0 },
    {      6,  -13,    3, 24,  0,  0 }, {      4,  -14,    3, 24,  0,  0 }, {      2,  -14,    3, 24,  0,  0 }, {      1,  -14,    3, 24,  0,  0 }, {      0,  -14,    3, 24,  0,  0 },
    {     -1,  -15,    3, 24,  0,  0 }, {     -2,  -15,    3, 24,  0,  0 }, {     -3,  -15,    3, 24,  0,  0 }, {     -4,  -15,    3, 24,  0,  0 }, {     -5,  -15,    3, 24,  0,  0 },
    {     -7,  -15,    0, 24,  0,  0 }, {     -9,  -16,    0, 24,  0,  0 }, {    -10,  -16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {    -11,  -16,    0, 24,  0,  0 }, {    -12,  -16,    0, 24,  0,  0 }, {    -13,  -16,    0, 24,  0,  0 }, {    -14,  -16,    0, 24,  0,  0 }, {    -15,  -17,    0, 24,  0,  0 },
    {    -16,  -17,    0, 24,  0,  0 }, {    -17,  -17,    0, 24,  0,  0 }, {    -18,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {    -29,  -17,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {    -29,  -17,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94649A, {
    MINI_GOLF_STATE(Unk0),              {     31,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     26,   16,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     24,   16,    0,  0,  0,  0 }, {     21,   15,    0,  0,  0,  0 }, {     19,   15,    0,  0,  0,  0 },
    {     17,   15,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     13,   14,    0,  0,  0,  0 }, {     11,   14,    0,  0,  0,  0 }, {      9,   14,    0,  0,  0,  0 },
    {      7,   14,    0,  0,  0,  0 }, {      5,   14,    0,  0,  0,  0 }, {      4,   14,    0,  0,  0,  0 }, {      3,   13,    0,  0,  0,  0 }, {      2,   13,    0,  0,  0,  0 },
    {      1,   13,    0,  0,  0,  0 }, {      0,   13,    0,  0,  0,  0 }, {     -1,   13,    0,  0,  0,  0 }, {     -2,   13,    0,  0,  0,  0 }, {     -1,   13,    0,  0,  0,  0 },
    {      0,   13,    0,  0,  0,  0 }, {      1,   13,    0,  0,  0,  0 }, {      2,   13,    0,  0,  0,  0 }, {      3,   13,    0,  0,  0,  0 }, {      4,   13,    0,  0,  0,  0 },
    {      5,   13,    0,  0,  0,  0 }, {      6,   12,    0,  0,  0,  0 }, {      7,   12,    0,  0,  0,  0 }, {      8,   12,    0,  0,  0,  0 }, {      9,   12,    0,  0,  0,  0 },
    {     10,   12,    0,  0,  0,  0 }, {     11,   12,    0,  0,  0,  0 }, {     12,   12,    0,  0,  0,  0 }, {     13,   12,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     14,   12,    0,  0,  0,  0 }, {     12,   12,    0,  0,  0,  0 }, {      9,   12,    0,  0,  0,  0 }, {      6,   12,    0,  0,  0,  0 },
    {      3,   12,    0,  0,  0,  0 }, {      0,   12,    0,  0,  0,  0 }, {     -3,   12,    0,  0,  0,  0 }, {     -6,   12,    0,  0,  0,  0 }, {     -9,   12,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {    -12,   12,    0,  0,  0,  0 }, {    -15,   12,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {    -18,   16,    0,  0,  0,  0 },
    {    -21,   16,    0,  0,  0,  0 }, {    -24,   16,    0,  0,  0,  0 }, {    -25,   17,    0,  0,  0,  0 }, {    -26,   19,    0,  0,  0,  0 }, {    -27,   21,    0,  0,  0,  0 },
    {    -28,   23,    0,  0,  0,  0 }, {    -26,   25,    0,  0,  0,  0 }, {    -25,   26,    0,  0,  0,  0 }, {    -24,   27,    1,  0,  0,  0 }, {    -23,   28,    1,  0,  0,  0 },
    {    -22,   29,    1,  0,  0,  0 }, {    -21,   30,    1,  0,  0,  0 }, {    -20,   30,    1,  0,  0,  0 }, {    -19,   30,    1,  0,  0,  0 }, {    -18,   30,    1,  0,  0,  0 },
    {    -17,   30,    1,  0,  0,  0 }, {    -17,   30,    1,  0,  0,  0 }, {    -17,   30,    1,  0,  0,  0 }, {    -18,   30,    1,  0,  0,  0 }, {    -19,   30,    1,  0,  0,  0 },
    {    -20,   30,    1,  0,  0,  0 }, {    -21,   30,    1,  0,  0,  0 }, {    -22,   29,    1,  0,  0,  0 }, {    -23,   28,    1,  0,  0,  0 }, {    -24,   27,    1,  0,  0,  0 },
    {    -25,   26,    0,  0,  0,  0 }, {    -26,   25,    0,  0,  0,  0 }, {    -28,   23,    0,  0,  0,  0 }, {    -27,   21,    0,  0,  0,  0 }, {    -26,   19,    0,  0,  0,  0 },
    {    -25,   17,    0,  0,  0,  0 }, {    -24,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -18,   16,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {    -15,   12,    0,  0,  0,  0 }, {    -12,   12,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     -9,   12,    0,  0,  0,  0 }, {     -8,   12,    0,  0,  0,  0 },
    {     -7,   12,    0,  0,  0,  0 }, {     -6,   12,    0,  0,  0,  0 }, {     -5,   12,    0,  0,  0,  0 }, {     -4,   12,    0,  0,  0,  0 }, {     -3,   12,    0,  0,  0,  0 },
    {     -2,   12,    0,  0,  0,  0 }, {     -1,   12,    0,  0,  0,  0 }, {      0,   12,    0,  0,  0,  0 }, {      1,   12,    0,  0,  0,  0 }, {      2,   12,    0,  0,  0,  0 },
    {      3,   12,    0,  0,  0,  0 }, {      4,   12,    0,  0,  0,  0 }, {      5,   12,    0,  0,  0,  0 }, {      6,   12,    0,  0,  0,  0 }, {      7,   12,    0,  0,  0,  0 },
    {      8,   12,    0,  0,  0,  0 }, {      9,   12,    0,  0,  0,  0 }, {     10,   12,    0,  0,  0,  0 }, {     11,   12,    0,  0,  0,  0 }, {     12,   12,    0,  0,  0,  0 },
    {     13,   12,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     14,   12,    0,  0,  0,  0 }, {     12,   12,    0,  0,  0,  0 },
    {      9,   12,    0,  0,  0,  0 }, {      6,   12,    0,  0,  0,  0 }, {      3,   12,    0,  0,  0,  0 }, {      0,   12,    0,  0,  0,  0 }, {     -3,   12,    0,  0,  0,  0 },
    {     -6,   12,    0,  0,  0,  0 }, {     -9,   12,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {    -12,   12,    0,  0,  0,  0 }, {    -15,   12,    0,  0,  0,  0 },
    MINI_GOLF_ANIMATION(PlaceBallDown), {    -18,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -24,   16,    0,  0,  0,  0 }, {    -25,   17,    0,  0,  0,  0 },
    {    -26,   19,    0,  0,  0,  0 }, {    -27,   21,    0,  0,  0,  0 }, {    -28,   23,    0,  0,  0,  0 }, {    -26,   25,    0,  0,  0,  0 }, {    -24,   27,    1,  0,  0,  0 },
    {    -22,   29,    1,  0,  0,  0 }, {    -20,   30,    1,  0,  0,  0 }, {    -18,   30,    1,  0,  0,  0 }, {    -16,   30,    2,  0,  0,  0 }, {    -14,   29,    2,  0,  0,  0 },
    {    -14,   27,    2,  0,  0,  0 }, {    -13,   25,    2,  0,  0,  0 }, {    -12,   23,    3,  0,  0,  0 }, {    -12,   21,    3,  0,  0,  0 }, {    -11,   19,    3,  0,  0,  0 },
    {    -12,   17,    3,  0,  0,  0 }, {    -12,   15,    3,  0,  0,  0 }, {    -12,   13,    3,  0,  0,  0 }, {    -13,   11,    3,  0,  0,  0 }, {    -13,    9,    3,  0,  0,  0 },
    {    -13,    7,    3,  0,  0,  0 }, {    -14,    5,    3,  0,  0,  0 }, {    -14,    3,    3,  0,  0,  0 }, {    -14,    2,    3,  0,  0,  0 }, {    -14,    1,    3,  0,  0,  0 },
    {    -15,    0,    3,  0,  0,  0 }, {    -15,   -1,    3,  0,  0,  0 }, {    -15,   -2,    3,  0,  0,  0 }, {    -15,   -3,    3,  0,  0,  0 }, {    -15,   -4,    3,  0,  0,  0 },
    {    -15,   -6,    0,  0,  0,  0 }, {    -16,   -8,    0,  0,  0,  0 }, {    -16,   -9,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {    -16,  -10,    0,  0,  0,  0 }, {    -16,  -11,    0,  0,  0,  0 }, {    -16,  -12,    0,  0,  0,  0 }, {    -16,  -13,    0,  0,  0,  0 }, {    -17,  -14,    0,  0,  0,  0 },
    {    -17,  -15,    0,  0,  0,  0 }, {    -17,  -16,    0,  0,  0,  0 }, {    -17,  -17,    0,  0,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {    -17,  -28,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {    -17,  -28,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_949158, {
    MINI_GOLF_STATE(Unk0),              {     16,    0,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     16,    5,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     16,    7,    0,  8,  0,  0 }, {     15,   10,    0,  8,  0,  0 }, {     15,   12,    0,  8,  0,  0 },
    {     15,   14,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     14,   18,    0,  8,  0,  0 }, {     14,   20,    0,  8,  0,  0 }, {     14,   22,    0,  8,  0,  0 },
    {     14,   24,    0,  8,  0,  0 }, {     14,   26,    0,  8,  0,  0 }, {     14,   27,    0,  8,  0,  0 }, {     13,   28,    0,  8,  0,  0 }, {     13,   29,    0,  8,  0,  0 },
    {     13,   30,    0,  8,  0,  0 }, {     13,   31,    0,  8,  0,  0 }, {     13,   32,    0,  8,  0,  0 }, {     13,   33,    0,  8,  0,  0 }, {     13,   32,    0,  8,  0,  0 },
    {     13,   31,    0,  8,  0,  0 }, {     13,   30,    0,  8,  0,  0 }, {     13,   29,    0,  8,  0,  0 }, {     13,   28,    0,  8,  0,  0 }, {     13,   27,    0,  8,  0,  0 },
    {     13,   26,    0,  8,  0,  0 }, {     12,   25,    0,  8,  0,  0 }, {     12,   24,    0,  8,  0,  0 }, {     12,   23,    0,  8,  0,  0 }, {     12,   22,    0,  8,  0,  0 },
    {     12,   21,    0,  8,  0,  0 }, {     12,   20,    0,  8,  0,  0 }, {     12,   19,    0,  8,  0,  0 }, {     12,   18,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     12,   17,    0,  8,  0,  0 }, {     12,   19,    0,  8,  0,  0 }, {     12,   22,    0,  8,  0,  0 }, {     12,   25,    0,  8,  0,  0 },
    {     12,   28,    0,  8,  0,  0 }, {     12,   31,    0,  8,  0,  0 }, {     12,   34,    0,  8,  0,  0 }, {     12,   37,    0,  8,  0,  0 }, {     12,   40,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     12,   43,    0,  8,  0,  0 }, {     12,   46,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     16,   49,    0,  8,  0,  0 },
    {     16,   52,    0,  8,  0,  0 }, {     16,   55,    0,  8,  0,  0 }, {     17,   56,    0,  8,  0,  0 }, {     19,   57,    0,  8,  0,  0 }, {     21,   58,    0,  8,  0,  0 },
    {     23,   59,    0,  8,  0,  0 }, {     25,   57,    0,  8,  0,  0 }, {     26,   56,    0,  8,  0,  0 }, {     27,   55,    1,  8,  0,  0 }, {     28,   54,    1,  8,  0,  0 },
    {     29,   53,    1,  8,  0,  0 }, {     30,   52,    1,  8,  0,  0 }, {     30,   51,    1,  8,  0,  0 }, {     30,   50,    1,  8,  0,  0 }, {     30,   49,    1,  8,  0,  0 },
    {     30,   48,    1,  8,  0,  0 }, {     30,   48,    1,  8,  0,  0 }, {     30,   48,    1,  8,  0,  0 }, {     30,   49,    1,  8,  0,  0 }, {     30,   50,    1,  8,  0,  0 },
    {     30,   51,    1,  8,  0,  0 }, {     30,   52,    1,  8,  0,  0 }, {     29,   53,    1,  8,  0,  0 }, {     28,   54,    1,  8,  0,  0 }, {     27,   55,    1,  8,  0,  0 },
    {     26,   56,    0,  8,  0,  0 }, {     25,   57,    0,  8,  0,  0 }, {     23,   59,    0,  8,  0,  0 }, {     21,   58,    0,  8,  0,  0 }, {     19,   57,    0,  8,  0,  0 },
    {     17,   56,    0,  8,  0,  0 }, {     16,   55,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   49,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     12,   46,    0,  8,  0,  0 }, {     12,   43,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     12,   40,    0,  8,  0,  0 }, {     12,   39,    0,  8,  0,  0 },
    {     12,   38,    0,  8,  0,  0 }, {     12,   37,    0,  8,  0,  0 }, {     12,   36,    0,  8,  0,  0 }, {     12,   35,    0,  8,  0,  0 }, {     12,   34,    0,  8,  0,  0 },
    {     12,   33,    0,  8,  0,  0 }, {     12,   32,    0,  8,  0,  0 }, {     12,   31,    0,  8,  0,  0 }, {     12,   30,    0,  8,  0,  0 }, {     12,   29,    0,  8,  0,  0 },
    {     12,   28,    0,  8,  0,  0 }, {     12,   27,    0,  8,  0,  0 }, {     12,   26,    0,  8,  0,  0 }, {     12,   25,    0,  8,  0,  0 }, {     12,   24,    0,  8,  0,  0 },
    {     12,   23,    0,  8,  0,  0 }, {     12,   22,    0,  8,  0,  0 }, {     12,   21,    0,  8,  0,  0 }, {     12,   20,    0,  8,  0,  0 }, {     12,   19,    0,  8,  0,  0 },
    {     12,   18,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     12,   17,    0,  8,  0,  0 }, {     12,   19,    0,  8,  0,  0 },
    {     12,   22,    0,  8,  0,  0 }, {     12,   25,    0,  8,  0,  0 }, {     12,   28,    0,  8,  0,  0 }, {     12,   31,    0,  8,  0,  0 }, {     12,   34,    0,  8,  0,  0 },
    {     12,   37,    0,  8,  0,  0 }, {     12,   40,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     12,   43,    0,  8,  0,  0 }, {     12,   46,    0,  8,  0,  0 },
    MINI_GOLF_ANIMATION(PlaceBallDown), {     16,   49,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   55,    0,  8,  0,  0 }, {     17,   56,    0,  8,  0,  0 },
    {     19,   57,    0,  8,  0,  0 }, {     21,   58,    0,  8,  0,  0 }, {     23,   59,    0,  8,  0,  0 }, {     25,   57,    0,  8,  0,  0 }, {     27,   55,    1,  8,  0,  0 },
    {     29,   53,    1,  8,  0,  0 }, {     30,   51,    1,  8,  0,  0 }, {     30,   49,    1,  8,  0,  0 }, {     30,   47,    2,  8,  0,  0 }, {     29,   45,    2,  8,  0,  0 },
    {     27,   45,    2,  8,  0,  0 }, {     25,   44,    2,  8,  0,  0 }, {     23,   43,    3,  8,  0,  0 }, {     21,   43,    3,  8,  0,  0 }, {     19,   42,    3,  8,  0,  0 },
    {     17,   43,    3,  8,  0,  0 }, {     15,   43,    3,  8,  0,  0 }, {     13,   43,    3,  8,  0,  0 }, {     11,   44,    3,  8,  0,  0 }, {      9,   44,    3,  8,  0,  0 },
    {      7,   44,    3,  8,  0,  0 }, {      5,   45,    3,  8,  0,  0 }, {      3,   45,    3,  8,  0,  0 }, {      2,   45,    3,  8,  0,  0 }, {      1,   45,    3,  8,  0,  0 },
    {      0,   46,    3,  8,  0,  0 }, {     -1,   46,    3,  8,  0,  0 }, {     -2,   46,    3,  8,  0,  0 }, {     -3,   46,    3,  8,  0,  0 }, {     -4,   46,    3,  8,  0,  0 },
    {     -6,   46,    0,  8,  0,  0 }, {     -8,   47,    0,  8,  0,  0 }, {     -9,   47,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {    -10,   47,    0,  8,  0,  0 }, {    -11,   47,    0,  8,  0,  0 }, {    -12,   47,    0,  8,  0,  0 }, {    -13,   47,    0,  8,  0,  0 }, {    -14,   48,    0,  8,  0,  0 },
    {    -15,   48,    0,  8,  0,  0 }, {    -16,   48,    0,  8,  0,  0 }, {    -17,   48,    0,  8,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {    -28,   48,    0,  0,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {    -28,   48,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94BE16, {
    MINI_GOLF_STATE(Unk0),              {      0,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {      5,   15,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk3),              {      7,   15,    0, 16,  0,  0 }, {     10,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 },
    {     14,   16,    0, 16,  0,  0 }, {     16,   15,    0, 16,  0,  0 }, {     18,   17,    0, 16,  0,  0 }, {     20,   17,    0, 16,  0,  0 }, {     22,   17,    0, 16,  0,  0 },
    {     24,   17,    0, 16,  0,  0 }, {     26,   17,    0, 16,  0,  0 }, {     27,   17,    0, 16,  0,  0 }, {     28,   18,    0, 16,  0,  0 }, {     29,   18,    0, 16,  0,  0 },
    {     30,   18,    0, 16,  0,  0 }, {     31,   18,    0, 16,  0,  0 }, {     32,   18,    0, 16,  0,  0 }, {     33,   18,    0, 16,  0,  0 }, {     32,   18,    0, 16,  0,  0 },
    {     31,   18,    0, 16,  0,  0 }, {     30,   18,    0, 16,  0,  0 }, {     29,   18,    0, 16,  0,  0 }, {     28,   18,    0, 16,  0,  0 }, {     27,   18,    0, 16,  0,  0 },
    {     26,   18,    0, 16,  0,  0 }, {     25,   19,    0, 16,  0,  0 }, {     24,   19,    0, 16,  0,  0 }, {     23,   19,    0, 16,  0,  0 }, {     22,   19,    0, 16,  0,  0 },
    {     21,   19,    0, 16,  0,  0 }, {     20,   19,    0, 16,  0,  0 }, {     19,   19,    0, 16,  0,  0 }, {     18,   19,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     17,   19,    0, 16,  0,  0 }, {     19,   19,    0, 16,  0,  0 }, {     22,   19,    0, 16,  0,  0 }, {     25,   19,    0, 16,  0,  0 },
    {     28,   19,    0, 16,  0,  0 }, {     31,   19,    0, 16,  0,  0 }, {     34,   19,    0, 16,  0,  0 }, {     37,   19,    0, 16,  0,  0 }, {     40,   19,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     43,   19,    0, 16,  0,  0 }, {     46,   19,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     49,   15,    0, 16,  0,  0 },
    {     52,   15,    0, 16,  0,  0 }, {     55,   15,    0, 16,  0,  0 }, {     56,   14,    0, 16,  0,  0 }, {     57,   12,    0, 16,  0,  0 }, {     58,   10,    0, 16,  0,  0 },
    {     59,    8,    0, 16,  0,  0 }, {     57,    6,    0, 16,  0,  0 }, {     56,    5,    0, 16,  0,  0 }, {     55,    4,    1, 16,  0,  0 }, {     54,    3,    1, 16,  0,  0 },
    {     53,    2,    1, 16,  0,  0 }, {     52,    1,    1, 16,  0,  0 }, {     51,    1,    1, 16,  0,  0 }, {     50,    1,    1, 16,  0,  0 }, {     49,    1,    1, 16,  0,  0 },
    {     48,    1,    1, 16,  0,  0 }, {     48,    1,    1, 16,  0,  0 }, {     48,    1,    1, 16,  0,  0 }, {     49,    1,    1, 16,  0,  0 }, {     50,    1,    1, 16,  0,  0 },
    {     51,    1,    1, 16,  0,  0 }, {     52,    1,    1, 16,  0,  0 }, {     53,    2,    1, 16,  0,  0 }, {     54,    3,    1, 16,  0,  0 }, {     55,    4,    1, 16,  0,  0 },
    {     56,    5,    0, 16,  0,  0 }, {     57,    6,    0, 16,  0,  0 }, {     59,    8,    0, 16,  0,  0 }, {     58,   10,    0, 16,  0,  0 }, {     57,   12,    0, 16,  0,  0 },
    {     56,   14,    0, 16,  0,  0 }, {     55,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 }, {     49,   15,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     46,   19,    0, 16,  0,  0 }, {     43,   19,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     40,   19,    0, 16,  0,  0 }, {     39,   19,    0, 16,  0,  0 },
    {     38,   19,    0, 16,  0,  0 }, {     37,   19,    0, 16,  0,  0 }, {     36,   19,    0, 16,  0,  0 }, {     35,   19,    0, 16,  0,  0 }, {     34,   19,    0, 16,  0,  0 },
    {     33,   19,    0, 16,  0,  0 }, {     32,   19,    0, 16,  0,  0 }, {     31,   19,    0, 16,  0,  0 }, {     30,   19,    0, 16,  0,  0 }, {     29,   19,    0, 16,  0,  0 },
    {     28,   19,    0, 16,  0,  0 }, {     27,   19,    0, 16,  0,  0 }, {     26,   19,    0, 16,  0,  0 }, {     25,   19,    0, 16,  0,  0 }, {     24,   19,    0, 16,  0,  0 },
    {     23,   19,    0, 16,  0,  0 }, {     22,   19,    0, 16,  0,  0 }, {     21,   19,    0, 16,  0,  0 }, {     20,   19,    0, 16,  0,  0 }, {     19,   19,    0, 16,  0,  0 },
    {     18,   19,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     17,   19,    0, 16,  0,  0 }, {     19,   19,    0, 16,  0,  0 },
    {     22,   19,    0, 16,  0,  0 }, {     25,   19,    0, 16,  0,  0 }, {     28,   19,    0, 16,  0,  0 }, {     31,   19,    0, 16,  0,  0 }, {     34,   19,    0, 16,  0,  0 },
    {     37,   19,    0, 16,  0,  0 }, {     40,   19,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     43,   19,    0, 16,  0,  0 }, {     46,   19,    0, 16,  0,  0 },
    MINI_GOLF_ANIMATION(PlaceBallDown), {     49,   15,    0, 16,  0,  0 }, {     52,   15,    0, 16,  0,  0 }, {     55,   15,    0, 16,  0,  0 }, {     56,   14,    0, 16,  0,  0 },
    {     57,   12,    0, 16,  0,  0 }, {     58,   10,    0, 16,  0,  0 }, {     59,    8,    0, 16,  0,  0 }, {     57,    6,    0, 16,  0,  0 }, {     55,    4,    1, 16,  0,  0 },
    {     53,    2,    1, 16,  0,  0 }, {     51,    1,    1, 16,  0,  0 }, {     49,    1,    1, 16,  0,  0 }, {     47,    1,    2, 16,  0,  0 }, {     45,    2,    2, 16,  0,  0 },
    {     45,    4,    2, 16,  0,  0 }, {     44,    6,    2, 16,  0,  0 }, {     43,    8,    3, 16,  0,  0 }, {     43,   10,    3, 16,  0,  0 }, {     42,   12,    3, 16,  0,  0 },
    {     43,   14,    3, 16,  0,  0 }, {     43,   16,    3, 16,  0,  0 }, {     43,   18,    3, 16,  0,  0 }, {     44,   20,    3, 16,  0,  0 }, {     44,   22,    3, 16,  0,  0 },
    {     44,   24,    3, 16,  0,  0 }, {     45,   26,    3, 16,  0,  0 }, {     45,   28,    3, 16,  0,  0 }, {     45,   29,    3, 16,  0,  0 }, {     45,   30,    3, 16,  0,  0 },
    {     46,   31,    3, 16,  0,  0 }, {     46,   32,    3, 16,  0,  0 }, {     46,   33,    3, 16,  0,  0 }, {     46,   34,    3, 16,  0,  0 }, {     46,   35,    3, 16,  0,  0 },
    {     46,   37,    0, 16,  0,  0 }, {     47,   39,    0, 16,  0,  0 }, {     47,   40,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     47,   41,    0, 16,  0,  0 }, {     47,   42,    0, 16,  0,  0 }, {     47,   43,    0, 16,  0,  0 }, {     47,   44,    0, 16,  0,  0 }, {     48,   45,    0, 16,  0,  0 },
    {     48,   46,    0, 16,  0,  0 }, {     48,   47,    0, 16,  0,  0 }, {     48,   48,    0, 16,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {     48,   59,    0,  8,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     48,   59,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_94EAD4, {
    MINI_GOLF_STATE(Unk0),              {     15,   31,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown),
    {     15,   26,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk3),              {     15,   24,    0, 24,  0,  0 }, {     16,   21,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 },
    {     16,   17,    0, 24,  0,  0 }, {     15,   15,    0, 24,  0,  0 }, {     17,   13,    0, 24,  0,  0 }, {     17,   11,    0, 24,  0,  0 }, {     17,    9,    0, 24,  0,  0 },
    {     17,    7,    0, 24,  0,  0 }, {     17,    5,    0, 24,  0,  0 }, {     17,    4,    0, 24,  0,  0 }, {     18,    3,    0, 24,  0,  0 }, {     18,    2,    0, 24,  0,  0 },
    {     18,    1,    0, 24,  0,  0 }, {     18,    0,    0, 24,  0,  0 }, {     18,   -1,    0, 24,  0,  0 }, {     18,   -2,    0, 24,  0,  0 }, {     18,   -1,    0, 24,  0,  0 },
    {     18,    0,    0, 24,  0,  0 }, {     18,    1,    0, 24,  0,  0 }, {     18,    2,    0, 24,  0,  0 }, {     18,    3,    0, 24,  0,  0 }, {     18,    4,    0, 24,  0,  0 },
    {     18,    5,    0, 24,  0,  0 }, {     19,    6,    0, 24,  0,  0 }, {     19,    7,    0, 24,  0,  0 }, {     19,    8,    0, 24,  0,  0 }, {     19,    9,    0, 24,  0,  0 },
    {     19,   10,    0, 24,  0,  0 }, {     19,   11,    0, 24,  0,  0 }, {     19,   12,    0, 24,  0,  0 }, {     19,   13,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),
    MINI_GOLF_STATE(Unk3),              {     19,   14,    0, 24,  0,  0 }, {     19,   12,    0, 24,  0,  0 }, {     19,    9,    0, 24,  0,  0 }, {     19,    6,    0, 24,  0,  0 },
    {     19,    3,    0, 24,  0,  0 }, {     19,    0,    0, 24,  0,  0 }, {     19,   -3,    0, 24,  0,  0 }, {     19,   -6,    0, 24,  0,  0 }, {     19,   -9,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(Walk),          {     19,  -12,    0, 24,  0,  0 }, {     19,  -15,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     15,  -18,    0, 24,  0,  0 },
    {     15,  -21,    0, 24,  0,  0 }, {     15,  -24,    0, 24,  0,  0 }, {     14,  -25,    0, 24,  0,  0 }, {     12,  -26,    0, 24,  0,  0 }, {     10,  -27,    0, 24,  0,  0 },
    {      8,  -28,    0, 24,  0,  0 }, {      6,  -26,    0, 24,  0,  0 }, {      5,  -25,    0, 24,  0,  0 }, {      4,  -24,    1, 24,  0,  0 }, {      3,  -23,    1, 24,  0,  0 },
    {      2,  -22,    1, 24,  0,  0 }, {      1,  -21,    1, 24,  0,  0 }, {      1,  -20,    1, 24,  0,  0 }, {      1,  -19,    1, 24,  0,  0 }, {      1,  -18,    1, 24,  0,  0 },
    {      1,  -17,    1, 24,  0,  0 }, {      1,  -17,    1, 24,  0,  0 }, {      1,  -17,    1, 24,  0,  0 }, {      1,  -18,    1, 24,  0,  0 }, {      1,  -19,    1, 24,  0,  0 },
    {      1,  -20,    1, 24,  0,  0 }, {      1,  -21,    1, 24,  0,  0 }, {      2,  -22,    1, 24,  0,  0 }, {      3,  -23,    1, 24,  0,  0 }, {      4,  -24,    1, 24,  0,  0 },
    {      5,  -25,    0, 24,  0,  0 }, {      6,  -26,    0, 24,  0,  0 }, {      8,  -28,    0, 24,  0,  0 }, {     10,  -27,    0, 24,  0,  0 }, {     12,  -26,    0, 24,  0,  0 },
    {     14,  -25,    0, 24,  0,  0 }, {     15,  -24,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 }, {     15,  -18,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),
    {     19,  -15,    0, 24,  0,  0 }, {     19,  -12,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(PlaceBallDown), {     19,   -9,    0, 24,  0,  0 }, {     19,   -8,    0, 24,  0,  0 },
    {     19,   -7,    0, 24,  0,  0 }, {     19,   -6,    0, 24,  0,  0 }, {     19,   -5,    0, 24,  0,  0 }, {     19,   -4,    0, 24,  0,  0 }, {     19,   -3,    0, 24,  0,  0 },
    {     19,   -2,    0, 24,  0,  0 }, {     19,   -1,    0, 24,  0,  0 }, {     19,    0,    0, 24,  0,  0 }, {     19,    1,    0, 24,  0,  0 }, {     19,    2,    0, 24,  0,  0 },
    {     19,    3,    0, 24,  0,  0 }, {     19,    4,    0, 24,  0,  0 }, {     19,    5,    0, 24,  0,  0 }, {     19,    6,    0, 24,  0,  0 }, {     19,    7,    0, 24,  0,  0 },
    {     19,    8,    0, 24,  0,  0 }, {     19,    9,    0, 24,  0,  0 }, {     19,   10,    0, 24,  0,  0 }, {     19,   11,    0, 24,  0,  0 }, {     19,   12,    0, 24,  0,  0 },
    {     19,   13,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),              {     19,   14,    0, 24,  0,  0 }, {     19,   12,    0, 24,  0,  0 },
    {     19,    9,    0, 24,  0,  0 }, {     19,    6,    0, 24,  0,  0 }, {     19,    3,    0, 24,  0,  0 }, {     19,    0,    0, 24,  0,  0 }, {     19,   -3,    0, 24,  0,  0 },
    {     19,   -6,    0, 24,  0,  0 }, {     19,   -9,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          {     19,  -12,    0, 24,  0,  0 }, {     19,  -15,    0, 24,  0,  0 },
    MINI_GOLF_ANIMATION(PlaceBallDown), {     15,  -18,    0, 24,  0,  0 }, {     15,  -21,    0, 24,  0,  0 }, {     15,  -24,    0, 24,  0,  0 }, {     14,  -25,    0, 24,  0,  0 },
    {     12,  -26,    0, 24,  0,  0 }, {     10,  -27,    0, 24,  0,  0 }, {      8,  -28,    0, 24,  0,  0 }, {      6,  -26,    0, 24,  0,  0 }, {      4,  -24,    1, 24,  0,  0 },
    {      2,  -22,    1, 24,  0,  0 }, {      1,  -20,    1, 24,  0,  0 }, {      1,  -18,    1, 24,  0,  0 }, {      1,  -16,    2, 24,  0,  0 }, {      2,  -14,    2, 24,  0,  0 },
    {      4,  -14,    2, 24,  0,  0 }, {      6,  -13,    2, 24,  0,  0 }, {      8,  -12,    3, 24,  0,  0 }, {     10,  -12,    3, 24,  0,  0 }, {     12,  -11,    3, 24,  0,  0 },
    {     14,  -12,    3, 24,  0,  0 }, {     16,  -12,    3, 24,  0,  0 }, {     18,  -12,    3, 24,  0,  0 }, {     20,  -13,    3, 24,  0,  0 }, {     22,  -13,    3, 24,  0,  0 },
    {     24,  -13,    3, 24,  0,  0 }, {     26,  -14,    3, 24,  0,  0 }, {     28,  -14,    3, 24,  0,  0 }, {     29,  -14,    3, 24,  0,  0 }, {     30,  -14,    3, 24,  0,  0 },
    {     31,  -15,    3, 24,  0,  0 }, {     32,  -15,    3, 24,  0,  0 }, {     33,  -15,    3, 24,  0,  0 }, {     34,  -15,    3, 24,  0,  0 }, {     35,  -15,    3, 24,  0,  0 },
    {     37,  -15,    0, 24,  0,  0 }, {     39,  -16,    0, 24,  0,  0 }, {     40,  -16,    0, 24,  0,  0 }, MINI_GOLF_STATE(Unk2),              MINI_GOLF_STATE(Unk3),
    {     41,  -16,    0, 24,  0,  0 }, {     42,  -16,    0, 24,  0,  0 }, {     43,  -16,    0, 24,  0,  0 }, {     44,  -16,    0, 24,  0,  0 }, {     45,  -17,    0, 24,  0,  0 },
    {     46,  -17,    0, 24,  0,  0 }, {     47,  -17,    0, 24,  0,  0 }, {     48,  -17,    0, 24,  0,  0 }, MINI_GOLF_ANIMATION(Walk),          MINI_GOLF_STATE(Unk2),
    {     59,  -17,    0, 16,  0,  0 }, MINI_GOLF_STATE(Unk6),              MINI_GOLF_STATE(Unk3),              {     59,  -17,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95275E, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     21,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 },
    {     11,   16,    0,  0,  0,  0 }, {     10,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 },
    {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -2,   16,    0,  0,  0,  0 }, {     -3,   16,    0,  0,  0,  0 },
    {     -4,   16,    0,  0,  0,  0 }, {     -5,   16,    0,  0,  0,  0 }, {     -6,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 }, {     -8,   16,    0,  0,  0,  0 },
    {     -9,   16,    0,  0,  0,  0 }, {    -10,   16,    0,  0,  0,  0 }, {    -11,   16,    0,  0,  0,  0 }, {    -12,   16,    0,  0,  0,  0 }, {    -13,   16,    0,  0,  0,  0 },
    {    -14,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, {    -16,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 }, {    -18,   16,    0,  0,  0,  0 },
    {    -19,   16,    0,  0,  0,  0 }, {    -20,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -22,   16,    0,  0,  0,  0 }, {    -23,   16,    0,  0,  0,  0 },
    {    -24,   16,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 }, {    -26,   16,    0,  0,  0,  0 }, {    -27,   16,    0,  0,  0,  0 }, {    -28,   16,    0,  0,  0,  0 },
    {    -29,   16,    0,  0,  0,  0 }, {    -30,   16,    0,  0,  0,  0 }, {    -31,   16,    0,  0,  0,  0 }, {    -32,   16,    0,  0,  0,  0 }, {    -33,   16,    0,  0,  0,  0 },
    {    -34,   16,    0,  0,  0,  0 }, {    -35,   16,    0,  0,  0,  0 }, {    -36,   16,    0,  0,  0,  0 }, {    -37,   16,    0,  0,  0,  0 }, {    -38,   16,    0,  0,  0,  0 },
    {    -39,   16,    0,  0,  0,  0 }, {    -40,   16,    0,  0,  0,  0 }, {    -41,   16,    0,  0,  0,  0 }, {    -42,   16,    0,  0,  0,  0 }, {    -43,   16,    0,  0,  0,  0 },
    {    -44,   16,    0,  0,  0,  0 }, {    -45,   16,    0,  0,  0,  0 }, {    -46,   16,    0,  0,  0,  0 }, {    -47,   16,    0,  0,  0,  0 }, {    -48,   16,    0,  0,  0,  0 },
    {    -49,   16,    0,  0,  0,  0 }, {    -50,   16,    0,  0,  0,  0 }, {    -51,   16,    0,  0,  0,  0 }, {    -52,   16,    0,  0,  0,  0 }, {    -53,   16,    0,  0,  0,  0 },
    {    -54,   16,    0,  0,  0,  0 }, {    -55,   16,    0,  0,  0,  0 }, {    -56,   16,    0,  0,  0,  0 }, {    -57,   16,    0,  0,  0,  0 }, {    -58,   16,    0,  0,  0,  0 },
    {    -59,   16,    0,  0,  0,  0 }, {    -60,   16,    0,  0,  0,  0 }, {    -61,   16,    0,  0,  0,  0 }, {    -62,   16,    0,  0,  0,  0 }, {    -63,   16,    0,  0,  0,  0 },
    {    -64,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_952AC0, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   15,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   17,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   19,    0,  8,  0,  0 },
    {     16,   20,    0,  8,  0,  0 }, {     16,   21,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   29,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     16,   33,    0,  8,  0,  0 }, {     16,   34,    0,  8,  0,  0 },
    {     16,   35,    0,  8,  0,  0 }, {     16,   36,    0,  8,  0,  0 }, {     16,   37,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 }, {     16,   39,    0,  8,  0,  0 },
    {     16,   40,    0,  8,  0,  0 }, {     16,   41,    0,  8,  0,  0 }, {     16,   42,    0,  8,  0,  0 }, {     16,   43,    0,  8,  0,  0 }, {     16,   44,    0,  8,  0,  0 },
    {     16,   45,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, {     16,   47,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 }, {     16,   49,    0,  8,  0,  0 },
    {     16,   50,    0,  8,  0,  0 }, {     16,   51,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   53,    0,  8,  0,  0 }, {     16,   54,    0,  8,  0,  0 },
    {     16,   55,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 }, {     16,   57,    0,  8,  0,  0 }, {     16,   58,    0,  8,  0,  0 }, {     16,   59,    0,  8,  0,  0 },
    {     16,   60,    0,  8,  0,  0 }, {     16,   61,    0,  8,  0,  0 }, {     16,   62,    0,  8,  0,  0 }, {     16,   63,    0,  8,  0,  0 }, {     16,   64,    0,  8,  0,  0 },
    {     16,   65,    0,  8,  0,  0 }, {     16,   66,    0,  8,  0,  0 }, {     16,   67,    0,  8,  0,  0 }, {     16,   68,    0,  8,  0,  0 }, {     16,   69,    0,  8,  0,  0 },
    {     16,   70,    0,  8,  0,  0 }, {     16,   71,    0,  8,  0,  0 }, {     16,   72,    0,  8,  0,  0 }, {     16,   73,    0,  8,  0,  0 }, {     16,   74,    0,  8,  0,  0 },
    {     16,   75,    0,  8,  0,  0 }, {     16,   76,    0,  8,  0,  0 }, {     16,   77,    0,  8,  0,  0 }, {     16,   78,    0,  8,  0,  0 }, {     16,   79,    0,  8,  0,  0 },
    {     16,   80,    0,  8,  0,  0 }, {     16,   81,    0,  8,  0,  0 }, {     16,   82,    0,  8,  0,  0 }, {     16,   83,    0,  8,  0,  0 }, {     16,   84,    0,  8,  0,  0 },
    {     16,   85,    0,  8,  0,  0 }, {     16,   86,    0,  8,  0,  0 }, {     16,   87,    0,  8,  0,  0 }, {     16,   88,    0,  8,  0,  0 }, {     16,   89,    0,  8,  0,  0 },
    {     16,   90,    0,  8,  0,  0 }, {     16,   91,    0,  8,  0,  0 }, {     16,   92,    0,  8,  0,  0 }, {     16,   93,    0,  8,  0,  0 }, {     16,   94,    0,  8,  0,  0 },
    {     16,   95,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_952E22, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 }, {      9,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     13,   16,    0, 16,  0,  0 }, {     14,   16,    0, 16,  0,  0 },
    {     15,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     17,   16,    0, 16,  0,  0 }, {     18,   16,    0, 16,  0,  0 }, {     19,   16,    0, 16,  0,  0 },
    {     20,   16,    0, 16,  0,  0 }, {     21,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 },
    {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 }, {     29,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 }, {     32,   16,    0, 16,  0,  0 }, {     33,   16,    0, 16,  0,  0 }, {     34,   16,    0, 16,  0,  0 },
    {     35,   16,    0, 16,  0,  0 }, {     36,   16,    0, 16,  0,  0 }, {     37,   16,    0, 16,  0,  0 }, {     38,   16,    0, 16,  0,  0 }, {     39,   16,    0, 16,  0,  0 },
    {     40,   16,    0, 16,  0,  0 }, {     41,   16,    0, 16,  0,  0 }, {     42,   16,    0, 16,  0,  0 }, {     43,   16,    0, 16,  0,  0 }, {     44,   16,    0, 16,  0,  0 },
    {     45,   16,    0, 16,  0,  0 }, {     46,   16,    0, 16,  0,  0 }, {     47,   16,    0, 16,  0,  0 }, {     48,   16,    0, 16,  0,  0 }, {     49,   16,    0, 16,  0,  0 },
    {     50,   16,    0, 16,  0,  0 }, {     51,   16,    0, 16,  0,  0 }, {     52,   16,    0, 16,  0,  0 }, {     53,   16,    0, 16,  0,  0 }, {     54,   16,    0, 16,  0,  0 },
    {     55,   16,    0, 16,  0,  0 }, {     56,   16,    0, 16,  0,  0 }, {     57,   16,    0, 16,  0,  0 }, {     58,   16,    0, 16,  0,  0 }, {     59,   16,    0, 16,  0,  0 },
    {     60,   16,    0, 16,  0,  0 }, {     61,   16,    0, 16,  0,  0 }, {     62,   16,    0, 16,  0,  0 }, {     63,   16,    0, 16,  0,  0 }, {     64,   16,    0, 16,  0,  0 },
    {     65,   16,    0, 16,  0,  0 }, {     66,   16,    0, 16,  0,  0 }, {     67,   16,    0, 16,  0,  0 }, {     68,   16,    0, 16,  0,  0 }, {     69,   16,    0, 16,  0,  0 },
    {     70,   16,    0, 16,  0,  0 }, {     71,   16,    0, 16,  0,  0 }, {     72,   16,    0, 16,  0,  0 }, {     73,   16,    0, 16,  0,  0 }, {     74,   16,    0, 16,  0,  0 },
    {     75,   16,    0, 16,  0,  0 }, {     76,   16,    0, 16,  0,  0 }, {     77,   16,    0, 16,  0,  0 }, {     78,   16,    0, 16,  0,  0 }, {     79,   16,    0, 16,  0,  0 },
    {     80,   16,    0, 16,  0,  0 }, {     81,   16,    0, 16,  0,  0 }, {     82,   16,    0, 16,  0,  0 }, {     83,   16,    0, 16,  0,  0 }, {     84,   16,    0, 16,  0,  0 },
    {     85,   16,    0, 16,  0,  0 }, {     86,   16,    0, 16,  0,  0 }, {     87,   16,    0, 16,  0,  0 }, {     88,   16,    0, 16,  0,  0 }, {     89,   16,    0, 16,  0,  0 },
    {     90,   16,    0, 16,  0,  0 }, {     91,   16,    0, 16,  0,  0 }, {     92,   16,    0, 16,  0,  0 }, {     93,   16,    0, 16,  0,  0 }, {     94,   16,    0, 16,  0,  0 },
    {     95,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_953184, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   21,    0, 24,  0,  0 }, {     16,   20,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 }, {     16,   17,    0, 24,  0,  0 },
    {     16,   16,    0, 24,  0,  0 }, {     16,   15,    0, 24,  0,  0 }, {     16,   14,    0, 24,  0,  0 }, {     16,   13,    0, 24,  0,  0 }, {     16,   12,    0, 24,  0,  0 },
    {     16,   11,    0, 24,  0,  0 }, {     16,   10,    0, 24,  0,  0 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 }, {     16,    7,    0, 24,  0,  0 },
    {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 }, {     16,   -1,    0, 24,  0,  0 }, {     16,   -2,    0, 24,  0,  0 }, {     16,   -3,    0, 24,  0,  0 },
    {     16,   -4,    0, 24,  0,  0 }, {     16,   -5,    0, 24,  0,  0 }, {     16,   -6,    0, 24,  0,  0 }, {     16,   -7,    0, 24,  0,  0 }, {     16,   -8,    0, 24,  0,  0 },
    {     16,   -9,    0, 24,  0,  0 }, {     16,  -10,    0, 24,  0,  0 }, {     16,  -11,    0, 24,  0,  0 }, {     16,  -12,    0, 24,  0,  0 }, {     16,  -13,    0, 24,  0,  0 },
    {     16,  -14,    0, 24,  0,  0 }, {     16,  -15,    0, 24,  0,  0 }, {     16,  -16,    0, 24,  0,  0 }, {     16,  -17,    0, 24,  0,  0 }, {     16,  -18,    0, 24,  0,  0 },
    {     16,  -19,    0, 24,  0,  0 }, {     16,  -20,    0, 24,  0,  0 }, {     16,  -21,    0, 24,  0,  0 }, {     16,  -22,    0, 24,  0,  0 }, {     16,  -23,    0, 24,  0,  0 },
    {     16,  -24,    0, 24,  0,  0 }, {     16,  -25,    0, 24,  0,  0 }, {     16,  -26,    0, 24,  0,  0 }, {     16,  -27,    0, 24,  0,  0 }, {     16,  -28,    0, 24,  0,  0 },
    {     16,  -29,    0, 24,  0,  0 }, {     16,  -30,    0, 24,  0,  0 }, {     16,  -31,    0, 24,  0,  0 }, {     16,  -32,    0, 24,  0,  0 }, {     16,  -33,    0, 24,  0,  0 },
    {     16,  -34,    0, 24,  0,  0 }, {     16,  -35,    0, 24,  0,  0 }, {     16,  -36,    0, 24,  0,  0 }, {     16,  -37,    0, 24,  0,  0 }, {     16,  -38,    0, 24,  0,  0 },
    {     16,  -39,    0, 24,  0,  0 }, {     16,  -40,    0, 24,  0,  0 }, {     16,  -41,    0, 24,  0,  0 }, {     16,  -42,    0, 24,  0,  0 }, {     16,  -43,    0, 24,  0,  0 },
    {     16,  -44,    0, 24,  0,  0 }, {     16,  -45,    0, 24,  0,  0 }, {     16,  -46,    0, 24,  0,  0 }, {     16,  -47,    0, 24,  0,  0 }, {     16,  -48,    0, 24,  0,  0 },
    {     16,  -49,    0, 24,  0,  0 }, {     16,  -50,    0, 24,  0,  0 }, {     16,  -51,    0, 24,  0,  0 }, {     16,  -52,    0, 24,  0,  0 }, {     16,  -53,    0, 24,  0,  0 },
    {     16,  -54,    0, 24,  0,  0 }, {     16,  -55,    0, 24,  0,  0 }, {     16,  -56,    0, 24,  0,  0 }, {     16,  -57,    0, 24,  0,  0 }, {     16,  -58,    0, 24,  0,  0 },
    {     16,  -59,    0, 24,  0,  0 }, {     16,  -60,    0, 24,  0,  0 }, {     16,  -61,    0, 24,  0,  0 }, {     16,  -62,    0, 24,  0,  0 }, {     16,  -63,    0, 24,  0,  0 },
    {     16,  -64,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9534E6, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     21,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 },
    {     11,   16,    0,  0,  0,  0 }, {     10,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 },
    {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -2,   16,    0,  0,  0,  0 }, {     -3,   16,    0,  0,  0,  0 },
    {     -4,   16,    0,  0,  0,  0 }, {     -5,   16,    0,  0,  0,  0 }, {     -6,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 }, {     -8,   16,    0,  0,  0,  0 },
    {     -9,   16,    0,  0,  0,  0 }, {    -10,   16,    0,  0,  0,  0 }, {    -11,   16,    0,  0,  0,  0 }, {    -12,   16,    0,  0,  0,  0 }, {    -13,   16,    0,  0,  0,  0 },
    {    -14,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, {    -16,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 }, {    -18,   16,    0,  0,  0,  0 },
    {    -19,   16,    0,  0,  0,  0 }, {    -20,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -22,   16,    0,  0,  0,  0 }, {    -23,   16,    0,  0,  0,  0 },
    {    -24,   16,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 }, {    -26,   16,    0,  0,  0,  0 }, {    -27,   16,    0,  0,  0,  0 }, {    -28,   16,    0,  0,  0,  0 },
    {    -29,   16,    0,  0,  0,  0 }, {    -30,   16,    0,  0,  0,  0 }, {    -31,   16,    0,  0,  0,  0 }, {    -32,   16,    0,  0,  0,  0 }, {    -33,   16,    0,  0,  0,  0 },
    {    -34,   16,    0,  0,  0,  0 }, {    -35,   16,    0,  0,  0,  0 }, {    -36,   16,    0,  0,  0,  0 }, {    -37,   16,    0,  0,  0,  0 }, {    -38,   16,    0,  0,  0,  0 },
    {    -39,   16,    0,  0,  0,  0 }, {    -40,   16,    0,  0,  0,  0 }, {    -41,   16,    0,  0,  0,  0 }, {    -42,   16,    0,  0,  0,  0 }, {    -43,   16,    0,  0,  0,  0 },
    {    -44,   16,    0,  0,  0,  0 }, {    -45,   16,    0,  0,  0,  0 }, {    -46,   16,    0,  0,  0,  0 }, {    -47,   16,    0,  0,  0,  0 }, {    -48,   16,    0,  0,  0,  0 },
    {    -49,   16,    0,  0,  0,  0 }, {    -50,   16,    0,  0,  0,  0 }, {    -51,   16,    0,  0,  0,  0 }, {    -52,   16,    0,  0,  0,  0 }, {    -53,   16,    0,  0,  0,  0 },
    {    -54,   16,    0,  0,  0,  0 }, {    -55,   16,    0,  0,  0,  0 }, {    -56,   16,    0,  0,  0,  0 }, {    -57,   16,    0,  0,  0,  0 }, {    -58,   16,    0,  0,  0,  0 },
    {    -59,   16,    0,  0,  0,  0 }, {    -60,   16,    0,  0,  0,  0 }, {    -61,   16,    0,  0,  0,  0 }, {    -62,   16,    0,  0,  0,  0 }, {    -63,   16,    0,  0,  0,  0 },
    {    -64,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_953848, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   15,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   17,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   19,    0,  8,  0,  0 },
    {     16,   20,    0,  8,  0,  0 }, {     16,   21,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   29,    0,  8,  0,  0 },
    {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     16,   33,    0,  8,  0,  0 }, {     16,   34,    0,  8,  0,  0 },
    {     16,   35,    0,  8,  0,  0 }, {     16,   36,    0,  8,  0,  0 }, {     16,   37,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 }, {     16,   39,    0,  8,  0,  0 },
    {     16,   40,    0,  8,  0,  0 }, {     16,   41,    0,  8,  0,  0 }, {     16,   42,    0,  8,  0,  0 }, {     16,   43,    0,  8,  0,  0 }, {     16,   44,    0,  8,  0,  0 },
    {     16,   45,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, {     16,   47,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 }, {     16,   49,    0,  8,  0,  0 },
    {     16,   50,    0,  8,  0,  0 }, {     16,   51,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   53,    0,  8,  0,  0 }, {     16,   54,    0,  8,  0,  0 },
    {     16,   55,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 }, {     16,   57,    0,  8,  0,  0 }, {     16,   58,    0,  8,  0,  0 }, {     16,   59,    0,  8,  0,  0 },
    {     16,   60,    0,  8,  0,  0 }, {     16,   61,    0,  8,  0,  0 }, {     16,   62,    0,  8,  0,  0 }, {     16,   63,    0,  8,  0,  0 }, {     16,   64,    0,  8,  0,  0 },
    {     16,   65,    0,  8,  0,  0 }, {     16,   66,    0,  8,  0,  0 }, {     16,   67,    0,  8,  0,  0 }, {     16,   68,    0,  8,  0,  0 }, {     16,   69,    0,  8,  0,  0 },
    {     16,   70,    0,  8,  0,  0 }, {     16,   71,    0,  8,  0,  0 }, {     16,   72,    0,  8,  0,  0 }, {     16,   73,    0,  8,  0,  0 }, {     16,   74,    0,  8,  0,  0 },
    {     16,   75,    0,  8,  0,  0 }, {     16,   76,    0,  8,  0,  0 }, {     16,   77,    0,  8,  0,  0 }, {     16,   78,    0,  8,  0,  0 }, {     16,   79,    0,  8,  0,  0 },
    {     16,   80,    0,  8,  0,  0 }, {     16,   81,    0,  8,  0,  0 }, {     16,   82,    0,  8,  0,  0 }, {     16,   83,    0,  8,  0,  0 }, {     16,   84,    0,  8,  0,  0 },
    {     16,   85,    0,  8,  0,  0 }, {     16,   86,    0,  8,  0,  0 }, {     16,   87,    0,  8,  0,  0 }, {     16,   88,    0,  8,  0,  0 }, {     16,   89,    0,  8,  0,  0 },
    {     16,   90,    0,  8,  0,  0 }, {     16,   91,    0,  8,  0,  0 }, {     16,   92,    0,  8,  0,  0 }, {     16,   93,    0,  8,  0,  0 }, {     16,   94,    0,  8,  0,  0 },
    {     16,   95,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_953BAA, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 }, {      9,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     13,   16,    0, 16,  0,  0 }, {     14,   16,    0, 16,  0,  0 },
    {     15,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     17,   16,    0, 16,  0,  0 }, {     18,   16,    0, 16,  0,  0 }, {     19,   16,    0, 16,  0,  0 },
    {     20,   16,    0, 16,  0,  0 }, {     21,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 },
    {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 }, {     29,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 }, {     32,   16,    0, 16,  0,  0 }, {     33,   16,    0, 16,  0,  0 }, {     34,   16,    0, 16,  0,  0 },
    {     35,   16,    0, 16,  0,  0 }, {     36,   16,    0, 16,  0,  0 }, {     37,   16,    0, 16,  0,  0 }, {     38,   16,    0, 16,  0,  0 }, {     39,   16,    0, 16,  0,  0 },
    {     40,   16,    0, 16,  0,  0 }, {     41,   16,    0, 16,  0,  0 }, {     42,   16,    0, 16,  0,  0 }, {     43,   16,    0, 16,  0,  0 }, {     44,   16,    0, 16,  0,  0 },
    {     45,   16,    0, 16,  0,  0 }, {     46,   16,    0, 16,  0,  0 }, {     47,   16,    0, 16,  0,  0 }, {     48,   16,    0, 16,  0,  0 }, {     49,   16,    0, 16,  0,  0 },
    {     50,   16,    0, 16,  0,  0 }, {     51,   16,    0, 16,  0,  0 }, {     52,   16,    0, 16,  0,  0 }, {     53,   16,    0, 16,  0,  0 }, {     54,   16,    0, 16,  0,  0 },
    {     55,   16,    0, 16,  0,  0 }, {     56,   16,    0, 16,  0,  0 }, {     57,   16,    0, 16,  0,  0 }, {     58,   16,    0, 16,  0,  0 }, {     59,   16,    0, 16,  0,  0 },
    {     60,   16,    0, 16,  0,  0 }, {     61,   16,    0, 16,  0,  0 }, {     62,   16,    0, 16,  0,  0 }, {     63,   16,    0, 16,  0,  0 }, {     64,   16,    0, 16,  0,  0 },
    {     65,   16,    0, 16,  0,  0 }, {     66,   16,    0, 16,  0,  0 }, {     67,   16,    0, 16,  0,  0 }, {     68,   16,    0, 16,  0,  0 }, {     69,   16,    0, 16,  0,  0 },
    {     70,   16,    0, 16,  0,  0 }, {     71,   16,    0, 16,  0,  0 }, {     72,   16,    0, 16,  0,  0 }, {     73,   16,    0, 16,  0,  0 }, {     74,   16,    0, 16,  0,  0 },
    {     75,   16,    0, 16,  0,  0 }, {     76,   16,    0, 16,  0,  0 }, {     77,   16,    0, 16,  0,  0 }, {     78,   16,    0, 16,  0,  0 }, {     79,   16,    0, 16,  0,  0 },
    {     80,   16,    0, 16,  0,  0 }, {     81,   16,    0, 16,  0,  0 }, {     82,   16,    0, 16,  0,  0 }, {     83,   16,    0, 16,  0,  0 }, {     84,   16,    0, 16,  0,  0 },
    {     85,   16,    0, 16,  0,  0 }, {     86,   16,    0, 16,  0,  0 }, {     87,   16,    0, 16,  0,  0 }, {     88,   16,    0, 16,  0,  0 }, {     89,   16,    0, 16,  0,  0 },
    {     90,   16,    0, 16,  0,  0 }, {     91,   16,    0, 16,  0,  0 }, {     92,   16,    0, 16,  0,  0 }, {     93,   16,    0, 16,  0,  0 }, {     94,   16,    0, 16,  0,  0 },
    {     95,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_953F0C, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   21,    0, 24,  0,  0 }, {     16,   20,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 }, {     16,   17,    0, 24,  0,  0 },
    {     16,   16,    0, 24,  0,  0 }, {     16,   15,    0, 24,  0,  0 }, {     16,   14,    0, 24,  0,  0 }, {     16,   13,    0, 24,  0,  0 }, {     16,   12,    0, 24,  0,  0 },
    {     16,   11,    0, 24,  0,  0 }, {     16,   10,    0, 24,  0,  0 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 }, {     16,    7,    0, 24,  0,  0 },
    {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 }, {     16,   -1,    0, 24,  0,  0 }, {     16,   -2,    0, 24,  0,  0 }, {     16,   -3,    0, 24,  0,  0 },
    {     16,   -4,    0, 24,  0,  0 }, {     16,   -5,    0, 24,  0,  0 }, {     16,   -6,    0, 24,  0,  0 }, {     16,   -7,    0, 24,  0,  0 }, {     16,   -8,    0, 24,  0,  0 },
    {     16,   -9,    0, 24,  0,  0 }, {     16,  -10,    0, 24,  0,  0 }, {     16,  -11,    0, 24,  0,  0 }, {     16,  -12,    0, 24,  0,  0 }, {     16,  -13,    0, 24,  0,  0 },
    {     16,  -14,    0, 24,  0,  0 }, {     16,  -15,    0, 24,  0,  0 }, {     16,  -16,    0, 24,  0,  0 }, {     16,  -17,    0, 24,  0,  0 }, {     16,  -18,    0, 24,  0,  0 },
    {     16,  -19,    0, 24,  0,  0 }, {     16,  -20,    0, 24,  0,  0 }, {     16,  -21,    0, 24,  0,  0 }, {     16,  -22,    0, 24,  0,  0 }, {     16,  -23,    0, 24,  0,  0 },
    {     16,  -24,    0, 24,  0,  0 }, {     16,  -25,    0, 24,  0,  0 }, {     16,  -26,    0, 24,  0,  0 }, {     16,  -27,    0, 24,  0,  0 }, {     16,  -28,    0, 24,  0,  0 },
    {     16,  -29,    0, 24,  0,  0 }, {     16,  -30,    0, 24,  0,  0 }, {     16,  -31,    0, 24,  0,  0 }, {     16,  -32,    0, 24,  0,  0 }, {     16,  -33,    0, 24,  0,  0 },
    {     16,  -34,    0, 24,  0,  0 }, {     16,  -35,    0, 24,  0,  0 }, {     16,  -36,    0, 24,  0,  0 }, {     16,  -37,    0, 24,  0,  0 }, {     16,  -38,    0, 24,  0,  0 },
    {     16,  -39,    0, 24,  0,  0 }, {     16,  -40,    0, 24,  0,  0 }, {     16,  -41,    0, 24,  0,  0 }, {     16,  -42,    0, 24,  0,  0 }, {     16,  -43,    0, 24,  0,  0 },
    {     16,  -44,    0, 24,  0,  0 }, {     16,  -45,    0, 24,  0,  0 }, {     16,  -46,    0, 24,  0,  0 }, {     16,  -47,    0, 24,  0,  0 }, {     16,  -48,    0, 24,  0,  0 },
    {     16,  -49,    0, 24,  0,  0 }, {     16,  -50,    0, 24,  0,  0 }, {     16,  -51,    0, 24,  0,  0 }, {     16,  -52,    0, 24,  0,  0 }, {     16,  -53,    0, 24,  0,  0 },
    {     16,  -54,    0, 24,  0,  0 }, {     16,  -55,    0, 24,  0,  0 }, {     16,  -56,    0, 24,  0,  0 }, {     16,  -57,    0, 24,  0,  0 }, {     16,  -58,    0, 24,  0,  0 },
    {     16,  -59,    0, 24,  0,  0 }, {     16,  -60,    0, 24,  0,  0 }, {     16,  -61,    0, 24,  0,  0 }, {     16,  -62,    0, 24,  0,  0 }, {     16,  -63,    0, 24,  0,  0 },
    {     16,  -64,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_95426E, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     21,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 },
    {     11,   16,    0,  0,  0,  0 }, {     10,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 },
    {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0,  2,  0,  0 }, {      0,   16,    0,  2,  0,  0 }, {     -1,   16,    0,  2,  0,  0 }, {     -2,   16,    0,  2,  0,  0 }, {     -3,   16,    0,  2,  0,  0 },
    {     -4,   16,    0,  2,  0,  0 }, {     -5,   16,    0,  2,  0,  0 }, {     -6,   16,    0,  2,  0,  0 }, {     -7,   16,    0,  2,  0,  0 }, {     -8,   16,    0,  2,  0,  0 },
    {     -9,   16,    0,  4,  0,  0 }, {    -10,   16,    0,  4,  0,  0 }, {    -11,   16,    0,  4,  0,  0 }, {    -12,   16,    0,  4,  0,  0 }, {    -13,   16,    0,  4,  0,  0 },
    {    -14,   16,    0,  4,  0,  0 }, {    -15,   16,    0,  4,  0,  0 }, {    -16,   16,    0,  4,  0,  0 }, {    -17,   16,    0,  4,  0,  0 }, {    -18,   16,    0,  4,  0,  0 },
    {    -19,   16,    0,  6,  0,  0 }, {    -20,   16,    0,  6,  0,  0 }, {    -21,   16,    0,  6,  0,  0 }, {    -22,   16,    0,  6,  0,  0 }, {    -23,   16,    0,  6,  0,  0 },
    {    -24,   16,    0,  6,  0,  0 }, {    -25,   16,    0,  6,  0,  0 }, {    -26,   16,    0,  8,  0,  0 }, {    -27,   16,    0,  8,  0,  0 }, {    -28,   16,    0,  8,  0,  0 },
    {    -29,   16,    0,  8,  0,  0 }, {    -30,   16,    0,  8,  0,  0 }, {    -31,   16,    0,  8,  0,  0 }, {    -32,   16,    0,  8,  0,  0 }, {    -33,   16,    0,  8,  0,  0 },
    {    -34,   16,    0,  8,  0,  0 }, {    -35,   16,    0,  8,  0,  0 }, {    -36,   16,    0, 10,  0,  0 }, {    -37,   16,    0, 10,  0,  0 }, {    -38,   16,    0, 10,  0,  0 },
    {    -39,   16,    0, 10,  0,  0 }, {    -40,   16,    0, 10,  0,  0 }, {    -41,   16,    0, 10,  0,  0 }, {    -42,   16,    0, 10,  0,  0 }, {    -43,   16,    0, 12,  0,  0 },
    {    -44,   16,    0, 12,  0,  0 }, {    -45,   16,    0, 12,  0,  0 }, {    -46,   16,    0, 12,  0,  0 }, {    -47,   16,    0, 12,  0,  0 }, {    -48,   16,    0, 12,  0,  0 },
    {    -49,   16,    0, 12,  0,  0 }, {    -50,   16,    0, 12,  0,  0 }, {    -51,   16,    0, 12,  0,  0 }, {    -52,   16,    0, 12,  0,  0 }, {    -53,   16,    0, 14,  0,  0 },
    {    -54,   16,    0, 14,  0,  0 }, {    -55,   16,    0, 14,  0,  0 }, {    -56,   16,    0, 14,  0,  0 }, {    -57,   16,    0, 14,  0,  0 }, {    -58,   16,    0, 14,  0,  0 },
    {    -59,   16,    0, 14,  0,  0 }, {    -60,   16,    0, 14,  0,  0 }, {    -61,   16,    0, 14,  0,  0 }, {    -62,   16,    0, 14,  0,  0 }, {    -63,   16,    0, 16,  0,  0 },
    {    -64,   16,    0, 16,  0,  0 }, {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 },
    {     27,   16,    0,  0,  0,  0 }, {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 },
    {     22,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 },
    {     17,   16,    0,  0,  0,  0 }, {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 },
    {     12,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {     10,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 },
    {      7,   16,    0,  0,  0,  0 }, {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 },
    {      2,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -2,   16,    0,  0,  0,  0 },
    {     -3,   16,    0,  0,  0,  0 }, {     -4,   16,    0,  0,  0,  0 }, {     -5,   16,    0,  0,  0,  0 }, {     -6,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 },
    {     -8,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, {    -10,   16,    0,  0,  0,  0 }, {    -11,   16,    0,  0,  0,  0 }, {    -12,   16,    0,  0,  0,  0 },
    {    -13,   16,    0,  0,  0,  0 }, {    -14,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, {    -16,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 },
    {    -18,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 }, {    -20,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -22,   16,    0,  0,  0,  0 },
    {    -23,   16,    0,  0,  0,  0 }, {    -24,   16,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 }, {    -26,   16,    0,  0,  0,  0 }, {    -27,   16,    0,  0,  0,  0 },
    {    -28,   16,    0,  0,  0,  0 }, {    -29,   16,    0,  0,  0,  0 }, {    -30,   16,    0,  0,  0,  0 }, {    -31,   16,    0,  0,  0,  0 }, {    -32,   16,    0,  0,  0,  0 },
    {    -33,   16,    0,  0,  0,  0 }, {    -34,   16,    0,  0,  0,  0 }, {    -35,   16,    0,  0,  0,  0 }, {    -36,   16,    0,  0,  0,  0 }, {    -37,   16,    0,  0,  0,  0 },
    {    -38,   16,    0,  0,  0,  0 }, {    -39,   16,    0,  0,  0,  0 }, {    -40,   16,    0,  0,  0,  0 }, {    -41,   16,    0,  0,  0,  0 }, {    -42,   16,    0,  0,  0,  0 },
    {    -43,   16,    0,  0,  0,  0 }, {    -44,   16,    0,  0,  0,  0 }, {    -45,   16,    0,  0,  0,  0 }, {    -46,   16,    0,  0,  0,  0 }, {    -47,   16,    0,  0,  0,  0 },
    {    -48,   16,    0,  0,  0,  0 }, {    -49,   16,    0,  0,  0,  0 }, {    -50,   16,    0,  0,  0,  0 }, {    -51,   16,    0,  0,  0,  0 }, {    -52,   16,    0,  0,  0,  0 },
    {    -53,   16,    0,  0,  0,  0 }, {    -54,   16,    0,  0,  0,  0 }, {    -55,   16,    0,  0,  0,  0 }, {    -56,   16,    0,  0,  0,  0 }, {    -57,   16,    0,  0,  0,  0 },
    {    -58,   16,    0,  0,  0,  0 }, {    -59,   16,    0,  0,  0,  0 }, {    -60,   16,    0,  0,  0,  0 }, {    -61,   16,    0,  0,  0,  0 }, {    -62,   16,    0,  0,  0,  0 },
    {    -63,   16,    0,  0,  0,  0 }, {    -64,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_954930, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   15,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   17,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   19,    0,  8,  0,  0 },
    {     16,   20,    0,  8,  0,  0 }, {     16,   21,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   29,    0,  8,  0,  0 },
    {     16,   30,    0, 10,  0,  0 }, {     16,   31,    0, 10,  0,  0 }, {     16,   32,    0, 10,  0,  0 }, {     16,   33,    0, 10,  0,  0 }, {     16,   34,    0, 10,  0,  0 },
    {     16,   35,    0, 10,  0,  0 }, {     16,   36,    0, 10,  0,  0 }, {     16,   37,    0, 10,  0,  0 }, {     16,   38,    0, 10,  0,  0 }, {     16,   39,    0, 10,  0,  0 },
    {     16,   40,    0, 12,  0,  0 }, {     16,   41,    0, 12,  0,  0 }, {     16,   42,    0, 12,  0,  0 }, {     16,   43,    0, 12,  0,  0 }, {     16,   44,    0, 12,  0,  0 },
    {     16,   45,    0, 12,  0,  0 }, {     16,   46,    0, 12,  0,  0 }, {     16,   47,    0, 12,  0,  0 }, {     16,   48,    0, 12,  0,  0 }, {     16,   49,    0, 12,  0,  0 },
    {     16,   50,    0, 14,  0,  0 }, {     16,   51,    0, 14,  0,  0 }, {     16,   52,    0, 14,  0,  0 }, {     16,   53,    0, 14,  0,  0 }, {     16,   54,    0, 14,  0,  0 },
    {     16,   55,    0, 14,  0,  0 }, {     16,   56,    0, 14,  0,  0 }, {     16,   57,    0, 16,  0,  0 }, {     16,   58,    0, 16,  0,  0 }, {     16,   59,    0, 16,  0,  0 },
    {     16,   60,    0, 16,  0,  0 }, {     16,   61,    0, 16,  0,  0 }, {     16,   62,    0, 16,  0,  0 }, {     16,   63,    0, 16,  0,  0 }, {     16,   64,    0, 16,  0,  0 },
    {     16,   65,    0, 16,  0,  0 }, {     16,   66,    0, 16,  0,  0 }, {     16,   67,    0, 18,  0,  0 }, {     16,   68,    0, 18,  0,  0 }, {     16,   69,    0, 18,  0,  0 },
    {     16,   70,    0, 18,  0,  0 }, {     16,   71,    0, 18,  0,  0 }, {     16,   72,    0, 18,  0,  0 }, {     16,   73,    0, 18,  0,  0 }, {     16,   74,    0, 20,  0,  0 },
    {     16,   75,    0, 20,  0,  0 }, {     16,   76,    0, 20,  0,  0 }, {     16,   77,    0, 20,  0,  0 }, {     16,   78,    0, 20,  0,  0 }, {     16,   79,    0, 20,  0,  0 },
    {     16,   80,    0, 20,  0,  0 }, {     16,   81,    0, 20,  0,  0 }, {     16,   82,    0, 20,  0,  0 }, {     16,   83,    0, 20,  0,  0 }, {     16,   84,    0, 22,  0,  0 },
    {     16,   85,    0, 22,  0,  0 }, {     16,   86,    0, 22,  0,  0 }, {     16,   87,    0, 22,  0,  0 }, {     16,   88,    0, 22,  0,  0 }, {     16,   89,    0, 22,  0,  0 },
    {     16,   90,    0, 22,  0,  0 }, {     16,   91,    0, 22,  0,  0 }, {     16,   92,    0, 22,  0,  0 }, {     16,   93,    0, 22,  0,  0 }, {     16,   94,    0, 24,  0,  0 },
    {     16,   95,    0, 24,  0,  0 }, {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 },
    {     16,    4,    0,  8,  0,  0 }, {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 },
    {     16,    9,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 },
    {     16,   14,    0,  8,  0,  0 }, {     16,   15,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   17,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 },
    {     16,   19,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   21,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 },
    {     16,   24,    0,  8,  0,  0 }, {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 },
    {     16,   29,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     16,   33,    0,  8,  0,  0 },
    {     16,   34,    0,  8,  0,  0 }, {     16,   35,    0,  8,  0,  0 }, {     16,   36,    0,  8,  0,  0 }, {     16,   37,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 },
    {     16,   39,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, {     16,   41,    0,  8,  0,  0 }, {     16,   42,    0,  8,  0,  0 }, {     16,   43,    0,  8,  0,  0 },
    {     16,   44,    0,  8,  0,  0 }, {     16,   45,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, {     16,   47,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 },
    {     16,   49,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 }, {     16,   51,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   53,    0,  8,  0,  0 },
    {     16,   54,    0,  8,  0,  0 }, {     16,   55,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 }, {     16,   57,    0,  8,  0,  0 }, {     16,   58,    0,  8,  0,  0 },
    {     16,   59,    0,  8,  0,  0 }, {     16,   60,    0,  8,  0,  0 }, {     16,   61,    0,  8,  0,  0 }, {     16,   62,    0,  8,  0,  0 }, {     16,   63,    0,  8,  0,  0 },
    {     16,   64,    0,  8,  0,  0 }, {     16,   65,    0,  8,  0,  0 }, {     16,   66,    0,  8,  0,  0 }, {     16,   67,    0,  8,  0,  0 }, {     16,   68,    0,  8,  0,  0 },
    {     16,   69,    0,  8,  0,  0 }, {     16,   70,    0,  8,  0,  0 }, {     16,   71,    0,  8,  0,  0 }, {     16,   72,    0,  8,  0,  0 }, {     16,   73,    0,  8,  0,  0 },
    {     16,   74,    0,  8,  0,  0 }, {     16,   75,    0,  8,  0,  0 }, {     16,   76,    0,  8,  0,  0 }, {     16,   77,    0,  8,  0,  0 }, {     16,   78,    0,  8,  0,  0 },
    {     16,   79,    0,  8,  0,  0 }, {     16,   80,    0,  8,  0,  0 }, {     16,   81,    0,  8,  0,  0 }, {     16,   82,    0,  8,  0,  0 }, {     16,   83,    0,  8,  0,  0 },
    {     16,   84,    0,  8,  0,  0 }, {     16,   85,    0,  8,  0,  0 }, {     16,   86,    0,  8,  0,  0 }, {     16,   87,    0,  8,  0,  0 }, {     16,   88,    0,  8,  0,  0 },
    {     16,   89,    0,  8,  0,  0 }, {     16,   90,    0,  8,  0,  0 }, {     16,   91,    0,  8,  0,  0 }, {     16,   92,    0,  8,  0,  0 }, {     16,   93,    0,  8,  0,  0 },
    {     16,   94,    0,  8,  0,  0 }, {     16,   95,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_954FF2, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 }, {      9,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     13,   16,    0, 16,  0,  0 }, {     14,   16,    0, 16,  0,  0 },
    {     15,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     17,   16,    0, 16,  0,  0 }, {     18,   16,    0, 16,  0,  0 }, {     19,   16,    0, 16,  0,  0 },
    {     20,   16,    0, 16,  0,  0 }, {     21,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 },
    {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 }, {     29,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 18,  0,  0 }, {     31,   16,    0, 18,  0,  0 }, {     32,   16,    0, 18,  0,  0 }, {     33,   16,    0, 18,  0,  0 }, {     34,   16,    0, 18,  0,  0 },
    {     35,   16,    0, 18,  0,  0 }, {     36,   16,    0, 18,  0,  0 }, {     37,   16,    0, 18,  0,  0 }, {     38,   16,    0, 18,  0,  0 }, {     39,   16,    0, 18,  0,  0 },
    {     40,   16,    0, 20,  0,  0 }, {     41,   16,    0, 20,  0,  0 }, {     42,   16,    0, 20,  0,  0 }, {     43,   16,    0, 20,  0,  0 }, {     44,   16,    0, 20,  0,  0 },
    {     45,   16,    0, 20,  0,  0 }, {     46,   16,    0, 20,  0,  0 }, {     47,   16,    0, 20,  0,  0 }, {     48,   16,    0, 20,  0,  0 }, {     49,   16,    0, 20,  0,  0 },
    {     50,   16,    0, 22,  0,  0 }, {     51,   16,    0, 22,  0,  0 }, {     52,   16,    0, 22,  0,  0 }, {     53,   16,    0, 22,  0,  0 }, {     54,   16,    0, 22,  0,  0 },
    {     55,   16,    0, 22,  0,  0 }, {     56,   16,    0, 22,  0,  0 }, {     57,   16,    0, 24,  0,  0 }, {     58,   16,    0, 24,  0,  0 }, {     59,   16,    0, 24,  0,  0 },
    {     60,   16,    0, 24,  0,  0 }, {     61,   16,    0, 24,  0,  0 }, {     62,   16,    0, 24,  0,  0 }, {     63,   16,    0, 24,  0,  0 }, {     64,   16,    0, 24,  0,  0 },
    {     65,   16,    0, 24,  0,  0 }, {     66,   16,    0, 24,  0,  0 }, {     67,   16,    0, 26,  0,  0 }, {     68,   16,    0, 26,  0,  0 }, {     69,   16,    0, 26,  0,  0 },
    {     70,   16,    0, 26,  0,  0 }, {     71,   16,    0, 26,  0,  0 }, {     72,   16,    0, 26,  0,  0 }, {     73,   16,    0, 26,  0,  0 }, {     74,   16,    0, 28,  0,  0 },
    {     75,   16,    0, 28,  0,  0 }, {     76,   16,    0, 28,  0,  0 }, {     77,   16,    0, 28,  0,  0 }, {     78,   16,    0, 28,  0,  0 }, {     79,   16,    0, 28,  0,  0 },
    {     80,   16,    0, 28,  0,  0 }, {     81,   16,    0, 28,  0,  0 }, {     82,   16,    0, 28,  0,  0 }, {     83,   16,    0, 28,  0,  0 }, {     84,   16,    0, 30,  0,  0 },
    {     85,   16,    0, 30,  0,  0 }, {     86,   16,    0, 30,  0,  0 }, {     87,   16,    0, 30,  0,  0 }, {     88,   16,    0, 30,  0,  0 }, {     89,   16,    0, 30,  0,  0 },
    {     90,   16,    0, 30,  0,  0 }, {     91,   16,    0, 30,  0,  0 }, {     92,   16,    0, 30,  0,  0 }, {     93,   16,    0, 30,  0,  0 }, {     94,   16,    0,  0,  0,  0 },
    {     95,   16,    0,  0,  0,  0 }, {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 },
    {      4,   16,    0, 16,  0,  0 }, {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 },
    {      9,   16,    0, 16,  0,  0 }, {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     13,   16,    0, 16,  0,  0 },
    {     14,   16,    0, 16,  0,  0 }, {     15,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     17,   16,    0, 16,  0,  0 }, {     18,   16,    0, 16,  0,  0 },
    {     19,   16,    0, 16,  0,  0 }, {     20,   16,    0, 16,  0,  0 }, {     21,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 },
    {     24,   16,    0, 16,  0,  0 }, {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 },
    {     29,   16,    0, 16,  0,  0 }, {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 }, {     32,   16,    0, 16,  0,  0 }, {     33,   16,    0, 16,  0,  0 },
    {     34,   16,    0, 16,  0,  0 }, {     35,   16,    0, 16,  0,  0 }, {     36,   16,    0, 16,  0,  0 }, {     37,   16,    0, 16,  0,  0 }, {     38,   16,    0, 16,  0,  0 },
    {     39,   16,    0, 16,  0,  0 }, {     40,   16,    0, 16,  0,  0 }, {     41,   16,    0, 16,  0,  0 }, {     42,   16,    0, 16,  0,  0 }, {     43,   16,    0, 16,  0,  0 },
    {     44,   16,    0, 16,  0,  0 }, {     45,   16,    0, 16,  0,  0 }, {     46,   16,    0, 16,  0,  0 }, {     47,   16,    0, 16,  0,  0 }, {     48,   16,    0, 16,  0,  0 },
    {     49,   16,    0, 16,  0,  0 }, {     50,   16,    0, 16,  0,  0 }, {     51,   16,    0, 16,  0,  0 }, {     52,   16,    0, 16,  0,  0 }, {     53,   16,    0, 16,  0,  0 },
    {     54,   16,    0, 16,  0,  0 }, {     55,   16,    0, 16,  0,  0 }, {     56,   16,    0, 16,  0,  0 }, {     57,   16,    0, 16,  0,  0 }, {     58,   16,    0, 16,  0,  0 },
    {     59,   16,    0, 16,  0,  0 }, {     60,   16,    0, 16,  0,  0 }, {     61,   16,    0, 16,  0,  0 }, {     62,   16,    0, 16,  0,  0 }, {     63,   16,    0, 16,  0,  0 },
    {     64,   16,    0, 16,  0,  0 }, {     65,   16,    0, 16,  0,  0 }, {     66,   16,    0, 16,  0,  0 }, {     67,   16,    0, 16,  0,  0 }, {     68,   16,    0, 16,  0,  0 },
    {     69,   16,    0, 16,  0,  0 }, {     70,   16,    0, 16,  0,  0 }, {     71,   16,    0, 16,  0,  0 }, {     72,   16,    0, 16,  0,  0 }, {     73,   16,    0, 16,  0,  0 },
    {     74,   16,    0, 16,  0,  0 }, {     75,   16,    0, 16,  0,  0 }, {     76,   16,    0, 16,  0,  0 }, {     77,   16,    0, 16,  0,  0 }, {     78,   16,    0, 16,  0,  0 },
    {     79,   16,    0, 16,  0,  0 }, {     80,   16,    0, 16,  0,  0 }, {     81,   16,    0, 16,  0,  0 }, {     82,   16,    0, 16,  0,  0 }, {     83,   16,    0, 16,  0,  0 },
    {     84,   16,    0, 16,  0,  0 }, {     85,   16,    0, 16,  0,  0 }, {     86,   16,    0, 16,  0,  0 }, {     87,   16,    0, 16,  0,  0 }, {     88,   16,    0, 16,  0,  0 },
    {     89,   16,    0, 16,  0,  0 }, {     90,   16,    0, 16,  0,  0 }, {     91,   16,    0, 16,  0,  0 }, {     92,   16,    0, 16,  0,  0 }, {     93,   16,    0, 16,  0,  0 },
    {     94,   16,    0, 16,  0,  0 }, {     95,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9556B4, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   21,    0, 24,  0,  0 }, {     16,   20,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 }, {     16,   17,    0, 24,  0,  0 },
    {     16,   16,    0, 24,  0,  0 }, {     16,   15,    0, 24,  0,  0 }, {     16,   14,    0, 24,  0,  0 }, {     16,   13,    0, 24,  0,  0 }, {     16,   12,    0, 24,  0,  0 },
    {     16,   11,    0, 24,  0,  0 }, {     16,   10,    0, 24,  0,  0 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 }, {     16,    7,    0, 24,  0,  0 },
    {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    1,    0, 26,  0,  0 }, {     16,    0,    0, 26,  0,  0 }, {     16,   -1,    0, 26,  0,  0 }, {     16,   -2,    0, 26,  0,  0 }, {     16,   -3,    0, 26,  0,  0 },
    {     16,   -4,    0, 26,  0,  0 }, {     16,   -5,    0, 26,  0,  0 }, {     16,   -6,    0, 26,  0,  0 }, {     16,   -7,    0, 26,  0,  0 }, {     16,   -8,    0, 26,  0,  0 },
    {     16,   -9,    0, 28,  0,  0 }, {     16,  -10,    0, 28,  0,  0 }, {     16,  -11,    0, 28,  0,  0 }, {     16,  -12,    0, 28,  0,  0 }, {     16,  -13,    0, 28,  0,  0 },
    {     16,  -14,    0, 28,  0,  0 }, {     16,  -15,    0, 28,  0,  0 }, {     16,  -16,    0, 28,  0,  0 }, {     16,  -17,    0, 28,  0,  0 }, {     16,  -18,    0, 28,  0,  0 },
    {     16,  -19,    0, 30,  0,  0 }, {     16,  -20,    0, 30,  0,  0 }, {     16,  -21,    0, 30,  0,  0 }, {     16,  -22,    0, 30,  0,  0 }, {     16,  -23,    0, 30,  0,  0 },
    {     16,  -24,    0, 30,  0,  0 }, {     16,  -25,    0, 30,  0,  0 }, {     16,  -26,    0,  0,  0,  0 }, {     16,  -27,    0,  0,  0,  0 }, {     16,  -28,    0,  0,  0,  0 },
    {     16,  -29,    0,  0,  0,  0 }, {     16,  -30,    0,  0,  0,  0 }, {     16,  -31,    0,  0,  0,  0 }, {     16,  -32,    0,  0,  0,  0 }, {     16,  -33,    0,  0,  0,  0 },
    {     16,  -34,    0,  0,  0,  0 }, {     16,  -35,    0,  0,  0,  0 }, {     16,  -36,    0,  2,  0,  0 }, {     16,  -37,    0,  2,  0,  0 }, {     16,  -38,    0,  2,  0,  0 },
    {     16,  -39,    0,  2,  0,  0 }, {     16,  -40,    0,  2,  0,  0 }, {     16,  -41,    0,  2,  0,  0 }, {     16,  -42,    0,  2,  0,  0 }, {     16,  -43,    0,  4,  0,  0 },
    {     16,  -44,    0,  4,  0,  0 }, {     16,  -45,    0,  4,  0,  0 }, {     16,  -46,    0,  4,  0,  0 }, {     16,  -47,    0,  4,  0,  0 }, {     16,  -48,    0,  4,  0,  0 },
    {     16,  -49,    0,  4,  0,  0 }, {     16,  -50,    0,  4,  0,  0 }, {     16,  -51,    0,  4,  0,  0 }, {     16,  -52,    0,  4,  0,  0 }, {     16,  -53,    0,  6,  0,  0 },
    {     16,  -54,    0,  6,  0,  0 }, {     16,  -55,    0,  6,  0,  0 }, {     16,  -56,    0,  6,  0,  0 }, {     16,  -57,    0,  6,  0,  0 }, {     16,  -58,    0,  6,  0,  0 },
    {     16,  -59,    0,  6,  0,  0 }, {     16,  -60,    0,  6,  0,  0 }, {     16,  -61,    0,  6,  0,  0 }, {     16,  -62,    0,  6,  0,  0 }, {     16,  -63,    0,  8,  0,  0 },
    {     16,  -64,    0,  8,  0,  0 }, {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 },
    {     16,   27,    0, 24,  0,  0 }, {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 },
    {     16,   22,    0, 24,  0,  0 }, {     16,   21,    0, 24,  0,  0 }, {     16,   20,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 },
    {     16,   17,    0, 24,  0,  0 }, {     16,   16,    0, 24,  0,  0 }, {     16,   15,    0, 24,  0,  0 }, {     16,   14,    0, 24,  0,  0 }, {     16,   13,    0, 24,  0,  0 },
    {     16,   12,    0, 24,  0,  0 }, {     16,   11,    0, 24,  0,  0 }, {     16,   10,    0, 24,  0,  0 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 },
    {     16,    7,    0, 24,  0,  0 }, {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 },
    {     16,    2,    0, 24,  0,  0 }, {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 }, {     16,   -1,    0, 24,  0,  0 }, {     16,   -2,    0, 24,  0,  0 },
    {     16,   -3,    0, 24,  0,  0 }, {     16,   -4,    0, 24,  0,  0 }, {     16,   -5,    0, 24,  0,  0 }, {     16,   -6,    0, 24,  0,  0 }, {     16,   -7,    0, 24,  0,  0 },
    {     16,   -8,    0, 24,  0,  0 }, {     16,   -9,    0, 24,  0,  0 }, {     16,  -10,    0, 24,  0,  0 }, {     16,  -11,    0, 24,  0,  0 }, {     16,  -12,    0, 24,  0,  0 },
    {     16,  -13,    0, 24,  0,  0 }, {     16,  -14,    0, 24,  0,  0 }, {     16,  -15,    0, 24,  0,  0 }, {     16,  -16,    0, 24,  0,  0 }, {     16,  -17,    0, 24,  0,  0 },
    {     16,  -18,    0, 24,  0,  0 }, {     16,  -19,    0, 24,  0,  0 }, {     16,  -20,    0, 24,  0,  0 }, {     16,  -21,    0, 24,  0,  0 }, {     16,  -22,    0, 24,  0,  0 },
    {     16,  -23,    0, 24,  0,  0 }, {     16,  -24,    0, 24,  0,  0 }, {     16,  -25,    0, 24,  0,  0 }, {     16,  -26,    0, 24,  0,  0 }, {     16,  -27,    0, 24,  0,  0 },
    {     16,  -28,    0, 24,  0,  0 }, {     16,  -29,    0, 24,  0,  0 }, {     16,  -30,    0, 24,  0,  0 }, {     16,  -31,    0, 24,  0,  0 }, {     16,  -32,    0, 24,  0,  0 },
    {     16,  -33,    0, 24,  0,  0 }, {     16,  -34,    0, 24,  0,  0 }, {     16,  -35,    0, 24,  0,  0 }, {     16,  -36,    0, 24,  0,  0 }, {     16,  -37,    0, 24,  0,  0 },
    {     16,  -38,    0, 24,  0,  0 }, {     16,  -39,    0, 24,  0,  0 }, {     16,  -40,    0, 24,  0,  0 }, {     16,  -41,    0, 24,  0,  0 }, {     16,  -42,    0, 24,  0,  0 },
    {     16,  -43,    0, 24,  0,  0 }, {     16,  -44,    0, 24,  0,  0 }, {     16,  -45,    0, 24,  0,  0 }, {     16,  -46,    0, 24,  0,  0 }, {     16,  -47,    0, 24,  0,  0 },
    {     16,  -48,    0, 24,  0,  0 }, {     16,  -49,    0, 24,  0,  0 }, {     16,  -50,    0, 24,  0,  0 }, {     16,  -51,    0, 24,  0,  0 }, {     16,  -52,    0, 24,  0,  0 },
    {     16,  -53,    0, 24,  0,  0 }, {     16,  -54,    0, 24,  0,  0 }, {     16,  -55,    0, 24,  0,  0 }, {     16,  -56,    0, 24,  0,  0 }, {     16,  -57,    0, 24,  0,  0 },
    {     16,  -58,    0, 24,  0,  0 }, {     16,  -59,    0, 24,  0,  0 }, {     16,  -60,    0, 24,  0,  0 }, {     16,  -61,    0, 24,  0,  0 }, {     16,  -62,    0, 24,  0,  0 },
    {     16,  -63,    0, 24,  0,  0 }, {     16,  -64,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_955D76, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 }, {     22,   16,    0,  0,  0,  0 },
    {     21,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 }, {     17,   16,    0,  0,  0,  0 },
    {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 }, {     12,   16,    0,  0,  0,  0 },
    {     11,   16,    0,  0,  0,  0 }, {     10,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 }, {      7,   16,    0,  0,  0,  0 },
    {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 }, {      2,   16,    0,  0,  0,  0 },
    {      1,   16,    0, 30,  0,  0 }, {      0,   16,    0, 30,  0,  0 }, {     -1,   16,    0, 30,  0,  0 }, {     -2,   16,    0, 30,  0,  0 }, {     -3,   16,    0, 30,  0,  0 },
    {     -4,   16,    0, 30,  0,  0 }, {     -5,   16,    0, 30,  0,  0 }, {     -6,   16,    0, 30,  0,  0 }, {     -7,   16,    0, 30,  0,  0 }, {     -8,   16,    0, 30,  0,  0 },
    {     -9,   16,    0, 28,  0,  0 }, {    -10,   16,    0, 28,  0,  0 }, {    -11,   16,    0, 28,  0,  0 }, {    -12,   16,    0, 28,  0,  0 }, {    -13,   16,    0, 28,  0,  0 },
    {    -14,   16,    0, 28,  0,  0 }, {    -15,   16,    0, 28,  0,  0 }, {    -16,   16,    0, 28,  0,  0 }, {    -17,   16,    0, 28,  0,  0 }, {    -18,   16,    0, 28,  0,  0 },
    {    -19,   16,    0, 26,  0,  0 }, {    -20,   16,    0, 26,  0,  0 }, {    -21,   16,    0, 26,  0,  0 }, {    -22,   16,    0, 26,  0,  0 }, {    -23,   16,    0, 26,  0,  0 },
    {    -24,   16,    0, 26,  0,  0 }, {    -25,   16,    0, 26,  0,  0 }, {    -26,   16,    0, 24,  0,  0 }, {    -27,   16,    0, 24,  0,  0 }, {    -28,   16,    0, 24,  0,  0 },
    {    -29,   16,    0, 24,  0,  0 }, {    -30,   16,    0, 24,  0,  0 }, {    -31,   16,    0, 24,  0,  0 }, {    -32,   16,    0, 24,  0,  0 }, {    -33,   16,    0, 24,  0,  0 },
    {    -34,   16,    0, 24,  0,  0 }, {    -35,   16,    0, 24,  0,  0 }, {    -36,   16,    0, 22,  0,  0 }, {    -37,   16,    0, 22,  0,  0 }, {    -38,   16,    0, 22,  0,  0 },
    {    -39,   16,    0, 22,  0,  0 }, {    -40,   16,    0, 22,  0,  0 }, {    -41,   16,    0, 22,  0,  0 }, {    -42,   16,    0, 22,  0,  0 }, {    -43,   16,    0, 20,  0,  0 },
    {    -44,   16,    0, 20,  0,  0 }, {    -45,   16,    0, 20,  0,  0 }, {    -46,   16,    0, 20,  0,  0 }, {    -47,   16,    0, 20,  0,  0 }, {    -48,   16,    0, 20,  0,  0 },
    {    -49,   16,    0, 20,  0,  0 }, {    -50,   16,    0, 20,  0,  0 }, {    -51,   16,    0, 20,  0,  0 }, {    -52,   16,    0, 20,  0,  0 }, {    -53,   16,    0, 18,  0,  0 },
    {    -54,   16,    0, 18,  0,  0 }, {    -55,   16,    0, 18,  0,  0 }, {    -56,   16,    0, 18,  0,  0 }, {    -57,   16,    0, 18,  0,  0 }, {    -58,   16,    0, 18,  0,  0 },
    {    -59,   16,    0, 18,  0,  0 }, {    -60,   16,    0, 18,  0,  0 }, {    -61,   16,    0, 18,  0,  0 }, {    -62,   16,    0, 18,  0,  0 }, {    -63,   16,    0, 16,  0,  0 },
    {    -64,   16,    0, 16,  0,  0 }, {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 },
    {     27,   16,    0,  0,  0,  0 }, {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,    0,  0,  0,  0 },
    {     22,   16,    0,  0,  0,  0 }, {     21,   16,    0,  0,  0,  0 }, {     20,   16,    0,  0,  0,  0 }, {     19,   16,    0,  0,  0,  0 }, {     18,   16,    0,  0,  0,  0 },
    {     17,   16,    0,  0,  0,  0 }, {     16,   16,    0,  0,  0,  0 }, {     15,   16,    0,  0,  0,  0 }, {     14,   16,    0,  0,  0,  0 }, {     13,   16,    0,  0,  0,  0 },
    {     12,   16,    0,  0,  0,  0 }, {     11,   16,    0,  0,  0,  0 }, {     10,   16,    0,  0,  0,  0 }, {      9,   16,    0,  0,  0,  0 }, {      8,   16,    0,  0,  0,  0 },
    {      7,   16,    0,  0,  0,  0 }, {      6,   16,    0,  0,  0,  0 }, {      5,   16,    0,  0,  0,  0 }, {      4,   16,    0,  0,  0,  0 }, {      3,   16,    0,  0,  0,  0 },
    {      2,   16,    0,  0,  0,  0 }, {      1,   16,    0,  0,  0,  0 }, {      0,   16,    0,  0,  0,  0 }, {     -1,   16,    0,  0,  0,  0 }, {     -2,   16,    0,  0,  0,  0 },
    {     -3,   16,    0,  0,  0,  0 }, {     -4,   16,    0,  0,  0,  0 }, {     -5,   16,    0,  0,  0,  0 }, {     -6,   16,    0,  0,  0,  0 }, {     -7,   16,    0,  0,  0,  0 },
    {     -8,   16,    0,  0,  0,  0 }, {     -9,   16,    0,  0,  0,  0 }, {    -10,   16,    0,  0,  0,  0 }, {    -11,   16,    0,  0,  0,  0 }, {    -12,   16,    0,  0,  0,  0 },
    {    -13,   16,    0,  0,  0,  0 }, {    -14,   16,    0,  0,  0,  0 }, {    -15,   16,    0,  0,  0,  0 }, {    -16,   16,    0,  0,  0,  0 }, {    -17,   16,    0,  0,  0,  0 },
    {    -18,   16,    0,  0,  0,  0 }, {    -19,   16,    0,  0,  0,  0 }, {    -20,   16,    0,  0,  0,  0 }, {    -21,   16,    0,  0,  0,  0 }, {    -22,   16,    0,  0,  0,  0 },
    {    -23,   16,    0,  0,  0,  0 }, {    -24,   16,    0,  0,  0,  0 }, {    -25,   16,    0,  0,  0,  0 }, {    -26,   16,    0,  0,  0,  0 }, {    -27,   16,    0,  0,  0,  0 },
    {    -28,   16,    0,  0,  0,  0 }, {    -29,   16,    0,  0,  0,  0 }, {    -30,   16,    0,  0,  0,  0 }, {    -31,   16,    0,  0,  0,  0 }, {    -32,   16,    0,  0,  0,  0 },
    {    -33,   16,    0,  0,  0,  0 }, {    -34,   16,    0,  0,  0,  0 }, {    -35,   16,    0,  0,  0,  0 }, {    -36,   16,    0,  0,  0,  0 }, {    -37,   16,    0,  0,  0,  0 },
    {    -38,   16,    0,  0,  0,  0 }, {    -39,   16,    0,  0,  0,  0 }, {    -40,   16,    0,  0,  0,  0 }, {    -41,   16,    0,  0,  0,  0 }, {    -42,   16,    0,  0,  0,  0 },
    {    -43,   16,    0,  0,  0,  0 }, {    -44,   16,    0,  0,  0,  0 }, {    -45,   16,    0,  0,  0,  0 }, {    -46,   16,    0,  0,  0,  0 }, {    -47,   16,    0,  0,  0,  0 },
    {    -48,   16,    0,  0,  0,  0 }, {    -49,   16,    0,  0,  0,  0 }, {    -50,   16,    0,  0,  0,  0 }, {    -51,   16,    0,  0,  0,  0 }, {    -52,   16,    0,  0,  0,  0 },
    {    -53,   16,    0,  0,  0,  0 }, {    -54,   16,    0,  0,  0,  0 }, {    -55,   16,    0,  0,  0,  0 }, {    -56,   16,    0,  0,  0,  0 }, {    -57,   16,    0,  0,  0,  0 },
    {    -58,   16,    0,  0,  0,  0 }, {    -59,   16,    0,  0,  0,  0 }, {    -60,   16,    0,  0,  0,  0 }, {    -61,   16,    0,  0,  0,  0 }, {    -62,   16,    0,  0,  0,  0 },
    {    -63,   16,    0,  0,  0,  0 }, {    -64,   16,    0,  0,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_956438, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 }, {     16,    9,    0,  8,  0,  0 },
    {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 }, {     16,   14,    0,  8,  0,  0 },
    {     16,   15,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   17,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 }, {     16,   19,    0,  8,  0,  0 },
    {     16,   20,    0,  8,  0,  0 }, {     16,   21,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 }, {     16,   24,    0,  8,  0,  0 },
    {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 }, {     16,   29,    0,  8,  0,  0 },
    {     16,   30,    0,  6,  0,  0 }, {     16,   31,    0,  6,  0,  0 }, {     16,   32,    0,  6,  0,  0 }, {     16,   33,    0,  6,  0,  0 }, {     16,   34,    0,  6,  0,  0 },
    {     16,   35,    0,  6,  0,  0 }, {     16,   36,    0,  6,  0,  0 }, {     16,   37,    0,  6,  0,  0 }, {     16,   38,    0,  6,  0,  0 }, {     16,   39,    0,  6,  0,  0 },
    {     16,   40,    0,  4,  0,  0 }, {     16,   41,    0,  4,  0,  0 }, {     16,   42,    0,  4,  0,  0 }, {     16,   43,    0,  4,  0,  0 }, {     16,   44,    0,  4,  0,  0 },
    {     16,   45,    0,  4,  0,  0 }, {     16,   46,    0,  4,  0,  0 }, {     16,   47,    0,  4,  0,  0 }, {     16,   48,    0,  4,  0,  0 }, {     16,   49,    0,  4,  0,  0 },
    {     16,   50,    0,  2,  0,  0 }, {     16,   51,    0,  2,  0,  0 }, {     16,   52,    0,  2,  0,  0 }, {     16,   53,    0,  2,  0,  0 }, {     16,   54,    0,  2,  0,  0 },
    {     16,   55,    0,  2,  0,  0 }, {     16,   56,    0,  2,  0,  0 }, {     16,   57,    0,  0,  0,  0 }, {     16,   58,    0,  0,  0,  0 }, {     16,   59,    0,  0,  0,  0 },
    {     16,   60,    0,  0,  0,  0 }, {     16,   61,    0,  0,  0,  0 }, {     16,   62,    0,  0,  0,  0 }, {     16,   63,    0,  0,  0,  0 }, {     16,   64,    0,  0,  0,  0 },
    {     16,   65,    0,  0,  0,  0 }, {     16,   66,    0,  0,  0,  0 }, {     16,   67,    0, 30,  0,  0 }, {     16,   68,    0, 30,  0,  0 }, {     16,   69,    0, 30,  0,  0 },
    {     16,   70,    0, 30,  0,  0 }, {     16,   71,    0, 30,  0,  0 }, {     16,   72,    0, 30,  0,  0 }, {     16,   73,    0, 30,  0,  0 }, {     16,   74,    0, 28,  0,  0 },
    {     16,   75,    0, 28,  0,  0 }, {     16,   76,    0, 28,  0,  0 }, {     16,   77,    0, 28,  0,  0 }, {     16,   78,    0, 28,  0,  0 }, {     16,   79,    0, 28,  0,  0 },
    {     16,   80,    0, 28,  0,  0 }, {     16,   81,    0, 28,  0,  0 }, {     16,   82,    0, 28,  0,  0 }, {     16,   83,    0, 28,  0,  0 }, {     16,   84,    0, 26,  0,  0 },
    {     16,   85,    0, 26,  0,  0 }, {     16,   86,    0, 26,  0,  0 }, {     16,   87,    0, 26,  0,  0 }, {     16,   88,    0, 26,  0,  0 }, {     16,   89,    0, 26,  0,  0 },
    {     16,   90,    0, 26,  0,  0 }, {     16,   91,    0, 26,  0,  0 }, {     16,   92,    0, 26,  0,  0 }, {     16,   93,    0, 26,  0,  0 }, {     16,   94,    0, 24,  0,  0 },
    {     16,   95,    0, 24,  0,  0 }, {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 },
    {     16,    4,    0,  8,  0,  0 }, {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,    0,  8,  0,  0 },
    {     16,    9,    0,  8,  0,  0 }, {     16,   10,    0,  8,  0,  0 }, {     16,   11,    0,  8,  0,  0 }, {     16,   12,    0,  8,  0,  0 }, {     16,   13,    0,  8,  0,  0 },
    {     16,   14,    0,  8,  0,  0 }, {     16,   15,    0,  8,  0,  0 }, {     16,   16,    0,  8,  0,  0 }, {     16,   17,    0,  8,  0,  0 }, {     16,   18,    0,  8,  0,  0 },
    {     16,   19,    0,  8,  0,  0 }, {     16,   20,    0,  8,  0,  0 }, {     16,   21,    0,  8,  0,  0 }, {     16,   22,    0,  8,  0,  0 }, {     16,   23,    0,  8,  0,  0 },
    {     16,   24,    0,  8,  0,  0 }, {     16,   25,    0,  8,  0,  0 }, {     16,   26,    0,  8,  0,  0 }, {     16,   27,    0,  8,  0,  0 }, {     16,   28,    0,  8,  0,  0 },
    {     16,   29,    0,  8,  0,  0 }, {     16,   30,    0,  8,  0,  0 }, {     16,   31,    0,  8,  0,  0 }, {     16,   32,    0,  8,  0,  0 }, {     16,   33,    0,  8,  0,  0 },
    {     16,   34,    0,  8,  0,  0 }, {     16,   35,    0,  8,  0,  0 }, {     16,   36,    0,  8,  0,  0 }, {     16,   37,    0,  8,  0,  0 }, {     16,   38,    0,  8,  0,  0 },
    {     16,   39,    0,  8,  0,  0 }, {     16,   40,    0,  8,  0,  0 }, {     16,   41,    0,  8,  0,  0 }, {     16,   42,    0,  8,  0,  0 }, {     16,   43,    0,  8,  0,  0 },
    {     16,   44,    0,  8,  0,  0 }, {     16,   45,    0,  8,  0,  0 }, {     16,   46,    0,  8,  0,  0 }, {     16,   47,    0,  8,  0,  0 }, {     16,   48,    0,  8,  0,  0 },
    {     16,   49,    0,  8,  0,  0 }, {     16,   50,    0,  8,  0,  0 }, {     16,   51,    0,  8,  0,  0 }, {     16,   52,    0,  8,  0,  0 }, {     16,   53,    0,  8,  0,  0 },
    {     16,   54,    0,  8,  0,  0 }, {     16,   55,    0,  8,  0,  0 }, {     16,   56,    0,  8,  0,  0 }, {     16,   57,    0,  8,  0,  0 }, {     16,   58,    0,  8,  0,  0 },
    {     16,   59,    0,  8,  0,  0 }, {     16,   60,    0,  8,  0,  0 }, {     16,   61,    0,  8,  0,  0 }, {     16,   62,    0,  8,  0,  0 }, {     16,   63,    0,  8,  0,  0 },
    {     16,   64,    0,  8,  0,  0 }, {     16,   65,    0,  8,  0,  0 }, {     16,   66,    0,  8,  0,  0 }, {     16,   67,    0,  8,  0,  0 }, {     16,   68,    0,  8,  0,  0 },
    {     16,   69,    0,  8,  0,  0 }, {     16,   70,    0,  8,  0,  0 }, {     16,   71,    0,  8,  0,  0 }, {     16,   72,    0,  8,  0,  0 }, {     16,   73,    0,  8,  0,  0 },
    {     16,   74,    0,  8,  0,  0 }, {     16,   75,    0,  8,  0,  0 }, {     16,   76,    0,  8,  0,  0 }, {     16,   77,    0,  8,  0,  0 }, {     16,   78,    0,  8,  0,  0 },
    {     16,   79,    0,  8,  0,  0 }, {     16,   80,    0,  8,  0,  0 }, {     16,   81,    0,  8,  0,  0 }, {     16,   82,    0,  8,  0,  0 }, {     16,   83,    0,  8,  0,  0 },
    {     16,   84,    0,  8,  0,  0 }, {     16,   85,    0,  8,  0,  0 }, {     16,   86,    0,  8,  0,  0 }, {     16,   87,    0,  8,  0,  0 }, {     16,   88,    0,  8,  0,  0 },
    {     16,   89,    0,  8,  0,  0 }, {     16,   90,    0,  8,  0,  0 }, {     16,   91,    0,  8,  0,  0 }, {     16,   92,    0,  8,  0,  0 }, {     16,   93,    0,  8,  0,  0 },
    {     16,   94,    0,  8,  0,  0 }, {     16,   95,    0,  8,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_956AFA, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 }, {      9,   16,    0, 16,  0,  0 },
    {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     13,   16,    0, 16,  0,  0 }, {     14,   16,    0, 16,  0,  0 },
    {     15,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     17,   16,    0, 16,  0,  0 }, {     18,   16,    0, 16,  0,  0 }, {     19,   16,    0, 16,  0,  0 },
    {     20,   16,    0, 16,  0,  0 }, {     21,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 }, {     24,   16,    0, 16,  0,  0 },
    {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 }, {     29,   16,    0, 16,  0,  0 },
    {     30,   16,    0, 14,  0,  0 }, {     31,   16,    0, 14,  0,  0 }, {     32,   16,    0, 14,  0,  0 }, {     33,   16,    0, 14,  0,  0 }, {     34,   16,    0, 14,  0,  0 },
    {     35,   16,    0, 14,  0,  0 }, {     36,   16,    0, 14,  0,  0 }, {     37,   16,    0, 14,  0,  0 }, {     38,   16,    0, 14,  0,  0 }, {     39,   16,    0, 14,  0,  0 },
    {     40,   16,    0, 12,  0,  0 }, {     41,   16,    0, 12,  0,  0 }, {     42,   16,    0, 12,  0,  0 }, {     43,   16,    0, 12,  0,  0 }, {     44,   16,    0, 12,  0,  0 },
    {     45,   16,    0, 12,  0,  0 }, {     46,   16,    0, 12,  0,  0 }, {     47,   16,    0, 12,  0,  0 }, {     48,   16,    0, 12,  0,  0 }, {     49,   16,    0, 12,  0,  0 },
    {     50,   16,    0, 10,  0,  0 }, {     51,   16,    0, 10,  0,  0 }, {     52,   16,    0, 10,  0,  0 }, {     53,   16,    0, 10,  0,  0 }, {     54,   16,    0, 10,  0,  0 },
    {     55,   16,    0, 10,  0,  0 }, {     56,   16,    0, 10,  0,  0 }, {     57,   16,    0,  8,  0,  0 }, {     58,   16,    0,  8,  0,  0 }, {     59,   16,    0,  8,  0,  0 },
    {     60,   16,    0,  8,  0,  0 }, {     61,   16,    0,  8,  0,  0 }, {     62,   16,    0,  8,  0,  0 }, {     63,   16,    0,  8,  0,  0 }, {     64,   16,    0,  8,  0,  0 },
    {     65,   16,    0,  8,  0,  0 }, {     66,   16,    0,  8,  0,  0 }, {     67,   16,    0,  6,  0,  0 }, {     68,   16,    0,  6,  0,  0 }, {     69,   16,    0,  6,  0,  0 },
    {     70,   16,    0,  6,  0,  0 }, {     71,   16,    0,  6,  0,  0 }, {     72,   16,    0,  6,  0,  0 }, {     73,   16,    0,  6,  0,  0 }, {     74,   16,    0,  4,  0,  0 },
    {     75,   16,    0,  4,  0,  0 }, {     76,   16,    0,  4,  0,  0 }, {     77,   16,    0,  4,  0,  0 }, {     78,   16,    0,  4,  0,  0 }, {     79,   16,    0,  4,  0,  0 },
    {     80,   16,    0,  4,  0,  0 }, {     81,   16,    0,  4,  0,  0 }, {     82,   16,    0,  4,  0,  0 }, {     83,   16,    0,  4,  0,  0 }, {     84,   16,    0,  2,  0,  0 },
    {     85,   16,    0,  2,  0,  0 }, {     86,   16,    0,  2,  0,  0 }, {     87,   16,    0,  2,  0,  0 }, {     88,   16,    0,  2,  0,  0 }, {     89,   16,    0,  2,  0,  0 },
    {     90,   16,    0,  2,  0,  0 }, {     91,   16,    0,  2,  0,  0 }, {     92,   16,    0,  2,  0,  0 }, {     93,   16,    0,  2,  0,  0 }, {     94,   16,    0,  0,  0,  0 },
    {     95,   16,    0,  0,  0,  0 }, {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 },
    {      4,   16,    0, 16,  0,  0 }, {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,    0, 16,  0,  0 },
    {      9,   16,    0, 16,  0,  0 }, {     10,   16,    0, 16,  0,  0 }, {     11,   16,    0, 16,  0,  0 }, {     12,   16,    0, 16,  0,  0 }, {     13,   16,    0, 16,  0,  0 },
    {     14,   16,    0, 16,  0,  0 }, {     15,   16,    0, 16,  0,  0 }, {     16,   16,    0, 16,  0,  0 }, {     17,   16,    0, 16,  0,  0 }, {     18,   16,    0, 16,  0,  0 },
    {     19,   16,    0, 16,  0,  0 }, {     20,   16,    0, 16,  0,  0 }, {     21,   16,    0, 16,  0,  0 }, {     22,   16,    0, 16,  0,  0 }, {     23,   16,    0, 16,  0,  0 },
    {     24,   16,    0, 16,  0,  0 }, {     25,   16,    0, 16,  0,  0 }, {     26,   16,    0, 16,  0,  0 }, {     27,   16,    0, 16,  0,  0 }, {     28,   16,    0, 16,  0,  0 },
    {     29,   16,    0, 16,  0,  0 }, {     30,   16,    0, 16,  0,  0 }, {     31,   16,    0, 16,  0,  0 }, {     32,   16,    0, 16,  0,  0 }, {     33,   16,    0, 16,  0,  0 },
    {     34,   16,    0, 16,  0,  0 }, {     35,   16,    0, 16,  0,  0 }, {     36,   16,    0, 16,  0,  0 }, {     37,   16,    0, 16,  0,  0 }, {     38,   16,    0, 16,  0,  0 },
    {     39,   16,    0, 16,  0,  0 }, {     40,   16,    0, 16,  0,  0 }, {     41,   16,    0, 16,  0,  0 }, {     42,   16,    0, 16,  0,  0 }, {     43,   16,    0, 16,  0,  0 },
    {     44,   16,    0, 16,  0,  0 }, {     45,   16,    0, 16,  0,  0 }, {     46,   16,    0, 16,  0,  0 }, {     47,   16,    0, 16,  0,  0 }, {     48,   16,    0, 16,  0,  0 },
    {     49,   16,    0, 16,  0,  0 }, {     50,   16,    0, 16,  0,  0 }, {     51,   16,    0, 16,  0,  0 }, {     52,   16,    0, 16,  0,  0 }, {     53,   16,    0, 16,  0,  0 },
    {     54,   16,    0, 16,  0,  0 }, {     55,   16,    0, 16,  0,  0 }, {     56,   16,    0, 16,  0,  0 }, {     57,   16,    0, 16,  0,  0 }, {     58,   16,    0, 16,  0,  0 },
    {     59,   16,    0, 16,  0,  0 }, {     60,   16,    0, 16,  0,  0 }, {     61,   16,    0, 16,  0,  0 }, {     62,   16,    0, 16,  0,  0 }, {     63,   16,    0, 16,  0,  0 },
    {     64,   16,    0, 16,  0,  0 }, {     65,   16,    0, 16,  0,  0 }, {     66,   16,    0, 16,  0,  0 }, {     67,   16,    0, 16,  0,  0 }, {     68,   16,    0, 16,  0,  0 },
    {     69,   16,    0, 16,  0,  0 }, {     70,   16,    0, 16,  0,  0 }, {     71,   16,    0, 16,  0,  0 }, {     72,   16,    0, 16,  0,  0 }, {     73,   16,    0, 16,  0,  0 },
    {     74,   16,    0, 16,  0,  0 }, {     75,   16,    0, 16,  0,  0 }, {     76,   16,    0, 16,  0,  0 }, {     77,   16,    0, 16,  0,  0 }, {     78,   16,    0, 16,  0,  0 },
    {     79,   16,    0, 16,  0,  0 }, {     80,   16,    0, 16,  0,  0 }, {     81,   16,    0, 16,  0,  0 }, {     82,   16,    0, 16,  0,  0 }, {     83,   16,    0, 16,  0,  0 },
    {     84,   16,    0, 16,  0,  0 }, {     85,   16,    0, 16,  0,  0 }, {     86,   16,    0, 16,  0,  0 }, {     87,   16,    0, 16,  0,  0 }, {     88,   16,    0, 16,  0,  0 },
    {     89,   16,    0, 16,  0,  0 }, {     90,   16,    0, 16,  0,  0 }, {     91,   16,    0, 16,  0,  0 }, {     92,   16,    0, 16,  0,  0 }, {     93,   16,    0, 16,  0,  0 },
    {     94,   16,    0, 16,  0,  0 }, {     95,   16,    0, 16,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfo_9571BC, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 }, {     16,   22,    0, 24,  0,  0 },
    {     16,   21,    0, 24,  0,  0 }, {     16,   20,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 }, {     16,   17,    0, 24,  0,  0 },
    {     16,   16,    0, 24,  0,  0 }, {     16,   15,    0, 24,  0,  0 }, {     16,   14,    0, 24,  0,  0 }, {     16,   13,    0, 24,  0,  0 }, {     16,   12,    0, 24,  0,  0 },
    {     16,   11,    0, 24,  0,  0 }, {     16,   10,    0, 24,  0,  0 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 }, {     16,    7,    0, 24,  0,  0 },
    {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 }, {     16,    2,    0, 24,  0,  0 },
    {     16,    1,    0, 22,  0,  0 }, {     16,    0,    0, 22,  0,  0 }, {     16,   -1,    0, 22,  0,  0 }, {     16,   -2,    0, 22,  0,  0 }, {     16,   -3,    0, 22,  0,  0 },
    {     16,   -4,    0, 22,  0,  0 }, {     16,   -5,    0, 22,  0,  0 }, {     16,   -6,    0, 22,  0,  0 }, {     16,   -7,    0, 22,  0,  0 }, {     16,   -8,    0, 22,  0,  0 },
    {     16,   -9,    0, 20,  0,  0 }, {     16,  -10,    0, 20,  0,  0 }, {     16,  -11,    0, 20,  0,  0 }, {     16,  -12,    0, 20,  0,  0 }, {     16,  -13,    0, 20,  0,  0 },
    {     16,  -14,    0, 20,  0,  0 }, {     16,  -15,    0, 20,  0,  0 }, {     16,  -16,    0, 20,  0,  0 }, {     16,  -17,    0, 20,  0,  0 }, {     16,  -18,    0, 20,  0,  0 },
    {     16,  -19,    0, 18,  0,  0 }, {     16,  -20,    0, 18,  0,  0 }, {     16,  -21,    0, 18,  0,  0 }, {     16,  -22,    0, 18,  0,  0 }, {     16,  -23,    0, 18,  0,  0 },
    {     16,  -24,    0, 18,  0,  0 }, {     16,  -25,    0, 18,  0,  0 }, {     16,  -26,    0, 16,  0,  0 }, {     16,  -27,    0, 16,  0,  0 }, {     16,  -28,    0, 16,  0,  0 },
    {     16,  -29,    0, 16,  0,  0 }, {     16,  -30,    0, 16,  0,  0 }, {     16,  -31,    0, 16,  0,  0 }, {     16,  -32,    0, 16,  0,  0 }, {     16,  -33,    0, 16,  0,  0 },
    {     16,  -34,    0, 16,  0,  0 }, {     16,  -35,    0, 16,  0,  0 }, {     16,  -36,    0, 14,  0,  0 }, {     16,  -37,    0, 14,  0,  0 }, {     16,  -38,    0, 14,  0,  0 },
    {     16,  -39,    0, 14,  0,  0 }, {     16,  -40,    0, 14,  0,  0 }, {     16,  -41,    0, 14,  0,  0 }, {     16,  -42,    0, 14,  0,  0 }, {     16,  -43,    0, 12,  0,  0 },
    {     16,  -44,    0, 12,  0,  0 }, {     16,  -45,    0, 12,  0,  0 }, {     16,  -46,    0, 12,  0,  0 }, {     16,  -47,    0, 12,  0,  0 }, {     16,  -48,    0, 12,  0,  0 },
    {     16,  -49,    0, 12,  0,  0 }, {     16,  -50,    0, 12,  0,  0 }, {     16,  -51,    0, 12,  0,  0 }, {     16,  -52,    0, 12,  0,  0 }, {     16,  -53,    0, 10,  0,  0 },
    {     16,  -54,    0, 10,  0,  0 }, {     16,  -55,    0, 10,  0,  0 }, {     16,  -56,    0, 10,  0,  0 }, {     16,  -57,    0, 10,  0,  0 }, {     16,  -58,    0, 10,  0,  0 },
    {     16,  -59,    0, 10,  0,  0 }, {     16,  -60,    0, 10,  0,  0 }, {     16,  -61,    0, 10,  0,  0 }, {     16,  -62,    0, 10,  0,  0 }, {     16,  -63,    0,  8,  0,  0 },
    {     16,  -64,    0,  8,  0,  0 }, {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 },
    {     16,   27,    0, 24,  0,  0 }, {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,    0, 24,  0,  0 },
    {     16,   22,    0, 24,  0,  0 }, {     16,   21,    0, 24,  0,  0 }, {     16,   20,    0, 24,  0,  0 }, {     16,   19,    0, 24,  0,  0 }, {     16,   18,    0, 24,  0,  0 },
    {     16,   17,    0, 24,  0,  0 }, {     16,   16,    0, 24,  0,  0 }, {     16,   15,    0, 24,  0,  0 }, {     16,   14,    0, 24,  0,  0 }, {     16,   13,    0, 24,  0,  0 },
    {     16,   12,    0, 24,  0,  0 }, {     16,   11,    0, 24,  0,  0 }, {     16,   10,    0, 24,  0,  0 }, {     16,    9,    0, 24,  0,  0 }, {     16,    8,    0, 24,  0,  0 },
    {     16,    7,    0, 24,  0,  0 }, {     16,    6,    0, 24,  0,  0 }, {     16,    5,    0, 24,  0,  0 }, {     16,    4,    0, 24,  0,  0 }, {     16,    3,    0, 24,  0,  0 },
    {     16,    2,    0, 24,  0,  0 }, {     16,    1,    0, 24,  0,  0 }, {     16,    0,    0, 24,  0,  0 }, {     16,   -1,    0, 24,  0,  0 }, {     16,   -2,    0, 24,  0,  0 },
    {     16,   -3,    0, 24,  0,  0 }, {     16,   -4,    0, 24,  0,  0 }, {     16,   -5,    0, 24,  0,  0 }, {     16,   -6,    0, 24,  0,  0 }, {     16,   -7,    0, 24,  0,  0 },
    {     16,   -8,    0, 24,  0,  0 }, {     16,   -9,    0, 24,  0,  0 }, {     16,  -10,    0, 24,  0,  0 }, {     16,  -11,    0, 24,  0,  0 }, {     16,  -12,    0, 24,  0,  0 },
    {     16,  -13,    0, 24,  0,  0 }, {     16,  -14,    0, 24,  0,  0 }, {     16,  -15,    0, 24,  0,  0 }, {     16,  -16,    0, 24,  0,  0 }, {     16,  -17,    0, 24,  0,  0 },
    {     16,  -18,    0, 24,  0,  0 }, {     16,  -19,    0, 24,  0,  0 }, {     16,  -20,    0, 24,  0,  0 }, {     16,  -21,    0, 24,  0,  0 }, {     16,  -22,    0, 24,  0,  0 },
    {     16,  -23,    0, 24,  0,  0 }, {     16,  -24,    0, 24,  0,  0 }, {     16,  -25,    0, 24,  0,  0 }, {     16,  -26,    0, 24,  0,  0 }, {     16,  -27,    0, 24,  0,  0 },
    {     16,  -28,    0, 24,  0,  0 }, {     16,  -29,    0, 24,  0,  0 }, {     16,  -30,    0, 24,  0,  0 }, {     16,  -31,    0, 24,  0,  0 }, {     16,  -32,    0, 24,  0,  0 },
    {     16,  -33,    0, 24,  0,  0 }, {     16,  -34,    0, 24,  0,  0 }, {     16,  -35,    0, 24,  0,  0 }, {     16,  -36,    0, 24,  0,  0 }, {     16,  -37,    0, 24,  0,  0 },
    {     16,  -38,    0, 24,  0,  0 }, {     16,  -39,    0, 24,  0,  0 }, {     16,  -40,    0, 24,  0,  0 }, {     16,  -41,    0, 24,  0,  0 }, {     16,  -42,    0, 24,  0,  0 },
    {     16,  -43,    0, 24,  0,  0 }, {     16,  -44,    0, 24,  0,  0 }, {     16,  -45,    0, 24,  0,  0 }, {     16,  -46,    0, 24,  0,  0 }, {     16,  -47,    0, 24,  0,  0 },
    {     16,  -48,    0, 24,  0,  0 }, {     16,  -49,    0, 24,  0,  0 }, {     16,  -50,    0, 24,  0,  0 }, {     16,  -51,    0, 24,  0,  0 }, {     16,  -52,    0, 24,  0,  0 },
    {     16,  -53,    0, 24,  0,  0 }, {     16,  -54,    0, 24,  0,  0 }, {     16,  -55,    0, 24,  0,  0 }, {     16,  -56,    0, 24,  0,  0 }, {     16,  -57,    0, 24,  0,  0 },
    {     16,  -58,    0, 24,  0,  0 }, {     16,  -59,    0, 24,  0,  0 }, {     16,  -60,    0, 24,  0,  0 }, {     16,  -61,    0, 24,  0,  0 }, {     16,  -62,    0, 24,  0,  0 },
    {     16,  -63,    0, 24,  0,  0 }, {     16,  -64,    0, 24,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeCorkscrewUp0, {
    {   31,   16,    0,    0,    0,    0}, {   30,   16,    0,    0,    0,    0}, {   29,   16,    0,    0,    0,    0}, {   28,   16,    0,    0,    0,    0}, {   27,   16,    0,    0,    0,    0},
    {   26,   16,    0,    0,    0,    0}, {   25,   16,    0,    0,    0,    0}, {   24,   16,    0,    0,    0,    0}, {   23,   16,    1,    0,    1,    0}, {   22,   16,    1,    0,    1,    0},
    {   21,   16,    1,    0,    1,    0}, {   20,   16,    1,    0,    1,    0}, {   19,   16,    1,    0,    1,    0}, {   18,   16,    1,    0,    1,    0}, {   17,   16,    2,    0,    1,    0},
    {   16,   16,    2,    0,    1,    0}, {   15,   16,    2,    0,    1,    0}, {   14,   16,    2,    0,    1,    0}, {   13,   16,    2,    0,    1,    0}, {   12,   16,    3,    0,    1,    0},
    {   11,   16,    3,    0,    1,    0}, {   10,   16,    3,    0,    1,    0}, {    9,   16,    4,    0,    1,    0}, {    8,   16,    4,    0,    1,    0}, {    7,   16,    4,    0,    2,    0},
    {    6,   16,    5,    0,    2,    0}, {    5,   16,    5,    0,    2,    0}, {    5,   16,    6,    0,    2,    0}, {    4,   16,    6,    0,    2,    0}, {    3,   16,    6,    0,   34,    0},
    {    2,   16,    7,    0,   34,    0}, {    1,   15,    7,    0,   34,    0}, {    0,   15,    8,    0,   34,    0}, {   -1,   15,    8,    0,   34,    0}, {   -2,   15,    9,    0,   34,    0},
    {   -3,   15,    9,    0,   34,    0}, {   -4,   15,   10,    0,   34,    0}, {   -5,   15,   10,    0,   34,    0}, {   -6,   15,   11,    0,   34,    0}, {   -6,   15,   12,    0,   34,    0},
    {   -7,   15,   12,    0,   34,    0}, {   -8,   15,   13,    0,   34,    0}, {   -9,   15,   13,    0,   34,    0}, {  -10,   15,   14,    0,   34,    0}, {  -11,   15,   15,    0,   34,    0},
    {  -12,   14,   15,    0,   34,    0}, {  -12,   14,   16,    0,   34,    0}, {  -13,   14,   17,    0,   34,    0}, {  -14,   14,   17,    0,   34,    0}, {  -15,   14,   18,    0,   34,    0},
    {  -16,   14,   19,    0,   34,    0}, {  -16,   14,   20,    0,   34,    0}, {  -17,   14,   20,    0,   34,    0}, {  -18,   13,   21,    0,   35,    0}, {  -19,   13,   22,    0,   35,    0},
    {  -19,   13,   23,    0,   35,    0}, {  -20,   13,   24,    0,   35,    0}, {  -21,   13,   24,    0,   35,    0}, {  -22,   13,   25,    0,   35,    0}, {  -22,   12,   26,    0,   35,    0},
    {  -23,   12,   27,    0,   35,    0}, {  -24,   12,   28,    0,   35,    0}, {  -24,   12,   29,    0,   35,    0}, {  -25,   12,   29,    0,   35,    0}, {  -26,   11,   30,    0,   35,    0},
    {  -26,   11,   31,    0,   35,    0}, {  -27,   11,   32,    0,   35,    0}, {  -28,   11,   33,    0,   35,    0}, {  -28,   10,   34,    0,   35,    0}, {  -29,   10,   35,    0,   35,    0},
    {  -29,   10,   36,    0,   35,    0}, {  -30,   10,   37,    0,   35,    0}, {  -31,    9,   38,    0,   35,    0}, {  -31,    9,   39,    0,   35,    0}, {  -32,    9,   39,    0,   35,    0},
    {  -32,    8,   40,    0,   35,    0}, {  -33,    8,   41,    0,   35,    0}, {  -33,    8,   42,    0,   36,    0}, {  -34,    7,   43,    0,   36,    0}, {  -34,    7,   44,    0,   36,    0},
    {  -35,    7,   45,    0,   36,    0}, {  -35,    6,   46,    0,   36,    0}, {  -36,    6,   47,    0,   36,    0}, {  -36,    5,   48,    0,   36,    0}, {  -37,    5,   49,    0,   36,    0},
    {  -37,    4,   50,    0,   36,    0}, {  -38,    4,   51,    0,   36,    0}, {  -38,    4,   52,    0,   36,    0}, {  -38,    3,   53,    0,   36,    0}, {  -39,    3,   54,    0,   36,    0},
    {  -39,    2,   55,    0,   36,    0}, {  -39,    2,   56,    0,   36,    0}, {  -40,    1,   57,    0,   36,    0}, {  -40,    1,   58,    0,   36,    0}, {  -40,    0,   59,    0,   36,    0},
    {  -41,   -1,   60,    0,   36,    0}, {  -41,   -1,   61,    0,   36,    0}, {  -41,   -2,   61,    0,   36,    0}, {  -42,   -2,   62,    0,   37,    0}, {  -42,   -3,   63,    0,   37,    0},
    {  -42,   -3,   64,    0,   37,    0}, {  -43,   -4,   65,    0,   37,    0}, {  -43,   -5,   66,    0,   37,    0}, {  -43,   -5,   67,    0,   37,    0}, {  -43,   -6,   68,    0,   37,    0},
    {  -43,   -7,   69,    0,   37,    0}, {  -44,   -7,   70,    0,   37,    0}, {  -44,   -8,   70,    0,   37,    0}, {  -44,   -9,   71,    0,   37,    0}, {  -44,   -9,   72,    0,   37,    0},
    {  -45,  -10,   73,    0,   37,    0}, {  -45,  -11,   74,    0,   37,    0}, {  -45,  -11,   75,    0,   37,    0}, {  -45,  -12,   75,    0,   37,    0}, {  -45,  -13,   76,    0,   37,    0},
    {  -45,  -14,   77,    0,   37,    0}, {  -45,  -14,   78,    0,   37,    0}, {  -46,  -15,   79,    0,   37,    0}, {  -46,  -16,   79,    0,   37,    0}, {  -46,  -17,   80,    0,   37,    0},
    {  -46,  -18,   81,    0,   37,    0}, {  -46,  -18,   82,    0,   37,    0}, {  -46,  -19,   82,    0,   37,    0}, {  -46,  -20,   83,    0,   37,    0}, {  -46,  -21,   84,    0,   37,    0},
    {  -47,  -22,   84,    0,   37,    0}, {  -47,  -23,   85,    0,   38,    0}, {  -47,  -23,   86,    0,   38,    0}, {  -47,  -24,   86,    0,   38,    0}, {  -47,  -25,   87,    0,   38,    0},
    {  -47,  -26,   87,    0,   38,    0}, {  -47,  -27,   88,    0,   38,    0}, {  -47,  -28,   88,    0,   38,    0}, {  -47,  -29,   89,    0,   38,    0}, {  -47,  -30,   90,    0,   38,    0},
    {  -47,  -30,   90,    0,   38,    0}, {  -47,  -31,   91,    0,   38,    0}, {  -47,  -32,   91,    0,   38,    0}, {  -47,  -33,   92,    0,   38,    0}, {  -48,  -34,   92,    0,   38,    0},
    {  -48,  -35,   92,    0,   38,    0}, {  -48,  -36,   93,    0,   38,    0}, {  -48,  -37,   93,    0,   38,    0}, {  -48,  -38,   94,    0,   38,    0}, {  -48,  -39,   94,    0,   38,    0},
    {  -48,  -40,   94,    0,   38,    0}, {  -48,  -41,   95,    0,   38,    0}, {  -48,  -42,   95,    0,   38,    0}, {  -48,  -43,   95,    0,   38,    0}, {  -48,  -44,   96,    0,   38,    0},
    {  -48,  -45,   96,    0,   38,    0}, {  -48,  -46,   96,    0,   38,    0}, {  -48,  -47,   97,    0,   38,    0}, {  -48,  -48,   97,    0,   38,    0}, {  -48,  -49,   97,    0,   38,    0},
    {  -48,  -49,   97,    8,   15,    0}, {  -48,  -50,   97,    8,   15,    0}, {  -48,  -51,   98,    8,   15,    0}, {  -48,  -52,   98,    8,   15,    0}, {  -48,  -53,   98,    8,   16,    0},
    {  -48,  -54,   98,    8,   16,    0}, {  -48,  -55,   98,    8,   16,    0}, {  -48,  -56,   98,    8,   16,    0}, {  -48,  -57,   98,    8,   16,    0}, {  -48,  -58,   98,    8,   16,    0},
    {  -48,  -59,   99,    8,   16,    0}, {  -48,  -60,   99,    8,   16,    0}, {  -48,  -61,   99,    8,   16,    0}, {  -48,  -62,   99,    8,   16,    0}, {  -48,  -63,   99,    8,   16,    0},
    {  -48,  -64,   99,    8,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeCorkscrewUp1, {
    {   16,    0,    0,    8,    0,    0}, {   16,    1,    0,    8,    0,    0}, {   16,    2,    0,    8,    0,    0}, {   16,    3,    0,    8,    0,    0}, {   16,    4,    0,    8,    0,    0},
    {   16,    5,    0,    8,    0,    0}, {   16,    6,    0,    8,    0,    0}, {   16,    7,    0,    8,    0,    0}, {   16,    8,    0,    8,    0,    0}, {   16,    9,    1,    8,    1,    0},
    {   16,   10,    1,    8,    1,    0}, {   16,   11,    1,    8,    1,    0}, {   16,   12,    1,    8,    1,    0}, {   16,   13,    1,    8,    1,    0}, {   16,   14,    1,    8,    1,    0},
    {   16,   15,    2,    8,    1,    0}, {   16,   16,    2,    8,    1,    0}, {   16,   17,    2,    8,    1,    0}, {   16,   18,    2,    8,    1,    0}, {   16,   19,    2,    8,    1,    0},
    {   16,   20,    3,    8,    1,    0}, {   16,   21,    3,    8,    1,    0}, {   16,   22,    3,    8,    1,    0}, {   16,   23,    4,    8,    1,    0}, {   16,   24,    4,    8,    1,    0},
    {   16,   25,    4,    8,    2,    0}, {   16,   26,    5,    8,    2,    0}, {   16,   27,    5,    8,    2,    0}, {   16,   27,    6,    8,    2,    0}, {   16,   28,    6,    8,    2,    0},
    {   16,   29,    6,    8,   34,    0}, {   16,   30,    7,    8,   34,    0}, {   15,   31,    7,    8,   34,    0}, {   15,   32,    8,    8,   34,    0}, {   15,   33,    8,    8,   34,    0},
    {   15,   34,    9,    8,   34,    0}, {   15,   35,    9,    8,   34,    0}, {   15,   36,   10,    8,   34,    0}, {   15,   37,   10,    8,   34,    0}, {   15,   38,   11,    8,   34,    0},
    {   15,   38,   12,    8,   34,    0}, {   15,   39,   12,    8,   34,    0}, {   15,   40,   13,    8,   34,    0}, {   15,   41,   13,    8,   34,    0}, {   15,   42,   14,    8,   34,    0},
    {   15,   43,   15,    8,   34,    0}, {   14,   44,   15,    8,   34,    0}, {   14,   44,   16,    8,   34,    0}, {   14,   45,   17,    8,   34,    0}, {   14,   46,   17,    8,   34,    0},
    {   14,   47,   18,    8,   34,    0}, {   14,   48,   19,    8,   34,    0}, {   14,   48,   20,    8,   34,    0}, {   14,   49,   20,    8,   34,    0}, {   13,   50,   21,    8,   35,    0},
    {   13,   51,   22,    8,   35,    0}, {   13,   51,   23,    8,   35,    0}, {   13,   52,   24,    8,   35,    0}, {   13,   53,   24,    8,   35,    0}, {   13,   54,   25,    8,   35,    0},
    {   12,   54,   26,    8,   35,    0}, {   12,   55,   27,    8,   35,    0}, {   12,   56,   28,    8,   35,    0}, {   12,   56,   29,    8,   35,    0}, {   12,   57,   29,    8,   35,    0},
    {   11,   58,   30,    8,   35,    0}, {   11,   58,   31,    8,   35,    0}, {   11,   59,   32,    8,   35,    0}, {   11,   60,   33,    8,   35,    0}, {   10,   60,   34,    8,   35,    0},
    {   10,   61,   35,    8,   35,    0}, {   10,   61,   36,    8,   35,    0}, {   10,   62,   37,    8,   35,    0}, {    9,   63,   38,    8,   35,    0}, {    9,   63,   39,    8,   35,    0},
    {    9,   64,   39,    8,   35,    0}, {    8,   64,   40,    8,   35,    0}, {    8,   65,   41,    8,   35,    0}, {    8,   65,   42,    8,   36,    0}, {    7,   66,   43,    8,   36,    0},
    {    7,   66,   44,    8,   36,    0}, {    7,   67,   45,    8,   36,    0}, {    6,   67,   46,    8,   36,    0}, {    6,   68,   47,    8,   36,    0}, {    5,   68,   48,    8,   36,    0},
    {    5,   69,   49,    8,   36,    0}, {    4,   69,   50,    8,   36,    0}, {    4,   70,   51,    8,   36,    0}, {    4,   70,   52,    8,   36,    0}, {    3,   70,   53,    8,   36,    0},
    {    3,   71,   54,    8,   36,    0}, {    2,   71,   55,    8,   36,    0}, {    2,   71,   56,    8,   36,    0}, {    1,   72,   57,    8,   36,    0}, {    1,   72,   58,    8,   36,    0},
    {    0,   72,   59,    8,   36,    0}, {   -1,   73,   60,    8,   36,    0}, {   -1,   73,   61,    8,   36,    0}, {   -2,   73,   61,    8,   36,    0}, {   -2,   74,   62,    8,   37,    0},
    {   -3,   74,   63,    8,   37,    0}, {   -3,   74,   64,    8,   37,    0}, {   -4,   75,   65,    8,   37,    0}, {   -5,   75,   66,    8,   37,    0}, {   -5,   75,   67,    8,   37,    0},
    {   -6,   75,   68,    8,   37,    0}, {   -7,   75,   69,    8,   37,    0}, {   -7,   76,   70,    8,   37,    0}, {   -8,   76,   70,    8,   37,    0}, {   -9,   76,   71,    8,   37,    0},
    {   -9,   76,   72,    8,   37,    0}, {  -10,   77,   73,    8,   37,    0}, {  -11,   77,   74,    8,   37,    0}, {  -11,   77,   75,    8,   37,    0}, {  -12,   77,   75,    8,   37,    0},
    {  -13,   77,   76,    8,   37,    0}, {  -14,   77,   77,    8,   37,    0}, {  -14,   77,   78,    8,   37,    0}, {  -15,   78,   79,    8,   37,    0}, {  -16,   78,   79,    8,   37,    0},
    {  -17,   78,   80,    8,   37,    0}, {  -18,   78,   81,    8,   37,    0}, {  -18,   78,   82,    8,   37,    0}, {  -19,   78,   82,    8,   37,    0}, {  -20,   78,   83,    8,   37,    0},
    {  -21,   78,   84,    8,   37,    0}, {  -22,   79,   84,    8,   37,    0}, {  -23,   79,   85,    8,   38,    0}, {  -23,   79,   86,    8,   38,    0}, {  -24,   79,   86,    8,   38,    0},
    {  -25,   79,   87,    8,   38,    0}, {  -26,   79,   87,    8,   38,    0}, {  -27,   79,   88,    8,   38,    0}, {  -28,   79,   88,    8,   38,    0}, {  -29,   79,   89,    8,   38,    0},
    {  -30,   79,   90,    8,   38,    0}, {  -30,   79,   90,    8,   38,    0}, {  -31,   79,   91,    8,   38,    0}, {  -32,   79,   91,    8,   38,    0}, {  -33,   79,   92,    8,   38,    0},
    {  -34,   80,   92,    8,   38,    0}, {  -35,   80,   92,    8,   38,    0}, {  -36,   80,   93,    8,   38,    0}, {  -37,   80,   93,    8,   38,    0}, {  -38,   80,   94,    8,   38,    0},
    {  -39,   80,   94,    8,   38,    0}, {  -40,   80,   94,    8,   38,    0}, {  -41,   80,   95,    8,   38,    0}, {  -42,   80,   95,    8,   38,    0}, {  -43,   80,   95,    8,   38,    0},
    {  -44,   80,   96,    8,   38,    0}, {  -45,   80,   96,    8,   38,    0}, {  -46,   80,   96,    8,   38,    0}, {  -47,   80,   97,    8,   38,    0}, {  -48,   80,   97,    8,   38,    0},
    {  -49,   80,   97,    8,   38,    0}, {  -49,   80,   97,   16,   15,    0}, {  -50,   80,   97,   16,   15,    0}, {  -51,   80,   98,   16,   15,    0}, {  -52,   80,   98,   16,   15,    0},
    {  -53,   80,   98,   16,   16,    0}, {  -54,   80,   98,   16,   16,    0}, {  -55,   80,   98,   16,   16,    0}, {  -56,   80,   98,   16,   16,    0}, {  -57,   80,   98,   16,   16,    0},
    {  -58,   80,   98,   16,   16,    0}, {  -59,   80,   99,   16,   16,    0}, {  -60,   80,   99,   16,   16,    0}, {  -61,   80,   99,   16,   16,    0}, {  -62,   80,   99,   16,   16,    0},
    {  -63,   80,   99,   16,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeCorkscrewUp2, {
    {    0,   16,    0,   16,    0,    0}, {    1,   16,    0,   16,    0,    0}, {    2,   16,    0,   16,    0,    0}, {    3,   16,    0,   16,    0,    0}, {    4,   16,    0,   16,    0,    0},
    {    5,   16,    0,   16,    0,    0}, {    6,   16,    0,   16,    0,    0}, {    7,   16,    0,   16,    0,    0}, {    8,   16,    0,   16,    0,    0}, {    9,   16,    1,   16,    1,    0},
    {   10,   16,    1,   16,    1,    0}, {   11,   16,    1,   16,    1,    0}, {   12,   16,    1,   16,    1,    0}, {   13,   16,    1,   16,    1,    0}, {   14,   16,    1,   16,    1,    0},
    {   15,   16,    2,   16,    1,    0}, {   16,   16,    2,   16,    1,    0}, {   17,   16,    2,   16,    1,    0}, {   18,   16,    2,   16,    1,    0}, {   19,   16,    2,   16,    1,    0},
    {   20,   16,    3,   16,    1,    0}, {   21,   16,    3,   16,    1,    0}, {   22,   16,    3,   16,    1,    0}, {   23,   16,    4,   16,    1,    0}, {   24,   16,    4,   16,    1,    0},
    {   25,   16,    4,   16,    2,    0}, {   26,   16,    5,   16,    2,    0}, {   27,   16,    5,   16,    2,    0}, {   27,   16,    6,   16,    2,    0}, {   28,   16,    6,   16,    2,    0},
    {   29,   16,    6,   16,   34,    0}, {   30,   16,    7,   16,   34,    0}, {   31,   17,    7,   16,   34,    0}, {   32,   17,    8,   16,   34,    0}, {   33,   17,    8,   16,   34,    0},
    {   34,   17,    9,   16,   34,    0}, {   35,   17,    9,   16,   34,    0}, {   36,   17,   10,   16,   34,    0}, {   37,   17,   10,   16,   34,    0}, {   38,   17,   11,   16,   34,    0},
    {   38,   17,   12,   16,   34,    0}, {   39,   17,   12,   16,   34,    0}, {   40,   17,   13,   16,   34,    0}, {   41,   17,   13,   16,   34,    0}, {   42,   17,   14,   16,   34,    0},
    {   43,   17,   15,   16,   34,    0}, {   44,   18,   15,   16,   34,    0}, {   44,   18,   16,   16,   34,    0}, {   45,   18,   17,   16,   34,    0}, {   46,   18,   17,   16,   34,    0},
    {   47,   18,   18,   16,   34,    0}, {   48,   18,   19,   16,   34,    0}, {   48,   18,   20,   16,   34,    0}, {   49,   18,   20,   16,   34,    0}, {   50,   19,   21,   16,   35,    0},
    {   51,   19,   22,   16,   35,    0}, {   51,   19,   23,   16,   35,    0}, {   52,   19,   24,   16,   35,    0}, {   53,   19,   24,   16,   35,    0}, {   54,   19,   25,   16,   35,    0},
    {   54,   20,   26,   16,   35,    0}, {   55,   20,   27,   16,   35,    0}, {   56,   20,   28,   16,   35,    0}, {   56,   20,   29,   16,   35,    0}, {   57,   20,   29,   16,   35,    0},
    {   58,   21,   30,   16,   35,    0}, {   58,   21,   31,   16,   35,    0}, {   59,   21,   32,   16,   35,    0}, {   60,   21,   33,   16,   35,    0}, {   60,   22,   34,   16,   35,    0},
    {   61,   22,   35,   16,   35,    0}, {   61,   22,   36,   16,   35,    0}, {   62,   22,   37,   16,   35,    0}, {   63,   23,   38,   16,   35,    0}, {   63,   23,   39,   16,   35,    0},
    {   64,   23,   39,   16,   35,    0}, {   64,   24,   40,   16,   35,    0}, {   65,   24,   41,   16,   35,    0}, {   65,   24,   42,   16,   36,    0}, {   66,   25,   43,   16,   36,    0},
    {   66,   25,   44,   16,   36,    0}, {   67,   25,   45,   16,   36,    0}, {   67,   26,   46,   16,   36,    0}, {   68,   26,   47,   16,   36,    0}, {   68,   27,   48,   16,   36,    0},
    {   69,   27,   49,   16,   36,    0}, {   69,   28,   50,   16,   36,    0}, {   70,   28,   51,   16,   36,    0}, {   70,   28,   52,   16,   36,    0}, {   70,   29,   53,   16,   36,    0},
    {   71,   29,   54,   16,   36,    0}, {   71,   30,   55,   16,   36,    0}, {   71,   30,   56,   16,   36,    0}, {   72,   31,   57,   16,   36,    0}, {   72,   31,   58,   16,   36,    0},
    {   72,   32,   59,   16,   36,    0}, {   73,   33,   60,   16,   36,    0}, {   73,   33,   61,   16,   36,    0}, {   73,   34,   61,   16,   36,    0}, {   74,   34,   62,   16,   37,    0},
    {   74,   35,   63,   16,   37,    0}, {   74,   35,   64,   16,   37,    0}, {   75,   36,   65,   16,   37,    0}, {   75,   37,   66,   16,   37,    0}, {   75,   37,   67,   16,   37,    0},
    {   75,   38,   68,   16,   37,    0}, {   75,   39,   69,   16,   37,    0}, {   76,   39,   70,   16,   37,    0}, {   76,   40,   70,   16,   37,    0}, {   76,   41,   71,   16,   37,    0},
    {   76,   41,   72,   16,   37,    0}, {   77,   42,   73,   16,   37,    0}, {   77,   43,   74,   16,   37,    0}, {   77,   43,   75,   16,   37,    0}, {   77,   44,   75,   16,   37,    0},
    {   77,   45,   76,   16,   37,    0}, {   77,   46,   77,   16,   37,    0}, {   77,   46,   78,   16,   37,    0}, {   78,   47,   79,   16,   37,    0}, {   78,   48,   79,   16,   37,    0},
    {   78,   49,   80,   16,   37,    0}, {   78,   50,   81,   16,   37,    0}, {   78,   50,   82,   16,   37,    0}, {   78,   51,   82,   16,   37,    0}, {   78,   52,   83,   16,   37,    0},
    {   78,   53,   84,   16,   37,    0}, {   79,   54,   84,   16,   37,    0}, {   79,   55,   85,   16,   38,    0}, {   79,   55,   86,   16,   38,    0}, {   79,   56,   86,   16,   38,    0},
    {   79,   57,   87,   16,   38,    0}, {   79,   58,   87,   16,   38,    0}, {   79,   59,   88,   16,   38,    0}, {   79,   60,   88,   16,   38,    0}, {   79,   61,   89,   16,   38,    0},
    {   79,   62,   90,   16,   38,    0}, {   79,   62,   90,   16,   38,    0}, {   79,   63,   91,   16,   38,    0}, {   79,   64,   91,   16,   38,    0}, {   79,   65,   92,   16,   38,    0},
    {   80,   66,   92,   16,   38,    0}, {   80,   67,   92,   16,   38,    0}, {   80,   68,   93,   16,   38,    0}, {   80,   69,   93,   16,   38,    0}, {   80,   70,   94,   16,   38,    0},
    {   80,   71,   94,   16,   38,    0}, {   80,   72,   94,   16,   38,    0}, {   80,   73,   95,   16,   38,    0}, {   80,   74,   95,   16,   38,    0}, {   80,   75,   95,   16,   38,    0},
    {   80,   76,   96,   16,   38,    0}, {   80,   77,   96,   16,   38,    0}, {   80,   78,   96,   16,   38,    0}, {   80,   79,   97,   16,   38,    0}, {   80,   80,   97,   16,   38,    0},
    {   80,   81,   97,   16,   38,    0}, {   80,   81,   97,   24,   15,    0}, {   80,   82,   97,   24,   15,    0}, {   80,   83,   98,   24,   15,    0}, {   80,   84,   98,   24,   15,    0},
    {   80,   85,   98,   24,   16,    0}, {   80,   86,   98,   24,   16,    0}, {   80,   87,   98,   24,   16,    0}, {   80,   88,   98,   24,   16,    0}, {   80,   89,   98,   24,   16,    0},
    {   80,   90,   98,   24,   16,    0}, {   80,   91,   99,   24,   16,    0}, {   80,   92,   99,   24,   16,    0}, {   80,   93,   99,   24,   16,    0}, {   80,   94,   99,   24,   16,    0},
    {   80,   95,   99,   24,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeCorkscrewUp3, {
    {   16,   31,    0,   24,    0,    0}, {   16,   30,    0,   24,    0,    0}, {   16,   29,    0,   24,    0,    0}, {   16,   28,    0,   24,    0,    0}, {   16,   27,    0,   24,    0,    0},
    {   16,   26,    0,   24,    0,    0}, {   16,   25,    0,   24,    0,    0}, {   16,   24,    0,   24,    0,    0}, {   16,   23,    1,   24,    1,    0}, {   16,   22,    1,   24,    1,    0},
    {   16,   21,    1,   24,    1,    0}, {   16,   20,    1,   24,    1,    0}, {   16,   19,    1,   24,    1,    0}, {   16,   18,    1,   24,    1,    0}, {   16,   17,    2,   24,    1,    0},
    {   16,   16,    2,   24,    1,    0}, {   16,   15,    2,   24,    1,    0}, {   16,   14,    2,   24,    1,    0}, {   16,   13,    2,   24,    1,    0}, {   16,   12,    3,   24,    1,    0},
    {   16,   11,    3,   24,    1,    0}, {   16,   10,    3,   24,    1,    0}, {   16,    9,    4,   24,    1,    0}, {   16,    8,    4,   24,    1,    0}, {   16,    7,    4,   24,    2,    0},
    {   16,    6,    5,   24,    2,    0}, {   16,    5,    5,   24,    2,    0}, {   16,    5,    6,   24,    2,    0}, {   16,    4,    6,   24,    2,    0}, {   16,    3,    6,   24,   34,    0},
    {   16,    2,    7,   24,   34,    0}, {   17,    1,    7,   24,   34,    0}, {   17,    0,    8,   24,   34,    0}, {   17,   -1,    8,   24,   34,    0}, {   17,   -2,    9,   24,   34,    0},
    {   17,   -3,    9,   24,   34,    0}, {   17,   -4,   10,   24,   34,    0}, {   17,   -5,   10,   24,   34,    0}, {   17,   -6,   11,   24,   34,    0}, {   17,   -6,   12,   24,   34,    0},
    {   17,   -7,   12,   24,   34,    0}, {   17,   -8,   13,   24,   34,    0}, {   17,   -9,   13,   24,   34,    0}, {   17,  -10,   14,   24,   34,    0}, {   17,  -11,   15,   24,   34,    0},
    {   18,  -12,   15,   24,   34,    0}, {   18,  -12,   16,   24,   34,    0}, {   18,  -13,   17,   24,   34,    0}, {   18,  -14,   17,   24,   34,    0}, {   18,  -15,   18,   24,   34,    0},
    {   18,  -16,   19,   24,   34,    0}, {   18,  -16,   20,   24,   34,    0}, {   18,  -17,   20,   24,   34,    0}, {   19,  -18,   21,   24,   35,    0}, {   19,  -19,   22,   24,   35,    0},
    {   19,  -19,   23,   24,   35,    0}, {   19,  -20,   24,   24,   35,    0}, {   19,  -21,   24,   24,   35,    0}, {   19,  -22,   25,   24,   35,    0}, {   20,  -22,   26,   24,   35,    0},
    {   20,  -23,   27,   24,   35,    0}, {   20,  -24,   28,   24,   35,    0}, {   20,  -24,   29,   24,   35,    0}, {   20,  -25,   29,   24,   35,    0}, {   21,  -26,   30,   24,   35,    0},
    {   21,  -26,   31,   24,   35,    0}, {   21,  -27,   32,   24,   35,    0}, {   21,  -28,   33,   24,   35,    0}, {   22,  -28,   34,   24,   35,    0}, {   22,  -29,   35,   24,   35,    0},
    {   22,  -29,   36,   24,   35,    0}, {   22,  -30,   37,   24,   35,    0}, {   23,  -31,   38,   24,   35,    0}, {   23,  -31,   39,   24,   35,    0}, {   23,  -32,   39,   24,   35,    0},
    {   24,  -32,   40,   24,   35,    0}, {   24,  -33,   41,   24,   35,    0}, {   24,  -33,   42,   24,   36,    0}, {   25,  -34,   43,   24,   36,    0}, {   25,  -34,   44,   24,   36,    0},
    {   25,  -35,   45,   24,   36,    0}, {   26,  -35,   46,   24,   36,    0}, {   26,  -36,   47,   24,   36,    0}, {   27,  -36,   48,   24,   36,    0}, {   27,  -37,   49,   24,   36,    0},
    {   28,  -37,   50,   24,   36,    0}, {   28,  -38,   51,   24,   36,    0}, {   28,  -38,   52,   24,   36,    0}, {   29,  -38,   53,   24,   36,    0}, {   29,  -39,   54,   24,   36,    0},
    {   30,  -39,   55,   24,   36,    0}, {   30,  -39,   56,   24,   36,    0}, {   31,  -40,   57,   24,   36,    0}, {   31,  -40,   58,   24,   36,    0}, {   32,  -40,   59,   24,   36,    0},
    {   33,  -41,   60,   24,   36,    0}, {   33,  -41,   61,   24,   36,    0}, {   34,  -41,   61,   24,   36,    0}, {   34,  -42,   62,   24,   37,    0}, {   35,  -42,   63,   24,   37,    0},
    {   35,  -42,   64,   24,   37,    0}, {   36,  -43,   65,   24,   37,    0}, {   37,  -43,   66,   24,   37,    0}, {   37,  -43,   67,   24,   37,    0}, {   38,  -43,   68,   24,   37,    0},
    {   39,  -43,   69,   24,   37,    0}, {   39,  -44,   70,   24,   37,    0}, {   40,  -44,   70,   24,   37,    0}, {   41,  -44,   71,   24,   37,    0}, {   41,  -44,   72,   24,   37,    0},
    {   42,  -45,   73,   24,   37,    0}, {   43,  -45,   74,   24,   37,    0}, {   43,  -45,   75,   24,   37,    0}, {   44,  -45,   75,   24,   37,    0}, {   45,  -45,   76,   24,   37,    0},
    {   46,  -45,   77,   24,   37,    0}, {   46,  -45,   78,   24,   37,    0}, {   47,  -46,   79,   24,   37,    0}, {   48,  -46,   79,   24,   37,    0}, {   49,  -46,   80,   24,   37,    0},
    {   50,  -46,   81,   24,   37,    0}, {   50,  -46,   82,   24,   37,    0}, {   51,  -46,   82,   24,   37,    0}, {   52,  -46,   83,   24,   37,    0}, {   53,  -46,   84,   24,   37,    0},
    {   54,  -47,   84,   24,   37,    0}, {   55,  -47,   85,   24,   38,    0}, {   55,  -47,   86,   24,   38,    0}, {   56,  -47,   86,   24,   38,    0}, {   57,  -47,   87,   24,   38,    0},
    {   58,  -47,   87,   24,   38,    0}, {   59,  -47,   88,   24,   38,    0}, {   60,  -47,   88,   24,   38,    0}, {   61,  -47,   89,   24,   38,    0}, {   62,  -47,   90,   24,   38,    0},
    {   62,  -47,   90,   24,   38,    0}, {   63,  -47,   91,   24,   38,    0}, {   64,  -47,   91,   24,   38,    0}, {   65,  -47,   92,   24,   38,    0}, {   66,  -48,   92,   24,   38,    0},
    {   67,  -48,   92,   24,   38,    0}, {   68,  -48,   93,   24,   38,    0}, {   69,  -48,   93,   24,   38,    0}, {   70,  -48,   94,   24,   38,    0}, {   71,  -48,   94,   24,   38,    0},
    {   72,  -48,   94,   24,   38,    0}, {   73,  -48,   95,   24,   38,    0}, {   74,  -48,   95,   24,   38,    0}, {   75,  -48,   95,   24,   38,    0}, {   76,  -48,   96,   24,   38,    0},
    {   77,  -48,   96,   24,   38,    0}, {   78,  -48,   96,   24,   38,    0}, {   79,  -48,   97,   24,   38,    0}, {   80,  -48,   97,   24,   38,    0}, {   81,  -48,   97,   24,   38,    0},
    {   81,  -48,   97,    0,   15,    0}, {   82,  -48,   97,    0,   15,    0}, {   83,  -48,   98,    0,   15,    0}, {   84,  -48,   98,    0,   15,    0}, {   85,  -48,   98,    0,   16,    0},
    {   86,  -48,   98,    0,   16,    0}, {   87,  -48,   98,    0,   16,    0}, {   88,  -48,   98,    0,   16,    0}, {   89,  -48,   98,    0,   16,    0}, {   90,  -48,   98,    0,   16,    0},
    {   91,  -48,   99,    0,   16,    0}, {   92,  -48,   99,    0,   16,    0}, {   93,  -48,   99,    0,   16,    0}, {   94,  -48,   99,    0,   16,    0}, {   95,  -48,   99,    0,   16,    0},
    {   96,  -48,   99,    0,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeCorkscrewUp0, {
    {   31,   16,    0,    0,    0,    0}, {   30,   16,    0,    0,    0,    0}, {   29,   16,    0,    0,    0,    0}, {   28,   16,    0,    0,    0,    0}, {   27,   16,    0,    0,    0,    0},
    {   26,   16,    0,    0,    0,    0}, {   25,   16,    0,    0,    0,    0}, {   24,   16,    0,    0,    0,    0}, {   23,   16,    1,    0,    1,    0}, {   22,   16,    1,    0,    1,    0},
    {   21,   16,    1,    0,    1,    0}, {   20,   16,    1,    0,    1,    0}, {   19,   16,    1,    0,    1,    0}, {   18,   16,    1,    0,    1,    0}, {   17,   16,    2,    0,    1,    0},
    {   16,   16,    2,    0,    1,    0}, {   15,   16,    2,    0,    1,    0}, {   14,   16,    2,    0,    1,    0}, {   13,   16,    2,    0,    1,    0}, {   12,   16,    3,    0,    1,    0},
    {   11,   16,    3,    0,    1,    0}, {   10,   16,    3,    0,    1,    0}, {    9,   16,    4,    0,    1,    0}, {    8,   16,    4,    0,    1,    0}, {    7,   16,    4,    0,    2,    0},
    {    6,   16,    5,    0,    2,    0}, {    5,   16,    5,    0,    2,    0}, {    5,   16,    6,    0,    2,    0}, {    4,   16,    6,    0,    2,    0}, {    3,   16,    6,    0,   24,    0},
    {    2,   16,    7,    0,   24,    0}, {    1,   17,    7,    0,   24,    0}, {    0,   17,    8,    0,   24,    0}, {   -1,   17,    8,    0,   24,    0}, {   -2,   17,    9,    0,   24,    0},
    {   -3,   17,    9,    0,   24,    0}, {   -4,   17,   10,    0,   24,    0}, {   -5,   17,   10,    0,   24,    0}, {   -6,   17,   11,    0,   24,    0}, {   -6,   17,   12,    0,   24,    0},
    {   -7,   17,   12,    0,   24,    0}, {   -8,   17,   13,    0,   24,    0}, {   -9,   17,   13,    0,   24,    0}, {  -10,   17,   14,    0,   24,    0}, {  -11,   17,   15,    0,   24,    0},
    {  -12,   18,   15,    0,   24,    0}, {  -12,   18,   16,    0,   24,    0}, {  -13,   18,   17,    0,   24,    0}, {  -14,   18,   17,    0,   24,    0}, {  -15,   18,   18,    0,   24,    0},
    {  -16,   18,   19,    0,   24,    0}, {  -16,   18,   20,    0,   24,    0}, {  -17,   18,   20,    0,   24,    0}, {  -18,   19,   21,    0,   25,    0}, {  -19,   19,   22,    0,   25,    0},
    {  -19,   19,   23,    0,   25,    0}, {  -20,   19,   24,    0,   25,    0}, {  -21,   19,   24,    0,   25,    0}, {  -22,   19,   25,    0,   25,    0}, {  -22,   20,   26,    0,   25,    0},
    {  -23,   20,   27,    0,   25,    0}, {  -24,   20,   28,    0,   25,    0}, {  -24,   20,   29,    0,   25,    0}, {  -25,   20,   29,    0,   25,    0}, {  -26,   21,   30,    0,   25,    0},
    {  -26,   21,   31,    0,   25,    0}, {  -27,   21,   32,    0,   25,    0}, {  -28,   21,   33,    0,   25,    0}, {  -28,   22,   34,    0,   25,    0}, {  -29,   22,   35,    0,   25,    0},
    {  -29,   22,   36,    0,   25,    0}, {  -30,   22,   37,    0,   25,    0}, {  -31,   23,   38,    0,   25,    0}, {  -31,   23,   39,    0,   25,    0}, {  -32,   23,   39,    0,   25,    0},
    {  -32,   24,   40,    0,   25,    0}, {  -33,   24,   41,    0,   25,    0}, {  -33,   24,   42,    0,   26,    0}, {  -34,   25,   43,    0,   26,    0}, {  -34,   25,   44,    0,   26,    0},
    {  -35,   25,   45,    0,   26,    0}, {  -35,   26,   46,    0,   26,    0}, {  -36,   26,   47,    0,   26,    0}, {  -36,   27,   48,    0,   26,    0}, {  -37,   27,   49,    0,   26,    0},
    {  -37,   28,   50,    0,   26,    0}, {  -38,   28,   51,    0,   26,    0}, {  -38,   28,   52,    0,   26,    0}, {  -38,   29,   53,    0,   26,    0}, {  -39,   29,   54,    0,   26,    0},
    {  -39,   30,   55,    0,   26,    0}, {  -39,   30,   56,    0,   26,    0}, {  -40,   31,   57,    0,   26,    0}, {  -40,   31,   58,    0,   26,    0}, {  -40,   32,   59,    0,   26,    0},
    {  -41,   33,   60,    0,   26,    0}, {  -41,   33,   61,    0,   26,    0}, {  -41,   34,   61,    0,   26,    0}, {  -42,   34,   62,    0,   27,    0}, {  -42,   35,   63,    0,   27,    0},
    {  -42,   35,   64,    0,   27,    0}, {  -43,   36,   65,    0,   27,    0}, {  -43,   37,   66,    0,   27,    0}, {  -43,   37,   67,    0,   27,    0}, {  -43,   38,   68,    0,   27,    0},
    {  -43,   39,   69,    0,   27,    0}, {  -44,   39,   70,    0,   27,    0}, {  -44,   40,   70,    0,   27,    0}, {  -44,   41,   71,    0,   27,    0}, {  -44,   41,   72,    0,   27,    0},
    {  -45,   42,   73,    0,   27,    0}, {  -45,   43,   74,    0,   27,    0}, {  -45,   43,   75,    0,   27,    0}, {  -45,   44,   75,    0,   27,    0}, {  -45,   45,   76,    0,   27,    0},
    {  -45,   46,   77,    0,   27,    0}, {  -45,   46,   78,    0,   27,    0}, {  -46,   47,   79,    0,   27,    0}, {  -46,   48,   79,    0,   27,    0}, {  -46,   49,   80,    0,   27,    0},
    {  -46,   50,   81,    0,   27,    0}, {  -46,   50,   82,    0,   27,    0}, {  -46,   51,   82,    0,   27,    0}, {  -46,   52,   83,    0,   27,    0}, {  -46,   53,   84,    0,   27,    0},
    {  -47,   54,   84,    0,   27,    0}, {  -47,   55,   85,    0,   28,    0}, {  -47,   55,   86,    0,   28,    0}, {  -47,   56,   86,    0,   28,    0}, {  -47,   57,   87,    0,   28,    0},
    {  -47,   58,   87,    0,   28,    0}, {  -47,   59,   88,    0,   28,    0}, {  -47,   60,   88,    0,   28,    0}, {  -47,   61,   89,    0,   28,    0}, {  -47,   62,   90,    0,   28,    0},
    {  -47,   62,   90,    0,   28,    0}, {  -47,   63,   91,    0,   28,    0}, {  -47,   64,   91,    0,   28,    0}, {  -47,   65,   92,    0,   28,    0}, {  -48,   66,   92,    0,   28,    0},
    {  -48,   67,   92,    0,   28,    0}, {  -48,   68,   93,    0,   28,    0}, {  -48,   69,   93,    0,   28,    0}, {  -48,   70,   94,    0,   28,    0}, {  -48,   71,   94,    0,   28,    0},
    {  -48,   72,   94,    0,   28,    0}, {  -48,   73,   95,    0,   28,    0}, {  -48,   74,   95,    0,   28,    0}, {  -48,   75,   95,    0,   28,    0}, {  -48,   76,   96,    0,   28,    0},
    {  -48,   77,   96,    0,   28,    0}, {  -48,   78,   96,    0,   28,    0}, {  -48,   79,   97,    0,   28,    0}, {  -48,   80,   97,    0,   28,    0}, {  -48,   81,   97,    0,   28,    0},
    {  -48,   81,   97,   24,   15,    0}, {  -48,   82,   97,   24,   15,    0}, {  -48,   83,   98,   24,   15,    0}, {  -48,   84,   98,   24,   15,    0}, {  -48,   85,   98,   24,   16,    0},
    {  -48,   86,   98,   24,   16,    0}, {  -48,   87,   98,   24,   16,    0}, {  -48,   88,   98,   24,   16,    0}, {  -48,   89,   98,   24,   16,    0}, {  -48,   90,   98,   24,   16,    0},
    {  -48,   91,   99,   24,   16,    0}, {  -48,   92,   99,   24,   16,    0}, {  -48,   93,   99,   24,   16,    0}, {  -48,   94,   99,   24,   16,    0}, {  -48,   95,   99,   24,   16,    0},
    {  -48,   96,   99,   24,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeCorkscrewUp1, {
    {   16,    0,    0,    8,    0,    0}, {   16,    1,    0,    8,    0,    0}, {   16,    2,    0,    8,    0,    0}, {   16,    3,    0,    8,    0,    0}, {   16,    4,    0,    8,    0,    0},
    {   16,    5,    0,    8,    0,    0}, {   16,    6,    0,    8,    0,    0}, {   16,    7,    0,    8,    0,    0}, {   16,    8,    0,    8,    0,    0}, {   16,    9,    1,    8,    1,    0},
    {   16,   10,    1,    8,    1,    0}, {   16,   11,    1,    8,    1,    0}, {   16,   12,    1,    8,    1,    0}, {   16,   13,    1,    8,    1,    0}, {   16,   14,    1,    8,    1,    0},
    {   16,   15,    2,    8,    1,    0}, {   16,   16,    2,    8,    1,    0}, {   16,   17,    2,    8,    1,    0}, {   16,   18,    2,    8,    1,    0}, {   16,   19,    2,    8,    1,    0},
    {   16,   20,    3,    8,    1,    0}, {   16,   21,    3,    8,    1,    0}, {   16,   22,    3,    8,    1,    0}, {   16,   23,    4,    8,    1,    0}, {   16,   24,    4,    8,    1,    0},
    {   16,   25,    4,    8,    2,    0}, {   16,   26,    5,    8,    2,    0}, {   16,   27,    5,    8,    2,    0}, {   16,   27,    6,    8,    2,    0}, {   16,   28,    6,    8,    2,    0},
    {   16,   29,    6,    8,   24,    0}, {   16,   30,    7,    8,   24,    0}, {   17,   31,    7,    8,   24,    0}, {   17,   32,    8,    8,   24,    0}, {   17,   33,    8,    8,   24,    0},
    {   17,   34,    9,    8,   24,    0}, {   17,   35,    9,    8,   24,    0}, {   17,   36,   10,    8,   24,    0}, {   17,   37,   10,    8,   24,    0}, {   17,   38,   11,    8,   24,    0},
    {   17,   38,   12,    8,   24,    0}, {   17,   39,   12,    8,   24,    0}, {   17,   40,   13,    8,   24,    0}, {   17,   41,   13,    8,   24,    0}, {   17,   42,   14,    8,   24,    0},
    {   17,   43,   15,    8,   24,    0}, {   18,   44,   15,    8,   24,    0}, {   18,   44,   16,    8,   24,    0}, {   18,   45,   17,    8,   24,    0}, {   18,   46,   17,    8,   24,    0},
    {   18,   47,   18,    8,   24,    0}, {   18,   48,   19,    8,   24,    0}, {   18,   48,   20,    8,   24,    0}, {   18,   49,   20,    8,   24,    0}, {   19,   50,   21,    8,   25,    0},
    {   19,   51,   22,    8,   25,    0}, {   19,   51,   23,    8,   25,    0}, {   19,   52,   24,    8,   25,    0}, {   19,   53,   24,    8,   25,    0}, {   19,   54,   25,    8,   25,    0},
    {   20,   54,   26,    8,   25,    0}, {   20,   55,   27,    8,   25,    0}, {   20,   56,   28,    8,   25,    0}, {   20,   56,   29,    8,   25,    0}, {   20,   57,   29,    8,   25,    0},
    {   21,   58,   30,    8,   25,    0}, {   21,   58,   31,    8,   25,    0}, {   21,   59,   32,    8,   25,    0}, {   21,   60,   33,    8,   25,    0}, {   22,   60,   34,    8,   25,    0},
    {   22,   61,   35,    8,   25,    0}, {   22,   61,   36,    8,   25,    0}, {   22,   62,   37,    8,   25,    0}, {   23,   63,   38,    8,   25,    0}, {   23,   63,   39,    8,   25,    0},
    {   23,   64,   39,    8,   25,    0}, {   24,   64,   40,    8,   25,    0}, {   24,   65,   41,    8,   25,    0}, {   24,   65,   42,    8,   26,    0}, {   25,   66,   43,    8,   26,    0},
    {   25,   66,   44,    8,   26,    0}, {   25,   67,   45,    8,   26,    0}, {   26,   67,   46,    8,   26,    0}, {   26,   68,   47,    8,   26,    0}, {   27,   68,   48,    8,   26,    0},
    {   27,   69,   49,    8,   26,    0}, {   28,   69,   50,    8,   26,    0}, {   28,   70,   51,    8,   26,    0}, {   28,   70,   52,    8,   26,    0}, {   29,   70,   53,    8,   26,    0},
    {   29,   71,   54,    8,   26,    0}, {   30,   71,   55,    8,   26,    0}, {   30,   71,   56,    8,   26,    0}, {   31,   72,   57,    8,   26,    0}, {   31,   72,   58,    8,   26,    0},
    {   32,   72,   59,    8,   26,    0}, {   33,   73,   60,    8,   26,    0}, {   33,   73,   61,    8,   26,    0}, {   34,   73,   61,    8,   26,    0}, {   34,   74,   62,    8,   27,    0},
    {   35,   74,   63,    8,   27,    0}, {   35,   74,   64,    8,   27,    0}, {   36,   75,   65,    8,   27,    0}, {   37,   75,   66,    8,   27,    0}, {   37,   75,   67,    8,   27,    0},
    {   38,   75,   68,    8,   27,    0}, {   39,   75,   69,    8,   27,    0}, {   39,   76,   70,    8,   27,    0}, {   40,   76,   70,    8,   27,    0}, {   41,   76,   71,    8,   27,    0},
    {   41,   76,   72,    8,   27,    0}, {   42,   77,   73,    8,   27,    0}, {   43,   77,   74,    8,   27,    0}, {   43,   77,   75,    8,   27,    0}, {   44,   77,   75,    8,   27,    0},
    {   45,   77,   76,    8,   27,    0}, {   46,   77,   77,    8,   27,    0}, {   46,   77,   78,    8,   27,    0}, {   47,   78,   79,    8,   27,    0}, {   48,   78,   79,    8,   27,    0},
    {   49,   78,   80,    8,   27,    0}, {   50,   78,   81,    8,   27,    0}, {   50,   78,   82,    8,   27,    0}, {   51,   78,   82,    8,   27,    0}, {   52,   78,   83,    8,   27,    0},
    {   53,   78,   84,    8,   27,    0}, {   54,   79,   84,    8,   27,    0}, {   55,   79,   85,    8,   28,    0}, {   55,   79,   86,    8,   28,    0}, {   56,   79,   86,    8,   28,    0},
    {   57,   79,   87,    8,   28,    0}, {   58,   79,   87,    8,   28,    0}, {   59,   79,   88,    8,   28,    0}, {   60,   79,   88,    8,   28,    0}, {   61,   79,   89,    8,   28,    0},
    {   62,   79,   90,    8,   28,    0}, {   62,   79,   90,    8,   28,    0}, {   63,   79,   91,    8,   28,    0}, {   64,   79,   91,    8,   28,    0}, {   65,   79,   92,    8,   28,    0},
    {   66,   80,   92,    8,   28,    0}, {   67,   80,   92,    8,   28,    0}, {   68,   80,   93,    8,   28,    0}, {   69,   80,   93,    8,   28,    0}, {   70,   80,   94,    8,   28,    0},
    {   71,   80,   94,    8,   28,    0}, {   72,   80,   94,    8,   28,    0}, {   73,   80,   95,    8,   28,    0}, {   74,   80,   95,    8,   28,    0}, {   75,   80,   95,    8,   28,    0},
    {   76,   80,   96,    8,   28,    0}, {   77,   80,   96,    8,   28,    0}, {   78,   80,   96,    8,   28,    0}, {   79,   80,   97,    8,   28,    0}, {   80,   80,   97,    8,   28,    0},
    {   81,   80,   97,    8,   28,    0}, {   81,   80,   97,    0,   15,    0}, {   82,   80,   97,    0,   15,    0}, {   83,   80,   98,    0,   15,    0}, {   84,   80,   98,    0,   15,    0},
    {   85,   80,   98,    0,   16,    0}, {   86,   80,   98,    0,   16,    0}, {   87,   80,   98,    0,   16,    0}, {   88,   80,   98,    0,   16,    0}, {   89,   80,   98,    0,   16,    0},
    {   90,   80,   98,    0,   16,    0}, {   91,   80,   99,    0,   16,    0}, {   92,   80,   99,    0,   16,    0}, {   93,   80,   99,    0,   16,    0}, {   94,   80,   99,    0,   16,    0},
    {   95,   80,   99,    0,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeCorkscrewUp2, {
    {    0,   16,    0,   16,    0,    0}, {    1,   16,    0,   16,    0,    0}, {    2,   16,    0,   16,    0,    0}, {    3,   16,    0,   16,    0,    0}, {    4,   16,    0,   16,    0,    0},
    {    5,   16,    0,   16,    0,    0}, {    6,   16,    0,   16,    0,    0}, {    7,   16,    0,   16,    0,    0}, {    8,   16,    0,   16,    0,    0}, {    9,   16,    1,   16,    1,    0},
    {   10,   16,    1,   16,    1,    0}, {   11,   16,    1,   16,    1,    0}, {   12,   16,    1,   16,    1,    0}, {   13,   16,    1,   16,    1,    0}, {   14,   16,    1,   16,    1,    0},
    {   15,   16,    2,   16,    1,    0}, {   16,   16,    2,   16,    1,    0}, {   17,   16,    2,   16,    1,    0}, {   18,   16,    2,   16,    1,    0}, {   19,   16,    2,   16,    1,    0},
    {   20,   16,    3,   16,    1,    0}, {   21,   16,    3,   16,    1,    0}, {   22,   16,    3,   16,    1,    0}, {   23,   16,    4,   16,    1,    0}, {   24,   16,    4,   16,    1,    0},
    {   25,   16,    4,   16,    2,    0}, {   26,   16,    5,   16,    2,    0}, {   27,   16,    5,   16,    2,    0}, {   27,   16,    6,   16,    2,    0}, {   28,   16,    6,   16,    2,    0},
    {   29,   16,    6,   16,   24,    0}, {   30,   16,    7,   16,   24,    0}, {   31,   15,    7,   16,   24,    0}, {   32,   15,    8,   16,   24,    0}, {   33,   15,    8,   16,   24,    0},
    {   34,   15,    9,   16,   24,    0}, {   35,   15,    9,   16,   24,    0}, {   36,   15,   10,   16,   24,    0}, {   37,   15,   10,   16,   24,    0}, {   38,   15,   11,   16,   24,    0},
    {   38,   15,   12,   16,   24,    0}, {   39,   15,   12,   16,   24,    0}, {   40,   15,   13,   16,   24,    0}, {   41,   15,   13,   16,   24,    0}, {   42,   15,   14,   16,   24,    0},
    {   43,   15,   15,   16,   24,    0}, {   44,   14,   15,   16,   24,    0}, {   44,   14,   16,   16,   24,    0}, {   45,   14,   17,   16,   24,    0}, {   46,   14,   17,   16,   24,    0},
    {   47,   14,   18,   16,   24,    0}, {   48,   14,   19,   16,   24,    0}, {   48,   14,   20,   16,   24,    0}, {   49,   14,   20,   16,   24,    0}, {   50,   13,   21,   16,   25,    0},
    {   51,   13,   22,   16,   25,    0}, {   51,   13,   23,   16,   25,    0}, {   52,   13,   24,   16,   25,    0}, {   53,   13,   24,   16,   25,    0}, {   54,   13,   25,   16,   25,    0},
    {   54,   12,   26,   16,   25,    0}, {   55,   12,   27,   16,   25,    0}, {   56,   12,   28,   16,   25,    0}, {   56,   12,   29,   16,   25,    0}, {   57,   12,   29,   16,   25,    0},
    {   58,   11,   30,   16,   25,    0}, {   58,   11,   31,   16,   25,    0}, {   59,   11,   32,   16,   25,    0}, {   60,   11,   33,   16,   25,    0}, {   60,   10,   34,   16,   25,    0},
    {   61,   10,   35,   16,   25,    0}, {   61,   10,   36,   16,   25,    0}, {   62,   10,   37,   16,   25,    0}, {   63,    9,   38,   16,   25,    0}, {   63,    9,   39,   16,   25,    0},
    {   64,    9,   39,   16,   25,    0}, {   64,    8,   40,   16,   25,    0}, {   65,    8,   41,   16,   25,    0}, {   65,    8,   42,   16,   26,    0}, {   66,    7,   43,   16,   26,    0},
    {   66,    7,   44,   16,   26,    0}, {   67,    7,   45,   16,   26,    0}, {   67,    6,   46,   16,   26,    0}, {   68,    6,   47,   16,   26,    0}, {   68,    5,   48,   16,   26,    0},
    {   69,    5,   49,   16,   26,    0}, {   69,    4,   50,   16,   26,    0}, {   70,    4,   51,   16,   26,    0}, {   70,    4,   52,   16,   26,    0}, {   70,    3,   53,   16,   26,    0},
    {   71,    3,   54,   16,   26,    0}, {   71,    2,   55,   16,   26,    0}, {   71,    2,   56,   16,   26,    0}, {   72,    1,   57,   16,   26,    0}, {   72,    1,   58,   16,   26,    0},
    {   72,    0,   59,   16,   26,    0}, {   73,   -1,   60,   16,   26,    0}, {   73,   -1,   61,   16,   26,    0}, {   73,   -2,   61,   16,   26,    0}, {   74,   -2,   62,   16,   27,    0},
    {   74,   -3,   63,   16,   27,    0}, {   74,   -3,   64,   16,   27,    0}, {   75,   -4,   65,   16,   27,    0}, {   75,   -5,   66,   16,   27,    0}, {   75,   -5,   67,   16,   27,    0},
    {   75,   -6,   68,   16,   27,    0}, {   75,   -7,   69,   16,   27,    0}, {   76,   -7,   70,   16,   27,    0}, {   76,   -8,   70,   16,   27,    0}, {   76,   -9,   71,   16,   27,    0},
    {   76,   -9,   72,   16,   27,    0}, {   77,  -10,   73,   16,   27,    0}, {   77,  -11,   74,   16,   27,    0}, {   77,  -11,   75,   16,   27,    0}, {   77,  -12,   75,   16,   27,    0},
    {   77,  -13,   76,   16,   27,    0}, {   77,  -14,   77,   16,   27,    0}, {   77,  -14,   78,   16,   27,    0}, {   78,  -15,   79,   16,   27,    0}, {   78,  -16,   79,   16,   27,    0},
    {   78,  -17,   80,   16,   27,    0}, {   78,  -18,   81,   16,   27,    0}, {   78,  -18,   82,   16,   27,    0}, {   78,  -19,   82,   16,   27,    0}, {   78,  -20,   83,   16,   27,    0},
    {   78,  -21,   84,   16,   27,    0}, {   79,  -22,   84,   16,   27,    0}, {   79,  -23,   85,   16,   28,    0}, {   79,  -23,   86,   16,   28,    0}, {   79,  -24,   86,   16,   28,    0},
    {   79,  -25,   87,   16,   28,    0}, {   79,  -26,   87,   16,   28,    0}, {   79,  -27,   88,   16,   28,    0}, {   79,  -28,   88,   16,   28,    0}, {   79,  -29,   89,   16,   28,    0},
    {   79,  -30,   90,   16,   28,    0}, {   79,  -30,   90,   16,   28,    0}, {   79,  -31,   91,   16,   28,    0}, {   79,  -32,   91,   16,   28,    0}, {   79,  -33,   92,   16,   28,    0},
    {   80,  -34,   92,   16,   28,    0}, {   80,  -35,   92,   16,   28,    0}, {   80,  -36,   93,   16,   28,    0}, {   80,  -37,   93,   16,   28,    0}, {   80,  -38,   94,   16,   28,    0},
    {   80,  -39,   94,   16,   28,    0}, {   80,  -40,   94,   16,   28,    0}, {   80,  -41,   95,   16,   28,    0}, {   80,  -42,   95,   16,   28,    0}, {   80,  -43,   95,   16,   28,    0},
    {   80,  -44,   96,   16,   28,    0}, {   80,  -45,   96,   16,   28,    0}, {   80,  -46,   96,   16,   28,    0}, {   80,  -47,   97,   16,   28,    0}, {   80,  -48,   97,   16,   28,    0},
    {   80,  -49,   97,   16,   28,    0}, {   80,  -49,   97,    8,   15,    0}, {   80,  -50,   97,    8,   15,    0}, {   80,  -51,   98,    8,   15,    0}, {   80,  -52,   98,    8,   15,    0},
    {   80,  -53,   98,    8,   16,    0}, {   80,  -54,   98,    8,   16,    0}, {   80,  -55,   98,    8,   16,    0}, {   80,  -56,   98,    8,   16,    0}, {   80,  -57,   98,    8,   16,    0},
    {   80,  -58,   98,    8,   16,    0}, {   80,  -59,   99,    8,   16,    0}, {   80,  -60,   99,    8,   16,    0}, {   80,  -61,   99,    8,   16,    0}, {   80,  -62,   99,    8,   16,    0},
    {   80,  -63,   99,    8,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeCorkscrewUp3, {
    {   16,   31,    0,   24,    0,    0}, {   16,   30,    0,   24,    0,    0}, {   16,   29,    0,   24,    0,    0}, {   16,   28,    0,   24,    0,    0}, {   16,   27,    0,   24,    0,    0},
    {   16,   26,    0,   24,    0,    0}, {   16,   25,    0,   24,    0,    0}, {   16,   24,    0,   24,    0,    0}, {   16,   23,    1,   24,    1,    0}, {   16,   22,    1,   24,    1,    0},
    {   16,   21,    1,   24,    1,    0}, {   16,   20,    1,   24,    1,    0}, {   16,   19,    1,   24,    1,    0}, {   16,   18,    1,   24,    1,    0}, {   16,   17,    2,   24,    1,    0},
    {   16,   16,    2,   24,    1,    0}, {   16,   15,    2,   24,    1,    0}, {   16,   14,    2,   24,    1,    0}, {   16,   13,    2,   24,    1,    0}, {   16,   12,    3,   24,    1,    0},
    {   16,   11,    3,   24,    1,    0}, {   16,   10,    3,   24,    1,    0}, {   16,    9,    4,   24,    1,    0}, {   16,    8,    4,   24,    1,    0}, {   16,    7,    4,   24,    2,    0},
    {   16,    6,    5,   24,    2,    0}, {   16,    5,    5,   24,    2,    0}, {   16,    5,    6,   24,    2,    0}, {   16,    4,    6,   24,    2,    0}, {   16,    3,    6,   24,   24,    0},
    {   16,    2,    7,   24,   24,    0}, {   15,    1,    7,   24,   24,    0}, {   15,    0,    8,   24,   24,    0}, {   15,   -1,    8,   24,   24,    0}, {   15,   -2,    9,   24,   24,    0},
    {   15,   -3,    9,   24,   24,    0}, {   15,   -4,   10,   24,   24,    0}, {   15,   -5,   10,   24,   24,    0}, {   15,   -6,   11,   24,   24,    0}, {   15,   -6,   12,   24,   24,    0},
    {   15,   -7,   12,   24,   24,    0}, {   15,   -8,   13,   24,   24,    0}, {   15,   -9,   13,   24,   24,    0}, {   15,  -10,   14,   24,   24,    0}, {   15,  -11,   15,   24,   24,    0},
    {   14,  -12,   15,   24,   24,    0}, {   14,  -12,   16,   24,   24,    0}, {   14,  -13,   17,   24,   24,    0}, {   14,  -14,   17,   24,   24,    0}, {   14,  -15,   18,   24,   24,    0},
    {   14,  -16,   19,   24,   24,    0}, {   14,  -16,   20,   24,   24,    0}, {   14,  -17,   20,   24,   24,    0}, {   13,  -18,   21,   24,   25,    0}, {   13,  -19,   22,   24,   25,    0},
    {   13,  -19,   23,   24,   25,    0}, {   13,  -20,   24,   24,   25,    0}, {   13,  -21,   24,   24,   25,    0}, {   13,  -22,   25,   24,   25,    0}, {   12,  -22,   26,   24,   25,    0},
    {   12,  -23,   27,   24,   25,    0}, {   12,  -24,   28,   24,   25,    0}, {   12,  -24,   29,   24,   25,    0}, {   12,  -25,   29,   24,   25,    0}, {   11,  -26,   30,   24,   25,    0},
    {   11,  -26,   31,   24,   25,    0}, {   11,  -27,   32,   24,   25,    0}, {   11,  -28,   33,   24,   25,    0}, {   10,  -28,   34,   24,   25,    0}, {   10,  -29,   35,   24,   25,    0},
    {   10,  -29,   36,   24,   25,    0}, {   10,  -30,   37,   24,   25,    0}, {    9,  -31,   38,   24,   25,    0}, {    9,  -31,   39,   24,   25,    0}, {    9,  -32,   39,   24,   25,    0},
    {    8,  -32,   40,   24,   25,    0}, {    8,  -33,   41,   24,   25,    0}, {    8,  -33,   42,   24,   26,    0}, {    7,  -34,   43,   24,   26,    0}, {    7,  -34,   44,   24,   26,    0},
    {    7,  -35,   45,   24,   26,    0}, {    6,  -35,   46,   24,   26,    0}, {    6,  -36,   47,   24,   26,    0}, {    5,  -36,   48,   24,   26,    0}, {    5,  -37,   49,   24,   26,    0},
    {    4,  -37,   50,   24,   26,    0}, {    4,  -38,   51,   24,   26,    0}, {    4,  -38,   52,   24,   26,    0}, {    3,  -38,   53,   24,   26,    0}, {    3,  -39,   54,   24,   26,    0},
    {    2,  -39,   55,   24,   26,    0}, {    2,  -39,   56,   24,   26,    0}, {    1,  -40,   57,   24,   26,    0}, {    1,  -40,   58,   24,   26,    0}, {    0,  -40,   59,   24,   26,    0},
    {   -1,  -41,   60,   24,   26,    0}, {   -1,  -41,   61,   24,   26,    0}, {   -2,  -41,   61,   24,   26,    0}, {   -2,  -42,   62,   24,   27,    0}, {   -3,  -42,   63,   24,   27,    0},
    {   -3,  -42,   64,   24,   27,    0}, {   -4,  -43,   65,   24,   27,    0}, {   -5,  -43,   66,   24,   27,    0}, {   -5,  -43,   67,   24,   27,    0}, {   -6,  -43,   68,   24,   27,    0},
    {   -7,  -43,   69,   24,   27,    0}, {   -7,  -44,   70,   24,   27,    0}, {   -8,  -44,   70,   24,   27,    0}, {   -9,  -44,   71,   24,   27,    0}, {   -9,  -44,   72,   24,   27,    0},
    {  -10,  -45,   73,   24,   27,    0}, {  -11,  -45,   74,   24,   27,    0}, {  -11,  -45,   75,   24,   27,    0}, {  -12,  -45,   75,   24,   27,    0}, {  -13,  -45,   76,   24,   27,    0},
    {  -14,  -45,   77,   24,   27,    0}, {  -14,  -45,   78,   24,   27,    0}, {  -15,  -46,   79,   24,   27,    0}, {  -16,  -46,   79,   24,   27,    0}, {  -17,  -46,   80,   24,   27,    0},
    {  -18,  -46,   81,   24,   27,    0}, {  -18,  -46,   82,   24,   27,    0}, {  -19,  -46,   82,   24,   27,    0}, {  -20,  -46,   83,   24,   27,    0}, {  -21,  -46,   84,   24,   27,    0},
    {  -22,  -47,   84,   24,   27,    0}, {  -23,  -47,   85,   24,   28,    0}, {  -23,  -47,   86,   24,   28,    0}, {  -24,  -47,   86,   24,   28,    0}, {  -25,  -47,   87,   24,   28,    0},
    {  -26,  -47,   87,   24,   28,    0}, {  -27,  -47,   88,   24,   28,    0}, {  -28,  -47,   88,   24,   28,    0}, {  -29,  -47,   89,   24,   28,    0}, {  -30,  -47,   90,   24,   28,    0},
    {  -30,  -47,   90,   24,   28,    0}, {  -31,  -47,   91,   24,   28,    0}, {  -32,  -47,   91,   24,   28,    0}, {  -33,  -47,   92,   24,   28,    0}, {  -34,  -48,   92,   24,   28,    0},
    {  -35,  -48,   92,   24,   28,    0}, {  -36,  -48,   93,   24,   28,    0}, {  -37,  -48,   93,   24,   28,    0}, {  -38,  -48,   94,   24,   28,    0}, {  -39,  -48,   94,   24,   28,    0},
    {  -40,  -48,   94,   24,   28,    0}, {  -41,  -48,   95,   24,   28,    0}, {  -42,  -48,   95,   24,   28,    0}, {  -43,  -48,   95,   24,   28,    0}, {  -44,  -48,   96,   24,   28,    0},
    {  -45,  -48,   96,   24,   28,    0}, {  -46,  -48,   96,   24,   28,    0}, {  -47,  -48,   97,   24,   28,    0}, {  -48,  -48,   97,   24,   28,    0}, {  -49,  -48,   97,   24,   28,    0},
    {  -49,  -48,   97,   16,   15,    0}, {  -50,  -48,   97,   16,   15,    0}, {  -51,  -48,   98,   16,   15,    0}, {  -52,  -48,   98,   16,   15,    0}, {  -53,  -48,   98,   16,   16,    0},
    {  -54,  -48,   98,   16,   16,    0}, {  -55,  -48,   98,   16,   16,    0}, {  -56,  -48,   98,   16,   16,    0}, {  -57,  -48,   98,   16,   16,    0}, {  -58,  -48,   98,   16,   16,    0},
    {  -59,  -48,   99,   16,   16,    0}, {  -60,  -48,   99,   16,   16,    0}, {  -61,  -48,   99,   16,   16,    0}, {  -62,  -48,   99,   16,   16,    0}, {  -63,  -48,   99,   16,   16,    0},
    {  -64,  -48,   99,   16,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeCorkscrewDown0, {
    {   31,   16,   27,   16,   16,    0}, {   30,   16,   27,   16,   16,    0}, {   29,   16,   27,   16,   16,    0}, {   28,   16,   27,   16,   16,    0}, {   27,   16,   27,   16,   16,    0},
    {   26,   16,   27,   16,   16,    0}, {   25,   16,   27,   16,   16,    0}, {   24,   16,   27,   16,   16,    0}, {   23,   16,   27,   16,   16,    0}, {   22,   16,   26,   16,   16,    0},
    {   21,   16,   26,   16,   16,    0}, {   20,   16,   26,   16,   23,    0}, {   19,   16,   26,   16,   23,    0}, {   18,   16,   26,   16,   23,    0}, {   17,   16,   26,   16,   23,    0},
    {   17,   16,   25,   24,   33,    0}, {   16,   16,   25,   24,   33,    0}, {   15,   16,   25,   24,   33,    0}, {   14,   16,   25,   24,   33,    0}, {   13,   16,   24,   24,   33,    0},
    {   12,   16,   24,   24,   33,    0}, {   11,   16,   24,   24,   33,    0}, {   10,   16,   23,   24,   33,    0}, {    9,   16,   23,   24,   33,    0}, {    8,   16,   23,   24,   33,    0},
    {    7,   16,   22,   24,   33,    0}, {    6,   16,   22,   24,   33,    0}, {    5,   16,   22,   24,   33,    0}, {    4,   16,   21,   24,   33,    0}, {    3,   16,   21,   24,   33,    0},
    {    2,   16,   20,   24,   33,    0}, {    1,   15,   20,   24,   33,    0}, {    0,   15,   19,   24,   33,    0}, {   -1,   15,   19,   24,   33,    0}, {   -2,   15,   18,   24,   33,    0},
    {   -2,   15,   18,   24,   33,    0}, {   -3,   15,   17,   24,   33,    0}, {   -4,   15,   17,   24,   33,    0}, {   -5,   15,   16,   24,   33,    0}, {   -6,   15,   16,   24,   33,    0},
    {   -7,   15,   15,   24,   33,    0}, {   -8,   15,   14,   24,   33,    0}, {   -9,   15,   14,   24,   33,    0}, {   -9,   15,   13,   24,   33,    0}, {  -10,   15,   13,   24,   32,    0},
    {  -11,   14,   12,   24,   32,    0}, {  -12,   14,   11,   24,   32,    0}, {  -13,   14,   11,   24,   32,    0}, {  -14,   14,   10,   24,   32,    0}, {  -14,   14,    9,   24,   32,    0},
    {  -15,   14,    8,   24,   32,    0}, {  -16,   14,    8,   24,   32,    0}, {  -17,   14,    7,   24,   32,    0}, {  -18,   13,    6,   24,   32,    0}, {  -18,   13,    5,   24,   32,    0},
    {  -19,   13,    5,   24,   32,    0}, {  -20,   13,    4,   24,   32,    0}, {  -21,   13,    3,   24,   32,    0}, {  -21,   13,    2,   24,   32,    0}, {  -22,   13,    1,   24,   32,    0},
    {  -23,   12,    0,   24,   32,    0}, {  -23,   12,    0,   24,   32,    0}, {  -24,   12,   -1,   24,   32,    0}, {  -25,   12,   -2,   24,   32,    0}, {  -25,   11,   -3,   24,   32,    0},
    {  -26,   11,   -4,   24,   32,    0}, {  -27,   11,   -5,   24,   32,    0}, {  -27,   11,   -6,   24,   32,    0}, {  -28,   11,   -7,   24,   32,    0}, {  -29,   10,   -7,   24,   32,    0},
    {  -29,   10,   -8,   24,   32,    0}, {  -30,   10,   -9,   24,   32,    0}, {  -30,    9,  -10,   24,   31,    0}, {  -31,    9,  -11,   24,   31,    0}, {  -31,    9,  -12,   24,   31,    0},
    {  -32,    8,  -13,   24,   31,    0}, {  -33,    8,  -14,   24,   31,    0}, {  -33,    8,  -15,   24,   31,    0}, {  -34,    7,  -16,   24,   31,    0}, {  -34,    7,  -17,   24,   31,    0},
    {  -35,    7,  -18,   24,   31,    0}, {  -35,    6,  -19,   24,   31,    0}, {  -36,    6,  -20,   24,   31,    0}, {  -36,    6,  -21,   24,   31,    0}, {  -36,    5,  -22,   24,   31,    0},
    {  -37,    5,  -23,   24,   31,    0}, {  -37,    4,  -24,   24,   31,    0}, {  -38,    4,  -25,   24,   31,    0}, {  -38,    3,  -26,   24,   31,    0}, {  -39,    3,  -26,   24,   31,    0},
    {  -39,    2,  -27,   24,   31,    0}, {  -39,    2,  -28,   24,   31,    0}, {  -40,    1,  -29,   24,   31,    0}, {  -40,    1,  -30,   24,   30,    0}, {  -40,    0,  -31,   24,   30,    0},
    {  -41,    0,  -32,   24,   30,    0}, {  -41,   -1,  -33,   24,   30,    0}, {  -41,   -1,  -34,   24,   30,    0}, {  -42,   -2,  -35,   24,   30,    0}, {  -42,   -3,  -36,   24,   30,    0},
    {  -42,   -3,  -37,   24,   30,    0}, {  -42,   -4,  -38,   24,   30,    0}, {  -43,   -4,  -39,   24,   30,    0}, {  -43,   -5,  -40,   24,   30,    0}, {  -43,   -6,  -40,   24,   30,    0},
    {  -43,   -6,  -41,   24,   30,    0}, {  -44,   -7,  -42,   24,   30,    0}, {  -44,   -8,  -43,   24,   30,    0}, {  -44,   -8,  -44,   24,   30,    0}, {  -44,   -9,  -45,   24,   30,    0},
    {  -44,  -10,  -46,   24,   30,    0}, {  -45,  -10,  -46,   24,   30,    0}, {  -45,  -11,  -47,   24,   30,    0}, {  -45,  -12,  -48,   24,   30,    0}, {  -45,  -13,  -49,   24,   30,    0},
    {  -45,  -13,  -50,   24,   30,    0}, {  -45,  -14,  -50,   24,   30,    0}, {  -46,  -15,  -51,   24,   29,    0}, {  -46,  -16,  -52,   24,   29,    0}, {  -46,  -16,  -53,   24,   29,    0},
    {  -46,  -17,  -53,   24,   29,    0}, {  -46,  -18,  -54,   24,   29,    0}, {  -46,  -19,  -55,   24,   29,    0}, {  -46,  -20,  -56,   24,   29,    0}, {  -46,  -20,  -56,   24,   29,    0},
    {  -47,  -21,  -57,   24,   29,    0}, {  -47,  -22,  -58,   24,   29,    0}, {  -47,  -23,  -58,   24,   29,    0}, {  -47,  -24,  -59,   24,   29,    0}, {  -47,  -25,  -59,   24,   29,    0},
    {  -47,  -26,  -60,   24,   29,    0}, {  -47,  -26,  -61,   24,   29,    0}, {  -47,  -27,  -61,   24,   29,    0}, {  -47,  -28,  -62,   24,   29,    0}, {  -47,  -29,  -62,   24,   29,    0},
    {  -47,  -30,  -63,   24,   29,    0}, {  -47,  -31,  -63,   24,   29,    0}, {  -47,  -32,  -64,   24,   29,    0}, {  -47,  -33,  -64,   24,   29,    0}, {  -48,  -34,  -65,   24,   29,    0},
    {  -48,  -35,  -65,   24,   29,    0}, {  -48,  -36,  -66,   24,    6,    0}, {  -48,  -37,  -66,   24,    6,    0}, {  -48,  -37,  -67,   24,    6,    0}, {  -48,  -38,  -67,   24,    6,    0},
    {  -48,  -39,  -67,   24,    6,    0}, {  -48,  -40,  -68,   24,    5,    0}, {  -48,  -41,  -68,   24,    5,    0}, {  -48,  -42,  -68,   24,    5,    0}, {  -48,  -43,  -69,   24,    5,    0},
    {  -48,  -44,  -69,   24,    5,    0}, {  -48,  -45,  -69,   24,    5,    0}, {  -48,  -46,  -69,   24,    5,    0}, {  -48,  -47,  -70,   24,    5,    0}, {  -48,  -48,  -70,   24,    5,    0},
    {  -48,  -49,  -70,   24,    5,    0}, {  -48,  -50,  -70,   24,    5,    0}, {  -48,  -51,  -71,   24,    5,    0}, {  -48,  -52,  -71,   24,    5,    0}, {  -48,  -53,  -71,   24,    5,    0},
    {  -48,  -54,  -71,   24,    5,    0}, {  -48,  -55,  -71,   24,    5,    0}, {  -48,  -56,  -71,   24,    0,    0}, {  -48,  -57,  -71,   24,    0,    0}, {  -48,  -58,  -71,   24,    0,    0},
    {  -48,  -59,  -72,   24,    0,    0}, {  -48,  -60,  -72,   24,    0,    0}, {  -48,  -61,  -72,   24,    0,    0}, {  -48,  -62,  -72,   24,    0,    0}, {  -48,  -63,  -72,   24,    0,    0},
    {  -48,  -64,  -72,   24,    0,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeCorkscrewDown1, {
    {   16,    0,   27,   24,   16,    0}, {   16,    1,   27,   24,   16,    0}, {   16,    2,   27,   24,   16,    0}, {   16,    3,   27,   24,   16,    0}, {   16,    4,   27,   24,   16,    0},
    {   16,    5,   27,   24,   16,    0}, {   16,    6,   27,   24,   16,    0}, {   16,    7,   27,   24,   16,    0}, {   16,    8,   27,   24,   16,    0}, {   16,    9,   27,   24,   16,    0},
    {   16,   10,   26,   24,   16,    0}, {   16,   11,   26,   24,   16,    0}, {   16,   12,   26,   24,   23,    0}, {   16,   13,   26,   24,   23,    0}, {   16,   14,   26,   24,   23,    0},
    {   16,   15,   26,   24,   23,    0}, {   16,   15,   25,    0,   33,    0}, {   16,   16,   25,    0,   33,    0}, {   16,   17,   25,    0,   33,    0}, {   16,   18,   25,    0,   33,    0},
    {   16,   19,   24,    0,   33,    0}, {   16,   20,   24,    0,   33,    0}, {   16,   21,   24,    0,   33,    0}, {   16,   22,   23,    0,   33,    0}, {   16,   23,   23,    0,   33,    0},
    {   16,   24,   23,    0,   33,    0}, {   16,   25,   22,    0,   33,    0}, {   16,   26,   22,    0,   33,    0}, {   16,   27,   22,    0,   33,    0}, {   16,   28,   21,    0,   33,    0},
    {   16,   29,   21,    0,   33,    0}, {   16,   30,   20,    0,   33,    0}, {   15,   31,   20,    0,   33,    0}, {   15,   32,   19,    0,   33,    0}, {   15,   33,   19,    0,   33,    0},
    {   15,   34,   18,    0,   33,    0}, {   15,   34,   18,    0,   33,    0}, {   15,   35,   17,    0,   33,    0}, {   15,   36,   17,    0,   33,    0}, {   15,   37,   16,    0,   33,    0},
    {   15,   38,   16,    0,   33,    0}, {   15,   39,   15,    0,   33,    0}, {   15,   40,   14,    0,   33,    0}, {   15,   41,   14,    0,   33,    0}, {   15,   41,   13,    0,   33,    0},
    {   15,   42,   13,    0,   32,    0}, {   14,   43,   12,    0,   32,    0}, {   14,   44,   11,    0,   32,    0}, {   14,   45,   11,    0,   32,    0}, {   14,   46,   10,    0,   32,    0},
    {   14,   46,    9,    0,   32,    0}, {   14,   47,    8,    0,   32,    0}, {   14,   48,    8,    0,   32,    0}, {   14,   49,    7,    0,   32,    0}, {   13,   50,    6,    0,   32,    0},
    {   13,   50,    5,    0,   32,    0}, {   13,   51,    5,    0,   32,    0}, {   13,   52,    4,    0,   32,    0}, {   13,   53,    3,    0,   32,    0}, {   13,   53,    2,    0,   32,    0},
    {   13,   54,    1,    0,   32,    0}, {   12,   55,    0,    0,   32,    0}, {   12,   55,    0,    0,   32,    0}, {   12,   56,   -1,    0,   32,    0}, {   12,   57,   -2,    0,   32,    0},
    {   11,   57,   -3,    0,   32,    0}, {   11,   58,   -4,    0,   32,    0}, {   11,   59,   -5,    0,   32,    0}, {   11,   59,   -6,    0,   32,    0}, {   11,   60,   -7,    0,   32,    0},
    {   10,   61,   -7,    0,   32,    0}, {   10,   61,   -8,    0,   32,    0}, {   10,   62,   -9,    0,   32,    0}, {    9,   62,  -10,    0,   31,    0}, {    9,   63,  -11,    0,   31,    0},
    {    9,   63,  -12,    0,   31,    0}, {    8,   64,  -13,    0,   31,    0}, {    8,   65,  -14,    0,   31,    0}, {    8,   65,  -15,    0,   31,    0}, {    7,   66,  -16,    0,   31,    0},
    {    7,   66,  -17,    0,   31,    0}, {    7,   67,  -18,    0,   31,    0}, {    6,   67,  -19,    0,   31,    0}, {    6,   68,  -20,    0,   31,    0}, {    6,   68,  -21,    0,   31,    0},
    {    5,   68,  -22,    0,   31,    0}, {    5,   69,  -23,    0,   31,    0}, {    4,   69,  -24,    0,   31,    0}, {    4,   70,  -25,    0,   31,    0}, {    3,   70,  -26,    0,   31,    0},
    {    3,   71,  -26,    0,   31,    0}, {    2,   71,  -27,    0,   31,    0}, {    2,   71,  -28,    0,   31,    0}, {    1,   72,  -29,    0,   31,    0}, {    1,   72,  -30,    0,   30,    0},
    {    0,   72,  -31,    0,   30,    0}, {    0,   73,  -32,    0,   30,    0}, {   -1,   73,  -33,    0,   30,    0}, {   -1,   73,  -34,    0,   30,    0}, {   -2,   74,  -35,    0,   30,    0},
    {   -3,   74,  -36,    0,   30,    0}, {   -3,   74,  -37,    0,   30,    0}, {   -4,   74,  -38,    0,   30,    0}, {   -4,   75,  -39,    0,   30,    0}, {   -5,   75,  -40,    0,   30,    0},
    {   -6,   75,  -40,    0,   30,    0}, {   -6,   75,  -41,    0,   30,    0}, {   -7,   76,  -42,    0,   30,    0}, {   -8,   76,  -43,    0,   30,    0}, {   -8,   76,  -44,    0,   30,    0},
    {   -9,   76,  -45,    0,   30,    0}, {  -10,   76,  -46,    0,   30,    0}, {  -10,   77,  -46,    0,   30,    0}, {  -11,   77,  -47,    0,   30,    0}, {  -12,   77,  -48,    0,   30,    0},
    {  -13,   77,  -49,    0,   30,    0}, {  -13,   77,  -50,    0,   30,    0}, {  -14,   77,  -50,    0,   30,    0}, {  -15,   78,  -51,    0,   29,    0}, {  -16,   78,  -52,    0,   29,    0},
    {  -16,   78,  -53,    0,   29,    0}, {  -17,   78,  -53,    0,   29,    0}, {  -18,   78,  -54,    0,   29,    0}, {  -19,   78,  -55,    0,   29,    0}, {  -20,   78,  -56,    0,   29,    0},
    {  -20,   78,  -56,    0,   29,    0}, {  -21,   79,  -57,    0,   29,    0}, {  -22,   79,  -58,    0,   29,    0}, {  -23,   79,  -58,    0,   29,    0}, {  -24,   79,  -59,    0,   29,    0},
    {  -25,   79,  -59,    0,   29,    0}, {  -26,   79,  -60,    0,   29,    0}, {  -26,   79,  -61,    0,   29,    0}, {  -27,   79,  -61,    0,   29,    0}, {  -28,   79,  -62,    0,   29,    0},
    {  -29,   79,  -62,    0,   29,    0}, {  -30,   79,  -63,    0,   29,    0}, {  -31,   79,  -63,    0,   29,    0}, {  -32,   79,  -64,    0,   29,    0}, {  -33,   79,  -64,    0,   29,    0},
    {  -34,   80,  -65,    0,   29,    0}, {  -35,   80,  -65,    0,   29,    0}, {  -36,   80,  -66,    0,    6,    0}, {  -37,   80,  -66,    0,    6,    0}, {  -37,   80,  -67,    0,    6,    0},
    {  -38,   80,  -67,    0,    6,    0}, {  -39,   80,  -67,    0,    6,    0}, {  -40,   80,  -68,    0,    5,    0}, {  -41,   80,  -68,    0,    5,    0}, {  -42,   80,  -68,    0,    5,    0},
    {  -43,   80,  -69,    0,    5,    0}, {  -44,   80,  -69,    0,    5,    0}, {  -45,   80,  -69,    0,    5,    0}, {  -46,   80,  -69,    0,    5,    0}, {  -47,   80,  -70,    0,    5,    0},
    {  -48,   80,  -70,    0,    5,    0}, {  -49,   80,  -70,    0,    5,    0}, {  -50,   80,  -70,    0,    5,    0}, {  -51,   80,  -71,    0,    5,    0}, {  -52,   80,  -71,    0,    5,    0},
    {  -53,   80,  -71,    0,    5,    0}, {  -54,   80,  -71,    0,    5,    0}, {  -55,   80,  -71,    0,    5,    0}, {  -56,   80,  -71,    0,    0,    0}, {  -57,   80,  -71,    0,    0,    0},
    {  -58,   80,  -71,    0,    0,    0}, {  -59,   80,  -72,    0,    0,    0}, {  -60,   80,  -72,    0,    0,    0}, {  -61,   80,  -72,    0,    0,    0}, {  -62,   80,  -72,    0,    0,    0},
    {  -63,   80,  -72,    0,    0,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeCorkscrewDown2, {
    {    0,   16,   27,    0,   16,    0}, {    1,   16,   27,    0,   16,    0}, {    2,   16,   27,    0,   16,    0}, {    3,   16,   27,    0,   16,    0}, {    4,   16,   27,    0,   16,    0},
    {    5,   16,   27,    0,   16,    0}, {    6,   16,   27,    0,   16,    0}, {    7,   16,   27,    0,   16,    0}, {    8,   16,   27,    0,   16,    0}, {    9,   16,   27,    0,   16,    0},
    {   10,   16,   26,    0,   16,    0}, {   11,   16,   26,    0,   16,    0}, {   12,   16,   26,    0,   23,    0}, {   13,   16,   26,    0,   23,    0}, {   14,   16,   26,    0,   23,    0},
    {   15,   16,   26,    0,   23,    0}, {   15,   16,   25,    8,   33,    0}, {   16,   16,   25,    8,   33,    0}, {   17,   16,   25,    8,   33,    0}, {   18,   16,   25,    8,   33,    0},
    {   19,   16,   24,    8,   33,    0}, {   20,   16,   24,    8,   33,    0}, {   21,   16,   24,    8,   33,    0}, {   22,   16,   23,    8,   33,    0}, {   23,   16,   23,    8,   33,    0},
    {   24,   16,   23,    8,   33,    0}, {   25,   16,   22,    8,   33,    0}, {   26,   16,   22,    8,   33,    0}, {   27,   16,   22,    8,   33,    0}, {   28,   16,   21,    8,   33,    0},
    {   29,   16,   21,    8,   33,    0}, {   30,   16,   20,    8,   33,    0}, {   31,   17,   20,    8,   33,    0}, {   32,   17,   19,    8,   33,    0}, {   33,   17,   19,    8,   33,    0},
    {   34,   17,   18,    8,   33,    0}, {   34,   17,   18,    8,   33,    0}, {   35,   17,   17,    8,   33,    0}, {   36,   17,   17,    8,   33,    0}, {   37,   17,   16,    8,   33,    0},
    {   38,   17,   16,    8,   33,    0}, {   39,   17,   15,    8,   33,    0}, {   40,   17,   14,    8,   33,    0}, {   41,   17,   14,    8,   33,    0}, {   41,   17,   13,    8,   33,    0},
    {   42,   17,   13,    8,   32,    0}, {   43,   18,   12,    8,   32,    0}, {   44,   18,   11,    8,   32,    0}, {   45,   18,   11,    8,   32,    0}, {   46,   18,   10,    8,   32,    0},
    {   46,   18,    9,    8,   32,    0}, {   47,   18,    8,    8,   32,    0}, {   48,   18,    8,    8,   32,    0}, {   49,   18,    7,    8,   32,    0}, {   50,   19,    6,    8,   32,    0},
    {   50,   19,    5,    8,   32,    0}, {   51,   19,    5,    8,   32,    0}, {   52,   19,    4,    8,   32,    0}, {   53,   19,    3,    8,   32,    0}, {   53,   19,    2,    8,   32,    0},
    {   54,   19,    1,    8,   32,    0}, {   55,   20,    0,    8,   32,    0}, {   55,   20,    0,    8,   32,    0}, {   56,   20,   -1,    8,   32,    0}, {   57,   20,   -2,    8,   32,    0},
    {   57,   21,   -3,    8,   32,    0}, {   58,   21,   -4,    8,   32,    0}, {   59,   21,   -5,    8,   32,    0}, {   59,   21,   -6,    8,   32,    0}, {   60,   21,   -7,    8,   32,    0},
    {   61,   22,   -7,    8,   32,    0}, {   61,   22,   -8,    8,   32,    0}, {   62,   22,   -9,    8,   32,    0}, {   62,   23,  -10,    8,   31,    0}, {   63,   23,  -11,    8,   31,    0},
    {   63,   23,  -12,    8,   31,    0}, {   64,   24,  -13,    8,   31,    0}, {   65,   24,  -14,    8,   31,    0}, {   65,   24,  -15,    8,   31,    0}, {   66,   25,  -16,    8,   31,    0},
    {   66,   25,  -17,    8,   31,    0}, {   67,   25,  -18,    8,   31,    0}, {   67,   26,  -19,    8,   31,    0}, {   68,   26,  -20,    8,   31,    0}, {   68,   26,  -21,    8,   31,    0},
    {   68,   27,  -22,    8,   31,    0}, {   69,   27,  -23,    8,   31,    0}, {   69,   28,  -24,    8,   31,    0}, {   70,   28,  -25,    8,   31,    0}, {   70,   29,  -26,    8,   31,    0},
    {   71,   29,  -26,    8,   31,    0}, {   71,   30,  -27,    8,   31,    0}, {   71,   30,  -28,    8,   31,    0}, {   72,   31,  -29,    8,   31,    0}, {   72,   31,  -30,    8,   30,    0},
    {   72,   32,  -31,    8,   30,    0}, {   73,   32,  -32,    8,   30,    0}, {   73,   33,  -33,    8,   30,    0}, {   73,   33,  -34,    8,   30,    0}, {   74,   34,  -35,    8,   30,    0},
    {   74,   35,  -36,    8,   30,    0}, {   74,   35,  -37,    8,   30,    0}, {   74,   36,  -38,    8,   30,    0}, {   75,   36,  -39,    8,   30,    0}, {   75,   37,  -40,    8,   30,    0},
    {   75,   38,  -40,    8,   30,    0}, {   75,   38,  -41,    8,   30,    0}, {   76,   39,  -42,    8,   30,    0}, {   76,   40,  -43,    8,   30,    0}, {   76,   40,  -44,    8,   30,    0},
    {   76,   41,  -45,    8,   30,    0}, {   76,   42,  -46,    8,   30,    0}, {   77,   42,  -46,    8,   30,    0}, {   77,   43,  -47,    8,   30,    0}, {   77,   44,  -48,    8,   30,    0},
    {   77,   45,  -49,    8,   30,    0}, {   77,   45,  -50,    8,   30,    0}, {   77,   46,  -50,    8,   30,    0}, {   78,   47,  -51,    8,   29,    0}, {   78,   48,  -52,    8,   29,    0},
    {   78,   48,  -53,    8,   29,    0}, {   78,   49,  -53,    8,   29,    0}, {   78,   50,  -54,    8,   29,    0}, {   78,   51,  -55,    8,   29,    0}, {   78,   52,  -56,    8,   29,    0},
    {   78,   52,  -56,    8,   29,    0}, {   79,   53,  -57,    8,   29,    0}, {   79,   54,  -58,    8,   29,    0}, {   79,   55,  -58,    8,   29,    0}, {   79,   56,  -59,    8,   29,    0},
    {   79,   57,  -59,    8,   29,    0}, {   79,   58,  -60,    8,   29,    0}, {   79,   58,  -61,    8,   29,    0}, {   79,   59,  -61,    8,   29,    0}, {   79,   60,  -62,    8,   29,    0},
    {   79,   61,  -62,    8,   29,    0}, {   79,   62,  -63,    8,   29,    0}, {   79,   63,  -63,    8,   29,    0}, {   79,   64,  -64,    8,   29,    0}, {   79,   65,  -64,    8,   29,    0},
    {   80,   66,  -65,    8,   29,    0}, {   80,   67,  -65,    8,   29,    0}, {   80,   68,  -66,    8,    6,    0}, {   80,   69,  -66,    8,    6,    0}, {   80,   69,  -67,    8,    6,    0},
    {   80,   70,  -67,    8,    6,    0}, {   80,   71,  -67,    8,    6,    0}, {   80,   72,  -68,    8,    5,    0}, {   80,   73,  -68,    8,    5,    0}, {   80,   74,  -68,    8,    5,    0},
    {   80,   75,  -69,    8,    5,    0}, {   80,   76,  -69,    8,    5,    0}, {   80,   77,  -69,    8,    5,    0}, {   80,   78,  -69,    8,    5,    0}, {   80,   79,  -70,    8,    5,    0},
    {   80,   80,  -70,    8,    5,    0}, {   80,   81,  -70,    8,    5,    0}, {   80,   82,  -70,    8,    5,    0}, {   80,   83,  -71,    8,    5,    0}, {   80,   84,  -71,    8,    5,    0},
    {   80,   85,  -71,    8,    5,    0}, {   80,   86,  -71,    8,    5,    0}, {   80,   87,  -71,    8,    5,    0}, {   80,   88,  -71,    8,    0,    0}, {   80,   89,  -71,    8,    0,    0},
    {   80,   90,  -71,    8,    0,    0}, {   80,   91,  -72,    8,    0,    0}, {   80,   92,  -72,    8,    0,    0}, {   80,   93,  -72,    8,    0,    0}, {   80,   94,  -72,    8,    0,    0},
    {   80,   95,  -72,    8,    0,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeCorkscrewDown3, {
    {   16,   31,   27,    8,   16,    0}, {   16,   30,   27,    8,   16,    0}, {   16,   29,   27,    8,   16,    0}, {   16,   28,   27,    8,   16,    0}, {   16,   27,   27,    8,   16,    0},
    {   16,   26,   27,    8,   16,    0}, {   16,   25,   27,    8,   16,    0}, {   16,   24,   27,    8,   16,    0}, {   16,   23,   27,    8,   16,    0}, {   16,   22,   26,    8,   16,    0},
    {   16,   21,   26,    8,   16,    0}, {   16,   20,   26,    8,   23,    0}, {   16,   19,   26,    8,   23,    0}, {   16,   18,   26,    8,   23,    0}, {   16,   17,   26,    8,   23,    0},
    {   16,   17,   25,   16,   33,    0}, {   16,   16,   25,   16,   33,    0}, {   16,   15,   25,   16,   33,    0}, {   16,   14,   25,   16,   33,    0}, {   16,   13,   24,   16,   33,    0},
    {   16,   12,   24,   16,   33,    0}, {   16,   11,   24,   16,   33,    0}, {   16,   10,   23,   16,   33,    0}, {   16,    9,   23,   16,   33,    0}, {   16,    8,   23,   16,   33,    0},
    {   16,    7,   22,   16,   33,    0}, {   16,    6,   22,   16,   33,    0}, {   16,    5,   22,   16,   33,    0}, {   16,    4,   21,   16,   33,    0}, {   16,    3,   21,   16,   33,    0},
    {   16,    2,   20,   16,   33,    0}, {   17,    1,   20,   16,   33,    0}, {   17,    0,   19,   16,   33,    0}, {   17,   -1,   19,   16,   33,    0}, {   17,   -2,   18,   16,   33,    0},
    {   17,   -2,   18,   16,   33,    0}, {   17,   -3,   17,   16,   33,    0}, {   17,   -4,   17,   16,   33,    0}, {   17,   -5,   16,   16,   33,    0}, {   17,   -6,   16,   16,   33,    0},
    {   17,   -7,   15,   16,   33,    0}, {   17,   -8,   14,   16,   33,    0}, {   17,   -9,   14,   16,   33,    0}, {   17,   -9,   13,   16,   33,    0}, {   17,  -10,   13,   16,   32,    0},
    {   18,  -11,   12,   16,   32,    0}, {   18,  -12,   11,   16,   32,    0}, {   18,  -13,   11,   16,   32,    0}, {   18,  -14,   10,   16,   32,    0}, {   18,  -14,    9,   16,   32,    0},
    {   18,  -15,    8,   16,   32,    0}, {   18,  -16,    8,   16,   32,    0}, {   18,  -17,    7,   16,   32,    0}, {   19,  -18,    6,   16,   32,    0}, {   19,  -18,    5,   16,   32,    0},
    {   19,  -19,    5,   16,   32,    0}, {   19,  -20,    4,   16,   32,    0}, {   19,  -21,    3,   16,   32,    0}, {   19,  -21,    2,   16,   32,    0}, {   19,  -22,    1,   16,   32,    0},
    {   20,  -23,    0,   16,   32,    0}, {   20,  -23,    0,   16,   32,    0}, {   20,  -24,   -1,   16,   32,    0}, {   20,  -25,   -2,   16,   32,    0}, {   21,  -25,   -3,   16,   32,    0},
    {   21,  -26,   -4,   16,   32,    0}, {   21,  -27,   -5,   16,   32,    0}, {   21,  -27,   -6,   16,   32,    0}, {   21,  -28,   -7,   16,   32,    0}, {   22,  -29,   -7,   16,   32,    0},
    {   22,  -29,   -8,   16,   32,    0}, {   22,  -30,   -9,   16,   32,    0}, {   23,  -30,  -10,   16,   31,    0}, {   23,  -31,  -11,   16,   31,    0}, {   23,  -31,  -12,   16,   31,    0},
    {   24,  -32,  -13,   16,   31,    0}, {   24,  -33,  -14,   16,   31,    0}, {   24,  -33,  -15,   16,   31,    0}, {   25,  -34,  -16,   16,   31,    0}, {   25,  -34,  -17,   16,   31,    0},
    {   25,  -35,  -18,   16,   31,    0}, {   26,  -35,  -19,   16,   31,    0}, {   26,  -36,  -20,   16,   31,    0}, {   26,  -36,  -21,   16,   31,    0}, {   27,  -36,  -22,   16,   31,    0},
    {   27,  -37,  -23,   16,   31,    0}, {   28,  -37,  -24,   16,   31,    0}, {   28,  -38,  -25,   16,   31,    0}, {   29,  -38,  -26,   16,   31,    0}, {   29,  -39,  -26,   16,   31,    0},
    {   30,  -39,  -27,   16,   31,    0}, {   30,  -39,  -28,   16,   31,    0}, {   31,  -40,  -29,   16,   31,    0}, {   31,  -40,  -30,   16,   30,    0}, {   32,  -40,  -31,   16,   30,    0},
    {   32,  -41,  -32,   16,   30,    0}, {   33,  -41,  -33,   16,   30,    0}, {   33,  -41,  -34,   16,   30,    0}, {   34,  -42,  -35,   16,   30,    0}, {   35,  -42,  -36,   16,   30,    0},
    {   35,  -42,  -37,   16,   30,    0}, {   36,  -42,  -38,   16,   30,    0}, {   36,  -43,  -39,   16,   30,    0}, {   37,  -43,  -40,   16,   30,    0}, {   38,  -43,  -40,   16,   30,    0},
    {   38,  -43,  -41,   16,   30,    0}, {   39,  -44,  -42,   16,   30,    0}, {   40,  -44,  -43,   16,   30,    0}, {   40,  -44,  -44,   16,   30,    0}, {   41,  -44,  -45,   16,   30,    0},
    {   42,  -44,  -46,   16,   30,    0}, {   42,  -45,  -46,   16,   30,    0}, {   43,  -45,  -47,   16,   30,    0}, {   44,  -45,  -48,   16,   30,    0}, {   45,  -45,  -49,   16,   30,    0},
    {   45,  -45,  -50,   16,   30,    0}, {   46,  -45,  -50,   16,   30,    0}, {   47,  -46,  -51,   16,   29,    0}, {   48,  -46,  -52,   16,   29,    0}, {   48,  -46,  -53,   16,   29,    0},
    {   49,  -46,  -53,   16,   29,    0}, {   50,  -46,  -54,   16,   29,    0}, {   51,  -46,  -55,   16,   29,    0}, {   52,  -46,  -56,   16,   29,    0}, {   52,  -46,  -56,   16,   29,    0},
    {   53,  -47,  -57,   16,   29,    0}, {   54,  -47,  -58,   16,   29,    0}, {   55,  -47,  -58,   16,   29,    0}, {   56,  -47,  -59,   16,   29,    0}, {   57,  -47,  -59,   16,   29,    0},
    {   58,  -47,  -60,   16,   29,    0}, {   58,  -47,  -61,   16,   29,    0}, {   59,  -47,  -61,   16,   29,    0}, {   60,  -47,  -62,   16,   29,    0}, {   61,  -47,  -62,   16,   29,    0},
    {   62,  -47,  -63,   16,   29,    0}, {   63,  -47,  -63,   16,   29,    0}, {   64,  -47,  -64,   16,   29,    0}, {   65,  -47,  -64,   16,   29,    0}, {   66,  -48,  -65,   16,   29,    0},
    {   67,  -48,  -65,   16,   29,    0}, {   68,  -48,  -66,   16,    6,    0}, {   69,  -48,  -66,   16,    6,    0}, {   69,  -48,  -67,   16,    6,    0}, {   70,  -48,  -67,   16,    6,    0},
    {   71,  -48,  -67,   16,    6,    0}, {   72,  -48,  -68,   16,    5,    0}, {   73,  -48,  -68,   16,    5,    0}, {   74,  -48,  -68,   16,    5,    0}, {   75,  -48,  -69,   16,    5,    0},
    {   76,  -48,  -69,   16,    5,    0}, {   77,  -48,  -69,   16,    5,    0}, {   78,  -48,  -69,   16,    5,    0}, {   79,  -48,  -70,   16,    5,    0}, {   80,  -48,  -70,   16,    5,    0},
    {   81,  -48,  -70,   16,    5,    0}, {   82,  -48,  -70,   16,    5,    0}, {   83,  -48,  -71,   16,    5,    0}, {   84,  -48,  -71,   16,    5,    0}, {   85,  -48,  -71,   16,    5,    0},
    {   86,  -48,  -71,   16,    5,    0}, {   87,  -48,  -71,   16,    5,    0}, {   88,  -48,  -71,   16,    0,    0}, {   89,  -48,  -71,   16,    0,    0}, {   90,  -48,  -71,   16,    0,    0},
    {   91,  -48,  -72,   16,    0,    0}, {   92,  -48,  -72,   16,    0,    0}, {   93,  -48,  -72,   16,    0,    0}, {   94,  -48,  -72,   16,    0,    0}, {   95,  -48,  -72,   16,    0,    0},
    {   96,  -48,  -72,   16,    0,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeCorkscrewDown0, {
    {   31,   16,   27,   16,   16,    0}, {   30,   16,   27,   16,   16,    0}, {   29,   16,   27,   16,   16,    0}, {   28,   16,   27,   16,   16,    0}, {   27,   16,   27,   16,   16,    0},
    {   26,   16,   27,   16,   16,    0}, {   25,   16,   27,   16,   16,    0}, {   24,   16,   27,   16,   16,    0}, {   23,   16,   27,   16,   16,    0}, {   22,   16,   26,   16,   16,    0},
    {   21,   16,   26,   16,   16,    0}, {   20,   16,   26,   16,   23,    0}, {   19,   16,   26,   16,   23,    0}, {   18,   16,   26,   16,   23,    0}, {   17,   16,   26,   16,   23,    0},
    {   17,   16,   25,    8,   43,    0}, {   16,   16,   25,    8,   43,    0}, {   15,   16,   25,    8,   43,    0}, {   14,   16,   25,    8,   43,    0}, {   13,   16,   24,    8,   43,    0},
    {   12,   16,   24,    8,   43,    0}, {   11,   16,   24,    8,   43,    0}, {   10,   16,   23,    8,   43,    0}, {    9,   16,   23,    8,   43,    0}, {    8,   16,   23,    8,   43,    0},
    {    7,   16,   22,    8,   43,    0}, {    6,   16,   22,    8,   43,    0}, {    5,   16,   22,    8,   43,    0}, {    4,   16,   21,    8,   43,    0}, {    3,   16,   21,    8,   43,    0},
    {    2,   16,   20,    8,   43,    0}, {    1,   17,   20,    8,   43,    0}, {    0,   17,   19,    8,   43,    0}, {   -1,   17,   19,    8,   43,    0}, {   -2,   17,   18,    8,   43,    0},
    {   -2,   17,   18,    8,   43,    0}, {   -3,   17,   17,    8,   43,    0}, {   -4,   17,   17,    8,   43,    0}, {   -5,   17,   16,    8,   43,    0}, {   -6,   17,   16,    8,   43,    0},
    {   -7,   17,   15,    8,   43,    0}, {   -8,   17,   14,    8,   43,    0}, {   -9,   17,   14,    8,   43,    0}, {   -9,   17,   13,    8,   43,    0}, {  -10,   17,   13,    8,   42,    0},
    {  -11,   18,   12,    8,   42,    0}, {  -12,   18,   11,    8,   42,    0}, {  -13,   18,   11,    8,   42,    0}, {  -14,   18,   10,    8,   42,    0}, {  -14,   18,    9,    8,   42,    0},
    {  -15,   18,    8,    8,   42,    0}, {  -16,   18,    8,    8,   42,    0}, {  -17,   18,    7,    8,   42,    0}, {  -18,   19,    6,    8,   42,    0}, {  -18,   19,    5,    8,   42,    0},
    {  -19,   19,    5,    8,   42,    0}, {  -20,   19,    4,    8,   42,    0}, {  -21,   19,    3,    8,   42,    0}, {  -21,   19,    2,    8,   42,    0}, {  -22,   19,    1,    8,   42,    0},
    {  -23,   20,    0,    8,   42,    0}, {  -23,   20,    0,    8,   42,    0}, {  -24,   20,   -1,    8,   42,    0}, {  -25,   20,   -2,    8,   42,    0}, {  -25,   21,   -3,    8,   42,    0},
    {  -26,   21,   -4,    8,   42,    0}, {  -27,   21,   -5,    8,   42,    0}, {  -27,   21,   -6,    8,   42,    0}, {  -28,   21,   -7,    8,   42,    0}, {  -29,   22,   -7,    8,   42,    0},
    {  -29,   22,   -8,    8,   42,    0}, {  -30,   22,   -9,    8,   42,    0}, {  -30,   23,  -10,    8,   41,    0}, {  -31,   23,  -11,    8,   41,    0}, {  -31,   23,  -12,    8,   41,    0},
    {  -32,   24,  -13,    8,   41,    0}, {  -33,   24,  -14,    8,   41,    0}, {  -33,   24,  -15,    8,   41,    0}, {  -34,   25,  -16,    8,   41,    0}, {  -34,   25,  -17,    8,   41,    0},
    {  -35,   25,  -18,    8,   41,    0}, {  -35,   26,  -19,    8,   41,    0}, {  -36,   26,  -20,    8,   41,    0}, {  -36,   26,  -21,    8,   41,    0}, {  -36,   27,  -22,    8,   41,    0},
    {  -37,   27,  -23,    8,   41,    0}, {  -37,   28,  -24,    8,   41,    0}, {  -38,   28,  -25,    8,   41,    0}, {  -38,   29,  -26,    8,   41,    0}, {  -39,   29,  -26,    8,   41,    0},
    {  -39,   30,  -27,    8,   41,    0}, {  -39,   30,  -28,    8,   41,    0}, {  -40,   31,  -29,    8,   41,    0}, {  -40,   31,  -30,    8,   40,    0}, {  -40,   32,  -31,    8,   40,    0},
    {  -41,   32,  -32,    8,   40,    0}, {  -41,   33,  -33,    8,   40,    0}, {  -41,   33,  -34,    8,   40,    0}, {  -42,   34,  -35,    8,   40,    0}, {  -42,   35,  -36,    8,   40,    0},
    {  -42,   35,  -37,    8,   40,    0}, {  -42,   36,  -38,    8,   40,    0}, {  -43,   36,  -39,    8,   40,    0}, {  -43,   37,  -40,    8,   40,    0}, {  -43,   38,  -40,    8,   40,    0},
    {  -43,   38,  -41,    8,   40,    0}, {  -44,   39,  -42,    8,   40,    0}, {  -44,   40,  -43,    8,   40,    0}, {  -44,   40,  -44,    8,   40,    0}, {  -44,   41,  -45,    8,   40,    0},
    {  -44,   42,  -46,    8,   40,    0}, {  -45,   42,  -46,    8,   40,    0}, {  -45,   43,  -47,    8,   40,    0}, {  -45,   44,  -48,    8,   40,    0}, {  -45,   45,  -49,    8,   40,    0},
    {  -45,   45,  -50,    8,   40,    0}, {  -45,   46,  -50,    8,   40,    0}, {  -46,   47,  -51,    8,   39,    0}, {  -46,   48,  -52,    8,   39,    0}, {  -46,   48,  -53,    8,   39,    0},
    {  -46,   49,  -53,    8,   39,    0}, {  -46,   50,  -54,    8,   39,    0}, {  -46,   51,  -55,    8,   39,    0}, {  -46,   52,  -56,    8,   39,    0}, {  -46,   52,  -56,    8,   39,    0},
    {  -47,   53,  -57,    8,   39,    0}, {  -47,   54,  -58,    8,   39,    0}, {  -47,   55,  -58,    8,   39,    0}, {  -47,   56,  -59,    8,   39,    0}, {  -47,   57,  -59,    8,   39,    0},
    {  -47,   58,  -60,    8,   39,    0}, {  -47,   58,  -61,    8,   39,    0}, {  -47,   59,  -61,    8,   39,    0}, {  -47,   60,  -62,    8,   39,    0}, {  -47,   61,  -62,    8,   39,    0},
    {  -47,   62,  -63,    8,   39,    0}, {  -47,   63,  -63,    8,   39,    0}, {  -47,   64,  -64,    8,   39,    0}, {  -47,   65,  -64,    8,   39,    0}, {  -48,   66,  -65,    8,   39,    0},
    {  -48,   67,  -65,    8,   39,    0}, {  -48,   68,  -66,    8,    6,    0}, {  -48,   69,  -66,    8,    6,    0}, {  -48,   69,  -67,    8,    6,    0}, {  -48,   70,  -67,    8,    6,    0},
    {  -48,   71,  -67,    8,    6,    0}, {  -48,   72,  -68,    8,    5,    0}, {  -48,   73,  -68,    8,    5,    0}, {  -48,   74,  -68,    8,    5,    0}, {  -48,   75,  -69,    8,    5,    0},
    {  -48,   76,  -69,    8,    5,    0}, {  -48,   77,  -69,    8,    5,    0}, {  -48,   78,  -69,    8,    5,    0}, {  -48,   79,  -70,    8,    5,    0}, {  -48,   80,  -70,    8,    5,    0},
    {  -48,   81,  -70,    8,    5,    0}, {  -48,   82,  -70,    8,    5,    0}, {  -48,   83,  -71,    8,    5,    0}, {  -48,   84,  -71,    8,    5,    0}, {  -48,   85,  -71,    8,    5,    0},
    {  -48,   86,  -71,    8,    5,    0}, {  -48,   87,  -71,    8,    5,    0}, {  -48,   88,  -71,    8,    0,    0}, {  -48,   89,  -71,    8,    0,    0}, {  -48,   90,  -71,    8,    0,    0},
    {  -48,   91,  -72,    8,    0,    0}, {  -48,   92,  -72,    8,    0,    0}, {  -48,   93,  -72,    8,    0,    0}, {  -48,   94,  -72,    8,    0,    0}, {  -48,   95,  -72,    8,    0,    0},
    {  -48,   96,  -72,    8,    0,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeCorkscrewDown1, {
    {   16,    0,   27,   24,   16,    0}, {   16,    1,   27,   24,   16,    0}, {   16,    2,   27,   24,   16,    0}, {   16,    3,   27,   24,   16,    0}, {   16,    4,   27,   24,   16,    0},
    {   16,    5,   27,   24,   16,    0}, {   16,    6,   27,   24,   16,    0}, {   16,    7,   27,   24,   16,    0}, {   16,    8,   27,   24,   16,    0}, {   16,    9,   27,   24,   16,    0},
    {   16,   10,   26,   24,   16,    0}, {   16,   11,   26,   24,   16,    0}, {   16,   12,   26,   24,   23,    0}, {   16,   13,   26,   24,   23,    0}, {   16,   14,   26,   24,   23,    0},
    {   16,   15,   26,   24,   23,    0}, {   16,   15,   25,   16,   43,    0}, {   16,   16,   25,   16,   43,    0}, {   16,   17,   25,   16,   43,    0}, {   16,   18,   25,   16,   43,    0},
    {   16,   19,   24,   16,   43,    0}, {   16,   20,   24,   16,   43,    0}, {   16,   21,   24,   16,   43,    0}, {   16,   22,   23,   16,   43,    0}, {   16,   23,   23,   16,   43,    0},
    {   16,   24,   23,   16,   43,    0}, {   16,   25,   22,   16,   43,    0}, {   16,   26,   22,   16,   43,    0}, {   16,   27,   22,   16,   43,    0}, {   16,   28,   21,   16,   43,    0},
    {   16,   29,   21,   16,   43,    0}, {   16,   30,   20,   16,   43,    0}, {   17,   31,   20,   16,   43,    0}, {   17,   32,   19,   16,   43,    0}, {   17,   33,   19,   16,   43,    0},
    {   17,   34,   18,   16,   43,    0}, {   17,   34,   18,   16,   43,    0}, {   17,   35,   17,   16,   43,    0}, {   17,   36,   17,   16,   43,    0}, {   17,   37,   16,   16,   43,    0},
    {   17,   38,   16,   16,   43,    0}, {   17,   39,   15,   16,   43,    0}, {   17,   40,   14,   16,   43,    0}, {   17,   41,   14,   16,   43,    0}, {   17,   41,   13,   16,   43,    0},
    {   17,   42,   13,   16,   42,    0}, {   18,   43,   12,   16,   42,    0}, {   18,   44,   11,   16,   42,    0}, {   18,   45,   11,   16,   42,    0}, {   18,   46,   10,   16,   42,    0},
    {   18,   46,    9,   16,   42,    0}, {   18,   47,    8,   16,   42,    0}, {   18,   48,    8,   16,   42,    0}, {   18,   49,    7,   16,   42,    0}, {   19,   50,    6,   16,   42,    0},
    {   19,   50,    5,   16,   42,    0}, {   19,   51,    5,   16,   42,    0}, {   19,   52,    4,   16,   42,    0}, {   19,   53,    3,   16,   42,    0}, {   19,   53,    2,   16,   42,    0},
    {   19,   54,    1,   16,   42,    0}, {   20,   55,    0,   16,   42,    0}, {   20,   55,    0,   16,   42,    0}, {   20,   56,   -1,   16,   42,    0}, {   20,   57,   -2,   16,   42,    0},
    {   21,   57,   -3,   16,   42,    0}, {   21,   58,   -4,   16,   42,    0}, {   21,   59,   -5,   16,   42,    0}, {   21,   59,   -6,   16,   42,    0}, {   21,   60,   -7,   16,   42,    0},
    {   22,   61,   -7,   16,   42,    0}, {   22,   61,   -8,   16,   42,    0}, {   22,   62,   -9,   16,   42,    0}, {   23,   62,  -10,   16,   41,    0}, {   23,   63,  -11,   16,   41,    0},
    {   23,   63,  -12,   16,   41,    0}, {   24,   64,  -13,   16,   41,    0}, {   24,   65,  -14,   16,   41,    0}, {   24,   65,  -15,   16,   41,    0}, {   25,   66,  -16,   16,   41,    0},
    {   25,   66,  -17,   16,   41,    0}, {   25,   67,  -18,   16,   41,    0}, {   26,   67,  -19,   16,   41,    0}, {   26,   68,  -20,   16,   41,    0}, {   26,   68,  -21,   16,   41,    0},
    {   27,   68,  -22,   16,   41,    0}, {   27,   69,  -23,   16,   41,    0}, {   28,   69,  -24,   16,   41,    0}, {   28,   70,  -25,   16,   41,    0}, {   29,   70,  -26,   16,   41,    0},
    {   29,   71,  -26,   16,   41,    0}, {   30,   71,  -27,   16,   41,    0}, {   30,   71,  -28,   16,   41,    0}, {   31,   72,  -29,   16,   41,    0}, {   31,   72,  -30,   16,   40,    0},
    {   32,   72,  -31,   16,   40,    0}, {   32,   73,  -32,   16,   40,    0}, {   33,   73,  -33,   16,   40,    0}, {   33,   73,  -34,   16,   40,    0}, {   34,   74,  -35,   16,   40,    0},
    {   35,   74,  -36,   16,   40,    0}, {   35,   74,  -37,   16,   40,    0}, {   36,   74,  -38,   16,   40,    0}, {   36,   75,  -39,   16,   40,    0}, {   37,   75,  -40,   16,   40,    0},
    {   38,   75,  -40,   16,   40,    0}, {   38,   75,  -41,   16,   40,    0}, {   39,   76,  -42,   16,   40,    0}, {   40,   76,  -43,   16,   40,    0}, {   40,   76,  -44,   16,   40,    0},
    {   41,   76,  -45,   16,   40,    0}, {   42,   76,  -46,   16,   40,    0}, {   42,   77,  -46,   16,   40,    0}, {   43,   77,  -47,   16,   40,    0}, {   44,   77,  -48,   16,   40,    0},
    {   45,   77,  -49,   16,   40,    0}, {   45,   77,  -50,   16,   40,    0}, {   46,   77,  -50,   16,   40,    0}, {   47,   78,  -51,   16,   39,    0}, {   48,   78,  -52,   16,   39,    0},
    {   48,   78,  -53,   16,   39,    0}, {   49,   78,  -53,   16,   39,    0}, {   50,   78,  -54,   16,   39,    0}, {   51,   78,  -55,   16,   39,    0}, {   52,   78,  -56,   16,   39,    0},
    {   52,   78,  -56,   16,   39,    0}, {   53,   79,  -57,   16,   39,    0}, {   54,   79,  -58,   16,   39,    0}, {   55,   79,  -58,   16,   39,    0}, {   56,   79,  -59,   16,   39,    0},
    {   57,   79,  -59,   16,   39,    0}, {   58,   79,  -60,   16,   39,    0}, {   58,   79,  -61,   16,   39,    0}, {   59,   79,  -61,   16,   39,    0}, {   60,   79,  -62,   16,   39,    0},
    {   61,   79,  -62,   16,   39,    0}, {   62,   79,  -63,   16,   39,    0}, {   63,   79,  -63,   16,   39,    0}, {   64,   79,  -64,   16,   39,    0}, {   65,   79,  -64,   16,   39,    0},
    {   66,   80,  -65,   16,   39,    0}, {   67,   80,  -65,   16,   39,    0}, {   68,   80,  -66,   16,    6,    0}, {   69,   80,  -66,   16,    6,    0}, {   69,   80,  -67,   16,    6,    0},
    {   70,   80,  -67,   16,    6,    0}, {   71,   80,  -67,   16,    6,    0}, {   72,   80,  -68,   16,    5,    0}, {   73,   80,  -68,   16,    5,    0}, {   74,   80,  -68,   16,    5,    0},
    {   75,   80,  -69,   16,    5,    0}, {   76,   80,  -69,   16,    5,    0}, {   77,   80,  -69,   16,    5,    0}, {   78,   80,  -69,   16,    5,    0}, {   79,   80,  -70,   16,    5,    0},
    {   80,   80,  -70,   16,    5,    0}, {   81,   80,  -70,   16,    5,    0}, {   82,   80,  -70,   16,    5,    0}, {   83,   80,  -71,   16,    5,    0}, {   84,   80,  -71,   16,    5,    0},
    {   85,   80,  -71,   16,    5,    0}, {   86,   80,  -71,   16,    5,    0}, {   87,   80,  -71,   16,    5,    0}, {   88,   80,  -71,   16,    0,    0}, {   89,   80,  -71,   16,    0,    0},
    {   90,   80,  -71,   16,    0,    0}, {   91,   80,  -72,   16,    0,    0}, {   92,   80,  -72,   16,    0,    0}, {   93,   80,  -72,   16,    0,    0}, {   94,   80,  -72,   16,    0,    0},
    {   95,   80,  -72,   16,    0,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeCorkscrewDown2, {
    {    0,   16,   27,    0,   16,    0}, {    1,   16,   27,    0,   16,    0}, {    2,   16,   27,    0,   16,    0}, {    3,   16,   27,    0,   16,    0}, {    4,   16,   27,    0,   16,    0},
    {    5,   16,   27,    0,   16,    0}, {    6,   16,   27,    0,   16,    0}, {    7,   16,   27,    0,   16,    0}, {    8,   16,   27,    0,   16,    0}, {    9,   16,   27,    0,   16,    0},
    {   10,   16,   26,    0,   16,    0}, {   11,   16,   26,    0,   16,    0}, {   12,   16,   26,    0,   23,    0}, {   13,   16,   26,    0,   23,    0}, {   14,   16,   26,    0,   23,    0},
    {   15,   16,   26,    0,   23,    0}, {   15,   16,   25,   24,   43,    0}, {   16,   16,   25,   24,   43,    0}, {   17,   16,   25,   24,   43,    0}, {   18,   16,   25,   24,   43,    0},
    {   19,   16,   24,   24,   43,    0}, {   20,   16,   24,   24,   43,    0}, {   21,   16,   24,   24,   43,    0}, {   22,   16,   23,   24,   43,    0}, {   23,   16,   23,   24,   43,    0},
    {   24,   16,   23,   24,   43,    0}, {   25,   16,   22,   24,   43,    0}, {   26,   16,   22,   24,   43,    0}, {   27,   16,   22,   24,   43,    0}, {   28,   16,   21,   24,   43,    0},
    {   29,   16,   21,   24,   43,    0}, {   30,   16,   20,   24,   43,    0}, {   31,   15,   20,   24,   43,    0}, {   32,   15,   19,   24,   43,    0}, {   33,   15,   19,   24,   43,    0},
    {   34,   15,   18,   24,   43,    0}, {   34,   15,   18,   24,   43,    0}, {   35,   15,   17,   24,   43,    0}, {   36,   15,   17,   24,   43,    0}, {   37,   15,   16,   24,   43,    0},
    {   38,   15,   16,   24,   43,    0}, {   39,   15,   15,   24,   43,    0}, {   40,   15,   14,   24,   43,    0}, {   41,   15,   14,   24,   43,    0}, {   41,   15,   13,   24,   43,    0},
    {   42,   15,   13,   24,   42,    0}, {   43,   14,   12,   24,   42,    0}, {   44,   14,   11,   24,   42,    0}, {   45,   14,   11,   24,   42,    0}, {   46,   14,   10,   24,   42,    0},
    {   46,   14,    9,   24,   42,    0}, {   47,   14,    8,   24,   42,    0}, {   48,   14,    8,   24,   42,    0}, {   49,   14,    7,   24,   42,    0}, {   50,   13,    6,   24,   42,    0},
    {   50,   13,    5,   24,   42,    0}, {   51,   13,    5,   24,   42,    0}, {   52,   13,    4,   24,   42,    0}, {   53,   13,    3,   24,   42,    0}, {   53,   13,    2,   24,   42,    0},
    {   54,   13,    1,   24,   42,    0}, {   55,   12,    0,   24,   42,    0}, {   55,   12,    0,   24,   42,    0}, {   56,   12,   -1,   24,   42,    0}, {   57,   12,   -2,   24,   42,    0},
    {   57,   11,   -3,   24,   42,    0}, {   58,   11,   -4,   24,   42,    0}, {   59,   11,   -5,   24,   42,    0}, {   59,   11,   -6,   24,   42,    0}, {   60,   11,   -7,   24,   42,    0},
    {   61,   10,   -7,   24,   42,    0}, {   61,   10,   -8,   24,   42,    0}, {   62,   10,   -9,   24,   42,    0}, {   62,    9,  -10,   24,   41,    0}, {   63,    9,  -11,   24,   41,    0},
    {   63,    9,  -12,   24,   41,    0}, {   64,    8,  -13,   24,   41,    0}, {   65,    8,  -14,   24,   41,    0}, {   65,    8,  -15,   24,   41,    0}, {   66,    7,  -16,   24,   41,    0},
    {   66,    7,  -17,   24,   41,    0}, {   67,    7,  -18,   24,   41,    0}, {   67,    6,  -19,   24,   41,    0}, {   68,    6,  -20,   24,   41,    0}, {   68,    6,  -21,   24,   41,    0},
    {   68,    5,  -22,   24,   41,    0}, {   69,    5,  -23,   24,   41,    0}, {   69,    4,  -24,   24,   41,    0}, {   70,    4,  -25,   24,   41,    0}, {   70,    3,  -26,   24,   41,    0},
    {   71,    3,  -26,   24,   41,    0}, {   71,    2,  -27,   24,   41,    0}, {   71,    2,  -28,   24,   41,    0}, {   72,    1,  -29,   24,   41,    0}, {   72,    1,  -30,   24,   40,    0},
    {   72,    0,  -31,   24,   40,    0}, {   73,    0,  -32,   24,   40,    0}, {   73,   -1,  -33,   24,   40,    0}, {   73,   -1,  -34,   24,   40,    0}, {   74,   -2,  -35,   24,   40,    0},
    {   74,   -3,  -36,   24,   40,    0}, {   74,   -3,  -37,   24,   40,    0}, {   74,   -4,  -38,   24,   40,    0}, {   75,   -4,  -39,   24,   40,    0}, {   75,   -5,  -40,   24,   40,    0},
    {   75,   -6,  -40,   24,   40,    0}, {   75,   -6,  -41,   24,   40,    0}, {   76,   -7,  -42,   24,   40,    0}, {   76,   -8,  -43,   24,   40,    0}, {   76,   -8,  -44,   24,   40,    0},
    {   76,   -9,  -45,   24,   40,    0}, {   76,  -10,  -46,   24,   40,    0}, {   77,  -10,  -46,   24,   40,    0}, {   77,  -11,  -47,   24,   40,    0}, {   77,  -12,  -48,   24,   40,    0},
    {   77,  -13,  -49,   24,   40,    0}, {   77,  -13,  -50,   24,   40,    0}, {   77,  -14,  -50,   24,   40,    0}, {   78,  -15,  -51,   24,   39,    0}, {   78,  -16,  -52,   24,   39,    0},
    {   78,  -16,  -53,   24,   39,    0}, {   78,  -17,  -53,   24,   39,    0}, {   78,  -18,  -54,   24,   39,    0}, {   78,  -19,  -55,   24,   39,    0}, {   78,  -20,  -56,   24,   39,    0},
    {   78,  -20,  -56,   24,   39,    0}, {   79,  -21,  -57,   24,   39,    0}, {   79,  -22,  -58,   24,   39,    0}, {   79,  -23,  -58,   24,   39,    0}, {   79,  -24,  -59,   24,   39,    0},
    {   79,  -25,  -59,   24,   39,    0}, {   79,  -26,  -60,   24,   39,    0}, {   79,  -26,  -61,   24,   39,    0}, {   79,  -27,  -61,   24,   39,    0}, {   79,  -28,  -62,   24,   39,    0},
    {   79,  -29,  -62,   24,   39,    0}, {   79,  -30,  -63,   24,   39,    0}, {   79,  -31,  -63,   24,   39,    0}, {   79,  -32,  -64,   24,   39,    0}, {   79,  -33,  -64,   24,   39,    0},
    {   80,  -34,  -65,   24,   39,    0}, {   80,  -35,  -65,   24,   39,    0}, {   80,  -36,  -66,   24,    6,    0}, {   80,  -37,  -66,   24,    6,    0}, {   80,  -37,  -67,   24,    6,    0},
    {   80,  -38,  -67,   24,    6,    0}, {   80,  -39,  -67,   24,    6,    0}, {   80,  -40,  -68,   24,    5,    0}, {   80,  -41,  -68,   24,    5,    0}, {   80,  -42,  -68,   24,    5,    0},
    {   80,  -43,  -69,   24,    5,    0}, {   80,  -44,  -69,   24,    5,    0}, {   80,  -45,  -69,   24,    5,    0}, {   80,  -46,  -69,   24,    5,    0}, {   80,  -47,  -70,   24,    5,    0},
    {   80,  -48,  -70,   24,    5,    0}, {   80,  -49,  -70,   24,    5,    0}, {   80,  -50,  -70,   24,    5,    0}, {   80,  -51,  -71,   24,    5,    0}, {   80,  -52,  -71,   24,    5,    0},
    {   80,  -53,  -71,   24,    5,    0}, {   80,  -54,  -71,   24,    5,    0}, {   80,  -55,  -71,   24,    5,    0}, {   80,  -56,  -71,   24,    0,    0}, {   80,  -57,  -71,   24,    0,    0},
    {   80,  -58,  -71,   24,    0,    0}, {   80,  -59,  -72,   24,    0,    0}, {   80,  -60,  -72,   24,    0,    0}, {   80,  -61,  -72,   24,    0,    0}, {   80,  -62,  -72,   24,    0,    0},
    {   80,  -63,  -72,   24,    0,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeCorkscrewDown3, {
    {   16,   31,   27,    8,   16,    0}, {   16,   30,   27,    8,   16,    0}, {   16,   29,   27,    8,   16,    0}, {   16,   28,   27,    8,   16,    0}, {   16,   27,   27,    8,   16,    0},
    {   16,   26,   27,    8,   16,    0}, {   16,   25,   27,    8,   16,    0}, {   16,   24,   27,    8,   16,    0}, {   16,   23,   27,    8,   16,    0}, {   16,   22,   26,    8,   16,    0},
    {   16,   21,   26,    8,   16,    0}, {   16,   20,   26,    8,   23,    0}, {   16,   19,   26,    8,   23,    0}, {   16,   18,   26,    8,   23,    0}, {   16,   17,   26,    8,   23,    0},
    {   16,   17,   25,    0,   43,    0}, {   16,   16,   25,    0,   43,    0}, {   16,   15,   25,    0,   43,    0}, {   16,   14,   25,    0,   43,    0}, {   16,   13,   24,    0,   43,    0},
    {   16,   12,   24,    0,   43,    0}, {   16,   11,   24,    0,   43,    0}, {   16,   10,   23,    0,   43,    0}, {   16,    9,   23,    0,   43,    0}, {   16,    8,   23,    0,   43,    0},
    {   16,    7,   22,    0,   43,    0}, {   16,    6,   22,    0,   43,    0}, {   16,    5,   22,    0,   43,    0}, {   16,    4,   21,    0,   43,    0}, {   16,    3,   21,    0,   43,    0},
    {   16,    2,   20,    0,   43,    0}, {   15,    1,   20,    0,   43,    0}, {   15,    0,   19,    0,   43,    0}, {   15,   -1,   19,    0,   43,    0}, {   15,   -2,   18,    0,   43,    0},
    {   15,   -2,   18,    0,   43,    0}, {   15,   -3,   17,    0,   43,    0}, {   15,   -4,   17,    0,   43,    0}, {   15,   -5,   16,    0,   43,    0}, {   15,   -6,   16,    0,   43,    0},
    {   15,   -7,   15,    0,   43,    0}, {   15,   -8,   14,    0,   43,    0}, {   15,   -9,   14,    0,   43,    0}, {   15,   -9,   13,    0,   43,    0}, {   15,  -10,   13,    0,   42,    0},
    {   14,  -11,   12,    0,   42,    0}, {   14,  -12,   11,    0,   42,    0}, {   14,  -13,   11,    0,   42,    0}, {   14,  -14,   10,    0,   42,    0}, {   14,  -14,    9,    0,   42,    0},
    {   14,  -15,    8,    0,   42,    0}, {   14,  -16,    8,    0,   42,    0}, {   14,  -17,    7,    0,   42,    0}, {   13,  -18,    6,    0,   42,    0}, {   13,  -18,    5,    0,   42,    0},
    {   13,  -19,    5,    0,   42,    0}, {   13,  -20,    4,    0,   42,    0}, {   13,  -21,    3,    0,   42,    0}, {   13,  -21,    2,    0,   42,    0}, {   13,  -22,    1,    0,   42,    0},
    {   12,  -23,    0,    0,   42,    0}, {   12,  -23,    0,    0,   42,    0}, {   12,  -24,   -1,    0,   42,    0}, {   12,  -25,   -2,    0,   42,    0}, {   11,  -25,   -3,    0,   42,    0},
    {   11,  -26,   -4,    0,   42,    0}, {   11,  -27,   -5,    0,   42,    0}, {   11,  -27,   -6,    0,   42,    0}, {   11,  -28,   -7,    0,   42,    0}, {   10,  -29,   -7,    0,   42,    0},
    {   10,  -29,   -8,    0,   42,    0}, {   10,  -30,   -9,    0,   42,    0}, {    9,  -30,  -10,    0,   41,    0}, {    9,  -31,  -11,    0,   41,    0}, {    9,  -31,  -12,    0,   41,    0},
    {    8,  -32,  -13,    0,   41,    0}, {    8,  -33,  -14,    0,   41,    0}, {    8,  -33,  -15,    0,   41,    0}, {    7,  -34,  -16,    0,   41,    0}, {    7,  -34,  -17,    0,   41,    0},
    {    7,  -35,  -18,    0,   41,    0}, {    6,  -35,  -19,    0,   41,    0}, {    6,  -36,  -20,    0,   41,    0}, {    6,  -36,  -21,    0,   41,    0}, {    5,  -36,  -22,    0,   41,    0},
    {    5,  -37,  -23,    0,   41,    0}, {    4,  -37,  -24,    0,   41,    0}, {    4,  -38,  -25,    0,   41,    0}, {    3,  -38,  -26,    0,   41,    0}, {    3,  -39,  -26,    0,   41,    0},
    {    2,  -39,  -27,    0,   41,    0}, {    2,  -39,  -28,    0,   41,    0}, {    1,  -40,  -29,    0,   41,    0}, {    1,  -40,  -30,    0,   40,    0}, {    0,  -40,  -31,    0,   40,    0},
    {    0,  -41,  -32,    0,   40,    0}, {   -1,  -41,  -33,    0,   40,    0}, {   -1,  -41,  -34,    0,   40,    0}, {   -2,  -42,  -35,    0,   40,    0}, {   -3,  -42,  -36,    0,   40,    0},
    {   -3,  -42,  -37,    0,   40,    0}, {   -4,  -42,  -38,    0,   40,    0}, {   -4,  -43,  -39,    0,   40,    0}, {   -5,  -43,  -40,    0,   40,    0}, {   -6,  -43,  -40,    0,   40,    0},
    {   -6,  -43,  -41,    0,   40,    0}, {   -7,  -44,  -42,    0,   40,    0}, {   -8,  -44,  -43,    0,   40,    0}, {   -8,  -44,  -44,    0,   40,    0}, {   -9,  -44,  -45,    0,   40,    0},
    {  -10,  -44,  -46,    0,   40,    0}, {  -10,  -45,  -46,    0,   40,    0}, {  -11,  -45,  -47,    0,   40,    0}, {  -12,  -45,  -48,    0,   40,    0}, {  -13,  -45,  -49,    0,   40,    0},
    {  -13,  -45,  -50,    0,   40,    0}, {  -14,  -45,  -50,    0,   40,    0}, {  -15,  -46,  -51,    0,   39,    0}, {  -16,  -46,  -52,    0,   39,    0}, {  -16,  -46,  -53,    0,   39,    0},
    {  -17,  -46,  -53,    0,   39,    0}, {  -18,  -46,  -54,    0,   39,    0}, {  -19,  -46,  -55,    0,   39,    0}, {  -20,  -46,  -56,    0,   39,    0}, {  -20,  -46,  -56,    0,   39,    0},
    {  -21,  -47,  -57,    0,   39,    0}, {  -22,  -47,  -58,    0,   39,    0}, {  -23,  -47,  -58,    0,   39,    0}, {  -24,  -47,  -59,    0,   39,    0}, {  -25,  -47,  -59,    0,   39,    0},
    {  -26,  -47,  -60,    0,   39,    0}, {  -26,  -47,  -61,    0,   39,    0}, {  -27,  -47,  -61,    0,   39,    0}, {  -28,  -47,  -62,    0,   39,    0}, {  -29,  -47,  -62,    0,   39,    0},
    {  -30,  -47,  -63,    0,   39,    0}, {  -31,  -47,  -63,    0,   39,    0}, {  -32,  -47,  -64,    0,   39,    0}, {  -33,  -47,  -64,    0,   39,    0}, {  -34,  -48,  -65,    0,   39,    0},
    {  -35,  -48,  -65,    0,   39,    0}, {  -36,  -48,  -66,    0,    6,    0}, {  -37,  -48,  -66,    0,    6,    0}, {  -37,  -48,  -67,    0,    6,    0}, {  -38,  -48,  -67,    0,    6,    0},
    {  -39,  -48,  -67,    0,    6,    0}, {  -40,  -48,  -68,    0,    5,    0}, {  -41,  -48,  -68,    0,    5,    0}, {  -42,  -48,  -68,    0,    5,    0}, {  -43,  -48,  -69,    0,    5,    0},
    {  -44,  -48,  -69,    0,    5,    0}, {  -45,  -48,  -69,    0,    5,    0}, {  -46,  -48,  -69,    0,    5,    0}, {  -47,  -48,  -70,    0,    5,    0}, {  -48,  -48,  -70,    0,    5,    0},
    {  -49,  -48,  -70,    0,    5,    0}, {  -50,  -48,  -70,    0,    5,    0}, {  -51,  -48,  -71,    0,    5,    0}, {  -52,  -48,  -71,    0,    5,    0}, {  -53,  -48,  -71,    0,    5,    0},
    {  -54,  -48,  -71,    0,    5,    0}, {  -55,  -48,  -71,    0,    5,    0}, {  -56,  -48,  -71,    0,    0,    0}, {  -57,  -48,  -71,    0,    0,    0}, {  -58,  -48,  -71,    0,    0,    0},
    {  -59,  -48,  -72,    0,    0,    0}, {  -60,  -48,  -72,    0,    0,    0}, {  -61,  -48,  -72,    0,    0,    0}, {  -62,  -48,  -72,    0,    0,    0}, {  -63,  -48,  -72,    0,    0,    0},
    {  -64,  -48,  -72,    0,    0,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftMediumHalfLoopUp0, {
    {31, 16, -1, 0, 2, 0}, {30, 16, 0, 0, 2, 0}, {29, 16, 0, 0, 2, 0}, {28, 15, 1, 0, 2, 0}, {27, 15, 1, 0, 2, 0},
    {26, 15, 2, 0, 2, 0}, {26, 15, 2, 0, 2, 0}, {25, 15, 3, 0, 2, 0}, {24, 15, 3, 0, 2, 0}, {23, 15, 4, 0, 2, 0},
    {22, 15, 4, 0, 2, 0}, {21, 14, 5, 0, 2, 0}, {20, 14, 5, 0, 2, 0}, {19, 14, 6, 0, 2, 0}, {18, 14, 6, 0, 2, 0},
    {18, 14, 7, 0, 2, 0}, {17, 14, 7, 0, 2, 0}, {16, 14, 8, 0, 2, 0}, {15, 14, 9, 0, 2, 0}, {14, 13, 9, 0, 2, 0},
    {13, 13, 10, 0, 2, 0}, {12, 13, 10, 0, 2, 0}, {11, 13, 11, 0, 2, 0}, {11, 13, 11, 0, 2, 0}, {10, 13, 12, 0, 2, 0},
    {9, 13, 13, 0, 2, 0}, {8, 12, 13, 0, 2, 0}, {7, 12, 14, 0, 2, 0}, {6, 12, 14, 0, 2, 0}, {5, 12, 15, 0, 2, 0},
    {4, 12, 16, 0, 2, 0}, {4, 12, 16, 0, 2, 0}, {3, 12, 17, 0, 2, 0}, {2, 12, 17, 0, 3, 0}, {1, 11, 18, 0, 3, 0},
    {0, 11, 19, 0, 3, 0}, {-1, 11, 19, 0, 3, 0}, {-1, 11, 20, 0, 3, 0}, {-2, 11, 21, 0, 3, 0}, {-3, 11, 21, 0, 3, 0},
    {-4, 11, 22, 0, 3, 0}, {-5, 11, 23, 0, 3, 0}, {-6, 10, 23, 0, 3, 0}, {-6, 10, 24, 0, 3, 0}, {-7, 10, 25, 0, 3, 0},
    {-8, 10, 25, 0, 3, 0}, {-9, 10, 26, 0, 3, 0}, {-10, 10, 27, 0, 3, 0}, {-11, 10, 28, 0, 3, 0}, {-11, 9, 28, 0, 3, 0},
    {-12, 9, 29, 0, 3, 0}, {-13, 9, 30, 0, 3, 0}, {-14, 9, 30, 0, 3, 0}, {-14, 9, 31, 0, 3, 0}, {-15, 9, 32, 0, 3, 0},
    {-16, 9, 33, 0, 3, 0}, {-17, 9, 33, 0, 3, 0}, {-18, 8, 34, 0, 3, 0}, {-18, 8, 35, 0, 3, 0}, {-19, 8, 36, 0, 3, 0},
    {-20, 8, 37, 0, 3, 0}, {-21, 8, 37, 0, 3, 0}, {-21, 8, 38, 0, 3, 0}, {-22, 8, 39, 0, 3, 0}, {-23, 8, 40, 0, 3, 0},
    {-24, 7, 41, 0, 3, 0}, {-24, 7, 41, 0, 3, 0}, {-25, 7, 42, 0, 3, 0}, {-26, 7, 43, 0, 3, 0}, {-26, 7, 44, 0, 3, 0},
    {-27, 7, 45, 0, 3, 0}, {-28, 7, 46, 0, 3, 0}, {-29, 6, 46, 0, 3, 0}, {-29, 6, 47, 0, 3, 0}, {-30, 6, 48, 0, 3, 0},
    {-31, 6, 49, 0, 3, 0}, {-31, 6, 50, 0, 3, 0}, {-32, 6, 51, 0, 3, 0}, {-33, 6, 52, 0, 3, 0}, {-33, 6, 53, 0, 3, 0},
    {-34, 5, 53, 0, 3, 0}, {-35, 5, 54, 0, 3, 0}, {-35, 5, 55, 0, 3, 0}, {-36, 5, 56, 0, 4, 0}, {-37, 5, 57, 0, 4, 0},
    {-37, 5, 58, 0, 4, 0}, {-38, 5, 59, 0, 4, 0}, {-38, 5, 60, 0, 4, 0}, {-39, 4, 61, 0, 4, 0}, {-40, 4, 62, 0, 4, 0},
    {-40, 4, 63, 0, 4, 0}, {-41, 4, 64, 0, 4, 0}, {-42, 4, 65, 0, 4, 0}, {-42, 4, 66, 0, 4, 0}, {-43, 4, 67, 0, 4, 0},
    {-43, 3, 68, 0, 4, 0}, {-44, 3, 69, 0, 4, 0}, {-44, 3, 70, 0, 4, 0}, {-45, 3, 71, 0, 4, 0}, {-45, 3, 72, 0, 4, 0},
    {-46, 3, 73, 0, 4, 0}, {-47, 3, 74, 0, 4, 0}, {-47, 3, 75, 0, 4, 0}, {-48, 2, 76, 0, 4, 0}, {-48, 2, 77, 0, 4, 0},
    {-49, 2, 78, 0, 4, 0}, {-49, 2, 79, 0, 4, 0}, {-50, 2, 80, 0, 4, 0}, {-50, 2, 81, 0, 4, 0}, {-50, 2, 82, 0, 4, 0},
    {-51, 2, 83, 0, 4, 0}, {-51, 1, 84, 0, 4, 0}, {-52, 1, 86, 0, 4, 0}, {-52, 1, 87, 0, 4, 0}, {-53, 1, 88, 0, 4, 0},
    {-53, 1, 89, 0, 4, 0}, {-53, 1, 90, 0, 4, 0}, {-54, 1, 91, 0, 9, 0}, {-54, 0, 92, 0, 9, 0}, {-55, 0, 93, 0, 9, 0},
    {-55, 0, 94, 0, 9, 0}, {-55, 0, 96, 0, 9, 0}, {-56, 0, 97, 0, 9, 0}, {-56, 0, 98, 0, 9, 0}, {-56, 0, 99, 0, 9, 0},
    {-57, 0, 100, 0, 9, 0}, {-57, -1, 101, 0, 9, 0}, {-57, -1, 102, 0, 9, 0}, {-58, -1, 104, 0, 9, 0}, {-58, -1, 105, 0, 9, 0},
    {-58, -1, 106, 0, 9, 0}, {-58, -1, 107, 0, 9, 0}, {-59, -1, 108, 0, 9, 0}, {-59, -1, 109, 0, 9, 0}, {-59, -2, 111, 0, 9, 0},
    {-59, -2, 112, 0, 9, 0}, {-60, -2, 113, 0, 9, 0}, {-60, -2, 114, 0, 9, 0}, {-60, -2, 115, 0, 9, 0}, {-60, -2, 117, 0, 9, 0},
    {-60, -2, 118, 0, 9, 0}, {-60, -3, 119, 0, 10, 0}, {-60, -3, 120, 0, 10, 0}, {-61, -3, 121, 0, 10, 0}, {-61, -3, 123, 0, 10, 0},
    {-61, -3, 124, 0, 10, 0}, {-61, -3, 125, 0, 10, 0}, {-61, -3, 126, 0, 10, 0}, {-61, -3, 127, 0, 10, 0}, {-61, -4, 129, 0, 10, 0},
    {-61, -4, 130, 0, 10, 0}, {-61, -4, 131, 0, 10, 0}, {-61, -4, 132, 0, 10, 0}, {-61, -4, 134, 0, 10, 0}, {-60, -4, 135, 0, 10, 0},
    {-60, -4, 136, 0, 10, 0}, {-60, -4, 137, 0, 11, 0}, {-60, -5, 138, 0, 11, 0}, {-60, -5, 140, 0, 11, 0}, {-60, -5, 141, 0, 11, 0},
    {-60, -5, 142, 0, 11, 0}, {-59, -5, 143, 0, 11, 0}, {-59, -5, 144, 0, 11, 0}, {-59, -5, 145, 0, 11, 0}, {-59, -6, 147, 0, 11, 0},
    {-58, -6, 148, 0, 11, 0}, {-58, -6, 149, 0, 11, 0}, {-58, -6, 150, 0, 11, 0}, {-58, -6, 151, 0, 11, 0}, {-57, -6, 152, 0, 11, 0},
    {-57, -6, 154, 0, 11, 0}, {-56, -6, 155, 0, 11, 0}, {-56, -7, 156, 0, 12, 0}, {-56, -7, 157, 0, 12, 0}, {-55, -7, 158, 0, 12, 0},
    {-55, -7, 159, 0, 12, 0}, {-54, -7, 160, 0, 12, 0}, {-54, -7, 161, 0, 12, 0}, {-54, -7, 162, 0, 12, 0}, {-53, -8, 163, 0, 12, 0},
    {-53, -8, 165, 0, 12, 0}, {-52, -8, 166, 0, 12, 0}, {-52, -8, 167, 0, 12, 0}, {-51, -8, 168, 0, 12, 0}, {-50, -8, 169, 0, 12, 0},
    {-50, -8, 170, 0, 12, 0}, {-49, -8, 171, 0, 12, 0}, {-49, -9, 172, 0, 12, 0}, {-48, -9, 173, 0, 13, 0}, {-48, -9, 174, 0, 13, 0},
    {-47, -9, 174, 0, 13, 0}, {-46, -9, 175, 0, 13, 0}, {-46, -9, 176, 0, 13, 0}, {-45, -9, 177, 0, 13, 0}, {-44, -9, 178, 0, 13, 0},
    {-44, -10, 179, 0, 13, 0}, {-43, -10, 180, 0, 13, 0}, {-42, -10, 181, 0, 13, 0}, {-41, -10, 182, 0, 13, 0}, {-41, -10, 182, 0, 13, 0},
    {-40, -10, 183, 0, 13, 0}, {-39, -10, 184, 0, 13, 0}, {-39, -11, 185, 0, 13, 0}, {-38, -11, 186, 0, 13, 0}, {-37, -11, 186, 0, 13, 0},
    {-36, -11, 187, 0, 14, 0}, {-35, -11, 188, 0, 14, 0}, {-35, -11, 188, 0, 14, 0}, {-34, -11, 189, 0, 14, 0}, {-33, -11, 190, 0, 14, 0},
    {-32, -12, 190, 0, 14, 0}, {-31, -12, 191, 0, 14, 0}, {-30, -12, 192, 0, 14, 0}, {-30, -12, 192, 0, 14, 0}, {-29, -12, 193, 0, 14, 0},
    {-28, -12, 193, 0, 14, 0}, {-27, -12, 194, 0, 14, 0}, {-26, -12, 195, 0, 14, 0}, {-25, -13, 195, 0, 14, 0}, {-24, -13, 196, 0, 14, 0},
    {-23, -13, 196, 0, 14, 0}, {-22, -13, 196, 0, 15, 0}, {-21, -13, 197, 0, 15, 0}, {-21, -13, 197, 0, 15, 0}, {-20, -13, 198, 0, 15, 0},
    {-19, -14, 198, 0, 15, 0}, {-18, -14, 198, 0, 15, 0}, {-17, -14, 199, 0, 15, 0}, {-16, -14, 199, 0, 15, 0}, {-15, -14, 199, 0, 15, 0},
    {-14, -14, 200, 0, 15, 0}, {-13, -14, 200, 0, 15, 0}, {-12, -14, 200, 0, 15, 0}, {-11, -15, 200, 0, 15, 0}, {-10, -15, 201, 0, 15, 0},
    {-9, -15, 201, 0, 15, 0}, {-8, -15, 201, 0, 15, 0}, {-7, -15, 201, 0, 16, 0}, {-6, -15, 201, 0, 16, 0}, {-5, -15, 201, 0, 16, 0},
    {-4, -15, 202, 0, 16, 0}, {-3, -16, 202, 0, 16, 0}, {-2, -16, 202, 0, 16, 0}, {-1, -16, 202, 0, 16, 0}, {0, -16, 202, 0, 16, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftMediumHalfLoopUp1, {
    {16, 0, -1, 8, 2, 0}, {16, 1, -1, 8, 2, 0}, {16, 2, 0, 8, 2, 0}, {16, 3, 0, 8, 2, 0}, {15, 4, 1, 8, 2, 0},
    {15, 5, 1, 8, 2, 0}, {15, 6, 2, 8, 2, 0}, {15, 6, 2, 8, 2, 0}, {15, 7, 3, 8, 2, 0}, {15, 8, 3, 8, 2, 0},
    {15, 9, 4, 8, 2, 0}, {15, 10, 4, 8, 2, 0}, {14, 11, 5, 8, 2, 0}, {14, 12, 5, 8, 2, 0}, {14, 13, 6, 8, 2, 0},
    {14, 14, 6, 8, 2, 0}, {14, 14, 7, 8, 2, 0}, {14, 15, 7, 8, 2, 0}, {14, 16, 8, 8, 2, 0}, {14, 17, 9, 8, 2, 0},
    {13, 18, 9, 8, 2, 0}, {13, 19, 10, 8, 2, 0}, {13, 20, 10, 8, 2, 0}, {13, 21, 11, 8, 2, 0}, {13, 21, 11, 8, 2, 0},
    {13, 22, 12, 8, 2, 0}, {13, 23, 13, 8, 2, 0}, {12, 24, 13, 8, 2, 0}, {12, 25, 14, 8, 2, 0}, {12, 26, 14, 8, 2, 0},
    {12, 27, 15, 8, 2, 0}, {12, 28, 16, 8, 2, 0}, {12, 28, 16, 8, 2, 0}, {12, 29, 17, 8, 2, 0}, {12, 30, 17, 8, 3, 0},
    {11, 31, 18, 8, 3, 0}, {11, 32, 19, 8, 3, 0}, {11, 33, 19, 8, 3, 0}, {11, 33, 20, 8, 3, 0}, {11, 34, 21, 8, 3, 0},
    {11, 35, 21, 8, 3, 0}, {11, 36, 22, 8, 3, 0}, {11, 37, 23, 8, 3, 0}, {10, 38, 23, 8, 3, 0}, {10, 38, 24, 8, 3, 0},
    {10, 39, 25, 8, 3, 0}, {10, 40, 25, 8, 3, 0}, {10, 41, 26, 8, 3, 0}, {10, 42, 27, 8, 3, 0}, {10, 43, 28, 8, 3, 0},
    {9, 43, 28, 8, 3, 0}, {9, 44, 29, 8, 3, 0}, {9, 45, 30, 8, 3, 0}, {9, 46, 30, 8, 3, 0}, {9, 46, 31, 8, 3, 0},
    {9, 47, 32, 8, 3, 0}, {9, 48, 33, 8, 3, 0}, {9, 49, 33, 8, 3, 0}, {8, 50, 34, 8, 3, 0}, {8, 50, 35, 8, 3, 0},
    {8, 51, 36, 8, 3, 0}, {8, 52, 37, 8, 3, 0}, {8, 53, 37, 8, 3, 0}, {8, 53, 38, 8, 3, 0}, {8, 54, 39, 8, 3, 0},
    {8, 55, 40, 8, 3, 0}, {7, 56, 41, 8, 3, 0}, {7, 56, 41, 8, 3, 0}, {7, 57, 42, 8, 3, 0}, {7, 58, 43, 8, 3, 0},
    {7, 58, 44, 8, 3, 0}, {7, 59, 45, 8, 3, 0}, {7, 60, 46, 8, 3, 0}, {6, 61, 46, 8, 3, 0}, {6, 61, 47, 8, 3, 0},
    {6, 62, 48, 8, 3, 0}, {6, 63, 49, 8, 3, 0}, {6, 63, 50, 8, 3, 0}, {6, 64, 51, 8, 3, 0}, {6, 65, 52, 8, 3, 0},
    {6, 65, 53, 8, 3, 0}, {5, 66, 53, 8, 3, 0}, {5, 67, 54, 8, 3, 0}, {5, 67, 55, 8, 3, 0}, {5, 68, 56, 8, 4, 0},
    {5, 69, 57, 8, 4, 0}, {5, 69, 58, 8, 4, 0}, {5, 70, 59, 8, 4, 0}, {5, 70, 60, 8, 4, 0}, {4, 71, 61, 8, 4, 0},
    {4, 72, 62, 8, 4, 0}, {4, 72, 63, 8, 4, 0}, {4, 73, 64, 8, 4, 0}, {4, 74, 65, 8, 4, 0}, {4, 74, 66, 8, 4, 0},
    {4, 75, 67, 8, 4, 0}, {3, 75, 68, 8, 4, 0}, {3, 76, 69, 8, 4, 0}, {3, 76, 70, 8, 4, 0}, {3, 77, 71, 8, 4, 0},
    {3, 77, 72, 8, 4, 0}, {3, 78, 73, 8, 4, 0}, {3, 79, 74, 8, 4, 0}, {3, 79, 75, 8, 4, 0}, {2, 80, 76, 8, 4, 0},
    {2, 80, 77, 8, 4, 0}, {2, 81, 78, 8, 4, 0}, {2, 81, 79, 8, 4, 0}, {2, 82, 80, 8, 4, 0}, {2, 82, 81, 8, 4, 0},
    {2, 82, 82, 8, 4, 0}, {2, 83, 83, 8, 4, 0}, {1, 83, 84, 8, 4, 0}, {1, 84, 86, 8, 4, 0}, {1, 84, 87, 8, 4, 0},
    {1, 85, 88, 8, 4, 0}, {1, 85, 89, 8, 4, 0}, {1, 85, 90, 8, 4, 0}, {1, 86, 91, 8, 9, 0}, {0, 86, 92, 8, 9, 0},
    {0, 87, 93, 8, 9, 0}, {0, 87, 94, 8, 9, 0}, {0, 87, 96, 8, 9, 0}, {0, 88, 97, 8, 9, 0}, {0, 88, 98, 8, 9, 0},
    {0, 88, 99, 8, 9, 0}, {0, 89, 100, 8, 9, 0}, {-1, 89, 101, 8, 9, 0}, {-1, 89, 102, 8, 9, 0}, {-1, 90, 104, 8, 9, 0},
    {-1, 90, 105, 8, 9, 0}, {-1, 90, 106, 8, 9, 0}, {-1, 90, 107, 8, 9, 0}, {-1, 91, 108, 8, 9, 0}, {-1, 91, 109, 8, 9, 0},
    {-2, 91, 111, 8, 9, 0}, {-2, 91, 112, 8, 9, 0}, {-2, 92, 113, 8, 9, 0}, {-2, 92, 114, 8, 9, 0}, {-2, 92, 115, 8, 9, 0},
    {-2, 92, 117, 8, 9, 0}, {-2, 92, 118, 8, 9, 0}, {-3, 92, 119, 8, 10, 0}, {-3, 92, 120, 8, 10, 0}, {-3, 93, 121, 8, 10, 0},
    {-3, 93, 123, 8, 10, 0}, {-3, 93, 124, 8, 10, 0}, {-3, 93, 125, 8, 10, 0}, {-3, 93, 126, 8, 10, 0}, {-3, 93, 127, 8, 10, 0},
    {-4, 93, 129, 8, 10, 0}, {-4, 93, 130, 8, 10, 0}, {-4, 93, 131, 8, 10, 0}, {-4, 93, 132, 8, 10, 0}, {-4, 93, 134, 8, 10, 0},
    {-4, 92, 135, 8, 10, 0}, {-4, 92, 136, 8, 10, 0}, {-4, 92, 137, 8, 11, 0}, {-5, 92, 138, 8, 11, 0}, {-5, 92, 140, 8, 11, 0},
    {-5, 92, 141, 8, 11, 0}, {-5, 92, 142, 8, 11, 0}, {-5, 91, 143, 8, 11, 0}, {-5, 91, 144, 8, 11, 0}, {-5, 91, 145, 8, 11, 0},
    {-6, 91, 147, 8, 11, 0}, {-6, 90, 148, 8, 11, 0}, {-6, 90, 149, 8, 11, 0}, {-6, 90, 150, 8, 11, 0}, {-6, 90, 151, 8, 11, 0},
    {-6, 89, 152, 8, 11, 0}, {-6, 89, 154, 8, 11, 0}, {-6, 88, 155, 8, 11, 0}, {-7, 88, 156, 8, 12, 0}, {-7, 88, 157, 8, 12, 0},
    {-7, 87, 158, 8, 12, 0}, {-7, 87, 159, 8, 12, 0}, {-7, 86, 160, 8, 12, 0}, {-7, 86, 161, 8, 12, 0}, {-7, 86, 162, 8, 12, 0},
    {-8, 85, 163, 8, 12, 0}, {-8, 85, 165, 8, 12, 0}, {-8, 84, 166, 8, 12, 0}, {-8, 84, 167, 8, 12, 0}, {-8, 83, 168, 8, 12, 0},
    {-8, 82, 169, 8, 12, 0}, {-8, 82, 170, 8, 12, 0}, {-8, 81, 171, 8, 12, 0}, {-9, 81, 172, 8, 12, 0}, {-9, 80, 173, 8, 13, 0},
    {-9, 80, 174, 8, 13, 0}, {-9, 79, 174, 8, 13, 0}, {-9, 78, 175, 8, 13, 0}, {-9, 78, 176, 8, 13, 0}, {-9, 77, 177, 8, 13, 0},
    {-9, 76, 178, 8, 13, 0}, {-10, 76, 179, 8, 13, 0}, {-10, 75, 180, 8, 13, 0}, {-10, 74, 181, 8, 13, 0}, {-10, 73, 182, 8, 13, 0},
    {-10, 73, 182, 8, 13, 0}, {-10, 72, 183, 8, 13, 0}, {-10, 71, 184, 8, 13, 0}, {-11, 71, 185, 8, 13, 0}, {-11, 70, 186, 8, 13, 0},
    {-11, 69, 186, 8, 13, 0}, {-11, 68, 187, 8, 14, 0}, {-11, 67, 188, 8, 14, 0}, {-11, 67, 188, 8, 14, 0}, {-11, 66, 189, 8, 14, 0},
    {-11, 65, 190, 8, 14, 0}, {-12, 64, 190, 8, 14, 0}, {-12, 63, 191, 8, 14, 0}, {-12, 62, 192, 8, 14, 0}, {-12, 62, 192, 8, 14, 0},
    {-12, 61, 193, 8, 14, 0}, {-12, 60, 193, 8, 14, 0}, {-12, 59, 194, 8, 14, 0}, {-12, 58, 195, 8, 14, 0}, {-13, 57, 195, 8, 14, 0},
    {-13, 56, 196, 8, 14, 0}, {-13, 55, 196, 8, 14, 0}, {-13, 54, 196, 8, 15, 0}, {-13, 53, 197, 8, 15, 0}, {-13, 53, 197, 8, 15, 0},
    {-13, 52, 198, 8, 15, 0}, {-14, 51, 198, 8, 15, 0}, {-14, 50, 198, 8, 15, 0}, {-14, 49, 199, 8, 15, 0}, {-14, 48, 199, 8, 15, 0},
    {-14, 47, 199, 8, 15, 0}, {-14, 46, 200, 8, 15, 0}, {-14, 45, 200, 8, 15, 0}, {-14, 44, 200, 8, 15, 0}, {-15, 43, 200, 8, 15, 0},
    {-15, 42, 201, 8, 15, 0}, {-15, 41, 201, 8, 15, 0}, {-15, 40, 201, 8, 15, 0}, {-15, 39, 201, 8, 16, 0}, {-15, 38, 201, 8, 16, 0},
    {-15, 37, 201, 8, 16, 0}, {-15, 36, 202, 8, 16, 0}, {-16, 35, 202, 8, 16, 0}, {-16, 34, 202, 8, 16, 0}, {-16, 33, 202, 8, 16, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftMediumHalfLoopUp2, {
    {0, 16, -1, 16, 2, 0}, {1, 16, -1, 16, 2, 0}, {2, 16, 0, 16, 2, 0}, {3, 16, 0, 16, 2, 0}, {4, 17, 1, 16, 2, 0},
    {5, 17, 1, 16, 2, 0}, {6, 17, 2, 16, 2, 0}, {6, 17, 2, 16, 2, 0}, {7, 17, 3, 16, 2, 0}, {8, 17, 3, 16, 2, 0},
    {9, 17, 4, 16, 2, 0}, {10, 17, 4, 16, 2, 0}, {11, 18, 5, 16, 2, 0}, {12, 18, 5, 16, 2, 0}, {13, 18, 6, 16, 2, 0},
    {14, 18, 6, 16, 2, 0}, {14, 18, 7, 16, 2, 0}, {15, 18, 7, 16, 2, 0}, {16, 18, 8, 16, 2, 0}, {17, 18, 9, 16, 2, 0},
    {18, 19, 9, 16, 2, 0}, {19, 19, 10, 16, 2, 0}, {20, 19, 10, 16, 2, 0}, {21, 19, 11, 16, 2, 0}, {21, 19, 11, 16, 2, 0},
    {22, 19, 12, 16, 2, 0}, {23, 19, 13, 16, 2, 0}, {24, 20, 13, 16, 2, 0}, {25, 20, 14, 16, 2, 0}, {26, 20, 14, 16, 2, 0},
    {27, 20, 15, 16, 2, 0}, {28, 20, 16, 16, 2, 0}, {28, 20, 16, 16, 2, 0}, {29, 20, 17, 16, 2, 0}, {30, 20, 17, 16, 3, 0},
    {31, 21, 18, 16, 3, 0}, {32, 21, 19, 16, 3, 0}, {33, 21, 19, 16, 3, 0}, {33, 21, 20, 16, 3, 0}, {34, 21, 21, 16, 3, 0},
    {35, 21, 21, 16, 3, 0}, {36, 21, 22, 16, 3, 0}, {37, 21, 23, 16, 3, 0}, {38, 22, 23, 16, 3, 0}, {38, 22, 24, 16, 3, 0},
    {39, 22, 25, 16, 3, 0}, {40, 22, 25, 16, 3, 0}, {41, 22, 26, 16, 3, 0}, {42, 22, 27, 16, 3, 0}, {43, 22, 28, 16, 3, 0},
    {43, 23, 28, 16, 3, 0}, {44, 23, 29, 16, 3, 0}, {45, 23, 30, 16, 3, 0}, {46, 23, 30, 16, 3, 0}, {46, 23, 31, 16, 3, 0},
    {47, 23, 32, 16, 3, 0}, {48, 23, 33, 16, 3, 0}, {49, 23, 33, 16, 3, 0}, {50, 24, 34, 16, 3, 0}, {50, 24, 35, 16, 3, 0},
    {51, 24, 36, 16, 3, 0}, {52, 24, 37, 16, 3, 0}, {53, 24, 37, 16, 3, 0}, {53, 24, 38, 16, 3, 0}, {54, 24, 39, 16, 3, 0},
    {55, 24, 40, 16, 3, 0}, {56, 25, 41, 16, 3, 0}, {56, 25, 41, 16, 3, 0}, {57, 25, 42, 16, 3, 0}, {58, 25, 43, 16, 3, 0},
    {58, 25, 44, 16, 3, 0}, {59, 25, 45, 16, 3, 0}, {60, 25, 46, 16, 3, 0}, {61, 26, 46, 16, 3, 0}, {61, 26, 47, 16, 3, 0},
    {62, 26, 48, 16, 3, 0}, {63, 26, 49, 16, 3, 0}, {63, 26, 50, 16, 3, 0}, {64, 26, 51, 16, 3, 0}, {65, 26, 52, 16, 3, 0},
    {65, 26, 53, 16, 3, 0}, {66, 27, 53, 16, 3, 0}, {67, 27, 54, 16, 3, 0}, {67, 27, 55, 16, 3, 0}, {68, 27, 56, 16, 4, 0},
    {69, 27, 57, 16, 4, 0}, {69, 27, 58, 16, 4, 0}, {70, 27, 59, 16, 4, 0}, {70, 27, 60, 16, 4, 0}, {71, 28, 61, 16, 4, 0},
    {72, 28, 62, 16, 4, 0}, {72, 28, 63, 16, 4, 0}, {73, 28, 64, 16, 4, 0}, {74, 28, 65, 16, 4, 0}, {74, 28, 66, 16, 4, 0},
    {75, 28, 67, 16, 4, 0}, {75, 29, 68, 16, 4, 0}, {76, 29, 69, 16, 4, 0}, {76, 29, 70, 16, 4, 0}, {77, 29, 71, 16, 4, 0},
    {77, 29, 72, 16, 4, 0}, {78, 29, 73, 16, 4, 0}, {79, 29, 74, 16, 4, 0}, {79, 29, 75, 16, 4, 0}, {80, 30, 76, 16, 4, 0},
    {80, 30, 77, 16, 4, 0}, {81, 30, 78, 16, 4, 0}, {81, 30, 79, 16, 4, 0}, {82, 30, 80, 16, 4, 0}, {82, 30, 81, 16, 4, 0},
    {82, 30, 82, 16, 4, 0}, {83, 30, 83, 16, 4, 0}, {83, 31, 84, 16, 4, 0}, {84, 31, 86, 16, 4, 0}, {84, 31, 87, 16, 4, 0},
    {85, 31, 88, 16, 4, 0}, {85, 31, 89, 16, 4, 0}, {85, 31, 90, 16, 4, 0}, {86, 31, 91, 16, 9, 0}, {86, 32, 92, 16, 9, 0},
    {87, 32, 93, 16, 9, 0}, {87, 32, 94, 16, 9, 0}, {87, 32, 96, 16, 9, 0}, {88, 32, 97, 16, 9, 0}, {88, 32, 98, 16, 9, 0},
    {88, 32, 99, 16, 9, 0}, {89, 32, 100, 16, 9, 0}, {89, 33, 101, 16, 9, 0}, {89, 33, 102, 16, 9, 0}, {90, 33, 104, 16, 9, 0},
    {90, 33, 105, 16, 9, 0}, {90, 33, 106, 16, 9, 0}, {90, 33, 107, 16, 9, 0}, {91, 33, 108, 16, 9, 0}, {91, 33, 109, 16, 9, 0},
    {91, 34, 111, 16, 9, 0}, {91, 34, 112, 16, 9, 0}, {92, 34, 113, 16, 9, 0}, {92, 34, 114, 16, 9, 0}, {92, 34, 115, 16, 9, 0},
    {92, 34, 117, 16, 9, 0}, {92, 34, 118, 16, 9, 0}, {92, 35, 119, 16, 10, 0}, {92, 35, 120, 16, 10, 0}, {93, 35, 121, 16, 10, 0},
    {93, 35, 123, 16, 10, 0}, {93, 35, 124, 16, 10, 0}, {93, 35, 125, 16, 10, 0}, {93, 35, 126, 16, 10, 0}, {93, 35, 127, 16, 10, 0},
    {93, 36, 129, 16, 10, 0}, {93, 36, 130, 16, 10, 0}, {93, 36, 131, 16, 10, 0}, {93, 36, 132, 16, 10, 0}, {93, 36, 134, 16, 10, 0},
    {92, 36, 135, 16, 10, 0}, {92, 36, 136, 16, 10, 0}, {92, 36, 137, 16, 11, 0}, {92, 37, 138, 16, 11, 0}, {92, 37, 140, 16, 11, 0},
    {92, 37, 141, 16, 11, 0}, {92, 37, 142, 16, 11, 0}, {91, 37, 143, 16, 11, 0}, {91, 37, 144, 16, 11, 0}, {91, 37, 145, 16, 11, 0},
    {91, 38, 147, 16, 11, 0}, {90, 38, 148, 16, 11, 0}, {90, 38, 149, 16, 11, 0}, {90, 38, 150, 16, 11, 0}, {90, 38, 151, 16, 11, 0},
    {89, 38, 152, 16, 11, 0}, {89, 38, 154, 16, 11, 0}, {88, 38, 155, 16, 11, 0}, {88, 39, 156, 16, 12, 0}, {88, 39, 157, 16, 12, 0},
    {87, 39, 158, 16, 12, 0}, {87, 39, 159, 16, 12, 0}, {86, 39, 160, 16, 12, 0}, {86, 39, 161, 16, 12, 0}, {86, 39, 162, 16, 12, 0},
    {85, 40, 163, 16, 12, 0}, {85, 40, 165, 16, 12, 0}, {84, 40, 166, 16, 12, 0}, {84, 40, 167, 16, 12, 0}, {83, 40, 168, 16, 12, 0},
    {82, 40, 169, 16, 12, 0}, {82, 40, 170, 16, 12, 0}, {81, 40, 171, 16, 12, 0}, {81, 41, 172, 16, 12, 0}, {80, 41, 173, 16, 13, 0},
    {80, 41, 174, 16, 13, 0}, {79, 41, 174, 16, 13, 0}, {78, 41, 175, 16, 13, 0}, {78, 41, 176, 16, 13, 0}, {77, 41, 177, 16, 13, 0},
    {76, 41, 178, 16, 13, 0}, {76, 42, 179, 16, 13, 0}, {75, 42, 180, 16, 13, 0}, {74, 42, 181, 16, 13, 0}, {73, 42, 182, 16, 13, 0},
    {73, 42, 182, 16, 13, 0}, {72, 42, 183, 16, 13, 0}, {71, 42, 184, 16, 13, 0}, {71, 43, 185, 16, 13, 0}, {70, 43, 186, 16, 13, 0},
    {69, 43, 186, 16, 13, 0}, {68, 43, 187, 16, 14, 0}, {67, 43, 188, 16, 14, 0}, {67, 43, 188, 16, 14, 0}, {66, 43, 189, 16, 14, 0},
    {65, 43, 190, 16, 14, 0}, {64, 44, 190, 16, 14, 0}, {63, 44, 191, 16, 14, 0}, {62, 44, 192, 16, 14, 0}, {62, 44, 192, 16, 14, 0},
    {61, 44, 193, 16, 14, 0}, {60, 44, 193, 16, 14, 0}, {59, 44, 194, 16, 14, 0}, {58, 44, 195, 16, 14, 0}, {57, 45, 195, 16, 14, 0},
    {56, 45, 196, 16, 14, 0}, {55, 45, 196, 16, 14, 0}, {54, 45, 196, 16, 15, 0}, {53, 45, 197, 16, 15, 0}, {53, 45, 197, 16, 15, 0},
    {52, 45, 198, 16, 15, 0}, {51, 46, 198, 16, 15, 0}, {50, 46, 198, 16, 15, 0}, {49, 46, 199, 16, 15, 0}, {48, 46, 199, 16, 15, 0},
    {47, 46, 199, 16, 15, 0}, {46, 46, 200, 16, 15, 0}, {45, 46, 200, 16, 15, 0}, {44, 46, 200, 16, 15, 0}, {43, 47, 200, 16, 15, 0},
    {42, 47, 201, 16, 15, 0}, {41, 47, 201, 16, 15, 0}, {40, 47, 201, 16, 15, 0}, {39, 47, 201, 16, 16, 0}, {38, 47, 201, 16, 16, 0},
    {37, 47, 201, 16, 16, 0}, {36, 47, 202, 16, 16, 0}, {35, 48, 202, 16, 16, 0}, {34, 48, 202, 16, 16, 0}, {33, 48, 202, 16, 16, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftMediumHalfLoopUp3, {
    {16, 31, -1, 24, 2, 0}, {16, 30, 0, 24, 2, 0}, {16, 29, 0, 24, 2, 0}, {17, 28, 1, 24, 2, 0}, {17, 27, 1, 24, 2, 0},
    {17, 26, 2, 24, 2, 0}, {17, 26, 2, 24, 2, 0}, {17, 25, 3, 24, 2, 0}, {17, 24, 3, 24, 2, 0}, {17, 23, 4, 24, 2, 0},
    {17, 22, 4, 24, 2, 0}, {18, 21, 5, 24, 2, 0}, {18, 20, 5, 24, 2, 0}, {18, 19, 6, 24, 2, 0}, {18, 18, 6, 24, 2, 0},
    {18, 18, 7, 24, 2, 0}, {18, 17, 7, 24, 2, 0}, {18, 16, 8, 24, 2, 0}, {18, 15, 9, 24, 2, 0}, {19, 14, 9, 24, 2, 0},
    {19, 13, 10, 24, 2, 0}, {19, 12, 10, 24, 2, 0}, {19, 11, 11, 24, 2, 0}, {19, 11, 11, 24, 2, 0}, {19, 10, 12, 24, 2, 0},
    {19, 9, 13, 24, 2, 0}, {20, 8, 13, 24, 2, 0}, {20, 7, 14, 24, 2, 0}, {20, 6, 14, 24, 2, 0}, {20, 5, 15, 24, 2, 0},
    {20, 4, 16, 24, 2, 0}, {20, 4, 16, 24, 2, 0}, {20, 3, 17, 24, 2, 0}, {20, 2, 17, 24, 3, 0}, {21, 1, 18, 24, 3, 0},
    {21, 0, 19, 24, 3, 0}, {21, -1, 19, 24, 3, 0}, {21, -1, 20, 24, 3, 0}, {21, -2, 21, 24, 3, 0}, {21, -3, 21, 24, 3, 0},
    {21, -4, 22, 24, 3, 0}, {21, -5, 23, 24, 3, 0}, {22, -6, 23, 24, 3, 0}, {22, -6, 24, 24, 3, 0}, {22, -7, 25, 24, 3, 0},
    {22, -8, 25, 24, 3, 0}, {22, -9, 26, 24, 3, 0}, {22, -10, 27, 24, 3, 0}, {22, -11, 28, 24, 3, 0}, {23, -11, 28, 24, 3, 0},
    {23, -12, 29, 24, 3, 0}, {23, -13, 30, 24, 3, 0}, {23, -14, 30, 24, 3, 0}, {23, -14, 31, 24, 3, 0}, {23, -15, 32, 24, 3, 0},
    {23, -16, 33, 24, 3, 0}, {23, -17, 33, 24, 3, 0}, {24, -18, 34, 24, 3, 0}, {24, -18, 35, 24, 3, 0}, {24, -19, 36, 24, 3, 0},
    {24, -20, 37, 24, 3, 0}, {24, -21, 37, 24, 3, 0}, {24, -21, 38, 24, 3, 0}, {24, -22, 39, 24, 3, 0}, {24, -23, 40, 24, 3, 0},
    {25, -24, 41, 24, 3, 0}, {25, -24, 41, 24, 3, 0}, {25, -25, 42, 24, 3, 0}, {25, -26, 43, 24, 3, 0}, {25, -26, 44, 24, 3, 0},
    {25, -27, 45, 24, 3, 0}, {25, -28, 46, 24, 3, 0}, {26, -29, 46, 24, 3, 0}, {26, -29, 47, 24, 3, 0}, {26, -30, 48, 24, 3, 0},
    {26, -31, 49, 24, 3, 0}, {26, -31, 50, 24, 3, 0}, {26, -32, 51, 24, 3, 0}, {26, -33, 52, 24, 3, 0}, {26, -33, 53, 24, 3, 0},
    {27, -34, 53, 24, 3, 0}, {27, -35, 54, 24, 3, 0}, {27, -35, 55, 24, 3, 0}, {27, -36, 56, 24, 4, 0}, {27, -37, 57, 24, 4, 0},
    {27, -37, 58, 24, 4, 0}, {27, -38, 59, 24, 4, 0}, {27, -38, 60, 24, 4, 0}, {28, -39, 61, 24, 4, 0}, {28, -40, 62, 24, 4, 0},
    {28, -40, 63, 24, 4, 0}, {28, -41, 64, 24, 4, 0}, {28, -42, 65, 24, 4, 0}, {28, -42, 66, 24, 4, 0}, {28, -43, 67, 24, 4, 0},
    {29, -43, 68, 24, 4, 0}, {29, -44, 69, 24, 4, 0}, {29, -44, 70, 24, 4, 0}, {29, -45, 71, 24, 4, 0}, {29, -45, 72, 24, 4, 0},
    {29, -46, 73, 24, 4, 0}, {29, -47, 74, 24, 4, 0}, {29, -47, 75, 24, 4, 0}, {30, -48, 76, 24, 4, 0}, {30, -48, 77, 24, 4, 0},
    {30, -49, 78, 24, 4, 0}, {30, -49, 79, 24, 4, 0}, {30, -50, 80, 24, 4, 0}, {30, -50, 81, 24, 4, 0}, {30, -50, 82, 24, 4, 0},
    {30, -51, 83, 24, 4, 0}, {31, -51, 84, 24, 4, 0}, {31, -52, 86, 24, 4, 0}, {31, -52, 87, 24, 4, 0}, {31, -53, 88, 24, 4, 0},
    {31, -53, 89, 24, 4, 0}, {31, -53, 90, 24, 4, 0}, {31, -54, 91, 24, 9, 0}, {32, -54, 92, 24, 9, 0}, {32, -55, 93, 24, 9, 0},
    {32, -55, 94, 24, 9, 0}, {32, -55, 96, 24, 9, 0}, {32, -56, 97, 24, 9, 0}, {32, -56, 98, 24, 9, 0}, {32, -56, 99, 24, 9, 0},
    {32, -57, 100, 24, 9, 0}, {33, -57, 101, 24, 9, 0}, {33, -57, 102, 24, 9, 0}, {33, -58, 104, 24, 9, 0}, {33, -58, 105, 24, 9, 0},
    {33, -58, 106, 24, 9, 0}, {33, -58, 107, 24, 9, 0}, {33, -59, 108, 24, 9, 0}, {33, -59, 109, 24, 9, 0}, {34, -59, 111, 24, 9, 0},
    {34, -59, 112, 24, 9, 0}, {34, -60, 113, 24, 9, 0}, {34, -60, 114, 24, 9, 0}, {34, -60, 115, 24, 9, 0}, {34, -60, 117, 24, 9, 0},
    {34, -60, 118, 24, 9, 0}, {35, -60, 119, 24, 10, 0}, {35, -60, 120, 24, 10, 0}, {35, -61, 121, 24, 10, 0}, {35, -61, 123, 24, 10, 0},
    {35, -61, 124, 24, 10, 0}, {35, -61, 125, 24, 10, 0}, {35, -61, 126, 24, 10, 0}, {35, -61, 127, 24, 10, 0}, {36, -61, 129, 24, 10, 0},
    {36, -61, 130, 24, 10, 0}, {36, -61, 131, 24, 10, 0}, {36, -61, 132, 24, 10, 0}, {36, -61, 134, 24, 10, 0}, {36, -60, 135, 24, 10, 0},
    {36, -60, 136, 24, 10, 0}, {36, -60, 137, 24, 11, 0}, {37, -60, 138, 24, 11, 0}, {37, -60, 140, 24, 11, 0}, {37, -60, 141, 24, 11, 0},
    {37, -60, 142, 24, 11, 0}, {37, -59, 143, 24, 11, 0}, {37, -59, 144, 24, 11, 0}, {37, -59, 145, 24, 11, 0}, {38, -59, 147, 24, 11, 0},
    {38, -58, 148, 24, 11, 0}, {38, -58, 149, 24, 11, 0}, {38, -58, 150, 24, 11, 0}, {38, -58, 151, 24, 11, 0}, {38, -57, 152, 24, 11, 0},
    {38, -57, 154, 24, 11, 0}, {38, -56, 155, 24, 11, 0}, {39, -56, 156, 24, 12, 0}, {39, -56, 157, 24, 12, 0}, {39, -55, 158, 24, 12, 0},
    {39, -55, 159, 24, 12, 0}, {39, -54, 160, 24, 12, 0}, {39, -54, 161, 24, 12, 0}, {39, -54, 162, 24, 12, 0}, {40, -53, 163, 24, 12, 0},
    {40, -53, 165, 24, 12, 0}, {40, -52, 166, 24, 12, 0}, {40, -52, 167, 24, 12, 0}, {40, -51, 168, 24, 12, 0}, {40, -50, 169, 24, 12, 0},
    {40, -50, 170, 24, 12, 0}, {40, -49, 171, 24, 12, 0}, {41, -49, 172, 24, 12, 0}, {41, -48, 173, 24, 13, 0}, {41, -48, 174, 24, 13, 0},
    {41, -47, 174, 24, 13, 0}, {41, -46, 175, 24, 13, 0}, {41, -46, 176, 24, 13, 0}, {41, -45, 177, 24, 13, 0}, {41, -44, 178, 24, 13, 0},
    {42, -44, 179, 24, 13, 0}, {42, -43, 180, 24, 13, 0}, {42, -42, 181, 24, 13, 0}, {42, -41, 182, 24, 13, 0}, {42, -41, 182, 24, 13, 0},
    {42, -40, 183, 24, 13, 0}, {42, -39, 184, 24, 13, 0}, {43, -39, 185, 24, 13, 0}, {43, -38, 186, 24, 13, 0}, {43, -37, 186, 24, 13, 0},
    {43, -36, 187, 24, 14, 0}, {43, -35, 188, 24, 14, 0}, {43, -35, 188, 24, 14, 0}, {43, -34, 189, 24, 14, 0}, {43, -33, 190, 24, 14, 0},
    {44, -32, 190, 24, 14, 0}, {44, -31, 191, 24, 14, 0}, {44, -30, 192, 24, 14, 0}, {44, -30, 192, 24, 14, 0}, {44, -29, 193, 24, 14, 0},
    {44, -28, 193, 24, 14, 0}, {44, -27, 194, 24, 14, 0}, {44, -26, 195, 24, 14, 0}, {45, -25, 195, 24, 14, 0}, {45, -24, 196, 24, 14, 0},
    {45, -23, 196, 24, 14, 0}, {45, -22, 196, 24, 15, 0}, {45, -21, 197, 24, 15, 0}, {45, -21, 197, 24, 15, 0}, {45, -20, 198, 24, 15, 0},
    {46, -19, 198, 24, 15, 0}, {46, -18, 198, 24, 15, 0}, {46, -17, 199, 24, 15, 0}, {46, -16, 199, 24, 15, 0}, {46, -15, 199, 24, 15, 0},
    {46, -14, 200, 24, 15, 0}, {46, -13, 200, 24, 15, 0}, {46, -12, 200, 24, 15, 0}, {47, -11, 200, 24, 15, 0}, {47, -10, 201, 24, 15, 0},
    {47, -9, 201, 24, 15, 0}, {47, -8, 201, 24, 15, 0}, {47, -7, 201, 24, 16, 0}, {47, -6, 201, 24, 16, 0}, {47, -5, 201, 24, 16, 0},
    {47, -4, 202, 24, 16, 0}, {48, -3, 202, 24, 16, 0}, {48, -2, 202, 24, 16, 0}, {48, -1, 202, 24, 16, 0}, {48, 0, 202, 24, 16, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightMediumHalfLoopUp0, {
    {31, 16, -1, 0, 2, 0}, {30, 16, 0, 0, 2, 0}, {29, 16, 0, 0, 2, 0}, {28, 17, 1, 0, 2, 0}, {27, 17, 1, 0, 2, 0},
    {26, 17, 2, 0, 2, 0}, {26, 17, 2, 0, 2, 0}, {25, 17, 3, 0, 2, 0}, {24, 17, 3, 0, 2, 0}, {23, 17, 4, 0, 2, 0},
    {22, 17, 4, 0, 2, 0}, {21, 18, 5, 0, 2, 0}, {20, 18, 5, 0, 2, 0}, {19, 18, 6, 0, 2, 0}, {18, 18, 6, 0, 2, 0},
    {18, 18, 7, 0, 2, 0}, {17, 18, 7, 0, 2, 0}, {16, 18, 8, 0, 2, 0}, {15, 18, 9, 0, 2, 0}, {14, 19, 9, 0, 2, 0},
    {13, 19, 10, 0, 2, 0}, {12, 19, 10, 0, 2, 0}, {11, 19, 11, 0, 2, 0}, {11, 19, 11, 0, 2, 0}, {10, 19, 12, 0, 2, 0},
    {9, 19, 13, 0, 2, 0}, {8, 20, 13, 0, 2, 0}, {7, 20, 14, 0, 2, 0}, {6, 20, 14, 0, 2, 0}, {5, 20, 15, 0, 2, 0},
    {4, 20, 16, 0, 2, 0}, {4, 20, 16, 0, 2, 0}, {3, 20, 17, 0, 2, 0}, {2, 20, 17, 0, 3, 0}, {1, 21, 18, 0, 3, 0},
    {0, 21, 19, 0, 3, 0}, {-1, 21, 19, 0, 3, 0}, {-1, 21, 20, 0, 3, 0}, {-2, 21, 21, 0, 3, 0}, {-3, 21, 21, 0, 3, 0},
    {-4, 21, 22, 0, 3, 0}, {-5, 21, 23, 0, 3, 0}, {-6, 22, 23, 0, 3, 0}, {-6, 22, 24, 0, 3, 0}, {-7, 22, 25, 0, 3, 0},
    {-8, 22, 25, 0, 3, 0}, {-9, 22, 26, 0, 3, 0}, {-10, 22, 27, 0, 3, 0}, {-11, 22, 28, 0, 3, 0}, {-11, 23, 28, 0, 3, 0},
    {-12, 23, 29, 0, 3, 0}, {-13, 23, 30, 0, 3, 0}, {-14, 23, 30, 0, 3, 0}, {-14, 23, 31, 0, 3, 0}, {-15, 23, 32, 0, 3, 0},
    {-16, 23, 33, 0, 3, 0}, {-17, 23, 33, 0, 3, 0}, {-18, 24, 34, 0, 3, 0}, {-18, 24, 35, 0, 3, 0}, {-19, 24, 36, 0, 3, 0},
    {-20, 24, 37, 0, 3, 0}, {-21, 24, 37, 0, 3, 0}, {-21, 24, 38, 0, 3, 0}, {-22, 24, 39, 0, 3, 0}, {-23, 24, 40, 0, 3, 0},
    {-24, 25, 41, 0, 3, 0}, {-24, 25, 41, 0, 3, 0}, {-25, 25, 42, 0, 3, 0}, {-26, 25, 43, 0, 3, 0}, {-26, 25, 44, 0, 3, 0},
    {-27, 25, 45, 0, 3, 0}, {-28, 25, 46, 0, 3, 0}, {-29, 26, 46, 0, 3, 0}, {-29, 26, 47, 0, 3, 0}, {-30, 26, 48, 0, 3, 0},
    {-31, 26, 49, 0, 3, 0}, {-31, 26, 50, 0, 3, 0}, {-32, 26, 51, 0, 3, 0}, {-33, 26, 52, 0, 3, 0}, {-33, 26, 53, 0, 3, 0},
    {-34, 27, 53, 0, 3, 0}, {-35, 27, 54, 0, 3, 0}, {-35, 27, 55, 0, 3, 0}, {-36, 27, 56, 0, 4, 0}, {-37, 27, 57, 0, 4, 0},
    {-37, 27, 58, 0, 4, 0}, {-38, 27, 59, 0, 4, 0}, {-38, 27, 60, 0, 4, 0}, {-39, 28, 61, 0, 4, 0}, {-40, 28, 62, 0, 4, 0},
    {-40, 28, 63, 0, 4, 0}, {-41, 28, 64, 0, 4, 0}, {-42, 28, 65, 0, 4, 0}, {-42, 28, 66, 0, 4, 0}, {-43, 28, 67, 0, 4, 0},
    {-43, 29, 68, 0, 4, 0}, {-44, 29, 69, 0, 4, 0}, {-44, 29, 70, 0, 4, 0}, {-45, 29, 71, 0, 4, 0}, {-45, 29, 72, 0, 4, 0},
    {-46, 29, 73, 0, 4, 0}, {-47, 29, 74, 0, 4, 0}, {-47, 29, 75, 0, 4, 0}, {-48, 30, 76, 0, 4, 0}, {-48, 30, 77, 0, 4, 0},
    {-49, 30, 78, 0, 4, 0}, {-49, 30, 79, 0, 4, 0}, {-50, 30, 80, 0, 4, 0}, {-50, 30, 81, 0, 4, 0}, {-50, 30, 82, 0, 4, 0},
    {-51, 30, 83, 0, 4, 0}, {-51, 31, 84, 0, 4, 0}, {-52, 31, 86, 0, 4, 0}, {-52, 31, 87, 0, 4, 0}, {-53, 31, 88, 0, 4, 0},
    {-53, 31, 89, 0, 4, 0}, {-53, 31, 90, 0, 4, 0}, {-54, 31, 91, 0, 9, 0}, {-54, 32, 92, 0, 9, 0}, {-55, 32, 93, 0, 9, 0},
    {-55, 32, 94, 0, 9, 0}, {-55, 32, 96, 0, 9, 0}, {-56, 32, 97, 0, 9, 0}, {-56, 32, 98, 0, 9, 0}, {-56, 32, 99, 0, 9, 0},
    {-57, 32, 100, 0, 9, 0}, {-57, 33, 101, 0, 9, 0}, {-57, 33, 102, 0, 9, 0}, {-58, 33, 104, 0, 9, 0}, {-58, 33, 105, 0, 9, 0},
    {-58, 33, 106, 0, 9, 0}, {-58, 33, 107, 0, 9, 0}, {-59, 33, 108, 0, 9, 0}, {-59, 33, 109, 0, 9, 0}, {-59, 34, 111, 0, 9, 0},
    {-59, 34, 112, 0, 9, 0}, {-60, 34, 113, 0, 9, 0}, {-60, 34, 114, 0, 9, 0}, {-60, 34, 115, 0, 9, 0}, {-60, 34, 117, 0, 9, 0},
    {-60, 34, 118, 0, 9, 0}, {-60, 35, 119, 0, 10, 0}, {-60, 35, 120, 0, 10, 0}, {-61, 35, 121, 0, 10, 0}, {-61, 35, 123, 0, 10, 0},
    {-61, 35, 124, 0, 10, 0}, {-61, 35, 125, 0, 10, 0}, {-61, 35, 126, 0, 10, 0}, {-61, 35, 127, 0, 10, 0}, {-61, 36, 129, 0, 10, 0},
    {-61, 36, 130, 0, 10, 0}, {-61, 36, 131, 0, 10, 0}, {-61, 36, 132, 0, 10, 0}, {-61, 36, 134, 0, 10, 0}, {-60, 36, 135, 0, 10, 0},
    {-60, 36, 136, 0, 10, 0}, {-60, 36, 137, 0, 11, 0}, {-60, 37, 138, 0, 11, 0}, {-60, 37, 140, 0, 11, 0}, {-60, 37, 141, 0, 11, 0},
    {-60, 37, 142, 0, 11, 0}, {-59, 37, 143, 0, 11, 0}, {-59, 37, 144, 0, 11, 0}, {-59, 37, 145, 0, 11, 0}, {-59, 38, 147, 0, 11, 0},
    {-58, 38, 148, 0, 11, 0}, {-58, 38, 149, 0, 11, 0}, {-58, 38, 150, 0, 11, 0}, {-58, 38, 151, 0, 11, 0}, {-57, 38, 152, 0, 11, 0},
    {-57, 38, 154, 0, 11, 0}, {-56, 38, 155, 0, 11, 0}, {-56, 39, 156, 0, 12, 0}, {-56, 39, 157, 0, 12, 0}, {-55, 39, 158, 0, 12, 0},
    {-55, 39, 159, 0, 12, 0}, {-54, 39, 160, 0, 12, 0}, {-54, 39, 161, 0, 12, 0}, {-54, 39, 162, 0, 12, 0}, {-53, 40, 163, 0, 12, 0},
    {-53, 40, 165, 0, 12, 0}, {-52, 40, 166, 0, 12, 0}, {-52, 40, 167, 0, 12, 0}, {-51, 40, 168, 0, 12, 0}, {-50, 40, 169, 0, 12, 0},
    {-50, 40, 170, 0, 12, 0}, {-49, 40, 171, 0, 12, 0}, {-49, 41, 172, 0, 12, 0}, {-48, 41, 173, 0, 13, 0}, {-48, 41, 174, 0, 13, 0},
    {-47, 41, 174, 0, 13, 0}, {-46, 41, 175, 0, 13, 0}, {-46, 41, 176, 0, 13, 0}, {-45, 41, 177, 0, 13, 0}, {-44, 41, 178, 0, 13, 0},
    {-44, 42, 179, 0, 13, 0}, {-43, 42, 180, 0, 13, 0}, {-42, 42, 181, 0, 13, 0}, {-41, 42, 182, 0, 13, 0}, {-41, 42, 182, 0, 13, 0},
    {-40, 42, 183, 0, 13, 0}, {-39, 42, 184, 0, 13, 0}, {-39, 43, 185, 0, 13, 0}, {-38, 43, 186, 0, 13, 0}, {-37, 43, 186, 0, 13, 0},
    {-36, 43, 187, 0, 14, 0}, {-35, 43, 188, 0, 14, 0}, {-35, 43, 188, 0, 14, 0}, {-34, 43, 189, 0, 14, 0}, {-33, 43, 190, 0, 14, 0},
    {-32, 44, 190, 0, 14, 0}, {-31, 44, 191, 0, 14, 0}, {-30, 44, 192, 0, 14, 0}, {-30, 44, 192, 0, 14, 0}, {-29, 44, 193, 0, 14, 0},
    {-28, 44, 193, 0, 14, 0}, {-27, 44, 194, 0, 14, 0}, {-26, 44, 195, 0, 14, 0}, {-25, 45, 195, 0, 14, 0}, {-24, 45, 196, 0, 14, 0},
    {-23, 45, 196, 0, 14, 0}, {-22, 45, 196, 0, 15, 0}, {-21, 45, 197, 0, 15, 0}, {-21, 45, 197, 0, 15, 0}, {-20, 45, 198, 0, 15, 0},
    {-19, 46, 198, 0, 15, 0}, {-18, 46, 198, 0, 15, 0}, {-17, 46, 199, 0, 15, 0}, {-16, 46, 199, 0, 15, 0}, {-15, 46, 199, 0, 15, 0},
    {-14, 46, 200, 0, 15, 0}, {-13, 46, 200, 0, 15, 0}, {-12, 46, 200, 0, 15, 0}, {-11, 47, 200, 0, 15, 0}, {-10, 47, 201, 0, 15, 0},
    {-9, 47, 201, 0, 15, 0}, {-8, 47, 201, 0, 15, 0}, {-7, 47, 201, 0, 16, 0}, {-6, 47, 201, 0, 16, 0}, {-5, 47, 201, 0, 16, 0},
    {-4, 47, 202, 0, 16, 0}, {-3, 48, 202, 0, 16, 0}, {-2, 48, 202, 0, 16, 0}, {-1, 48, 202, 0, 16, 0}, {0, 48, 202, 0, 16, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightMediumHalfLoopUp1, {
    {16, 0, -1, 8, 2, 0}, {16, 1, -1, 8, 2, 0}, {16, 2, 0, 8, 2, 0}, {16, 3, 0, 8, 2, 0}, {17, 4, 1, 8, 2, 0},
    {17, 5, 1, 8, 2, 0}, {17, 6, 2, 8, 2, 0}, {17, 6, 2, 8, 2, 0}, {17, 7, 3, 8, 2, 0}, {17, 8, 3, 8, 2, 0},
    {17, 9, 4, 8, 2, 0}, {17, 10, 4, 8, 2, 0}, {18, 11, 5, 8, 2, 0}, {18, 12, 5, 8, 2, 0}, {18, 13, 6, 8, 2, 0},
    {18, 14, 6, 8, 2, 0}, {18, 14, 7, 8, 2, 0}, {18, 15, 7, 8, 2, 0}, {18, 16, 8, 8, 2, 0}, {18, 17, 9, 8, 2, 0},
    {19, 18, 9, 8, 2, 0}, {19, 19, 10, 8, 2, 0}, {19, 20, 10, 8, 2, 0}, {19, 21, 11, 8, 2, 0}, {19, 21, 11, 8, 2, 0},
    {19, 22, 12, 8, 2, 0}, {19, 23, 13, 8, 2, 0}, {20, 24, 13, 8, 2, 0}, {20, 25, 14, 8, 2, 0}, {20, 26, 14, 8, 2, 0},
    {20, 27, 15, 8, 2, 0}, {20, 28, 16, 8, 2, 0}, {20, 28, 16, 8, 2, 0}, {20, 29, 17, 8, 2, 0}, {20, 30, 17, 8, 3, 0},
    {21, 31, 18, 8, 3, 0}, {21, 32, 19, 8, 3, 0}, {21, 33, 19, 8, 3, 0}, {21, 33, 20, 8, 3, 0}, {21, 34, 21, 8, 3, 0},
    {21, 35, 21, 8, 3, 0}, {21, 36, 22, 8, 3, 0}, {21, 37, 23, 8, 3, 0}, {22, 38, 23, 8, 3, 0}, {22, 38, 24, 8, 3, 0},
    {22, 39, 25, 8, 3, 0}, {22, 40, 25, 8, 3, 0}, {22, 41, 26, 8, 3, 0}, {22, 42, 27, 8, 3, 0}, {22, 43, 28, 8, 3, 0},
    {23, 43, 28, 8, 3, 0}, {23, 44, 29, 8, 3, 0}, {23, 45, 30, 8, 3, 0}, {23, 46, 30, 8, 3, 0}, {23, 46, 31, 8, 3, 0},
    {23, 47, 32, 8, 3, 0}, {23, 48, 33, 8, 3, 0}, {23, 49, 33, 8, 3, 0}, {24, 50, 34, 8, 3, 0}, {24, 50, 35, 8, 3, 0},
    {24, 51, 36, 8, 3, 0}, {24, 52, 37, 8, 3, 0}, {24, 53, 37, 8, 3, 0}, {24, 53, 38, 8, 3, 0}, {24, 54, 39, 8, 3, 0},
    {24, 55, 40, 8, 3, 0}, {25, 56, 41, 8, 3, 0}, {25, 56, 41, 8, 3, 0}, {25, 57, 42, 8, 3, 0}, {25, 58, 43, 8, 3, 0},
    {25, 58, 44, 8, 3, 0}, {25, 59, 45, 8, 3, 0}, {25, 60, 46, 8, 3, 0}, {26, 61, 46, 8, 3, 0}, {26, 61, 47, 8, 3, 0},
    {26, 62, 48, 8, 3, 0}, {26, 63, 49, 8, 3, 0}, {26, 63, 50, 8, 3, 0}, {26, 64, 51, 8, 3, 0}, {26, 65, 52, 8, 3, 0},
    {26, 65, 53, 8, 3, 0}, {27, 66, 53, 8, 3, 0}, {27, 67, 54, 8, 3, 0}, {27, 67, 55, 8, 3, 0}, {27, 68, 56, 8, 4, 0},
    {27, 69, 57, 8, 4, 0}, {27, 69, 58, 8, 4, 0}, {27, 70, 59, 8, 4, 0}, {27, 70, 60, 8, 4, 0}, {28, 71, 61, 8, 4, 0},
    {28, 72, 62, 8, 4, 0}, {28, 72, 63, 8, 4, 0}, {28, 73, 64, 8, 4, 0}, {28, 74, 65, 8, 4, 0}, {28, 74, 66, 8, 4, 0},
    {28, 75, 67, 8, 4, 0}, {29, 75, 68, 8, 4, 0}, {29, 76, 69, 8, 4, 0}, {29, 76, 70, 8, 4, 0}, {29, 77, 71, 8, 4, 0},
    {29, 77, 72, 8, 4, 0}, {29, 78, 73, 8, 4, 0}, {29, 79, 74, 8, 4, 0}, {29, 79, 75, 8, 4, 0}, {30, 80, 76, 8, 4, 0},
    {30, 80, 77, 8, 4, 0}, {30, 81, 78, 8, 4, 0}, {30, 81, 79, 8, 4, 0}, {30, 82, 80, 8, 4, 0}, {30, 82, 81, 8, 4, 0},
    {30, 82, 82, 8, 4, 0}, {30, 83, 83, 8, 4, 0}, {31, 83, 84, 8, 4, 0}, {31, 84, 86, 8, 4, 0}, {31, 84, 87, 8, 4, 0},
    {31, 85, 88, 8, 4, 0}, {31, 85, 89, 8, 4, 0}, {31, 85, 90, 8, 4, 0}, {31, 86, 91, 8, 9, 0}, {32, 86, 92, 8, 9, 0},
    {32, 87, 93, 8, 9, 0}, {32, 87, 94, 8, 9, 0}, {32, 87, 96, 8, 9, 0}, {32, 88, 97, 8, 9, 0}, {32, 88, 98, 8, 9, 0},
    {32, 88, 99, 8, 9, 0}, {32, 89, 100, 8, 9, 0}, {33, 89, 101, 8, 9, 0}, {33, 89, 102, 8, 9, 0}, {33, 90, 104, 8, 9, 0},
    {33, 90, 105, 8, 9, 0}, {33, 90, 106, 8, 9, 0}, {33, 90, 107, 8, 9, 0}, {33, 91, 108, 8, 9, 0}, {33, 91, 109, 8, 9, 0},
    {34, 91, 111, 8, 9, 0}, {34, 91, 112, 8, 9, 0}, {34, 92, 113, 8, 9, 0}, {34, 92, 114, 8, 9, 0}, {34, 92, 115, 8, 9, 0},
    {34, 92, 117, 8, 9, 0}, {34, 92, 118, 8, 9, 0}, {35, 92, 119, 8, 10, 0}, {35, 92, 120, 8, 10, 0}, {35, 93, 121, 8, 10, 0},
    {35, 93, 123, 8, 10, 0}, {35, 93, 124, 8, 10, 0}, {35, 93, 125, 8, 10, 0}, {35, 93, 126, 8, 10, 0}, {35, 93, 127, 8, 10, 0},
    {36, 93, 129, 8, 10, 0}, {36, 93, 130, 8, 10, 0}, {36, 93, 131, 8, 10, 0}, {36, 93, 132, 8, 10, 0}, {36, 93, 134, 8, 10, 0},
    {36, 92, 135, 8, 10, 0}, {36, 92, 136, 8, 10, 0}, {36, 92, 137, 8, 11, 0}, {37, 92, 138, 8, 11, 0}, {37, 92, 140, 8, 11, 0},
    {37, 92, 141, 8, 11, 0}, {37, 92, 142, 8, 11, 0}, {37, 91, 143, 8, 11, 0}, {37, 91, 144, 8, 11, 0}, {37, 91, 145, 8, 11, 0},
    {38, 91, 147, 8, 11, 0}, {38, 90, 148, 8, 11, 0}, {38, 90, 149, 8, 11, 0}, {38, 90, 150, 8, 11, 0}, {38, 90, 151, 8, 11, 0},
    {38, 89, 152, 8, 11, 0}, {38, 89, 154, 8, 11, 0}, {38, 88, 155, 8, 11, 0}, {39, 88, 156, 8, 12, 0}, {39, 88, 157, 8, 12, 0},
    {39, 87, 158, 8, 12, 0}, {39, 87, 159, 8, 12, 0}, {39, 86, 160, 8, 12, 0}, {39, 86, 161, 8, 12, 0}, {39, 86, 162, 8, 12, 0},
    {40, 85, 163, 8, 12, 0}, {40, 85, 165, 8, 12, 0}, {40, 84, 166, 8, 12, 0}, {40, 84, 167, 8, 12, 0}, {40, 83, 168, 8, 12, 0},
    {40, 82, 169, 8, 12, 0}, {40, 82, 170, 8, 12, 0}, {40, 81, 171, 8, 12, 0}, {41, 81, 172, 8, 12, 0}, {41, 80, 173, 8, 13, 0},
    {41, 80, 174, 8, 13, 0}, {41, 79, 174, 8, 13, 0}, {41, 78, 175, 8, 13, 0}, {41, 78, 176, 8, 13, 0}, {41, 77, 177, 8, 13, 0},
    {41, 76, 178, 8, 13, 0}, {42, 76, 179, 8, 13, 0}, {42, 75, 180, 8, 13, 0}, {42, 74, 181, 8, 13, 0}, {42, 73, 182, 8, 13, 0},
    {42, 73, 182, 8, 13, 0}, {42, 72, 183, 8, 13, 0}, {42, 71, 184, 8, 13, 0}, {43, 71, 185, 8, 13, 0}, {43, 70, 186, 8, 13, 0},
    {43, 69, 186, 8, 13, 0}, {43, 68, 187, 8, 14, 0}, {43, 67, 188, 8, 14, 0}, {43, 67, 188, 8, 14, 0}, {43, 66, 189, 8, 14, 0},
    {43, 65, 190, 8, 14, 0}, {44, 64, 190, 8, 14, 0}, {44, 63, 191, 8, 14, 0}, {44, 62, 192, 8, 14, 0}, {44, 62, 192, 8, 14, 0},
    {44, 61, 193, 8, 14, 0}, {44, 60, 193, 8, 14, 0}, {44, 59, 194, 8, 14, 0}, {44, 58, 195, 8, 14, 0}, {45, 57, 195, 8, 14, 0},
    {45, 56, 196, 8, 14, 0}, {45, 55, 196, 8, 14, 0}, {45, 54, 196, 8, 15, 0}, {45, 53, 197, 8, 15, 0}, {45, 53, 197, 8, 15, 0},
    {45, 52, 198, 8, 15, 0}, {46, 51, 198, 8, 15, 0}, {46, 50, 198, 8, 15, 0}, {46, 49, 199, 8, 15, 0}, {46, 48, 199, 8, 15, 0},
    {46, 47, 199, 8, 15, 0}, {46, 46, 200, 8, 15, 0}, {46, 45, 200, 8, 15, 0}, {46, 44, 200, 8, 15, 0}, {47, 43, 200, 8, 15, 0},
    {47, 42, 201, 8, 15, 0}, {47, 41, 201, 8, 15, 0}, {47, 40, 201, 8, 15, 0}, {47, 39, 201, 8, 16, 0}, {47, 38, 201, 8, 16, 0},
    {47, 37, 201, 8, 16, 0}, {47, 36, 202, 8, 16, 0}, {48, 35, 202, 8, 16, 0}, {48, 34, 202, 8, 16, 0}, {48, 33, 202, 8, 16, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightMediumHalfLoopUp2, {
    {0, 16, -1, 16, 2, 0}, {1, 16, -1, 16, 2, 0}, {2, 16, 0, 16, 2, 0}, {3, 16, 0, 16, 2, 0}, {4, 15, 1, 16, 2, 0},
    {5, 15, 1, 16, 2, 0}, {6, 15, 2, 16, 2, 0}, {6, 15, 2, 16, 2, 0}, {7, 15, 3, 16, 2, 0}, {8, 15, 3, 16, 2, 0},
    {9, 15, 4, 16, 2, 0}, {10, 15, 4, 16, 2, 0}, {11, 14, 5, 16, 2, 0}, {12, 14, 5, 16, 2, 0}, {13, 14, 6, 16, 2, 0},
    {14, 14, 6, 16, 2, 0}, {14, 14, 7, 16, 2, 0}, {15, 14, 7, 16, 2, 0}, {16, 14, 8, 16, 2, 0}, {17, 14, 9, 16, 2, 0},
    {18, 13, 9, 16, 2, 0}, {19, 13, 10, 16, 2, 0}, {20, 13, 10, 16, 2, 0}, {21, 13, 11, 16, 2, 0}, {21, 13, 11, 16, 2, 0},
    {22, 13, 12, 16, 2, 0}, {23, 13, 13, 16, 2, 0}, {24, 12, 13, 16, 2, 0}, {25, 12, 14, 16, 2, 0}, {26, 12, 14, 16, 2, 0},
    {27, 12, 15, 16, 2, 0}, {28, 12, 16, 16, 2, 0}, {28, 12, 16, 16, 2, 0}, {29, 12, 17, 16, 2, 0}, {30, 12, 17, 16, 3, 0},
    {31, 11, 18, 16, 3, 0}, {32, 11, 19, 16, 3, 0}, {33, 11, 19, 16, 3, 0}, {33, 11, 20, 16, 3, 0}, {34, 11, 21, 16, 3, 0},
    {35, 11, 21, 16, 3, 0}, {36, 11, 22, 16, 3, 0}, {37, 11, 23, 16, 3, 0}, {38, 10, 23, 16, 3, 0}, {38, 10, 24, 16, 3, 0},
    {39, 10, 25, 16, 3, 0}, {40, 10, 25, 16, 3, 0}, {41, 10, 26, 16, 3, 0}, {42, 10, 27, 16, 3, 0}, {43, 10, 28, 16, 3, 0},
    {43, 9, 28, 16, 3, 0}, {44, 9, 29, 16, 3, 0}, {45, 9, 30, 16, 3, 0}, {46, 9, 30, 16, 3, 0}, {46, 9, 31, 16, 3, 0},
    {47, 9, 32, 16, 3, 0}, {48, 9, 33, 16, 3, 0}, {49, 9, 33, 16, 3, 0}, {50, 8, 34, 16, 3, 0}, {50, 8, 35, 16, 3, 0},
    {51, 8, 36, 16, 3, 0}, {52, 8, 37, 16, 3, 0}, {53, 8, 37, 16, 3, 0}, {53, 8, 38, 16, 3, 0}, {54, 8, 39, 16, 3, 0},
    {55, 8, 40, 16, 3, 0}, {56, 7, 41, 16, 3, 0}, {56, 7, 41, 16, 3, 0}, {57, 7, 42, 16, 3, 0}, {58, 7, 43, 16, 3, 0},
    {58, 7, 44, 16, 3, 0}, {59, 7, 45, 16, 3, 0}, {60, 7, 46, 16, 3, 0}, {61, 6, 46, 16, 3, 0}, {61, 6, 47, 16, 3, 0},
    {62, 6, 48, 16, 3, 0}, {63, 6, 49, 16, 3, 0}, {63, 6, 50, 16, 3, 0}, {64, 6, 51, 16, 3, 0}, {65, 6, 52, 16, 3, 0},
    {65, 6, 53, 16, 3, 0}, {66, 5, 53, 16, 3, 0}, {67, 5, 54, 16, 3, 0}, {67, 5, 55, 16, 3, 0}, {68, 5, 56, 16, 4, 0},
    {69, 5, 57, 16, 4, 0}, {69, 5, 58, 16, 4, 0}, {70, 5, 59, 16, 4, 0}, {70, 5, 60, 16, 4, 0}, {71, 4, 61, 16, 4, 0},
    {72, 4, 62, 16, 4, 0}, {72, 4, 63, 16, 4, 0}, {73, 4, 64, 16, 4, 0}, {74, 4, 65, 16, 4, 0}, {74, 4, 66, 16, 4, 0},
    {75, 4, 67, 16, 4, 0}, {75, 3, 68, 16, 4, 0}, {76, 3, 69, 16, 4, 0}, {76, 3, 70, 16, 4, 0}, {77, 3, 71, 16, 4, 0},
    {77, 3, 72, 16, 4, 0}, {78, 3, 73, 16, 4, 0}, {79, 3, 74, 16, 4, 0}, {79, 3, 75, 16, 4, 0}, {80, 2, 76, 16, 4, 0},
    {80, 2, 77, 16, 4, 0}, {81, 2, 78, 16, 4, 0}, {81, 2, 79, 16, 4, 0}, {82, 2, 80, 16, 4, 0}, {82, 2, 81, 16, 4, 0},
    {82, 2, 82, 16, 4, 0}, {83, 2, 83, 16, 4, 0}, {83, 1, 84, 16, 4, 0}, {84, 1, 86, 16, 4, 0}, {84, 1, 87, 16, 4, 0},
    {85, 1, 88, 16, 4, 0}, {85, 1, 89, 16, 4, 0}, {85, 1, 90, 16, 4, 0}, {86, 1, 91, 16, 9, 0}, {86, 0, 92, 16, 9, 0},
    {87, 0, 93, 16, 9, 0}, {87, 0, 94, 16, 9, 0}, {87, 0, 96, 16, 9, 0}, {88, 0, 97, 16, 9, 0}, {88, 0, 98, 16, 9, 0},
    {88, 0, 99, 16, 9, 0}, {89, 0, 100, 16, 9, 0}, {89, -1, 101, 16, 9, 0}, {89, -1, 102, 16, 9, 0}, {90, -1, 104, 16, 9, 0},
    {90, -1, 105, 16, 9, 0}, {90, -1, 106, 16, 9, 0}, {90, -1, 107, 16, 9, 0}, {91, -1, 108, 16, 9, 0}, {91, -1, 109, 16, 9, 0},
    {91, -2, 111, 16, 9, 0}, {91, -2, 112, 16, 9, 0}, {92, -2, 113, 16, 9, 0}, {92, -2, 114, 16, 9, 0}, {92, -2, 115, 16, 9, 0},
    {92, -2, 117, 16, 9, 0}, {92, -2, 118, 16, 9, 0}, {92, -3, 119, 16, 10, 0}, {92, -3, 120, 16, 10, 0}, {93, -3, 121, 16, 10, 0},
    {93, -3, 123, 16, 10, 0}, {93, -3, 124, 16, 10, 0}, {93, -3, 125, 16, 10, 0}, {93, -3, 126, 16, 10, 0}, {93, -3, 127, 16, 10, 0},
    {93, -4, 129, 16, 10, 0}, {93, -4, 130, 16, 10, 0}, {93, -4, 131, 16, 10, 0}, {93, -4, 132, 16, 10, 0}, {93, -4, 134, 16, 10, 0},
    {92, -4, 135, 16, 10, 0}, {92, -4, 136, 16, 10, 0}, {92, -4, 137, 16, 11, 0}, {92, -5, 138, 16, 11, 0}, {92, -5, 140, 16, 11, 0},
    {92, -5, 141, 16, 11, 0}, {92, -5, 142, 16, 11, 0}, {91, -5, 143, 16, 11, 0}, {91, -5, 144, 16, 11, 0}, {91, -5, 145, 16, 11, 0},
    {91, -6, 147, 16, 11, 0}, {90, -6, 148, 16, 11, 0}, {90, -6, 149, 16, 11, 0}, {90, -6, 150, 16, 11, 0}, {90, -6, 151, 16, 11, 0},
    {89, -6, 152, 16, 11, 0}, {89, -6, 154, 16, 11, 0}, {88, -6, 155, 16, 11, 0}, {88, -7, 156, 16, 12, 0}, {88, -7, 157, 16, 12, 0},
    {87, -7, 158, 16, 12, 0}, {87, -7, 159, 16, 12, 0}, {86, -7, 160, 16, 12, 0}, {86, -7, 161, 16, 12, 0}, {86, -7, 162, 16, 12, 0},
    {85, -8, 163, 16, 12, 0}, {85, -8, 165, 16, 12, 0}, {84, -8, 166, 16, 12, 0}, {84, -8, 167, 16, 12, 0}, {83, -8, 168, 16, 12, 0},
    {82, -8, 169, 16, 12, 0}, {82, -8, 170, 16, 12, 0}, {81, -8, 171, 16, 12, 0}, {81, -9, 172, 16, 12, 0}, {80, -9, 173, 16, 13, 0},
    {80, -9, 174, 16, 13, 0}, {79, -9, 174, 16, 13, 0}, {78, -9, 175, 16, 13, 0}, {78, -9, 176, 16, 13, 0}, {77, -9, 177, 16, 13, 0},
    {76, -9, 178, 16, 13, 0}, {76, -10, 179, 16, 13, 0}, {75, -10, 180, 16, 13, 0}, {74, -10, 181, 16, 13, 0}, {73, -10, 182, 16, 13, 0},
    {73, -10, 182, 16, 13, 0}, {72, -10, 183, 16, 13, 0}, {71, -10, 184, 16, 13, 0}, {71, -11, 185, 16, 13, 0}, {70, -11, 186, 16, 13, 0},
    {69, -11, 186, 16, 13, 0}, {68, -11, 187, 16, 14, 0}, {67, -11, 188, 16, 14, 0}, {67, -11, 188, 16, 14, 0}, {66, -11, 189, 16, 14, 0},
    {65, -11, 190, 16, 14, 0}, {64, -12, 190, 16, 14, 0}, {63, -12, 191, 16, 14, 0}, {62, -12, 192, 16, 14, 0}, {62, -12, 192, 16, 14, 0},
    {61, -12, 193, 16, 14, 0}, {60, -12, 193, 16, 14, 0}, {59, -12, 194, 16, 14, 0}, {58, -12, 195, 16, 14, 0}, {57, -13, 195, 16, 14, 0},
    {56, -13, 196, 16, 14, 0}, {55, -13, 196, 16, 14, 0}, {54, -13, 196, 16, 15, 0}, {53, -13, 197, 16, 15, 0}, {53, -13, 197, 16, 15, 0},
    {52, -13, 198, 16, 15, 0}, {51, -14, 198, 16, 15, 0}, {50, -14, 198, 16, 15, 0}, {49, -14, 199, 16, 15, 0}, {48, -14, 199, 16, 15, 0},
    {47, -14, 199, 16, 15, 0}, {46, -14, 200, 16, 15, 0}, {45, -14, 200, 16, 15, 0}, {44, -14, 200, 16, 15, 0}, {43, -15, 200, 16, 15, 0},
    {42, -15, 201, 16, 15, 0}, {41, -15, 201, 16, 15, 0}, {40, -15, 201, 16, 15, 0}, {39, -15, 201, 16, 16, 0}, {38, -15, 201, 16, 16, 0},
    {37, -15, 201, 16, 16, 0}, {36, -15, 202, 16, 16, 0}, {35, -16, 202, 16, 16, 0}, {34, -16, 202, 16, 16, 0}, {33, -16, 202, 16, 16, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightMediumHalfLoopUp3, {
    {16, 31, -1, 24, 2, 0}, {16, 30, 0, 24, 2, 0}, {16, 29, 0, 24, 2, 0}, {15, 28, 1, 24, 2, 0}, {15, 27, 1, 24, 2, 0},
    {15, 26, 2, 24, 2, 0}, {15, 26, 2, 24, 2, 0}, {15, 25, 3, 24, 2, 0}, {15, 24, 3, 24, 2, 0}, {15, 23, 4, 24, 2, 0},
    {15, 22, 4, 24, 2, 0}, {14, 21, 5, 24, 2, 0}, {14, 20, 5, 24, 2, 0}, {14, 19, 6, 24, 2, 0}, {14, 18, 6, 24, 2, 0},
    {14, 18, 7, 24, 2, 0}, {14, 17, 7, 24, 2, 0}, {14, 16, 8, 24, 2, 0}, {14, 15, 9, 24, 2, 0}, {13, 14, 9, 24, 2, 0},
    {13, 13, 10, 24, 2, 0}, {13, 12, 10, 24, 2, 0}, {13, 11, 11, 24, 2, 0}, {13, 11, 11, 24, 2, 0}, {13, 10, 12, 24, 2, 0},
    {13, 9, 13, 24, 2, 0}, {12, 8, 13, 24, 2, 0}, {12, 7, 14, 24, 2, 0}, {12, 6, 14, 24, 2, 0}, {12, 5, 15, 24, 2, 0},
    {12, 4, 16, 24, 2, 0}, {12, 4, 16, 24, 2, 0}, {12, 3, 17, 24, 2, 0}, {12, 2, 17, 24, 3, 0}, {11, 1, 18, 24, 3, 0},
    {11, 0, 19, 24, 3, 0}, {11, -1, 19, 24, 3, 0}, {11, -1, 20, 24, 3, 0}, {11, -2, 21, 24, 3, 0}, {11, -3, 21, 24, 3, 0},
    {11, -4, 22, 24, 3, 0}, {11, -5, 23, 24, 3, 0}, {10, -6, 23, 24, 3, 0}, {10, -6, 24, 24, 3, 0}, {10, -7, 25, 24, 3, 0},
    {10, -8, 25, 24, 3, 0}, {10, -9, 26, 24, 3, 0}, {10, -10, 27, 24, 3, 0}, {10, -11, 28, 24, 3, 0}, {9, -11, 28, 24, 3, 0},
    {9, -12, 29, 24, 3, 0}, {9, -13, 30, 24, 3, 0}, {9, -14, 30, 24, 3, 0}, {9, -14, 31, 24, 3, 0}, {9, -15, 32, 24, 3, 0},
    {9, -16, 33, 24, 3, 0}, {9, -17, 33, 24, 3, 0}, {8, -18, 34, 24, 3, 0}, {8, -18, 35, 24, 3, 0}, {8, -19, 36, 24, 3, 0},
    {8, -20, 37, 24, 3, 0}, {8, -21, 37, 24, 3, 0}, {8, -21, 38, 24, 3, 0}, {8, -22, 39, 24, 3, 0}, {8, -23, 40, 24, 3, 0},
    {7, -24, 41, 24, 3, 0}, {7, -24, 41, 24, 3, 0}, {7, -25, 42, 24, 3, 0}, {7, -26, 43, 24, 3, 0}, {7, -26, 44, 24, 3, 0},
    {7, -27, 45, 24, 3, 0}, {7, -28, 46, 24, 3, 0}, {6, -29, 46, 24, 3, 0}, {6, -29, 47, 24, 3, 0}, {6, -30, 48, 24, 3, 0},
    {6, -31, 49, 24, 3, 0}, {6, -31, 50, 24, 3, 0}, {6, -32, 51, 24, 3, 0}, {6, -33, 52, 24, 3, 0}, {6, -33, 53, 24, 3, 0},
    {5, -34, 53, 24, 3, 0}, {5, -35, 54, 24, 3, 0}, {5, -35, 55, 24, 3, 0}, {5, -36, 56, 24, 4, 0}, {5, -37, 57, 24, 4, 0},
    {5, -37, 58, 24, 4, 0}, {5, -38, 59, 24, 4, 0}, {5, -38, 60, 24, 4, 0}, {4, -39, 61, 24, 4, 0}, {4, -40, 62, 24, 4, 0},
    {4, -40, 63, 24, 4, 0}, {4, -41, 64, 24, 4, 0}, {4, -42, 65, 24, 4, 0}, {4, -42, 66, 24, 4, 0}, {4, -43, 67, 24, 4, 0},
    {3, -43, 68, 24, 4, 0}, {3, -44, 69, 24, 4, 0}, {3, -44, 70, 24, 4, 0}, {3, -45, 71, 24, 4, 0}, {3, -45, 72, 24, 4, 0},
    {3, -46, 73, 24, 4, 0}, {3, -47, 74, 24, 4, 0}, {3, -47, 75, 24, 4, 0}, {2, -48, 76, 24, 4, 0}, {2, -48, 77, 24, 4, 0},
    {2, -49, 78, 24, 4, 0}, {2, -49, 79, 24, 4, 0}, {2, -50, 80, 24, 4, 0}, {2, -50, 81, 24, 4, 0}, {2, -50, 82, 24, 4, 0},
    {2, -51, 83, 24, 4, 0}, {1, -51, 84, 24, 4, 0}, {1, -52, 86, 24, 4, 0}, {1, -52, 87, 24, 4, 0}, {1, -53, 88, 24, 4, 0},
    {1, -53, 89, 24, 4, 0}, {1, -53, 90, 24, 4, 0}, {1, -54, 91, 24, 9, 0}, {0, -54, 92, 24, 9, 0}, {0, -55, 93, 24, 9, 0},
    {0, -55, 94, 24, 9, 0}, {0, -55, 96, 24, 9, 0}, {0, -56, 97, 24, 9, 0}, {0, -56, 98, 24, 9, 0}, {0, -56, 99, 24, 9, 0},
    {0, -57, 100, 24, 9, 0}, {-1, -57, 101, 24, 9, 0}, {-1, -57, 102, 24, 9, 0}, {-1, -58, 104, 24, 9, 0}, {-1, -58, 105, 24, 9, 0},
    {-1, -58, 106, 24, 9, 0}, {-1, -58, 107, 24, 9, 0}, {-1, -59, 108, 24, 9, 0}, {-1, -59, 109, 24, 9, 0}, {-2, -59, 111, 24, 9, 0},
    {-2, -59, 112, 24, 9, 0}, {-2, -60, 113, 24, 9, 0}, {-2, -60, 114, 24, 9, 0}, {-2, -60, 115, 24, 9, 0}, {-2, -60, 117, 24, 9, 0},
    {-2, -60, 118, 24, 9, 0}, {-3, -60, 119, 24, 10, 0}, {-3, -60, 120, 24, 10, 0}, {-3, -61, 121, 24, 10, 0}, {-3, -61, 123, 24, 10, 0},
    {-3, -61, 124, 24, 10, 0}, {-3, -61, 125, 24, 10, 0}, {-3, -61, 126, 24, 10, 0}, {-3, -61, 127, 24, 10, 0}, {-4, -61, 129, 24, 10, 0},
    {-4, -61, 130, 24, 10, 0}, {-4, -61, 131, 24, 10, 0}, {-4, -61, 132, 24, 10, 0}, {-4, -61, 134, 24, 10, 0}, {-4, -60, 135, 24, 10, 0},
    {-4, -60, 136, 24, 10, 0}, {-4, -60, 137, 24, 11, 0}, {-5, -60, 138, 24, 11, 0}, {-5, -60, 140, 24, 11, 0}, {-5, -60, 141, 24, 11, 0},
    {-5, -60, 142, 24, 11, 0}, {-5, -59, 143, 24, 11, 0}, {-5, -59, 144, 24, 11, 0}, {-5, -59, 145, 24, 11, 0}, {-6, -59, 147, 24, 11, 0},
    {-6, -58, 148, 24, 11, 0}, {-6, -58, 149, 24, 11, 0}, {-6, -58, 150, 24, 11, 0}, {-6, -58, 151, 24, 11, 0}, {-6, -57, 152, 24, 11, 0},
    {-6, -57, 154, 24, 11, 0}, {-6, -56, 155, 24, 11, 0}, {-7, -56, 156, 24, 12, 0}, {-7, -56, 157, 24, 12, 0}, {-7, -55, 158, 24, 12, 0},
    {-7, -55, 159, 24, 12, 0}, {-7, -54, 160, 24, 12, 0}, {-7, -54, 161, 24, 12, 0}, {-7, -54, 162, 24, 12, 0}, {-8, -53, 163, 24, 12, 0},
    {-8, -53, 165, 24, 12, 0}, {-8, -52, 166, 24, 12, 0}, {-8, -52, 167, 24, 12, 0}, {-8, -51, 168, 24, 12, 0}, {-8, -50, 169, 24, 12, 0},
    {-8, -50, 170, 24, 12, 0}, {-8, -49, 171, 24, 12, 0}, {-9, -49, 172, 24, 12, 0}, {-9, -48, 173, 24, 13, 0}, {-9, -48, 174, 24, 13, 0},
    {-9, -47, 174, 24, 13, 0}, {-9, -46, 175, 24, 13, 0}, {-9, -46, 176, 24, 13, 0}, {-9, -45, 177, 24, 13, 0}, {-9, -44, 178, 24, 13, 0},
    {-10, -44, 179, 24, 13, 0}, {-10, -43, 180, 24, 13, 0}, {-10, -42, 181, 24, 13, 0}, {-10, -41, 182, 24, 13, 0}, {-10, -41, 182, 24, 13, 0},
    {-10, -40, 183, 24, 13, 0}, {-10, -39, 184, 24, 13, 0}, {-11, -39, 185, 24, 13, 0}, {-11, -38, 186, 24, 13, 0}, {-11, -37, 186, 24, 13, 0},
    {-11, -36, 187, 24, 14, 0}, {-11, -35, 188, 24, 14, 0}, {-11, -35, 188, 24, 14, 0}, {-11, -34, 189, 24, 14, 0}, {-11, -33, 190, 24, 14, 0},
    {-12, -32, 190, 24, 14, 0}, {-12, -31, 191, 24, 14, 0}, {-12, -30, 192, 24, 14, 0}, {-12, -30, 192, 24, 14, 0}, {-12, -29, 193, 24, 14, 0},
    {-12, -28, 193, 24, 14, 0}, {-12, -27, 194, 24, 14, 0}, {-12, -26, 195, 24, 14, 0}, {-13, -25, 195, 24, 14, 0}, {-13, -24, 196, 24, 14, 0},
    {-13, -23, 196, 24, 14, 0}, {-13, -22, 196, 24, 15, 0}, {-13, -21, 197, 24, 15, 0}, {-13, -21, 197, 24, 15, 0}, {-13, -20, 198, 24, 15, 0},
    {-14, -19, 198, 24, 15, 0}, {-14, -18, 198, 24, 15, 0}, {-14, -17, 199, 24, 15, 0}, {-14, -16, 199, 24, 15, 0}, {-14, -15, 199, 24, 15, 0},
    {-14, -14, 200, 24, 15, 0}, {-14, -13, 200, 24, 15, 0}, {-14, -12, 200, 24, 15, 0}, {-15, -11, 200, 24, 15, 0}, {-15, -10, 201, 24, 15, 0},
    {-15, -9, 201, 24, 15, 0}, {-15, -8, 201, 24, 15, 0}, {-15, -7, 201, 24, 16, 0}, {-15, -6, 201, 24, 16, 0}, {-15, -5, 201, 24, 16, 0},
    {-15, -4, 202, 24, 16, 0}, {-16, -3, 202, 24, 16, 0}, {-16, -2, 202, 24, 16, 0}, {-16, -1, 202, 24, 16, 0}, {-16, 0, 202, 24, 16, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftMediumHalfLoopDown0, {
    {31, 16, 35, 16, 16, 0}, {30, 16, 35, 16, 16, 0}, {29, 16, 35, 16, 16, 0}, {28, 15, 35, 16, 16, 0}, {27, 15, 35, 16, 16, 0},
    {26, 15, 35, 16, 16, 0}, {25, 15, 35, 16, 16, 0}, {24, 15, 34, 16, 23, 0}, {23, 15, 34, 16, 23, 0}, {22, 15, 34, 16, 23, 0},
    {21, 15, 34, 16, 23, 0}, {20, 14, 34, 16, 23, 0}, {19, 14, 33, 16, 23, 0}, {18, 14, 33, 16, 23, 0}, {17, 14, 33, 16, 23, 0},
    {16, 14, 32, 16, 23, 0}, {15, 14, 32, 16, 23, 0}, {14, 14, 32, 16, 23, 0}, {13, 14, 31, 16, 23, 0}, {12, 13, 31, 16, 23, 0},
    {11, 13, 31, 16, 23, 0}, {11, 13, 30, 16, 23, 0}, {10, 13, 30, 16, 23, 0}, {9, 13, 29, 16, 22, 0}, {8, 13, 29, 16, 22, 0},
    {7, 13, 28, 16, 22, 0}, {6, 12, 28, 16, 22, 0}, {5, 12, 27, 16, 22, 0}, {4, 12, 27, 16, 22, 0}, {3, 12, 26, 16, 22, 0},
    {2, 12, 26, 16, 22, 0}, {2, 12, 25, 16, 22, 0}, {1, 12, 24, 16, 22, 0}, {0, 12, 24, 16, 22, 0}, {-1, 11, 23, 16, 22, 0},
    {-2, 11, 22, 16, 22, 0}, {-3, 11, 22, 16, 22, 0}, {-3, 11, 21, 16, 22, 0}, {-4, 11, 20, 16, 22, 0}, {-5, 11, 20, 16, 21, 0},
    {-6, 11, 19, 16, 21, 0}, {-7, 11, 18, 16, 21, 0}, {-7, 10, 17, 16, 21, 0}, {-8, 10, 17, 16, 21, 0}, {-9, 10, 16, 16, 21, 0},
    {-9, 10, 15, 16, 21, 0}, {-10, 10, 14, 16, 21, 0}, {-11, 10, 13, 16, 21, 0}, {-12, 10, 12, 16, 21, 0}, {-12, 9, 11, 16, 21, 0},
    {-13, 9, 11, 16, 21, 0}, {-14, 9, 10, 16, 21, 0}, {-14, 9, 9, 16, 21, 0}, {-15, 9, 8, 16, 21, 0}, {-16, 9, 7, 16, 21, 0},
    {-16, 9, 6, 16, 21, 0}, {-17, 9, 5, 16, 20, 0}, {-17, 8, 4, 16, 20, 0}, {-18, 8, 3, 16, 20, 0}, {-18, 8, 2, 16, 20, 0},
    {-19, 8, 1, 16, 20, 0}, {-20, 8, 0, 16, 20, 0}, {-20, 8, -1, 16, 20, 0}, {-21, 8, -2, 16, 20, 0}, {-21, 8, -3, 16, 20, 0},
    {-22, 7, -4, 16, 20, 0}, {-22, 7, -5, 16, 20, 0}, {-22, 7, -6, 16, 20, 0}, {-23, 7, -8, 16, 20, 0}, {-23, 7, -9, 16, 20, 0},
    {-24, 7, -10, 16, 20, 0}, {-24, 7, -11, 16, 20, 0}, {-24, 6, -12, 16, 19, 0}, {-25, 6, -13, 16, 19, 0}, {-25, 6, -14, 16, 19, 0},
    {-26, 6, -15, 16, 19, 0}, {-26, 6, -17, 16, 19, 0}, {-26, 6, -18, 16, 19, 0}, {-26, 6, -19, 16, 19, 0}, {-27, 6, -20, 16, 19, 0},
    {-27, 5, -21, 16, 19, 0}, {-27, 5, -22, 16, 19, 0}, {-27, 5, -24, 16, 19, 0}, {-28, 5, -25, 16, 19, 0}, {-28, 5, -26, 16, 19, 0},
    {-28, 5, -27, 16, 19, 0}, {-28, 5, -28, 16, 19, 0}, {-28, 4, -30, 16, 19, 0}, {-28, 4, -31, 16, 18, 0}, {-28, 4, -32, 16, 18, 0},
    {-29, 4, -33, 16, 18, 0}, {-29, 4, -34, 16, 18, 0}, {-29, 4, -36, 16, 18, 0}, {-29, 4, -37, 16, 18, 0}, {-29, 4, -38, 16, 18, 0},
    {-29, 3, -39, 16, 18, 0}, {-29, 3, -40, 16, 18, 0}, {-29, 3, -42, 16, 18, 0}, {-29, 3, -43, 16, 18, 0}, {-29, 3, -44, 16, 18, 0},
    {-29, 3, -45, 16, 18, 0}, {-28, 3, -46, 16, 18, 0}, {-28, 3, -48, 16, 18, 0}, {-28, 2, -49, 16, 17, 0}, {-28, 2, -50, 16, 17, 0},
    {-28, 2, -51, 16, 17, 0}, {-28, 2, -52, 16, 17, 0}, {-28, 2, -54, 16, 17, 0}, {-27, 2, -55, 16, 17, 0}, {-27, 2, -56, 16, 17, 0},
    {-27, 1, -57, 16, 17, 0}, {-27, 1, -58, 16, 17, 0}, {-26, 1, -60, 16, 17, 0}, {-26, 1, -61, 16, 17, 0}, {-26, 1, -62, 16, 17, 0},
    {-26, 1, -63, 16, 17, 0}, {-25, 1, -64, 16, 17, 0}, {-25, 1, -65, 16, 17, 0}, {-25, 0, -67, 16, 17, 0}, {-24, 0, -68, 16, 17, 0},
    {-24, 0, -69, 16, 17, 0}, {-24, 0, -70, 16, 17, 0}, {-23, 0, -71, 16, 17, 0}, {-23, 0, -72, 16, 17, 0}, {-23, 0, -73, 16, 17, 0},
    {-22, 0, -75, 16, 17, 0}, {-22, -1, -76, 16, 17, 0}, {-21, -1, -77, 16, 8, 0}, {-21, -1, -78, 16, 8, 0}, {-21, -1, -79, 16, 8, 0},
    {-20, -1, -80, 16, 8, 0}, {-20, -1, -81, 16, 8, 0}, {-19, -1, -82, 16, 8, 0}, {-19, -2, -83, 16, 8, 0}, {-18, -2, -84, 16, 8, 0},
    {-18, -2, -85, 16, 8, 0}, {-18, -2, -87, 16, 8, 0}, {-17, -2, -88, 16, 8, 0}, {-17, -2, -89, 16, 8, 0}, {-16, -2, -90, 16, 8, 0},
    {-16, -2, -91, 16, 8, 0}, {-15, -3, -92, 16, 8, 0}, {-15, -3, -93, 16, 8, 0}, {-14, -3, -94, 16, 8, 0}, {-13, -3, -95, 16, 8, 0},
    {-13, -3, -96, 16, 8, 0}, {-12, -3, -97, 16, 8, 0}, {-12, -3, -98, 16, 8, 0}, {-11, -3, -99, 16, 8, 0}, {-11, -4, -100, 16, 8, 0},
    {-10, -4, -101, 16, 8, 0}, {-10, -4, -102, 16, 8, 0}, {-9, -4, -103, 16, 8, 0}, {-8, -4, -104, 16, 8, 0}, {-8, -4, -105, 16, 8, 0},
    {-7, -4, -106, 16, 8, 0}, {-6, -5, -107, 16, 8, 0}, {-6, -5, -108, 16, 8, 0}, {-5, -5, -109, 16, 8, 0}, {-5, -5, -110, 16, 8, 0},
    {-4, -5, -110, 16, 8, 0}, {-3, -5, -111, 16, 7, 0}, {-3, -5, -112, 16, 7, 0}, {-2, -5, -113, 16, 7, 0}, {-1, -6, -114, 16, 7, 0},
    {-1, -6, -115, 16, 7, 0}, {0, -6, -116, 16, 7, 0}, {1, -6, -117, 16, 7, 0}, {1, -6, -118, 16, 7, 0}, {2, -6, -119, 16, 7, 0},
    {3, -6, -119, 16, 7, 0}, {3, -6, -120, 16, 7, 0}, {4, -7, -121, 16, 7, 0}, {5, -7, -122, 16, 7, 0}, {6, -7, -123, 16, 7, 0},
    {6, -7, -124, 16, 7, 0}, {7, -7, -124, 16, 7, 0}, {8, -7, -125, 16, 7, 0}, {8, -7, -126, 16, 7, 0}, {9, -8, -127, 16, 7, 0},
    {10, -8, -128, 16, 7, 0}, {11, -8, -129, 16, 7, 0}, {11, -8, -129, 16, 7, 0}, {12, -8, -130, 16, 7, 0}, {13, -8, -131, 16, 7, 0},
    {14, -8, -132, 16, 7, 0}, {14, -8, -132, 16, 7, 0}, {15, -9, -133, 16, 7, 0}, {16, -9, -134, 16, 7, 0}, {17, -9, -135, 16, 7, 0},
    {18, -9, -135, 16, 7, 0}, {18, -9, -136, 16, 7, 0}, {19, -9, -137, 16, 7, 0}, {20, -9, -138, 16, 7, 0}, {21, -9, -138, 16, 7, 0},
    {21, -10, -139, 16, 7, 0}, {22, -10, -140, 16, 7, 0}, {23, -10, -141, 16, 7, 0}, {24, -10, -141, 16, 7, 0}, {25, -10, -142, 16, 7, 0},
    {26, -10, -143, 16, 7, 0}, {26, -10, -143, 16, 7, 0}, {27, -11, -144, 16, 7, 0}, {28, -11, -145, 16, 7, 0}, {29, -11, -145, 16, 7, 0},
    {30, -11, -146, 16, 7, 0}, {31, -11, -147, 16, 7, 0}, {31, -11, -147, 16, 7, 0}, {32, -11, -148, 16, 7, 0}, {33, -11, -149, 16, 7, 0},
    {34, -12, -149, 16, 7, 0}, {35, -12, -150, 16, 6, 0}, {36, -12, -150, 16, 6, 0}, {36, -12, -151, 16, 6, 0}, {37, -12, -152, 16, 6, 0},
    {38, -12, -152, 16, 6, 0}, {39, -12, -153, 16, 6, 0}, {40, -12, -154, 16, 6, 0}, {41, -13, -154, 16, 6, 0}, {42, -13, -155, 16, 6, 0},
    {43, -13, -155, 16, 6, 0}, {43, -13, -156, 16, 6, 0}, {44, -13, -156, 16, 6, 0}, {45, -13, -157, 16, 6, 0}, {46, -13, -158, 16, 6, 0},
    {47, -14, -158, 16, 6, 0}, {48, -14, -159, 16, 6, 0}, {49, -14, -159, 16, 6, 0}, {50, -14, -160, 16, 6, 0}, {50, -14, -160, 16, 6, 0},
    {51, -14, -161, 16, 6, 0}, {52, -14, -161, 16, 6, 0}, {53, -14, -162, 16, 6, 0}, {54, -15, -162, 16, 6, 0}, {55, -15, -163, 16, 6, 0},
    {56, -15, -163, 16, 6, 0}, {57, -15, -164, 16, 6, 0}, {58, -15, -164, 16, 6, 0}, {58, -15, -165, 16, 6, 0}, {59, -15, -165, 16, 6, 0},
    {60, -15, -166, 16, 6, 0}, {61, -16, -166, 16, 6, 0}, {62, -16, -167, 16, 6, 0}, {63, -16, -167, 16, 6, 0}, {64, -16, -168, 16, 6, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftMediumHalfLoopDown1, {
    {16, 0, 35, 24, 16, 0}, {16, 1, 35, 24, 16, 0}, {16, 2, 35, 24, 16, 0}, {16, 3, 35, 24, 16, 0}, {15, 4, 35, 24, 16, 0},
    {15, 5, 35, 24, 16, 0}, {15, 6, 35, 24, 16, 0}, {15, 7, 35, 24, 16, 0}, {15, 8, 34, 24, 23, 0}, {15, 9, 34, 24, 23, 0},
    {15, 10, 34, 24, 23, 0}, {15, 11, 34, 24, 23, 0}, {14, 12, 34, 24, 23, 0}, {14, 13, 33, 24, 23, 0}, {14, 14, 33, 24, 23, 0},
    {14, 15, 33, 24, 23, 0}, {14, 16, 32, 24, 23, 0}, {14, 17, 32, 24, 23, 0}, {14, 18, 32, 24, 23, 0}, {14, 19, 31, 24, 23, 0},
    {13, 20, 31, 24, 23, 0}, {13, 21, 31, 24, 23, 0}, {13, 21, 30, 24, 23, 0}, {13, 22, 30, 24, 23, 0}, {13, 23, 29, 24, 22, 0},
    {13, 24, 29, 24, 22, 0}, {13, 25, 28, 24, 22, 0}, {12, 26, 28, 24, 22, 0}, {12, 27, 27, 24, 22, 0}, {12, 28, 27, 24, 22, 0},
    {12, 29, 26, 24, 22, 0}, {12, 30, 26, 24, 22, 0}, {12, 30, 25, 24, 22, 0}, {12, 31, 24, 24, 22, 0}, {12, 32, 24, 24, 22, 0},
    {11, 33, 23, 24, 22, 0}, {11, 34, 22, 24, 22, 0}, {11, 35, 22, 24, 22, 0}, {11, 35, 21, 24, 22, 0}, {11, 36, 20, 24, 22, 0},
    {11, 37, 20, 24, 21, 0}, {11, 38, 19, 24, 21, 0}, {11, 39, 18, 24, 21, 0}, {10, 39, 17, 24, 21, 0}, {10, 40, 17, 24, 21, 0},
    {10, 41, 16, 24, 21, 0}, {10, 41, 15, 24, 21, 0}, {10, 42, 14, 24, 21, 0}, {10, 43, 13, 24, 21, 0}, {10, 44, 12, 24, 21, 0},
    {9, 44, 11, 24, 21, 0}, {9, 45, 11, 24, 21, 0}, {9, 46, 10, 24, 21, 0}, {9, 46, 9, 24, 21, 0}, {9, 47, 8, 24, 21, 0},
    {9, 48, 7, 24, 21, 0}, {9, 48, 6, 24, 21, 0}, {9, 49, 5, 24, 20, 0}, {8, 49, 4, 24, 20, 0}, {8, 50, 3, 24, 20, 0},
    {8, 50, 2, 24, 20, 0}, {8, 51, 1, 24, 20, 0}, {8, 52, 0, 24, 20, 0}, {8, 52, -1, 24, 20, 0}, {8, 53, -2, 24, 20, 0},
    {8, 53, -3, 24, 20, 0}, {7, 54, -4, 24, 20, 0}, {7, 54, -5, 24, 20, 0}, {7, 54, -6, 24, 20, 0}, {7, 55, -8, 24, 20, 0},
    {7, 55, -9, 24, 20, 0}, {7, 56, -10, 24, 20, 0}, {7, 56, -11, 24, 20, 0}, {6, 56, -12, 24, 19, 0}, {6, 57, -13, 24, 19, 0},
    {6, 57, -14, 24, 19, 0}, {6, 58, -15, 24, 19, 0}, {6, 58, -17, 24, 19, 0}, {6, 58, -18, 24, 19, 0}, {6, 58, -19, 24, 19, 0},
    {6, 59, -20, 24, 19, 0}, {5, 59, -21, 24, 19, 0}, {5, 59, -22, 24, 19, 0}, {5, 59, -24, 24, 19, 0}, {5, 60, -25, 24, 19, 0},
    {5, 60, -26, 24, 19, 0}, {5, 60, -27, 24, 19, 0}, {5, 60, -28, 24, 19, 0}, {4, 60, -30, 24, 19, 0}, {4, 60, -31, 24, 18, 0},
    {4, 60, -32, 24, 18, 0}, {4, 61, -33, 24, 18, 0}, {4, 61, -34, 24, 18, 0}, {4, 61, -36, 24, 18, 0}, {4, 61, -37, 24, 18, 0},
    {4, 61, -38, 24, 18, 0}, {3, 61, -39, 24, 18, 0}, {3, 61, -40, 24, 18, 0}, {3, 61, -42, 24, 18, 0}, {3, 61, -43, 24, 18, 0},
    {3, 61, -44, 24, 18, 0}, {3, 61, -45, 24, 18, 0}, {3, 60, -46, 24, 18, 0}, {3, 60, -48, 24, 18, 0}, {2, 60, -49, 24, 17, 0},
    {2, 60, -50, 24, 17, 0}, {2, 60, -51, 24, 17, 0}, {2, 60, -52, 24, 17, 0}, {2, 60, -54, 24, 17, 0}, {2, 59, -55, 24, 17, 0},
    {2, 59, -56, 24, 17, 0}, {1, 59, -57, 24, 17, 0}, {1, 59, -58, 24, 17, 0}, {1, 58, -60, 24, 17, 0}, {1, 58, -61, 24, 17, 0},
    {1, 58, -62, 24, 17, 0}, {1, 58, -63, 24, 17, 0}, {1, 57, -64, 24, 17, 0}, {1, 57, -65, 24, 17, 0}, {0, 57, -67, 24, 17, 0},
    {0, 56, -68, 24, 17, 0}, {0, 56, -69, 24, 17, 0}, {0, 56, -70, 24, 17, 0}, {0, 55, -71, 24, 17, 0}, {0, 55, -72, 24, 17, 0},
    {0, 55, -73, 24, 17, 0}, {0, 54, -75, 24, 17, 0}, {-1, 54, -76, 24, 17, 0}, {-1, 53, -77, 24, 8, 0}, {-1, 53, -78, 24, 8, 0},
    {-1, 53, -79, 24, 8, 0}, {-1, 52, -80, 24, 8, 0}, {-1, 52, -81, 24, 8, 0}, {-1, 51, -82, 24, 8, 0}, {-2, 51, -83, 24, 8, 0},
    {-2, 50, -84, 24, 8, 0}, {-2, 50, -85, 24, 8, 0}, {-2, 50, -87, 24, 8, 0}, {-2, 49, -88, 24, 8, 0}, {-2, 49, -89, 24, 8, 0},
    {-2, 48, -90, 24, 8, 0}, {-2, 48, -91, 24, 8, 0}, {-3, 47, -92, 24, 8, 0}, {-3, 47, -93, 24, 8, 0}, {-3, 46, -94, 24, 8, 0},
    {-3, 45, -95, 24, 8, 0}, {-3, 45, -96, 24, 8, 0}, {-3, 44, -97, 24, 8, 0}, {-3, 44, -98, 24, 8, 0}, {-3, 43, -99, 24, 8, 0},
    {-4, 43, -100, 24, 8, 0}, {-4, 42, -101, 24, 8, 0}, {-4, 42, -102, 24, 8, 0}, {-4, 41, -103, 24, 8, 0}, {-4, 40, -104, 24, 8, 0},
    {-4, 40, -105, 24, 8, 0}, {-4, 39, -106, 24, 8, 0}, {-5, 38, -107, 24, 8, 0}, {-5, 38, -108, 24, 8, 0}, {-5, 37, -109, 24, 8, 0},
    {-5, 37, -110, 24, 8, 0}, {-5, 36, -110, 24, 8, 0}, {-5, 35, -111, 24, 7, 0}, {-5, 35, -112, 24, 7, 0}, {-5, 34, -113, 24, 7, 0},
    {-6, 33, -114, 24, 7, 0}, {-6, 33, -115, 24, 7, 0}, {-6, 32, -116, 24, 7, 0}, {-6, 31, -117, 24, 7, 0}, {-6, 31, -118, 24, 7, 0},
    {-6, 30, -119, 24, 7, 0}, {-6, 29, -119, 24, 7, 0}, {-6, 29, -120, 24, 7, 0}, {-7, 28, -121, 24, 7, 0}, {-7, 27, -122, 24, 7, 0},
    {-7, 26, -123, 24, 7, 0}, {-7, 26, -124, 24, 7, 0}, {-7, 25, -124, 24, 7, 0}, {-7, 24, -125, 24, 7, 0}, {-7, 24, -126, 24, 7, 0},
    {-8, 23, -127, 24, 7, 0}, {-8, 22, -128, 24, 7, 0}, {-8, 21, -129, 24, 7, 0}, {-8, 21, -129, 24, 7, 0}, {-8, 20, -130, 24, 7, 0},
    {-8, 19, -131, 24, 7, 0}, {-8, 18, -132, 24, 7, 0}, {-8, 18, -132, 24, 7, 0}, {-9, 17, -133, 24, 7, 0}, {-9, 16, -134, 24, 7, 0},
    {-9, 15, -135, 24, 7, 0}, {-9, 14, -135, 24, 7, 0}, {-9, 14, -136, 24, 7, 0}, {-9, 13, -137, 24, 7, 0}, {-9, 12, -138, 24, 7, 0},
    {-9, 11, -138, 24, 7, 0}, {-10, 11, -139, 24, 7, 0}, {-10, 10, -140, 24, 7, 0}, {-10, 9, -141, 24, 7, 0}, {-10, 8, -141, 24, 7, 0},
    {-10, 7, -142, 24, 7, 0}, {-10, 6, -143, 24, 7, 0}, {-10, 6, -143, 24, 7, 0}, {-11, 5, -144, 24, 7, 0}, {-11, 4, -145, 24, 7, 0},
    {-11, 3, -145, 24, 7, 0}, {-11, 2, -146, 24, 7, 0}, {-11, 1, -147, 24, 7, 0}, {-11, 1, -147, 24, 7, 0}, {-11, 0, -148, 24, 7, 0},
    {-11, -1, -149, 24, 7, 0}, {-12, -2, -149, 24, 7, 0}, {-12, -3, -150, 24, 6, 0}, {-12, -4, -150, 24, 6, 0}, {-12, -4, -151, 24, 6, 0},
    {-12, -5, -152, 24, 6, 0}, {-12, -6, -152, 24, 6, 0}, {-12, -7, -153, 24, 6, 0}, {-12, -8, -154, 24, 6, 0}, {-13, -9, -154, 24, 6, 0},
    {-13, -10, -155, 24, 6, 0}, {-13, -11, -155, 24, 6, 0}, {-13, -11, -156, 24, 6, 0}, {-13, -12, -156, 24, 6, 0}, {-13, -13, -157, 24, 6, 0},
    {-13, -14, -158, 24, 6, 0}, {-14, -15, -158, 24, 6, 0}, {-14, -16, -159, 24, 6, 0}, {-14, -17, -159, 24, 6, 0}, {-14, -18, -160, 24, 6, 0},
    {-14, -18, -160, 24, 6, 0}, {-14, -19, -161, 24, 6, 0}, {-14, -20, -161, 24, 6, 0}, {-14, -21, -162, 24, 6, 0}, {-15, -22, -162, 24, 6, 0},
    {-15, -23, -163, 24, 6, 0}, {-15, -24, -163, 24, 6, 0}, {-15, -25, -164, 24, 6, 0}, {-15, -26, -164, 24, 6, 0}, {-15, -26, -165, 24, 6, 0},
    {-15, -27, -165, 24, 6, 0}, {-15, -28, -166, 24, 6, 0}, {-16, -29, -166, 24, 6, 0}, {-16, -30, -167, 24, 6, 0}, {-16, -31, -167, 24, 6, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftMediumHalfLoopDown2, {
    {0, 16, 35, 0, 16, 0}, {1, 16, 35, 0, 16, 0}, {2, 16, 35, 0, 16, 0}, {3, 16, 35, 0, 16, 0}, {4, 17, 35, 0, 16, 0},
    {5, 17, 35, 0, 16, 0}, {6, 17, 35, 0, 16, 0}, {7, 17, 35, 0, 16, 0}, {8, 17, 34, 0, 23, 0}, {9, 17, 34, 0, 23, 0},
    {10, 17, 34, 0, 23, 0}, {11, 17, 34, 0, 23, 0}, {12, 18, 34, 0, 23, 0}, {13, 18, 33, 0, 23, 0}, {14, 18, 33, 0, 23, 0},
    {15, 18, 33, 0, 23, 0}, {16, 18, 32, 0, 23, 0}, {17, 18, 32, 0, 23, 0}, {18, 18, 32, 0, 23, 0}, {19, 18, 31, 0, 23, 0},
    {20, 19, 31, 0, 23, 0}, {21, 19, 31, 0, 23, 0}, {21, 19, 30, 0, 23, 0}, {22, 19, 30, 0, 23, 0}, {23, 19, 29, 0, 22, 0},
    {24, 19, 29, 0, 22, 0}, {25, 19, 28, 0, 22, 0}, {26, 20, 28, 0, 22, 0}, {27, 20, 27, 0, 22, 0}, {28, 20, 27, 0, 22, 0},
    {29, 20, 26, 0, 22, 0}, {30, 20, 26, 0, 22, 0}, {30, 20, 25, 0, 22, 0}, {31, 20, 24, 0, 22, 0}, {32, 20, 24, 0, 22, 0},
    {33, 21, 23, 0, 22, 0}, {34, 21, 22, 0, 22, 0}, {35, 21, 22, 0, 22, 0}, {35, 21, 21, 0, 22, 0}, {36, 21, 20, 0, 22, 0},
    {37, 21, 20, 0, 21, 0}, {38, 21, 19, 0, 21, 0}, {39, 21, 18, 0, 21, 0}, {39, 22, 17, 0, 21, 0}, {40, 22, 17, 0, 21, 0},
    {41, 22, 16, 0, 21, 0}, {41, 22, 15, 0, 21, 0}, {42, 22, 14, 0, 21, 0}, {43, 22, 13, 0, 21, 0}, {44, 22, 12, 0, 21, 0},
    {44, 23, 11, 0, 21, 0}, {45, 23, 11, 0, 21, 0}, {46, 23, 10, 0, 21, 0}, {46, 23, 9, 0, 21, 0}, {47, 23, 8, 0, 21, 0},
    {48, 23, 7, 0, 21, 0}, {48, 23, 6, 0, 21, 0}, {49, 23, 5, 0, 20, 0}, {49, 24, 4, 0, 20, 0}, {50, 24, 3, 0, 20, 0},
    {50, 24, 2, 0, 20, 0}, {51, 24, 1, 0, 20, 0}, {52, 24, 0, 0, 20, 0}, {52, 24, -1, 0, 20, 0}, {53, 24, -2, 0, 20, 0},
    {53, 24, -3, 0, 20, 0}, {54, 25, -4, 0, 20, 0}, {54, 25, -5, 0, 20, 0}, {54, 25, -6, 0, 20, 0}, {55, 25, -8, 0, 20, 0},
    {55, 25, -9, 0, 20, 0}, {56, 25, -10, 0, 20, 0}, {56, 25, -11, 0, 20, 0}, {56, 26, -12, 0, 19, 0}, {57, 26, -13, 0, 19, 0},
    {57, 26, -14, 0, 19, 0}, {58, 26, -15, 0, 19, 0}, {58, 26, -17, 0, 19, 0}, {58, 26, -18, 0, 19, 0}, {58, 26, -19, 0, 19, 0},
    {59, 26, -20, 0, 19, 0}, {59, 27, -21, 0, 19, 0}, {59, 27, -22, 0, 19, 0}, {59, 27, -24, 0, 19, 0}, {60, 27, -25, 0, 19, 0},
    {60, 27, -26, 0, 19, 0}, {60, 27, -27, 0, 19, 0}, {60, 27, -28, 0, 19, 0}, {60, 28, -30, 0, 19, 0}, {60, 28, -31, 0, 18, 0},
    {60, 28, -32, 0, 18, 0}, {61, 28, -33, 0, 18, 0}, {61, 28, -34, 0, 18, 0}, {61, 28, -36, 0, 18, 0}, {61, 28, -37, 0, 18, 0},
    {61, 28, -38, 0, 18, 0}, {61, 29, -39, 0, 18, 0}, {61, 29, -40, 0, 18, 0}, {61, 29, -42, 0, 18, 0}, {61, 29, -43, 0, 18, 0},
    {61, 29, -44, 0, 18, 0}, {61, 29, -45, 0, 18, 0}, {60, 29, -46, 0, 18, 0}, {60, 29, -48, 0, 18, 0}, {60, 30, -49, 0, 17, 0},
    {60, 30, -50, 0, 17, 0}, {60, 30, -51, 0, 17, 0}, {60, 30, -52, 0, 17, 0}, {60, 30, -54, 0, 17, 0}, {59, 30, -55, 0, 17, 0},
    {59, 30, -56, 0, 17, 0}, {59, 31, -57, 0, 17, 0}, {59, 31, -58, 0, 17, 0}, {58, 31, -60, 0, 17, 0}, {58, 31, -61, 0, 17, 0},
    {58, 31, -62, 0, 17, 0}, {58, 31, -63, 0, 17, 0}, {57, 31, -64, 0, 17, 0}, {57, 31, -65, 0, 17, 0}, {57, 32, -67, 0, 17, 0},
    {56, 32, -68, 0, 17, 0}, {56, 32, -69, 0, 17, 0}, {56, 32, -70, 0, 17, 0}, {55, 32, -71, 0, 17, 0}, {55, 32, -72, 0, 17, 0},
    {55, 32, -73, 0, 17, 0}, {54, 32, -75, 0, 17, 0}, {54, 33, -76, 0, 17, 0}, {53, 33, -77, 0, 8, 0}, {53, 33, -78, 0, 8, 0},
    {53, 33, -79, 0, 8, 0}, {52, 33, -80, 0, 8, 0}, {52, 33, -81, 0, 8, 0}, {51, 33, -82, 0, 8, 0}, {51, 34, -83, 0, 8, 0},
    {50, 34, -84, 0, 8, 0}, {50, 34, -85, 0, 8, 0}, {50, 34, -87, 0, 8, 0}, {49, 34, -88, 0, 8, 0}, {49, 34, -89, 0, 8, 0},
    {48, 34, -90, 0, 8, 0}, {48, 34, -91, 0, 8, 0}, {47, 35, -92, 0, 8, 0}, {47, 35, -93, 0, 8, 0}, {46, 35, -94, 0, 8, 0},
    {45, 35, -95, 0, 8, 0}, {45, 35, -96, 0, 8, 0}, {44, 35, -97, 0, 8, 0}, {44, 35, -98, 0, 8, 0}, {43, 35, -99, 0, 8, 0},
    {43, 36, -100, 0, 8, 0}, {42, 36, -101, 0, 8, 0}, {42, 36, -102, 0, 8, 0}, {41, 36, -103, 0, 8, 0}, {40, 36, -104, 0, 8, 0},
    {40, 36, -105, 0, 8, 0}, {39, 36, -106, 0, 8, 0}, {38, 37, -107, 0, 8, 0}, {38, 37, -108, 0, 8, 0}, {37, 37, -109, 0, 8, 0},
    {37, 37, -110, 0, 8, 0}, {36, 37, -110, 0, 8, 0}, {35, 37, -111, 0, 7, 0}, {35, 37, -112, 0, 7, 0}, {34, 37, -113, 0, 7, 0},
    {33, 38, -114, 0, 7, 0}, {33, 38, -115, 0, 7, 0}, {32, 38, -116, 0, 7, 0}, {31, 38, -117, 0, 7, 0}, {31, 38, -118, 0, 7, 0},
    {30, 38, -119, 0, 7, 0}, {29, 38, -119, 0, 7, 0}, {29, 38, -120, 0, 7, 0}, {28, 39, -121, 0, 7, 0}, {27, 39, -122, 0, 7, 0},
    {26, 39, -123, 0, 7, 0}, {26, 39, -124, 0, 7, 0}, {25, 39, -124, 0, 7, 0}, {24, 39, -125, 0, 7, 0}, {24, 39, -126, 0, 7, 0},
    {23, 40, -127, 0, 7, 0}, {22, 40, -128, 0, 7, 0}, {21, 40, -129, 0, 7, 0}, {21, 40, -129, 0, 7, 0}, {20, 40, -130, 0, 7, 0},
    {19, 40, -131, 0, 7, 0}, {18, 40, -132, 0, 7, 0}, {18, 40, -132, 0, 7, 0}, {17, 41, -133, 0, 7, 0}, {16, 41, -134, 0, 7, 0},
    {15, 41, -135, 0, 7, 0}, {14, 41, -135, 0, 7, 0}, {14, 41, -136, 0, 7, 0}, {13, 41, -137, 0, 7, 0}, {12, 41, -138, 0, 7, 0},
    {11, 41, -138, 0, 7, 0}, {11, 42, -139, 0, 7, 0}, {10, 42, -140, 0, 7, 0}, {9, 42, -141, 0, 7, 0}, {8, 42, -141, 0, 7, 0},
    {7, 42, -142, 0, 7, 0}, {6, 42, -143, 0, 7, 0}, {6, 42, -143, 0, 7, 0}, {5, 43, -144, 0, 7, 0}, {4, 43, -145, 0, 7, 0},
    {3, 43, -145, 0, 7, 0}, {2, 43, -146, 0, 7, 0}, {1, 43, -147, 0, 7, 0}, {1, 43, -147, 0, 7, 0}, {0, 43, -148, 0, 7, 0},
    {-1, 43, -149, 0, 7, 0}, {-2, 44, -149, 0, 7, 0}, {-3, 44, -150, 0, 6, 0}, {-4, 44, -150, 0, 6, 0}, {-4, 44, -151, 0, 6, 0},
    {-5, 44, -152, 0, 6, 0}, {-6, 44, -152, 0, 6, 0}, {-7, 44, -153, 0, 6, 0}, {-8, 44, -154, 0, 6, 0}, {-9, 45, -154, 0, 6, 0},
    {-10, 45, -155, 0, 6, 0}, {-11, 45, -155, 0, 6, 0}, {-11, 45, -156, 0, 6, 0}, {-12, 45, -156, 0, 6, 0}, {-13, 45, -157, 0, 6, 0},
    {-14, 45, -158, 0, 6, 0}, {-15, 46, -158, 0, 6, 0}, {-16, 46, -159, 0, 6, 0}, {-17, 46, -159, 0, 6, 0}, {-18, 46, -160, 0, 6, 0},
    {-18, 46, -160, 0, 6, 0}, {-19, 46, -161, 0, 6, 0}, {-20, 46, -161, 0, 6, 0}, {-21, 46, -162, 0, 6, 0}, {-22, 47, -162, 0, 6, 0},
    {-23, 47, -163, 0, 6, 0}, {-24, 47, -163, 0, 6, 0}, {-25, 47, -164, 0, 6, 0}, {-26, 47, -164, 0, 6, 0}, {-26, 47, -165, 0, 6, 0},
    {-27, 47, -165, 0, 6, 0}, {-28, 47, -166, 0, 6, 0}, {-29, 48, -166, 0, 6, 0}, {-30, 48, -167, 0, 6, 0}, {-31, 48, -167, 0, 6, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftMediumHalfLoopDown3, {
    {16, 31, 35, 8, 16, 0}, {16, 30, 35, 8, 16, 0}, {16, 29, 35, 8, 16, 0}, {17, 28, 35, 8, 16, 0}, {17, 27, 35, 8, 16, 0},
    {17, 26, 35, 8, 16, 0}, {17, 25, 35, 8, 16, 0}, {17, 24, 34, 8, 23, 0}, {17, 23, 34, 8, 23, 0}, {17, 22, 34, 8, 23, 0},
    {17, 21, 34, 8, 23, 0}, {18, 20, 34, 8, 23, 0}, {18, 19, 33, 8, 23, 0}, {18, 18, 33, 8, 23, 0}, {18, 17, 33, 8, 23, 0},
    {18, 16, 32, 8, 23, 0}, {18, 15, 32, 8, 23, 0}, {18, 14, 32, 8, 23, 0}, {18, 13, 31, 8, 23, 0}, {19, 12, 31, 8, 23, 0},
    {19, 11, 31, 8, 23, 0}, {19, 11, 30, 8, 23, 0}, {19, 10, 30, 8, 23, 0}, {19, 9, 29, 8, 22, 0}, {19, 8, 29, 8, 22, 0},
    {19, 7, 28, 8, 22, 0}, {20, 6, 28, 8, 22, 0}, {20, 5, 27, 8, 22, 0}, {20, 4, 27, 8, 22, 0}, {20, 3, 26, 8, 22, 0},
    {20, 2, 26, 8, 22, 0}, {20, 2, 25, 8, 22, 0}, {20, 1, 24, 8, 22, 0}, {20, 0, 24, 8, 22, 0}, {21, -1, 23, 8, 22, 0},
    {21, -2, 22, 8, 22, 0}, {21, -3, 22, 8, 22, 0}, {21, -3, 21, 8, 22, 0}, {21, -4, 20, 8, 22, 0}, {21, -5, 20, 8, 21, 0},
    {21, -6, 19, 8, 21, 0}, {21, -7, 18, 8, 21, 0}, {22, -7, 17, 8, 21, 0}, {22, -8, 17, 8, 21, 0}, {22, -9, 16, 8, 21, 0},
    {22, -9, 15, 8, 21, 0}, {22, -10, 14, 8, 21, 0}, {22, -11, 13, 8, 21, 0}, {22, -12, 12, 8, 21, 0}, {23, -12, 11, 8, 21, 0},
    {23, -13, 11, 8, 21, 0}, {23, -14, 10, 8, 21, 0}, {23, -14, 9, 8, 21, 0}, {23, -15, 8, 8, 21, 0}, {23, -16, 7, 8, 21, 0},
    {23, -16, 6, 8, 21, 0}, {23, -17, 5, 8, 20, 0}, {24, -17, 4, 8, 20, 0}, {24, -18, 3, 8, 20, 0}, {24, -18, 2, 8, 20, 0},
    {24, -19, 1, 8, 20, 0}, {24, -20, 0, 8, 20, 0}, {24, -20, -1, 8, 20, 0}, {24, -21, -2, 8, 20, 0}, {24, -21, -3, 8, 20, 0},
    {25, -22, -4, 8, 20, 0}, {25, -22, -5, 8, 20, 0}, {25, -22, -6, 8, 20, 0}, {25, -23, -8, 8, 20, 0}, {25, -23, -9, 8, 20, 0},
    {25, -24, -10, 8, 20, 0}, {25, -24, -11, 8, 20, 0}, {26, -24, -12, 8, 19, 0}, {26, -25, -13, 8, 19, 0}, {26, -25, -14, 8, 19, 0},
    {26, -26, -15, 8, 19, 0}, {26, -26, -17, 8, 19, 0}, {26, -26, -18, 8, 19, 0}, {26, -26, -19, 8, 19, 0}, {26, -27, -20, 8, 19, 0},
    {27, -27, -21, 8, 19, 0}, {27, -27, -22, 8, 19, 0}, {27, -27, -24, 8, 19, 0}, {27, -28, -25, 8, 19, 0}, {27, -28, -26, 8, 19, 0},
    {27, -28, -27, 8, 19, 0}, {27, -28, -28, 8, 19, 0}, {28, -28, -30, 8, 19, 0}, {28, -28, -31, 8, 18, 0}, {28, -28, -32, 8, 18, 0},
    {28, -29, -33, 8, 18, 0}, {28, -29, -34, 8, 18, 0}, {28, -29, -36, 8, 18, 0}, {28, -29, -37, 8, 18, 0}, {28, -29, -38, 8, 18, 0},
    {29, -29, -39, 8, 18, 0}, {29, -29, -40, 8, 18, 0}, {29, -29, -42, 8, 18, 0}, {29, -29, -43, 8, 18, 0}, {29, -29, -44, 8, 18, 0},
    {29, -29, -45, 8, 18, 0}, {29, -28, -46, 8, 18, 0}, {29, -28, -48, 8, 18, 0}, {30, -28, -49, 8, 17, 0}, {30, -28, -50, 8, 17, 0},
    {30, -28, -51, 8, 17, 0}, {30, -28, -52, 8, 17, 0}, {30, -28, -54, 8, 17, 0}, {30, -27, -55, 8, 17, 0}, {30, -27, -56, 8, 17, 0},
    {31, -27, -57, 8, 17, 0}, {31, -27, -58, 8, 17, 0}, {31, -26, -60, 8, 17, 0}, {31, -26, -61, 8, 17, 0}, {31, -26, -62, 8, 17, 0},
    {31, -26, -63, 8, 17, 0}, {31, -25, -64, 8, 17, 0}, {31, -25, -65, 8, 17, 0}, {32, -25, -67, 8, 17, 0}, {32, -24, -68, 8, 17, 0},
    {32, -24, -69, 8, 17, 0}, {32, -24, -70, 8, 17, 0}, {32, -23, -71, 8, 17, 0}, {32, -23, -72, 8, 17, 0}, {32, -23, -73, 8, 17, 0},
    {32, -22, -75, 8, 17, 0}, {33, -22, -76, 8, 17, 0}, {33, -21, -77, 8, 8, 0}, {33, -21, -78, 8, 8, 0}, {33, -21, -79, 8, 8, 0},
    {33, -20, -80, 8, 8, 0}, {33, -20, -81, 8, 8, 0}, {33, -19, -82, 8, 8, 0}, {34, -19, -83, 8, 8, 0}, {34, -18, -84, 8, 8, 0},
    {34, -18, -85, 8, 8, 0}, {34, -18, -87, 8, 8, 0}, {34, -17, -88, 8, 8, 0}, {34, -17, -89, 8, 8, 0}, {34, -16, -90, 8, 8, 0},
    {34, -16, -91, 8, 8, 0}, {35, -15, -92, 8, 8, 0}, {35, -15, -93, 8, 8, 0}, {35, -14, -94, 8, 8, 0}, {35, -13, -95, 8, 8, 0},
    {35, -13, -96, 8, 8, 0}, {35, -12, -97, 8, 8, 0}, {35, -12, -98, 8, 8, 0}, {35, -11, -99, 8, 8, 0}, {36, -11, -100, 8, 8, 0},
    {36, -10, -101, 8, 8, 0}, {36, -10, -102, 8, 8, 0}, {36, -9, -103, 8, 8, 0}, {36, -8, -104, 8, 8, 0}, {36, -8, -105, 8, 8, 0},
    {36, -7, -106, 8, 8, 0}, {37, -6, -107, 8, 8, 0}, {37, -6, -108, 8, 8, 0}, {37, -5, -109, 8, 8, 0}, {37, -5, -110, 8, 8, 0},
    {37, -4, -110, 8, 8, 0}, {37, -3, -111, 8, 7, 0}, {37, -3, -112, 8, 7, 0}, {37, -2, -113, 8, 7, 0}, {38, -1, -114, 8, 7, 0},
    {38, -1, -115, 8, 7, 0}, {38, 0, -116, 8, 7, 0}, {38, 1, -117, 8, 7, 0}, {38, 1, -118, 8, 7, 0}, {38, 2, -119, 8, 7, 0},
    {38, 3, -119, 8, 7, 0}, {38, 3, -120, 8, 7, 0}, {39, 4, -121, 8, 7, 0}, {39, 5, -122, 8, 7, 0}, {39, 6, -123, 8, 7, 0},
    {39, 6, -124, 8, 7, 0}, {39, 7, -124, 8, 7, 0}, {39, 8, -125, 8, 7, 0}, {39, 8, -126, 8, 7, 0}, {40, 9, -127, 8, 7, 0},
    {40, 10, -128, 8, 7, 0}, {40, 11, -129, 8, 7, 0}, {40, 11, -129, 8, 7, 0}, {40, 12, -130, 8, 7, 0}, {40, 13, -131, 8, 7, 0},
    {40, 14, -132, 8, 7, 0}, {40, 14, -132, 8, 7, 0}, {41, 15, -133, 8, 7, 0}, {41, 16, -134, 8, 7, 0}, {41, 17, -135, 8, 7, 0},
    {41, 18, -135, 8, 7, 0}, {41, 18, -136, 8, 7, 0}, {41, 19, -137, 8, 7, 0}, {41, 20, -138, 8, 7, 0}, {41, 21, -138, 8, 7, 0},
    {42, 21, -139, 8, 7, 0}, {42, 22, -140, 8, 7, 0}, {42, 23, -141, 8, 7, 0}, {42, 24, -141, 8, 7, 0}, {42, 25, -142, 8, 7, 0},
    {42, 26, -143, 8, 7, 0}, {42, 26, -143, 8, 7, 0}, {43, 27, -144, 8, 7, 0}, {43, 28, -145, 8, 7, 0}, {43, 29, -145, 8, 7, 0},
    {43, 30, -146, 8, 7, 0}, {43, 31, -147, 8, 7, 0}, {43, 31, -147, 8, 7, 0}, {43, 32, -148, 8, 7, 0}, {43, 33, -149, 8, 7, 0},
    {44, 34, -149, 8, 7, 0}, {44, 35, -150, 8, 6, 0}, {44, 36, -150, 8, 6, 0}, {44, 36, -151, 8, 6, 0}, {44, 37, -152, 8, 6, 0},
    {44, 38, -152, 8, 6, 0}, {44, 39, -153, 8, 6, 0}, {44, 40, -154, 8, 6, 0}, {45, 41, -154, 8, 6, 0}, {45, 42, -155, 8, 6, 0},
    {45, 43, -155, 8, 6, 0}, {45, 43, -156, 8, 6, 0}, {45, 44, -156, 8, 6, 0}, {45, 45, -157, 8, 6, 0}, {45, 46, -158, 8, 6, 0},
    {46, 47, -158, 8, 6, 0}, {46, 48, -159, 8, 6, 0}, {46, 49, -159, 8, 6, 0}, {46, 50, -160, 8, 6, 0}, {46, 50, -160, 8, 6, 0},
    {46, 51, -161, 8, 6, 0}, {46, 52, -161, 8, 6, 0}, {46, 53, -162, 8, 6, 0}, {47, 54, -162, 8, 6, 0}, {47, 55, -163, 8, 6, 0},
    {47, 56, -163, 8, 6, 0}, {47, 57, -164, 8, 6, 0}, {47, 58, -164, 8, 6, 0}, {47, 58, -165, 8, 6, 0}, {47, 59, -165, 8, 6, 0},
    {47, 60, -166, 8, 6, 0}, {48, 61, -166, 8, 6, 0}, {48, 62, -167, 8, 6, 0}, {48, 63, -167, 8, 6, 0}, {48, 64, -168, 8, 6, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightMediumHalfLoopDown0, {
    {31, 16, 35, 16, 16, 0}, {30, 16, 35, 16, 16, 0}, {29, 16, 35, 16, 16, 0}, {28, 17, 35, 16, 16, 0}, {27, 17, 35, 16, 16, 0},
    {26, 17, 35, 16, 16, 0}, {25, 17, 35, 16, 16, 0}, {24, 17, 34, 16, 23, 0}, {23, 17, 34, 16, 23, 0}, {22, 17, 34, 16, 23, 0},
    {21, 17, 34, 16, 23, 0}, {20, 18, 34, 16, 23, 0}, {19, 18, 33, 16, 23, 0}, {18, 18, 33, 16, 23, 0}, {17, 18, 33, 16, 23, 0},
    {16, 18, 32, 16, 23, 0}, {15, 18, 32, 16, 23, 0}, {14, 18, 32, 16, 23, 0}, {13, 18, 31, 16, 23, 0}, {12, 19, 31, 16, 23, 0},
    {11, 19, 31, 16, 23, 0}, {11, 19, 30, 16, 23, 0}, {10, 19, 30, 16, 23, 0}, {9, 19, 29, 16, 22, 0}, {8, 19, 29, 16, 22, 0},
    {7, 19, 28, 16, 22, 0}, {6, 20, 28, 16, 22, 0}, {5, 20, 27, 16, 22, 0}, {4, 20, 27, 16, 22, 0}, {3, 20, 26, 16, 22, 0},
    {2, 20, 26, 16, 22, 0}, {2, 20, 25, 16, 22, 0}, {1, 20, 24, 16, 22, 0}, {0, 20, 24, 16, 22, 0}, {-1, 21, 23, 16, 22, 0},
    {-2, 21, 22, 16, 22, 0}, {-3, 21, 22, 16, 22, 0}, {-3, 21, 21, 16, 22, 0}, {-4, 21, 20, 16, 22, 0}, {-5, 21, 20, 16, 21, 0},
    {-6, 21, 19, 16, 21, 0}, {-7, 21, 18, 16, 21, 0}, {-7, 22, 17, 16, 21, 0}, {-8, 22, 17, 16, 21, 0}, {-9, 22, 16, 16, 21, 0},
    {-9, 22, 15, 16, 21, 0}, {-10, 22, 14, 16, 21, 0}, {-11, 22, 13, 16, 21, 0}, {-12, 22, 12, 16, 21, 0}, {-12, 23, 11, 16, 21, 0},
    {-13, 23, 11, 16, 21, 0}, {-14, 23, 10, 16, 21, 0}, {-14, 23, 9, 16, 21, 0}, {-15, 23, 8, 16, 21, 0}, {-16, 23, 7, 16, 21, 0},
    {-16, 23, 6, 16, 21, 0}, {-17, 23, 5, 16, 20, 0}, {-17, 24, 4, 16, 20, 0}, {-18, 24, 3, 16, 20, 0}, {-18, 24, 2, 16, 20, 0},
    {-19, 24, 1, 16, 20, 0}, {-20, 24, 0, 16, 20, 0}, {-20, 24, -1, 16, 20, 0}, {-21, 24, -2, 16, 20, 0}, {-21, 24, -3, 16, 20, 0},
    {-22, 25, -4, 16, 20, 0}, {-22, 25, -5, 16, 20, 0}, {-22, 25, -6, 16, 20, 0}, {-23, 25, -8, 16, 20, 0}, {-23, 25, -9, 16, 20, 0},
    {-24, 25, -10, 16, 20, 0}, {-24, 25, -11, 16, 20, 0}, {-24, 26, -12, 16, 19, 0}, {-25, 26, -13, 16, 19, 0}, {-25, 26, -14, 16, 19, 0},
    {-26, 26, -15, 16, 19, 0}, {-26, 26, -17, 16, 19, 0}, {-26, 26, -18, 16, 19, 0}, {-26, 26, -19, 16, 19, 0}, {-27, 26, -20, 16, 19, 0},
    {-27, 27, -21, 16, 19, 0}, {-27, 27, -22, 16, 19, 0}, {-27, 27, -24, 16, 19, 0}, {-28, 27, -25, 16, 19, 0}, {-28, 27, -26, 16, 19, 0},
    {-28, 27, -27, 16, 19, 0}, {-28, 27, -28, 16, 19, 0}, {-28, 28, -30, 16, 19, 0}, {-28, 28, -31, 16, 18, 0}, {-28, 28, -32, 16, 18, 0},
    {-29, 28, -33, 16, 18, 0}, {-29, 28, -34, 16, 18, 0}, {-29, 28, -36, 16, 18, 0}, {-29, 28, -37, 16, 18, 0}, {-29, 28, -38, 16, 18, 0},
    {-29, 29, -39, 16, 18, 0}, {-29, 29, -40, 16, 18, 0}, {-29, 29, -42, 16, 18, 0}, {-29, 29, -43, 16, 18, 0}, {-29, 29, -44, 16, 18, 0},
    {-29, 29, -45, 16, 18, 0}, {-28, 29, -46, 16, 18, 0}, {-28, 29, -48, 16, 18, 0}, {-28, 30, -49, 16, 17, 0}, {-28, 30, -50, 16, 17, 0},
    {-28, 30, -51, 16, 17, 0}, {-28, 30, -52, 16, 17, 0}, {-28, 30, -54, 16, 17, 0}, {-27, 30, -55, 16, 17, 0}, {-27, 30, -56, 16, 17, 0},
    {-27, 31, -57, 16, 17, 0}, {-27, 31, -58, 16, 17, 0}, {-26, 31, -60, 16, 17, 0}, {-26, 31, -61, 16, 17, 0}, {-26, 31, -62, 16, 17, 0},
    {-26, 31, -63, 16, 17, 0}, {-25, 31, -64, 16, 17, 0}, {-25, 31, -65, 16, 17, 0}, {-25, 32, -67, 16, 17, 0}, {-24, 32, -68, 16, 17, 0},
    {-24, 32, -69, 16, 17, 0}, {-24, 32, -70, 16, 17, 0}, {-23, 32, -71, 16, 17, 0}, {-23, 32, -72, 16, 17, 0}, {-23, 32, -73, 16, 17, 0},
    {-22, 32, -75, 16, 17, 0}, {-22, 33, -76, 16, 17, 0}, {-21, 33, -77, 16, 8, 0}, {-21, 33, -78, 16, 8, 0}, {-21, 33, -79, 16, 8, 0},
    {-20, 33, -80, 16, 8, 0}, {-20, 33, -81, 16, 8, 0}, {-19, 33, -82, 16, 8, 0}, {-19, 34, -83, 16, 8, 0}, {-18, 34, -84, 16, 8, 0},
    {-18, 34, -85, 16, 8, 0}, {-18, 34, -87, 16, 8, 0}, {-17, 34, -88, 16, 8, 0}, {-17, 34, -89, 16, 8, 0}, {-16, 34, -90, 16, 8, 0},
    {-16, 34, -91, 16, 8, 0}, {-15, 35, -92, 16, 8, 0}, {-15, 35, -93, 16, 8, 0}, {-14, 35, -94, 16, 8, 0}, {-13, 35, -95, 16, 8, 0},
    {-13, 35, -96, 16, 8, 0}, {-12, 35, -97, 16, 8, 0}, {-12, 35, -98, 16, 8, 0}, {-11, 35, -99, 16, 8, 0}, {-11, 36, -100, 16, 8, 0},
    {-10, 36, -101, 16, 8, 0}, {-10, 36, -102, 16, 8, 0}, {-9, 36, -103, 16, 8, 0}, {-8, 36, -104, 16, 8, 0}, {-8, 36, -105, 16, 8, 0},
    {-7, 36, -106, 16, 8, 0}, {-6, 37, -107, 16, 8, 0}, {-6, 37, -108, 16, 8, 0}, {-5, 37, -109, 16, 8, 0}, {-5, 37, -110, 16, 8, 0},
    {-4, 37, -110, 16, 8, 0}, {-3, 37, -111, 16, 7, 0}, {-3, 37, -112, 16, 7, 0}, {-2, 37, -113, 16, 7, 0}, {-1, 38, -114, 16, 7, 0},
    {-1, 38, -115, 16, 7, 0}, {0, 38, -116, 16, 7, 0}, {1, 38, -117, 16, 7, 0}, {1, 38, -118, 16, 7, 0}, {2, 38, -119, 16, 7, 0},
    {3, 38, -119, 16, 7, 0}, {3, 38, -120, 16, 7, 0}, {4, 39, -121, 16, 7, 0}, {5, 39, -122, 16, 7, 0}, {6, 39, -123, 16, 7, 0},
    {6, 39, -124, 16, 7, 0}, {7, 39, -124, 16, 7, 0}, {8, 39, -125, 16, 7, 0}, {8, 39, -126, 16, 7, 0}, {9, 40, -127, 16, 7, 0},
    {10, 40, -128, 16, 7, 0}, {11, 40, -129, 16, 7, 0}, {11, 40, -129, 16, 7, 0}, {12, 40, -130, 16, 7, 0}, {13, 40, -131, 16, 7, 0},
    {14, 40, -132, 16, 7, 0}, {14, 40, -132, 16, 7, 0}, {15, 41, -133, 16, 7, 0}, {16, 41, -134, 16, 7, 0}, {17, 41, -135, 16, 7, 0},
    {18, 41, -135, 16, 7, 0}, {18, 41, -136, 16, 7, 0}, {19, 41, -137, 16, 7, 0}, {20, 41, -138, 16, 7, 0}, {21, 41, -138, 16, 7, 0},
    {21, 42, -139, 16, 7, 0}, {22, 42, -140, 16, 7, 0}, {23, 42, -141, 16, 7, 0}, {24, 42, -141, 16, 7, 0}, {25, 42, -142, 16, 7, 0},
    {26, 42, -143, 16, 7, 0}, {26, 42, -143, 16, 7, 0}, {27, 43, -144, 16, 7, 0}, {28, 43, -145, 16, 7, 0}, {29, 43, -145, 16, 7, 0},
    {30, 43, -146, 16, 7, 0}, {31, 43, -147, 16, 7, 0}, {31, 43, -147, 16, 7, 0}, {32, 43, -148, 16, 7, 0}, {33, 43, -149, 16, 7, 0},
    {34, 44, -149, 16, 7, 0}, {35, 44, -150, 16, 6, 0}, {36, 44, -150, 16, 6, 0}, {36, 44, -151, 16, 6, 0}, {37, 44, -152, 16, 6, 0},
    {38, 44, -152, 16, 6, 0}, {39, 44, -153, 16, 6, 0}, {40, 44, -154, 16, 6, 0}, {41, 45, -154, 16, 6, 0}, {42, 45, -155, 16, 6, 0},
    {43, 45, -155, 16, 6, 0}, {43, 45, -156, 16, 6, 0}, {44, 45, -156, 16, 6, 0}, {45, 45, -157, 16, 6, 0}, {46, 45, -158, 16, 6, 0},
    {47, 46, -158, 16, 6, 0}, {48, 46, -159, 16, 6, 0}, {49, 46, -159, 16, 6, 0}, {50, 46, -160, 16, 6, 0}, {50, 46, -160, 16, 6, 0},
    {51, 46, -161, 16, 6, 0}, {52, 46, -161, 16, 6, 0}, {53, 46, -162, 16, 6, 0}, {54, 47, -162, 16, 6, 0}, {55, 47, -163, 16, 6, 0},
    {56, 47, -163, 16, 6, 0}, {57, 47, -164, 16, 6, 0}, {58, 47, -164, 16, 6, 0}, {58, 47, -165, 16, 6, 0}, {59, 47, -165, 16, 6, 0},
    {60, 47, -166, 16, 6, 0}, {61, 48, -166, 16, 6, 0}, {62, 48, -167, 16, 6, 0}, {63, 48, -167, 16, 6, 0}, {64, 48, -168, 16, 6, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightMediumHalfLoopDown1, {
    {16, 0, 35, 24, 16, 0}, {16, 1, 35, 24, 16, 0}, {16, 2, 35, 24, 16, 0}, {16, 3, 35, 24, 16, 0}, {17, 4, 35, 24, 16, 0},
    {17, 5, 35, 24, 16, 0}, {17, 6, 35, 24, 16, 0}, {17, 7, 35, 24, 16, 0}, {17, 8, 34, 24, 23, 0}, {17, 9, 34, 24, 23, 0},
    {17, 10, 34, 24, 23, 0}, {17, 11, 34, 24, 23, 0}, {18, 12, 34, 24, 23, 0}, {18, 13, 33, 24, 23, 0}, {18, 14, 33, 24, 23, 0},
    {18, 15, 33, 24, 23, 0}, {18, 16, 32, 24, 23, 0}, {18, 17, 32, 24, 23, 0}, {18, 18, 32, 24, 23, 0}, {18, 19, 31, 24, 23, 0},
    {19, 20, 31, 24, 23, 0}, {19, 21, 31, 24, 23, 0}, {19, 21, 30, 24, 23, 0}, {19, 22, 30, 24, 23, 0}, {19, 23, 29, 24, 22, 0},
    {19, 24, 29, 24, 22, 0}, {19, 25, 28, 24, 22, 0}, {20, 26, 28, 24, 22, 0}, {20, 27, 27, 24, 22, 0}, {20, 28, 27, 24, 22, 0},
    {20, 29, 26, 24, 22, 0}, {20, 30, 26, 24, 22, 0}, {20, 30, 25, 24, 22, 0}, {20, 31, 24, 24, 22, 0}, {20, 32, 24, 24, 22, 0},
    {21, 33, 23, 24, 22, 0}, {21, 34, 22, 24, 22, 0}, {21, 35, 22, 24, 22, 0}, {21, 35, 21, 24, 22, 0}, {21, 36, 20, 24, 22, 0},
    {21, 37, 20, 24, 21, 0}, {21, 38, 19, 24, 21, 0}, {21, 39, 18, 24, 21, 0}, {22, 39, 17, 24, 21, 0}, {22, 40, 17, 24, 21, 0},
    {22, 41, 16, 24, 21, 0}, {22, 41, 15, 24, 21, 0}, {22, 42, 14, 24, 21, 0}, {22, 43, 13, 24, 21, 0}, {22, 44, 12, 24, 21, 0},
    {23, 44, 11, 24, 21, 0}, {23, 45, 11, 24, 21, 0}, {23, 46, 10, 24, 21, 0}, {23, 46, 9, 24, 21, 0}, {23, 47, 8, 24, 21, 0},
    {23, 48, 7, 24, 21, 0}, {23, 48, 6, 24, 21, 0}, {23, 49, 5, 24, 20, 0}, {24, 49, 4, 24, 20, 0}, {24, 50, 3, 24, 20, 0},
    {24, 50, 2, 24, 20, 0}, {24, 51, 1, 24, 20, 0}, {24, 52, 0, 24, 20, 0}, {24, 52, -1, 24, 20, 0}, {24, 53, -2, 24, 20, 0},
    {24, 53, -3, 24, 20, 0}, {25, 54, -4, 24, 20, 0}, {25, 54, -5, 24, 20, 0}, {25, 54, -6, 24, 20, 0}, {25, 55, -8, 24, 20, 0},
    {25, 55, -9, 24, 20, 0}, {25, 56, -10, 24, 20, 0}, {25, 56, -11, 24, 20, 0}, {26, 56, -12, 24, 19, 0}, {26, 57, -13, 24, 19, 0},
    {26, 57, -14, 24, 19, 0}, {26, 58, -15, 24, 19, 0}, {26, 58, -17, 24, 19, 0}, {26, 58, -18, 24, 19, 0}, {26, 58, -19, 24, 19, 0},
    {26, 59, -20, 24, 19, 0}, {27, 59, -21, 24, 19, 0}, {27, 59, -22, 24, 19, 0}, {27, 59, -24, 24, 19, 0}, {27, 60, -25, 24, 19, 0},
    {27, 60, -26, 24, 19, 0}, {27, 60, -27, 24, 19, 0}, {27, 60, -28, 24, 19, 0}, {28, 60, -30, 24, 19, 0}, {28, 60, -31, 24, 18, 0},
    {28, 60, -32, 24, 18, 0}, {28, 61, -33, 24, 18, 0}, {28, 61, -34, 24, 18, 0}, {28, 61, -36, 24, 18, 0}, {28, 61, -37, 24, 18, 0},
    {28, 61, -38, 24, 18, 0}, {29, 61, -39, 24, 18, 0}, {29, 61, -40, 24, 18, 0}, {29, 61, -42, 24, 18, 0}, {29, 61, -43, 24, 18, 0},
    {29, 61, -44, 24, 18, 0}, {29, 61, -45, 24, 18, 0}, {29, 60, -46, 24, 18, 0}, {29, 60, -48, 24, 18, 0}, {30, 60, -49, 24, 17, 0},
    {30, 60, -50, 24, 17, 0}, {30, 60, -51, 24, 17, 0}, {30, 60, -52, 24, 17, 0}, {30, 60, -54, 24, 17, 0}, {30, 59, -55, 24, 17, 0},
    {30, 59, -56, 24, 17, 0}, {31, 59, -57, 24, 17, 0}, {31, 59, -58, 24, 17, 0}, {31, 58, -60, 24, 17, 0}, {31, 58, -61, 24, 17, 0},
    {31, 58, -62, 24, 17, 0}, {31, 58, -63, 24, 17, 0}, {31, 57, -64, 24, 17, 0}, {31, 57, -65, 24, 17, 0}, {32, 57, -67, 24, 17, 0},
    {32, 56, -68, 24, 17, 0}, {32, 56, -69, 24, 17, 0}, {32, 56, -70, 24, 17, 0}, {32, 55, -71, 24, 17, 0}, {32, 55, -72, 24, 17, 0},
    {32, 55, -73, 24, 17, 0}, {32, 54, -75, 24, 17, 0}, {33, 54, -76, 24, 17, 0}, {33, 53, -77, 24, 8, 0}, {33, 53, -78, 24, 8, 0},
    {33, 53, -79, 24, 8, 0}, {33, 52, -80, 24, 8, 0}, {33, 52, -81, 24, 8, 0}, {33, 51, -82, 24, 8, 0}, {34, 51, -83, 24, 8, 0},
    {34, 50, -84, 24, 8, 0}, {34, 50, -85, 24, 8, 0}, {34, 50, -87, 24, 8, 0}, {34, 49, -88, 24, 8, 0}, {34, 49, -89, 24, 8, 0},
    {34, 48, -90, 24, 8, 0}, {34, 48, -91, 24, 8, 0}, {35, 47, -92, 24, 8, 0}, {35, 47, -93, 24, 8, 0}, {35, 46, -94, 24, 8, 0},
    {35, 45, -95, 24, 8, 0}, {35, 45, -96, 24, 8, 0}, {35, 44, -97, 24, 8, 0}, {35, 44, -98, 24, 8, 0}, {35, 43, -99, 24, 8, 0},
    {36, 43, -100, 24, 8, 0}, {36, 42, -101, 24, 8, 0}, {36, 42, -102, 24, 8, 0}, {36, 41, -103, 24, 8, 0}, {36, 40, -104, 24, 8, 0},
    {36, 40, -105, 24, 8, 0}, {36, 39, -106, 24, 8, 0}, {37, 38, -107, 24, 8, 0}, {37, 38, -108, 24, 8, 0}, {37, 37, -109, 24, 8, 0},
    {37, 37, -110, 24, 8, 0}, {37, 36, -110, 24, 8, 0}, {37, 35, -111, 24, 7, 0}, {37, 35, -112, 24, 7, 0}, {37, 34, -113, 24, 7, 0},
    {38, 33, -114, 24, 7, 0}, {38, 33, -115, 24, 7, 0}, {38, 32, -116, 24, 7, 0}, {38, 31, -117, 24, 7, 0}, {38, 31, -118, 24, 7, 0},
    {38, 30, -119, 24, 7, 0}, {38, 29, -119, 24, 7, 0}, {38, 29, -120, 24, 7, 0}, {39, 28, -121, 24, 7, 0}, {39, 27, -122, 24, 7, 0},
    {39, 26, -123, 24, 7, 0}, {39, 26, -124, 24, 7, 0}, {39, 25, -124, 24, 7, 0}, {39, 24, -125, 24, 7, 0}, {39, 24, -126, 24, 7, 0},
    {40, 23, -127, 24, 7, 0}, {40, 22, -128, 24, 7, 0}, {40, 21, -129, 24, 7, 0}, {40, 21, -129, 24, 7, 0}, {40, 20, -130, 24, 7, 0},
    {40, 19, -131, 24, 7, 0}, {40, 18, -132, 24, 7, 0}, {40, 18, -132, 24, 7, 0}, {41, 17, -133, 24, 7, 0}, {41, 16, -134, 24, 7, 0},
    {41, 15, -135, 24, 7, 0}, {41, 14, -135, 24, 7, 0}, {41, 14, -136, 24, 7, 0}, {41, 13, -137, 24, 7, 0}, {41, 12, -138, 24, 7, 0},
    {41, 11, -138, 24, 7, 0}, {42, 11, -139, 24, 7, 0}, {42, 10, -140, 24, 7, 0}, {42, 9, -141, 24, 7, 0}, {42, 8, -141, 24, 7, 0},
    {42, 7, -142, 24, 7, 0}, {42, 6, -143, 24, 7, 0}, {42, 6, -143, 24, 7, 0}, {43, 5, -144, 24, 7, 0}, {43, 4, -145, 24, 7, 0},
    {43, 3, -145, 24, 7, 0}, {43, 2, -146, 24, 7, 0}, {43, 1, -147, 24, 7, 0}, {43, 1, -147, 24, 7, 0}, {43, 0, -148, 24, 7, 0},
    {43, -1, -149, 24, 7, 0}, {44, -2, -149, 24, 7, 0}, {44, -3, -150, 24, 6, 0}, {44, -4, -150, 24, 6, 0}, {44, -4, -151, 24, 6, 0},
    {44, -5, -152, 24, 6, 0}, {44, -6, -152, 24, 6, 0}, {44, -7, -153, 24, 6, 0}, {44, -8, -154, 24, 6, 0}, {45, -9, -154, 24, 6, 0},
    {45, -10, -155, 24, 6, 0}, {45, -11, -155, 24, 6, 0}, {45, -11, -156, 24, 6, 0}, {45, -12, -156, 24, 6, 0}, {45, -13, -157, 24, 6, 0},
    {45, -14, -158, 24, 6, 0}, {46, -15, -158, 24, 6, 0}, {46, -16, -159, 24, 6, 0}, {46, -17, -159, 24, 6, 0}, {46, -18, -160, 24, 6, 0},
    {46, -18, -160, 24, 6, 0}, {46, -19, -161, 24, 6, 0}, {46, -20, -161, 24, 6, 0}, {46, -21, -162, 24, 6, 0}, {47, -22, -162, 24, 6, 0},
    {47, -23, -163, 24, 6, 0}, {47, -24, -163, 24, 6, 0}, {47, -25, -164, 24, 6, 0}, {47, -26, -164, 24, 6, 0}, {47, -26, -165, 24, 6, 0},
    {47, -27, -165, 24, 6, 0}, {47, -28, -166, 24, 6, 0}, {48, -29, -166, 24, 6, 0}, {48, -30, -167, 24, 6, 0}, {48, -31, -167, 24, 6, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightMediumHalfLoopDown2, {
    {0, 16, 35, 0, 16, 0}, {1, 16, 35, 0, 16, 0}, {2, 16, 35, 0, 16, 0}, {3, 16, 35, 0, 16, 0}, {4, 15, 35, 0, 16, 0},
    {5, 15, 35, 0, 16, 0}, {6, 15, 35, 0, 16, 0}, {7, 15, 35, 0, 16, 0}, {8, 15, 34, 0, 23, 0}, {9, 15, 34, 0, 23, 0},
    {10, 15, 34, 0, 23, 0}, {11, 15, 34, 0, 23, 0}, {12, 14, 34, 0, 23, 0}, {13, 14, 33, 0, 23, 0}, {14, 14, 33, 0, 23, 0},
    {15, 14, 33, 0, 23, 0}, {16, 14, 32, 0, 23, 0}, {17, 14, 32, 0, 23, 0}, {18, 14, 32, 0, 23, 0}, {19, 14, 31, 0, 23, 0},
    {20, 13, 31, 0, 23, 0}, {21, 13, 31, 0, 23, 0}, {21, 13, 30, 0, 23, 0}, {22, 13, 30, 0, 23, 0}, {23, 13, 29, 0, 22, 0},
    {24, 13, 29, 0, 22, 0}, {25, 13, 28, 0, 22, 0}, {26, 12, 28, 0, 22, 0}, {27, 12, 27, 0, 22, 0}, {28, 12, 27, 0, 22, 0},
    {29, 12, 26, 0, 22, 0}, {30, 12, 26, 0, 22, 0}, {30, 12, 25, 0, 22, 0}, {31, 12, 24, 0, 22, 0}, {32, 12, 24, 0, 22, 0},
    {33, 11, 23, 0, 22, 0}, {34, 11, 22, 0, 22, 0}, {35, 11, 22, 0, 22, 0}, {35, 11, 21, 0, 22, 0}, {36, 11, 20, 0, 22, 0},
    {37, 11, 20, 0, 21, 0}, {38, 11, 19, 0, 21, 0}, {39, 11, 18, 0, 21, 0}, {39, 10, 17, 0, 21, 0}, {40, 10, 17, 0, 21, 0},
    {41, 10, 16, 0, 21, 0}, {41, 10, 15, 0, 21, 0}, {42, 10, 14, 0, 21, 0}, {43, 10, 13, 0, 21, 0}, {44, 10, 12, 0, 21, 0},
    {44, 9, 11, 0, 21, 0}, {45, 9, 11, 0, 21, 0}, {46, 9, 10, 0, 21, 0}, {46, 9, 9, 0, 21, 0}, {47, 9, 8, 0, 21, 0},
    {48, 9, 7, 0, 21, 0}, {48, 9, 6, 0, 21, 0}, {49, 9, 5, 0, 20, 0}, {49, 8, 4, 0, 20, 0}, {50, 8, 3, 0, 20, 0},
    {50, 8, 2, 0, 20, 0}, {51, 8, 1, 0, 20, 0}, {52, 8, 0, 0, 20, 0}, {52, 8, -1, 0, 20, 0}, {53, 8, -2, 0, 20, 0},
    {53, 8, -3, 0, 20, 0}, {54, 7, -4, 0, 20, 0}, {54, 7, -5, 0, 20, 0}, {54, 7, -6, 0, 20, 0}, {55, 7, -8, 0, 20, 0},
    {55, 7, -9, 0, 20, 0}, {56, 7, -10, 0, 20, 0}, {56, 7, -11, 0, 20, 0}, {56, 6, -12, 0, 19, 0}, {57, 6, -13, 0, 19, 0},
    {57, 6, -14, 0, 19, 0}, {58, 6, -15, 0, 19, 0}, {58, 6, -17, 0, 19, 0}, {58, 6, -18, 0, 19, 0}, {58, 6, -19, 0, 19, 0},
    {59, 6, -20, 0, 19, 0}, {59, 5, -21, 0, 19, 0}, {59, 5, -22, 0, 19, 0}, {59, 5, -24, 0, 19, 0}, {60, 5, -25, 0, 19, 0},
    {60, 5, -26, 0, 19, 0}, {60, 5, -27, 0, 19, 0}, {60, 5, -28, 0, 19, 0}, {60, 4, -30, 0, 19, 0}, {60, 4, -31, 0, 18, 0},
    {60, 4, -32, 0, 18, 0}, {61, 4, -33, 0, 18, 0}, {61, 4, -34, 0, 18, 0}, {61, 4, -36, 0, 18, 0}, {61, 4, -37, 0, 18, 0},
    {61, 4, -38, 0, 18, 0}, {61, 3, -39, 0, 18, 0}, {61, 3, -40, 0, 18, 0}, {61, 3, -42, 0, 18, 0}, {61, 3, -43, 0, 18, 0},
    {61, 3, -44, 0, 18, 0}, {61, 3, -45, 0, 18, 0}, {60, 3, -46, 0, 18, 0}, {60, 3, -48, 0, 18, 0}, {60, 2, -49, 0, 17, 0},
    {60, 2, -50, 0, 17, 0}, {60, 2, -51, 0, 17, 0}, {60, 2, -52, 0, 17, 0}, {60, 2, -54, 0, 17, 0}, {59, 2, -55, 0, 17, 0},
    {59, 2, -56, 0, 17, 0}, {59, 1, -57, 0, 17, 0}, {59, 1, -58, 0, 17, 0}, {58, 1, -60, 0, 17, 0}, {58, 1, -61, 0, 17, 0},
    {58, 1, -62, 0, 17, 0}, {58, 1, -63, 0, 17, 0}, {57, 1, -64, 0, 17, 0}, {57, 1, -65, 0, 17, 0}, {57, 0, -67, 0, 17, 0},
    {56, 0, -68, 0, 17, 0}, {56, 0, -69, 0, 17, 0}, {56, 0, -70, 0, 17, 0}, {55, 0, -71, 0, 17, 0}, {55, 0, -72, 0, 17, 0},
    {55, 0, -73, 0, 17, 0}, {54, 0, -75, 0, 17, 0}, {54, -1, -76, 0, 17, 0}, {53, -1, -77, 0, 8, 0}, {53, -1, -78, 0, 8, 0},
    {53, -1, -79, 0, 8, 0}, {52, -1, -80, 0, 8, 0}, {52, -1, -81, 0, 8, 0}, {51, -1, -82, 0, 8, 0}, {51, -2, -83, 0, 8, 0},
    {50, -2, -84, 0, 8, 0}, {50, -2, -85, 0, 8, 0}, {50, -2, -87, 0, 8, 0}, {49, -2, -88, 0, 8, 0}, {49, -2, -89, 0, 8, 0},
    {48, -2, -90, 0, 8, 0}, {48, -2, -91, 0, 8, 0}, {47, -3, -92, 0, 8, 0}, {47, -3, -93, 0, 8, 0}, {46, -3, -94, 0, 8, 0},
    {45, -3, -95, 0, 8, 0}, {45, -3, -96, 0, 8, 0}, {44, -3, -97, 0, 8, 0}, {44, -3, -98, 0, 8, 0}, {43, -3, -99, 0, 8, 0},
    {43, -4, -100, 0, 8, 0}, {42, -4, -101, 0, 8, 0}, {42, -4, -102, 0, 8, 0}, {41, -4, -103, 0, 8, 0}, {40, -4, -104, 0, 8, 0},
    {40, -4, -105, 0, 8, 0}, {39, -4, -106, 0, 8, 0}, {38, -5, -107, 0, 8, 0}, {38, -5, -108, 0, 8, 0}, {37, -5, -109, 0, 8, 0},
    {37, -5, -110, 0, 8, 0}, {36, -5, -110, 0, 8, 0}, {35, -5, -111, 0, 7, 0}, {35, -5, -112, 0, 7, 0}, {34, -5, -113, 0, 7, 0},
    {33, -6, -114, 0, 7, 0}, {33, -6, -115, 0, 7, 0}, {32, -6, -116, 0, 7, 0}, {31, -6, -117, 0, 7, 0}, {31, -6, -118, 0, 7, 0},
    {30, -6, -119, 0, 7, 0}, {29, -6, -119, 0, 7, 0}, {29, -6, -120, 0, 7, 0}, {28, -7, -121, 0, 7, 0}, {27, -7, -122, 0, 7, 0},
    {26, -7, -123, 0, 7, 0}, {26, -7, -124, 0, 7, 0}, {25, -7, -124, 0, 7, 0}, {24, -7, -125, 0, 7, 0}, {24, -7, -126, 0, 7, 0},
    {23, -8, -127, 0, 7, 0}, {22, -8, -128, 0, 7, 0}, {21, -8, -129, 0, 7, 0}, {21, -8, -129, 0, 7, 0}, {20, -8, -130, 0, 7, 0},
    {19, -8, -131, 0, 7, 0}, {18, -8, -132, 0, 7, 0}, {18, -8, -132, 0, 7, 0}, {17, -9, -133, 0, 7, 0}, {16, -9, -134, 0, 7, 0},
    {15, -9, -135, 0, 7, 0}, {14, -9, -135, 0, 7, 0}, {14, -9, -136, 0, 7, 0}, {13, -9, -137, 0, 7, 0}, {12, -9, -138, 0, 7, 0},
    {11, -9, -138, 0, 7, 0}, {11, -10, -139, 0, 7, 0}, {10, -10, -140, 0, 7, 0}, {9, -10, -141, 0, 7, 0}, {8, -10, -141, 0, 7, 0},
    {7, -10, -142, 0, 7, 0}, {6, -10, -143, 0, 7, 0}, {6, -10, -143, 0, 7, 0}, {5, -11, -144, 0, 7, 0}, {4, -11, -145, 0, 7, 0},
    {3, -11, -145, 0, 7, 0}, {2, -11, -146, 0, 7, 0}, {1, -11, -147, 0, 7, 0}, {1, -11, -147, 0, 7, 0}, {0, -11, -148, 0, 7, 0},
    {-1, -11, -149, 0, 7, 0}, {-2, -12, -149, 0, 7, 0}, {-3, -12, -150, 0, 6, 0}, {-4, -12, -150, 0, 6, 0}, {-4, -12, -151, 0, 6, 0},
    {-5, -12, -152, 0, 6, 0}, {-6, -12, -152, 0, 6, 0}, {-7, -12, -153, 0, 6, 0}, {-8, -12, -154, 0, 6, 0}, {-9, -13, -154, 0, 6, 0},
    {-10, -13, -155, 0, 6, 0}, {-11, -13, -155, 0, 6, 0}, {-11, -13, -156, 0, 6, 0}, {-12, -13, -156, 0, 6, 0}, {-13, -13, -157, 0, 6, 0},
    {-14, -13, -158, 0, 6, 0}, {-15, -14, -158, 0, 6, 0}, {-16, -14, -159, 0, 6, 0}, {-17, -14, -159, 0, 6, 0}, {-18, -14, -160, 0, 6, 0},
    {-18, -14, -160, 0, 6, 0}, {-19, -14, -161, 0, 6, 0}, {-20, -14, -161, 0, 6, 0}, {-21, -14, -162, 0, 6, 0}, {-22, -15, -162, 0, 6, 0},
    {-23, -15, -163, 0, 6, 0}, {-24, -15, -163, 0, 6, 0}, {-25, -15, -164, 0, 6, 0}, {-26, -15, -164, 0, 6, 0}, {-26, -15, -165, 0, 6, 0},
    {-27, -15, -165, 0, 6, 0}, {-28, -15, -166, 0, 6, 0}, {-29, -16, -166, 0, 6, 0}, {-30, -16, -167, 0, 6, 0}, {-31, -16, -167, 0, 6, 0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightMediumHalfLoopDown3, {
    {16, 31, 35, 8, 16, 0}, {16, 30, 35, 8, 16, 0}, {16, 29, 35, 8, 16, 0}, {15, 28, 35, 8, 16, 0}, {15, 27, 35, 8, 16, 0},
    {15, 26, 35, 8, 16, 0}, {15, 25, 35, 8, 16, 0}, {15, 24, 34, 8, 23, 0}, {15, 23, 34, 8, 23, 0}, {15, 22, 34, 8, 23, 0},
    {15, 21, 34, 8, 23, 0}, {14, 20, 34, 8, 23, 0}, {14, 19, 33, 8, 23, 0}, {14, 18, 33, 8, 23, 0}, {14, 17, 33, 8, 23, 0},
    {14, 16, 32, 8, 23, 0}, {14, 15, 32, 8, 23, 0}, {14, 14, 32, 8, 23, 0}, {14, 13, 31, 8, 23, 0}, {13, 12, 31, 8, 23, 0},
    {13, 11, 31, 8, 23, 0}, {13, 11, 30, 8, 23, 0}, {13, 10, 30, 8, 23, 0}, {13, 9, 29, 8, 22, 0}, {13, 8, 29, 8, 22, 0},
    {13, 7, 28, 8, 22, 0}, {12, 6, 28, 8, 22, 0}, {12, 5, 27, 8, 22, 0}, {12, 4, 27, 8, 22, 0}, {12, 3, 26, 8, 22, 0},
    {12, 2, 26, 8, 22, 0}, {12, 2, 25, 8, 22, 0}, {12, 1, 24, 8, 22, 0}, {12, 0, 24, 8, 22, 0}, {11, -1, 23, 8, 22, 0},
    {11, -2, 22, 8, 22, 0}, {11, -3, 22, 8, 22, 0}, {11, -3, 21, 8, 22, 0}, {11, -4, 20, 8, 22, 0}, {11, -5, 20, 8, 21, 0},
    {11, -6, 19, 8, 21, 0}, {11, -7, 18, 8, 21, 0}, {10, -7, 17, 8, 21, 0}, {10, -8, 17, 8, 21, 0}, {10, -9, 16, 8, 21, 0},
    {10, -9, 15, 8, 21, 0}, {10, -10, 14, 8, 21, 0}, {10, -11, 13, 8, 21, 0}, {10, -12, 12, 8, 21, 0}, {9, -12, 11, 8, 21, 0},
    {9, -13, 11, 8, 21, 0}, {9, -14, 10, 8, 21, 0}, {9, -14, 9, 8, 21, 0}, {9, -15, 8, 8, 21, 0}, {9, -16, 7, 8, 21, 0},
    {9, -16, 6, 8, 21, 0}, {9, -17, 5, 8, 20, 0}, {8, -17, 4, 8, 20, 0}, {8, -18, 3, 8, 20, 0}, {8, -18, 2, 8, 20, 0},
    {8, -19, 1, 8, 20, 0}, {8, -20, 0, 8, 20, 0}, {8, -20, -1, 8, 20, 0}, {8, -21, -2, 8, 20, 0}, {8, -21, -3, 8, 20, 0},
    {7, -22, -4, 8, 20, 0}, {7, -22, -5, 8, 20, 0}, {7, -22, -6, 8, 20, 0}, {7, -23, -8, 8, 20, 0}, {7, -23, -9, 8, 20, 0},
    {7, -24, -10, 8, 20, 0}, {7, -24, -11, 8, 20, 0}, {6, -24, -12, 8, 19, 0}, {6, -25, -13, 8, 19, 0}, {6, -25, -14, 8, 19, 0},
    {6, -26, -15, 8, 19, 0}, {6, -26, -17, 8, 19, 0}, {6, -26, -18, 8, 19, 0}, {6, -26, -19, 8, 19, 0}, {6, -27, -20, 8, 19, 0},
    {5, -27, -21, 8, 19, 0}, {5, -27, -22, 8, 19, 0}, {5, -27, -24, 8, 19, 0}, {5, -28, -25, 8, 19, 0}, {5, -28, -26, 8, 19, 0},
    {5, -28, -27, 8, 19, 0}, {5, -28, -28, 8, 19, 0}, {4, -28, -30, 8, 19, 0}, {4, -28, -31, 8, 18, 0}, {4, -28, -32, 8, 18, 0},
    {4, -29, -33, 8, 18, 0}, {4, -29, -34, 8, 18, 0}, {4, -29, -36, 8, 18, 0}, {4, -29, -37, 8, 18, 0}, {4, -29, -38, 8, 18, 0},
    {3, -29, -39, 8, 18, 0}, {3, -29, -40, 8, 18, 0}, {3, -29, -42, 8, 18, 0}, {3, -29, -43, 8, 18, 0}, {3, -29, -44, 8, 18, 0},
    {3, -29, -45, 8, 18, 0}, {3, -28, -46, 8, 18, 0}, {3, -28, -48, 8, 18, 0}, {2, -28, -49, 8, 17, 0}, {2, -28, -50, 8, 17, 0},
    {2, -28, -51, 8, 17, 0}, {2, -28, -52, 8, 17, 0}, {2, -28, -54, 8, 17, 0}, {2, -27, -55, 8, 17, 0}, {2, -27, -56, 8, 17, 0},
    {1, -27, -57, 8, 17, 0}, {1, -27, -58, 8, 17, 0}, {1, -26, -60, 8, 17, 0}, {1, -26, -61, 8, 17, 0}, {1, -26, -62, 8, 17, 0},
    {1, -26, -63, 8, 17, 0}, {1, -25, -64, 8, 17, 0}, {1, -25, -65, 8, 17, 0}, {0, -25, -67, 8, 17, 0}, {0, -24, -68, 8, 17, 0},
    {0, -24, -69, 8, 17, 0}, {0, -24, -70, 8, 17, 0}, {0, -23, -71, 8, 17, 0}, {0, -23, -72, 8, 17, 0}, {0, -23, -73, 8, 17, 0},
    {0, -22, -75, 8, 17, 0}, {-1, -22, -76, 8, 17, 0}, {-1, -21, -77, 8, 8, 0}, {-1, -21, -78, 8, 8, 0}, {-1, -21, -79, 8, 8, 0},
    {-1, -20, -80, 8, 8, 0}, {-1, -20, -81, 8, 8, 0}, {-1, -19, -82, 8, 8, 0}, {-2, -19, -83, 8, 8, 0}, {-2, -18, -84, 8, 8, 0},
    {-2, -18, -85, 8, 8, 0}, {-2, -18, -87, 8, 8, 0}, {-2, -17, -88, 8, 8, 0}, {-2, -17, -89, 8, 8, 0}, {-2, -16, -90, 8, 8, 0},
    {-2, -16, -91, 8, 8, 0}, {-3, -15, -92, 8, 8, 0}, {-3, -15, -93, 8, 8, 0}, {-3, -14, -94, 8, 8, 0}, {-3, -13, -95, 8, 8, 0},
    {-3, -13, -96, 8, 8, 0}, {-3, -12, -97, 8, 8, 0}, {-3, -12, -98, 8, 8, 0}, {-3, -11, -99, 8, 8, 0}, {-4, -11, -100, 8, 8, 0},
    {-4, -10, -101, 8, 8, 0}, {-4, -10, -102, 8, 8, 0}, {-4, -9, -103, 8, 8, 0}, {-4, -8, -104, 8, 8, 0}, {-4, -8, -105, 8, 8, 0},
    {-4, -7, -106, 8, 8, 0}, {-5, -6, -107, 8, 8, 0}, {-5, -6, -108, 8, 8, 0}, {-5, -5, -109, 8, 8, 0}, {-5, -5, -110, 8, 8, 0},
    {-5, -4, -110, 8, 8, 0}, {-5, -3, -111, 8, 7, 0}, {-5, -3, -112, 8, 7, 0}, {-5, -2, -113, 8, 7, 0}, {-6, -1, -114, 8, 7, 0},
    {-6, -1, -115, 8, 7, 0}, {-6, 0, -116, 8, 7, 0}, {-6, 1, -117, 8, 7, 0}, {-6, 1, -118, 8, 7, 0}, {-6, 2, -119, 8, 7, 0},
    {-6, 3, -119, 8, 7, 0}, {-6, 3, -120, 8, 7, 0}, {-7, 4, -121, 8, 7, 0}, {-7, 5, -122, 8, 7, 0}, {-7, 6, -123, 8, 7, 0},
    {-7, 6, -124, 8, 7, 0}, {-7, 7, -124, 8, 7, 0}, {-7, 8, -125, 8, 7, 0}, {-7, 8, -126, 8, 7, 0}, {-8, 9, -127, 8, 7, 0},
    {-8, 10, -128, 8, 7, 0}, {-8, 11, -129, 8, 7, 0}, {-8, 11, -129, 8, 7, 0}, {-8, 12, -130, 8, 7, 0}, {-8, 13, -131, 8, 7, 0},
    {-8, 14, -132, 8, 7, 0}, {-8, 14, -132, 8, 7, 0}, {-9, 15, -133, 8, 7, 0}, {-9, 16, -134, 8, 7, 0}, {-9, 17, -135, 8, 7, 0},
    {-9, 18, -135, 8, 7, 0}, {-9, 18, -136, 8, 7, 0}, {-9, 19, -137, 8, 7, 0}, {-9, 20, -138, 8, 7, 0}, {-9, 21, -138, 8, 7, 0},
    {-10, 21, -139, 8, 7, 0}, {-10, 22, -140, 8, 7, 0}, {-10, 23, -141, 8, 7, 0}, {-10, 24, -141, 8, 7, 0}, {-10, 25, -142, 8, 7, 0},
    {-10, 26, -143, 8, 7, 0}, {-10, 26, -143, 8, 7, 0}, {-11, 27, -144, 8, 7, 0}, {-11, 28, -145, 8, 7, 0}, {-11, 29, -145, 8, 7, 0},
    {-11, 30, -146, 8, 7, 0}, {-11, 31, -147, 8, 7, 0}, {-11, 31, -147, 8, 7, 0}, {-11, 32, -148, 8, 7, 0}, {-11, 33, -149, 8, 7, 0},
    {-12, 34, -149, 8, 7, 0}, {-12, 35, -150, 8, 6, 0}, {-12, 36, -150, 8, 6, 0}, {-12, 36, -151, 8, 6, 0}, {-12, 37, -152, 8, 6, 0},
    {-12, 38, -152, 8, 6, 0}, {-12, 39, -153, 8, 6, 0}, {-12, 40, -154, 8, 6, 0}, {-13, 41, -154, 8, 6, 0}, {-13, 42, -155, 8, 6, 0},
    {-13, 43, -155, 8, 6, 0}, {-13, 43, -156, 8, 6, 0}, {-13, 44, -156, 8, 6, 0}, {-13, 45, -157, 8, 6, 0}, {-13, 46, -158, 8, 6, 0},
    {-14, 47, -158, 8, 6, 0}, {-14, 48, -159, 8, 6, 0}, {-14, 49, -159, 8, 6, 0}, {-14, 50, -160, 8, 6, 0}, {-14, 50, -160, 8, 6, 0},
    {-14, 51, -161, 8, 6, 0}, {-14, 52, -161, 8, 6, 0}, {-14, 53, -162, 8, 6, 0}, {-15, 54, -162, 8, 6, 0}, {-15, 55, -163, 8, 6, 0},
    {-15, 56, -163, 8, 6, 0}, {-15, 57, -164, 8, 6, 0}, {-15, 58, -164, 8, 6, 0}, {-15, 58, -165, 8, 6, 0}, {-15, 59, -165, 8, 6, 0},
    {-15, 60, -166, 8, 6, 0}, {-16, 61, -166, 8, 6, 0}, {-16, 62, -167, 8, 6, 0}, {-16, 63, -167, 8, 6, 0}, {-16, 64, -168, 8, 6, 0},
})



CREATE_VEHICLE_INFO(TrackVehicleInfoLeftZeroGRollUp0, {
    {   31,   16,    0,    0,    2,    0}, {   30,   16,    0,    0,    2,    0}, {   29,   16,    1,    0,    2,    0}, {   28,   17,    1,    0,    2,    0}, {   27,   17,    1,    0,    2,    0},
    {   26,   17,    2,    0,    2,    0}, {   25,   17,    2,    0,    2,    0}, {   24,   17,    3,    0,    2,    0}, {   24,   17,    3,    0,    2,    0}, {   23,   18,    4,    0,    2,    1},
    {   22,   18,    4,    0,    2,    1}, {   21,   18,    4,    0,    2,    1}, {   20,   18,    5,    0,    2,    1}, {   19,   18,    5,    0,    2,    1}, {   18,   18,    6,    0,    2,    1},
    {   18,   19,    6,    0,    2,    1}, {   17,   19,    7,    0,    2,    1}, {   16,   19,    7,    0,    2,    1}, {   15,   19,    8,    0,    2,    1}, {   14,   19,    8,    0,    2,    1},
    {   13,   20,    9,    0,    2,    1}, {   12,   20,    9,    0,    2,    1}, {   11,   20,   10,    0,    2,    1}, {   10,   20,   10,    0,    2,    1}, {    9,   20,   11,    0,    2,    2},
    {    8,   21,   11,    0,    2,    2}, {    7,   21,   12,    0,    2,    2}, {    6,   21,   12,    0,    2,    2}, {    5,   21,   13,    0,    2,    2}, {    5,   21,   14,    0,    2,    2},
    {    4,   21,   14,    0,    2,    2}, {    3,   22,   15,    0,    2,    2}, {    2,   22,   15,    0,    2,    2}, {    1,   22,   16,    0,    2,    2}, {    0,   22,   16,    0,    2,    2},
    {   -1,   22,   17,    0,    2,    2}, {   -2,   22,   17,    0,    2,    5}, {   -3,   23,   18,    0,    2,    5}, {   -3,   23,   19,    0,    2,    5}, {   -4,   23,   19,    0,    2,    5},
    {   -5,   23,   20,    0,    2,    5}, {   -6,   23,   20,    0,    2,    5}, {   -7,   23,   21,    0,    2,    5}, {   -8,   23,   21,    0,    2,    5}, {   -9,   23,   22,    0,    2,    5},
    {   -9,   23,   23,    0,    2,    5}, {  -10,   23,   23,    0,    2,    5}, {  -11,   23,   24,    0,    2,    6}, {  -12,   24,   24,    0,    2,    6}, {  -13,   24,   25,    0,    2,    6},
    {  -14,   24,   25,    0,    2,    6}, {  -15,   24,   26,    0,    2,    6}, {  -16,   24,   27,    0,    2,    6}, {  -17,   24,   27,    0,    2,    6}, {  -17,   24,   28,    0,    2,    6},
    {  -18,   24,   28,    0,    2,    6}, {  -19,   24,   29,    0,    2,    6}, {  -20,   24,   29,    0,    2,    6}, {  -21,   23,   30,    0,    2,    7}, {  -22,   23,   30,    0,    2,    7},
    {  -23,   23,   31,    0,    2,    7}, {  -24,   23,   32,    0,    2,    7}, {  -25,   23,   32,    0,    2,    7}, {  -26,   23,   33,    0,    2,    7}, {  -27,   23,   33,    0,    2,    7},
    {  -28,   23,   34,    0,    2,    7}, {  -29,   23,   34,    0,    2,    7}, {  -30,   23,   34,    0,    2,    7}, {  -31,   22,   35,    0,    2,    7}, {  -32,   22,   35,    0,    2,    7},
    {  -33,   22,   36,    0,    2,    8}, {  -34,   22,   36,    0,    2,    8}, {  -35,   22,   37,    0,    2,    8}, {  -36,   22,   37,    0,    2,    8}, {  -37,   21,   37,    0,    2,    8},
    {  -38,   21,   38,    0,    2,    8}, {  -39,   21,   38,    0,    2,    8}, {  -40,   21,   38,    0,    2,    8}, {  -41,   21,   39,    0,    2,    8}, {  -42,   21,   39,    0,    2,    8},
    {  -43,   20,   39,    0,    2,    8}, {  -44,   20,   40,    0,    2,    8}, {  -45,   20,   40,    0,    0,    9}, {  -46,   20,   40,    0,    0,    9}, {  -47,   19,   40,    0,    0,    9},
    {  -48,   19,   40,    0,    0,    9}, {  -49,   19,   41,    0,    0,    9}, {  -50,   19,   41,    0,    0,    9}, {  -51,   19,   41,    0,    0,    9}, {  -52,   18,   41,    0,    0,    9},
    {  -53,   18,   41,    0,    0,    9}, {  -54,   18,   41,    0,    0,    9}, {  -55,   18,   41,    0,    0,    9}, {  -56,   18,   42,    0,    0,    9}, {  -57,   17,   42,   16,   16,    0},
    {  -58,   17,   42,   16,   16,    0}, {  -60,   17,   42,   16,   16,    0}, {  -61,   17,   42,   16,   16,    0}, {  -62,   17,   42,   16,   16,    0}, {  -63,   16,   42,   16,   16,    0},
    {  -64,   16,   42,   16,   16,    0}, {  -64,   16,   42,   16,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftZeroGRollUp1, {
    {   16,    0,   -1,    8,    2,    0}, {   16,    1,    0,    8,    2,    0}, {   16,    2,    0,    8,    2,    0}, {   16,    3,    1,    8,    2,    0}, {   17,    4,    1,    8,    2,    0},
    {   17,    5,    1,    8,    2,    0}, {   17,    6,    2,    8,    2,    0}, {   17,    7,    2,    8,    2,    0}, {   17,    8,    3,    8,    2,    0}, {   17,    8,    3,    8,    2,    0},
    {   18,    9,    4,    8,    2,    1}, {   18,   10,    4,    8,    2,    1}, {   18,   11,    4,    8,    2,    1}, {   18,   12,    5,    8,    2,    1}, {   18,   13,    5,    8,    2,    1},
    {   18,   14,    6,    8,    2,    1}, {   19,   14,    6,    8,    2,    1}, {   19,   15,    7,    8,    2,    1}, {   19,   16,    7,    8,    2,    1}, {   19,   17,    8,    8,    2,    1},
    {   19,   18,    8,    8,    2,    1}, {   20,   19,    9,    8,    2,    1}, {   20,   20,    9,    8,    2,    1}, {   20,   21,   10,    8,    2,    1}, {   20,   22,   10,    8,    2,    1},
    {   20,   23,   11,    8,    2,    2}, {   21,   24,   11,    8,    2,    2}, {   21,   25,   12,    8,    2,    2}, {   21,   26,   12,    8,    2,    2}, {   21,   27,   13,    8,    2,    2},
    {   21,   27,   14,    8,    2,    2}, {   21,   28,   14,    8,    2,    2}, {   22,   29,   15,    8,    2,    2}, {   22,   30,   15,    8,    2,    2}, {   22,   31,   16,    8,    2,    2},
    {   22,   32,   16,    8,    2,    2}, {   22,   33,   17,    8,    2,    2}, {   22,   34,   17,    8,    2,    5}, {   23,   35,   18,    8,    2,    5}, {   23,   35,   19,    8,    2,    5},
    {   23,   36,   19,    8,    2,    5}, {   23,   37,   20,    8,    2,    5}, {   23,   38,   20,    8,    2,    5}, {   23,   39,   21,    8,    2,    5}, {   23,   40,   21,    8,    2,    5},
    {   23,   41,   22,    8,    2,    5}, {   23,   41,   23,    8,    2,    5}, {   23,   42,   23,    8,    2,    5}, {   23,   43,   24,    8,    2,    6}, {   24,   44,   24,    8,    2,    6},
    {   24,   45,   25,    8,    2,    6}, {   24,   46,   25,    8,    2,    6}, {   24,   47,   26,    8,    2,    6}, {   24,   48,   27,    8,    2,    6}, {   24,   49,   27,    8,    2,    6},
    {   24,   49,   28,    8,    2,    6}, {   24,   50,   28,    8,    2,    6}, {   24,   51,   29,    8,    2,    6}, {   24,   52,   29,    8,    2,    6}, {   23,   53,   30,    8,    2,    7},
    {   23,   54,   30,    8,    2,    7}, {   23,   55,   31,    8,    2,    7}, {   23,   56,   32,    8,    2,    7}, {   23,   57,   32,    8,    2,    7}, {   23,   58,   33,    8,    2,    7},
    {   23,   59,   33,    8,    2,    7}, {   23,   60,   34,    8,    2,    7}, {   23,   61,   34,    8,    2,    7}, {   23,   62,   34,    8,    2,    7}, {   22,   63,   35,    8,    2,    7},
    {   22,   64,   35,    8,    2,    7}, {   22,   65,   36,    8,    2,    8}, {   22,   66,   36,    8,    2,    8}, {   22,   67,   37,    8,    2,    8}, {   22,   68,   37,    8,    2,    8},
    {   21,   69,   37,    8,    2,    8}, {   21,   70,   38,    8,    2,    8}, {   21,   71,   38,    8,    2,    8}, {   21,   72,   38,    8,    2,    8}, {   21,   73,   39,    8,    2,    8},
    {   21,   74,   39,    8,    2,    8}, {   20,   75,   39,    8,    2,    8}, {   20,   76,   40,    8,    2,    8}, {   20,   77,   40,    8,    0,    9}, {   20,   78,   40,    8,    0,    9},
    {   19,   79,   40,    8,    0,    9}, {   19,   80,   40,    8,    0,    9}, {   19,   81,   41,    8,    0,    9}, {   19,   82,   41,    8,    0,    9}, {   19,   83,   41,    8,    0,    9},
    {   18,   84,   41,    8,    0,    9}, {   18,   85,   41,    8,    0,    9}, {   18,   86,   41,    8,    0,    9}, {   18,   87,   41,    8,    0,    9}, {   18,   88,   42,    8,    0,    9},
    {   17,   89,   42,   24,   16,    0}, {   17,   90,   42,   24,   16,    0}, {   17,   92,   42,   24,   16,    0}, {   17,   93,   42,   24,   16,    0}, {   17,   94,   42,   24,   16,    0},
    {   16,   95,   42,   24,   16,    0}, {   16,   96,   42,   24,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftZeroGRollUp2, {
    {    0,   16,   -1,   16,    2,    0}, {    1,   16,    0,   16,    2,    0}, {    2,   16,    0,   16,    2,    0}, {    3,   16,    1,   16,    2,    0}, {    4,   15,    1,   16,    2,    0},
    {    5,   15,    1,   16,    2,    0}, {    6,   15,    2,   16,    2,    0}, {    7,   15,    2,   16,    2,    0}, {    8,   15,    3,   16,    2,    0}, {    8,   15,    3,   16,    2,    0},
    {    9,   14,    4,   16,    2,    1}, {   10,   14,    4,   16,    2,    1}, {   11,   14,    4,   16,    2,    1}, {   12,   14,    5,   16,    2,    1}, {   13,   14,    5,   16,    2,    1},
    {   14,   14,    6,   16,    2,    1}, {   14,   13,    6,   16,    2,    1}, {   15,   13,    7,   16,    2,    1}, {   16,   13,    7,   16,    2,    1}, {   17,   13,    8,   16,    2,    1},
    {   18,   13,    8,   16,    2,    1}, {   19,   12,    9,   16,    2,    1}, {   20,   12,    9,   16,    2,    1}, {   21,   12,   10,   16,    2,    1}, {   22,   12,   10,   16,    2,    1},
    {   23,   12,   11,   16,    2,    2}, {   24,   11,   11,   16,    2,    2}, {   25,   11,   12,   16,    2,    2}, {   26,   11,   12,   16,    2,    2}, {   27,   11,   13,   16,    2,    2},
    {   27,   11,   14,   16,    2,    2}, {   28,   11,   14,   16,    2,    2}, {   29,   10,   15,   16,    2,    2}, {   30,   10,   15,   16,    2,    2}, {   31,   10,   16,   16,    2,    2},
    {   32,   10,   16,   16,    2,    2}, {   33,   10,   17,   16,    2,    2}, {   34,   10,   17,   16,    2,    5}, {   35,    9,   18,   16,    2,    5}, {   35,    9,   19,   16,    2,    5},
    {   36,    9,   19,   16,    2,    5}, {   37,    9,   20,   16,    2,    5}, {   38,    9,   20,   16,    2,    5}, {   39,    9,   21,   16,    2,    5}, {   40,    9,   21,   16,    2,    5},
    {   41,    9,   22,   16,    2,    5}, {   41,    9,   23,   16,    2,    5}, {   42,    9,   23,   16,    2,    5}, {   43,    9,   24,   16,    2,    6}, {   44,    8,   24,   16,    2,    6},
    {   45,    8,   25,   16,    2,    6}, {   46,    8,   25,   16,    2,    6}, {   47,    8,   26,   16,    2,    6}, {   48,    8,   27,   16,    2,    6}, {   49,    8,   27,   16,    2,    6},
    {   49,    8,   28,   16,    2,    6}, {   50,    8,   28,   16,    2,    6}, {   51,    8,   29,   16,    2,    6}, {   52,    8,   29,   16,    2,    6}, {   53,    9,   30,   16,    2,    7},
    {   54,    9,   30,   16,    2,    7}, {   55,    9,   31,   16,    2,    7}, {   56,    9,   32,   16,    2,    7}, {   57,    9,   32,   16,    2,    7}, {   58,    9,   33,   16,    2,    7},
    {   59,    9,   33,   16,    2,    7}, {   60,    9,   34,   16,    2,    7}, {   61,    9,   34,   16,    2,    7}, {   62,    9,   34,   16,    2,    7}, {   63,   10,   35,   16,    2,    7},
    {   64,   10,   35,   16,    2,    7}, {   65,   10,   36,   16,    2,    8}, {   66,   10,   36,   16,    2,    8}, {   67,   10,   37,   16,    2,    8}, {   68,   10,   37,   16,    2,    8},
    {   69,   11,   37,   16,    2,    8}, {   70,   11,   38,   16,    2,    8}, {   71,   11,   38,   16,    2,    8}, {   72,   11,   38,   16,    2,    8}, {   73,   11,   39,   16,    2,    8},
    {   74,   11,   39,   16,    2,    8}, {   75,   12,   39,   16,    2,    8}, {   76,   12,   40,   16,    2,    8}, {   77,   12,   40,   16,    0,    9}, {   78,   12,   40,   16,    0,    9},
    {   79,   13,   40,   16,    0,    9}, {   80,   13,   40,   16,    0,    9}, {   81,   13,   41,   16,    0,    9}, {   82,   13,   41,   16,    0,    9}, {   83,   13,   41,   16,    0,    9},
    {   84,   14,   41,   16,    0,    9}, {   85,   14,   41,   16,    0,    9}, {   86,   14,   41,   16,    0,    9}, {   87,   14,   41,   16,    0,    9}, {   88,   14,   42,   16,    0,    9},
    {   89,   15,   42,    0,   16,    0}, {   90,   15,   42,    0,   16,    0}, {   92,   15,   42,    0,   16,    0}, {   93,   15,   42,    0,   16,    0}, {   94,   15,   42,    0,   16,    0},
    {   95,   16,   42,    0,   16,    0}, {   96,   16,   42,    0,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftZeroGRollUp3, {
    {   16,   31,    0,   24,    2,    0}, {   16,   30,    0,   24,    2,    0}, {   16,   29,    1,   24,    2,    0}, {   15,   28,    1,   24,    2,    0}, {   15,   27,    1,   24,    2,    0},
    {   15,   26,    2,   24,    2,    0}, {   15,   25,    2,   24,    2,    0}, {   15,   24,    3,   24,    2,    0}, {   15,   24,    3,   24,    2,    0}, {   14,   23,    4,   24,    2,    1},
    {   14,   22,    4,   24,    2,    1}, {   14,   21,    4,   24,    2,    1}, {   14,   20,    5,   24,    2,    1}, {   14,   19,    5,   24,    2,    1}, {   14,   18,    6,   24,    2,    1},
    {   13,   18,    6,   24,    2,    1}, {   13,   17,    7,   24,    2,    1}, {   13,   16,    7,   24,    2,    1}, {   13,   15,    8,   24,    2,    1}, {   13,   14,    8,   24,    2,    1},
    {   12,   13,    9,   24,    2,    1}, {   12,   12,    9,   24,    2,    1}, {   12,   11,   10,   24,    2,    1}, {   12,   10,   10,   24,    2,    1}, {   12,    9,   11,   24,    2,    2},
    {   11,    8,   11,   24,    2,    2}, {   11,    7,   12,   24,    2,    2}, {   11,    6,   12,   24,    2,    2}, {   11,    5,   13,   24,    2,    2}, {   11,    5,   14,   24,    2,    2},
    {   11,    4,   14,   24,    2,    2}, {   10,    3,   15,   24,    2,    2}, {   10,    2,   15,   24,    2,    2}, {   10,    1,   16,   24,    2,    2}, {   10,    0,   16,   24,    2,    2},
    {   10,   -1,   17,   24,    2,    2}, {   10,   -2,   17,   24,    2,    5}, {    9,   -3,   18,   24,    2,    5}, {    9,   -3,   19,   24,    2,    5}, {    9,   -4,   19,   24,    2,    5},
    {    9,   -5,   20,   24,    2,    5}, {    9,   -6,   20,   24,    2,    5}, {    9,   -7,   21,   24,    2,    5}, {    9,   -8,   21,   24,    2,    5}, {    9,   -9,   22,   24,    2,    5},
    {    9,   -9,   23,   24,    2,    5}, {    9,  -10,   23,   24,    2,    5}, {    9,  -11,   24,   24,    2,    6}, {    8,  -12,   24,   24,    2,    6}, {    8,  -13,   25,   24,    2,    6},
    {    8,  -14,   25,   24,    2,    6}, {    8,  -15,   26,   24,    2,    6}, {    8,  -16,   27,   24,    2,    6}, {    8,  -17,   27,   24,    2,    6}, {    8,  -17,   28,   24,    2,    6},
    {    8,  -18,   28,   24,    2,    6}, {    8,  -19,   29,   24,    2,    6}, {    8,  -20,   29,   24,    2,    6}, {    9,  -21,   30,   24,    2,    7}, {    9,  -22,   30,   24,    2,    7},
    {    9,  -23,   31,   24,    2,    7}, {    9,  -24,   32,   24,    2,    7}, {    9,  -25,   32,   24,    2,    7}, {    9,  -26,   33,   24,    2,    7}, {    9,  -27,   33,   24,    2,    7},
    {    9,  -28,   34,   24,    2,    7}, {    9,  -29,   34,   24,    2,    7}, {    9,  -30,   34,   24,    2,    7}, {   10,  -31,   35,   24,    2,    7}, {   10,  -32,   35,   24,    2,    7},
    {   10,  -33,   36,   24,    2,    8}, {   10,  -34,   36,   24,    2,    8}, {   10,  -35,   37,   24,    2,    8}, {   10,  -36,   37,   24,    2,    8}, {   11,  -37,   37,   24,    2,    8},
    {   11,  -38,   38,   24,    2,    8}, {   11,  -39,   38,   24,    2,    8}, {   11,  -40,   38,   24,    2,    8}, {   11,  -41,   39,   24,    2,    8}, {   11,  -42,   39,   24,    2,    8},
    {   12,  -43,   39,   24,    2,    8}, {   12,  -44,   40,   24,    2,    8}, {   12,  -45,   40,   24,    0,    9}, {   12,  -46,   40,   24,    0,    9}, {   13,  -47,   40,   24,    0,    9},
    {   13,  -48,   40,   24,    0,    9}, {   13,  -49,   41,   24,    0,    9}, {   13,  -50,   41,   24,    0,    9}, {   13,  -51,   41,   24,    0,    9}, {   14,  -52,   41,   24,    0,    9},
    {   14,  -53,   41,   24,    0,    9}, {   14,  -54,   41,   24,    0,    9}, {   14,  -55,   41,   24,    0,    9}, {   14,  -56,   42,   24,    0,    9}, {   15,  -57,   42,    8,   16,    0},
    {   15,  -58,   42,    8,   16,    0}, {   15,  -60,   42,    8,   16,    0}, {   15,  -61,   42,    8,   16,    0}, {   15,  -62,   42,    8,   16,    0}, {   16,  -63,   42,    8,   16,    0},
    {   16,  -64,   42,    8,   16,    0}, {   16,  -64,   42,    8,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightZeroGRollUp0, {
    {   31,   16,    0,    1,    2,    0}, {   30,   16,    0,    1,    2,    0}, {   29,   16,    1,    1,    2,    0}, {   28,   15,    1,    1,    2,    0}, {   27,   15,    1,    1,    2,    0},
    {   26,   15,    2,    1,    2,    0}, {   25,   15,    2,    1,    2,    0}, {   24,   15,    3,    1,    2,    0}, {   24,   15,    3,    1,    2,    0}, {   23,   14,    4,    1,    2,    0},
    {   22,   14,    4,    1,    2,    0}, {   21,   14,    4,    1,    2,    0}, {   20,   14,    5,    1,    2,    0}, {   19,   14,    5,    0,    2,    3}, {   18,   14,    6,    0,    2,    3},
    {   18,   13,    6,    0,    2,    3}, {   17,   13,    7,    0,    2,    3}, {   16,   13,    7,    0,    2,    3}, {   15,   13,    8,    0,    2,    3}, {   14,   13,    8,    0,    2,    3},
    {   13,   12,    9,    0,    2,    3}, {   12,   12,    9,    1,    1,    3}, {   11,   12,   10,    1,    1,    3}, {   10,   12,   10,    1,    1,    3}, {    9,   12,   11,    1,    2,    4},
    {    8,   11,   11,    1,    2,    4}, {    7,   11,   12,    1,    2,    4}, {    6,   11,   12,    1,    2,    4}, {    5,   11,   13,    1,    2,    4}, {    5,   11,   14,    1,    2,    4},
    {    4,   11,   14,    1,    2,    4}, {    3,   10,   15,    1,    2,    4}, {    2,   10,   15,    1,    2,    4}, {    1,   10,   16,    1,    2,    4}, {    0,   10,   16,    1,    2,    4},
    {   -1,   10,   17,    1,    2,    4}, {   -2,   10,   17,    1,    2,    4}, {   -3,    9,   18,    1,    2,    4}, {   -3,    9,   19,    0,    2,   10}, {   -4,    9,   19,    0,    2,   10},
    {   -5,    9,   20,    0,    2,   10}, {   -6,    9,   20,    0,    2,   10}, {   -7,    9,   21,    0,    2,   10}, {   -8,    9,   21,    0,    2,   10}, {   -9,    9,   22,    0,    2,   10},
    {   -9,    9,   23,    0,    2,   10}, {  -10,    9,   23,    0,    2,   10}, {  -11,    9,   24,    0,    2,   11}, {  -12,    8,   24,    0,    2,   11}, {  -13,    8,   25,    0,    2,   11},
    {  -14,    8,   25,    0,    2,   11}, {  -15,    8,   26,    0,    2,   11}, {  -16,    8,   27,    0,    2,   11}, {  -17,    8,   27,    0,    2,   11}, {  -17,    8,   28,    0,    2,   11},
    {  -18,    8,   28,    0,    2,   11}, {  -19,    8,   29,    0,    2,   11}, {  -20,    8,   29,    0,    2,   11}, {  -21,    9,   30,    0,    2,   12}, {  -22,    9,   30,    0,    2,   12},
    {  -23,    9,   31,    0,    2,   12}, {  -24,    9,   32,    0,    2,   12}, {  -25,    9,   32,    0,    2,   12}, {  -26,    9,   33,    0,    2,   12}, {  -27,    9,   33,    0,    2,   12},
    {  -28,    9,   34,    0,    2,   12}, {  -29,    9,   34,    0,    2,   12}, {  -30,    9,   34,    0,    2,   12}, {  -31,   10,   35,    0,    2,   12}, {  -32,   10,   35,    0,    2,   12},
    {  -33,   10,   36,    0,    2,   13}, {  -34,   10,   36,    0,    2,   13}, {  -35,   10,   37,    0,    2,   13}, {  -36,   10,   37,    0,    2,   13}, {  -37,   11,   37,    0,    2,   13},
    {  -38,   11,   38,    0,    2,   13}, {  -39,   11,   38,    0,    2,   13}, {  -40,   11,   38,    0,    2,   13}, {  -41,   11,   39,    0,    2,   13}, {  -42,   11,   39,    0,    2,   13},
    {  -43,   12,   39,    0,    2,   13}, {  -44,   12,   40,    0,    2,   13}, {  -45,   12,   40,    0,    0,   14}, {  -46,   12,   40,    0,    0,   14}, {  -47,   13,   40,    0,    0,   14},
    {  -48,   13,   40,    0,    0,   14}, {  -49,   13,   41,    0,    0,   14}, {  -50,   13,   41,    0,    0,   14}, {  -51,   13,   41,    0,    0,   14}, {  -52,   14,   41,    0,    0,   14},
    {  -53,   14,   41,    0,    0,   14}, {  -54,   14,   41,    0,    0,   14}, {  -55,   14,   41,    0,    0,   14}, {  -56,   14,   42,    0,    0,   14}, {  -57,   15,   42,   16,   16,    0},
    {  -58,   15,   42,   16,   16,    0}, {  -60,   15,   42,   16,   16,    0}, {  -61,   15,   42,   16,   16,    0}, {  -62,   15,   42,   16,   16,    0}, {  -63,   16,   42,   16,   16,    0},
    {  -64,   16,   42,   16,   16,    0}, {  -64,   16,   42,   16,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightZeroGRollUp1, {
    {   16,    0,   -1,    8,    2,    0}, {   16,    1,    0,    9,    2,    0}, {   16,    2,    0,    9,    2,    0}, {   16,    3,    1,    9,    2,    0}, {   15,    4,    1,    9,    2,    0},
    {   15,    5,    1,    9,    2,    0}, {   15,    6,    2,    9,    2,    0}, {   15,    7,    2,    9,    2,    0}, {   15,    8,    3,    9,    2,    0}, {   15,    8,    3,    9,    2,    0},
    {   14,    9,    4,    9,    2,    0}, {   14,   10,    4,    9,    2,    0}, {   14,   11,    4,    9,    2,    0}, {   14,   12,    5,    9,    2,    0}, {   14,   13,    5,    8,    2,    3},
    {   14,   14,    6,    8,    2,    3}, {   13,   14,    6,    8,    2,    3}, {   13,   15,    7,    8,    2,    3}, {   13,   16,    7,    8,    2,    3}, {   13,   17,    8,    8,    2,    3},
    {   13,   18,    8,    8,    2,    3}, {   12,   19,    9,    8,    2,    3}, {   12,   20,    9,    9,    1,    3}, {   12,   21,   10,    9,    1,    3}, {   12,   22,   10,    9,    1,    3},
    {   12,   23,   11,    9,    2,    4}, {   11,   24,   11,    9,    2,    4}, {   11,   25,   12,    9,    2,    4}, {   11,   26,   12,    9,    2,    4}, {   11,   27,   13,    9,    2,    4},
    {   11,   27,   14,    9,    2,    4}, {   11,   28,   14,    9,    2,    4}, {   10,   29,   15,    9,    2,    4}, {   10,   30,   15,    9,    2,    4}, {   10,   31,   16,    9,    2,    4},
    {   10,   32,   16,    9,    2,    4}, {   10,   33,   17,    9,    2,    4}, {   10,   34,   17,    9,    2,    4}, {    9,   35,   18,    9,    2,    4}, {    9,   35,   19,    8,    2,   10},
    {    9,   36,   19,    8,    2,   10}, {    9,   37,   20,    8,    2,   10}, {    9,   38,   20,    8,    2,   10}, {    9,   39,   21,    8,    2,   10}, {    9,   40,   21,    8,    2,   10},
    {    9,   41,   22,    8,    2,   10}, {    9,   41,   23,    8,    2,   10}, {    9,   42,   23,    8,    2,   10}, {    9,   43,   24,    8,    2,   11}, {    8,   44,   24,    8,    2,   11},
    {    8,   45,   25,    8,    2,   11}, {    8,   46,   25,    8,    2,   11}, {    8,   47,   26,    8,    2,   11}, {    8,   48,   27,    8,    2,   11}, {    8,   49,   27,    8,    2,   11},
    {    8,   49,   28,    8,    2,   11}, {    8,   50,   28,    8,    2,   11}, {    8,   51,   29,    8,    2,   11}, {    8,   52,   29,    8,    2,   11}, {    9,   53,   30,    8,    2,   12},
    {    9,   54,   30,    8,    2,   12}, {    9,   55,   31,    8,    2,   12}, {    9,   56,   32,    8,    2,   12}, {    9,   57,   32,    8,    2,   12}, {    9,   58,   33,    8,    2,   12},
    {    9,   59,   33,    8,    2,   12}, {    9,   60,   34,    8,    2,   12}, {    9,   61,   34,    8,    2,   12}, {    9,   62,   34,    8,    2,   12}, {   10,   63,   35,    8,    2,   12},
    {   10,   64,   35,    8,    2,   12}, {   10,   65,   36,    8,    2,   13}, {   10,   66,   36,    8,    2,   13}, {   10,   67,   37,    8,    2,   13}, {   10,   68,   37,    8,    2,   13},
    {   11,   69,   37,    8,    2,   13}, {   11,   70,   38,    8,    2,   13}, {   11,   71,   38,    8,    2,   13}, {   11,   72,   38,    8,    2,   13}, {   11,   73,   39,    8,    2,   13},
    {   11,   74,   39,    8,    2,   13}, {   12,   75,   39,    8,    2,   13}, {   12,   76,   40,    8,    2,   13}, {   12,   77,   40,    8,    0,   14}, {   12,   78,   40,    8,    0,   14},
    {   13,   79,   40,    8,    0,   14}, {   13,   80,   40,    8,    0,   14}, {   13,   81,   41,    8,    0,   14}, {   13,   82,   41,    8,    0,   14}, {   13,   83,   41,    8,    0,   14},
    {   14,   84,   41,    8,    0,   14}, {   14,   85,   41,    8,    0,   14}, {   14,   86,   41,    8,    0,   14}, {   14,   87,   41,    8,    0,   14}, {   14,   88,   42,    8,    0,   14},
    {   15,   89,   42,   24,   16,    0}, {   15,   90,   42,   24,   16,    0}, {   15,   92,   42,   24,   16,    0}, {   15,   93,   42,   24,   16,    0}, {   15,   94,   42,   24,   16,    0},
    {   16,   95,   42,   24,   16,    0}, {   16,   96,   42,   24,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightZeroGRollUp2, {
    {    0,   16,   -1,   16,    2,    0}, {    1,   16,    0,   17,    2,    0}, {    2,   16,    0,   17,    2,    0}, {    3,   16,    1,   17,    2,    0}, {    4,   17,    1,   17,    2,    0},
    {    5,   17,    1,   17,    2,    0}, {    6,   17,    2,   17,    2,    0}, {    7,   17,    2,   17,    2,    0}, {    8,   17,    3,   17,    2,    0}, {    8,   17,    3,   17,    2,    0},
    {    9,   18,    4,   17,    2,    0}, {   10,   18,    4,   17,    2,    0}, {   11,   18,    4,   17,    2,    0}, {   12,   18,    5,   17,    2,    0}, {   13,   18,    5,   16,    2,    3},
    {   14,   18,    6,   16,    2,    3}, {   14,   19,    6,   16,    2,    3}, {   15,   19,    7,   16,    2,    3}, {   16,   19,    7,   16,    2,    3}, {   17,   19,    8,   16,    2,    3},
    {   18,   19,    8,   16,    2,    3}, {   19,   20,    9,   16,    2,    3}, {   20,   20,    9,   17,    1,    3}, {   21,   20,   10,   17,    1,    3}, {   22,   20,   10,   17,    1,    3},
    {   23,   20,   11,   17,    2,    4}, {   24,   21,   11,   17,    2,    4}, {   25,   21,   12,   17,    2,    4}, {   26,   21,   12,   17,    2,    4}, {   27,   21,   13,   17,    2,    4},
    {   27,   21,   14,   17,    2,    4}, {   28,   21,   14,   17,    2,    4}, {   29,   22,   15,   17,    2,    4}, {   30,   22,   15,   17,    2,    4}, {   31,   22,   16,   17,    2,    4},
    {   32,   22,   16,   17,    2,    4}, {   33,   22,   17,   17,    2,    4}, {   34,   22,   17,   17,    2,    4}, {   35,   23,   18,   17,    2,    4}, {   35,   23,   19,   16,    2,   10},
    {   36,   23,   19,   16,    2,   10}, {   37,   23,   20,   16,    2,   10}, {   38,   23,   20,   16,    2,   10}, {   39,   23,   21,   16,    2,   10}, {   40,   23,   21,   16,    2,   10},
    {   41,   23,   22,   16,    2,   10}, {   41,   23,   23,   16,    2,   10}, {   42,   23,   23,   16,    2,   10}, {   43,   23,   24,   16,    2,   11}, {   44,   24,   24,   16,    2,   11},
    {   45,   24,   25,   16,    2,   11}, {   46,   24,   25,   16,    2,   11}, {   47,   24,   26,   16,    2,   11}, {   48,   24,   27,   16,    2,   11}, {   49,   24,   27,   16,    2,   11},
    {   49,   24,   28,   16,    2,   11}, {   50,   24,   28,   16,    2,   11}, {   51,   24,   29,   16,    2,   11}, {   52,   24,   29,   16,    2,   11}, {   53,   23,   30,   16,    2,   12},
    {   54,   23,   30,   16,    2,   12}, {   55,   23,   31,   16,    2,   12}, {   56,   23,   32,   16,    2,   12}, {   57,   23,   32,   16,    2,   12}, {   58,   23,   33,   16,    2,   12},
    {   59,   23,   33,   16,    2,   12}, {   60,   23,   34,   16,    2,   12}, {   61,   23,   34,   16,    2,   12}, {   62,   23,   34,   16,    2,   12}, {   63,   22,   35,   16,    2,   12},
    {   64,   22,   35,   16,    2,   12}, {   65,   22,   36,   16,    2,   13}, {   66,   22,   36,   16,    2,   13}, {   67,   22,   37,   16,    2,   13}, {   68,   22,   37,   16,    2,   13},
    {   69,   21,   37,   16,    2,   13}, {   70,   21,   38,   16,    2,   13}, {   71,   21,   38,   16,    2,   13}, {   72,   21,   38,   16,    2,   13}, {   73,   21,   39,   16,    2,   13},
    {   74,   21,   39,   16,    2,   13}, {   75,   20,   39,   16,    2,   13}, {   76,   20,   40,   16,    2,   13}, {   77,   20,   40,   16,    0,   14}, {   78,   20,   40,   16,    0,   14},
    {   79,   19,   40,   16,    0,   14}, {   80,   19,   40,   16,    0,   14}, {   81,   19,   41,   16,    0,   14}, {   82,   19,   41,   16,    0,   14}, {   83,   19,   41,   16,    0,   14},
    {   84,   18,   41,   16,    0,   14}, {   85,   18,   41,   16,    0,   14}, {   86,   18,   41,   16,    0,   14}, {   87,   18,   41,   16,    0,   14}, {   88,   18,   42,   16,    0,   14},
    {   89,   17,   42,    0,   16,    0}, {   90,   17,   42,    0,   16,    0}, {   92,   17,   42,    0,   16,    0}, {   93,   17,   42,    0,   16,    0}, {   94,   17,   42,    0,   16,    0},
    {   95,   16,   42,    0,   16,    0}, {   96,   16,   42,    0,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightZeroGRollUp3, {
    {   16,   31,    0,   25,    2,    0}, {   16,   30,    0,   25,    2,    0}, {   16,   29,    1,   25,    2,    0}, {   17,   28,    1,   25,    2,    0}, {   17,   27,    1,   25,    2,    0},
    {   17,   26,    2,   25,    2,    0}, {   17,   25,    2,   25,    2,    0}, {   17,   24,    3,   25,    2,    0}, {   17,   24,    3,   25,    2,    0}, {   18,   23,    4,   25,    2,    0},
    {   18,   22,    4,   25,    2,    0}, {   18,   21,    4,   25,    2,    0}, {   18,   20,    5,   25,    2,    0}, {   18,   19,    5,   24,    2,    3}, {   18,   18,    6,   24,    2,    3},
    {   19,   18,    6,   24,    2,    3}, {   19,   17,    7,   24,    2,    3}, {   19,   16,    7,   24,    2,    3}, {   19,   15,    8,   24,    2,    3}, {   19,   14,    8,   24,    2,    3},
    {   20,   13,    9,   24,    2,    3}, {   20,   12,    9,   25,    1,    3}, {   20,   11,   10,   25,    1,    3}, {   20,   10,   10,   25,    1,    3}, {   20,    9,   11,   25,    2,    4},
    {   21,    8,   11,   25,    2,    4}, {   21,    7,   12,   25,    2,    4}, {   21,    6,   12,   25,    2,    4}, {   21,    5,   13,   25,    2,    4}, {   21,    5,   14,   25,    2,    4},
    {   21,    4,   14,   25,    2,    4}, {   22,    3,   15,   25,    2,    4}, {   22,    2,   15,   25,    2,    4}, {   22,    1,   16,   25,    2,    4}, {   22,    0,   16,   25,    2,    4},
    {   22,   -1,   17,   25,    2,    4}, {   22,   -2,   17,   25,    2,    4}, {   23,   -3,   18,   25,    2,    4}, {   23,   -3,   19,   24,    2,   10}, {   23,   -4,   19,   24,    2,   10},
    {   23,   -5,   20,   24,    2,   10}, {   23,   -6,   20,   24,    2,   10}, {   23,   -7,   21,   24,    2,   10}, {   23,   -8,   21,   24,    2,   10}, {   23,   -9,   22,   24,    2,   10},
    {   23,   -9,   23,   24,    2,   10}, {   23,  -10,   23,   24,    2,   10}, {   23,  -11,   24,   24,    2,   11}, {   24,  -12,   24,   24,    2,   11}, {   24,  -13,   25,   24,    2,   11},
    {   24,  -14,   25,   24,    2,   11}, {   24,  -15,   26,   24,    2,   11}, {   24,  -16,   27,   24,    2,   11}, {   24,  -17,   27,   24,    2,   11}, {   24,  -17,   28,   24,    2,   11},
    {   24,  -18,   28,   24,    2,   11}, {   24,  -19,   29,   24,    2,   11}, {   24,  -20,   29,   24,    2,   11}, {   23,  -21,   30,   24,    2,   12}, {   23,  -22,   30,   24,    2,   12},
    {   23,  -23,   31,   24,    2,   12}, {   23,  -24,   32,   24,    2,   12}, {   23,  -25,   32,   24,    2,   12}, {   23,  -26,   33,   24,    2,   12}, {   23,  -27,   33,   24,    2,   12},
    {   23,  -28,   34,   24,    2,   12}, {   23,  -29,   34,   24,    2,   12}, {   23,  -30,   34,   24,    2,   12}, {   22,  -31,   35,   24,    2,   12}, {   22,  -32,   35,   24,    2,   12},
    {   22,  -33,   36,   24,    2,   13}, {   22,  -34,   36,   24,    2,   13}, {   22,  -35,   37,   24,    2,   13}, {   22,  -36,   37,   24,    2,   13}, {   21,  -37,   37,   24,    2,   13},
    {   21,  -38,   38,   24,    2,   13}, {   21,  -39,   38,   24,    2,   13}, {   21,  -40,   38,   24,    2,   13}, {   21,  -41,   39,   24,    2,   13}, {   21,  -42,   39,   24,    2,   13},
    {   20,  -43,   39,   24,    2,   13}, {   20,  -44,   40,   24,    2,   13}, {   20,  -45,   40,   24,    0,   14}, {   20,  -46,   40,   24,    0,   14}, {   19,  -47,   40,   24,    0,   14},
    {   19,  -48,   40,   24,    0,   14}, {   19,  -49,   41,   24,    0,   14}, {   19,  -50,   41,   24,    0,   14}, {   19,  -51,   41,   24,    0,   14}, {   18,  -52,   41,   24,    0,   14},
    {   18,  -53,   41,   24,    0,   14}, {   18,  -54,   41,   24,    0,   14}, {   18,  -55,   41,   24,    0,   14}, {   18,  -56,   42,   24,    0,   14}, {   17,  -57,   42,    8,   16,    0},
    {   17,  -58,   42,    8,   16,    0}, {   17,  -60,   42,    8,   16,    0}, {   17,  -61,   42,    8,   16,    0}, {   17,  -62,   42,    8,   16,    0}, {   16,  -63,   42,    8,   16,    0},
    {   16,  -64,   42,    8,   16,    0}, {   16,  -64,   42,    8,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftZeroGRollDown0, {
    {   32,   16,   19,   16,   16,    0}, {   31,   16,   19,   16,   16,    0}, {   30,   15,   19,   16,   16,    0}, {   29,   15,   19,   16,   16,    0}, {   28,   15,   19,   16,   16,    0},
    {   26,   15,   19,   16,   16,    0}, {   25,   15,   19,   16,   16,    0}, {   24,   14,   19,    0,    0,   14}, {   23,   14,   19,    0,    0,   14}, {   22,   14,   19,    0,    0,   14},
    {   21,   14,   19,    0,    0,   14}, {   20,   14,   18,    0,    0,   14}, {   19,   13,   18,    0,    0,   14}, {   18,   13,   18,    0,    0,   14}, {   17,   13,   18,    0,    0,   14},
    {   16,   13,   18,    0,    0,   14}, {   15,   13,   18,    0,    0,   14}, {   14,   12,   17,    0,    0,   14}, {   13,   12,   17,    0,    0,   14}, {   12,   12,   17,    0,    6,   13},
    {   11,   12,   17,    0,    6,   13}, {   10,   11,   16,    0,    6,   13}, {    9,   11,   16,    0,    6,   13}, {    8,   11,   16,    0,    6,   13}, {    7,   11,   15,    0,    6,   13},
    {    6,   11,   15,    0,    6,   13}, {    5,   11,   15,    0,    6,   13}, {    4,   10,   14,    0,    6,   13}, {    3,   10,   14,    0,    6,   13}, {    2,   10,   14,    0,    6,   13},
    {    1,   10,   13,    0,    6,   13}, {    0,   10,   13,    0,    6,   12}, {   -1,   10,   12,    0,    6,   12}, {   -2,    9,   12,    0,    6,   12}, {   -3,    9,   11,    0,    6,   12},
    {   -4,    9,   11,    0,    6,   12}, {   -5,    9,   10,    0,    6,   12}, {   -6,    9,   10,    0,    6,   12}, {   -7,    9,    9,    0,    6,   12}, {   -8,    9,    9,    0,    6,   12},
    {   -9,    9,    8,    0,    6,   12}, {  -10,    9,    8,    0,    6,   12}, {  -11,    9,    7,    0,    6,   12}, {  -12,    8,    7,    0,    6,   11}, {  -13,    8,    6,    0,    6,   11},
    {  -14,    8,    6,    0,    6,   11}, {  -15,    8,    5,    0,    6,   11}, {  -15,    8,    4,    0,    6,   11}, {  -16,    8,    4,    0,    6,   11}, {  -17,    8,    3,    0,    6,   11},
    {  -18,    8,    3,    0,    6,   11}, {  -19,    8,    2,    0,    6,   11}, {  -20,    8,    2,    0,    6,   11}, {  -21,    9,    1,    0,    6,   11}, {  -22,    9,    0,    0,    6,   10},
    {  -23,    9,    0,    0,    6,   10}, {  -23,    9,   -1,    0,    6,   10}, {  -24,    9,   -1,    0,    6,   10}, {  -25,    9,   -2,    0,    6,   10}, {  -26,    9,   -2,    0,    6,   10},
    {  -27,    9,   -3,    0,    6,   10}, {  -28,    9,   -4,    0,    6,   10}, {  -29,    9,   -4,    0,    6,   10}, {  -29,    9,   -5,   31,    6,    4}, {  -30,   10,   -5,   31,    6,    4},
    {  -31,   10,   -6,   31,    6,    4}, {  -32,   10,   -6,   31,    6,    4}, {  -33,   10,   -7,   31,    6,    4}, {  -34,   10,   -7,   31,    6,    4}, {  -35,   10,   -8,   31,    6,    4},
    {  -36,   11,   -9,   31,    6,    4}, {  -37,   11,   -9,   31,    6,    4}, {  -37,   11,  -10,   31,    6,    4}, {  -38,   11,  -10,   31,    6,    4}, {  -39,   11,  -11,   31,    6,    4},
    {  -40,   11,  -11,   31,    6,    4}, {  -41,   12,  -12,   31,    6,    4}, {  -42,   12,  -12,   31,    5,    3}, {  -43,   12,  -13,   31,    5,    3}, {  -44,   12,  -13,   31,    5,    3},
    {  -45,   12,  -14,    0,    6,    3}, {  -46,   13,  -14,    0,    6,    3}, {  -47,   13,  -15,    0,    6,    3}, {  -48,   13,  -15,    0,    6,    3}, {  -49,   13,  -16,    0,    6,    3},
    {  -50,   13,  -16,    0,    6,    3}, {  -50,   14,  -17,    0,    6,    3}, {  -51,   14,  -17,    0,    6,    3}, {  -52,   14,  -18,   31,    6,    0}, {  -53,   14,  -18,   31,    6,    0},
    {  -54,   14,  -19,   31,    6,    0}, {  -55,   14,  -19,   31,    6,    0}, {  -56,   15,  -20,   31,    6,    0}, {  -56,   15,  -20,   31,    6,    0}, {  -57,   15,  -20,   31,    6,    0},
    {  -58,   15,  -21,   31,    6,    0}, {  -59,   15,  -21,   31,    6,    0}, {  -60,   15,  -22,   31,    6,    0}, {  -61,   16,  -22,   31,    6,    0}, {  -62,   16,  -23,   31,    6,    0},
    {  -63,   16,  -23,   31,    6,    0}, {  -64,   16,  -24,    0,    6,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftZeroGRollDown1, {
    {   16,    0,   19,   24,   16,    0}, {   16,    0,   19,   24,   16,    0}, {   16,    1,   19,   24,   16,    0}, {   15,    2,   19,   24,   16,    0}, {   15,    3,   19,   24,   16,    0},
    {   15,    4,   19,   24,   16,    0}, {   15,    6,   19,   24,   16,    0}, {   15,    7,   19,   24,   16,    0}, {   14,    8,   19,    8,    0,   14}, {   14,    9,   19,    8,    0,   14},
    {   14,   10,   19,    8,    0,   14}, {   14,   11,   19,    8,    0,   14}, {   14,   12,   18,    8,    0,   14}, {   13,   13,   18,    8,    0,   14}, {   13,   14,   18,    8,    0,   14},
    {   13,   15,   18,    8,    0,   14}, {   13,   16,   18,    8,    0,   14}, {   13,   17,   18,    8,    0,   14}, {   12,   18,   17,    8,    0,   14}, {   12,   19,   17,    8,    0,   14},
    {   12,   20,   17,    8,    6,   13}, {   12,   21,   17,    8,    6,   13}, {   11,   22,   16,    8,    6,   13}, {   11,   23,   16,    8,    6,   13}, {   11,   24,   16,    8,    6,   13},
    {   11,   25,   15,    8,    6,   13}, {   11,   26,   15,    8,    6,   13}, {   11,   27,   15,    8,    6,   13}, {   10,   28,   14,    8,    6,   13}, {   10,   29,   14,    8,    6,   13},
    {   10,   30,   14,    8,    6,   13}, {   10,   31,   13,    8,    6,   13}, {   10,   32,   13,    8,    6,   12}, {   10,   33,   12,    8,    6,   12}, {    9,   34,   12,    8,    6,   12},
    {    9,   35,   11,    8,    6,   12}, {    9,   36,   11,    8,    6,   12}, {    9,   37,   10,    8,    6,   12}, {    9,   38,   10,    8,    6,   12}, {    9,   39,    9,    8,    6,   12},
    {    9,   40,    9,    8,    6,   12}, {    9,   41,    8,    8,    6,   12}, {    9,   42,    8,    8,    6,   12}, {    9,   43,    7,    8,    6,   12}, {    8,   44,    7,    8,    6,   11},
    {    8,   45,    6,    8,    6,   11}, {    8,   46,    6,    8,    6,   11}, {    8,   47,    5,    8,    6,   11}, {    8,   47,    4,    8,    6,   11}, {    8,   48,    4,    8,    6,   11},
    {    8,   49,    3,    8,    6,   11}, {    8,   50,    3,    8,    6,   11}, {    8,   51,    2,    8,    6,   11}, {    8,   52,    2,    8,    6,   11}, {    9,   53,    1,    8,    6,   11},
    {    9,   54,    0,    8,    6,   10}, {    9,   55,    0,    8,    6,   10}, {    9,   55,   -1,    8,    6,   10}, {    9,   56,   -1,    8,    6,   10}, {    9,   57,   -2,    8,    6,   10},
    {    9,   58,   -2,    8,    6,   10}, {    9,   59,   -3,    8,    6,   10}, {    9,   60,   -4,    8,    6,   10}, {    9,   61,   -4,    8,    6,   10}, {    9,   61,   -5,    7,    6,    4},
    {   10,   62,   -5,    7,    6,    4}, {   10,   63,   -6,    7,    6,    4}, {   10,   64,   -6,    7,    6,    4}, {   10,   65,   -7,    7,    6,    4}, {   10,   66,   -7,    7,    6,    4},
    {   10,   67,   -8,    7,    6,    4}, {   11,   68,   -9,    7,    6,    4}, {   11,   69,   -9,    7,    6,    4}, {   11,   69,  -10,    7,    6,    4}, {   11,   70,  -10,    7,    6,    4},
    {   11,   71,  -11,    7,    6,    4}, {   11,   72,  -11,    7,    6,    4}, {   12,   73,  -12,    7,    6,    4}, {   12,   74,  -12,    7,    5,    3}, {   12,   75,  -13,    7,    5,    3},
    {   12,   76,  -13,    7,    5,    3}, {   12,   77,  -14,    8,    6,    3}, {   13,   78,  -14,    8,    6,    3}, {   13,   79,  -15,    8,    6,    3}, {   13,   80,  -15,    8,    6,    3},
    {   13,   81,  -16,    8,    6,    3}, {   13,   82,  -16,    8,    6,    3}, {   14,   82,  -17,    8,    6,    3}, {   14,   83,  -17,    8,    6,    3}, {   14,   84,  -18,    7,    6,    0},
    {   14,   85,  -18,    7,    6,    0}, {   14,   86,  -19,    7,    6,    0}, {   14,   87,  -19,    7,    6,    0}, {   15,   88,  -20,    7,    6,    0}, {   15,   88,  -20,    7,    6,    0},
    {   15,   89,  -20,    7,    6,    0}, {   15,   90,  -21,    7,    6,    0}, {   15,   91,  -21,    7,    6,    0}, {   15,   92,  -22,    7,    6,    0}, {   16,   93,  -22,    7,    6,    0},
    {   16,   94,  -23,    7,    6,    0}, {   16,   95,  -23,    7,    6,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftZeroGRollDown2, {
    {    0,   16,   19,    0,   16,    0}, {    0,   16,   19,    0,   16,    0}, {    1,   16,   19,    0,   16,    0}, {    2,   17,   19,    0,   16,    0}, {    3,   17,   19,    0,   16,    0},
    {    4,   17,   19,    0,   16,    0}, {    6,   17,   19,    0,   16,    0}, {    7,   17,   19,    0,   16,    0}, {    8,   18,   19,   16,    0,   14}, {    9,   18,   19,   16,    0,   14},
    {   10,   18,   19,   16,    0,   14}, {   11,   18,   19,   16,    0,   14}, {   12,   18,   18,   16,    0,   14}, {   13,   19,   18,   16,    0,   14}, {   14,   19,   18,   16,    0,   14},
    {   15,   19,   18,   16,    0,   14}, {   16,   19,   18,   16,    0,   14}, {   17,   19,   18,   16,    0,   14}, {   18,   20,   17,   16,    0,   14}, {   19,   20,   17,   16,    0,   14},
    {   20,   20,   17,   16,    6,   13}, {   21,   20,   17,   16,    6,   13}, {   22,   21,   16,   16,    6,   13}, {   23,   21,   16,   16,    6,   13}, {   24,   21,   16,   16,    6,   13},
    {   25,   21,   15,   16,    6,   13}, {   26,   21,   15,   16,    6,   13}, {   27,   21,   15,   16,    6,   13}, {   28,   22,   14,   16,    6,   13}, {   29,   22,   14,   16,    6,   13},
    {   30,   22,   14,   16,    6,   13}, {   31,   22,   13,   16,    6,   13}, {   32,   22,   13,   16,    6,   12}, {   33,   22,   12,   16,    6,   12}, {   34,   23,   12,   16,    6,   12},
    {   35,   23,   11,   16,    6,   12}, {   36,   23,   11,   16,    6,   12}, {   37,   23,   10,   16,    6,   12}, {   38,   23,   10,   16,    6,   12}, {   39,   23,    9,   16,    6,   12},
    {   40,   23,    9,   16,    6,   12}, {   41,   23,    8,   16,    6,   12}, {   42,   23,    8,   16,    6,   12}, {   43,   23,    7,   16,    6,   12}, {   44,   24,    7,   16,    6,   11},
    {   45,   24,    6,   16,    6,   11}, {   46,   24,    6,   16,    6,   11}, {   47,   24,    5,   16,    6,   11}, {   47,   24,    4,   16,    6,   11}, {   48,   24,    4,   16,    6,   11},
    {   49,   24,    3,   16,    6,   11}, {   50,   24,    3,   16,    6,   11}, {   51,   24,    2,   16,    6,   11}, {   52,   24,    2,   16,    6,   11}, {   53,   23,    1,   16,    6,   11},
    {   54,   23,    0,   16,    6,   10}, {   55,   23,    0,   16,    6,   10}, {   55,   23,   -1,   16,    6,   10}, {   56,   23,   -1,   16,    6,   10}, {   57,   23,   -2,   16,    6,   10},
    {   58,   23,   -2,   16,    6,   10}, {   59,   23,   -3,   16,    6,   10}, {   60,   23,   -4,   16,    6,   10}, {   61,   23,   -4,   16,    6,   10}, {   61,   23,   -5,   15,    6,    4},
    {   62,   22,   -5,   15,    6,    4}, {   63,   22,   -6,   15,    6,    4}, {   64,   22,   -6,   15,    6,    4}, {   65,   22,   -7,   15,    6,    4}, {   66,   22,   -7,   15,    6,    4},
    {   67,   22,   -8,   15,    6,    4}, {   68,   21,   -9,   15,    6,    4}, {   69,   21,   -9,   15,    6,    4}, {   69,   21,  -10,   15,    6,    4}, {   70,   21,  -10,   15,    6,    4},
    {   71,   21,  -11,   15,    6,    4}, {   72,   21,  -11,   15,    6,    4}, {   73,   20,  -12,   15,    6,    4}, {   74,   20,  -12,   15,    5,    3}, {   75,   20,  -13,   15,    5,    3},
    {   76,   20,  -13,   15,    5,    3}, {   77,   20,  -14,   16,    6,    3}, {   78,   19,  -14,   16,    6,    3}, {   79,   19,  -15,   16,    6,    3}, {   80,   19,  -15,   16,    6,    3},
    {   81,   19,  -16,   16,    6,    3}, {   82,   19,  -16,   16,    6,    3}, {   82,   18,  -17,   16,    6,    3}, {   83,   18,  -17,   16,    6,    3}, {   84,   18,  -18,   15,    6,    0},
    {   85,   18,  -18,   15,    6,    0}, {   86,   18,  -19,   15,    6,    0}, {   87,   18,  -19,   15,    6,    0}, {   88,   17,  -20,   15,    6,    0}, {   88,   17,  -20,   15,    6,    0},
    {   89,   17,  -20,   15,    6,    0}, {   90,   17,  -21,   15,    6,    0}, {   91,   17,  -21,   15,    6,    0}, {   92,   17,  -22,   15,    6,    0}, {   93,   16,  -22,   15,    6,    0},
    {   94,   16,  -23,   15,    6,    0}, {   95,   16,  -23,   15,    6,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftZeroGRollDown3, {
    {   16,   32,   19,    8,   16,    0}, {   16,   31,   19,    8,   16,    0}, {   17,   30,   19,    8,   16,    0}, {   17,   29,   19,    8,   16,    0}, {   17,   28,   19,    8,   16,    0},
    {   17,   26,   19,    8,   16,    0}, {   17,   25,   19,    8,   16,    0}, {   18,   24,   19,   24,    0,   14}, {   18,   23,   19,   24,    0,   14}, {   18,   22,   19,   24,    0,   14},
    {   18,   21,   19,   24,    0,   14}, {   18,   20,   18,   24,    0,   14}, {   19,   19,   18,   24,    0,   14}, {   19,   18,   18,   24,    0,   14}, {   19,   17,   18,   24,    0,   14},
    {   19,   16,   18,   24,    0,   14}, {   19,   15,   18,   24,    0,   14}, {   20,   14,   17,   24,    0,   14}, {   20,   13,   17,   24,    0,   14}, {   20,   12,   17,   24,    6,   13},
    {   20,   11,   17,   24,    6,   13}, {   21,   10,   16,   24,    6,   13}, {   21,    9,   16,   24,    6,   13}, {   21,    8,   16,   24,    6,   13}, {   21,    7,   15,   24,    6,   13},
    {   21,    6,   15,   24,    6,   13}, {   21,    5,   15,   24,    6,   13}, {   22,    4,   14,   24,    6,   13}, {   22,    3,   14,   24,    6,   13}, {   22,    2,   14,   24,    6,   13},
    {   22,    1,   13,   24,    6,   13}, {   22,    0,   13,   24,    6,   12}, {   22,   -1,   12,   24,    6,   12}, {   23,   -2,   12,   24,    6,   12}, {   23,   -3,   11,   24,    6,   12},
    {   23,   -4,   11,   24,    6,   12}, {   23,   -5,   10,   24,    6,   12}, {   23,   -6,   10,   24,    6,   12}, {   23,   -7,    9,   24,    6,   12}, {   23,   -8,    9,   24,    6,   12},
    {   23,   -9,    8,   24,    6,   12}, {   23,  -10,    8,   24,    6,   12}, {   23,  -11,    7,   24,    6,   12}, {   24,  -12,    7,   24,    6,   11}, {   24,  -13,    6,   24,    6,   11},
    {   24,  -14,    6,   24,    6,   11}, {   24,  -15,    5,   24,    6,   11}, {   24,  -15,    4,   24,    6,   11}, {   24,  -16,    4,   24,    6,   11}, {   24,  -17,    3,   24,    6,   11},
    {   24,  -18,    3,   24,    6,   11}, {   24,  -19,    2,   24,    6,   11}, {   24,  -20,    2,   24,    6,   11}, {   23,  -21,    1,   24,    6,   11}, {   23,  -22,    0,   24,    6,   10},
    {   23,  -23,    0,   24,    6,   10}, {   23,  -23,   -1,   24,    6,   10}, {   23,  -24,   -1,   24,    6,   10}, {   23,  -25,   -2,   24,    6,   10}, {   23,  -26,   -2,   24,    6,   10},
    {   23,  -27,   -3,   24,    6,   10}, {   23,  -28,   -4,   24,    6,   10}, {   23,  -29,   -4,   24,    6,   10}, {   23,  -29,   -5,   23,    6,    4}, {   22,  -30,   -5,   23,    6,    4},
    {   22,  -31,   -6,   23,    6,    4}, {   22,  -32,   -6,   23,    6,    4}, {   22,  -33,   -7,   23,    6,    4}, {   22,  -34,   -7,   23,    6,    4}, {   22,  -35,   -8,   23,    6,    4},
    {   21,  -36,   -9,   23,    6,    4}, {   21,  -37,   -9,   23,    6,    4}, {   21,  -37,  -10,   23,    6,    4}, {   21,  -38,  -10,   23,    6,    4}, {   21,  -39,  -11,   23,    6,    4},
    {   21,  -40,  -11,   23,    6,    4}, {   20,  -41,  -12,   23,    6,    4}, {   20,  -42,  -12,   23,    5,    3}, {   20,  -43,  -13,   23,    5,    3}, {   20,  -44,  -13,   23,    5,    3},
    {   20,  -45,  -14,   24,    6,    3}, {   19,  -46,  -14,   24,    6,    3}, {   19,  -47,  -15,   24,    6,    3}, {   19,  -48,  -15,   24,    6,    3}, {   19,  -49,  -16,   24,    6,    3},
    {   19,  -50,  -16,   24,    6,    3}, {   18,  -50,  -17,   24,    6,    3}, {   18,  -51,  -17,   24,    6,    3}, {   18,  -52,  -18,   23,    6,    0}, {   18,  -53,  -18,   23,    6,    0},
    {   18,  -54,  -19,   23,    6,    0}, {   18,  -55,  -19,   23,    6,    0}, {   17,  -56,  -20,   23,    6,    0}, {   17,  -56,  -20,   23,    6,    0}, {   17,  -57,  -20,   23,    6,    0},
    {   17,  -58,  -21,   23,    6,    0}, {   17,  -59,  -21,   23,    6,    0}, {   17,  -60,  -22,   23,    6,    0}, {   16,  -61,  -22,   23,    6,    0}, {   16,  -62,  -23,   23,    6,    0},
    {   16,  -63,  -23,   23,    6,    0}, {   16,  -64,  -24,   24,    6,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightZeroGRollDown0, {
    {   32,   16,   19,   16,   16,    0}, {   31,   16,   19,   16,   16,    0}, {   30,   17,   19,   16,   16,    0}, {   29,   17,   19,   16,   16,    0}, {   28,   17,   19,   16,   16,    0},
    {   26,   17,   19,   16,   16,    0}, {   25,   17,   19,   16,   16,    0}, {   24,   18,   19,    0,    0,    9}, {   23,   18,   19,    0,    0,    9}, {   22,   18,   19,    0,    0,    9},
    {   21,   18,   19,    0,    0,    9}, {   20,   18,   18,    0,    0,    9}, {   19,   19,   18,    0,    0,    9}, {   18,   19,   18,    0,    0,    9}, {   17,   19,   18,    0,    0,    9},
    {   16,   19,   18,    0,    0,    9}, {   15,   19,   18,    0,    0,    9}, {   14,   20,   17,    0,    0,    9}, {   13,   20,   17,    0,    0,    9}, {   12,   20,   17,    0,    6,    8},
    {   11,   20,   17,    0,    6,    8}, {   10,   21,   16,    0,    6,    8}, {    9,   21,   16,    0,    6,    8}, {    8,   21,   16,    0,    6,    8}, {    7,   21,   15,    0,    6,    8},
    {    6,   21,   15,    0,    6,    8}, {    5,   21,   15,    0,    6,    8}, {    4,   22,   14,    0,    6,    8}, {    3,   22,   14,    0,    6,    8}, {    2,   22,   14,    0,    6,    8},
    {    1,   22,   13,    0,    6,    8}, {    0,   22,   13,    0,    6,    7}, {   -1,   22,   12,    0,    6,    7}, {   -2,   23,   12,    0,    6,    7}, {   -3,   23,   11,    0,    6,    7},
    {   -4,   23,   11,    0,    6,    7}, {   -5,   23,   10,    0,    6,    7}, {   -6,   23,   10,    0,    6,    7}, {   -7,   23,    9,    0,    6,    7}, {   -8,   23,    9,    0,    6,    7},
    {   -9,   23,    8,    0,    6,    7}, {  -10,   23,    8,    0,    6,    7}, {  -11,   23,    7,    0,    6,    7}, {  -12,   24,    7,    0,    6,    6}, {  -13,   24,    6,    0,    6,    6},
    {  -14,   24,    6,    0,    6,    6}, {  -15,   24,    5,    0,    6,    6}, {  -15,   24,    4,    0,    6,    6}, {  -16,   24,    4,    0,    6,    6}, {  -17,   24,    3,    0,    6,    6},
    {  -18,   24,    3,    0,    6,    6}, {  -19,   24,    2,    0,    6,    6}, {  -20,   24,    2,    0,    6,    6}, {  -21,   23,    1,    0,    6,    6}, {  -22,   23,    0,    0,    6,    5},
    {  -23,   23,    0,    0,    6,    5}, {  -23,   23,   -1,    0,    6,    5}, {  -24,   23,   -1,    0,    6,    5}, {  -25,   23,   -2,    0,    6,    5}, {  -26,   23,   -2,    0,    6,    5},
    {  -27,   23,   -3,    0,    6,    5}, {  -28,   23,   -4,    0,    6,    5}, {  -29,   23,   -4,    0,    6,    5}, {  -29,   23,   -5,    1,    6,    2}, {  -30,   22,   -5,    1,    6,    2},
    {  -31,   22,   -6,    1,    6,    2}, {  -32,   22,   -6,    1,    6,    2}, {  -33,   22,   -7,    1,    6,    2}, {  -34,   22,   -7,    1,    6,    2}, {  -35,   22,   -8,    1,    6,    2},
    {  -36,   21,   -9,    1,    6,    2}, {  -37,   21,   -9,    1,    6,    2}, {  -37,   21,  -10,    1,    6,    2}, {  -38,   21,  -10,    1,    6,    2}, {  -39,   21,  -11,    1,    6,    2},
    {  -40,   21,  -11,    1,    6,    2}, {  -41,   20,  -12,    1,    6,    2}, {  -42,   20,  -12,    1,    5,    1}, {  -43,   20,  -13,    1,    5,    1}, {  -44,   20,  -13,    1,    5,    1},
    {  -45,   20,  -14,    0,    6,    1}, {  -46,   19,  -14,    0,    6,    1}, {  -47,   19,  -15,    0,    6,    1}, {  -48,   19,  -15,    0,    6,    1}, {  -49,   19,  -16,    0,    6,    1},
    {  -50,   19,  -16,    0,    6,    1}, {  -50,   18,  -17,    0,    6,    1}, {  -51,   18,  -17,    0,    6,    1}, {  -52,   18,  -18,    1,    6,    0}, {  -53,   18,  -18,    1,    6,    0},
    {  -54,   18,  -19,    1,    6,    0}, {  -55,   18,  -19,    1,    6,    0}, {  -56,   17,  -20,    1,    6,    0}, {  -56,   17,  -20,    1,    6,    0}, {  -57,   17,  -20,    1,    6,    0},
    {  -58,   17,  -21,    1,    6,    0}, {  -59,   17,  -21,    1,    6,    0}, {  -60,   17,  -22,    1,    6,    0}, {  -61,   16,  -22,    1,    6,    0}, {  -62,   16,  -23,    1,    6,    0},
    {  -63,   16,  -23,    1,    6,    0}, {  -64,   16,  -24,    0,    6,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightZeroGRollDown1, {
    {   16,    0,   19,   24,   16,    0}, {   16,    0,   19,   24,   16,    0}, {   16,    1,   19,   24,   16,    0}, {   17,    2,   19,   24,   16,    0}, {   17,    3,   19,   24,   16,    0},
    {   17,    4,   19,   24,   16,    0}, {   17,    6,   19,   24,   16,    0}, {   17,    7,   19,   24,   16,    0}, {   18,    8,   19,    8,    0,    9}, {   18,    9,   19,    8,    0,    9},
    {   18,   10,   19,    8,    0,    9}, {   18,   11,   19,    8,    0,    9}, {   18,   12,   18,    8,    0,    9}, {   19,   13,   18,    8,    0,    9}, {   19,   14,   18,    8,    0,    9},
    {   19,   15,   18,    8,    0,    9}, {   19,   16,   18,    8,    0,    9}, {   19,   17,   18,    8,    0,    9}, {   20,   18,   17,    8,    0,    9}, {   20,   19,   17,    8,    0,    9},
    {   20,   20,   17,    8,    6,    8}, {   20,   21,   17,    8,    6,    8}, {   21,   22,   16,    8,    6,    8}, {   21,   23,   16,    8,    6,    8}, {   21,   24,   16,    8,    6,    8},
    {   21,   25,   15,    8,    6,    8}, {   21,   26,   15,    8,    6,    8}, {   21,   27,   15,    8,    6,    8}, {   22,   28,   14,    8,    6,    8}, {   22,   29,   14,    8,    6,    8},
    {   22,   30,   14,    8,    6,    8}, {   22,   31,   13,    8,    6,    8}, {   22,   32,   13,    8,    6,    7}, {   22,   33,   12,    8,    6,    7}, {   23,   34,   12,    8,    6,    7},
    {   23,   35,   11,    8,    6,    7}, {   23,   36,   11,    8,    6,    7}, {   23,   37,   10,    8,    6,    7}, {   23,   38,   10,    8,    6,    7}, {   23,   39,    9,    8,    6,    7},
    {   23,   40,    9,    8,    6,    7}, {   23,   41,    8,    8,    6,    7}, {   23,   42,    8,    8,    6,    7}, {   23,   43,    7,    8,    6,    7}, {   24,   44,    7,    8,    6,    6},
    {   24,   45,    6,    8,    6,    6}, {   24,   46,    6,    8,    6,    6}, {   24,   47,    5,    8,    6,    6}, {   24,   47,    4,    8,    6,    6}, {   24,   48,    4,    8,    6,    6},
    {   24,   49,    3,    8,    6,    6}, {   24,   50,    3,    8,    6,    6}, {   24,   51,    2,    8,    6,    6}, {   24,   52,    2,    8,    6,    6}, {   23,   53,    1,    8,    6,    6},
    {   23,   54,    0,    8,    6,    5}, {   23,   55,    0,    8,    6,    5}, {   23,   55,   -1,    8,    6,    5}, {   23,   56,   -1,    8,    6,    5}, {   23,   57,   -2,    8,    6,    5},
    {   23,   58,   -2,    8,    6,    5}, {   23,   59,   -3,    8,    6,    5}, {   23,   60,   -4,    8,    6,    5}, {   23,   61,   -4,    8,    6,    5}, {   23,   61,   -5,    9,    6,    2},
    {   22,   62,   -5,    9,    6,    2}, {   22,   63,   -6,    9,    6,    2}, {   22,   64,   -6,    9,    6,    2}, {   22,   65,   -7,    9,    6,    2}, {   22,   66,   -7,    9,    6,    2},
    {   22,   67,   -8,    9,    6,    2}, {   21,   68,   -9,    9,    6,    2}, {   21,   69,   -9,    9,    6,    2}, {   21,   69,  -10,    9,    6,    2}, {   21,   70,  -10,    9,    6,    2},
    {   21,   71,  -11,    9,    6,    2}, {   21,   72,  -11,    9,    6,    2}, {   20,   73,  -12,    9,    6,    2}, {   20,   74,  -12,    9,    5,    1}, {   20,   75,  -13,    9,    5,    1},
    {   20,   76,  -13,    9,    5,    1}, {   20,   77,  -14,    8,    6,    1}, {   19,   78,  -14,    8,    6,    1}, {   19,   79,  -15,    8,    6,    1}, {   19,   80,  -15,    8,    6,    1},
    {   19,   81,  -16,    8,    6,    1}, {   19,   82,  -16,    8,    6,    1}, {   18,   82,  -17,    8,    6,    1}, {   18,   83,  -17,    8,    6,    1}, {   18,   84,  -18,    9,    6,    0},
    {   18,   85,  -18,    9,    6,    0}, {   18,   86,  -19,    9,    6,    0}, {   18,   87,  -19,    9,    6,    0}, {   17,   88,  -20,    9,    6,    0}, {   17,   88,  -20,    9,    6,    0},
    {   17,   89,  -20,    9,    6,    0}, {   17,   90,  -21,    9,    6,    0}, {   17,   91,  -21,    9,    6,    0}, {   17,   92,  -22,    9,    6,    0}, {   16,   93,  -22,    9,    6,    0},
    {   16,   94,  -23,    9,    6,    0}, {   16,   95,  -23,    9,    6,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightZeroGRollDown2, {
    {    0,   16,   19,    0,   16,    0}, {    0,   16,   19,    0,   16,    0}, {    1,   16,   19,    0,   16,    0}, {    2,   15,   19,    0,   16,    0}, {    3,   15,   19,    0,   16,    0},
    {    4,   15,   19,    0,   16,    0}, {    6,   15,   19,    0,   16,    0}, {    7,   15,   19,    0,   16,    0}, {    8,   14,   19,   16,    0,    9}, {    9,   14,   19,   16,    0,    9},
    {   10,   14,   19,   16,    0,    9}, {   11,   14,   19,   16,    0,    9}, {   12,   14,   18,   16,    0,    9}, {   13,   13,   18,   16,    0,    9}, {   14,   13,   18,   16,    0,    9},
    {   15,   13,   18,   16,    0,    9}, {   16,   13,   18,   16,    0,    9}, {   17,   13,   18,   16,    0,    9}, {   18,   12,   17,   16,    0,    9}, {   19,   12,   17,   16,    0,    9},
    {   20,   12,   17,   16,    6,    8}, {   21,   12,   17,   16,    6,    8}, {   22,   11,   16,   16,    6,    8}, {   23,   11,   16,   16,    6,    8}, {   24,   11,   16,   16,    6,    8},
    {   25,   11,   15,   16,    6,    8}, {   26,   11,   15,   16,    6,    8}, {   27,   11,   15,   16,    6,    8}, {   28,   10,   14,   16,    6,    8}, {   29,   10,   14,   16,    6,    8},
    {   30,   10,   14,   16,    6,    8}, {   31,   10,   13,   16,    6,    8}, {   32,   10,   13,   16,    6,    7}, {   33,   10,   12,   16,    6,    7}, {   34,    9,   12,   16,    6,    7},
    {   35,    9,   11,   16,    6,    7}, {   36,    9,   11,   16,    6,    7}, {   37,    9,   10,   16,    6,    7}, {   38,    9,   10,   16,    6,    7}, {   39,    9,    9,   16,    6,    7},
    {   40,    9,    9,   16,    6,    7}, {   41,    9,    8,   16,    6,    7}, {   42,    9,    8,   16,    6,    7}, {   43,    9,    7,   16,    6,    7}, {   44,    8,    7,   16,    6,    6},
    {   45,    8,    6,   16,    6,    6}, {   46,    8,    6,   16,    6,    6}, {   47,    8,    5,   16,    6,    6}, {   47,    8,    4,   16,    6,    6}, {   48,    8,    4,   16,    6,    6},
    {   49,    8,    3,   16,    6,    6}, {   50,    8,    3,   16,    6,    6}, {   51,    8,    2,   16,    6,    6}, {   52,    8,    2,   16,    6,    6}, {   53,    9,    1,   16,    6,    6},
    {   54,    9,    0,   16,    6,    5}, {   55,    9,    0,   16,    6,    5}, {   55,    9,   -1,   16,    6,    5}, {   56,    9,   -1,   16,    6,    5}, {   57,    9,   -2,   16,    6,    5},
    {   58,    9,   -2,   16,    6,    5}, {   59,    9,   -3,   16,    6,    5}, {   60,    9,   -4,   16,    6,    5}, {   61,    9,   -4,   16,    6,    5}, {   61,    9,   -5,   17,    6,    2},
    {   62,   10,   -5,   17,    6,    2}, {   63,   10,   -6,   17,    6,    2}, {   64,   10,   -6,   17,    6,    2}, {   65,   10,   -7,   17,    6,    2}, {   66,   10,   -7,   17,    6,    2},
    {   67,   10,   -8,   17,    6,    2}, {   68,   11,   -9,   17,    6,    2}, {   69,   11,   -9,   17,    6,    2}, {   69,   11,  -10,   17,    6,    2}, {   70,   11,  -10,   17,    6,    2},
    {   71,   11,  -11,   17,    6,    2}, {   72,   11,  -11,   17,    6,    2}, {   73,   12,  -12,   17,    6,    2}, {   74,   12,  -12,   17,    5,    1}, {   75,   12,  -13,   17,    5,    1},
    {   76,   12,  -13,   17,    5,    1}, {   77,   12,  -14,   16,    6,    1}, {   78,   13,  -14,   16,    6,    1}, {   79,   13,  -15,   16,    6,    1}, {   80,   13,  -15,   16,    6,    1},
    {   81,   13,  -16,   16,    6,    1}, {   82,   13,  -16,   16,    6,    1}, {   82,   14,  -17,   16,    6,    1}, {   83,   14,  -17,   16,    6,    1}, {   84,   14,  -18,   17,    6,    0},
    {   85,   14,  -18,   17,    6,    0}, {   86,   14,  -19,   17,    6,    0}, {   87,   14,  -19,   17,    6,    0}, {   88,   15,  -20,   17,    6,    0}, {   88,   15,  -20,   17,    6,    0},
    {   89,   15,  -20,   17,    6,    0}, {   90,   15,  -21,   17,    6,    0}, {   91,   15,  -21,   17,    6,    0}, {   92,   15,  -22,   17,    6,    0}, {   93,   16,  -22,   17,    6,    0},
    {   94,   16,  -23,   17,    6,    0}, {   95,   16,  -23,   17,    6,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightZeroGRollDown3, {
    {   16,   32,   19,    8,   16,    0}, {   16,   31,   19,    8,   16,    0}, {   15,   30,   19,    8,   16,    0}, {   15,   29,   19,    8,   16,    0}, {   15,   28,   19,    8,   16,    0},
    {   15,   26,   19,    8,   16,    0}, {   15,   25,   19,    8,   16,    0}, {   14,   24,   19,   24,    0,    9}, {   14,   23,   19,   24,    0,    9}, {   14,   22,   19,   24,    0,    9},
    {   14,   21,   19,   24,    0,    9}, {   14,   20,   18,   24,    0,    9}, {   13,   19,   18,   24,    0,    9}, {   13,   18,   18,   24,    0,    9}, {   13,   17,   18,   24,    0,    9},
    {   13,   16,   18,   24,    0,    9}, {   13,   15,   18,   24,    0,    9}, {   12,   14,   17,   24,    0,    9}, {   12,   13,   17,   24,    0,    9}, {   12,   12,   17,   24,    6,    8},
    {   12,   11,   17,   24,    6,    8}, {   11,   10,   16,   24,    6,    8}, {   11,    9,   16,   24,    6,    8}, {   11,    8,   16,   24,    6,    8}, {   11,    7,   15,   24,    6,    8},
    {   11,    6,   15,   24,    6,    8}, {   11,    5,   15,   24,    6,    8}, {   10,    4,   14,   24,    6,    8}, {   10,    3,   14,   24,    6,    8}, {   10,    2,   14,   24,    6,    8},
    {   10,    1,   13,   24,    6,    8}, {   10,    0,   13,   24,    6,    7}, {   10,   -1,   12,   24,    6,    7}, {    9,   -2,   12,   24,    6,    7}, {    9,   -3,   11,   24,    6,    7},
    {    9,   -4,   11,   24,    6,    7}, {    9,   -5,   10,   24,    6,    7}, {    9,   -6,   10,   24,    6,    7}, {    9,   -7,    9,   24,    6,    7}, {    9,   -8,    9,   24,    6,    7},
    {    9,   -9,    8,   24,    6,    7}, {    9,  -10,    8,   24,    6,    7}, {    9,  -11,    7,   24,    6,    7}, {    8,  -12,    7,   24,    6,    6}, {    8,  -13,    6,   24,    6,    6},
    {    8,  -14,    6,   24,    6,    6}, {    8,  -15,    5,   24,    6,    6}, {    8,  -15,    4,   24,    6,    6}, {    8,  -16,    4,   24,    6,    6}, {    8,  -17,    3,   24,    6,    6},
    {    8,  -18,    3,   24,    6,    6}, {    8,  -19,    2,   24,    6,    6}, {    8,  -20,    2,   24,    6,    6}, {    9,  -21,    1,   24,    6,    6}, {    9,  -22,    0,   24,    6,    5},
    {    9,  -23,    0,   24,    6,    5}, {    9,  -23,   -1,   24,    6,    5}, {    9,  -24,   -1,   24,    6,    5}, {    9,  -25,   -2,   24,    6,    5}, {    9,  -26,   -2,   24,    6,    5},
    {    9,  -27,   -3,   24,    6,    5}, {    9,  -28,   -4,   24,    6,    5}, {    9,  -29,   -4,   24,    6,    5}, {    9,  -29,   -5,   25,    6,    2}, {   10,  -30,   -5,   25,    6,    2},
    {   10,  -31,   -6,   25,    6,    2}, {   10,  -32,   -6,   25,    6,    2}, {   10,  -33,   -7,   25,    6,    2}, {   10,  -34,   -7,   25,    6,    2}, {   10,  -35,   -8,   25,    6,    2},
    {   11,  -36,   -9,   25,    6,    2}, {   11,  -37,   -9,   25,    6,    2}, {   11,  -37,  -10,   25,    6,    2}, {   11,  -38,  -10,   25,    6,    2}, {   11,  -39,  -11,   25,    6,    2},
    {   11,  -40,  -11,   25,    6,    2}, {   12,  -41,  -12,   25,    6,    2}, {   12,  -42,  -12,   25,    5,    1}, {   12,  -43,  -13,   25,    5,    1}, {   12,  -44,  -13,   25,    5,    1},
    {   12,  -45,  -14,   24,    6,    1}, {   13,  -46,  -14,   24,    6,    1}, {   13,  -47,  -15,   24,    6,    1}, {   13,  -48,  -15,   24,    6,    1}, {   13,  -49,  -16,   24,    6,    1},
    {   13,  -50,  -16,   24,    6,    1}, {   14,  -50,  -17,   24,    6,    1}, {   14,  -51,  -17,   24,    6,    1}, {   14,  -52,  -18,   25,    6,    0}, {   14,  -53,  -18,   25,    6,    0},
    {   14,  -54,  -19,   25,    6,    0}, {   14,  -55,  -19,   25,    6,    0}, {   15,  -56,  -20,   25,    6,    0}, {   15,  -56,  -20,   25,    6,    0}, {   15,  -57,  -20,   25,    6,    0},
    {   15,  -58,  -21,   25,    6,    0}, {   15,  -59,  -21,   25,    6,    0}, {   15,  -60,  -22,   25,    6,    0}, {   16,  -61,  -22,   25,    6,    0}, {   16,  -62,  -23,   25,    6,    0},
    {   16,  -63,  -23,   25,    6,    0}, {   16,  -64,  -24,   24,    6,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeZeroGRollUp0, {
    {   31,   16,    0,    0,    4,    0}, {   31,   16,    1,    0,    4,    0}, {   30,   16,    2,    0,    4,    0}, {   30,   16,    3,    0,    4,    0}, {   29,   16,    4,    0,    4,    0},
    {   29,   16,    5,    0,    4,    0}, {   28,   16,    6,    0,    4,    0}, {   28,   16,    7,    0,    4,    0}, {   27,   16,    9,    0,    4,    0}, {   27,   16,   10,    0,    4,    0},
    {   26,   16,   11,    0,    4,    0}, {   25,   16,   12,    0,    4,    0}, {   25,   16,   13,    0,    4,    0}, {   24,   16,   14,    0,    4,    0}, {   24,   16,   15,    0,    4,    0},
    {   23,   17,   16,    0,    4,    0}, {   23,   17,   17,    0,    4,    0}, {   22,   17,   18,    0,    4,    0}, {   21,   17,   19,    0,    4,    0}, {   21,   17,   20,    0,    4,    0},
    {   20,   17,   22,    0,    4,    0}, {   20,   17,   23,    0,    4,    0}, {   19,   17,   24,    0,    4,    0}, {   19,   17,   25,    0,    4,    1}, {   18,   17,   26,    0,    4,    1},
    {   17,   17,   27,    0,    4,    1}, {   17,   17,   28,    0,    4,    1}, {   16,   17,   29,    0,    4,    1}, {   15,   17,   30,    0,    4,    1}, {   15,   17,   31,    0,    4,    1},
    {   14,   17,   33,    0,    4,    1}, {   14,   17,   34,    0,    4,    1}, {   13,   17,   35,    0,    4,    1}, {   12,   17,   36,    0,    4,    1}, {   12,   17,   37,    0,    4,    1},
    {   11,   18,   38,    0,    4,    1}, {   10,   18,   39,    0,    4,    1}, {   10,   18,   40,    0,    4,    1}, {    9,   18,   42,    0,    4,    1}, {    9,   18,   43,    0,    4,    1},
    {    8,   18,   44,    0,    4,    1}, {    7,   18,   45,    0,    4,    1}, {    7,   18,   46,    0,    4,    1}, {    6,   18,   47,    0,    4,    1}, {    5,   18,   48,    0,    4,    1},
    {    5,   18,   49,    0,    4,    1}, {    4,   18,   50,    0,    4,    1}, {    3,   18,   52,    0,    4,    1}, {    3,   18,   53,    0,    4,    1}, {    2,   18,   54,    0,    4,    1},
    {    1,   18,   55,    0,    4,    1}, {    1,   19,   56,    0,    4,    1}, {    0,   19,   57,    0,    4,    1}, {   -1,   19,   58,    0,    3,    2}, {   -1,   19,   59,    0,    3,    2},
    {   -2,   19,   61,    0,    3,    2}, {   -3,   19,   62,    0,    3,    2}, {   -4,   19,   63,    0,    3,    2}, {   -4,   19,   64,    0,    3,    2}, {   -5,   19,   65,    0,    3,    2},
    {   -6,   19,   66,    0,    3,    2}, {   -6,   19,   67,    0,    3,    2}, {   -7,   19,   68,    0,    3,    2}, {   -8,   19,   69,    0,    3,    2}, {   -9,   19,   71,    0,    3,    2},
    {   -9,   19,   72,    0,    3,    2}, {  -10,   19,   73,    0,    3,    2}, {  -11,   20,   74,    0,    3,    2}, {  -11,   20,   75,    0,    3,    2}, {  -12,   20,   76,    0,    3,    2},
    {  -13,   20,   77,    0,    3,    5}, {  -14,   20,   78,    0,    3,    5}, {  -14,   20,   79,    0,    3,    5}, {  -15,   20,   80,    0,    3,    5}, {  -16,   20,   81,    0,    3,    5},
    {  -17,   20,   83,    0,    3,    5}, {  -17,   20,   84,    0,    3,    5}, {  -18,   20,   85,    0,    3,    5}, {  -19,   20,   86,    0,    3,    5}, {  -20,   20,   87,    0,    3,    5},
    {  -20,   20,   88,    0,    3,    5}, {  -21,   20,   89,    0,    3,    5}, {  -22,   20,   90,    0,    3,    5}, {  -23,   20,   91,    0,    3,    5}, {  -24,   20,   92,    0,    3,    5},
    {  -24,   20,   93,    0,    3,    5}, {  -25,   20,   94,    0,    3,    5}, {  -26,   20,   95,    0,    3,    6}, {  -27,   20,   96,    0,    3,    6}, {  -28,   20,   97,    0,    3,    6},
    {  -29,   20,   98,    0,    3,    6}, {  -29,   20,   99,    0,    3,    6}, {  -30,   20,  100,    0,    3,    6}, {  -31,   20,  101,    0,    3,    6}, {  -32,   20,  102,    0,    3,    6},
    {  -33,   20,  103,    0,    3,    6}, {  -34,   20,  104,    0,    3,    6}, {  -34,   20,  105,    0,    3,    6}, {  -35,   20,  106,    0,    3,    6}, {  -36,   20,  107,    0,    3,    6},
    {  -37,   20,  108,    0,    3,    6}, {  -38,   20,  109,    0,    3,    6}, {  -39,   20,  110,    0,    3,    6}, {  -40,   20,  111,    0,    3,    6}, {  -41,   20,  112,    0,    3,    6},
    {  -42,   20,  113,    0,    3,    6}, {  -43,   20,  113,    0,    2,    7}, {  -44,   20,  114,    0,    2,    7}, {  -44,   20,  115,    0,    2,    7}, {  -45,   20,  116,    0,    2,    7},
    {  -46,   20,  117,    0,    2,    7}, {  -47,   20,  118,    0,    2,    7}, {  -48,   20,  119,    0,    2,    7}, {  -49,   20,  119,    0,    2,    7}, {  -50,   20,  120,    0,    2,    7},
    {  -51,   20,  121,    0,    2,    7}, {  -52,   20,  122,    0,    2,    7}, {  -53,   20,  122,    0,    2,    8}, {  -54,   20,  123,    0,    2,    8}, {  -55,   19,  124,    0,    2,    8},
    {  -56,   19,  125,    0,    2,    8}, {  -58,   19,  125,    0,    2,    8}, {  -59,   19,  126,    0,    2,    8}, {  -60,   19,  127,    0,    2,    8}, {  -61,   19,  127,    0,    2,    8},
    {  -62,   19,  128,    0,    2,    8}, {  -63,   19,  129,    0,    2,    8}, {  -64,   19,  129,    0,    2,    8}, {  -65,   19,  130,    0,    2,    8}, {  -66,   19,  131,    0,    2,    8},
    {  -68,   19,  131,    0,    2,    8}, {  -69,   18,  132,    0,    2,    8}, {  -70,   18,  132,    0,    2,    9}, {  -71,   18,  133,    0,    2,    9}, {  -72,   18,  133,    0,    2,    9},
    {  -73,   18,  134,    0,    2,    9}, {  -75,   18,  134,    0,    2,    9}, {  -76,   18,  134,    0,    2,    9}, {  -77,   18,  135,    0,    2,    9}, {  -78,   18,  135,    0,    2,    9},
    {  -80,   17,  136,    0,    2,    9}, {  -81,   17,  136,    0,    2,    9}, {  -82,   17,  136,    0,    2,    9}, {  -83,   17,  136,    0,    0,    9}, {  -85,   17,  137,    0,    0,    9},
    {  -86,   17,  137,    0,    0,    9}, {  -87,   17,  137,   16,   16,    0}, {  -89,   17,  137,   16,   16,    0}, {  -90,   17,  137,   16,   16,    0}, {  -91,   16,  137,   16,   16,    0},
    {  -93,   16,  138,   16,   16,    0}, {  -94,   16,  138,   16,   16,    0}, {  -95,   16,  138,   16,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeZeroGRollUp1, {
    {   16,    0,   -1,    8,    4,    0}, {   16,    1,    0,    8,    4,    0}, {   16,    1,    1,    8,    4,    0}, {   16,    2,    2,    8,    4,    0}, {   16,    2,    3,    8,    4,    0},
    {   16,    3,    4,    8,    4,    0}, {   16,    3,    5,    8,    4,    0}, {   16,    4,    6,    8,    4,    0}, {   16,    4,    7,    8,    4,    0}, {   16,    5,    9,    8,    4,    0},
    {   16,    5,   10,    8,    4,    0}, {   16,    6,   11,    8,    4,    0}, {   16,    7,   12,    8,    4,    0}, {   16,    7,   13,    8,    4,    0}, {   16,    8,   14,    8,    4,    0},
    {   16,    8,   15,    8,    4,    0}, {   17,    9,   16,    8,    4,    0}, {   17,    9,   17,    8,    4,    0}, {   17,   10,   18,    8,    4,    0}, {   17,   11,   19,    8,    4,    0},
    {   17,   11,   20,    8,    4,    0}, {   17,   12,   22,    8,    4,    0}, {   17,   12,   23,    8,    4,    0}, {   17,   13,   24,    8,    4,    0}, {   17,   13,   25,    8,    4,    1},
    {   17,   14,   26,    8,    4,    1}, {   17,   15,   27,    8,    4,    1}, {   17,   15,   28,    8,    4,    1}, {   17,   16,   29,    8,    4,    1}, {   17,   17,   30,    8,    4,    1},
    {   17,   17,   31,    8,    4,    1}, {   17,   18,   33,    8,    4,    1}, {   17,   18,   34,    8,    4,    1}, {   17,   19,   35,    8,    4,    1}, {   17,   20,   36,    8,    4,    1},
    {   17,   20,   37,    8,    4,    1}, {   18,   21,   38,    8,    4,    1}, {   18,   22,   39,    8,    4,    1}, {   18,   22,   40,    8,    4,    1}, {   18,   23,   42,    8,    4,    1},
    {   18,   23,   43,    8,    4,    1}, {   18,   24,   44,    8,    4,    1}, {   18,   25,   45,    8,    4,    1}, {   18,   25,   46,    8,    4,    1}, {   18,   26,   47,    8,    4,    1},
    {   18,   27,   48,    8,    4,    1}, {   18,   27,   49,    8,    4,    1}, {   18,   28,   50,    8,    4,    1}, {   18,   29,   52,    8,    4,    1}, {   18,   29,   53,    8,    4,    1},
    {   18,   30,   54,    8,    4,    1}, {   18,   31,   55,    8,    4,    1}, {   19,   31,   56,    8,    4,    1}, {   19,   32,   57,    8,    4,    1}, {   19,   33,   58,    8,    3,    2},
    {   19,   33,   59,    8,    3,    2}, {   19,   34,   61,    8,    3,    2}, {   19,   35,   62,    8,    3,    2}, {   19,   36,   63,    8,    3,    2}, {   19,   36,   64,    8,    3,    2},
    {   19,   37,   65,    8,    3,    2}, {   19,   38,   66,    8,    3,    2}, {   19,   38,   67,    8,    3,    2}, {   19,   39,   68,    8,    3,    2}, {   19,   40,   69,    8,    3,    2},
    {   19,   41,   71,    8,    3,    2}, {   19,   41,   72,    8,    3,    2}, {   19,   42,   73,    8,    3,    2}, {   20,   43,   74,    8,    3,    2}, {   20,   43,   75,    8,    3,    2},
    {   20,   44,   76,    8,    3,    2}, {   20,   45,   77,    8,    3,    5}, {   20,   46,   78,    8,    3,    5}, {   20,   46,   79,    8,    3,    5}, {   20,   47,   80,    8,    3,    5},
    {   20,   48,   81,    8,    3,    5}, {   20,   49,   83,    8,    3,    5}, {   20,   49,   84,    8,    3,    5}, {   20,   50,   85,    8,    3,    5}, {   20,   51,   86,    8,    3,    5},
    {   20,   52,   87,    8,    3,    5}, {   20,   52,   88,    8,    3,    5}, {   20,   53,   89,    8,    3,    5}, {   20,   54,   90,    8,    3,    5}, {   20,   55,   91,    8,    3,    5},
    {   20,   56,   92,    8,    3,    5}, {   20,   56,   93,    8,    3,    5}, {   20,   57,   94,    8,    3,    5}, {   20,   58,   95,    8,    3,    6}, {   20,   59,   96,    8,    3,    6},
    {   20,   60,   97,    8,    3,    6}, {   20,   61,   98,    8,    3,    6}, {   20,   61,   99,    8,    3,    6}, {   20,   62,  100,    8,    3,    6}, {   20,   63,  101,    8,    3,    6},
    {   20,   64,  102,    8,    3,    6}, {   20,   65,  103,    8,    3,    6}, {   20,   66,  104,    8,    3,    6}, {   20,   66,  105,    8,    3,    6}, {   20,   67,  106,    8,    3,    6},
    {   20,   68,  107,    8,    3,    6}, {   20,   69,  108,    8,    3,    6}, {   20,   70,  109,    8,    3,    6}, {   20,   71,  110,    8,    3,    6}, {   20,   72,  111,    8,    3,    6},
    {   20,   73,  112,    8,    3,    6}, {   20,   74,  113,    8,    3,    6}, {   20,   75,  113,    8,    2,    7}, {   20,   76,  114,    8,    2,    7}, {   20,   76,  115,    8,    2,    7},
    {   20,   77,  116,    8,    2,    7}, {   20,   78,  117,    8,    2,    7}, {   20,   79,  118,    8,    2,    7}, {   20,   80,  119,    8,    2,    7}, {   20,   81,  119,    8,    2,    7},
    {   20,   82,  120,    8,    2,    7}, {   20,   83,  121,    8,    2,    7}, {   20,   84,  122,    8,    2,    7}, {   20,   85,  122,    8,    2,    8}, {   20,   86,  123,    8,    2,    8},
    {   19,   87,  124,    8,    2,    8}, {   19,   88,  125,    8,    2,    8}, {   19,   90,  125,    8,    2,    8}, {   19,   91,  126,    8,    2,    8}, {   19,   92,  127,    8,    2,    8},
    {   19,   93,  127,    8,    2,    8}, {   19,   94,  128,    8,    2,    8}, {   19,   95,  129,    8,    2,    8}, {   19,   96,  129,    8,    2,    8}, {   19,   97,  130,    8,    2,    8},
    {   19,   98,  131,    8,    2,    8}, {   19,  100,  131,    8,    2,    8}, {   18,  101,  132,    8,    2,    8}, {   18,  102,  132,    8,    2,    9}, {   18,  103,  133,    8,    2,    9},
    {   18,  104,  133,    8,    2,    9}, {   18,  105,  134,    8,    2,    9}, {   18,  107,  134,    8,    2,    9}, {   18,  108,  134,    8,    2,    9}, {   18,  109,  135,    8,    2,    9},
    {   18,  110,  135,    8,    2,    9}, {   17,  112,  136,    8,    2,    9}, {   17,  113,  136,    8,    2,    9}, {   17,  114,  136,    8,    2,    9}, {   17,  115,  136,    8,    0,    9},
    {   17,  117,  137,    8,    0,    9}, {   17,  118,  137,    8,    0,    9}, {   17,  119,  137,   24,   16,    0}, {   17,  121,  137,   24,   16,    0}, {   17,  122,  137,   24,   16,    0},
    {   16,  123,  137,   24,   16,    0}, {   16,  125,  138,   24,   16,    0}, {   16,  126,  138,   24,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeZeroGRollUp2, {
    {    0,   16,   -1,   16,    4,    0}, {    1,   16,    0,   16,    4,    0}, {    1,   16,    1,   16,    4,    0}, {    2,   16,    2,   16,    4,    0}, {    2,   16,    3,   16,    4,    0},
    {    3,   16,    4,   16,    4,    0}, {    3,   16,    5,   16,    4,    0}, {    4,   16,    6,   16,    4,    0}, {    4,   16,    7,   16,    4,    0}, {    5,   16,    9,   16,    4,    0},
    {    5,   16,   10,   16,    4,    0}, {    6,   16,   11,   16,    4,    0}, {    7,   16,   12,   16,    4,    0}, {    7,   16,   13,   16,    4,    0}, {    8,   16,   14,   16,    4,    0},
    {    8,   16,   15,   16,    4,    0}, {    9,   15,   16,   16,    4,    0}, {    9,   15,   17,   16,    4,    0}, {   10,   15,   18,   16,    4,    0}, {   11,   15,   19,   16,    4,    0},
    {   11,   15,   20,   16,    4,    0}, {   12,   15,   22,   16,    4,    0}, {   12,   15,   23,   16,    4,    0}, {   13,   15,   24,   16,    4,    0}, {   13,   15,   25,   16,    4,    1},
    {   14,   15,   26,   16,    4,    1}, {   15,   15,   27,   16,    4,    1}, {   15,   15,   28,   16,    4,    1}, {   16,   15,   29,   16,    4,    1}, {   17,   15,   30,   16,    4,    1},
    {   17,   15,   31,   16,    4,    1}, {   18,   15,   33,   16,    4,    1}, {   18,   15,   34,   16,    4,    1}, {   19,   15,   35,   16,    4,    1}, {   20,   15,   36,   16,    4,    1},
    {   20,   15,   37,   16,    4,    1}, {   21,   14,   38,   16,    4,    1}, {   22,   14,   39,   16,    4,    1}, {   22,   14,   40,   16,    4,    1}, {   23,   14,   42,   16,    4,    1},
    {   23,   14,   43,   16,    4,    1}, {   24,   14,   44,   16,    4,    1}, {   25,   14,   45,   16,    4,    1}, {   25,   14,   46,   16,    4,    1}, {   26,   14,   47,   16,    4,    1},
    {   27,   14,   48,   16,    4,    1}, {   27,   14,   49,   16,    4,    1}, {   28,   14,   50,   16,    4,    1}, {   29,   14,   52,   16,    4,    1}, {   29,   14,   53,   16,    4,    1},
    {   30,   14,   54,   16,    4,    1}, {   31,   14,   55,   16,    4,    1}, {   31,   13,   56,   16,    4,    1}, {   32,   13,   57,   16,    4,    1}, {   33,   13,   58,   16,    3,    2},
    {   33,   13,   59,   16,    3,    2}, {   34,   13,   61,   16,    3,    2}, {   35,   13,   62,   16,    3,    2}, {   36,   13,   63,   16,    3,    2}, {   36,   13,   64,   16,    3,    2},
    {   37,   13,   65,   16,    3,    2}, {   38,   13,   66,   16,    3,    2}, {   38,   13,   67,   16,    3,    2}, {   39,   13,   68,   16,    3,    2}, {   40,   13,   69,   16,    3,    2},
    {   41,   13,   71,   16,    3,    2}, {   41,   13,   72,   16,    3,    2}, {   42,   13,   73,   16,    3,    2}, {   43,   12,   74,   16,    3,    2}, {   43,   12,   75,   16,    3,    2},
    {   44,   12,   76,   16,    3,    2}, {   45,   12,   77,   16,    3,    5}, {   46,   12,   78,   16,    3,    5}, {   46,   12,   79,   16,    3,    5}, {   47,   12,   80,   16,    3,    5},
    {   48,   12,   81,   16,    3,    5}, {   49,   12,   83,   16,    3,    5}, {   49,   12,   84,   16,    3,    5}, {   50,   12,   85,   16,    3,    5}, {   51,   12,   86,   16,    3,    5},
    {   52,   12,   87,   16,    3,    5}, {   52,   12,   88,   16,    3,    5}, {   53,   12,   89,   16,    3,    5}, {   54,   12,   90,   16,    3,    5}, {   55,   12,   91,   16,    3,    5},
    {   56,   12,   92,   16,    3,    5}, {   56,   12,   93,   16,    3,    5}, {   57,   12,   94,   16,    3,    5}, {   58,   12,   95,   16,    3,    6}, {   59,   12,   96,   16,    3,    6},
    {   60,   12,   97,   16,    3,    6}, {   61,   12,   98,   16,    3,    6}, {   61,   12,   99,   16,    3,    6}, {   62,   12,  100,   16,    3,    6}, {   63,   12,  101,   16,    3,    6},
    {   64,   12,  102,   16,    3,    6}, {   65,   12,  103,   16,    3,    6}, {   66,   12,  104,   16,    3,    6}, {   66,   12,  105,   16,    3,    6}, {   67,   12,  106,   16,    3,    6},
    {   68,   12,  107,   16,    3,    6}, {   69,   12,  108,   16,    3,    6}, {   70,   12,  109,   16,    3,    6}, {   71,   12,  110,   16,    3,    6}, {   72,   12,  111,   16,    3,    6},
    {   73,   12,  112,   16,    3,    6}, {   74,   12,  113,   16,    3,    6}, {   75,   12,  113,   16,    2,    7}, {   76,   12,  114,   16,    2,    7}, {   76,   12,  115,   16,    2,    7},
    {   77,   12,  116,   16,    2,    7}, {   78,   12,  117,   16,    2,    7}, {   79,   12,  118,   16,    2,    7}, {   80,   12,  119,   16,    2,    7}, {   81,   12,  119,   16,    2,    7},
    {   82,   12,  120,   16,    2,    7}, {   83,   12,  121,   16,    2,    7}, {   84,   12,  122,   16,    2,    7}, {   85,   12,  122,   16,    2,    8}, {   86,   12,  123,   16,    2,    8},
    {   87,   13,  124,   16,    2,    8}, {   88,   13,  125,   16,    2,    8}, {   90,   13,  125,   16,    2,    8}, {   91,   13,  126,   16,    2,    8}, {   92,   13,  127,   16,    2,    8},
    {   93,   13,  127,   16,    2,    8}, {   94,   13,  128,   16,    2,    8}, {   95,   13,  129,   16,    2,    8}, {   96,   13,  129,   16,    2,    8}, {   97,   13,  130,   16,    2,    8},
    {   98,   13,  131,   16,    2,    8}, {  100,   13,  131,   16,    2,    8}, {  101,   14,  132,   16,    2,    8}, {  102,   14,  132,   16,    2,    9}, {  103,   14,  133,   16,    2,    9},
    {  104,   14,  133,   16,    2,    9}, {  105,   14,  134,   16,    2,    9}, {  107,   14,  134,   16,    2,    9}, {  108,   14,  134,   16,    2,    9}, {  109,   14,  135,   16,    2,    9},
    {  110,   14,  135,   16,    2,    9}, {  112,   15,  136,   16,    2,    9}, {  113,   15,  136,   16,    2,    9}, {  114,   15,  136,   16,    2,    9}, {  115,   15,  136,   16,    0,    9},
    {  117,   15,  137,   16,    0,    9}, {  118,   15,  137,   16,    0,    9}, {  119,   15,  137,    0,   16,    0}, {  121,   15,  137,    0,   16,    0}, {  122,   15,  137,    0,   16,    0},
    {  123,   16,  137,    0,   16,    0}, {  125,   16,  138,    0,   16,    0}, {  126,   16,  138,    0,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeZeroGRollUp3, {
    {   16,   31,    0,   24,    4,    0}, {   16,   31,    1,   24,    4,    0}, {   16,   30,    2,   24,    4,    0}, {   16,   30,    3,   24,    4,    0}, {   16,   29,    4,   24,    4,    0},
    {   16,   29,    5,   24,    4,    0}, {   16,   28,    6,   24,    4,    0}, {   16,   28,    7,   24,    4,    0}, {   16,   27,    9,   24,    4,    0}, {   16,   27,   10,   24,    4,    0},
    {   16,   26,   11,   24,    4,    0}, {   16,   25,   12,   24,    4,    0}, {   16,   25,   13,   24,    4,    0}, {   16,   24,   14,   24,    4,    0}, {   16,   24,   15,   24,    4,    0},
    {   15,   23,   16,   24,    4,    0}, {   15,   23,   17,   24,    4,    0}, {   15,   22,   18,   24,    4,    0}, {   15,   21,   19,   24,    4,    0}, {   15,   21,   20,   24,    4,    0},
    {   15,   20,   22,   24,    4,    0}, {   15,   20,   23,   24,    4,    0}, {   15,   19,   24,   24,    4,    0}, {   15,   19,   25,   24,    4,    1}, {   15,   18,   26,   24,    4,    1},
    {   15,   17,   27,   24,    4,    1}, {   15,   17,   28,   24,    4,    1}, {   15,   16,   29,   24,    4,    1}, {   15,   15,   30,   24,    4,    1}, {   15,   15,   31,   24,    4,    1},
    {   15,   14,   33,   24,    4,    1}, {   15,   14,   34,   24,    4,    1}, {   15,   13,   35,   24,    4,    1}, {   15,   12,   36,   24,    4,    1}, {   15,   12,   37,   24,    4,    1},
    {   14,   11,   38,   24,    4,    1}, {   14,   10,   39,   24,    4,    1}, {   14,   10,   40,   24,    4,    1}, {   14,    9,   42,   24,    4,    1}, {   14,    9,   43,   24,    4,    1},
    {   14,    8,   44,   24,    4,    1}, {   14,    7,   45,   24,    4,    1}, {   14,    7,   46,   24,    4,    1}, {   14,    6,   47,   24,    4,    1}, {   14,    5,   48,   24,    4,    1},
    {   14,    5,   49,   24,    4,    1}, {   14,    4,   50,   24,    4,    1}, {   14,    3,   52,   24,    4,    1}, {   14,    3,   53,   24,    4,    1}, {   14,    2,   54,   24,    4,    1},
    {   14,    1,   55,   24,    4,    1}, {   13,    1,   56,   24,    4,    1}, {   13,    0,   57,   24,    4,    1}, {   13,   -1,   58,   24,    3,    2}, {   13,   -1,   59,   24,    3,    2},
    {   13,   -2,   61,   24,    3,    2}, {   13,   -3,   62,   24,    3,    2}, {   13,   -4,   63,   24,    3,    2}, {   13,   -4,   64,   24,    3,    2}, {   13,   -5,   65,   24,    3,    2},
    {   13,   -6,   66,   24,    3,    2}, {   13,   -6,   67,   24,    3,    2}, {   13,   -7,   68,   24,    3,    2}, {   13,   -8,   69,   24,    3,    2}, {   13,   -9,   71,   24,    3,    2},
    {   13,   -9,   72,   24,    3,    2}, {   13,  -10,   73,   24,    3,    2}, {   12,  -11,   74,   24,    3,    2}, {   12,  -11,   75,   24,    3,    2}, {   12,  -12,   76,   24,    3,    2},
    {   12,  -13,   77,   24,    3,    5}, {   12,  -14,   78,   24,    3,    5}, {   12,  -14,   79,   24,    3,    5}, {   12,  -15,   80,   24,    3,    5}, {   12,  -16,   81,   24,    3,    5},
    {   12,  -17,   83,   24,    3,    5}, {   12,  -17,   84,   24,    3,    5}, {   12,  -18,   85,   24,    3,    5}, {   12,  -19,   86,   24,    3,    5}, {   12,  -20,   87,   24,    3,    5},
    {   12,  -20,   88,   24,    3,    5}, {   12,  -21,   89,   24,    3,    5}, {   12,  -22,   90,   24,    3,    5}, {   12,  -23,   91,   24,    3,    5}, {   12,  -24,   92,   24,    3,    5},
    {   12,  -24,   93,   24,    3,    5}, {   12,  -25,   94,   24,    3,    5}, {   12,  -26,   95,   24,    3,    6}, {   12,  -27,   96,   24,    3,    6}, {   12,  -28,   97,   24,    3,    6},
    {   12,  -29,   98,   24,    3,    6}, {   12,  -29,   99,   24,    3,    6}, {   12,  -30,  100,   24,    3,    6}, {   12,  -31,  101,   24,    3,    6}, {   12,  -32,  102,   24,    3,    6},
    {   12,  -33,  103,   24,    3,    6}, {   12,  -34,  104,   24,    3,    6}, {   12,  -34,  105,   24,    3,    6}, {   12,  -35,  106,   24,    3,    6}, {   12,  -36,  107,   24,    3,    6},
    {   12,  -37,  108,   24,    3,    6}, {   12,  -38,  109,   24,    3,    6}, {   12,  -39,  110,   24,    3,    6}, {   12,  -40,  111,   24,    3,    6}, {   12,  -41,  112,   24,    3,    6},
    {   12,  -42,  113,   24,    3,    6}, {   12,  -43,  113,   24,    2,    7}, {   12,  -44,  114,   24,    2,    7}, {   12,  -44,  115,   24,    2,    7}, {   12,  -45,  116,   24,    2,    7},
    {   12,  -46,  117,   24,    2,    7}, {   12,  -47,  118,   24,    2,    7}, {   12,  -48,  119,   24,    2,    7}, {   12,  -49,  119,   24,    2,    7}, {   12,  -50,  120,   24,    2,    7},
    {   12,  -51,  121,   24,    2,    7}, {   12,  -52,  122,   24,    2,    7}, {   12,  -53,  122,   24,    2,    8}, {   12,  -54,  123,   24,    2,    8}, {   13,  -55,  124,   24,    2,    8},
    {   13,  -56,  125,   24,    2,    8}, {   13,  -58,  125,   24,    2,    8}, {   13,  -59,  126,   24,    2,    8}, {   13,  -60,  127,   24,    2,    8}, {   13,  -61,  127,   24,    2,    8},
    {   13,  -62,  128,   24,    2,    8}, {   13,  -63,  129,   24,    2,    8}, {   13,  -64,  129,   24,    2,    8}, {   13,  -65,  130,   24,    2,    8}, {   13,  -66,  131,   24,    2,    8},
    {   13,  -68,  131,   24,    2,    8}, {   14,  -69,  132,   24,    2,    8}, {   14,  -70,  132,   24,    2,    9}, {   14,  -71,  133,   24,    2,    9}, {   14,  -72,  133,   24,    2,    9},
    {   14,  -73,  134,   24,    2,    9}, {   14,  -75,  134,   24,    2,    9}, {   14,  -76,  134,   24,    2,    9}, {   14,  -77,  135,   24,    2,    9}, {   14,  -78,  135,   24,    2,    9},
    {   15,  -80,  136,   24,    2,    9}, {   15,  -81,  136,   24,    2,    9}, {   15,  -82,  136,   24,    2,    9}, {   15,  -83,  136,   24,    0,    9}, {   15,  -85,  137,   24,    0,    9},
    {   15,  -86,  137,   24,    0,    9}, {   15,  -87,  137,    8,   16,    0}, {   15,  -89,  137,    8,   16,    0}, {   15,  -90,  137,    8,   16,    0}, {   16,  -91,  137,    8,   16,    0},
    {   16,  -93,  138,    8,   16,    0}, {   16,  -94,  138,    8,   16,    0}, {   16,  -95,  138,    8,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeZeroGRollUp0, {
    {   31,   16,    0,    0,    4,    0}, {   31,   16,    1,    0,    4,    0}, {   30,   16,    2,    0,    4,    0}, {   30,   16,    3,    0,    4,    0}, {   29,   16,    4,    0,    4,    0},
    {   29,   16,    5,    0,    4,    0}, {   28,   16,    6,    0,    4,    0}, {   28,   16,    7,    0,    4,    0}, {   27,   16,    9,    0,    4,    0}, {   27,   16,   10,    0,    4,    0},
    {   26,   16,   11,    0,    4,    0}, {   25,   16,   12,    0,    4,    0}, {   25,   16,   13,    0,    4,    0}, {   24,   16,   14,    0,    4,    0}, {   24,   16,   15,    0,    4,    0},
    {   23,   15,   16,    0,    4,    0}, {   23,   15,   17,    0,    4,    0}, {   22,   15,   18,    0,    4,    0}, {   21,   15,   19,    0,    4,    0}, {   21,   15,   20,    0,    4,    0},
    {   20,   15,   22,    0,    4,    0}, {   20,   15,   23,    0,    4,    0}, {   19,   15,   24,    0,    4,    0}, {   19,   15,   25,    0,    4,    3}, {   18,   15,   26,    0,    4,    3},
    {   17,   15,   27,    0,    4,    3}, {   17,   15,   28,    0,    4,    3}, {   16,   15,   29,    0,    4,    3}, {   15,   15,   30,    0,    4,    3}, {   15,   15,   31,    0,    4,    3},
    {   14,   15,   33,    0,    4,    3}, {   14,   15,   34,    0,    4,    3}, {   13,   15,   35,    0,    4,    3}, {   12,   15,   36,    0,    4,    3}, {   12,   15,   37,    0,    4,    3},
    {   11,   14,   38,    0,    4,    3}, {   10,   14,   39,    0,    4,    3}, {   10,   14,   40,    0,    4,    3}, {    9,   14,   42,    0,    4,    3}, {    9,   14,   43,    0,    4,    3},
    {    8,   14,   44,    0,    4,    3}, {    7,   14,   45,    0,    4,    3}, {    7,   14,   46,    0,    4,    3}, {    6,   14,   47,    0,    4,    3}, {    5,   14,   48,    0,    4,    3},
    {    5,   14,   49,    0,    4,    3}, {    4,   14,   50,    0,    4,    3}, {    3,   14,   52,    0,    4,    3}, {    3,   14,   53,    0,    4,    3}, {    2,   14,   54,    0,    4,    3},
    {    1,   14,   55,    0,    4,    3}, {    1,   13,   56,    0,    4,    3}, {    0,   13,   57,    0,    4,    3}, {   -1,   13,   58,    0,    3,    4}, {   -1,   13,   59,    0,    3,    4},
    {   -2,   13,   61,    0,    3,    4}, {   -3,   13,   62,    0,    3,    4}, {   -4,   13,   63,    0,    3,    4}, {   -4,   13,   64,    0,    3,    4}, {   -5,   13,   65,    0,    3,    4},
    {   -6,   13,   66,    0,    3,    4}, {   -6,   13,   67,    0,    3,    4}, {   -7,   13,   68,    0,    3,    4}, {   -8,   13,   69,    0,    3,    4}, {   -9,   13,   71,    0,    3,    4},
    {   -9,   13,   72,    0,    3,    4}, {  -10,   13,   73,    0,    3,    4}, {  -11,   12,   74,    0,    3,    4}, {  -11,   12,   75,    0,    3,    4}, {  -12,   12,   76,    0,    3,    4},
    {  -13,   12,   77,    0,    3,   10}, {  -14,   12,   78,    0,    3,   10}, {  -14,   12,   79,    0,    3,   10}, {  -15,   12,   80,    0,    3,   10}, {  -16,   12,   81,    0,    3,   10},
    {  -17,   12,   83,    0,    3,   10}, {  -17,   12,   84,    0,    3,   10}, {  -18,   12,   85,    0,    3,   10}, {  -19,   12,   86,    0,    3,   10}, {  -20,   12,   87,    0,    3,   10},
    {  -20,   12,   88,    0,    3,   10}, {  -21,   12,   89,    0,    3,   10}, {  -22,   12,   90,    0,    3,   10}, {  -23,   12,   91,    0,    3,   10}, {  -24,   12,   92,    0,    3,   10},
    {  -24,   12,   93,    0,    3,   10}, {  -25,   12,   94,    0,    3,   10}, {  -26,   12,   95,    0,    3,   11}, {  -27,   12,   96,    0,    3,   11}, {  -28,   12,   97,    0,    3,   11},
    {  -29,   12,   98,    0,    3,   11}, {  -29,   12,   99,    0,    3,   11}, {  -30,   12,  100,    0,    3,   11}, {  -31,   12,  101,    0,    3,   11}, {  -32,   12,  102,    0,    3,   11},
    {  -33,   12,  103,    0,    3,   11}, {  -34,   12,  104,    0,    3,   11}, {  -34,   12,  105,    0,    3,   11}, {  -35,   12,  106,    0,    3,   11}, {  -36,   12,  107,    0,    3,   11},
    {  -37,   12,  108,    0,    3,   11}, {  -38,   12,  109,    0,    3,   11}, {  -39,   12,  110,    0,    3,   11}, {  -40,   12,  111,    0,    3,   11}, {  -41,   12,  112,    0,    3,   11},
    {  -42,   12,  113,    0,    3,   11}, {  -43,   12,  113,    0,    2,   12}, {  -44,   12,  114,    0,    2,   12}, {  -44,   12,  115,    0,    2,   12}, {  -45,   12,  116,    0,    2,   12},
    {  -46,   12,  117,    0,    2,   12}, {  -47,   12,  118,    0,    2,   12}, {  -48,   12,  119,    0,    2,   12}, {  -49,   12,  119,    0,    2,   12}, {  -50,   12,  120,    0,    2,   12},
    {  -51,   12,  121,    0,    2,   12}, {  -52,   12,  122,    0,    2,   12}, {  -53,   12,  122,    0,    2,   13}, {  -54,   12,  123,    0,    2,   13}, {  -55,   13,  124,    0,    2,   13},
    {  -56,   13,  125,    0,    2,   13}, {  -58,   13,  125,    0,    2,   13}, {  -59,   13,  126,    0,    2,   13}, {  -60,   13,  127,    0,    2,   13}, {  -61,   13,  127,    0,    2,   13},
    {  -62,   13,  128,    0,    2,   13}, {  -63,   13,  129,    0,    2,   13}, {  -64,   13,  129,    0,    2,   13}, {  -65,   13,  130,    0,    2,   13}, {  -66,   13,  131,    0,    2,   13},
    {  -68,   13,  131,    0,    2,   13}, {  -69,   14,  132,    0,    2,   13}, {  -70,   14,  132,    0,    2,   14}, {  -71,   14,  133,    0,    2,   14}, {  -72,   14,  133,    0,    2,   14},
    {  -73,   14,  134,    0,    2,   14}, {  -75,   14,  134,    0,    2,   14}, {  -76,   14,  134,    0,    2,   14}, {  -77,   14,  135,    0,    2,   14}, {  -78,   14,  135,    0,    2,   14},
    {  -80,   15,  136,    0,    2,   14}, {  -81,   15,  136,    0,    2,   14}, {  -82,   15,  136,    0,    2,   14}, {  -83,   15,  136,    0,    0,   14}, {  -85,   15,  137,    0,    0,   14},
    {  -86,   15,  137,    0,    0,   14}, {  -87,   15,  137,   16,   16,    0}, {  -89,   15,  137,   16,   16,    0}, {  -90,   15,  137,   16,   16,    0}, {  -91,   16,  137,   16,   16,    0},
    {  -93,   16,  138,   16,   16,    0}, {  -94,   16,  138,   16,   16,    0}, {  -95,   16,  138,   16,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeZeroGRollUp1, {
    {   16,    0,   -1,    8,    4,    0}, {   16,    1,    0,    8,    4,    0}, {   16,    1,    1,    8,    4,    0}, {   16,    2,    2,    8,    4,    0}, {   16,    2,    3,    8,    4,    0},
    {   16,    3,    4,    8,    4,    0}, {   16,    3,    5,    8,    4,    0}, {   16,    4,    6,    8,    4,    0}, {   16,    4,    7,    8,    4,    0}, {   16,    5,    9,    8,    4,    0},
    {   16,    5,   10,    8,    4,    0}, {   16,    6,   11,    8,    4,    0}, {   16,    7,   12,    8,    4,    0}, {   16,    7,   13,    8,    4,    0}, {   16,    8,   14,    8,    4,    0},
    {   16,    8,   15,    8,    4,    0}, {   15,    9,   16,    8,    4,    0}, {   15,    9,   17,    8,    4,    0}, {   15,   10,   18,    8,    4,    0}, {   15,   11,   19,    8,    4,    0},
    {   15,   11,   20,    8,    4,    0}, {   15,   12,   22,    8,    4,    0}, {   15,   12,   23,    8,    4,    0}, {   15,   13,   24,    8,    4,    0}, {   15,   13,   25,    8,    4,    3},
    {   15,   14,   26,    8,    4,    3}, {   15,   15,   27,    8,    4,    3}, {   15,   15,   28,    8,    4,    3}, {   15,   16,   29,    8,    4,    3}, {   15,   17,   30,    8,    4,    3},
    {   15,   17,   31,    8,    4,    3}, {   15,   18,   33,    8,    4,    3}, {   15,   18,   34,    8,    4,    3}, {   15,   19,   35,    8,    4,    3}, {   15,   20,   36,    8,    4,    3},
    {   15,   20,   37,    8,    4,    3}, {   14,   21,   38,    8,    4,    3}, {   14,   22,   39,    8,    4,    3}, {   14,   22,   40,    8,    4,    3}, {   14,   23,   42,    8,    4,    3},
    {   14,   23,   43,    8,    4,    3}, {   14,   24,   44,    8,    4,    3}, {   14,   25,   45,    8,    4,    3}, {   14,   25,   46,    8,    4,    3}, {   14,   26,   47,    8,    4,    3},
    {   14,   27,   48,    8,    4,    3}, {   14,   27,   49,    8,    4,    3}, {   14,   28,   50,    8,    4,    3}, {   14,   29,   52,    8,    4,    3}, {   14,   29,   53,    8,    4,    3},
    {   14,   30,   54,    8,    4,    3}, {   14,   31,   55,    8,    4,    3}, {   13,   31,   56,    8,    4,    3}, {   13,   32,   57,    8,    4,    3}, {   13,   33,   58,    8,    3,    4},
    {   13,   33,   59,    8,    3,    4}, {   13,   34,   61,    8,    3,    4}, {   13,   35,   62,    8,    3,    4}, {   13,   36,   63,    8,    3,    4}, {   13,   36,   64,    8,    3,    4},
    {   13,   37,   65,    8,    3,    4}, {   13,   38,   66,    8,    3,    4}, {   13,   38,   67,    8,    3,    4}, {   13,   39,   68,    8,    3,    4}, {   13,   40,   69,    8,    3,    4},
    {   13,   41,   71,    8,    3,    4}, {   13,   41,   72,    8,    3,    4}, {   13,   42,   73,    8,    3,    4}, {   12,   43,   74,    8,    3,    4}, {   12,   43,   75,    8,    3,    4},
    {   12,   44,   76,    8,    3,    4}, {   12,   45,   77,    8,    3,   10}, {   12,   46,   78,    8,    3,   10}, {   12,   46,   79,    8,    3,   10}, {   12,   47,   80,    8,    3,   10},
    {   12,   48,   81,    8,    3,   10}, {   12,   49,   83,    8,    3,   10}, {   12,   49,   84,    8,    3,   10}, {   12,   50,   85,    8,    3,   10}, {   12,   51,   86,    8,    3,   10},
    {   12,   52,   87,    8,    3,   10}, {   12,   52,   88,    8,    3,   10}, {   12,   53,   89,    8,    3,   10}, {   12,   54,   90,    8,    3,   10}, {   12,   55,   91,    8,    3,   10},
    {   12,   56,   92,    8,    3,   10}, {   12,   56,   93,    8,    3,   10}, {   12,   57,   94,    8,    3,   10}, {   12,   58,   95,    8,    3,   11}, {   12,   59,   96,    8,    3,   11},
    {   12,   60,   97,    8,    3,   11}, {   12,   61,   98,    8,    3,   11}, {   12,   61,   99,    8,    3,   11}, {   12,   62,  100,    8,    3,   11}, {   12,   63,  101,    8,    3,   11},
    {   12,   64,  102,    8,    3,   11}, {   12,   65,  103,    8,    3,   11}, {   12,   66,  104,    8,    3,   11}, {   12,   66,  105,    8,    3,   11}, {   12,   67,  106,    8,    3,   11},
    {   12,   68,  107,    8,    3,   11}, {   12,   69,  108,    8,    3,   11}, {   12,   70,  109,    8,    3,   11}, {   12,   71,  110,    8,    3,   11}, {   12,   72,  111,    8,    3,   11},
    {   12,   73,  112,    8,    3,   11}, {   12,   74,  113,    8,    3,   11}, {   12,   75,  113,    8,    2,   12}, {   12,   76,  114,    8,    2,   12}, {   12,   76,  115,    8,    2,   12},
    {   12,   77,  116,    8,    2,   12}, {   12,   78,  117,    8,    2,   12}, {   12,   79,  118,    8,    2,   12}, {   12,   80,  119,    8,    2,   12}, {   12,   81,  119,    8,    2,   12},
    {   12,   82,  120,    8,    2,   12}, {   12,   83,  121,    8,    2,   12}, {   12,   84,  122,    8,    2,   12}, {   12,   85,  122,    8,    2,   13}, {   12,   86,  123,    8,    2,   13},
    {   13,   87,  124,    8,    2,   13}, {   13,   88,  125,    8,    2,   13}, {   13,   90,  125,    8,    2,   13}, {   13,   91,  126,    8,    2,   13}, {   13,   92,  127,    8,    2,   13},
    {   13,   93,  127,    8,    2,   13}, {   13,   94,  128,    8,    2,   13}, {   13,   95,  129,    8,    2,   13}, {   13,   96,  129,    8,    2,   13}, {   13,   97,  130,    8,    2,   13},
    {   13,   98,  131,    8,    2,   13}, {   13,  100,  131,    8,    2,   13}, {   14,  101,  132,    8,    2,   13}, {   14,  102,  132,    8,    2,   14}, {   14,  103,  133,    8,    2,   14},
    {   14,  104,  133,    8,    2,   14}, {   14,  105,  134,    8,    2,   14}, {   14,  107,  134,    8,    2,   14}, {   14,  108,  134,    8,    2,   14}, {   14,  109,  135,    8,    2,   14},
    {   14,  110,  135,    8,    2,   14}, {   15,  112,  136,    8,    2,   14}, {   15,  113,  136,    8,    2,   14}, {   15,  114,  136,    8,    2,   14}, {   15,  115,  136,    8,    0,   14},
    {   15,  117,  137,    8,    0,   14}, {   15,  118,  137,    8,    0,   14}, {   15,  119,  137,   24,   16,    0}, {   15,  121,  137,   24,   16,    0}, {   15,  122,  137,   24,   16,    0},
    {   16,  123,  137,   24,   16,    0}, {   16,  125,  138,   24,   16,    0}, {   16,  126,  138,   24,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeZeroGRollUp2, {
    {    0,   16,   -1,   16,    4,    0}, {    1,   16,    0,   16,    4,    0}, {    1,   16,    1,   16,    4,    0}, {    2,   16,    2,   16,    4,    0}, {    2,   16,    3,   16,    4,    0},
    {    3,   16,    4,   16,    4,    0}, {    3,   16,    5,   16,    4,    0}, {    4,   16,    6,   16,    4,    0}, {    4,   16,    7,   16,    4,    0}, {    5,   16,    9,   16,    4,    0},
    {    5,   16,   10,   16,    4,    0}, {    6,   16,   11,   16,    4,    0}, {    7,   16,   12,   16,    4,    0}, {    7,   16,   13,   16,    4,    0}, {    8,   16,   14,   16,    4,    0},
    {    8,   16,   15,   16,    4,    0}, {    9,   17,   16,   16,    4,    0}, {    9,   17,   17,   16,    4,    0}, {   10,   17,   18,   16,    4,    0}, {   11,   17,   19,   16,    4,    0},
    {   11,   17,   20,   16,    4,    0}, {   12,   17,   22,   16,    4,    0}, {   12,   17,   23,   16,    4,    0}, {   13,   17,   24,   16,    4,    0}, {   13,   17,   25,   16,    4,    3},
    {   14,   17,   26,   16,    4,    3}, {   15,   17,   27,   16,    4,    3}, {   15,   17,   28,   16,    4,    3}, {   16,   17,   29,   16,    4,    3}, {   17,   17,   30,   16,    4,    3},
    {   17,   17,   31,   16,    4,    3}, {   18,   17,   33,   16,    4,    3}, {   18,   17,   34,   16,    4,    3}, {   19,   17,   35,   16,    4,    3}, {   20,   17,   36,   16,    4,    3},
    {   20,   17,   37,   16,    4,    3}, {   21,   18,   38,   16,    4,    3}, {   22,   18,   39,   16,    4,    3}, {   22,   18,   40,   16,    4,    3}, {   23,   18,   42,   16,    4,    3},
    {   23,   18,   43,   16,    4,    3}, {   24,   18,   44,   16,    4,    3}, {   25,   18,   45,   16,    4,    3}, {   25,   18,   46,   16,    4,    3}, {   26,   18,   47,   16,    4,    3},
    {   27,   18,   48,   16,    4,    3}, {   27,   18,   49,   16,    4,    3}, {   28,   18,   50,   16,    4,    3}, {   29,   18,   52,   16,    4,    3}, {   29,   18,   53,   16,    4,    3},
    {   30,   18,   54,   16,    4,    3}, {   31,   18,   55,   16,    4,    3}, {   31,   19,   56,   16,    4,    3}, {   32,   19,   57,   16,    4,    3}, {   33,   19,   58,   16,    3,    4},
    {   33,   19,   59,   16,    3,    4}, {   34,   19,   61,   16,    3,    4}, {   35,   19,   62,   16,    3,    4}, {   36,   19,   63,   16,    3,    4}, {   36,   19,   64,   16,    3,    4},
    {   37,   19,   65,   16,    3,    4}, {   38,   19,   66,   16,    3,    4}, {   38,   19,   67,   16,    3,    4}, {   39,   19,   68,   16,    3,    4}, {   40,   19,   69,   16,    3,    4},
    {   41,   19,   71,   16,    3,    4}, {   41,   19,   72,   16,    3,    4}, {   42,   19,   73,   16,    3,    4}, {   43,   20,   74,   16,    3,    4}, {   43,   20,   75,   16,    3,    4},
    {   44,   20,   76,   16,    3,    4}, {   45,   20,   77,   16,    3,   10}, {   46,   20,   78,   16,    3,   10}, {   46,   20,   79,   16,    3,   10}, {   47,   20,   80,   16,    3,   10},
    {   48,   20,   81,   16,    3,   10}, {   49,   20,   83,   16,    3,   10}, {   49,   20,   84,   16,    3,   10}, {   50,   20,   85,   16,    3,   10}, {   51,   20,   86,   16,    3,   10},
    {   52,   20,   87,   16,    3,   10}, {   52,   20,   88,   16,    3,   10}, {   53,   20,   89,   16,    3,   10}, {   54,   20,   90,   16,    3,   10}, {   55,   20,   91,   16,    3,   10},
    {   56,   20,   92,   16,    3,   10}, {   56,   20,   93,   16,    3,   10}, {   57,   20,   94,   16,    3,   10}, {   58,   20,   95,   16,    3,   11}, {   59,   20,   96,   16,    3,   11},
    {   60,   20,   97,   16,    3,   11}, {   61,   20,   98,   16,    3,   11}, {   61,   20,   99,   16,    3,   11}, {   62,   20,  100,   16,    3,   11}, {   63,   20,  101,   16,    3,   11},
    {   64,   20,  102,   16,    3,   11}, {   65,   20,  103,   16,    3,   11}, {   66,   20,  104,   16,    3,   11}, {   66,   20,  105,   16,    3,   11}, {   67,   20,  106,   16,    3,   11},
    {   68,   20,  107,   16,    3,   11}, {   69,   20,  108,   16,    3,   11}, {   70,   20,  109,   16,    3,   11}, {   71,   20,  110,   16,    3,   11}, {   72,   20,  111,   16,    3,   11},
    {   73,   20,  112,   16,    3,   11}, {   74,   20,  113,   16,    3,   11}, {   75,   20,  113,   16,    2,   12}, {   76,   20,  114,   16,    2,   12}, {   76,   20,  115,   16,    2,   12},
    {   77,   20,  116,   16,    2,   12}, {   78,   20,  117,   16,    2,   12}, {   79,   20,  118,   16,    2,   12}, {   80,   20,  119,   16,    2,   12}, {   81,   20,  119,   16,    2,   12},
    {   82,   20,  120,   16,    2,   12}, {   83,   20,  121,   16,    2,   12}, {   84,   20,  122,   16,    2,   12}, {   85,   20,  122,   16,    2,   13}, {   86,   20,  123,   16,    2,   13},
    {   87,   19,  124,   16,    2,   13}, {   88,   19,  125,   16,    2,   13}, {   90,   19,  125,   16,    2,   13}, {   91,   19,  126,   16,    2,   13}, {   92,   19,  127,   16,    2,   13},
    {   93,   19,  127,   16,    2,   13}, {   94,   19,  128,   16,    2,   13}, {   95,   19,  129,   16,    2,   13}, {   96,   19,  129,   16,    2,   13}, {   97,   19,  130,   16,    2,   13},
    {   98,   19,  131,   16,    2,   13}, {  100,   19,  131,   16,    2,   13}, {  101,   18,  132,   16,    2,   13}, {  102,   18,  132,   16,    2,   14}, {  103,   18,  133,   16,    2,   14},
    {  104,   18,  133,   16,    2,   14}, {  105,   18,  134,   16,    2,   14}, {  107,   18,  134,   16,    2,   14}, {  108,   18,  134,   16,    2,   14}, {  109,   18,  135,   16,    2,   14},
    {  110,   18,  135,   16,    2,   14}, {  112,   17,  136,   16,    2,   14}, {  113,   17,  136,   16,    2,   14}, {  114,   17,  136,   16,    2,   14}, {  115,   17,  136,   16,    0,   14},
    {  117,   17,  137,   16,    0,   14}, {  118,   17,  137,   16,    0,   14}, {  119,   17,  137,    0,   16,    0}, {  121,   17,  137,    0,   16,    0}, {  122,   17,  137,    0,   16,    0},
    {  123,   16,  137,    0,   16,    0}, {  125,   16,  138,    0,   16,    0}, {  126,   16,  138,    0,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeZeroGRollUp3, {
    {   16,   31,    0,   24,    4,    0}, {   16,   31,    1,   24,    4,    0}, {   16,   30,    2,   24,    4,    0}, {   16,   30,    3,   24,    4,    0}, {   16,   29,    4,   24,    4,    0},
    {   16,   29,    5,   24,    4,    0}, {   16,   28,    6,   24,    4,    0}, {   16,   28,    7,   24,    4,    0}, {   16,   27,    9,   24,    4,    0}, {   16,   27,   10,   24,    4,    0},
    {   16,   26,   11,   24,    4,    0}, {   16,   25,   12,   24,    4,    0}, {   16,   25,   13,   24,    4,    0}, {   16,   24,   14,   24,    4,    0}, {   16,   24,   15,   24,    4,    0},
    {   17,   23,   16,   24,    4,    0}, {   17,   23,   17,   24,    4,    0}, {   17,   22,   18,   24,    4,    0}, {   17,   21,   19,   24,    4,    0}, {   17,   21,   20,   24,    4,    0},
    {   17,   20,   22,   24,    4,    0}, {   17,   20,   23,   24,    4,    0}, {   17,   19,   24,   24,    4,    0}, {   17,   19,   25,   24,    4,    3}, {   17,   18,   26,   24,    4,    3},
    {   17,   17,   27,   24,    4,    3}, {   17,   17,   28,   24,    4,    3}, {   17,   16,   29,   24,    4,    3}, {   17,   15,   30,   24,    4,    3}, {   17,   15,   31,   24,    4,    3},
    {   17,   14,   33,   24,    4,    3}, {   17,   14,   34,   24,    4,    3}, {   17,   13,   35,   24,    4,    3}, {   17,   12,   36,   24,    4,    3}, {   17,   12,   37,   24,    4,    3},
    {   18,   11,   38,   24,    4,    3}, {   18,   10,   39,   24,    4,    3}, {   18,   10,   40,   24,    4,    3}, {   18,    9,   42,   24,    4,    3}, {   18,    9,   43,   24,    4,    3},
    {   18,    8,   44,   24,    4,    3}, {   18,    7,   45,   24,    4,    3}, {   18,    7,   46,   24,    4,    3}, {   18,    6,   47,   24,    4,    3}, {   18,    5,   48,   24,    4,    3},
    {   18,    5,   49,   24,    4,    3}, {   18,    4,   50,   24,    4,    3}, {   18,    3,   52,   24,    4,    3}, {   18,    3,   53,   24,    4,    3}, {   18,    2,   54,   24,    4,    3},
    {   18,    1,   55,   24,    4,    3}, {   19,    1,   56,   24,    4,    3}, {   19,    0,   57,   24,    4,    3}, {   19,   -1,   58,   24,    3,    4}, {   19,   -1,   59,   24,    3,    4},
    {   19,   -2,   61,   24,    3,    4}, {   19,   -3,   62,   24,    3,    4}, {   19,   -4,   63,   24,    3,    4}, {   19,   -4,   64,   24,    3,    4}, {   19,   -5,   65,   24,    3,    4},
    {   19,   -6,   66,   24,    3,    4}, {   19,   -6,   67,   24,    3,    4}, {   19,   -7,   68,   24,    3,    4}, {   19,   -8,   69,   24,    3,    4}, {   19,   -9,   71,   24,    3,    4},
    {   19,   -9,   72,   24,    3,    4}, {   19,  -10,   73,   24,    3,    4}, {   20,  -11,   74,   24,    3,    4}, {   20,  -11,   75,   24,    3,    4}, {   20,  -12,   76,   24,    3,    4},
    {   20,  -13,   77,   24,    3,   10}, {   20,  -14,   78,   24,    3,   10}, {   20,  -14,   79,   24,    3,   10}, {   20,  -15,   80,   24,    3,   10}, {   20,  -16,   81,   24,    3,   10},
    {   20,  -17,   83,   24,    3,   10}, {   20,  -17,   84,   24,    3,   10}, {   20,  -18,   85,   24,    3,   10}, {   20,  -19,   86,   24,    3,   10}, {   20,  -20,   87,   24,    3,   10},
    {   20,  -20,   88,   24,    3,   10}, {   20,  -21,   89,   24,    3,   10}, {   20,  -22,   90,   24,    3,   10}, {   20,  -23,   91,   24,    3,   10}, {   20,  -24,   92,   24,    3,   10},
    {   20,  -24,   93,   24,    3,   10}, {   20,  -25,   94,   24,    3,   10}, {   20,  -26,   95,   24,    3,   11}, {   20,  -27,   96,   24,    3,   11}, {   20,  -28,   97,   24,    3,   11},
    {   20,  -29,   98,   24,    3,   11}, {   20,  -29,   99,   24,    3,   11}, {   20,  -30,  100,   24,    3,   11}, {   20,  -31,  101,   24,    3,   11}, {   20,  -32,  102,   24,    3,   11},
    {   20,  -33,  103,   24,    3,   11}, {   20,  -34,  104,   24,    3,   11}, {   20,  -34,  105,   24,    3,   11}, {   20,  -35,  106,   24,    3,   11}, {   20,  -36,  107,   24,    3,   11},
    {   20,  -37,  108,   24,    3,   11}, {   20,  -38,  109,   24,    3,   11}, {   20,  -39,  110,   24,    3,   11}, {   20,  -40,  111,   24,    3,   11}, {   20,  -41,  112,   24,    3,   11},
    {   20,  -42,  113,   24,    3,   11}, {   20,  -43,  113,   24,    2,   12}, {   20,  -44,  114,   24,    2,   12}, {   20,  -44,  115,   24,    2,   12}, {   20,  -45,  116,   24,    2,   12},
    {   20,  -46,  117,   24,    2,   12}, {   20,  -47,  118,   24,    2,   12}, {   20,  -48,  119,   24,    2,   12}, {   20,  -49,  119,   24,    2,   12}, {   20,  -50,  120,   24,    2,   12},
    {   20,  -51,  121,   24,    2,   12}, {   20,  -52,  122,   24,    2,   12}, {   20,  -53,  122,   24,    2,   13}, {   20,  -54,  123,   24,    2,   13}, {   19,  -55,  124,   24,    2,   13},
    {   19,  -56,  125,   24,    2,   13}, {   19,  -58,  125,   24,    2,   13}, {   19,  -59,  126,   24,    2,   13}, {   19,  -60,  127,   24,    2,   13}, {   19,  -61,  127,   24,    2,   13},
    {   19,  -62,  128,   24,    2,   13}, {   19,  -63,  129,   24,    2,   13}, {   19,  -64,  129,   24,    2,   13}, {   19,  -65,  130,   24,    2,   13}, {   19,  -66,  131,   24,    2,   13},
    {   19,  -68,  131,   24,    2,   13}, {   18,  -69,  132,   24,    2,   13}, {   18,  -70,  132,   24,    2,   14}, {   18,  -71,  133,   24,    2,   14}, {   18,  -72,  133,   24,    2,   14},
    {   18,  -73,  134,   24,    2,   14}, {   18,  -75,  134,   24,    2,   14}, {   18,  -76,  134,   24,    2,   14}, {   18,  -77,  135,   24,    2,   14}, {   18,  -78,  135,   24,    2,   14},
    {   17,  -80,  136,   24,    2,   14}, {   17,  -81,  136,   24,    2,   14}, {   17,  -82,  136,   24,    2,   14}, {   17,  -83,  136,   24,    0,   14}, {   17,  -85,  137,   24,    0,   14},
    {   17,  -86,  137,   24,    0,   14}, {   17,  -87,  137,    8,   16,    0}, {   17,  -89,  137,    8,   16,    0}, {   17,  -90,  137,    8,   16,    0}, {   16,  -91,  137,    8,   16,    0},
    {   16,  -93,  138,    8,   16,    0}, {   16,  -94,  138,    8,   16,    0}, {   16,  -95,  138,    8,   16,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeZeroGRollDown0, {
    {   30,   16,   19,   16,   16,    0}, {   29,   16,   19,   16,   16,    0}, {   27,   16,   19,   16,   16,    0}, {   26,   15,   19,   16,   16,    0}, {   25,   15,   19,   16,   16,    0},
    {   23,   15,   18,   16,   16,    0}, {   22,   15,   18,    0,    0,   14}, {   21,   15,   18,    0,    0,   14}, {   19,   15,   18,    0,    0,   14}, {   18,   15,   17,    0,    6,   14},
    {   17,   15,   17,    0,    6,   14}, {   16,   15,   17,    0,    6,   14}, {   14,   14,   17,    0,    6,   14}, {   13,   14,   16,    0,    6,   14}, {   12,   14,   16,    0,    6,   14},
    {   11,   14,   15,    0,    6,   14}, {    9,   14,   15,    0,    6,   14}, {    8,   14,   14,    0,    6,   14}, {    7,   14,   14,    0,    6,   14}, {    6,   14,   13,    0,    6,   14},
    {    5,   14,   13,    0,    6,   13}, {    4,   13,   12,    0,    6,   13}, {    2,   13,   12,    0,    6,   13}, {    1,   13,   11,    0,    6,   13}, {    0,   13,   11,    0,    6,   13},
    {   -1,   13,   10,    0,    6,   13}, {   -2,   13,    9,    0,    6,   13}, {   -3,   13,    9,    0,    6,   13}, {   -4,   13,    8,    0,    6,   13}, {   -5,   13,    7,    0,    6,   13},
    {   -6,   13,    7,    0,    6,   13}, {   -8,   13,    6,    0,    6,   13}, {   -9,   13,    5,    0,    6,   13}, {  -10,   12,    5,    0,    6,   13}, {  -11,   12,    4,    0,    6,   13},
    {  -12,   12,    3,    0,    6,   12}, {  -13,   12,    2,    0,    6,   12}, {  -14,   12,    1,    0,    6,   12}, {  -15,   12,    1,    0,    6,   12}, {  -16,   12,    0,    0,    6,   12},
    {  -17,   12,   -1,    0,    6,   12}, {  -18,   12,   -2,    0,    6,   12}, {  -19,   12,   -3,    0,    6,   12}, {  -20,   12,   -3,    0,    6,   12}, {  -20,   12,   -4,    0,    6,   12},
    {  -21,   12,   -5,    0,    6,   12}, {  -22,   12,   -6,    0,    7,   11}, {  -23,   12,   -7,    0,    7,   11}, {  -24,   12,   -8,    0,    7,   11}, {  -25,   12,   -9,    0,    7,   11},
    {  -26,   12,  -10,    0,    7,   11}, {  -27,   12,  -11,    0,    7,   11}, {  -28,   12,  -12,    0,    7,   11}, {  -29,   12,  -13,    0,    7,   11}, {  -30,   12,  -14,    0,    7,   11},
    {  -30,   12,  -15,    0,    7,   11}, {  -31,   12,  -16,    0,    7,   11}, {  -32,   12,  -16,    0,    7,   11}, {  -33,   12,  -17,    0,    7,   11}, {  -34,   12,  -18,    0,    7,   11},
    {  -35,   12,  -19,    0,    7,   11}, {  -35,   12,  -20,    0,    7,   11}, {  -36,   12,  -21,    0,    7,   11}, {  -37,   12,  -23,    0,    7,   11}, {  -38,   12,  -24,    0,    7,   11},
    {  -39,   12,  -25,    0,    7,   10}, {  -40,   12,  -26,    0,    7,   10}, {  -40,   12,  -27,    0,    7,   10}, {  -41,   12,  -28,    0,    7,   10}, {  -42,   12,  -29,    0,    7,   10},
    {  -43,   12,  -30,    0,    7,   10}, {  -44,   12,  -31,    0,    7,   10}, {  -44,   12,  -32,    0,    7,   10}, {  -45,   12,  -33,    0,    7,   10}, {  -46,   12,  -34,    0,    7,   10},
    {  -47,   12,  -35,    0,    7,   10}, {  -47,   12,  -36,    0,    7,   10}, {  -48,   12,  -37,    0,    7,   10}, {  -49,   12,  -38,    0,    7,   10}, {  -50,   12,  -39,    0,    7,   10},
    {  -50,   12,  -40,    0,    7,   10}, {  -51,   12,  -42,    0,    7,   10}, {  -52,   12,  -43,    0,    7,    4}, {  -53,   12,  -44,    0,    7,    4}, {  -53,   12,  -45,    0,    7,    4},
    {  -54,   13,  -46,    0,    7,    4}, {  -55,   13,  -47,    0,    7,    4}, {  -55,   13,  -48,    0,    7,    4}, {  -56,   13,  -49,    0,    7,    4}, {  -57,   13,  -50,    0,    7,    4},
    {  -58,   13,  -51,    0,    7,    4}, {  -58,   13,  -53,    0,    7,    4}, {  -59,   13,  -54,    0,    7,    4}, {  -60,   13,  -55,    0,    7,    4}, {  -60,   13,  -56,    0,    7,    4},
    {  -61,   13,  -57,    0,    7,    4}, {  -62,   13,  -58,    0,    7,    4}, {  -63,   13,  -59,    0,    7,    4}, {  -63,   13,  -60,    0,    7,    4}, {  -64,   13,  -61,    0,    8,    3},
    {  -65,   13,  -63,    0,    8,    3}, {  -65,   14,  -64,    0,    8,    3}, {  -66,   14,  -65,    0,    8,    3}, {  -67,   14,  -66,    0,    8,    3}, {  -67,   14,  -67,    0,    8,    3},
    {  -68,   14,  -68,    0,    8,    3}, {  -69,   14,  -69,    0,    8,    3}, {  -69,   14,  -70,    0,    8,    3}, {  -70,   14,  -72,    0,    8,    3}, {  -71,   14,  -73,    0,    8,    3},
    {  -71,   14,  -74,    0,    8,    3}, {  -72,   14,  -75,    0,    8,    3}, {  -73,   14,  -76,    0,    8,    3}, {  -73,   14,  -77,    0,    8,    3}, {  -74,   14,  -78,    0,    8,    3},
    {  -74,   14,  -79,    0,    8,    3}, {  -75,   14,  -80,    0,    8,    3}, {  -76,   15,  -82,    0,    8,    3}, {  -76,   15,  -83,    0,    8,    3}, {  -77,   15,  -84,    0,    8,    3},
    {  -78,   15,  -85,    0,    8,    3}, {  -78,   15,  -86,    0,    8,    3}, {  -79,   15,  -87,    0,    8,    3}, {  -79,   15,  -88,    0,    8,    3}, {  -80,   15,  -89,    0,    8,    3},
    {  -81,   15,  -91,    0,    8,    3}, {  -81,   15,  -92,    0,    8,    3}, {  -82,   15,  -93,    0,    8,    3}, {  -83,   15,  -94,    0,    8,    3}, {  -83,   15,  -95,    0,    8,    0},
    {  -84,   15,  -96,    0,    8,    0}, {  -84,   15,  -97,    0,    8,    0}, {  -85,   15,  -98,    0,    8,    0}, {  -85,   15,  -99,    0,    8,    0}, {  -86,   15, -100,    0,    8,    0},
    {  -87,   15, -102,    0,    8,    0}, {  -87,   15, -103,    0,    8,    0}, {  -88,   16, -104,    0,    8,    0}, {  -88,   16, -105,    0,    8,    0}, {  -89,   16, -106,    0,    8,    0},
    {  -89,   16, -107,    0,    8,    0}, {  -90,   16, -108,    0,    8,    0}, {  -91,   16, -109,    0,    8,    0}, {  -91,   16, -110,    0,    8,    0}, {  -92,   16, -111,    0,    8,    0},
    {  -92,   16, -112,    0,    8,    0}, {  -93,   16, -113,    0,    8,    0}, {  -93,   16, -114,    0,    8,    0}, {  -94,   16, -115,    0,    8,    0}, {  -94,   16, -117,    0,    8,    0},
    {  -95,   16, -118,    0,    8,    0}, {  -95,   16, -119,    0,    8,    0}, {  -96,   16, -120,    0,    8,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeZeroGRollDown1, {
    {   16,    1,   19,   24,   16,    0}, {   16,    2,   19,   24,   16,    0}, {   16,    3,   19,   24,   16,    0}, {   16,    5,   19,   24,   16,    0}, {   15,    6,   19,   24,   16,    0},
    {   15,    7,   19,   24,   16,    0}, {   15,    9,   18,   24,   16,    0}, {   15,   10,   18,    8,    0,   14}, {   15,   11,   18,    8,    0,   14}, {   15,   13,   18,    8,    0,   14},
    {   15,   14,   17,    8,    6,   14}, {   15,   15,   17,    8,    6,   14}, {   15,   16,   17,    8,    6,   14}, {   14,   18,   17,    8,    6,   14}, {   14,   19,   16,    8,    6,   14},
    {   14,   20,   16,    8,    6,   14}, {   14,   21,   15,    8,    6,   14}, {   14,   23,   15,    8,    6,   14}, {   14,   24,   14,    8,    6,   14}, {   14,   25,   14,    8,    6,   14},
    {   14,   26,   13,    8,    6,   14}, {   14,   27,   13,    8,    6,   13}, {   13,   28,   12,    8,    6,   13}, {   13,   30,   12,    8,    6,   13}, {   13,   31,   11,    8,    6,   13},
    {   13,   32,   11,    8,    6,   13}, {   13,   33,   10,    8,    6,   13}, {   13,   34,    9,    8,    6,   13}, {   13,   35,    9,    8,    6,   13}, {   13,   36,    8,    8,    6,   13},
    {   13,   37,    7,    8,    6,   13}, {   13,   38,    7,    8,    6,   13}, {   13,   40,    6,    8,    6,   13}, {   13,   41,    5,    8,    6,   13}, {   12,   42,    5,    8,    6,   13},
    {   12,   43,    4,    8,    6,   13}, {   12,   44,    3,    8,    6,   12}, {   12,   45,    2,    8,    6,   12}, {   12,   46,    1,    8,    6,   12}, {   12,   47,    1,    8,    6,   12},
    {   12,   48,    0,    8,    6,   12}, {   12,   49,   -1,    8,    6,   12}, {   12,   50,   -2,    8,    6,   12}, {   12,   51,   -3,    8,    6,   12}, {   12,   52,   -3,    8,    6,   12},
    {   12,   52,   -4,    8,    6,   12}, {   12,   53,   -5,    8,    6,   12}, {   12,   54,   -6,    8,    7,   11}, {   12,   55,   -7,    8,    7,   11}, {   12,   56,   -8,    8,    7,   11},
    {   12,   57,   -9,    8,    7,   11}, {   12,   58,  -10,    8,    7,   11}, {   12,   59,  -11,    8,    7,   11}, {   12,   60,  -12,    8,    7,   11}, {   12,   61,  -13,    8,    7,   11},
    {   12,   62,  -14,    8,    7,   11}, {   12,   62,  -15,    8,    7,   11}, {   12,   63,  -16,    8,    7,   11}, {   12,   64,  -16,    8,    7,   11}, {   12,   65,  -17,    8,    7,   11},
    {   12,   66,  -18,    8,    7,   11}, {   12,   67,  -19,    8,    7,   11}, {   12,   67,  -20,    8,    7,   11}, {   12,   68,  -21,    8,    7,   11}, {   12,   69,  -23,    8,    7,   11},
    {   12,   70,  -24,    8,    7,   11}, {   12,   71,  -25,    8,    7,   10}, {   12,   72,  -26,    8,    7,   10}, {   12,   72,  -27,    8,    7,   10}, {   12,   73,  -28,    8,    7,   10},
    {   12,   74,  -29,    8,    7,   10}, {   12,   75,  -30,    8,    7,   10}, {   12,   76,  -31,    8,    7,   10}, {   12,   76,  -32,    8,    7,   10}, {   12,   77,  -33,    8,    7,   10},
    {   12,   78,  -34,    8,    7,   10}, {   12,   79,  -35,    8,    7,   10}, {   12,   79,  -36,    8,    7,   10}, {   12,   80,  -37,    8,    7,   10}, {   12,   81,  -38,    8,    7,   10},
    {   12,   82,  -39,    8,    7,   10}, {   12,   82,  -40,    8,    7,   10}, {   12,   83,  -42,    8,    7,   10}, {   12,   84,  -43,    8,    7,    4}, {   12,   85,  -44,    8,    7,    4},
    {   12,   85,  -45,    8,    7,    4}, {   13,   86,  -46,    8,    7,    4}, {   13,   87,  -47,    8,    7,    4}, {   13,   87,  -48,    8,    7,    4}, {   13,   88,  -49,    8,    7,    4},
    {   13,   89,  -50,    8,    7,    4}, {   13,   90,  -51,    8,    7,    4}, {   13,   90,  -53,    8,    7,    4}, {   13,   91,  -54,    8,    7,    4}, {   13,   92,  -55,    8,    7,    4},
    {   13,   92,  -56,    8,    7,    4}, {   13,   93,  -57,    8,    7,    4}, {   13,   94,  -58,    8,    7,    4}, {   13,   95,  -59,    8,    7,    4}, {   13,   95,  -60,    8,    7,    4},
    {   13,   96,  -61,    8,    8,    3}, {   13,   97,  -63,    8,    8,    3}, {   14,   97,  -64,    8,    8,    3}, {   14,   98,  -65,    8,    8,    3}, {   14,   99,  -66,    8,    8,    3},
    {   14,   99,  -67,    8,    8,    3}, {   14,  100,  -68,    8,    8,    3}, {   14,  101,  -69,    8,    8,    3}, {   14,  101,  -70,    8,    8,    3}, {   14,  102,  -72,    8,    8,    3},
    {   14,  103,  -73,    8,    8,    3}, {   14,  103,  -74,    8,    8,    3}, {   14,  104,  -75,    8,    8,    3}, {   14,  105,  -76,    8,    8,    3}, {   14,  105,  -77,    8,    8,    3},
    {   14,  106,  -78,    8,    8,    3}, {   14,  106,  -79,    8,    8,    3}, {   14,  107,  -80,    8,    8,    3}, {   15,  108,  -82,    8,    8,    3}, {   15,  108,  -83,    8,    8,    3},
    {   15,  109,  -84,    8,    8,    3}, {   15,  110,  -85,    8,    8,    3}, {   15,  110,  -86,    8,    8,    3}, {   15,  111,  -87,    8,    8,    3}, {   15,  111,  -88,    8,    8,    3},
    {   15,  112,  -89,    8,    8,    3}, {   15,  113,  -91,    8,    8,    3}, {   15,  113,  -92,    8,    8,    3}, {   15,  114,  -93,    8,    8,    3}, {   15,  115,  -94,    8,    8,    3},
    {   15,  115,  -95,    8,    8,    0}, {   15,  116,  -96,    8,    8,    0}, {   15,  116,  -97,    8,    8,    0}, {   15,  117,  -98,    8,    8,    0}, {   15,  117,  -99,    8,    8,    0},
    {   15,  118, -100,    8,    8,    0}, {   15,  119, -102,    8,    8,    0}, {   15,  119, -103,    8,    8,    0}, {   16,  120, -104,    8,    8,    0}, {   16,  120, -105,    8,    8,    0},
    {   16,  121, -106,    8,    8,    0}, {   16,  121, -107,    8,    8,    0}, {   16,  122, -108,    8,    8,    0}, {   16,  123, -109,    8,    8,    0}, {   16,  123, -110,    8,    8,    0},
    {   16,  124, -111,    8,    8,    0}, {   16,  124, -112,    8,    8,    0}, {   16,  125, -113,    8,    8,    0}, {   16,  125, -114,    8,    8,    0}, {   16,  126, -115,    8,    8,    0},
    {   16,  126, -117,    8,    8,    0}, {   16,  127, -118,    8,    8,    0}, {   16,  127, -119,    8,    8,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeZeroGRollDown2, {
    {    1,   16,   19,    0,   16,    0}, {    2,   16,   19,    0,   16,    0}, {    3,   16,   19,    0,   16,    0}, {    5,   16,   19,    0,   16,    0}, {    6,   17,   19,    0,   16,    0},
    {    7,   17,   19,    0,   16,    0}, {    9,   17,   18,    0,   16,    0}, {   10,   17,   18,   16,    0,   14}, {   11,   17,   18,   16,    0,   14}, {   13,   17,   18,   16,    0,   14},
    {   14,   17,   17,   16,    6,   14}, {   15,   17,   17,   16,    6,   14}, {   16,   17,   17,   16,    6,   14}, {   18,   18,   17,   16,    6,   14}, {   19,   18,   16,   16,    6,   14},
    {   20,   18,   16,   16,    6,   14}, {   21,   18,   15,   16,    6,   14}, {   23,   18,   15,   16,    6,   14}, {   24,   18,   14,   16,    6,   14}, {   25,   18,   14,   16,    6,   14},
    {   26,   18,   13,   16,    6,   14}, {   27,   18,   13,   16,    6,   13}, {   28,   19,   12,   16,    6,   13}, {   30,   19,   12,   16,    6,   13}, {   31,   19,   11,   16,    6,   13},
    {   32,   19,   11,   16,    6,   13}, {   33,   19,   10,   16,    6,   13}, {   34,   19,    9,   16,    6,   13}, {   35,   19,    9,   16,    6,   13}, {   36,   19,    8,   16,    6,   13},
    {   37,   19,    7,   16,    6,   13}, {   38,   19,    7,   16,    6,   13}, {   40,   19,    6,   16,    6,   13}, {   41,   19,    5,   16,    6,   13}, {   42,   20,    5,   16,    6,   13},
    {   43,   20,    4,   16,    6,   13}, {   44,   20,    3,   16,    6,   12}, {   45,   20,    2,   16,    6,   12}, {   46,   20,    1,   16,    6,   12}, {   47,   20,    1,   16,    6,   12},
    {   48,   20,    0,   16,    6,   12}, {   49,   20,   -1,   16,    6,   12}, {   50,   20,   -2,   16,    6,   12}, {   51,   20,   -3,   16,    6,   12}, {   52,   20,   -3,   16,    6,   12},
    {   52,   20,   -4,   16,    6,   12}, {   53,   20,   -5,   16,    6,   12}, {   54,   20,   -6,   16,    7,   11}, {   55,   20,   -7,   16,    7,   11}, {   56,   20,   -8,   16,    7,   11},
    {   57,   20,   -9,   16,    7,   11}, {   58,   20,  -10,   16,    7,   11}, {   59,   20,  -11,   16,    7,   11}, {   60,   20,  -12,   16,    7,   11}, {   61,   20,  -13,   16,    7,   11},
    {   62,   20,  -14,   16,    7,   11}, {   62,   20,  -15,   16,    7,   11}, {   63,   20,  -16,   16,    7,   11}, {   64,   20,  -16,   16,    7,   11}, {   65,   20,  -17,   16,    7,   11},
    {   66,   20,  -18,   16,    7,   11}, {   67,   20,  -19,   16,    7,   11}, {   67,   20,  -20,   16,    7,   11}, {   68,   20,  -21,   16,    7,   11}, {   69,   20,  -23,   16,    7,   11},
    {   70,   20,  -24,   16,    7,   11}, {   71,   20,  -25,   16,    7,   10}, {   72,   20,  -26,   16,    7,   10}, {   72,   20,  -27,   16,    7,   10}, {   73,   20,  -28,   16,    7,   10},
    {   74,   20,  -29,   16,    7,   10}, {   75,   20,  -30,   16,    7,   10}, {   76,   20,  -31,   16,    7,   10}, {   76,   20,  -32,   16,    7,   10}, {   77,   20,  -33,   16,    7,   10},
    {   78,   20,  -34,   16,    7,   10}, {   79,   20,  -35,   16,    7,   10}, {   79,   20,  -36,   16,    7,   10}, {   80,   20,  -37,   16,    7,   10}, {   81,   20,  -38,   16,    7,   10},
    {   82,   20,  -39,   16,    7,   10}, {   82,   20,  -40,   16,    7,   10}, {   83,   20,  -42,   16,    7,   10}, {   84,   20,  -43,   16,    7,    4}, {   85,   20,  -44,   16,    7,    4},
    {   85,   20,  -45,   16,    7,    4}, {   86,   19,  -46,   16,    7,    4}, {   87,   19,  -47,   16,    7,    4}, {   87,   19,  -48,   16,    7,    4}, {   88,   19,  -49,   16,    7,    4},
    {   89,   19,  -50,   16,    7,    4}, {   90,   19,  -51,   16,    7,    4}, {   90,   19,  -53,   16,    7,    4}, {   91,   19,  -54,   16,    7,    4}, {   92,   19,  -55,   16,    7,    4},
    {   92,   19,  -56,   16,    7,    4}, {   93,   19,  -57,   16,    7,    4}, {   94,   19,  -58,   16,    7,    4}, {   95,   19,  -59,   16,    7,    4}, {   95,   19,  -60,   16,    7,    4},
    {   96,   19,  -61,   16,    8,    3}, {   97,   19,  -63,   16,    8,    3}, {   97,   18,  -64,   16,    8,    3}, {   98,   18,  -65,   16,    8,    3}, {   99,   18,  -66,   16,    8,    3},
    {   99,   18,  -67,   16,    8,    3}, {  100,   18,  -68,   16,    8,    3}, {  101,   18,  -69,   16,    8,    3}, {  101,   18,  -70,   16,    8,    3}, {  102,   18,  -72,   16,    8,    3},
    {  103,   18,  -73,   16,    8,    3}, {  103,   18,  -74,   16,    8,    3}, {  104,   18,  -75,   16,    8,    3}, {  105,   18,  -76,   16,    8,    3}, {  105,   18,  -77,   16,    8,    3},
    {  106,   18,  -78,   16,    8,    3}, {  106,   18,  -79,   16,    8,    3}, {  107,   18,  -80,   16,    8,    3}, {  108,   17,  -82,   16,    8,    3}, {  108,   17,  -83,   16,    8,    3},
    {  109,   17,  -84,   16,    8,    3}, {  110,   17,  -85,   16,    8,    3}, {  110,   17,  -86,   16,    8,    3}, {  111,   17,  -87,   16,    8,    3}, {  111,   17,  -88,   16,    8,    3},
    {  112,   17,  -89,   16,    8,    3}, {  113,   17,  -91,   16,    8,    3}, {  113,   17,  -92,   16,    8,    3}, {  114,   17,  -93,   16,    8,    3}, {  115,   17,  -94,   16,    8,    3},
    {  115,   17,  -95,   16,    8,    0}, {  116,   17,  -96,   16,    8,    0}, {  116,   17,  -97,   16,    8,    0}, {  117,   17,  -98,   16,    8,    0}, {  117,   17,  -99,   16,    8,    0},
    {  118,   17, -100,   16,    8,    0}, {  119,   17, -102,   16,    8,    0}, {  119,   17, -103,   16,    8,    0}, {  120,   16, -104,   16,    8,    0}, {  120,   16, -105,   16,    8,    0},
    {  121,   16, -106,   16,    8,    0}, {  121,   16, -107,   16,    8,    0}, {  122,   16, -108,   16,    8,    0}, {  123,   16, -109,   16,    8,    0}, {  123,   16, -110,   16,    8,    0},
    {  124,   16, -111,   16,    8,    0}, {  124,   16, -112,   16,    8,    0}, {  125,   16, -113,   16,    8,    0}, {  125,   16, -114,   16,    8,    0}, {  126,   16, -115,   16,    8,    0},
    {  126,   16, -117,   16,    8,    0}, {  127,   16, -118,   16,    8,    0}, {  127,   16, -119,   16,    8,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftLargeZeroGRollDown3, {
    {   16,   30,   19,    8,   16,    0}, {   16,   29,   19,    8,   16,    0}, {   16,   27,   19,    8,   16,    0}, {   17,   26,   19,    8,   16,    0}, {   17,   25,   19,    8,   16,    0},
    {   17,   23,   18,    8,   16,    0}, {   17,   22,   18,   24,    0,   14}, {   17,   21,   18,   24,    0,   14}, {   17,   19,   18,   24,    0,   14}, {   17,   18,   17,   24,    6,   14},
    {   17,   17,   17,   24,    6,   14}, {   17,   16,   17,   24,    6,   14}, {   18,   14,   17,   24,    6,   14}, {   18,   13,   16,   24,    6,   14}, {   18,   12,   16,   24,    6,   14},
    {   18,   11,   15,   24,    6,   14}, {   18,    9,   15,   24,    6,   14}, {   18,    8,   14,   24,    6,   14}, {   18,    7,   14,   24,    6,   14}, {   18,    6,   13,   24,    6,   14},
    {   18,    5,   13,   24,    6,   13}, {   19,    4,   12,   24,    6,   13}, {   19,    2,   12,   24,    6,   13}, {   19,    1,   11,   24,    6,   13}, {   19,    0,   11,   24,    6,   13},
    {   19,   -1,   10,   24,    6,   13}, {   19,   -2,    9,   24,    6,   13}, {   19,   -3,    9,   24,    6,   13}, {   19,   -4,    8,   24,    6,   13}, {   19,   -5,    7,   24,    6,   13},
    {   19,   -6,    7,   24,    6,   13}, {   19,   -8,    6,   24,    6,   13}, {   19,   -9,    5,   24,    6,   13}, {   20,  -10,    5,   24,    6,   13}, {   20,  -11,    4,   24,    6,   13},
    {   20,  -12,    3,   24,    6,   12}, {   20,  -13,    2,   24,    6,   12}, {   20,  -14,    1,   24,    6,   12}, {   20,  -15,    1,   24,    6,   12}, {   20,  -16,    0,   24,    6,   12},
    {   20,  -17,   -1,   24,    6,   12}, {   20,  -18,   -2,   24,    6,   12}, {   20,  -19,   -3,   24,    6,   12}, {   20,  -20,   -3,   24,    6,   12}, {   20,  -20,   -4,   24,    6,   12},
    {   20,  -21,   -5,   24,    6,   12}, {   20,  -22,   -6,   24,    7,   11}, {   20,  -23,   -7,   24,    7,   11}, {   20,  -24,   -8,   24,    7,   11}, {   20,  -25,   -9,   24,    7,   11},
    {   20,  -26,  -10,   24,    7,   11}, {   20,  -27,  -11,   24,    7,   11}, {   20,  -28,  -12,   24,    7,   11}, {   20,  -29,  -13,   24,    7,   11}, {   20,  -30,  -14,   24,    7,   11},
    {   20,  -30,  -15,   24,    7,   11}, {   20,  -31,  -16,   24,    7,   11}, {   20,  -32,  -16,   24,    7,   11}, {   20,  -33,  -17,   24,    7,   11}, {   20,  -34,  -18,   24,    7,   11},
    {   20,  -35,  -19,   24,    7,   11}, {   20,  -35,  -20,   24,    7,   11}, {   20,  -36,  -21,   24,    7,   11}, {   20,  -37,  -23,   24,    7,   11}, {   20,  -38,  -24,   24,    7,   11},
    {   20,  -39,  -25,   24,    7,   10}, {   20,  -40,  -26,   24,    7,   10}, {   20,  -40,  -27,   24,    7,   10}, {   20,  -41,  -28,   24,    7,   10}, {   20,  -42,  -29,   24,    7,   10},
    {   20,  -43,  -30,   24,    7,   10}, {   20,  -44,  -31,   24,    7,   10}, {   20,  -44,  -32,   24,    7,   10}, {   20,  -45,  -33,   24,    7,   10}, {   20,  -46,  -34,   24,    7,   10},
    {   20,  -47,  -35,   24,    7,   10}, {   20,  -47,  -36,   24,    7,   10}, {   20,  -48,  -37,   24,    7,   10}, {   20,  -49,  -38,   24,    7,   10}, {   20,  -50,  -39,   24,    7,   10},
    {   20,  -50,  -40,   24,    7,   10}, {   20,  -51,  -42,   24,    7,   10}, {   20,  -52,  -43,   24,    7,    4}, {   20,  -53,  -44,   24,    7,    4}, {   20,  -53,  -45,   24,    7,    4},
    {   19,  -54,  -46,   24,    7,    4}, {   19,  -55,  -47,   24,    7,    4}, {   19,  -55,  -48,   24,    7,    4}, {   19,  -56,  -49,   24,    7,    4}, {   19,  -57,  -50,   24,    7,    4},
    {   19,  -58,  -51,   24,    7,    4}, {   19,  -58,  -53,   24,    7,    4}, {   19,  -59,  -54,   24,    7,    4}, {   19,  -60,  -55,   24,    7,    4}, {   19,  -60,  -56,   24,    7,    4},
    {   19,  -61,  -57,   24,    7,    4}, {   19,  -62,  -58,   24,    7,    4}, {   19,  -63,  -59,   24,    7,    4}, {   19,  -63,  -60,   24,    7,    4}, {   19,  -64,  -61,   24,    8,    3},
    {   19,  -65,  -63,   24,    8,    3}, {   18,  -65,  -64,   24,    8,    3}, {   18,  -66,  -65,   24,    8,    3}, {   18,  -67,  -66,   24,    8,    3}, {   18,  -67,  -67,   24,    8,    3},
    {   18,  -68,  -68,   24,    8,    3}, {   18,  -69,  -69,   24,    8,    3}, {   18,  -69,  -70,   24,    8,    3}, {   18,  -70,  -72,   24,    8,    3}, {   18,  -71,  -73,   24,    8,    3},
    {   18,  -71,  -74,   24,    8,    3}, {   18,  -72,  -75,   24,    8,    3}, {   18,  -73,  -76,   24,    8,    3}, {   18,  -73,  -77,   24,    8,    3}, {   18,  -74,  -78,   24,    8,    3},
    {   18,  -74,  -79,   24,    8,    3}, {   18,  -75,  -80,   24,    8,    3}, {   17,  -76,  -82,   24,    8,    3}, {   17,  -76,  -83,   24,    8,    3}, {   17,  -77,  -84,   24,    8,    3},
    {   17,  -78,  -85,   24,    8,    3}, {   17,  -78,  -86,   24,    8,    3}, {   17,  -79,  -87,   24,    8,    3}, {   17,  -79,  -88,   24,    8,    3}, {   17,  -80,  -89,   24,    8,    3},
    {   17,  -81,  -91,   24,    8,    3}, {   17,  -81,  -92,   24,    8,    3}, {   17,  -82,  -93,   24,    8,    3}, {   17,  -83,  -94,   24,    8,    3}, {   17,  -83,  -95,   24,    8,    0},
    {   17,  -84,  -96,   24,    8,    0}, {   17,  -84,  -97,   24,    8,    0}, {   17,  -85,  -98,   24,    8,    0}, {   17,  -85,  -99,   24,    8,    0}, {   17,  -86, -100,   24,    8,    0},
    {   17,  -87, -102,   24,    8,    0}, {   17,  -87, -103,   24,    8,    0}, {   16,  -88, -104,   24,    8,    0}, {   16,  -88, -105,   24,    8,    0}, {   16,  -89, -106,   24,    8,    0},
    {   16,  -89, -107,   24,    8,    0}, {   16,  -90, -108,   24,    8,    0}, {   16,  -91, -109,   24,    8,    0}, {   16,  -91, -110,   24,    8,    0}, {   16,  -92, -111,   24,    8,    0},
    {   16,  -92, -112,   24,    8,    0}, {   16,  -93, -113,   24,    8,    0}, {   16,  -93, -114,   24,    8,    0}, {   16,  -94, -115,   24,    8,    0}, {   16,  -94, -117,   24,    8,    0},
    {   16,  -95, -118,   24,    8,    0}, {   16,  -95, -119,   24,    8,    0}, {   16,  -96, -120,   24,    8,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeZeroGRollDown0, {
    {   30,   16,   19,   16,   16,    0}, {   29,   16,   19,   16,   16,    0}, {   27,   16,   19,   16,   16,    0}, {   26,   17,   19,   16,   16,    0}, {   25,   17,   19,   16,   16,    0},
    {   23,   17,   18,   16,   16,    0}, {   22,   17,   18,    0,    0,    9}, {   21,   17,   18,    0,    0,    9}, {   19,   17,   18,    0,    0,    9}, {   18,   17,   17,    0,    6,    9},
    {   17,   17,   17,    0,    6,    9}, {   16,   17,   17,    0,    6,    9}, {   14,   18,   17,    0,    6,    9}, {   13,   18,   16,    0,    6,    9}, {   12,   18,   16,    0,    6,    9},
    {   11,   18,   15,    0,    6,    9}, {    9,   18,   15,    0,    6,    9}, {    8,   18,   14,    0,    6,    9}, {    7,   18,   14,    0,    6,    9}, {    6,   18,   13,    0,    6,    9},
    {    5,   18,   13,    0,    6,    8}, {    4,   19,   12,    0,    6,    8}, {    2,   19,   12,    0,    6,    8}, {    1,   19,   11,    0,    6,    8}, {    0,   19,   11,    0,    6,    8},
    {   -1,   19,   10,    0,    6,    8}, {   -2,   19,    9,    0,    6,    8}, {   -3,   19,    9,    0,    6,    8}, {   -4,   19,    8,    0,    6,    8}, {   -5,   19,    7,    0,    6,    8},
    {   -6,   19,    7,    0,    6,    8}, {   -8,   19,    6,    0,    6,    8}, {   -9,   19,    5,    0,    6,    8}, {  -10,   20,    5,    0,    6,    8}, {  -11,   20,    4,    0,    6,    8},
    {  -12,   20,    3,    0,    6,    7}, {  -13,   20,    2,    0,    6,    7}, {  -14,   20,    1,    0,    6,    7}, {  -15,   20,    1,    0,    6,    7}, {  -16,   20,    0,    0,    6,    7},
    {  -17,   20,   -1,    0,    6,    7}, {  -18,   20,   -2,    0,    6,    7}, {  -19,   20,   -3,    0,    6,    7}, {  -20,   20,   -3,    0,    6,    7}, {  -20,   20,   -4,    0,    6,    7},
    {  -21,   20,   -5,    0,    6,    7}, {  -22,   20,   -6,    0,    7,    6}, {  -23,   20,   -7,    0,    7,    6}, {  -24,   20,   -8,    0,    7,    6}, {  -25,   20,   -9,    0,    7,    6},
    {  -26,   20,  -10,    0,    7,    6}, {  -27,   20,  -11,    0,    7,    6}, {  -28,   20,  -12,    0,    7,    6}, {  -29,   20,  -13,    0,    7,    6}, {  -30,   20,  -14,    0,    7,    6},
    {  -30,   20,  -15,    0,    7,    6}, {  -31,   20,  -16,    0,    7,    6}, {  -32,   20,  -16,    0,    7,    6}, {  -33,   20,  -17,    0,    7,    6}, {  -34,   20,  -18,    0,    7,    6},
    {  -35,   20,  -19,    0,    7,    6}, {  -35,   20,  -20,    0,    7,    6}, {  -36,   20,  -21,    0,    7,    6}, {  -37,   20,  -23,    0,    7,    6}, {  -38,   20,  -24,    0,    7,    6},
    {  -39,   20,  -25,    0,    7,    5}, {  -40,   20,  -26,    0,    7,    5}, {  -40,   20,  -27,    0,    7,    5}, {  -41,   20,  -28,    0,    7,    5}, {  -42,   20,  -29,    0,    7,    5},
    {  -43,   20,  -30,    0,    7,    5}, {  -44,   20,  -31,    0,    7,    5}, {  -44,   20,  -32,    0,    7,    5}, {  -45,   20,  -33,    0,    7,    5}, {  -46,   20,  -34,    0,    7,    5},
    {  -47,   20,  -35,    0,    7,    5}, {  -47,   20,  -36,    0,    7,    5}, {  -48,   20,  -37,    0,    7,    5}, {  -49,   20,  -38,    0,    7,    5}, {  -50,   20,  -39,    0,    7,    5},
    {  -50,   20,  -40,    0,    7,    5}, {  -51,   20,  -42,    0,    7,    5}, {  -52,   20,  -43,    0,    7,    2}, {  -53,   20,  -44,    0,    7,    2}, {  -53,   20,  -45,    0,    7,    2},
    {  -54,   19,  -46,    0,    7,    2}, {  -55,   19,  -47,    0,    7,    2}, {  -55,   19,  -48,    0,    7,    2}, {  -56,   19,  -49,    0,    7,    2}, {  -57,   19,  -50,    0,    7,    2},
    {  -58,   19,  -51,    0,    7,    2}, {  -58,   19,  -53,    0,    7,    2}, {  -59,   19,  -54,    0,    7,    2}, {  -60,   19,  -55,    0,    7,    2}, {  -60,   19,  -56,    0,    7,    2},
    {  -61,   19,  -57,    0,    7,    2}, {  -62,   19,  -58,    0,    7,    2}, {  -63,   19,  -59,    0,    7,    2}, {  -63,   19,  -60,    0,    7,    2}, {  -64,   19,  -61,    0,    8,    1},
    {  -65,   19,  -63,    0,    8,    1}, {  -65,   18,  -64,    0,    8,    1}, {  -66,   18,  -65,    0,    8,    1}, {  -67,   18,  -66,    0,    8,    1}, {  -67,   18,  -67,    0,    8,    1},
    {  -68,   18,  -68,    0,    8,    1}, {  -69,   18,  -69,    0,    8,    1}, {  -69,   18,  -70,    0,    8,    1}, {  -70,   18,  -72,    0,    8,    1}, {  -71,   18,  -73,    0,    8,    1},
    {  -71,   18,  -74,    0,    8,    1}, {  -72,   18,  -75,    0,    8,    1}, {  -73,   18,  -76,    0,    8,    1}, {  -73,   18,  -77,    0,    8,    1}, {  -74,   18,  -78,    0,    8,    1},
    {  -74,   18,  -79,    0,    8,    1}, {  -75,   18,  -80,    0,    8,    1}, {  -76,   17,  -82,    0,    8,    1}, {  -76,   17,  -83,    0,    8,    1}, {  -77,   17,  -84,    0,    8,    1},
    {  -78,   17,  -85,    0,    8,    1}, {  -78,   17,  -86,    0,    8,    1}, {  -79,   17,  -87,    0,    8,    1}, {  -79,   17,  -88,    0,    8,    1}, {  -80,   17,  -89,    0,    8,    1},
    {  -81,   17,  -91,    0,    8,    1}, {  -81,   17,  -92,    0,    8,    1}, {  -82,   17,  -93,    0,    8,    1}, {  -83,   17,  -94,    0,    8,    1}, {  -83,   17,  -95,    0,    8,    0},
    {  -84,   17,  -96,    0,    8,    0}, {  -84,   17,  -97,    0,    8,    0}, {  -85,   17,  -98,    0,    8,    0}, {  -85,   17,  -99,    0,    8,    0}, {  -86,   17, -100,    0,    8,    0},
    {  -87,   17, -102,    0,    8,    0}, {  -87,   17, -103,    0,    8,    0}, {  -88,   16, -104,    0,    8,    0}, {  -88,   16, -105,    0,    8,    0}, {  -89,   16, -106,    0,    8,    0},
    {  -89,   16, -107,    0,    8,    0}, {  -90,   16, -108,    0,    8,    0}, {  -91,   16, -109,    0,    8,    0}, {  -91,   16, -110,    0,    8,    0}, {  -92,   16, -111,    0,    8,    0},
    {  -92,   16, -112,    0,    8,    0}, {  -93,   16, -113,    0,    8,    0}, {  -93,   16, -114,    0,    8,    0}, {  -94,   16, -115,    0,    8,    0}, {  -94,   16, -117,    0,    8,    0},
    {  -95,   16, -118,    0,    8,    0}, {  -95,   16, -119,    0,    8,    0}, {  -96,   16, -120,    0,    8,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeZeroGRollDown1, {
    {   16,    1,   19,   24,   16,    0}, {   16,    2,   19,   24,   16,    0}, {   16,    3,   19,   24,   16,    0}, {   16,    5,   19,   24,   16,    0}, {   17,    6,   19,   24,   16,    0},
    {   17,    7,   19,   24,   16,    0}, {   17,    9,   18,   24,   16,    0}, {   17,   10,   18,    8,    0,    9}, {   17,   11,   18,    8,    0,    9}, {   17,   13,   18,    8,    0,    9},
    {   17,   14,   17,    8,    6,    9}, {   17,   15,   17,    8,    6,    9}, {   17,   16,   17,    8,    6,    9}, {   18,   18,   17,    8,    6,    9}, {   18,   19,   16,    8,    6,    9},
    {   18,   20,   16,    8,    6,    9}, {   18,   21,   15,    8,    6,    9}, {   18,   23,   15,    8,    6,    9}, {   18,   24,   14,    8,    6,    9}, {   18,   25,   14,    8,    6,    9},
    {   18,   26,   13,    8,    6,    9}, {   18,   27,   13,    8,    6,    8}, {   19,   28,   12,    8,    6,    8}, {   19,   30,   12,    8,    6,    8}, {   19,   31,   11,    8,    6,    8},
    {   19,   32,   11,    8,    6,    8}, {   19,   33,   10,    8,    6,    8}, {   19,   34,    9,    8,    6,    8}, {   19,   35,    9,    8,    6,    8}, {   19,   36,    8,    8,    6,    8},
    {   19,   37,    7,    8,    6,    8}, {   19,   38,    7,    8,    6,    8}, {   19,   40,    6,    8,    6,    8}, {   19,   41,    5,    8,    6,    8}, {   20,   42,    5,    8,    6,    8},
    {   20,   43,    4,    8,    6,    8}, {   20,   44,    3,    8,    6,    7}, {   20,   45,    2,    8,    6,    7}, {   20,   46,    1,    8,    6,    7}, {   20,   47,    1,    8,    6,    7},
    {   20,   48,    0,    8,    6,    7}, {   20,   49,   -1,    8,    6,    7}, {   20,   50,   -2,    8,    6,    7}, {   20,   51,   -3,    8,    6,    7}, {   20,   52,   -3,    8,    6,    7},
    {   20,   52,   -4,    8,    6,    7}, {   20,   53,   -5,    8,    6,    7}, {   20,   54,   -6,    8,    7,    6}, {   20,   55,   -7,    8,    7,    6}, {   20,   56,   -8,    8,    7,    6},
    {   20,   57,   -9,    8,    7,    6}, {   20,   58,  -10,    8,    7,    6}, {   20,   59,  -11,    8,    7,    6}, {   20,   60,  -12,    8,    7,    6}, {   20,   61,  -13,    8,    7,    6},
    {   20,   62,  -14,    8,    7,    6}, {   20,   62,  -15,    8,    7,    6}, {   20,   63,  -16,    8,    7,    6}, {   20,   64,  -16,    8,    7,    6}, {   20,   65,  -17,    8,    7,    6},
    {   20,   66,  -18,    8,    7,    6}, {   20,   67,  -19,    8,    7,    6}, {   20,   67,  -20,    8,    7,    6}, {   20,   68,  -21,    8,    7,    6}, {   20,   69,  -23,    8,    7,    6},
    {   20,   70,  -24,    8,    7,    6}, {   20,   71,  -25,    8,    7,    5}, {   20,   72,  -26,    8,    7,    5}, {   20,   72,  -27,    8,    7,    5}, {   20,   73,  -28,    8,    7,    5},
    {   20,   74,  -29,    8,    7,    5}, {   20,   75,  -30,    8,    7,    5}, {   20,   76,  -31,    8,    7,    5}, {   20,   76,  -32,    8,    7,    5}, {   20,   77,  -33,    8,    7,    5},
    {   20,   78,  -34,    8,    7,    5}, {   20,   79,  -35,    8,    7,    5}, {   20,   79,  -36,    8,    7,    5}, {   20,   80,  -37,    8,    7,    5}, {   20,   81,  -38,    8,    7,    5},
    {   20,   82,  -39,    8,    7,    5}, {   20,   82,  -40,    8,    7,    5}, {   20,   83,  -42,    8,    7,    5}, {   20,   84,  -43,    8,    7,    2}, {   20,   85,  -44,    8,    7,    2},
    {   20,   85,  -45,    8,    7,    2}, {   19,   86,  -46,    8,    7,    2}, {   19,   87,  -47,    8,    7,    2}, {   19,   87,  -48,    8,    7,    2}, {   19,   88,  -49,    8,    7,    2},
    {   19,   89,  -50,    8,    7,    2}, {   19,   90,  -51,    8,    7,    2}, {   19,   90,  -53,    8,    7,    2}, {   19,   91,  -54,    8,    7,    2}, {   19,   92,  -55,    8,    7,    2},
    {   19,   92,  -56,    8,    7,    2}, {   19,   93,  -57,    8,    7,    2}, {   19,   94,  -58,    8,    7,    2}, {   19,   95,  -59,    8,    7,    2}, {   19,   95,  -60,    8,    7,    2},
    {   19,   96,  -61,    8,    8,    1}, {   19,   97,  -63,    8,    8,    1}, {   18,   97,  -64,    8,    8,    1}, {   18,   98,  -65,    8,    8,    1}, {   18,   99,  -66,    8,    8,    1},
    {   18,   99,  -67,    8,    8,    1}, {   18,  100,  -68,    8,    8,    1}, {   18,  101,  -69,    8,    8,    1}, {   18,  101,  -70,    8,    8,    1}, {   18,  102,  -72,    8,    8,    1},
    {   18,  103,  -73,    8,    8,    1}, {   18,  103,  -74,    8,    8,    1}, {   18,  104,  -75,    8,    8,    1}, {   18,  105,  -76,    8,    8,    1}, {   18,  105,  -77,    8,    8,    1},
    {   18,  106,  -78,    8,    8,    1}, {   18,  106,  -79,    8,    8,    1}, {   18,  107,  -80,    8,    8,    1}, {   17,  108,  -82,    8,    8,    1}, {   17,  108,  -83,    8,    8,    1},
    {   17,  109,  -84,    8,    8,    1}, {   17,  110,  -85,    8,    8,    1}, {   17,  110,  -86,    8,    8,    1}, {   17,  111,  -87,    8,    8,    1}, {   17,  111,  -88,    8,    8,    1},
    {   17,  112,  -89,    8,    8,    1}, {   17,  113,  -91,    8,    8,    1}, {   17,  113,  -92,    8,    8,    1}, {   17,  114,  -93,    8,    8,    1}, {   17,  115,  -94,    8,    8,    1},
    {   17,  115,  -95,    8,    8,    0}, {   17,  116,  -96,    8,    8,    0}, {   17,  116,  -97,    8,    8,    0}, {   17,  117,  -98,    8,    8,    0}, {   17,  117,  -99,    8,    8,    0},
    {   17,  118, -100,    8,    8,    0}, {   17,  119, -102,    8,    8,    0}, {   17,  119, -103,    8,    8,    0}, {   16,  120, -104,    8,    8,    0}, {   16,  120, -105,    8,    8,    0},
    {   16,  121, -106,    8,    8,    0}, {   16,  121, -107,    8,    8,    0}, {   16,  122, -108,    8,    8,    0}, {   16,  123, -109,    8,    8,    0}, {   16,  123, -110,    8,    8,    0},
    {   16,  124, -111,    8,    8,    0}, {   16,  124, -112,    8,    8,    0}, {   16,  125, -113,    8,    8,    0}, {   16,  125, -114,    8,    8,    0}, {   16,  126, -115,    8,    8,    0},
    {   16,  126, -117,    8,    8,    0}, {   16,  127, -118,    8,    8,    0}, {   16,  127, -119,    8,    8,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeZeroGRollDown2, {
    {    1,   16,   19,    0,   16,    0}, {    2,   16,   19,    0,   16,    0}, {    3,   16,   19,    0,   16,    0}, {    5,   16,   19,    0,   16,    0}, {    6,   15,   19,    0,   16,    0},
    {    7,   15,   19,    0,   16,    0}, {    9,   15,   18,    0,   16,    0}, {   10,   15,   18,   16,    0,    9}, {   11,   15,   18,   16,    0,    9}, {   13,   15,   18,   16,    0,    9},
    {   14,   15,   17,   16,    6,    9}, {   15,   15,   17,   16,    6,    9}, {   16,   15,   17,   16,    6,    9}, {   18,   14,   17,   16,    6,    9}, {   19,   14,   16,   16,    6,    9},
    {   20,   14,   16,   16,    6,    9}, {   21,   14,   15,   16,    6,    9}, {   23,   14,   15,   16,    6,    9}, {   24,   14,   14,   16,    6,    9}, {   25,   14,   14,   16,    6,    9},
    {   26,   14,   13,   16,    6,    9}, {   27,   14,   13,   16,    6,    8}, {   28,   13,   12,   16,    6,    8}, {   30,   13,   12,   16,    6,    8}, {   31,   13,   11,   16,    6,    8},
    {   32,   13,   11,   16,    6,    8}, {   33,   13,   10,   16,    6,    8}, {   34,   13,    9,   16,    6,    8}, {   35,   13,    9,   16,    6,    8}, {   36,   13,    8,   16,    6,    8},
    {   37,   13,    7,   16,    6,    8}, {   38,   13,    7,   16,    6,    8}, {   40,   13,    6,   16,    6,    8}, {   41,   13,    5,   16,    6,    8}, {   42,   12,    5,   16,    6,    8},
    {   43,   12,    4,   16,    6,    8}, {   44,   12,    3,   16,    6,    7}, {   45,   12,    2,   16,    6,    7}, {   46,   12,    1,   16,    6,    7}, {   47,   12,    1,   16,    6,    7},
    {   48,   12,    0,   16,    6,    7}, {   49,   12,   -1,   16,    6,    7}, {   50,   12,   -2,   16,    6,    7}, {   51,   12,   -3,   16,    6,    7}, {   52,   12,   -3,   16,    6,    7},
    {   52,   12,   -4,   16,    6,    7}, {   53,   12,   -5,   16,    6,    7}, {   54,   12,   -6,   16,    7,    6}, {   55,   12,   -7,   16,    7,    6}, {   56,   12,   -8,   16,    7,    6},
    {   57,   12,   -9,   16,    7,    6}, {   58,   12,  -10,   16,    7,    6}, {   59,   12,  -11,   16,    7,    6}, {   60,   12,  -12,   16,    7,    6}, {   61,   12,  -13,   16,    7,    6},
    {   62,   12,  -14,   16,    7,    6}, {   62,   12,  -15,   16,    7,    6}, {   63,   12,  -16,   16,    7,    6}, {   64,   12,  -16,   16,    7,    6}, {   65,   12,  -17,   16,    7,    6},
    {   66,   12,  -18,   16,    7,    6}, {   67,   12,  -19,   16,    7,    6}, {   67,   12,  -20,   16,    7,    6}, {   68,   12,  -21,   16,    7,    6}, {   69,   12,  -23,   16,    7,    6},
    {   70,   12,  -24,   16,    7,    6}, {   71,   12,  -25,   16,    7,    5}, {   72,   12,  -26,   16,    7,    5}, {   72,   12,  -27,   16,    7,    5}, {   73,   12,  -28,   16,    7,    5},
    {   74,   12,  -29,   16,    7,    5}, {   75,   12,  -30,   16,    7,    5}, {   76,   12,  -31,   16,    7,    5}, {   76,   12,  -32,   16,    7,    5}, {   77,   12,  -33,   16,    7,    5},
    {   78,   12,  -34,   16,    7,    5}, {   79,   12,  -35,   16,    7,    5}, {   79,   12,  -36,   16,    7,    5}, {   80,   12,  -37,   16,    7,    5}, {   81,   12,  -38,   16,    7,    5},
    {   82,   12,  -39,   16,    7,    5}, {   82,   12,  -40,   16,    7,    5}, {   83,   12,  -42,   16,    7,    5}, {   84,   12,  -43,   16,    7,    2}, {   85,   12,  -44,   16,    7,    2},
    {   85,   12,  -45,   16,    7,    2}, {   86,   13,  -46,   16,    7,    2}, {   87,   13,  -47,   16,    7,    2}, {   87,   13,  -48,   16,    7,    2}, {   88,   13,  -49,   16,    7,    2},
    {   89,   13,  -50,   16,    7,    2}, {   90,   13,  -51,   16,    7,    2}, {   90,   13,  -53,   16,    7,    2}, {   91,   13,  -54,   16,    7,    2}, {   92,   13,  -55,   16,    7,    2},
    {   92,   13,  -56,   16,    7,    2}, {   93,   13,  -57,   16,    7,    2}, {   94,   13,  -58,   16,    7,    2}, {   95,   13,  -59,   16,    7,    2}, {   95,   13,  -60,   16,    7,    2},
    {   96,   13,  -61,   16,    8,    1}, {   97,   13,  -63,   16,    8,    1}, {   97,   14,  -64,   16,    8,    1}, {   98,   14,  -65,   16,    8,    1}, {   99,   14,  -66,   16,    8,    1},
    {   99,   14,  -67,   16,    8,    1}, {  100,   14,  -68,   16,    8,    1}, {  101,   14,  -69,   16,    8,    1}, {  101,   14,  -70,   16,    8,    1}, {  102,   14,  -72,   16,    8,    1},
    {  103,   14,  -73,   16,    8,    1}, {  103,   14,  -74,   16,    8,    1}, {  104,   14,  -75,   16,    8,    1}, {  105,   14,  -76,   16,    8,    1}, {  105,   14,  -77,   16,    8,    1},
    {  106,   14,  -78,   16,    8,    1}, {  106,   14,  -79,   16,    8,    1}, {  107,   14,  -80,   16,    8,    1}, {  108,   15,  -82,   16,    8,    1}, {  108,   15,  -83,   16,    8,    1},
    {  109,   15,  -84,   16,    8,    1}, {  110,   15,  -85,   16,    8,    1}, {  110,   15,  -86,   16,    8,    1}, {  111,   15,  -87,   16,    8,    1}, {  111,   15,  -88,   16,    8,    1},
    {  112,   15,  -89,   16,    8,    1}, {  113,   15,  -91,   16,    8,    1}, {  113,   15,  -92,   16,    8,    1}, {  114,   15,  -93,   16,    8,    1}, {  115,   15,  -94,   16,    8,    1},
    {  115,   15,  -95,   16,    8,    0}, {  116,   15,  -96,   16,    8,    0}, {  116,   15,  -97,   16,    8,    0}, {  117,   15,  -98,   16,    8,    0}, {  117,   15,  -99,   16,    8,    0},
    {  118,   15, -100,   16,    8,    0}, {  119,   15, -102,   16,    8,    0}, {  119,   15, -103,   16,    8,    0}, {  120,   16, -104,   16,    8,    0}, {  120,   16, -105,   16,    8,    0},
    {  121,   16, -106,   16,    8,    0}, {  121,   16, -107,   16,    8,    0}, {  122,   16, -108,   16,    8,    0}, {  123,   16, -109,   16,    8,    0}, {  123,   16, -110,   16,    8,    0},
    {  124,   16, -111,   16,    8,    0}, {  124,   16, -112,   16,    8,    0}, {  125,   16, -113,   16,    8,    0}, {  125,   16, -114,   16,    8,    0}, {  126,   16, -115,   16,    8,    0},
    {  126,   16, -117,   16,    8,    0}, {  127,   16, -118,   16,    8,    0}, {  127,   16, -119,   16,    8,    0},
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightLargeZeroGRollDown3, {
    {   16,   30,   19,    8,   16,    0}, {   16,   29,   19,    8,   16,    0}, {   16,   27,   19,    8,   16,    0}, {   15,   26,   19,    8,   16,    0}, {   15,   25,   19,    8,   16,    0},
    {   15,   23,   18,    8,   16,    0}, {   15,   22,   18,   24,    0,    9}, {   15,   21,   18,   24,    0,    9}, {   15,   19,   18,   24,    0,    9}, {   15,   18,   17,   24,    6,    9},
    {   15,   17,   17,   24,    6,    9}, {   15,   16,   17,   24,    6,    9}, {   14,   14,   17,   24,    6,    9}, {   14,   13,   16,   24,    6,    9}, {   14,   12,   16,   24,    6,    9},
    {   14,   11,   15,   24,    6,    9}, {   14,    9,   15,   24,    6,    9}, {   14,    8,   14,   24,    6,    9}, {   14,    7,   14,   24,    6,    9}, {   14,    6,   13,   24,    6,    9},
    {   14,    5,   13,   24,    6,    8}, {   13,    4,   12,   24,    6,    8}, {   13,    2,   12,   24,    6,    8}, {   13,    1,   11,   24,    6,    8}, {   13,    0,   11,   24,    6,    8},
    {   13,   -1,   10,   24,    6,    8}, {   13,   -2,    9,   24,    6,    8}, {   13,   -3,    9,   24,    6,    8}, {   13,   -4,    8,   24,    6,    8}, {   13,   -5,    7,   24,    6,    8},
    {   13,   -6,    7,   24,    6,    8}, {   13,   -8,    6,   24,    6,    8}, {   13,   -9,    5,   24,    6,    8}, {   12,  -10,    5,   24,    6,    8}, {   12,  -11,    4,   24,    6,    8},
    {   12,  -12,    3,   24,    6,    7}, {   12,  -13,    2,   24,    6,    7}, {   12,  -14,    1,   24,    6,    7}, {   12,  -15,    1,   24,    6,    7}, {   12,  -16,    0,   24,    6,    7},
    {   12,  -17,   -1,   24,    6,    7}, {   12,  -18,   -2,   24,    6,    7}, {   12,  -19,   -3,   24,    6,    7}, {   12,  -20,   -3,   24,    6,    7}, {   12,  -20,   -4,   24,    6,    7},
    {   12,  -21,   -5,   24,    6,    7}, {   12,  -22,   -6,   24,    7,    6}, {   12,  -23,   -7,   24,    7,    6}, {   12,  -24,   -8,   24,    7,    6}, {   12,  -25,   -9,   24,    7,    6},
    {   12,  -26,  -10,   24,    7,    6}, {   12,  -27,  -11,   24,    7,    6}, {   12,  -28,  -12,   24,    7,    6}, {   12,  -29,  -13,   24,    7,    6}, {   12,  -30,  -14,   24,    7,    6},
    {   12,  -30,  -15,   24,    7,    6}, {   12,  -31,  -16,   24,    7,    6}, {   12,  -32,  -16,   24,    7,    6}, {   12,  -33,  -17,   24,    7,    6}, {   12,  -34,  -18,   24,    7,    6},
    {   12,  -35,  -19,   24,    7,    6}, {   12,  -35,  -20,   24,    7,    6}, {   12,  -36,  -21,   24,    7,    6}, {   12,  -37,  -23,   24,    7,    6}, {   12,  -38,  -24,   24,    7,    6},
    {   12,  -39,  -25,   24,    7,    5}, {   12,  -40,  -26,   24,    7,    5}, {   12,  -40,  -27,   24,    7,    5}, {   12,  -41,  -28,   24,    7,    5}, {   12,  -42,  -29,   24,    7,    5},
    {   12,  -43,  -30,   24,    7,    5}, {   12,  -44,  -31,   24,    7,    5}, {   12,  -44,  -32,   24,    7,    5}, {   12,  -45,  -33,   24,    7,    5}, {   12,  -46,  -34,   24,    7,    5},
    {   12,  -47,  -35,   24,    7,    5}, {   12,  -47,  -36,   24,    7,    5}, {   12,  -48,  -37,   24,    7,    5}, {   12,  -49,  -38,   24,    7,    5}, {   12,  -50,  -39,   24,    7,    5},
    {   12,  -50,  -40,   24,    7,    5}, {   12,  -51,  -42,   24,    7,    5}, {   12,  -52,  -43,   24,    7,    2}, {   12,  -53,  -44,   24,    7,    2}, {   12,  -53,  -45,   24,    7,    2},
    {   13,  -54,  -46,   24,    7,    2}, {   13,  -55,  -47,   24,    7,    2}, {   13,  -55,  -48,   24,    7,    2}, {   13,  -56,  -49,   24,    7,    2}, {   13,  -57,  -50,   24,    7,    2},
    {   13,  -58,  -51,   24,    7,    2}, {   13,  -58,  -53,   24,    7,    2}, {   13,  -59,  -54,   24,    7,    2}, {   13,  -60,  -55,   24,    7,    2}, {   13,  -60,  -56,   24,    7,    2},
    {   13,  -61,  -57,   24,    7,    2}, {   13,  -62,  -58,   24,    7,    2}, {   13,  -63,  -59,   24,    7,    2}, {   13,  -63,  -60,   24,    7,    2}, {   13,  -64,  -61,   24,    8,    1},
    {   13,  -65,  -63,   24,    8,    1}, {   14,  -65,  -64,   24,    8,    1}, {   14,  -66,  -65,   24,    8,    1}, {   14,  -67,  -66,   24,    8,    1}, {   14,  -67,  -67,   24,    8,    1},
    {   14,  -68,  -68,   24,    8,    1}, {   14,  -69,  -69,   24,    8,    1}, {   14,  -69,  -70,   24,    8,    1}, {   14,  -70,  -72,   24,    8,    1}, {   14,  -71,  -73,   24,    8,    1},
    {   14,  -71,  -74,   24,    8,    1}, {   14,  -72,  -75,   24,    8,    1}, {   14,  -73,  -76,   24,    8,    1}, {   14,  -73,  -77,   24,    8,    1}, {   14,  -74,  -78,   24,    8,    1},
    {   14,  -74,  -79,   24,    8,    1}, {   14,  -75,  -80,   24,    8,    1}, {   15,  -76,  -82,   24,    8,    1}, {   15,  -76,  -83,   24,    8,    1}, {   15,  -77,  -84,   24,    8,    1},
    {   15,  -78,  -85,   24,    8,    1}, {   15,  -78,  -86,   24,    8,    1}, {   15,  -79,  -87,   24,    8,    1}, {   15,  -79,  -88,   24,    8,    1}, {   15,  -80,  -89,   24,    8,    1},
    {   15,  -81,  -91,   24,    8,    1}, {   15,  -81,  -92,   24,    8,    1}, {   15,  -82,  -93,   24,    8,    1}, {   15,  -83,  -94,   24,    8,    1}, {   15,  -83,  -95,   24,    8,    0},
    {   15,  -84,  -96,   24,    8,    0}, {   15,  -84,  -97,   24,    8,    0}, {   15,  -85,  -98,   24,    8,    0}, {   15,  -85,  -99,   24,    8,    0}, {   15,  -86, -100,   24,    8,    0},
    {   15,  -87, -102,   24,    8,    0}, {   15,  -87, -103,   24,    8,    0}, {   16,  -88, -104,   24,    8,    0}, {   16,  -88, -105,   24,    8,    0}, {   16,  -89, -106,   24,    8,    0},
    {   16,  -89, -107,   24,    8,    0}, {   16,  -90, -108,   24,    8,    0}, {   16,  -91, -109,   24,    8,    0}, {   16,  -91, -110,   24,    8,    0}, {   16,  -92, -111,   24,    8,    0},
    {   16,  -92, -112,   24,    8,    0}, {   16,  -93, -113,   24,    8,    0}, {   16,  -93, -114,   24,    8,    0}, {   16,  -94, -115,   24,    8,    0}, {   16,  -94, -117,   24,    8,    0},
    {   16,  -95, -118,   24,    8,    0}, {   16,  -95, -119,   24,    8,    0}, {   16,  -96, -120,   24,    8,    0},
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_LeftFlyerLargeHalfLoopDown0, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,   -1,  0,  0,  0 }, {     22,   16,   -1,  0,  0,  0 },
    {     21,   15,   -1,  0,  0,  0 }, {     20,   15,   -1,  0,  0,  0 }, {     19,   15,   -2,  0,  0,  0 }, {     18,   15,   -2,  0,  0,  0 }, {     17,   15,   -2,  0,  0,  0 },
    {     16,   15,   -3, 16, 23,  0 }, {     15,   15,   -3, 16, 23,  0 }, {     14,   15,   -4, 16, 23,  0 }, {     13,   15,   -4, 16, 23,  0 }, {     12,   15,   -5, 16, 23,  0 },
    {     11,   14,   -5, 16, 23,  0 }, {     10,   14,   -6, 16, 23,  0 }, {      9,   14,   -6, 16, 23,  0 }, {      8,   14,   -7, 16, 23,  0 }, {      7,   14,   -8, 16, 23,  0 },
    {      6,   14,   -8, 16, 23,  0 }, {      5,   14,   -9, 16, 23,  0 }, {      4,   14,  -10, 16, 23,  0 }, {      3,   14,  -11, 16, 23,  0 }, {      2,   14,  -11, 16, 23,  0 },
    {      1,   13,  -12, 16, 22,  0 }, {      0,   13,  -13, 16, 22,  0 }, {     -1,   13,  -14, 16, 22,  0 }, {     -2,   13,  -15, 16, 22,  0 }, {     -3,   13,  -16, 16, 22,  0 },
    {     -4,   13,  -17, 16, 22,  0 }, {     -5,   13,  -18, 16, 22,  0 }, {     -6,   13,  -19, 16, 22,  0 }, {     -7,   13,  -20, 16, 22,  0 }, {     -8,   12,  -21, 16, 22,  0 },
    {     -9,   12,  -22, 16, 22,  0 }, {     -9,   12,  -23, 16, 22,  0 }, {    -10,   12,  -24, 16, 22,  0 }, {    -11,   12,  -25, 16, 21,  0 }, {    -12,   12,  -26, 16, 21,  0 },
    {    -12,   12,  -27, 16, 21,  0 }, {    -13,   12,  -28, 16, 21,  0 }, {    -14,   12,  -29, 16, 21,  0 }, {    -14,   12,  -30, 16, 21,  0 }, {    -15,   11,  -31, 16, 21,  0 },
    {    -16,   11,  -32, 16, 21,  0 }, {    -16,   11,  -33, 16, 21,  0 }, {    -17,   11,  -34, 16, 21,  0 }, {    -17,   11,  -35, 16, 21,  0 }, {    -18,   11,  -36, 16, 21,  0 },
    {    -18,   11,  -37, 16, 21,  0 }, {    -19,   11,  -38, 16, 21,  0 }, {    -19,   11,  -39, 16, 21,  0 }, {    -20,   11,  -40, 16, 20,  0 }, {    -20,   10,  -41, 16, 20,  0 },
    {    -21,   10,  -42, 16, 20,  0 }, {    -21,   10,  -43, 16, 20,  0 }, {    -22,   10,  -44, 16, 20,  0 }, {    -22,   10,  -45, 16, 20,  0 }, {    -22,   10,  -46, 16, 20,  0 },
    {    -23,   10,  -47, 16, 20,  0 }, {    -23,   10,  -48, 16, 20,  0 }, {    -23,   10,  -49, 16, 20,  0 }, {    -24,   10,  -50, 16, 20,  0 }, {    -24,    9,  -51, 16, 20,  0 },
    {    -25,    9,  -52, 16, 20,  0 }, {    -25,    9,  -53, 16, 20,  0 }, {    -25,    9,  -54, 16, 20,  0 }, {    -26,    9,  -55, 16, 19,  0 }, {    -26,    9,  -56, 16, 19,  0 },
    {    -26,    9,  -57, 16, 19,  0 }, {    -26,    9,  -58, 16, 19,  0 }, {    -27,    9,  -59, 16, 19,  0 }, {    -27,    8,  -60, 16, 19,  0 }, {    -27,    8,  -61, 16, 19,  0 },
    {    -27,    8,  -62, 16, 19,  0 }, {    -28,    8,  -63, 16, 19,  0 }, {    -28,    8,  -64, 16, 19,  0 }, {    -28,    8,  -65, 16, 19,  0 }, {    -28,    8,  -66, 16, 19,  0 },
    {    -28,    8,  -67, 16, 19,  0 }, {    -28,    8,  -68, 16, 19,  0 }, {    -29,    8,  -69, 16, 19,  0 }, {    -29,    7,  -70, 16, 19,  0 }, {    -29,    7,  -71, 16, 19,  0 },
    {    -29,    7,  -72, 16, 19,  0 }, {    -29,    7,  -73, 16, 19,  0 }, {    -29,    7,  -74, 16, 19,  0 }, {    -29,    7,  -75, 16, 19,  0 }, {    -29,    7,  -76, 16, 19,  0 },
    {    -30,    7,  -77, 16, 19,  0 }, {    -30,    7,  -78, 16, 19,  0 }, {    -30,    7,  -79, 16, 18,  0 }, {    -30,    6,  -80, 16, 18,  0 }, {    -30,    6,  -81, 16, 18,  0 },
    {    -30,    6,  -82, 16, 18,  0 }, {    -30,    6,  -83, 16, 18,  0 }, {    -30,    6,  -84, 16, 18,  0 }, {    -30,    6,  -85, 16, 18,  0 }, {    -30,    6,  -86, 16, 18,  0 },
    {    -30,    6,  -87, 16, 18,  0 }, {    -30,    6,  -88, 16, 18,  0 }, {    -30,    5,  -89, 16, 18,  0 }, {    -30,    5,  -90, 16, 18,  0 }, {    -30,    5,  -91, 16, 18,  0 },
    {    -30,    5,  -92, 16, 18,  0 }, {    -30,    5,  -93, 16, 18,  0 }, {    -30,    5,  -94, 16, 18,  0 }, {    -30,    5,  -95, 16, 18,  0 }, {    -30,    5,  -96, 16, 18,  0 },
    {    -30,    5,  -97, 16, 18,  0 }, {    -30,    5,  -98, 16, 18,  0 }, {    -30,    4,  -99, 16, 18,  0 }, {    -30,    4, -100, 16, 18,  0 }, {    -30,    4, -101, 16, 18,  0 },
    {    -30,    4, -102, 16, 18,  0 }, {    -30,    4, -103, 16, 18,  0 }, {    -30,    4, -104, 16, 18,  0 }, {    -30,    4, -105, 16, 18,  0 }, {    -30,    4, -106, 16, 18,  0 },
    {    -30,    4, -107, 16, 18,  0 }, {    -30,    4, -108, 16, 18,  0 }, {    -30,    3, -109, 16, 18,  0 }, {    -30,    3, -110, 16, 18,  0 }, {    -30,    3, -111, 16, 18,  0 },
    {    -30,    3, -112, 16, 18,  0 }, {    -30,    3, -113, 16, 18,  0 }, {    -30,    3, -114, 16, 18,  0 }, {    -30,    3, -115, 16, 18,  0 }, {    -30,    3, -116, 16, 17,  0 },
    {    -30,    3, -117, 16, 17,  0 }, {    -29,    3, -118, 16, 17,  0 }, {    -29,    2, -119, 16, 17,  0 }, {    -29,    2, -120, 16, 17,  0 }, {    -29,    2, -121, 16, 17,  0 },
    {    -29,    2, -122, 16, 17,  0 }, {    -29,    2, -123, 16, 17,  0 }, {    -28,    2, -124, 16, 17,  0 }, {    -28,    2, -125, 16, 17,  0 }, {    -28,    2, -126, 16, 17,  0 },
    {    -28,    2, -127, 16, 17,  0 }, {    -28,    1, -128, 16, 17,  0 }, {    -28,    1, -129, 16, 17,  0 }, {    -27,    1, -130, 16, 17,  0 }, {    -27,    1, -131, 16, 17,  0 },
    {    -27,    1, -132, 16, 17,  0 }, {    -27,    1, -133, 16, 17,  0 }, {    -27,    1, -134, 16, 17,  0 }, {    -26,    1, -135, 16, 17,  0 }, {    -26,    1, -136, 16, 17,  0 },
    {    -26,    1, -137, 16, 17,  0 }, {    -26,    0, -138, 16, 17,  0 }, {    -25,    0, -139, 16, 17,  0 }, {    -25,    0, -140, 16, 17,  0 }, {    -25,    0, -141, 16, 17,  0 },
    {    -24,    0, -142, 16, 17,  0 }, {    -24,    0, -143, 16, 17,  0 }, {    -24,    0, -144, 16, 17,  0 }, {    -23,    0, -145, 16, 17,  0 }, {    -23,    0, -146, 16, 17,  0 },
    {    -23,    0, -147, 16, 17,  0 }, {    -23,   -1, -148, 16, 17,  0 }, {    -22,   -1, -149, 16, 58,  0 }, {    -22,   -1, -150, 16, 58,  0 }, {    -22,   -1, -151, 16, 58,  0 },
    {    -21,   -1, -152, 16, 58,  0 }, {    -21,   -1, -153, 16, 58,  0 }, {    -20,   -1, -154, 16, 58,  0 }, {    -20,   -1, -155, 16, 58,  0 }, {    -19,   -1, -156, 16, 58,  0 },
    {    -19,   -2, -157, 16, 58,  0 }, {    -19,   -2, -158, 16, 58,  0 }, {    -18,   -2, -159, 16, 58,  0 }, {    -18,   -2, -160, 16, 58,  0 }, {    -17,   -2, -161, 16, 58,  0 },
    {    -17,   -2, -162, 16, 58,  0 }, {    -17,   -2, -163, 16, 58,  0 }, {    -16,   -2, -164, 16, 58,  0 }, {    -16,   -2, -165, 16, 58,  0 }, {    -15,   -2, -166, 16, 58,  0 },
    {    -15,   -3, -167, 16, 58,  0 }, {    -14,   -3, -168, 16, 58,  0 }, {    -14,   -3, -169, 16, 58,  0 }, {    -14,   -3, -170, 16, 58,  0 }, {    -13,   -3, -171, 16, 58,  0 },
    {    -13,   -3, -172, 16, 58,  0 }, {    -12,   -3, -173, 16, 58,  0 }, {    -12,   -3, -174, 16, 58,  0 }, {    -11,   -3, -175, 16, 58,  0 }, {    -11,   -3, -176, 16, 58,  0 },
    {    -10,   -4, -177, 16, 58,  0 }, {    -10,   -4, -178, 16, 58,  0 }, {     -9,   -4, -179, 16, 58,  0 }, {     -8,   -4, -180, 16, 58,  0 }, {     -8,   -4, -181, 16, 58,  0 },
    {     -7,   -4, -182, 16, 58,  0 }, {     -7,   -4, -183, 16, 58,  0 }, {     -6,   -4, -184, 16, 58,  0 }, {     -5,   -4, -185, 16, 57,  0 }, {     -5,   -4, -186, 16, 57,  0 },
    {     -4,   -5, -187, 16, 57,  0 }, {     -4,   -5, -188, 16, 57,  0 }, {     -3,   -5, -189, 16, 57,  0 }, {     -2,   -5, -190, 16, 57,  0 }, {     -2,   -5, -191, 16, 57,  0 },
    {     -1,   -5, -192, 16, 57,  0 }, {      0,   -5, -193, 16, 57,  0 }, {      0,   -5, -194, 16, 57,  0 }, {      1,   -5, -195, 16, 57,  0 }, {      2,   -6, -196, 16, 57,  0 },
    {      3,   -6, -197, 16, 57,  0 }, {      3,   -6, -198, 16, 57,  0 }, {      4,   -6, -199, 16, 57,  0 }, {      5,   -6, -200, 16, 57,  0 }, {      5,   -6, -201, 16, 57,  0 },
    {      6,   -6, -202, 16, 57,  0 }, {      7,   -6, -203, 16, 57,  0 }, {      7,   -6, -204, 16, 57,  0 }, {      8,   -6, -205, 16, 57,  0 }, {      9,   -7, -206, 16, 57,  0 },
    {     10,   -7, -207, 16, 57,  0 }, {     11,   -7, -208, 16, 57,  0 }, {     12,   -7, -209, 16, 57,  0 }, {     13,   -7, -210, 16, 57,  0 }, {     14,   -7, -211, 16, 57,  0 },
    {     14,   -7, -212, 16, 57,  0 }, {     15,   -7, -213, 16, 57,  0 }, {     16,   -7, -214, 16, 57,  0 }, {     17,   -7, -215, 16, 57,  0 }, {     18,   -8, -216, 16, 57,  0 },
    {     19,   -8, -217, 16, 57,  0 }, {     20,   -8, -218, 16, 57,  0 }, {     21,   -8, -219, 16, 57,  0 }, {     22,   -8, -220, 16, 57,  0 }, {     23,   -8, -221, 16, 57,  0 },
    {     24,   -8, -222, 16, 57,  0 }, {     25,   -8, -222, 16, 57,  0 }, {     26,   -8, -223, 16, 57,  0 }, {     27,   -9, -224, 16, 57,  0 }, {     28,   -9, -225, 16, 57,  0 },
    {     29,   -9, -226, 16, 57,  0 }, {     30,   -9, -227, 16, 57,  0 }, {     31,   -9, -228, 16, 57,  0 }, {     32,   -9, -228, 16, 57,  0 }, {     33,   -9, -229, 16, 57,  0 },
    {     34,   -9, -230, 16, 56,  0 }, {     35,   -9, -231, 16, 56,  0 }, {     36,   -9, -231, 16, 56,  0 }, {     37,  -10, -232, 16, 56,  0 }, {     38,  -10, -233, 16, 56,  0 },
    {     39,  -10, -234, 16, 56,  0 }, {     40,  -10, -234, 16, 56,  0 }, {     41,  -10, -235, 16, 56,  0 }, {     42,  -10, -236, 16, 56,  0 }, {     43,  -10, -237, 16, 56,  0 },
    {     44,  -10, -237, 16, 56,  0 }, {     45,  -10, -238, 16, 56,  0 }, {     46,  -10, -239, 16, 56,  0 }, {     47,  -11, -239, 16, 56,  0 }, {     48,  -11, -240, 16, 56,  0 },
    {     49,  -11, -240, 16, 56,  0 }, {     50,  -11, -241, 16, 56,  0 }, {     51,  -11, -242, 16, 56,  0 }, {     52,  -11, -242, 16, 56,  0 }, {     53,  -11, -243, 16, 56,  0 },
    {     54,  -11, -243, 16, 56,  0 }, {     55,  -11, -244, 16, 56,  0 }, {     56,  -11, -245, 16, 56,  0 }, {     57,  -12, -245, 16, 56,  0 }, {     58,  -12, -246, 16, 56,  0 },
    {     59,  -12, -246, 16, 56,  0 }, {     60,  -12, -247, 16, 56,  0 }, {     61,  -12, -247, 16, 56,  0 }, {     62,  -12, -248, 16, 56,  0 }, {     63,  -12, -248, 16, 56,  0 },
    {     64,  -12, -249, 16, 56,  0 }, {     65,  -12, -249, 16, 56,  0 }, {     66,  -13, -250, 16, 56,  0 }, {     67,  -13, -250, 16, 56,  0 }, {     68,  -13, -251, 16, 56,  0 },
    {     69,  -13, -251, 16, 56,  0 }, {     70,  -13, -252, 16, 56,  0 }, {     71,  -13, -252, 16, 56,  0 }, {     72,  -13, -253, 16, 56,  0 }, {     73,  -13, -253, 16, 56,  0 },
    {     74,  -13, -254, 16, 56,  0 }, {     75,  -13, -254, 16, 56,  0 }, {     76,  -14, -255, 16, 56,  0 }, {     77,  -14, -255, 16, 56,  0 }, {     78,  -14, -256, 16, 56,  0 },
    {     79,  -14, -256, 16, 56,  0 }, {     80,  -14, -257, 16, 56,  0 }, {     81,  -14, -257, 16, 56,  0 }, {     82,  -14, -258, 16, 56,  0 }, {     83,  -14, -258, 16, 56,  0 },
    {     84,  -14, -259, 16, 56,  0 }, {     85,  -14, -259, 16, 56,  0 }, {     86,  -15, -260, 16, 56,  0 }, {     87,  -15, -260, 16, 56,  0 }, {     88,  -15, -261, 16, 56,  0 },
    {     89,  -15, -261, 16, 56,  0 }, {     90,  -15, -262, 16, 56,  0 }, {     91,  -15, -262, 16, 56,  0 }, {     92,  -15, -263, 16, 56,  0 }, {     93,  -15, -263, 16, 56,  0 },
    {     94,  -15, -264, 16, 56,  0 }
  })



CREATE_VEHICLE_INFO(TrackVehicleInfo_LeftFlyerLargeHalfLoopDown1, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,   -1,  8,  0,  0 }, {     16,    9,   -1,  8,  0,  0 },
    {     15,   10,   -1,  8,  0,  0 }, {     15,   11,   -1,  8,  0,  0 }, {     15,   12,   -2,  8,  0,  0 }, {     15,   13,   -2,  8,  0,  0 }, {     15,   14,   -2,  8,  0,  0 },
    {     15,   15,   -3, 24, 23,  0 }, {     15,   16,   -3, 24, 23,  0 }, {     15,   17,   -4, 24, 23,  0 }, {     15,   18,   -4, 24, 23,  0 }, {     15,   19,   -5, 24, 23,  0 },
    {     14,   20,   -5, 24, 23,  0 }, {     14,   21,   -6, 24, 23,  0 }, {     14,   22,   -6, 24, 23,  0 }, {     14,   23,   -7, 24, 23,  0 }, {     14,   24,   -8, 24, 23,  0 },
    {     14,   25,   -8, 24, 23,  0 }, {     14,   26,   -9, 24, 23,  0 }, {     14,   27,  -10, 24, 23,  0 }, {     14,   28,  -11, 24, 23,  0 }, {     14,   29,  -11, 24, 23,  0 },
    {     13,   30,  -12, 24, 22,  0 }, {     13,   31,  -13, 24, 22,  0 }, {     13,   32,  -14, 24, 22,  0 }, {     13,   33,  -15, 24, 22,  0 }, {     13,   34,  -16, 24, 22,  0 },
    {     13,   35,  -17, 24, 22,  0 }, {     13,   36,  -18, 24, 22,  0 }, {     13,   37,  -19, 24, 22,  0 }, {     13,   38,  -20, 24, 22,  0 }, {     12,   39,  -21, 24, 22,  0 },
    {     12,   40,  -22, 24, 22,  0 }, {     12,   40,  -23, 24, 22,  0 }, {     12,   41,  -24, 24, 22,  0 }, {     12,   42,  -25, 24, 21,  0 }, {     12,   43,  -26, 24, 21,  0 },
    {     12,   43,  -27, 24, 21,  0 }, {     12,   44,  -28, 24, 21,  0 }, {     12,   45,  -29, 24, 21,  0 }, {     12,   45,  -30, 24, 21,  0 }, {     11,   46,  -31, 24, 21,  0 },
    {     11,   47,  -32, 24, 21,  0 }, {     11,   47,  -33, 24, 21,  0 }, {     11,   48,  -34, 24, 21,  0 }, {     11,   48,  -35, 24, 21,  0 }, {     11,   49,  -36, 24, 21,  0 },
    {     11,   49,  -37, 24, 21,  0 }, {     11,   50,  -38, 24, 21,  0 }, {     11,   50,  -39, 24, 21,  0 }, {     11,   51,  -40, 24, 20,  0 }, {     10,   51,  -41, 24, 20,  0 },
    {     10,   52,  -42, 24, 20,  0 }, {     10,   52,  -43, 24, 20,  0 }, {     10,   53,  -44, 24, 20,  0 }, {     10,   53,  -45, 24, 20,  0 }, {     10,   53,  -46, 24, 20,  0 },
    {     10,   54,  -47, 24, 20,  0 }, {     10,   54,  -48, 24, 20,  0 }, {     10,   54,  -49, 24, 20,  0 }, {     10,   55,  -50, 24, 20,  0 }, {      9,   55,  -51, 24, 20,  0 },
    {      9,   56,  -52, 24, 20,  0 }, {      9,   56,  -53, 24, 20,  0 }, {      9,   56,  -54, 24, 20,  0 }, {      9,   57,  -55, 24, 19,  0 }, {      9,   57,  -56, 24, 19,  0 },
    {      9,   57,  -57, 24, 19,  0 }, {      9,   57,  -58, 24, 19,  0 }, {      9,   58,  -59, 24, 19,  0 }, {      8,   58,  -60, 24, 19,  0 }, {      8,   58,  -61, 24, 19,  0 },
    {      8,   58,  -62, 24, 19,  0 }, {      8,   59,  -63, 24, 19,  0 }, {      8,   59,  -64, 24, 19,  0 }, {      8,   59,  -65, 24, 19,  0 }, {      8,   59,  -66, 24, 19,  0 },
    {      8,   59,  -67, 24, 19,  0 }, {      8,   59,  -68, 24, 19,  0 }, {      8,   60,  -69, 24, 19,  0 }, {      7,   60,  -70, 24, 19,  0 }, {      7,   60,  -71, 24, 19,  0 },
    {      7,   60,  -72, 24, 19,  0 }, {      7,   60,  -73, 24, 19,  0 }, {      7,   60,  -74, 24, 19,  0 }, {      7,   60,  -75, 24, 19,  0 }, {      7,   60,  -76, 24, 19,  0 },
    {      7,   61,  -77, 24, 19,  0 }, {      7,   61,  -78, 24, 19,  0 }, {      7,   61,  -79, 24, 18,  0 }, {      6,   61,  -80, 24, 18,  0 }, {      6,   61,  -81, 24, 18,  0 },
    {      6,   61,  -82, 24, 18,  0 }, {      6,   61,  -83, 24, 18,  0 }, {      6,   61,  -84, 24, 18,  0 }, {      6,   61,  -85, 24, 18,  0 }, {      6,   61,  -86, 24, 18,  0 },
    {      6,   61,  -87, 24, 18,  0 }, {      6,   61,  -88, 24, 18,  0 }, {      5,   61,  -89, 24, 18,  0 }, {      5,   61,  -90, 24, 18,  0 }, {      5,   61,  -91, 24, 18,  0 },
    {      5,   61,  -92, 24, 18,  0 }, {      5,   61,  -93, 24, 18,  0 }, {      5,   61,  -94, 24, 18,  0 }, {      5,   61,  -95, 24, 18,  0 }, {      5,   61,  -96, 24, 18,  0 },
    {      5,   61,  -97, 24, 18,  0 }, {      5,   61,  -98, 24, 18,  0 }, {      4,   61,  -99, 24, 18,  0 }, {      4,   61, -100, 24, 18,  0 }, {      4,   61, -101, 24, 18,  0 },
    {      4,   61, -102, 24, 18,  0 }, {      4,   61, -103, 24, 18,  0 }, {      4,   61, -104, 24, 18,  0 }, {      4,   61, -105, 24, 18,  0 }, {      4,   61, -106, 24, 18,  0 },
    {      4,   61, -107, 24, 18,  0 }, {      4,   61, -108, 24, 18,  0 }, {      3,   61, -109, 24, 18,  0 }, {      3,   61, -110, 24, 18,  0 }, {      3,   61, -111, 24, 18,  0 },
    {      3,   61, -112, 24, 18,  0 }, {      3,   61, -113, 24, 18,  0 }, {      3,   61, -114, 24, 18,  0 }, {      3,   61, -115, 24, 18,  0 }, {      3,   61, -116, 24, 17,  0 },
    {      3,   61, -117, 24, 17,  0 }, {      3,   60, -118, 24, 17,  0 }, {      2,   60, -119, 24, 17,  0 }, {      2,   60, -120, 24, 17,  0 }, {      2,   60, -121, 24, 17,  0 },
    {      2,   60, -122, 24, 17,  0 }, {      2,   60, -123, 24, 17,  0 }, {      2,   59, -124, 24, 17,  0 }, {      2,   59, -125, 24, 17,  0 }, {      2,   59, -126, 24, 17,  0 },
    {      2,   59, -127, 24, 17,  0 }, {      1,   59, -128, 24, 17,  0 }, {      1,   59, -129, 24, 17,  0 }, {      1,   58, -130, 24, 17,  0 }, {      1,   58, -131, 24, 17,  0 },
    {      1,   58, -132, 24, 17,  0 }, {      1,   58, -133, 24, 17,  0 }, {      1,   58, -134, 24, 17,  0 }, {      1,   57, -135, 24, 17,  0 }, {      1,   57, -136, 24, 17,  0 },
    {      1,   57, -137, 24, 17,  0 }, {      0,   57, -138, 24, 17,  0 }, {      0,   56, -139, 24, 17,  0 }, {      0,   56, -140, 24, 17,  0 }, {      0,   56, -141, 24, 17,  0 },
    {      0,   55, -142, 24, 17,  0 }, {      0,   55, -143, 24, 17,  0 }, {      0,   55, -144, 24, 17,  0 }, {      0,   54, -145, 24, 17,  0 }, {      0,   54, -146, 24, 17,  0 },
    {      0,   54, -147, 24, 17,  0 }, {     -1,   54, -148, 24, 17,  0 }, {     -1,   53, -149, 24, 58,  0 }, {     -1,   53, -150, 24, 58,  0 }, {     -1,   53, -151, 24, 58,  0 },
    {     -1,   52, -152, 24, 58,  0 }, {     -1,   52, -153, 24, 58,  0 }, {     -1,   51, -154, 24, 58,  0 }, {     -1,   51, -155, 24, 58,  0 }, {     -1,   50, -156, 24, 58,  0 },
    {     -2,   50, -157, 24, 58,  0 }, {     -2,   50, -158, 24, 58,  0 }, {     -2,   49, -159, 24, 58,  0 }, {     -2,   49, -160, 24, 58,  0 }, {     -2,   48, -161, 24, 58,  0 },
    {     -2,   48, -162, 24, 58,  0 }, {     -2,   48, -163, 24, 58,  0 }, {     -2,   47, -164, 24, 58,  0 }, {     -2,   47, -165, 24, 58,  0 }, {     -2,   46, -166, 24, 58,  0 },
    {     -3,   46, -167, 24, 58,  0 }, {     -3,   45, -168, 24, 58,  0 }, {     -3,   45, -169, 24, 58,  0 }, {     -3,   45, -170, 24, 58,  0 }, {     -3,   44, -171, 24, 58,  0 },
    {     -3,   44, -172, 24, 58,  0 }, {     -3,   43, -173, 24, 58,  0 }, {     -3,   43, -174, 24, 58,  0 }, {     -3,   42, -175, 24, 58,  0 }, {     -3,   42, -176, 24, 58,  0 },
    {     -4,   41, -177, 24, 58,  0 }, {     -4,   41, -178, 24, 58,  0 }, {     -4,   40, -179, 24, 58,  0 }, {     -4,   39, -180, 24, 58,  0 }, {     -4,   39, -181, 24, 58,  0 },
    {     -4,   38, -182, 24, 58,  0 }, {     -4,   38, -183, 24, 58,  0 }, {     -4,   37, -184, 24, 58,  0 }, {     -4,   36, -185, 24, 57,  0 }, {     -4,   36, -186, 24, 57,  0 },
    {     -5,   35, -187, 24, 57,  0 }, {     -5,   35, -188, 24, 57,  0 }, {     -5,   34, -189, 24, 57,  0 }, {     -5,   33, -190, 24, 57,  0 }, {     -5,   33, -191, 24, 57,  0 },
    {     -5,   32, -192, 24, 57,  0 }, {     -5,   31, -193, 24, 57,  0 }, {     -5,   31, -194, 24, 57,  0 }, {     -5,   30, -195, 24, 57,  0 }, {     -6,   29, -196, 24, 57,  0 },
    {     -6,   28, -197, 24, 57,  0 }, {     -6,   28, -198, 24, 57,  0 }, {     -6,   27, -199, 24, 57,  0 }, {     -6,   26, -200, 24, 57,  0 }, {     -6,   26, -201, 24, 57,  0 },
    {     -6,   25, -202, 24, 57,  0 }, {     -6,   24, -203, 24, 57,  0 }, {     -6,   24, -204, 24, 57,  0 }, {     -6,   23, -205, 24, 57,  0 }, {     -7,   22, -206, 24, 57,  0 },
    {     -7,   21, -207, 24, 57,  0 }, {     -7,   20, -208, 24, 57,  0 }, {     -7,   19, -209, 24, 57,  0 }, {     -7,   18, -210, 24, 57,  0 }, {     -7,   17, -211, 24, 57,  0 },
    {     -7,   17, -212, 24, 57,  0 }, {     -7,   16, -213, 24, 57,  0 }, {     -7,   15, -214, 24, 57,  0 }, {     -7,   14, -215, 24, 57,  0 }, {     -8,   13, -216, 24, 57,  0 },
    {     -8,   12, -217, 24, 57,  0 }, {     -8,   11, -218, 24, 57,  0 }, {     -8,   10, -219, 24, 57,  0 }, {     -8,    9, -220, 24, 57,  0 }, {     -8,    8, -221, 24, 57,  0 },
    {     -8,    7, -222, 24, 57,  0 }, {     -8,    6, -222, 24, 57,  0 }, {     -8,    5, -223, 24, 57,  0 }, {     -9,    4, -224, 24, 57,  0 }, {     -9,    3, -225, 24, 57,  0 },
    {     -9,    2, -226, 24, 57,  0 }, {     -9,    1, -227, 24, 57,  0 }, {     -9,    0, -228, 24, 57,  0 }, {     -9,   -1, -228, 24, 57,  0 }, {     -9,   -2, -229, 24, 57,  0 },
    {     -9,   -3, -230, 24, 56,  0 }, {     -9,   -4, -231, 24, 56,  0 }, {     -9,   -5, -231, 24, 56,  0 }, {    -10,   -6, -232, 24, 56,  0 }, {    -10,   -7, -233, 24, 56,  0 },
    {    -10,   -8, -234, 24, 56,  0 }, {    -10,   -9, -234, 24, 56,  0 }, {    -10,  -10, -235, 24, 56,  0 }, {    -10,  -11, -236, 24, 56,  0 }, {    -10,  -12, -237, 24, 56,  0 },
    {    -10,  -13, -237, 24, 56,  0 }, {    -10,  -14, -238, 24, 56,  0 }, {    -10,  -15, -239, 24, 56,  0 }, {    -11,  -16, -239, 24, 56,  0 }, {    -11,  -17, -240, 24, 56,  0 },
    {    -11,  -18, -240, 24, 56,  0 }, {    -11,  -19, -241, 24, 56,  0 }, {    -11,  -20, -242, 24, 56,  0 }, {    -11,  -21, -242, 24, 56,  0 }, {    -11,  -22, -243, 24, 56,  0 },
    {    -11,  -23, -243, 24, 56,  0 }, {    -11,  -24, -244, 24, 56,  0 }, {    -11,  -25, -245, 24, 56,  0 }, {    -12,  -26, -245, 24, 56,  0 }, {    -12,  -27, -246, 24, 56,  0 },
    {    -12,  -28, -246, 24, 56,  0 }, {    -12,  -29, -247, 24, 56,  0 }, {    -12,  -30, -247, 24, 56,  0 }, {    -12,  -31, -248, 24, 56,  0 }, {    -12,  -32, -248, 24, 56,  0 },
    {    -12,  -33, -249, 24, 56,  0 }, {    -12,  -34, -249, 24, 56,  0 }, {    -13,  -35, -250, 24, 56,  0 }, {    -13,  -36, -250, 24, 56,  0 }, {    -13,  -37, -251, 24, 56,  0 },
    {    -13,  -38, -251, 24, 56,  0 }, {    -13,  -39, -252, 24, 56,  0 }, {    -13,  -40, -252, 24, 56,  0 }, {    -13,  -41, -253, 24, 56,  0 }, {    -13,  -42, -253, 24, 56,  0 },
    {    -13,  -43, -254, 24, 56,  0 }, {    -13,  -44, -254, 24, 56,  0 }, {    -14,  -45, -255, 24, 56,  0 }, {    -14,  -46, -255, 24, 56,  0 }, {    -14,  -47, -256, 24, 56,  0 },
    {    -14,  -48, -256, 24, 56,  0 }, {    -14,  -49, -257, 24, 56,  0 }, {    -14,  -50, -257, 24, 56,  0 }, {    -14,  -51, -258, 24, 56,  0 }, {    -14,  -52, -258, 24, 56,  0 },
    {    -14,  -53, -259, 24, 56,  0 }, {    -14,  -54, -259, 24, 56,  0 }, {    -15,  -55, -260, 24, 56,  0 }, {    -15,  -56, -260, 24, 56,  0 }, {    -15,  -57, -261, 24, 56,  0 },
    {    -15,  -58, -261, 24, 56,  0 }, {    -15,  -59, -262, 24, 56,  0 }, {    -15,  -60, -262, 24, 56,  0 }, {    -15,  -61, -263, 24, 56,  0 }, {    -15,  -62, -263, 24, 56,  0 },
    {    -15,  -63, -264, 24, 56,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_LeftFlyerLargeHalfLoopDown2, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,   -1, 16,  0,  0 }, {      9,   16,   -1, 16,  0,  0 },
    {     10,   17,   -1, 16,  0,  0 }, {     11,   17,   -1, 16,  0,  0 }, {     12,   17,   -2, 16,  0,  0 }, {     13,   17,   -2, 16,  0,  0 }, {     14,   17,   -2, 16,  0,  0 },
    {     15,   17,   -3,  0, 23,  0 }, {     16,   17,   -3,  0, 23,  0 }, {     17,   17,   -4,  0, 23,  0 }, {     18,   17,   -4,  0, 23,  0 }, {     19,   17,   -5,  0, 23,  0 },
    {     20,   18,   -5,  0, 23,  0 }, {     21,   18,   -6,  0, 23,  0 }, {     22,   18,   -6,  0, 23,  0 }, {     23,   18,   -7,  0, 23,  0 }, {     24,   18,   -8,  0, 23,  0 },
    {     25,   18,   -8,  0, 23,  0 }, {     26,   18,   -9,  0, 23,  0 }, {     27,   18,  -10,  0, 23,  0 }, {     28,   18,  -11,  0, 23,  0 }, {     29,   18,  -11,  0, 23,  0 },
    {     30,   19,  -12,  0, 22,  0 }, {     31,   19,  -13,  0, 22,  0 }, {     32,   19,  -14,  0, 22,  0 }, {     33,   19,  -15,  0, 22,  0 }, {     34,   19,  -16,  0, 22,  0 },
    {     35,   19,  -17,  0, 22,  0 }, {     36,   19,  -18,  0, 22,  0 }, {     37,   19,  -19,  0, 22,  0 }, {     38,   19,  -20,  0, 22,  0 }, {     39,   20,  -21,  0, 22,  0 },
    {     40,   20,  -22,  0, 22,  0 }, {     40,   20,  -23,  0, 22,  0 }, {     41,   20,  -24,  0, 22,  0 }, {     42,   20,  -25,  0, 21,  0 }, {     43,   20,  -26,  0, 21,  0 },
    {     43,   20,  -27,  0, 21,  0 }, {     44,   20,  -28,  0, 21,  0 }, {     45,   20,  -29,  0, 21,  0 }, {     45,   20,  -30,  0, 21,  0 }, {     46,   21,  -31,  0, 21,  0 },
    {     47,   21,  -32,  0, 21,  0 }, {     47,   21,  -33,  0, 21,  0 }, {     48,   21,  -34,  0, 21,  0 }, {     48,   21,  -35,  0, 21,  0 }, {     49,   21,  -36,  0, 21,  0 },
    {     49,   21,  -37,  0, 21,  0 }, {     50,   21,  -38,  0, 21,  0 }, {     50,   21,  -39,  0, 21,  0 }, {     51,   21,  -40,  0, 20,  0 }, {     51,   22,  -41,  0, 20,  0 },
    {     52,   22,  -42,  0, 20,  0 }, {     52,   22,  -43,  0, 20,  0 }, {     53,   22,  -44,  0, 20,  0 }, {     53,   22,  -45,  0, 20,  0 }, {     53,   22,  -46,  0, 20,  0 },
    {     54,   22,  -47,  0, 20,  0 }, {     54,   22,  -48,  0, 20,  0 }, {     54,   22,  -49,  0, 20,  0 }, {     55,   22,  -50,  0, 20,  0 }, {     55,   23,  -51,  0, 20,  0 },
    {     56,   23,  -52,  0, 20,  0 }, {     56,   23,  -53,  0, 20,  0 }, {     56,   23,  -54,  0, 20,  0 }, {     57,   23,  -55,  0, 19,  0 }, {     57,   23,  -56,  0, 19,  0 },
    {     57,   23,  -57,  0, 19,  0 }, {     57,   23,  -58,  0, 19,  0 }, {     58,   23,  -59,  0, 19,  0 }, {     58,   24,  -60,  0, 19,  0 }, {     58,   24,  -61,  0, 19,  0 },
    {     58,   24,  -62,  0, 19,  0 }, {     59,   24,  -63,  0, 19,  0 }, {     59,   24,  -64,  0, 19,  0 }, {     59,   24,  -65,  0, 19,  0 }, {     59,   24,  -66,  0, 19,  0 },
    {     59,   24,  -67,  0, 19,  0 }, {     59,   24,  -68,  0, 19,  0 }, {     60,   24,  -69,  0, 19,  0 }, {     60,   25,  -70,  0, 19,  0 }, {     60,   25,  -71,  0, 19,  0 },
    {     60,   25,  -72,  0, 19,  0 }, {     60,   25,  -73,  0, 19,  0 }, {     60,   25,  -74,  0, 19,  0 }, {     60,   25,  -75,  0, 19,  0 }, {     60,   25,  -76,  0, 19,  0 },
    {     61,   25,  -77,  0, 19,  0 }, {     61,   25,  -78,  0, 19,  0 }, {     61,   25,  -79,  0, 18,  0 }, {     61,   26,  -80,  0, 18,  0 }, {     61,   26,  -81,  0, 18,  0 },
    {     61,   26,  -82,  0, 18,  0 }, {     61,   26,  -83,  0, 18,  0 }, {     61,   26,  -84,  0, 18,  0 }, {     61,   26,  -85,  0, 18,  0 }, {     61,   26,  -86,  0, 18,  0 },
    {     61,   26,  -87,  0, 18,  0 }, {     61,   26,  -88,  0, 18,  0 }, {     61,   27,  -89,  0, 18,  0 }, {     61,   27,  -90,  0, 18,  0 }, {     61,   27,  -91,  0, 18,  0 },
    {     61,   27,  -92,  0, 18,  0 }, {     61,   27,  -93,  0, 18,  0 }, {     61,   27,  -94,  0, 18,  0 }, {     61,   27,  -95,  0, 18,  0 }, {     61,   27,  -96,  0, 18,  0 },
    {     61,   27,  -97,  0, 18,  0 }, {     61,   27,  -98,  0, 18,  0 }, {     61,   28,  -99,  0, 18,  0 }, {     61,   28, -100,  0, 18,  0 }, {     61,   28, -101,  0, 18,  0 },
    {     61,   28, -102,  0, 18,  0 }, {     61,   28, -103,  0, 18,  0 }, {     61,   28, -104,  0, 18,  0 }, {     61,   28, -105,  0, 18,  0 }, {     61,   28, -106,  0, 18,  0 },
    {     61,   28, -107,  0, 18,  0 }, {     61,   28, -108,  0, 18,  0 }, {     61,   29, -109,  0, 18,  0 }, {     61,   29, -110,  0, 18,  0 }, {     61,   29, -111,  0, 18,  0 },
    {     61,   29, -112,  0, 18,  0 }, {     61,   29, -113,  0, 18,  0 }, {     61,   29, -114,  0, 18,  0 }, {     61,   29, -115,  0, 18,  0 }, {     61,   29, -116,  0, 17,  0 },
    {     61,   29, -117,  0, 17,  0 }, {     60,   29, -118,  0, 17,  0 }, {     60,   30, -119,  0, 17,  0 }, {     60,   30, -120,  0, 17,  0 }, {     60,   30, -121,  0, 17,  0 },
    {     60,   30, -122,  0, 17,  0 }, {     60,   30, -123,  0, 17,  0 }, {     59,   30, -124,  0, 17,  0 }, {     59,   30, -125,  0, 17,  0 }, {     59,   30, -126,  0, 17,  0 },
    {     59,   30, -127,  0, 17,  0 }, {     59,   31, -128,  0, 17,  0 }, {     59,   31, -129,  0, 17,  0 }, {     58,   31, -130,  0, 17,  0 }, {     58,   31, -131,  0, 17,  0 },
    {     58,   31, -132,  0, 17,  0 }, {     58,   31, -133,  0, 17,  0 }, {     58,   31, -134,  0, 17,  0 }, {     57,   31, -135,  0, 17,  0 }, {     57,   31, -136,  0, 17,  0 },
    {     57,   31, -137,  0, 17,  0 }, {     57,   32, -138,  0, 17,  0 }, {     56,   32, -139,  0, 17,  0 }, {     56,   32, -140,  0, 17,  0 }, {     56,   32, -141,  0, 17,  0 },
    {     55,   32, -142,  0, 17,  0 }, {     55,   32, -143,  0, 17,  0 }, {     55,   32, -144,  0, 17,  0 }, {     54,   32, -145,  0, 17,  0 }, {     54,   32, -146,  0, 17,  0 },
    {     54,   32, -147,  0, 17,  0 }, {     54,   33, -148,  0, 17,  0 }, {     53,   33, -149,  0, 58,  0 }, {     53,   33, -150,  0, 58,  0 }, {     53,   33, -151,  0, 58,  0 },
    {     52,   33, -152,  0, 58,  0 }, {     52,   33, -153,  0, 58,  0 }, {     51,   33, -154,  0, 58,  0 }, {     51,   33, -155,  0, 58,  0 }, {     50,   33, -156,  0, 58,  0 },
    {     50,   34, -157,  0, 58,  0 }, {     50,   34, -158,  0, 58,  0 }, {     49,   34, -159,  0, 58,  0 }, {     49,   34, -160,  0, 58,  0 }, {     48,   34, -161,  0, 58,  0 },
    {     48,   34, -162,  0, 58,  0 }, {     48,   34, -163,  0, 58,  0 }, {     47,   34, -164,  0, 58,  0 }, {     47,   34, -165,  0, 58,  0 }, {     46,   34, -166,  0, 58,  0 },
    {     46,   35, -167,  0, 58,  0 }, {     45,   35, -168,  0, 58,  0 }, {     45,   35, -169,  0, 58,  0 }, {     45,   35, -170,  0, 58,  0 }, {     44,   35, -171,  0, 58,  0 },
    {     44,   35, -172,  0, 58,  0 }, {     43,   35, -173,  0, 58,  0 }, {     43,   35, -174,  0, 58,  0 }, {     42,   35, -175,  0, 58,  0 }, {     42,   35, -176,  0, 58,  0 },
    {     41,   36, -177,  0, 58,  0 }, {     41,   36, -178,  0, 58,  0 }, {     40,   36, -179,  0, 58,  0 }, {     39,   36, -180,  0, 58,  0 }, {     39,   36, -181,  0, 58,  0 },
    {     38,   36, -182,  0, 58,  0 }, {     38,   36, -183,  0, 58,  0 }, {     37,   36, -184,  0, 58,  0 }, {     36,   36, -185,  0, 57,  0 }, {     36,   36, -186,  0, 57,  0 },
    {     35,   37, -187,  0, 57,  0 }, {     35,   37, -188,  0, 57,  0 }, {     34,   37, -189,  0, 57,  0 }, {     33,   37, -190,  0, 57,  0 }, {     33,   37, -191,  0, 57,  0 },
    {     32,   37, -192,  0, 57,  0 }, {     31,   37, -193,  0, 57,  0 }, {     31,   37, -194,  0, 57,  0 }, {     30,   37, -195,  0, 57,  0 }, {     29,   38, -196,  0, 57,  0 },
    {     28,   38, -197,  0, 57,  0 }, {     28,   38, -198,  0, 57,  0 }, {     27,   38, -199,  0, 57,  0 }, {     26,   38, -200,  0, 57,  0 }, {     26,   38, -201,  0, 57,  0 },
    {     25,   38, -202,  0, 57,  0 }, {     24,   38, -203,  0, 57,  0 }, {     24,   38, -204,  0, 57,  0 }, {     23,   38, -205,  0, 57,  0 }, {     22,   39, -206,  0, 57,  0 },
    {     21,   39, -207,  0, 57,  0 }, {     20,   39, -208,  0, 57,  0 }, {     19,   39, -209,  0, 57,  0 }, {     18,   39, -210,  0, 57,  0 }, {     17,   39, -211,  0, 57,  0 },
    {     17,   39, -212,  0, 57,  0 }, {     16,   39, -213,  0, 57,  0 }, {     15,   39, -214,  0, 57,  0 }, {     14,   39, -215,  0, 57,  0 }, {     13,   40, -216,  0, 57,  0 },
    {     12,   40, -217,  0, 57,  0 }, {     11,   40, -218,  0, 57,  0 }, {     10,   40, -219,  0, 57,  0 }, {      9,   40, -220,  0, 57,  0 }, {      8,   40, -221,  0, 57,  0 },
    {      7,   40, -222,  0, 57,  0 }, {      6,   40, -222,  0, 57,  0 }, {      5,   40, -223,  0, 57,  0 }, {      4,   41, -224,  0, 57,  0 }, {      3,   41, -225,  0, 57,  0 },
    {      2,   41, -226,  0, 57,  0 }, {      1,   41, -227,  0, 57,  0 }, {      0,   41, -228,  0, 57,  0 }, {     -1,   41, -228,  0, 57,  0 }, {     -2,   41, -229,  0, 57,  0 },
    {     -3,   41, -230,  0, 56,  0 }, {     -4,   41, -231,  0, 56,  0 }, {     -5,   41, -231,  0, 56,  0 }, {     -6,   42, -232,  0, 56,  0 }, {     -7,   42, -233,  0, 56,  0 },
    {     -8,   42, -234,  0, 56,  0 }, {     -9,   42, -234,  0, 56,  0 }, {    -10,   42, -235,  0, 56,  0 }, {    -11,   42, -236,  0, 56,  0 }, {    -12,   42, -237,  0, 56,  0 },
    {    -13,   42, -237,  0, 56,  0 }, {    -14,   42, -238,  0, 56,  0 }, {    -15,   42, -239,  0, 56,  0 }, {    -16,   43, -239,  0, 56,  0 }, {    -17,   43, -240,  0, 56,  0 },
    {    -18,   43, -240,  0, 56,  0 }, {    -19,   43, -241,  0, 56,  0 }, {    -20,   43, -242,  0, 56,  0 }, {    -21,   43, -242,  0, 56,  0 }, {    -22,   43, -243,  0, 56,  0 },
    {    -23,   43, -243,  0, 56,  0 }, {    -24,   43, -244,  0, 56,  0 }, {    -25,   43, -245,  0, 56,  0 }, {    -26,   44, -245,  0, 56,  0 }, {    -27,   44, -246,  0, 56,  0 },
    {    -28,   44, -246,  0, 56,  0 }, {    -29,   44, -247,  0, 56,  0 }, {    -30,   44, -247,  0, 56,  0 }, {    -31,   44, -248,  0, 56,  0 }, {    -32,   44, -248,  0, 56,  0 },
    {    -33,   44, -249,  0, 56,  0 }, {    -34,   44, -249,  0, 56,  0 }, {    -35,   45, -250,  0, 56,  0 }, {    -36,   45, -250,  0, 56,  0 }, {    -37,   45, -251,  0, 56,  0 },
    {    -38,   45, -251,  0, 56,  0 }, {    -39,   45, -252,  0, 56,  0 }, {    -40,   45, -252,  0, 56,  0 }, {    -41,   45, -253,  0, 56,  0 }, {    -42,   45, -253,  0, 56,  0 },
    {    -43,   45, -254,  0, 56,  0 }, {    -44,   45, -254,  0, 56,  0 }, {    -45,   46, -255,  0, 56,  0 }, {    -46,   46, -255,  0, 56,  0 }, {    -47,   46, -256,  0, 56,  0 },
    {    -48,   46, -256,  0, 56,  0 }, {    -49,   46, -257,  0, 56,  0 }, {    -50,   46, -257,  0, 56,  0 }, {    -51,   46, -258,  0, 56,  0 }, {    -52,   46, -258,  0, 56,  0 },
    {    -53,   46, -259,  0, 56,  0 }, {    -54,   46, -259,  0, 56,  0 }, {    -55,   47, -260,  0, 56,  0 }, {    -56,   47, -260,  0, 56,  0 }, {    -57,   47, -261,  0, 56,  0 },
    {    -58,   47, -261,  0, 56,  0 }, {    -59,   47, -262,  0, 56,  0 }, {    -60,   47, -262,  0, 56,  0 }, {    -61,   47, -263,  0, 56,  0 }, {    -62,   47, -263,  0, 56,  0 },
    {    -63,   47, -264,  0, 56,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_LeftFlyerLargeHalfLoopDown3, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,   -1, 24,  0,  0 }, {     16,   22,   -1, 24,  0,  0 },
    {     17,   21,   -1, 24,  0,  0 }, {     17,   20,   -1, 24,  0,  0 }, {     17,   19,   -2, 24,  0,  0 }, {     17,   18,   -2, 24,  0,  0 }, {     17,   17,   -2, 24,  0,  0 },
    {     17,   16,   -3,  8, 23,  0 }, {     17,   15,   -3,  8, 23,  0 }, {     17,   14,   -4,  8, 23,  0 }, {     17,   13,   -4,  8, 23,  0 }, {     17,   12,   -5,  8, 23,  0 },
    {     18,   11,   -5,  8, 23,  0 }, {     18,   10,   -6,  8, 23,  0 }, {     18,    9,   -6,  8, 23,  0 }, {     18,    8,   -7,  8, 23,  0 }, {     18,    7,   -8,  8, 23,  0 },
    {     18,    6,   -8,  8, 23,  0 }, {     18,    5,   -9,  8, 23,  0 }, {     18,    4,  -10,  8, 23,  0 }, {     18,    3,  -11,  8, 23,  0 }, {     18,    2,  -11,  8, 23,  0 },
    {     19,    1,  -12,  8, 22,  0 }, {     19,    0,  -13,  8, 22,  0 }, {     19,   -1,  -14,  8, 22,  0 }, {     19,   -2,  -15,  8, 22,  0 }, {     19,   -3,  -16,  8, 22,  0 },
    {     19,   -4,  -17,  8, 22,  0 }, {     19,   -5,  -18,  8, 22,  0 }, {     19,   -6,  -19,  8, 22,  0 }, {     19,   -7,  -20,  8, 22,  0 }, {     20,   -8,  -21,  8, 22,  0 },
    {     20,   -9,  -22,  8, 22,  0 }, {     20,   -9,  -23,  8, 22,  0 }, {     20,  -10,  -24,  8, 22,  0 }, {     20,  -11,  -25,  8, 21,  0 }, {     20,  -12,  -26,  8, 21,  0 },
    {     20,  -12,  -27,  8, 21,  0 }, {     20,  -13,  -28,  8, 21,  0 }, {     20,  -14,  -29,  8, 21,  0 }, {     20,  -14,  -30,  8, 21,  0 }, {     21,  -15,  -31,  8, 21,  0 },
    {     21,  -16,  -32,  8, 21,  0 }, {     21,  -16,  -33,  8, 21,  0 }, {     21,  -17,  -34,  8, 21,  0 }, {     21,  -17,  -35,  8, 21,  0 }, {     21,  -18,  -36,  8, 21,  0 },
    {     21,  -18,  -37,  8, 21,  0 }, {     21,  -19,  -38,  8, 21,  0 }, {     21,  -19,  -39,  8, 21,  0 }, {     21,  -20,  -40,  8, 20,  0 }, {     22,  -20,  -41,  8, 20,  0 },
    {     22,  -21,  -42,  8, 20,  0 }, {     22,  -21,  -43,  8, 20,  0 }, {     22,  -22,  -44,  8, 20,  0 }, {     22,  -22,  -45,  8, 20,  0 }, {     22,  -22,  -46,  8, 20,  0 },
    {     22,  -23,  -47,  8, 20,  0 }, {     22,  -23,  -48,  8, 20,  0 }, {     22,  -23,  -49,  8, 20,  0 }, {     22,  -24,  -50,  8, 20,  0 }, {     23,  -24,  -51,  8, 20,  0 },
    {     23,  -25,  -52,  8, 20,  0 }, {     23,  -25,  -53,  8, 20,  0 }, {     23,  -25,  -54,  8, 20,  0 }, {     23,  -26,  -55,  8, 19,  0 }, {     23,  -26,  -56,  8, 19,  0 },
    {     23,  -26,  -57,  8, 19,  0 }, {     23,  -26,  -58,  8, 19,  0 }, {     23,  -27,  -59,  8, 19,  0 }, {     24,  -27,  -60,  8, 19,  0 }, {     24,  -27,  -61,  8, 19,  0 },
    {     24,  -27,  -62,  8, 19,  0 }, {     24,  -28,  -63,  8, 19,  0 }, {     24,  -28,  -64,  8, 19,  0 }, {     24,  -28,  -65,  8, 19,  0 }, {     24,  -28,  -66,  8, 19,  0 },
    {     24,  -28,  -67,  8, 19,  0 }, {     24,  -28,  -68,  8, 19,  0 }, {     24,  -29,  -69,  8, 19,  0 }, {     25,  -29,  -70,  8, 19,  0 }, {     25,  -29,  -71,  8, 19,  0 },
    {     25,  -29,  -72,  8, 19,  0 }, {     25,  -29,  -73,  8, 19,  0 }, {     25,  -29,  -74,  8, 19,  0 }, {     25,  -29,  -75,  8, 19,  0 }, {     25,  -29,  -76,  8, 19,  0 },
    {     25,  -30,  -77,  8, 19,  0 }, {     25,  -30,  -78,  8, 19,  0 }, {     25,  -30,  -79,  8, 18,  0 }, {     26,  -30,  -80,  8, 18,  0 }, {     26,  -30,  -81,  8, 18,  0 },
    {     26,  -30,  -82,  8, 18,  0 }, {     26,  -30,  -83,  8, 18,  0 }, {     26,  -30,  -84,  8, 18,  0 }, {     26,  -30,  -85,  8, 18,  0 }, {     26,  -30,  -86,  8, 18,  0 },
    {     26,  -30,  -87,  8, 18,  0 }, {     26,  -30,  -88,  8, 18,  0 }, {     27,  -30,  -89,  8, 18,  0 }, {     27,  -30,  -90,  8, 18,  0 }, {     27,  -30,  -91,  8, 18,  0 },
    {     27,  -30,  -92,  8, 18,  0 }, {     27,  -30,  -93,  8, 18,  0 }, {     27,  -30,  -94,  8, 18,  0 }, {     27,  -30,  -95,  8, 18,  0 }, {     27,  -30,  -96,  8, 18,  0 },
    {     27,  -30,  -97,  8, 18,  0 }, {     27,  -30,  -98,  8, 18,  0 }, {     28,  -30,  -99,  8, 18,  0 }, {     28,  -30, -100,  8, 18,  0 }, {     28,  -30, -101,  8, 18,  0 },
    {     28,  -30, -102,  8, 18,  0 }, {     28,  -30, -103,  8, 18,  0 }, {     28,  -30, -104,  8, 18,  0 }, {     28,  -30, -105,  8, 18,  0 }, {     28,  -30, -106,  8, 18,  0 },
    {     28,  -30, -107,  8, 18,  0 }, {     28,  -30, -108,  8, 18,  0 }, {     29,  -30, -109,  8, 18,  0 }, {     29,  -30, -110,  8, 18,  0 }, {     29,  -30, -111,  8, 18,  0 },
    {     29,  -30, -112,  8, 18,  0 }, {     29,  -30, -113,  8, 18,  0 }, {     29,  -30, -114,  8, 18,  0 }, {     29,  -30, -115,  8, 18,  0 }, {     29,  -30, -116,  8, 17,  0 },
    {     29,  -30, -117,  8, 17,  0 }, {     29,  -29, -118,  8, 17,  0 }, {     30,  -29, -119,  8, 17,  0 }, {     30,  -29, -120,  8, 17,  0 }, {     30,  -29, -121,  8, 17,  0 },
    {     30,  -29, -122,  8, 17,  0 }, {     30,  -29, -123,  8, 17,  0 }, {     30,  -28, -124,  8, 17,  0 }, {     30,  -28, -125,  8, 17,  0 }, {     30,  -28, -126,  8, 17,  0 },
    {     30,  -28, -127,  8, 17,  0 }, {     31,  -28, -128,  8, 17,  0 }, {     31,  -28, -129,  8, 17,  0 }, {     31,  -27, -130,  8, 17,  0 }, {     31,  -27, -131,  8, 17,  0 },
    {     31,  -27, -132,  8, 17,  0 }, {     31,  -27, -133,  8, 17,  0 }, {     31,  -27, -134,  8, 17,  0 }, {     31,  -26, -135,  8, 17,  0 }, {     31,  -26, -136,  8, 17,  0 },
    {     31,  -26, -137,  8, 17,  0 }, {     32,  -26, -138,  8, 17,  0 }, {     32,  -25, -139,  8, 17,  0 }, {     32,  -25, -140,  8, 17,  0 }, {     32,  -25, -141,  8, 17,  0 },
    {     32,  -24, -142,  8, 17,  0 }, {     32,  -24, -143,  8, 17,  0 }, {     32,  -24, -144,  8, 17,  0 }, {     32,  -23, -145,  8, 17,  0 }, {     32,  -23, -146,  8, 17,  0 },
    {     32,  -23, -147,  8, 17,  0 }, {     33,  -23, -148,  8, 17,  0 }, {     33,  -22, -149,  8, 58,  0 }, {     33,  -22, -150,  8, 58,  0 }, {     33,  -22, -151,  8, 58,  0 },
    {     33,  -21, -152,  8, 58,  0 }, {     33,  -21, -153,  8, 58,  0 }, {     33,  -20, -154,  8, 58,  0 }, {     33,  -20, -155,  8, 58,  0 }, {     33,  -19, -156,  8, 58,  0 },
    {     34,  -19, -157,  8, 58,  0 }, {     34,  -19, -158,  8, 58,  0 }, {     34,  -18, -159,  8, 58,  0 }, {     34,  -18, -160,  8, 58,  0 }, {     34,  -17, -161,  8, 58,  0 },
    {     34,  -17, -162,  8, 58,  0 }, {     34,  -17, -163,  8, 58,  0 }, {     34,  -16, -164,  8, 58,  0 }, {     34,  -16, -165,  8, 58,  0 }, {     34,  -15, -166,  8, 58,  0 },
    {     35,  -15, -167,  8, 58,  0 }, {     35,  -14, -168,  8, 58,  0 }, {     35,  -14, -169,  8, 58,  0 }, {     35,  -14, -170,  8, 58,  0 }, {     35,  -13, -171,  8, 58,  0 },
    {     35,  -13, -172,  8, 58,  0 }, {     35,  -12, -173,  8, 58,  0 }, {     35,  -12, -174,  8, 58,  0 }, {     35,  -11, -175,  8, 58,  0 }, {     35,  -11, -176,  8, 58,  0 },
    {     36,  -10, -177,  8, 58,  0 }, {     36,  -10, -178,  8, 58,  0 }, {     36,   -9, -179,  8, 58,  0 }, {     36,   -8, -180,  8, 58,  0 }, {     36,   -8, -181,  8, 58,  0 },
    {     36,   -7, -182,  8, 58,  0 }, {     36,   -7, -183,  8, 58,  0 }, {     36,   -6, -184,  8, 58,  0 }, {     36,   -5, -185,  8, 57,  0 }, {     36,   -5, -186,  8, 57,  0 },
    {     37,   -4, -187,  8, 57,  0 }, {     37,   -4, -188,  8, 57,  0 }, {     37,   -3, -189,  8, 57,  0 }, {     37,   -2, -190,  8, 57,  0 }, {     37,   -2, -191,  8, 57,  0 },
    {     37,   -1, -192,  8, 57,  0 }, {     37,    0, -193,  8, 57,  0 }, {     37,    0, -194,  8, 57,  0 }, {     37,    1, -195,  8, 57,  0 }, {     38,    2, -196,  8, 57,  0 },
    {     38,    3, -197,  8, 57,  0 }, {     38,    3, -198,  8, 57,  0 }, {     38,    4, -199,  8, 57,  0 }, {     38,    5, -200,  8, 57,  0 }, {     38,    5, -201,  8, 57,  0 },
    {     38,    6, -202,  8, 57,  0 }, {     38,    7, -203,  8, 57,  0 }, {     38,    7, -204,  8, 57,  0 }, {     38,    8, -205,  8, 57,  0 }, {     39,    9, -206,  8, 57,  0 },
    {     39,   10, -207,  8, 57,  0 }, {     39,   11, -208,  8, 57,  0 }, {     39,   12, -209,  8, 57,  0 }, {     39,   13, -210,  8, 57,  0 }, {     39,   14, -211,  8, 57,  0 },
    {     39,   14, -212,  8, 57,  0 }, {     39,   15, -213,  8, 57,  0 }, {     39,   16, -214,  8, 57,  0 }, {     39,   17, -215,  8, 57,  0 }, {     40,   18, -216,  8, 57,  0 },
    {     40,   19, -217,  8, 57,  0 }, {     40,   20, -218,  8, 57,  0 }, {     40,   21, -219,  8, 57,  0 }, {     40,   22, -220,  8, 57,  0 }, {     40,   23, -221,  8, 57,  0 },
    {     40,   24, -222,  8, 57,  0 }, {     40,   25, -222,  8, 57,  0 }, {     40,   26, -223,  8, 57,  0 }, {     41,   27, -224,  8, 57,  0 }, {     41,   28, -225,  8, 57,  0 },
    {     41,   29, -226,  8, 57,  0 }, {     41,   30, -227,  8, 57,  0 }, {     41,   31, -228,  8, 57,  0 }, {     41,   32, -228,  8, 57,  0 }, {     41,   33, -229,  8, 57,  0 },
    {     41,   34, -230,  8, 56,  0 }, {     41,   35, -231,  8, 56,  0 }, {     41,   36, -231,  8, 56,  0 }, {     42,   37, -232,  8, 56,  0 }, {     42,   38, -233,  8, 56,  0 },
    {     42,   39, -234,  8, 56,  0 }, {     42,   40, -234,  8, 56,  0 }, {     42,   41, -235,  8, 56,  0 }, {     42,   42, -236,  8, 56,  0 }, {     42,   43, -237,  8, 56,  0 },
    {     42,   44, -237,  8, 56,  0 }, {     42,   45, -238,  8, 56,  0 }, {     42,   46, -239,  8, 56,  0 }, {     43,   47, -239,  8, 56,  0 }, {     43,   48, -240,  8, 56,  0 },
    {     43,   49, -240,  8, 56,  0 }, {     43,   50, -241,  8, 56,  0 }, {     43,   51, -242,  8, 56,  0 }, {     43,   52, -242,  8, 56,  0 }, {     43,   53, -243,  8, 56,  0 },
    {     43,   54, -243,  8, 56,  0 }, {     43,   55, -244,  8, 56,  0 }, {     43,   56, -245,  8, 56,  0 }, {     44,   57, -245,  8, 56,  0 }, {     44,   58, -246,  8, 56,  0 },
    {     44,   59, -246,  8, 56,  0 }, {     44,   60, -247,  8, 56,  0 }, {     44,   61, -247,  8, 56,  0 }, {     44,   62, -248,  8, 56,  0 }, {     44,   63, -248,  8, 56,  0 },
    {     44,   64, -249,  8, 56,  0 }, {     44,   65, -249,  8, 56,  0 }, {     45,   66, -250,  8, 56,  0 }, {     45,   67, -250,  8, 56,  0 }, {     45,   68, -251,  8, 56,  0 },
    {     45,   69, -251,  8, 56,  0 }, {     45,   70, -252,  8, 56,  0 }, {     45,   71, -252,  8, 56,  0 }, {     45,   72, -253,  8, 56,  0 }, {     45,   73, -253,  8, 56,  0 },
    {     45,   74, -254,  8, 56,  0 }, {     45,   75, -254,  8, 56,  0 }, {     46,   76, -255,  8, 56,  0 }, {     46,   77, -255,  8, 56,  0 }, {     46,   78, -256,  8, 56,  0 },
    {     46,   79, -256,  8, 56,  0 }, {     46,   80, -257,  8, 56,  0 }, {     46,   81, -257,  8, 56,  0 }, {     46,   82, -258,  8, 56,  0 }, {     46,   83, -258,  8, 56,  0 },
    {     46,   84, -259,  8, 56,  0 }, {     46,   85, -259,  8, 56,  0 }, {     47,   86, -260,  8, 56,  0 }, {     47,   87, -260,  8, 56,  0 }, {     47,   88, -261,  8, 56,  0 },
    {     47,   89, -261,  8, 56,  0 }, {     47,   90, -262,  8, 56,  0 }, {     47,   91, -262,  8, 56,  0 }, {     47,   92, -263,  8, 56,  0 }, {     47,   93, -263,  8, 56,  0 },
    {     47,   94, -264,  8, 56,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_RightFlyerLargeHalfLoopDown0, {
    {     31,   16,    0,  0,  0,  0 }, {     30,   16,    0,  0,  0,  0 }, {     29,   16,    0,  0,  0,  0 }, {     28,   16,    0,  0,  0,  0 }, {     27,   16,    0,  0,  0,  0 },
    {     26,   16,    0,  0,  0,  0 }, {     25,   16,    0,  0,  0,  0 }, {     24,   16,    0,  0,  0,  0 }, {     23,   16,   -1,  0,  0,  0 }, {     22,   16,   -1,  0,  0,  0 },
    {     21,   17,   -1,  0,  0,  0 }, {     20,   17,   -1,  0,  0,  0 }, {     19,   17,   -2,  0,  0,  0 }, {     18,   17,   -2,  0,  0,  0 }, {     17,   17,   -2,  0,  0,  0 },
    {     16,   17,   -3, 16, 23,  0 }, {     15,   17,   -3, 16, 23,  0 }, {     14,   17,   -4, 16, 23,  0 }, {     13,   17,   -4, 16, 23,  0 }, {     12,   17,   -5, 16, 23,  0 },
    {     11,   18,   -5, 16, 23,  0 }, {     10,   18,   -6, 16, 23,  0 }, {      9,   18,   -6, 16, 23,  0 }, {      8,   18,   -7, 16, 23,  0 }, {      7,   18,   -8, 16, 23,  0 },
    {      6,   18,   -8, 16, 23,  0 }, {      5,   18,   -9, 16, 23,  0 }, {      4,   18,  -10, 16, 23,  0 }, {      3,   18,  -11, 16, 23,  0 }, {      2,   18,  -11, 16, 23,  0 },
    {      1,   19,  -12, 16, 22,  0 }, {      0,   19,  -13, 16, 22,  0 }, {     -1,   19,  -14, 16, 22,  0 }, {     -2,   19,  -15, 16, 22,  0 }, {     -3,   19,  -16, 16, 22,  0 },
    {     -4,   19,  -17, 16, 22,  0 }, {     -5,   19,  -18, 16, 22,  0 }, {     -6,   19,  -19, 16, 22,  0 }, {     -7,   19,  -20, 16, 22,  0 }, {     -8,   20,  -21, 16, 22,  0 },
    {     -9,   20,  -22, 16, 22,  0 }, {     -9,   20,  -23, 16, 22,  0 }, {    -10,   20,  -24, 16, 22,  0 }, {    -11,   20,  -25, 16, 21,  0 }, {    -12,   20,  -26, 16, 21,  0 },
    {    -12,   20,  -27, 16, 21,  0 }, {    -13,   20,  -28, 16, 21,  0 }, {    -14,   20,  -29, 16, 21,  0 }, {    -14,   20,  -30, 16, 21,  0 }, {    -15,   21,  -31, 16, 21,  0 },
    {    -16,   21,  -32, 16, 21,  0 }, {    -16,   21,  -33, 16, 21,  0 }, {    -17,   21,  -34, 16, 21,  0 }, {    -17,   21,  -35, 16, 21,  0 }, {    -18,   21,  -36, 16, 21,  0 },
    {    -18,   21,  -37, 16, 21,  0 }, {    -19,   21,  -38, 16, 21,  0 }, {    -19,   21,  -39, 16, 21,  0 }, {    -20,   21,  -40, 16, 20,  0 }, {    -20,   22,  -41, 16, 20,  0 },
    {    -21,   22,  -42, 16, 20,  0 }, {    -21,   22,  -43, 16, 20,  0 }, {    -22,   22,  -44, 16, 20,  0 }, {    -22,   22,  -45, 16, 20,  0 }, {    -22,   22,  -46, 16, 20,  0 },
    {    -23,   22,  -47, 16, 20,  0 }, {    -23,   22,  -48, 16, 20,  0 }, {    -23,   22,  -49, 16, 20,  0 }, {    -24,   22,  -50, 16, 20,  0 }, {    -24,   23,  -51, 16, 20,  0 },
    {    -25,   23,  -52, 16, 20,  0 }, {    -25,   23,  -53, 16, 20,  0 }, {    -25,   23,  -54, 16, 20,  0 }, {    -26,   23,  -55, 16, 19,  0 }, {    -26,   23,  -56, 16, 19,  0 },
    {    -26,   23,  -57, 16, 19,  0 }, {    -26,   23,  -58, 16, 19,  0 }, {    -27,   23,  -59, 16, 19,  0 }, {    -27,   24,  -60, 16, 19,  0 }, {    -27,   24,  -61, 16, 19,  0 },
    {    -27,   24,  -62, 16, 19,  0 }, {    -28,   24,  -63, 16, 19,  0 }, {    -28,   24,  -64, 16, 19,  0 }, {    -28,   24,  -65, 16, 19,  0 }, {    -28,   24,  -66, 16, 19,  0 },
    {    -28,   24,  -67, 16, 19,  0 }, {    -28,   24,  -68, 16, 19,  0 }, {    -29,   24,  -69, 16, 19,  0 }, {    -29,   25,  -70, 16, 19,  0 }, {    -29,   25,  -71, 16, 19,  0 },
    {    -29,   25,  -72, 16, 19,  0 }, {    -29,   25,  -73, 16, 19,  0 }, {    -29,   25,  -74, 16, 19,  0 }, {    -29,   25,  -75, 16, 19,  0 }, {    -29,   25,  -76, 16, 19,  0 },
    {    -30,   25,  -77, 16, 19,  0 }, {    -30,   25,  -78, 16, 19,  0 }, {    -30,   25,  -79, 16, 18,  0 }, {    -30,   26,  -80, 16, 18,  0 }, {    -30,   26,  -81, 16, 18,  0 },
    {    -30,   26,  -82, 16, 18,  0 }, {    -30,   26,  -83, 16, 18,  0 }, {    -30,   26,  -84, 16, 18,  0 }, {    -30,   26,  -85, 16, 18,  0 }, {    -30,   26,  -86, 16, 18,  0 },
    {    -30,   26,  -87, 16, 18,  0 }, {    -30,   26,  -88, 16, 18,  0 }, {    -30,   27,  -89, 16, 18,  0 }, {    -30,   27,  -90, 16, 18,  0 }, {    -30,   27,  -91, 16, 18,  0 },
    {    -30,   27,  -92, 16, 18,  0 }, {    -30,   27,  -93, 16, 18,  0 }, {    -30,   27,  -94, 16, 18,  0 }, {    -30,   27,  -95, 16, 18,  0 }, {    -30,   27,  -96, 16, 18,  0 },
    {    -30,   27,  -97, 16, 18,  0 }, {    -30,   27,  -98, 16, 18,  0 }, {    -30,   28,  -99, 16, 18,  0 }, {    -30,   28, -100, 16, 18,  0 }, {    -30,   28, -101, 16, 18,  0 },
    {    -30,   28, -102, 16, 18,  0 }, {    -30,   28, -103, 16, 18,  0 }, {    -30,   28, -104, 16, 18,  0 }, {    -30,   28, -105, 16, 18,  0 }, {    -30,   28, -106, 16, 18,  0 },
    {    -30,   28, -107, 16, 18,  0 }, {    -30,   28, -108, 16, 18,  0 }, {    -30,   29, -109, 16, 18,  0 }, {    -30,   29, -110, 16, 18,  0 }, {    -30,   29, -111, 16, 18,  0 },
    {    -30,   29, -112, 16, 18,  0 }, {    -30,   29, -113, 16, 18,  0 }, {    -30,   29, -114, 16, 18,  0 }, {    -30,   29, -115, 16, 18,  0 }, {    -30,   29, -116, 16, 17,  0 },
    {    -30,   29, -117, 16, 17,  0 }, {    -29,   29, -118, 16, 17,  0 }, {    -29,   30, -119, 16, 17,  0 }, {    -29,   30, -120, 16, 17,  0 }, {    -29,   30, -121, 16, 17,  0 },
    {    -29,   30, -122, 16, 17,  0 }, {    -29,   30, -123, 16, 17,  0 }, {    -28,   30, -124, 16, 17,  0 }, {    -28,   30, -125, 16, 17,  0 }, {    -28,   30, -126, 16, 17,  0 },
    {    -28,   30, -127, 16, 17,  0 }, {    -28,   31, -128, 16, 17,  0 }, {    -28,   31, -129, 16, 17,  0 }, {    -27,   31, -130, 16, 17,  0 }, {    -27,   31, -131, 16, 17,  0 },
    {    -27,   31, -132, 16, 17,  0 }, {    -27,   31, -133, 16, 17,  0 }, {    -27,   31, -134, 16, 17,  0 }, {    -26,   31, -135, 16, 17,  0 }, {    -26,   31, -136, 16, 17,  0 },
    {    -26,   31, -137, 16, 17,  0 }, {    -26,   32, -138, 16, 17,  0 }, {    -25,   32, -139, 16, 17,  0 }, {    -25,   32, -140, 16, 17,  0 }, {    -25,   32, -141, 16, 17,  0 },
    {    -24,   32, -142, 16, 17,  0 }, {    -24,   32, -143, 16, 17,  0 }, {    -24,   32, -144, 16, 17,  0 }, {    -23,   32, -145, 16, 17,  0 }, {    -23,   32, -146, 16, 17,  0 },
    {    -23,   32, -147, 16, 17,  0 }, {    -23,   33, -148, 16, 17,  0 }, {    -22,   33, -149, 16, 58,  0 }, {    -22,   33, -150, 16, 58,  0 }, {    -22,   33, -151, 16, 58,  0 },
    {    -21,   33, -152, 16, 58,  0 }, {    -21,   33, -153, 16, 58,  0 }, {    -20,   33, -154, 16, 58,  0 }, {    -20,   33, -155, 16, 58,  0 }, {    -19,   33, -156, 16, 58,  0 },
    {    -19,   34, -157, 16, 58,  0 }, {    -19,   34, -158, 16, 58,  0 }, {    -18,   34, -159, 16, 58,  0 }, {    -18,   34, -160, 16, 58,  0 }, {    -17,   34, -161, 16, 58,  0 },
    {    -17,   34, -162, 16, 58,  0 }, {    -17,   34, -163, 16, 58,  0 }, {    -16,   34, -164, 16, 58,  0 }, {    -16,   34, -165, 16, 58,  0 }, {    -15,   34, -166, 16, 58,  0 },
    {    -15,   35, -167, 16, 58,  0 }, {    -14,   35, -168, 16, 58,  0 }, {    -14,   35, -169, 16, 58,  0 }, {    -14,   35, -170, 16, 58,  0 }, {    -13,   35, -171, 16, 58,  0 },
    {    -13,   35, -172, 16, 58,  0 }, {    -12,   35, -173, 16, 58,  0 }, {    -12,   35, -174, 16, 58,  0 }, {    -11,   35, -175, 16, 58,  0 }, {    -11,   35, -176, 16, 58,  0 },
    {    -10,   36, -177, 16, 58,  0 }, {    -10,   36, -178, 16, 58,  0 }, {     -9,   36, -179, 16, 58,  0 }, {     -8,   36, -180, 16, 58,  0 }, {     -8,   36, -181, 16, 58,  0 },
    {     -7,   36, -182, 16, 58,  0 }, {     -7,   36, -183, 16, 58,  0 }, {     -6,   36, -184, 16, 58,  0 }, {     -5,   36, -185, 16, 57,  0 }, {     -5,   36, -186, 16, 57,  0 },
    {     -4,   37, -187, 16, 57,  0 }, {     -4,   37, -188, 16, 57,  0 }, {     -3,   37, -189, 16, 57,  0 }, {     -2,   37, -190, 16, 57,  0 }, {     -2,   37, -191, 16, 57,  0 },
    {     -1,   37, -192, 16, 57,  0 }, {      0,   37, -193, 16, 57,  0 }, {      0,   37, -194, 16, 57,  0 }, {      1,   37, -195, 16, 57,  0 }, {      2,   38, -196, 16, 57,  0 },
    {      3,   38, -197, 16, 57,  0 }, {      3,   38, -198, 16, 57,  0 }, {      4,   38, -199, 16, 57,  0 }, {      5,   38, -200, 16, 57,  0 }, {      5,   38, -201, 16, 57,  0 },
    {      6,   38, -202, 16, 57,  0 }, {      7,   38, -203, 16, 57,  0 }, {      7,   38, -204, 16, 57,  0 }, {      8,   38, -205, 16, 57,  0 }, {      9,   39, -206, 16, 57,  0 },
    {     10,   39, -207, 16, 57,  0 }, {     11,   39, -208, 16, 57,  0 }, {     12,   39, -209, 16, 57,  0 }, {     13,   39, -210, 16, 57,  0 }, {     14,   39, -211, 16, 57,  0 },
    {     14,   39, -212, 16, 57,  0 }, {     15,   39, -213, 16, 57,  0 }, {     16,   39, -214, 16, 57,  0 }, {     17,   39, -215, 16, 57,  0 }, {     18,   40, -216, 16, 57,  0 },
    {     19,   40, -217, 16, 57,  0 }, {     20,   40, -218, 16, 57,  0 }, {     21,   40, -219, 16, 57,  0 }, {     22,   40, -220, 16, 57,  0 }, {     23,   40, -221, 16, 57,  0 },
    {     24,   40, -222, 16, 57,  0 }, {     25,   40, -222, 16, 57,  0 }, {     26,   40, -223, 16, 57,  0 }, {     27,   41, -224, 16, 57,  0 }, {     28,   41, -225, 16, 57,  0 },
    {     29,   41, -226, 16, 57,  0 }, {     30,   41, -227, 16, 57,  0 }, {     31,   41, -228, 16, 57,  0 }, {     32,   41, -228, 16, 57,  0 }, {     33,   41, -229, 16, 57,  0 },
    {     34,   41, -230, 16, 56,  0 }, {     35,   41, -231, 16, 56,  0 }, {     36,   41, -231, 16, 56,  0 }, {     37,   42, -232, 16, 56,  0 }, {     38,   42, -233, 16, 56,  0 },
    {     39,   42, -234, 16, 56,  0 }, {     40,   42, -234, 16, 56,  0 }, {     41,   42, -235, 16, 56,  0 }, {     42,   42, -236, 16, 56,  0 }, {     43,   42, -237, 16, 56,  0 },
    {     44,   42, -237, 16, 56,  0 }, {     45,   42, -238, 16, 56,  0 }, {     46,   42, -239, 16, 56,  0 }, {     47,   43, -239, 16, 56,  0 }, {     48,   43, -240, 16, 56,  0 },
    {     49,   43, -240, 16, 56,  0 }, {     50,   43, -241, 16, 56,  0 }, {     51,   43, -242, 16, 56,  0 }, {     52,   43, -242, 16, 56,  0 }, {     53,   43, -243, 16, 56,  0 },
    {     54,   43, -243, 16, 56,  0 }, {     55,   43, -244, 16, 56,  0 }, {     56,   43, -245, 16, 56,  0 }, {     57,   44, -245, 16, 56,  0 }, {     58,   44, -246, 16, 56,  0 },
    {     59,   44, -246, 16, 56,  0 }, {     60,   44, -247, 16, 56,  0 }, {     61,   44, -247, 16, 56,  0 }, {     62,   44, -248, 16, 56,  0 }, {     63,   44, -248, 16, 56,  0 },
    {     64,   44, -249, 16, 56,  0 }, {     65,   44, -249, 16, 56,  0 }, {     66,   45, -250, 16, 56,  0 }, {     67,   45, -250, 16, 56,  0 }, {     68,   45, -251, 16, 56,  0 },
    {     69,   45, -251, 16, 56,  0 }, {     70,   45, -252, 16, 56,  0 }, {     71,   45, -252, 16, 56,  0 }, {     72,   45, -253, 16, 56,  0 }, {     73,   45, -253, 16, 56,  0 },
    {     74,   45, -254, 16, 56,  0 }, {     75,   45, -254, 16, 56,  0 }, {     76,   46, -255, 16, 56,  0 }, {     77,   46, -255, 16, 56,  0 }, {     78,   46, -256, 16, 56,  0 },
    {     79,   46, -256, 16, 56,  0 }, {     80,   46, -257, 16, 56,  0 }, {     81,   46, -257, 16, 56,  0 }, {     82,   46, -258, 16, 56,  0 }, {     83,   46, -258, 16, 56,  0 },
    {     84,   46, -259, 16, 56,  0 }, {     85,   46, -259, 16, 56,  0 }, {     86,   47, -260, 16, 56,  0 }, {     87,   47, -260, 16, 56,  0 }, {     88,   47, -261, 16, 56,  0 },
    {     89,   47, -261, 16, 56,  0 }, {     90,   47, -262, 16, 56,  0 }, {     91,   47, -262, 16, 56,  0 }, {     92,   47, -263, 16, 56,  0 }, {     93,   47, -263, 16, 56,  0 },
    {     94,   47, -264, 16, 56,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_RightFlyerLargeHalfLoopDown1, {
    {     16,    0,    0,  8,  0,  0 }, {     16,    1,    0,  8,  0,  0 }, {     16,    2,    0,  8,  0,  0 }, {     16,    3,    0,  8,  0,  0 }, {     16,    4,    0,  8,  0,  0 },
    {     16,    5,    0,  8,  0,  0 }, {     16,    6,    0,  8,  0,  0 }, {     16,    7,    0,  8,  0,  0 }, {     16,    8,   -1,  8,  0,  0 }, {     16,    9,   -1,  8,  0,  0 },
    {     17,   10,   -1,  8,  0,  0 }, {     17,   11,   -1,  8,  0,  0 }, {     17,   12,   -2,  8,  0,  0 }, {     17,   13,   -2,  8,  0,  0 }, {     17,   14,   -2,  8,  0,  0 },
    {     17,   15,   -3, 24, 23,  0 }, {     17,   16,   -3, 24, 23,  0 }, {     17,   17,   -4, 24, 23,  0 }, {     17,   18,   -4, 24, 23,  0 }, {     17,   19,   -5, 24, 23,  0 },
    {     18,   20,   -5, 24, 23,  0 }, {     18,   21,   -6, 24, 23,  0 }, {     18,   22,   -6, 24, 23,  0 }, {     18,   23,   -7, 24, 23,  0 }, {     18,   24,   -8, 24, 23,  0 },
    {     18,   25,   -8, 24, 23,  0 }, {     18,   26,   -9, 24, 23,  0 }, {     18,   27,  -10, 24, 23,  0 }, {     18,   28,  -11, 24, 23,  0 }, {     18,   29,  -11, 24, 23,  0 },
    {     19,   30,  -12, 24, 22,  0 }, {     19,   31,  -13, 24, 22,  0 }, {     19,   32,  -14, 24, 22,  0 }, {     19,   33,  -15, 24, 22,  0 }, {     19,   34,  -16, 24, 22,  0 },
    {     19,   35,  -17, 24, 22,  0 }, {     19,   36,  -18, 24, 22,  0 }, {     19,   37,  -19, 24, 22,  0 }, {     19,   38,  -20, 24, 22,  0 }, {     20,   39,  -21, 24, 22,  0 },
    {     20,   40,  -22, 24, 22,  0 }, {     20,   40,  -23, 24, 22,  0 }, {     20,   41,  -24, 24, 22,  0 }, {     20,   42,  -25, 24, 21,  0 }, {     20,   43,  -26, 24, 21,  0 },
    {     20,   43,  -27, 24, 21,  0 }, {     20,   44,  -28, 24, 21,  0 }, {     20,   45,  -29, 24, 21,  0 }, {     20,   45,  -30, 24, 21,  0 }, {     21,   46,  -31, 24, 21,  0 },
    {     21,   47,  -32, 24, 21,  0 }, {     21,   47,  -33, 24, 21,  0 }, {     21,   48,  -34, 24, 21,  0 }, {     21,   48,  -35, 24, 21,  0 }, {     21,   49,  -36, 24, 21,  0 },
    {     21,   49,  -37, 24, 21,  0 }, {     21,   50,  -38, 24, 21,  0 }, {     21,   50,  -39, 24, 21,  0 }, {     21,   51,  -40, 24, 20,  0 }, {     22,   51,  -41, 24, 20,  0 },
    {     22,   52,  -42, 24, 20,  0 }, {     22,   52,  -43, 24, 20,  0 }, {     22,   53,  -44, 24, 20,  0 }, {     22,   53,  -45, 24, 20,  0 }, {     22,   53,  -46, 24, 20,  0 },
    {     22,   54,  -47, 24, 20,  0 }, {     22,   54,  -48, 24, 20,  0 }, {     22,   54,  -49, 24, 20,  0 }, {     22,   55,  -50, 24, 20,  0 }, {     23,   55,  -51, 24, 20,  0 },
    {     23,   56,  -52, 24, 20,  0 }, {     23,   56,  -53, 24, 20,  0 }, {     23,   56,  -54, 24, 20,  0 }, {     23,   57,  -55, 24, 19,  0 }, {     23,   57,  -56, 24, 19,  0 },
    {     23,   57,  -57, 24, 19,  0 }, {     23,   57,  -58, 24, 19,  0 }, {     23,   58,  -59, 24, 19,  0 }, {     24,   58,  -60, 24, 19,  0 }, {     24,   58,  -61, 24, 19,  0 },
    {     24,   58,  -62, 24, 19,  0 }, {     24,   59,  -63, 24, 19,  0 }, {     24,   59,  -64, 24, 19,  0 }, {     24,   59,  -65, 24, 19,  0 }, {     24,   59,  -66, 24, 19,  0 },
    {     24,   59,  -67, 24, 19,  0 }, {     24,   59,  -68, 24, 19,  0 }, {     24,   60,  -69, 24, 19,  0 }, {     25,   60,  -70, 24, 19,  0 }, {     25,   60,  -71, 24, 19,  0 },
    {     25,   60,  -72, 24, 19,  0 }, {     25,   60,  -73, 24, 19,  0 }, {     25,   60,  -74, 24, 19,  0 }, {     25,   60,  -75, 24, 19,  0 }, {     25,   60,  -76, 24, 19,  0 },
    {     25,   61,  -77, 24, 19,  0 }, {     25,   61,  -78, 24, 19,  0 }, {     25,   61,  -79, 24, 18,  0 }, {     26,   61,  -80, 24, 18,  0 }, {     26,   61,  -81, 24, 18,  0 },
    {     26,   61,  -82, 24, 18,  0 }, {     26,   61,  -83, 24, 18,  0 }, {     26,   61,  -84, 24, 18,  0 }, {     26,   61,  -85, 24, 18,  0 }, {     26,   61,  -86, 24, 18,  0 },
    {     26,   61,  -87, 24, 18,  0 }, {     26,   61,  -88, 24, 18,  0 }, {     27,   61,  -89, 24, 18,  0 }, {     27,   61,  -90, 24, 18,  0 }, {     27,   61,  -91, 24, 18,  0 },
    {     27,   61,  -92, 24, 18,  0 }, {     27,   61,  -93, 24, 18,  0 }, {     27,   61,  -94, 24, 18,  0 }, {     27,   61,  -95, 24, 18,  0 }, {     27,   61,  -96, 24, 18,  0 },
    {     27,   61,  -97, 24, 18,  0 }, {     27,   61,  -98, 24, 18,  0 }, {     28,   61,  -99, 24, 18,  0 }, {     28,   61, -100, 24, 18,  0 }, {     28,   61, -101, 24, 18,  0 },
    {     28,   61, -102, 24, 18,  0 }, {     28,   61, -103, 24, 18,  0 }, {     28,   61, -104, 24, 18,  0 }, {     28,   61, -105, 24, 18,  0 }, {     28,   61, -106, 24, 18,  0 },
    {     28,   61, -107, 24, 18,  0 }, {     28,   61, -108, 24, 18,  0 }, {     29,   61, -109, 24, 18,  0 }, {     29,   61, -110, 24, 18,  0 }, {     29,   61, -111, 24, 18,  0 },
    {     29,   61, -112, 24, 18,  0 }, {     29,   61, -113, 24, 18,  0 }, {     29,   61, -114, 24, 18,  0 }, {     29,   61, -115, 24, 18,  0 }, {     29,   61, -116, 24, 17,  0 },
    {     29,   61, -117, 24, 17,  0 }, {     29,   60, -118, 24, 17,  0 }, {     30,   60, -119, 24, 17,  0 }, {     30,   60, -120, 24, 17,  0 }, {     30,   60, -121, 24, 17,  0 },
    {     30,   60, -122, 24, 17,  0 }, {     30,   60, -123, 24, 17,  0 }, {     30,   59, -124, 24, 17,  0 }, {     30,   59, -125, 24, 17,  0 }, {     30,   59, -126, 24, 17,  0 },
    {     30,   59, -127, 24, 17,  0 }, {     31,   59, -128, 24, 17,  0 }, {     31,   59, -129, 24, 17,  0 }, {     31,   58, -130, 24, 17,  0 }, {     31,   58, -131, 24, 17,  0 },
    {     31,   58, -132, 24, 17,  0 }, {     31,   58, -133, 24, 17,  0 }, {     31,   58, -134, 24, 17,  0 }, {     31,   57, -135, 24, 17,  0 }, {     31,   57, -136, 24, 17,  0 },
    {     31,   57, -137, 24, 17,  0 }, {     32,   57, -138, 24, 17,  0 }, {     32,   56, -139, 24, 17,  0 }, {     32,   56, -140, 24, 17,  0 }, {     32,   56, -141, 24, 17,  0 },
    {     32,   55, -142, 24, 17,  0 }, {     32,   55, -143, 24, 17,  0 }, {     32,   55, -144, 24, 17,  0 }, {     32,   54, -145, 24, 17,  0 }, {     32,   54, -146, 24, 17,  0 },
    {     32,   54, -147, 24, 17,  0 }, {     33,   54, -148, 24, 17,  0 }, {     33,   53, -149, 24, 58,  0 }, {     33,   53, -150, 24, 58,  0 }, {     33,   53, -151, 24, 58,  0 },
    {     33,   52, -152, 24, 58,  0 }, {     33,   52, -153, 24, 58,  0 }, {     33,   51, -154, 24, 58,  0 }, {     33,   51, -155, 24, 58,  0 }, {     33,   50, -156, 24, 58,  0 },
    {     34,   50, -157, 24, 58,  0 }, {     34,   50, -158, 24, 58,  0 }, {     34,   49, -159, 24, 58,  0 }, {     34,   49, -160, 24, 58,  0 }, {     34,   48, -161, 24, 58,  0 },
    {     34,   48, -162, 24, 58,  0 }, {     34,   48, -163, 24, 58,  0 }, {     34,   47, -164, 24, 58,  0 }, {     34,   47, -165, 24, 58,  0 }, {     34,   46, -166, 24, 58,  0 },
    {     35,   46, -167, 24, 58,  0 }, {     35,   45, -168, 24, 58,  0 }, {     35,   45, -169, 24, 58,  0 }, {     35,   45, -170, 24, 58,  0 }, {     35,   44, -171, 24, 58,  0 },
    {     35,   44, -172, 24, 58,  0 }, {     35,   43, -173, 24, 58,  0 }, {     35,   43, -174, 24, 58,  0 }, {     35,   42, -175, 24, 58,  0 }, {     35,   42, -176, 24, 58,  0 },
    {     36,   41, -177, 24, 58,  0 }, {     36,   41, -178, 24, 58,  0 }, {     36,   40, -179, 24, 58,  0 }, {     36,   39, -180, 24, 58,  0 }, {     36,   39, -181, 24, 58,  0 },
    {     36,   38, -182, 24, 58,  0 }, {     36,   38, -183, 24, 58,  0 }, {     36,   37, -184, 24, 58,  0 }, {     36,   36, -185, 24, 57,  0 }, {     36,   36, -186, 24, 57,  0 },
    {     37,   35, -187, 24, 57,  0 }, {     37,   35, -188, 24, 57,  0 }, {     37,   34, -189, 24, 57,  0 }, {     37,   33, -190, 24, 57,  0 }, {     37,   33, -191, 24, 57,  0 },
    {     37,   32, -192, 24, 57,  0 }, {     37,   31, -193, 24, 57,  0 }, {     37,   31, -194, 24, 57,  0 }, {     37,   30, -195, 24, 57,  0 }, {     38,   29, -196, 24, 57,  0 },
    {     38,   28, -197, 24, 57,  0 }, {     38,   28, -198, 24, 57,  0 }, {     38,   27, -199, 24, 57,  0 }, {     38,   26, -200, 24, 57,  0 }, {     38,   26, -201, 24, 57,  0 },
    {     38,   25, -202, 24, 57,  0 }, {     38,   24, -203, 24, 57,  0 }, {     38,   24, -204, 24, 57,  0 }, {     38,   23, -205, 24, 57,  0 }, {     39,   22, -206, 24, 57,  0 },
    {     39,   21, -207, 24, 57,  0 }, {     39,   20, -208, 24, 57,  0 }, {     39,   19, -209, 24, 57,  0 }, {     39,   18, -210, 24, 57,  0 }, {     39,   17, -211, 24, 57,  0 },
    {     39,   17, -212, 24, 57,  0 }, {     39,   16, -213, 24, 57,  0 }, {     39,   15, -214, 24, 57,  0 }, {     39,   14, -215, 24, 57,  0 }, {     40,   13, -216, 24, 57,  0 },
    {     40,   12, -217, 24, 57,  0 }, {     40,   11, -218, 24, 57,  0 }, {     40,   10, -219, 24, 57,  0 }, {     40,    9, -220, 24, 57,  0 }, {     40,    8, -221, 24, 57,  0 },
    {     40,    7, -222, 24, 57,  0 }, {     40,    6, -222, 24, 57,  0 }, {     40,    5, -223, 24, 57,  0 }, {     41,    4, -224, 24, 57,  0 }, {     41,    3, -225, 24, 57,  0 },
    {     41,    2, -226, 24, 57,  0 }, {     41,    1, -227, 24, 57,  0 }, {     41,    0, -228, 24, 57,  0 }, {     41,   -1, -228, 24, 57,  0 }, {     41,   -2, -229, 24, 57,  0 },
    {     41,   -3, -230, 24, 56,  0 }, {     41,   -4, -231, 24, 56,  0 }, {     41,   -5, -231, 24, 56,  0 }, {     42,   -6, -232, 24, 56,  0 }, {     42,   -7, -233, 24, 56,  0 },
    {     42,   -8, -234, 24, 56,  0 }, {     42,   -9, -234, 24, 56,  0 }, {     42,  -10, -235, 24, 56,  0 }, {     42,  -11, -236, 24, 56,  0 }, {     42,  -12, -237, 24, 56,  0 },
    {     42,  -13, -237, 24, 56,  0 }, {     42,  -14, -238, 24, 56,  0 }, {     42,  -15, -239, 24, 56,  0 }, {     43,  -16, -239, 24, 56,  0 }, {     43,  -17, -240, 24, 56,  0 },
    {     43,  -18, -240, 24, 56,  0 }, {     43,  -19, -241, 24, 56,  0 }, {     43,  -20, -242, 24, 56,  0 }, {     43,  -21, -242, 24, 56,  0 }, {     43,  -22, -243, 24, 56,  0 },
    {     43,  -23, -243, 24, 56,  0 }, {     43,  -24, -244, 24, 56,  0 }, {     43,  -25, -245, 24, 56,  0 }, {     44,  -26, -245, 24, 56,  0 }, {     44,  -27, -246, 24, 56,  0 },
    {     44,  -28, -246, 24, 56,  0 }, {     44,  -29, -247, 24, 56,  0 }, {     44,  -30, -247, 24, 56,  0 }, {     44,  -31, -248, 24, 56,  0 }, {     44,  -32, -248, 24, 56,  0 },
    {     44,  -33, -249, 24, 56,  0 }, {     44,  -34, -249, 24, 56,  0 }, {     45,  -35, -250, 24, 56,  0 }, {     45,  -36, -250, 24, 56,  0 }, {     45,  -37, -251, 24, 56,  0 },
    {     45,  -38, -251, 24, 56,  0 }, {     45,  -39, -252, 24, 56,  0 }, {     45,  -40, -252, 24, 56,  0 }, {     45,  -41, -253, 24, 56,  0 }, {     45,  -42, -253, 24, 56,  0 },
    {     45,  -43, -254, 24, 56,  0 }, {     45,  -44, -254, 24, 56,  0 }, {     46,  -45, -255, 24, 56,  0 }, {     46,  -46, -255, 24, 56,  0 }, {     46,  -47, -256, 24, 56,  0 },
    {     46,  -48, -256, 24, 56,  0 }, {     46,  -49, -257, 24, 56,  0 }, {     46,  -50, -257, 24, 56,  0 }, {     46,  -51, -258, 24, 56,  0 }, {     46,  -52, -258, 24, 56,  0 },
    {     46,  -53, -259, 24, 56,  0 }, {     46,  -54, -259, 24, 56,  0 }, {     47,  -55, -260, 24, 56,  0 }, {     47,  -56, -260, 24, 56,  0 }, {     47,  -57, -261, 24, 56,  0 },
    {     47,  -58, -261, 24, 56,  0 }, {     47,  -59, -262, 24, 56,  0 }, {     47,  -60, -262, 24, 56,  0 }, {     47,  -61, -263, 24, 56,  0 }, {     47,  -62, -263, 24, 56,  0 },
    {     47,  -63, -264, 24, 56,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_RightFlyerLargeHalfLoopDown2, {
    {      0,   16,    0, 16,  0,  0 }, {      1,   16,    0, 16,  0,  0 }, {      2,   16,    0, 16,  0,  0 }, {      3,   16,    0, 16,  0,  0 }, {      4,   16,    0, 16,  0,  0 },
    {      5,   16,    0, 16,  0,  0 }, {      6,   16,    0, 16,  0,  0 }, {      7,   16,    0, 16,  0,  0 }, {      8,   16,   -1, 16,  0,  0 }, {      9,   16,   -1, 16,  0,  0 },
    {     10,   15,   -1, 16,  0,  0 }, {     11,   15,   -1, 16,  0,  0 }, {     12,   15,   -2, 16,  0,  0 }, {     13,   15,   -2, 16,  0,  0 }, {     14,   15,   -2, 16,  0,  0 },
    {     15,   15,   -3,  0, 23,  0 }, {     16,   15,   -3,  0, 23,  0 }, {     17,   15,   -4,  0, 23,  0 }, {     18,   15,   -4,  0, 23,  0 }, {     19,   15,   -5,  0, 23,  0 },
    {     20,   14,   -5,  0, 23,  0 }, {     21,   14,   -6,  0, 23,  0 }, {     22,   14,   -6,  0, 23,  0 }, {     23,   14,   -7,  0, 23,  0 }, {     24,   14,   -8,  0, 23,  0 },
    {     25,   14,   -8,  0, 23,  0 }, {     26,   14,   -9,  0, 23,  0 }, {     27,   14,  -10,  0, 23,  0 }, {     28,   14,  -11,  0, 23,  0 }, {     29,   14,  -11,  0, 23,  0 },
    {     30,   13,  -12,  0, 22,  0 }, {     31,   13,  -13,  0, 22,  0 }, {     32,   13,  -14,  0, 22,  0 }, {     33,   13,  -15,  0, 22,  0 }, {     34,   13,  -16,  0, 22,  0 },
    {     35,   13,  -17,  0, 22,  0 }, {     36,   13,  -18,  0, 22,  0 }, {     37,   13,  -19,  0, 22,  0 }, {     38,   13,  -20,  0, 22,  0 }, {     39,   12,  -21,  0, 22,  0 },
    {     40,   12,  -22,  0, 22,  0 }, {     40,   12,  -23,  0, 22,  0 }, {     41,   12,  -24,  0, 22,  0 }, {     42,   12,  -25,  0, 21,  0 }, {     43,   12,  -26,  0, 21,  0 },
    {     43,   12,  -27,  0, 21,  0 }, {     44,   12,  -28,  0, 21,  0 }, {     45,   12,  -29,  0, 21,  0 }, {     45,   12,  -30,  0, 21,  0 }, {     46,   11,  -31,  0, 21,  0 },
    {     47,   11,  -32,  0, 21,  0 }, {     47,   11,  -33,  0, 21,  0 }, {     48,   11,  -34,  0, 21,  0 }, {     48,   11,  -35,  0, 21,  0 }, {     49,   11,  -36,  0, 21,  0 },
    {     49,   11,  -37,  0, 21,  0 }, {     50,   11,  -38,  0, 21,  0 }, {     50,   11,  -39,  0, 21,  0 }, {     51,   11,  -40,  0, 20,  0 }, {     51,   10,  -41,  0, 20,  0 },
    {     52,   10,  -42,  0, 20,  0 }, {     52,   10,  -43,  0, 20,  0 }, {     53,   10,  -44,  0, 20,  0 }, {     53,   10,  -45,  0, 20,  0 }, {     53,   10,  -46,  0, 20,  0 },
    {     54,   10,  -47,  0, 20,  0 }, {     54,   10,  -48,  0, 20,  0 }, {     54,   10,  -49,  0, 20,  0 }, {     55,   10,  -50,  0, 20,  0 }, {     55,    9,  -51,  0, 20,  0 },
    {     56,    9,  -52,  0, 20,  0 }, {     56,    9,  -53,  0, 20,  0 }, {     56,    9,  -54,  0, 20,  0 }, {     57,    9,  -55,  0, 19,  0 }, {     57,    9,  -56,  0, 19,  0 },
    {     57,    9,  -57,  0, 19,  0 }, {     57,    9,  -58,  0, 19,  0 }, {     58,    9,  -59,  0, 19,  0 }, {     58,    8,  -60,  0, 19,  0 }, {     58,    8,  -61,  0, 19,  0 },
    {     58,    8,  -62,  0, 19,  0 }, {     59,    8,  -63,  0, 19,  0 }, {     59,    8,  -64,  0, 19,  0 }, {     59,    8,  -65,  0, 19,  0 }, {     59,    8,  -66,  0, 19,  0 },
    {     59,    8,  -67,  0, 19,  0 }, {     59,    8,  -68,  0, 19,  0 }, {     60,    8,  -69,  0, 19,  0 }, {     60,    7,  -70,  0, 19,  0 }, {     60,    7,  -71,  0, 19,  0 },
    {     60,    7,  -72,  0, 19,  0 }, {     60,    7,  -73,  0, 19,  0 }, {     60,    7,  -74,  0, 19,  0 }, {     60,    7,  -75,  0, 19,  0 }, {     60,    7,  -76,  0, 19,  0 },
    {     61,    7,  -77,  0, 19,  0 }, {     61,    7,  -78,  0, 19,  0 }, {     61,    7,  -79,  0, 18,  0 }, {     61,    6,  -80,  0, 18,  0 }, {     61,    6,  -81,  0, 18,  0 },
    {     61,    6,  -82,  0, 18,  0 }, {     61,    6,  -83,  0, 18,  0 }, {     61,    6,  -84,  0, 18,  0 }, {     61,    6,  -85,  0, 18,  0 }, {     61,    6,  -86,  0, 18,  0 },
    {     61,    6,  -87,  0, 18,  0 }, {     61,    6,  -88,  0, 18,  0 }, {     61,    5,  -89,  0, 18,  0 }, {     61,    5,  -90,  0, 18,  0 }, {     61,    5,  -91,  0, 18,  0 },
    {     61,    5,  -92,  0, 18,  0 }, {     61,    5,  -93,  0, 18,  0 }, {     61,    5,  -94,  0, 18,  0 }, {     61,    5,  -95,  0, 18,  0 }, {     61,    5,  -96,  0, 18,  0 },
    {     61,    5,  -97,  0, 18,  0 }, {     61,    5,  -98,  0, 18,  0 }, {     61,    4,  -99,  0, 18,  0 }, {     61,    4, -100,  0, 18,  0 }, {     61,    4, -101,  0, 18,  0 },
    {     61,    4, -102,  0, 18,  0 }, {     61,    4, -103,  0, 18,  0 }, {     61,    4, -104,  0, 18,  0 }, {     61,    4, -105,  0, 18,  0 }, {     61,    4, -106,  0, 18,  0 },
    {     61,    4, -107,  0, 18,  0 }, {     61,    4, -108,  0, 18,  0 }, {     61,    3, -109,  0, 18,  0 }, {     61,    3, -110,  0, 18,  0 }, {     61,    3, -111,  0, 18,  0 },
    {     61,    3, -112,  0, 18,  0 }, {     61,    3, -113,  0, 18,  0 }, {     61,    3, -114,  0, 18,  0 }, {     61,    3, -115,  0, 18,  0 }, {     61,    3, -116,  0, 17,  0 },
    {     61,    3, -117,  0, 17,  0 }, {     60,    3, -118,  0, 17,  0 }, {     60,    2, -119,  0, 17,  0 }, {     60,    2, -120,  0, 17,  0 }, {     60,    2, -121,  0, 17,  0 },
    {     60,    2, -122,  0, 17,  0 }, {     60,    2, -123,  0, 17,  0 }, {     59,    2, -124,  0, 17,  0 }, {     59,    2, -125,  0, 17,  0 }, {     59,    2, -126,  0, 17,  0 },
    {     59,    2, -127,  0, 17,  0 }, {     59,    1, -128,  0, 17,  0 }, {     59,    1, -129,  0, 17,  0 }, {     58,    1, -130,  0, 17,  0 }, {     58,    1, -131,  0, 17,  0 },
    {     58,    1, -132,  0, 17,  0 }, {     58,    1, -133,  0, 17,  0 }, {     58,    1, -134,  0, 17,  0 }, {     57,    1, -135,  0, 17,  0 }, {     57,    1, -136,  0, 17,  0 },
    {     57,    1, -137,  0, 17,  0 }, {     57,    0, -138,  0, 17,  0 }, {     56,    0, -139,  0, 17,  0 }, {     56,    0, -140,  0, 17,  0 }, {     56,    0, -141,  0, 17,  0 },
    {     55,    0, -142,  0, 17,  0 }, {     55,    0, -143,  0, 17,  0 }, {     55,    0, -144,  0, 17,  0 }, {     54,    0, -145,  0, 17,  0 }, {     54,    0, -146,  0, 17,  0 },
    {     54,    0, -147,  0, 17,  0 }, {     54,   -1, -148,  0, 17,  0 }, {     53,   -1, -149,  0, 58,  0 }, {     53,   -1, -150,  0, 58,  0 }, {     53,   -1, -151,  0, 58,  0 },
    {     52,   -1, -152,  0, 58,  0 }, {     52,   -1, -153,  0, 58,  0 }, {     51,   -1, -154,  0, 58,  0 }, {     51,   -1, -155,  0, 58,  0 }, {     50,   -1, -156,  0, 58,  0 },
    {     50,   -2, -157,  0, 58,  0 }, {     50,   -2, -158,  0, 58,  0 }, {     49,   -2, -159,  0, 58,  0 }, {     49,   -2, -160,  0, 58,  0 }, {     48,   -2, -161,  0, 58,  0 },
    {     48,   -2, -162,  0, 58,  0 }, {     48,   -2, -163,  0, 58,  0 }, {     47,   -2, -164,  0, 58,  0 }, {     47,   -2, -165,  0, 58,  0 }, {     46,   -2, -166,  0, 58,  0 },
    {     46,   -3, -167,  0, 58,  0 }, {     45,   -3, -168,  0, 58,  0 }, {     45,   -3, -169,  0, 58,  0 }, {     45,   -3, -170,  0, 58,  0 }, {     44,   -3, -171,  0, 58,  0 },
    {     44,   -3, -172,  0, 58,  0 }, {     43,   -3, -173,  0, 58,  0 }, {     43,   -3, -174,  0, 58,  0 }, {     42,   -3, -175,  0, 58,  0 }, {     42,   -3, -176,  0, 58,  0 },
    {     41,   -4, -177,  0, 58,  0 }, {     41,   -4, -178,  0, 58,  0 }, {     40,   -4, -179,  0, 58,  0 }, {     39,   -4, -180,  0, 58,  0 }, {     39,   -4, -181,  0, 58,  0 },
    {     38,   -4, -182,  0, 58,  0 }, {     38,   -4, -183,  0, 58,  0 }, {     37,   -4, -184,  0, 58,  0 }, {     36,   -4, -185,  0, 57,  0 }, {     36,   -4, -186,  0, 57,  0 },
    {     35,   -5, -187,  0, 57,  0 }, {     35,   -5, -188,  0, 57,  0 }, {     34,   -5, -189,  0, 57,  0 }, {     33,   -5, -190,  0, 57,  0 }, {     33,   -5, -191,  0, 57,  0 },
    {     32,   -5, -192,  0, 57,  0 }, {     31,   -5, -193,  0, 57,  0 }, {     31,   -5, -194,  0, 57,  0 }, {     30,   -5, -195,  0, 57,  0 }, {     29,   -6, -196,  0, 57,  0 },
    {     28,   -6, -197,  0, 57,  0 }, {     28,   -6, -198,  0, 57,  0 }, {     27,   -6, -199,  0, 57,  0 }, {     26,   -6, -200,  0, 57,  0 }, {     26,   -6, -201,  0, 57,  0 },
    {     25,   -6, -202,  0, 57,  0 }, {     24,   -6, -203,  0, 57,  0 }, {     24,   -6, -204,  0, 57,  0 }, {     23,   -6, -205,  0, 57,  0 }, {     22,   -7, -206,  0, 57,  0 },
    {     21,   -7, -207,  0, 57,  0 }, {     20,   -7, -208,  0, 57,  0 }, {     19,   -7, -209,  0, 57,  0 }, {     18,   -7, -210,  0, 57,  0 }, {     17,   -7, -211,  0, 57,  0 },
    {     17,   -7, -212,  0, 57,  0 }, {     16,   -7, -213,  0, 57,  0 }, {     15,   -7, -214,  0, 57,  0 }, {     14,   -7, -215,  0, 57,  0 }, {     13,   -8, -216,  0, 57,  0 },
    {     12,   -8, -217,  0, 57,  0 }, {     11,   -8, -218,  0, 57,  0 }, {     10,   -8, -219,  0, 57,  0 }, {      9,   -8, -220,  0, 57,  0 }, {      8,   -8, -221,  0, 57,  0 },
    {      7,   -8, -222,  0, 57,  0 }, {      6,   -8, -222,  0, 57,  0 }, {      5,   -8, -223,  0, 57,  0 }, {      4,   -9, -224,  0, 57,  0 }, {      3,   -9, -225,  0, 57,  0 },
    {      2,   -9, -226,  0, 57,  0 }, {      1,   -9, -227,  0, 57,  0 }, {      0,   -9, -228,  0, 57,  0 }, {     -1,   -9, -228,  0, 57,  0 }, {     -2,   -9, -229,  0, 57,  0 },
    {     -3,   -9, -230,  0, 56,  0 }, {     -4,   -9, -231,  0, 56,  0 }, {     -5,   -9, -231,  0, 56,  0 }, {     -6,  -10, -232,  0, 56,  0 }, {     -7,  -10, -233,  0, 56,  0 },
    {     -8,  -10, -234,  0, 56,  0 }, {     -9,  -10, -234,  0, 56,  0 }, {    -10,  -10, -235,  0, 56,  0 }, {    -11,  -10, -236,  0, 56,  0 }, {    -12,  -10, -237,  0, 56,  0 },
    {    -13,  -10, -237,  0, 56,  0 }, {    -14,  -10, -238,  0, 56,  0 }, {    -15,  -10, -239,  0, 56,  0 }, {    -16,  -11, -239,  0, 56,  0 }, {    -17,  -11, -240,  0, 56,  0 },
    {    -18,  -11, -240,  0, 56,  0 }, {    -19,  -11, -241,  0, 56,  0 }, {    -20,  -11, -242,  0, 56,  0 }, {    -21,  -11, -242,  0, 56,  0 }, {    -22,  -11, -243,  0, 56,  0 },
    {    -23,  -11, -243,  0, 56,  0 }, {    -24,  -11, -244,  0, 56,  0 }, {    -25,  -11, -245,  0, 56,  0 }, {    -26,  -12, -245,  0, 56,  0 }, {    -27,  -12, -246,  0, 56,  0 },
    {    -28,  -12, -246,  0, 56,  0 }, {    -29,  -12, -247,  0, 56,  0 }, {    -30,  -12, -247,  0, 56,  0 }, {    -31,  -12, -248,  0, 56,  0 }, {    -32,  -12, -248,  0, 56,  0 },
    {    -33,  -12, -249,  0, 56,  0 }, {    -34,  -12, -249,  0, 56,  0 }, {    -35,  -13, -250,  0, 56,  0 }, {    -36,  -13, -250,  0, 56,  0 }, {    -37,  -13, -251,  0, 56,  0 },
    {    -38,  -13, -251,  0, 56,  0 }, {    -39,  -13, -252,  0, 56,  0 }, {    -40,  -13, -252,  0, 56,  0 }, {    -41,  -13, -253,  0, 56,  0 }, {    -42,  -13, -253,  0, 56,  0 },
    {    -43,  -13, -254,  0, 56,  0 }, {    -44,  -13, -254,  0, 56,  0 }, {    -45,  -14, -255,  0, 56,  0 }, {    -46,  -14, -255,  0, 56,  0 }, {    -47,  -14, -256,  0, 56,  0 },
    {    -48,  -14, -256,  0, 56,  0 }, {    -49,  -14, -257,  0, 56,  0 }, {    -50,  -14, -257,  0, 56,  0 }, {    -51,  -14, -258,  0, 56,  0 }, {    -52,  -14, -258,  0, 56,  0 },
    {    -53,  -14, -259,  0, 56,  0 }, {    -54,  -14, -259,  0, 56,  0 }, {    -55,  -15, -260,  0, 56,  0 }, {    -56,  -15, -260,  0, 56,  0 }, {    -57,  -15, -261,  0, 56,  0 },
    {    -58,  -15, -261,  0, 56,  0 }, {    -59,  -15, -262,  0, 56,  0 }, {    -60,  -15, -262,  0, 56,  0 }, {    -61,  -15, -263,  0, 56,  0 }, {    -62,  -15, -263,  0, 56,  0 },
    {    -63,  -15, -264,  0, 56,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_RightFlyerLargeHalfLoopDown3, {
    {     16,   31,    0, 24,  0,  0 }, {     16,   30,    0, 24,  0,  0 }, {     16,   29,    0, 24,  0,  0 }, {     16,   28,    0, 24,  0,  0 }, {     16,   27,    0, 24,  0,  0 },
    {     16,   26,    0, 24,  0,  0 }, {     16,   25,    0, 24,  0,  0 }, {     16,   24,    0, 24,  0,  0 }, {     16,   23,   -1, 24,  0,  0 }, {     16,   22,   -1, 24,  0,  0 },
    {     15,   21,   -1, 24,  0,  0 }, {     15,   20,   -1, 24,  0,  0 }, {     15,   19,   -2, 24,  0,  0 }, {     15,   18,   -2, 24,  0,  0 }, {     15,   17,   -2, 24,  0,  0 },
    {     15,   16,   -3,  8, 23,  0 }, {     15,   15,   -3,  8, 23,  0 }, {     15,   14,   -4,  8, 23,  0 }, {     15,   13,   -4,  8, 23,  0 }, {     15,   12,   -5,  8, 23,  0 },
    {     14,   11,   -5,  8, 23,  0 }, {     14,   10,   -6,  8, 23,  0 }, {     14,    9,   -6,  8, 23,  0 }, {     14,    8,   -7,  8, 23,  0 }, {     14,    7,   -8,  8, 23,  0 },
    {     14,    6,   -8,  8, 23,  0 }, {     14,    5,   -9,  8, 23,  0 }, {     14,    4,  -10,  8, 23,  0 }, {     14,    3,  -11,  8, 23,  0 }, {     14,    2,  -11,  8, 23,  0 },
    {     13,    1,  -12,  8, 22,  0 }, {     13,    0,  -13,  8, 22,  0 }, {     13,   -1,  -14,  8, 22,  0 }, {     13,   -2,  -15,  8, 22,  0 }, {     13,   -3,  -16,  8, 22,  0 },
    {     13,   -4,  -17,  8, 22,  0 }, {     13,   -5,  -18,  8, 22,  0 }, {     13,   -6,  -19,  8, 22,  0 }, {     13,   -7,  -20,  8, 22,  0 }, {     12,   -8,  -21,  8, 22,  0 },
    {     12,   -9,  -22,  8, 22,  0 }, {     12,   -9,  -23,  8, 22,  0 }, {     12,  -10,  -24,  8, 22,  0 }, {     12,  -11,  -25,  8, 21,  0 }, {     12,  -12,  -26,  8, 21,  0 },
    {     12,  -12,  -27,  8, 21,  0 }, {     12,  -13,  -28,  8, 21,  0 }, {     12,  -14,  -29,  8, 21,  0 }, {     12,  -14,  -30,  8, 21,  0 }, {     11,  -15,  -31,  8, 21,  0 },
    {     11,  -16,  -32,  8, 21,  0 }, {     11,  -16,  -33,  8, 21,  0 }, {     11,  -17,  -34,  8, 21,  0 }, {     11,  -17,  -35,  8, 21,  0 }, {     11,  -18,  -36,  8, 21,  0 },
    {     11,  -18,  -37,  8, 21,  0 }, {     11,  -19,  -38,  8, 21,  0 }, {     11,  -19,  -39,  8, 21,  0 }, {     11,  -20,  -40,  8, 20,  0 }, {     10,  -20,  -41,  8, 20,  0 },
    {     10,  -21,  -42,  8, 20,  0 }, {     10,  -21,  -43,  8, 20,  0 }, {     10,  -22,  -44,  8, 20,  0 }, {     10,  -22,  -45,  8, 20,  0 }, {     10,  -22,  -46,  8, 20,  0 },
    {     10,  -23,  -47,  8, 20,  0 }, {     10,  -23,  -48,  8, 20,  0 }, {     10,  -23,  -49,  8, 20,  0 }, {     10,  -24,  -50,  8, 20,  0 }, {      9,  -24,  -51,  8, 20,  0 },
    {      9,  -25,  -52,  8, 20,  0 }, {      9,  -25,  -53,  8, 20,  0 }, {      9,  -25,  -54,  8, 20,  0 }, {      9,  -26,  -55,  8, 19,  0 }, {      9,  -26,  -56,  8, 19,  0 },
    {      9,  -26,  -57,  8, 19,  0 }, {      9,  -26,  -58,  8, 19,  0 }, {      9,  -27,  -59,  8, 19,  0 }, {      8,  -27,  -60,  8, 19,  0 }, {      8,  -27,  -61,  8, 19,  0 },
    {      8,  -27,  -62,  8, 19,  0 }, {      8,  -28,  -63,  8, 19,  0 }, {      8,  -28,  -64,  8, 19,  0 }, {      8,  -28,  -65,  8, 19,  0 }, {      8,  -28,  -66,  8, 19,  0 },
    {      8,  -28,  -67,  8, 19,  0 }, {      8,  -28,  -68,  8, 19,  0 }, {      8,  -29,  -69,  8, 19,  0 }, {      7,  -29,  -70,  8, 19,  0 }, {      7,  -29,  -71,  8, 19,  0 },
    {      7,  -29,  -72,  8, 19,  0 }, {      7,  -29,  -73,  8, 19,  0 }, {      7,  -29,  -74,  8, 19,  0 }, {      7,  -29,  -75,  8, 19,  0 }, {      7,  -29,  -76,  8, 19,  0 },
    {      7,  -30,  -77,  8, 19,  0 }, {      7,  -30,  -78,  8, 19,  0 }, {      7,  -30,  -79,  8, 18,  0 }, {      6,  -30,  -80,  8, 18,  0 }, {      6,  -30,  -81,  8, 18,  0 },
    {      6,  -30,  -82,  8, 18,  0 }, {      6,  -30,  -83,  8, 18,  0 }, {      6,  -30,  -84,  8, 18,  0 }, {      6,  -30,  -85,  8, 18,  0 }, {      6,  -30,  -86,  8, 18,  0 },
    {      6,  -30,  -87,  8, 18,  0 }, {      6,  -30,  -88,  8, 18,  0 }, {      5,  -30,  -89,  8, 18,  0 }, {      5,  -30,  -90,  8, 18,  0 }, {      5,  -30,  -91,  8, 18,  0 },
    {      5,  -30,  -92,  8, 18,  0 }, {      5,  -30,  -93,  8, 18,  0 }, {      5,  -30,  -94,  8, 18,  0 }, {      5,  -30,  -95,  8, 18,  0 }, {      5,  -30,  -96,  8, 18,  0 },
    {      5,  -30,  -97,  8, 18,  0 }, {      5,  -30,  -98,  8, 18,  0 }, {      4,  -30,  -99,  8, 18,  0 }, {      4,  -30, -100,  8, 18,  0 }, {      4,  -30, -101,  8, 18,  0 },
    {      4,  -30, -102,  8, 18,  0 }, {      4,  -30, -103,  8, 18,  0 }, {      4,  -30, -104,  8, 18,  0 }, {      4,  -30, -105,  8, 18,  0 }, {      4,  -30, -106,  8, 18,  0 },
    {      4,  -30, -107,  8, 18,  0 }, {      4,  -30, -108,  8, 18,  0 }, {      3,  -30, -109,  8, 18,  0 }, {      3,  -30, -110,  8, 18,  0 }, {      3,  -30, -111,  8, 18,  0 },
    {      3,  -30, -112,  8, 18,  0 }, {      3,  -30, -113,  8, 18,  0 }, {      3,  -30, -114,  8, 18,  0 }, {      3,  -30, -115,  8, 18,  0 }, {      3,  -30, -116,  8, 17,  0 },
    {      3,  -30, -117,  8, 17,  0 }, {      3,  -29, -118,  8, 17,  0 }, {      2,  -29, -119,  8, 17,  0 }, {      2,  -29, -120,  8, 17,  0 }, {      2,  -29, -121,  8, 17,  0 },
    {      2,  -29, -122,  8, 17,  0 }, {      2,  -29, -123,  8, 17,  0 }, {      2,  -28, -124,  8, 17,  0 }, {      2,  -28, -125,  8, 17,  0 }, {      2,  -28, -126,  8, 17,  0 },
    {      2,  -28, -127,  8, 17,  0 }, {      1,  -28, -128,  8, 17,  0 }, {      1,  -28, -129,  8, 17,  0 }, {      1,  -27, -130,  8, 17,  0 }, {      1,  -27, -131,  8, 17,  0 },
    {      1,  -27, -132,  8, 17,  0 }, {      1,  -27, -133,  8, 17,  0 }, {      1,  -27, -134,  8, 17,  0 }, {      1,  -26, -135,  8, 17,  0 }, {      1,  -26, -136,  8, 17,  0 },
    {      1,  -26, -137,  8, 17,  0 }, {      0,  -26, -138,  8, 17,  0 }, {      0,  -25, -139,  8, 17,  0 }, {      0,  -25, -140,  8, 17,  0 }, {      0,  -25, -141,  8, 17,  0 },
    {      0,  -24, -142,  8, 17,  0 }, {      0,  -24, -143,  8, 17,  0 }, {      0,  -24, -144,  8, 17,  0 }, {      0,  -23, -145,  8, 17,  0 }, {      0,  -23, -146,  8, 17,  0 },
    {      0,  -23, -147,  8, 17,  0 }, {     -1,  -23, -148,  8, 17,  0 }, {     -1,  -22, -149,  8, 58,  0 }, {     -1,  -22, -150,  8, 58,  0 }, {     -1,  -22, -151,  8, 58,  0 },
    {     -1,  -21, -152,  8, 58,  0 }, {     -1,  -21, -153,  8, 58,  0 }, {     -1,  -20, -154,  8, 58,  0 }, {     -1,  -20, -155,  8, 58,  0 }, {     -1,  -19, -156,  8, 58,  0 },
    {     -2,  -19, -157,  8, 58,  0 }, {     -2,  -19, -158,  8, 58,  0 }, {     -2,  -18, -159,  8, 58,  0 }, {     -2,  -18, -160,  8, 58,  0 }, {     -2,  -17, -161,  8, 58,  0 },
    {     -2,  -17, -162,  8, 58,  0 }, {     -2,  -17, -163,  8, 58,  0 }, {     -2,  -16, -164,  8, 58,  0 }, {     -2,  -16, -165,  8, 58,  0 }, {     -2,  -15, -166,  8, 58,  0 },
    {     -3,  -15, -167,  8, 58,  0 }, {     -3,  -14, -168,  8, 58,  0 }, {     -3,  -14, -169,  8, 58,  0 }, {     -3,  -14, -170,  8, 58,  0 }, {     -3,  -13, -171,  8, 58,  0 },
    {     -3,  -13, -172,  8, 58,  0 }, {     -3,  -12, -173,  8, 58,  0 }, {     -3,  -12, -174,  8, 58,  0 }, {     -3,  -11, -175,  8, 58,  0 }, {     -3,  -11, -176,  8, 58,  0 },
    {     -4,  -10, -177,  8, 58,  0 }, {     -4,  -10, -178,  8, 58,  0 }, {     -4,   -9, -179,  8, 58,  0 }, {     -4,   -8, -180,  8, 58,  0 }, {     -4,   -8, -181,  8, 58,  0 },
    {     -4,   -7, -182,  8, 58,  0 }, {     -4,   -7, -183,  8, 58,  0 }, {     -4,   -6, -184,  8, 58,  0 }, {     -4,   -5, -185,  8, 57,  0 }, {     -4,   -5, -186,  8, 57,  0 },
    {     -5,   -4, -187,  8, 57,  0 }, {     -5,   -4, -188,  8, 57,  0 }, {     -5,   -3, -189,  8, 57,  0 }, {     -5,   -2, -190,  8, 57,  0 }, {     -5,   -2, -191,  8, 57,  0 },
    {     -5,   -1, -192,  8, 57,  0 }, {     -5,    0, -193,  8, 57,  0 }, {     -5,    0, -194,  8, 57,  0 }, {     -5,    1, -195,  8, 57,  0 }, {     -6,    2, -196,  8, 57,  0 },
    {     -6,    3, -197,  8, 57,  0 }, {     -6,    3, -198,  8, 57,  0 }, {     -6,    4, -199,  8, 57,  0 }, {     -6,    5, -200,  8, 57,  0 }, {     -6,    5, -201,  8, 57,  0 },
    {     -6,    6, -202,  8, 57,  0 }, {     -6,    7, -203,  8, 57,  0 }, {     -6,    7, -204,  8, 57,  0 }, {     -6,    8, -205,  8, 57,  0 }, {     -7,    9, -206,  8, 57,  0 },
    {     -7,   10, -207,  8, 57,  0 }, {     -7,   11, -208,  8, 57,  0 }, {     -7,   12, -209,  8, 57,  0 }, {     -7,   13, -210,  8, 57,  0 }, {     -7,   14, -211,  8, 57,  0 },
    {     -7,   14, -212,  8, 57,  0 }, {     -7,   15, -213,  8, 57,  0 }, {     -7,   16, -214,  8, 57,  0 }, {     -7,   17, -215,  8, 57,  0 }, {     -8,   18, -216,  8, 57,  0 },
    {     -8,   19, -217,  8, 57,  0 }, {     -8,   20, -218,  8, 57,  0 }, {     -8,   21, -219,  8, 57,  0 }, {     -8,   22, -220,  8, 57,  0 }, {     -8,   23, -221,  8, 57,  0 },
    {     -8,   24, -222,  8, 57,  0 }, {     -8,   25, -222,  8, 57,  0 }, {     -8,   26, -223,  8, 57,  0 }, {     -9,   27, -224,  8, 57,  0 }, {     -9,   28, -225,  8, 57,  0 },
    {     -9,   29, -226,  8, 57,  0 }, {     -9,   30, -227,  8, 57,  0 }, {     -9,   31, -228,  8, 57,  0 }, {     -9,   32, -228,  8, 57,  0 }, {     -9,   33, -229,  8, 57,  0 },
    {     -9,   34, -230,  8, 56,  0 }, {     -9,   35, -231,  8, 56,  0 }, {     -9,   36, -231,  8, 56,  0 }, {    -10,   37, -232,  8, 56,  0 }, {    -10,   38, -233,  8, 56,  0 },
    {    -10,   39, -234,  8, 56,  0 }, {    -10,   40, -234,  8, 56,  0 }, {    -10,   41, -235,  8, 56,  0 }, {    -10,   42, -236,  8, 56,  0 }, {    -10,   43, -237,  8, 56,  0 },
    {    -10,   44, -237,  8, 56,  0 }, {    -10,   45, -238,  8, 56,  0 }, {    -10,   46, -239,  8, 56,  0 }, {    -11,   47, -239,  8, 56,  0 }, {    -11,   48, -240,  8, 56,  0 },
    {    -11,   49, -240,  8, 56,  0 }, {    -11,   50, -241,  8, 56,  0 }, {    -11,   51, -242,  8, 56,  0 }, {    -11,   52, -242,  8, 56,  0 }, {    -11,   53, -243,  8, 56,  0 },
    {    -11,   54, -243,  8, 56,  0 }, {    -11,   55, -244,  8, 56,  0 }, {    -11,   56, -245,  8, 56,  0 }, {    -12,   57, -245,  8, 56,  0 }, {    -12,   58, -246,  8, 56,  0 },
    {    -12,   59, -246,  8, 56,  0 }, {    -12,   60, -247,  8, 56,  0 }, {    -12,   61, -247,  8, 56,  0 }, {    -12,   62, -248,  8, 56,  0 }, {    -12,   63, -248,  8, 56,  0 },
    {    -12,   64, -249,  8, 56,  0 }, {    -12,   65, -249,  8, 56,  0 }, {    -13,   66, -250,  8, 56,  0 }, {    -13,   67, -250,  8, 56,  0 }, {    -13,   68, -251,  8, 56,  0 },
    {    -13,   69, -251,  8, 56,  0 }, {    -13,   70, -252,  8, 56,  0 }, {    -13,   71, -252,  8, 56,  0 }, {    -13,   72, -253,  8, 56,  0 }, {    -13,   73, -253,  8, 56,  0 },
    {    -13,   74, -254,  8, 56,  0 }, {    -13,   75, -254,  8, 56,  0 }, {    -14,   76, -255,  8, 56,  0 }, {    -14,   77, -255,  8, 56,  0 }, {    -14,   78, -256,  8, 56,  0 },
    {    -14,   79, -256,  8, 56,  0 }, {    -14,   80, -257,  8, 56,  0 }, {    -14,   81, -257,  8, 56,  0 }, {    -14,   82, -258,  8, 56,  0 }, {    -14,   83, -258,  8, 56,  0 },
    {    -14,   84, -259,  8, 56,  0 }, {    -14,   85, -259,  8, 56,  0 }, {    -15,   86, -260,  8, 56,  0 }, {    -15,   87, -260,  8, 56,  0 }, {    -15,   88, -261,  8, 56,  0 },
    {    -15,   89, -261,  8, 56,  0 }, {    -15,   90, -262,  8, 56,  0 }, {    -15,   91, -262,  8, 56,  0 }, {    -15,   92, -263,  8, 56,  0 }, {    -15,   93, -263,  8, 56,  0 },
    {    -15,   94, -264,  8, 56,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_LeftFlyerLargeHalfLoopUninvertedDown0, {
    {     31,   16,   32,  0,  0,  0 }, {     30,   16,   32,  0,  0,  0 }, {     29,   16,   32,  0,  0,  0 }, {     28,   16,   32,  0,  0,  0 }, {     27,   16,   32,  0,  0,  0 },
    {     26,   16,   32,  0,  0,  0 }, {     25,   16,   32,  0,  0,  0 }, {     24,   16,   32,  0,  0,  0 }, {     23,   16,   31,  0,  0,  0 }, {     22,   16,   31,  0,  0,  0 },
    {     21,   15,   31,  0,  0,  0 }, {     20,   15,   31,  0,  0,  0 }, {     19,   15,   30,  0,  0,  0 }, {     18,   15,   30,  0,  0,  0 }, {     17,   15,   30,  0,  0,  0 },
    {     16,   15,   29,  0,  5,  0 }, {     15,   15,   29,  0,  5,  0 }, {     14,   15,   28,  0,  5,  0 }, {     13,   15,   28,  0,  5,  0 }, {     12,   15,   27,  0,  5,  0 },
    {     11,   14,   27,  0,  5,  0 }, {     10,   14,   26,  0,  5,  0 }, {      9,   14,   26,  0,  5,  0 }, {      8,   14,   25,  0,  5,  0 }, {      7,   14,   24,  0,  5,  0 },
    {      6,   14,   24,  0,  5,  0 }, {      5,   14,   23,  0,  5,  0 }, {      4,   14,   22,  0,  5,  0 }, {      3,   14,   21,  0,  5,  0 }, {      2,   14,   21,  0,  5,  0 },
    {      1,   13,   20,  0,  6,  0 }, {      0,   13,   19,  0,  6,  0 }, {     -1,   13,   18,  0,  6,  0 }, {     -2,   13,   17,  0,  6,  0 }, {     -3,   13,   16,  0,  6,  0 },
    {     -4,   13,   15,  0,  6,  0 }, {     -5,   13,   14,  0,  6,  0 }, {     -6,   13,   13,  0,  6,  0 }, {     -7,   13,   12,  0,  6,  0 }, {     -8,   12,   11,  0,  6,  0 },
    {     -9,   12,   10,  0,  6,  0 }, {     -9,   12,    9,  0,  6,  0 }, {    -10,   12,    8,  0,  6,  0 }, {    -11,   12,    7,  0,  7,  0 }, {    -12,   12,    6,  0,  7,  0 },
    {    -12,   12,    5,  0,  7,  0 }, {    -13,   12,    4,  0,  7,  0 }, {    -14,   12,    3,  0,  7,  0 }, {    -14,   12,    2,  0,  7,  0 }, {    -15,   11,    1,  0,  7,  0 },
    {    -16,   11,    0,  0,  7,  0 }, {    -16,   11,   -1,  0,  7,  0 }, {    -17,   11,   -2,  0,  7,  0 }, {    -17,   11,   -3,  0,  7,  0 }, {    -18,   11,   -4,  0,  7,  0 },
    {    -18,   11,   -5,  0,  7,  0 }, {    -19,   11,   -6,  0,  7,  0 }, {    -19,   11,   -7,  0,  7,  0 }, {    -20,   11,   -8,  0,  8,  0 }, {    -20,   10,   -9,  0,  8,  0 },
    {    -21,   10,  -10,  0,  8,  0 }, {    -21,   10,  -11,  0,  8,  0 }, {    -22,   10,  -12,  0,  8,  0 }, {    -22,   10,  -13,  0,  8,  0 }, {    -22,   10,  -14,  0,  8,  0 },
    {    -23,   10,  -15,  0,  8,  0 }, {    -23,   10,  -16,  0,  8,  0 }, {    -23,   10,  -17,  0,  8,  0 }, {    -24,   10,  -18,  0,  8,  0 }, {    -24,    9,  -19,  0,  8,  0 },
    {    -25,    9,  -20,  0,  8,  0 }, {    -25,    9,  -21,  0,  8,  0 }, {    -25,    9,  -22,  0,  8,  0 }, {    -26,    9,  -23,  0, 17,  0 }, {    -26,    9,  -24,  0, 17,  0 },
    {    -26,    9,  -25,  0, 17,  0 }, {    -26,    9,  -26,  0, 17,  0 }, {    -27,    9,  -27,  0, 17,  0 }, {    -27,    8,  -28,  0, 17,  0 }, {    -27,    8,  -29,  0, 17,  0 },
    {    -27,    8,  -30,  0, 17,  0 }, {    -28,    8,  -31,  0, 17,  0 }, {    -28,    8,  -32,  0, 17,  0 }, {    -28,    8,  -33,  0, 17,  0 }, {    -28,    8,  -34,  0, 17,  0 },
    {    -28,    8,  -35,  0, 17,  0 }, {    -28,    8,  -36,  0, 17,  0 }, {    -29,    8,  -37,  0, 17,  0 }, {    -29,    7,  -38,  0, 17,  0 }, {    -29,    7,  -39,  0, 17,  0 },
    {    -29,    7,  -40,  0, 17,  0 }, {    -29,    7,  -41,  0, 17,  0 }, {    -29,    7,  -42,  0, 17,  0 }, {    -29,    7,  -43,  0, 17,  0 }, {    -29,    7,  -44,  0, 17,  0 },
    {    -30,    7,  -45,  0, 17,  0 }, {    -30,    7,  -46,  0, 17,  0 }, {    -30,    7,  -47,  0, 18,  0 }, {    -30,    6,  -48,  0, 18,  0 }, {    -30,    6,  -49,  0, 18,  0 },
    {    -30,    6,  -50,  0, 18,  0 }, {    -30,    6,  -51,  0, 18,  0 }, {    -30,    6,  -52,  0, 18,  0 }, {    -30,    6,  -53,  0, 18,  0 }, {    -30,    6,  -54,  0, 18,  0 },
    {    -30,    6,  -55,  0, 18,  0 }, {    -30,    6,  -56,  0, 18,  0 }, {    -30,    5,  -57,  0, 18,  0 }, {    -30,    5,  -58,  0, 18,  0 }, {    -30,    5,  -59,  0, 18,  0 },
    {    -30,    5,  -60,  0, 18,  0 }, {    -30,    5,  -61,  0, 18,  0 }, {    -30,    5,  -62,  0, 18,  0 }, {    -30,    5,  -63,  0, 18,  0 }, {    -30,    5,  -64,  0, 18,  0 },
    {    -30,    5,  -65,  0, 18,  0 }, {    -30,    5,  -66,  0, 18,  0 }, {    -30,    4,  -67,  0, 18,  0 }, {    -30,    4,  -68,  0, 18,  0 }, {    -30,    4,  -69,  0, 18,  0 },
    {    -30,    4,  -70,  0, 18,  0 }, {    -30,    4,  -71,  0, 18,  0 }, {    -30,    4,  -72,  0, 18,  0 }, {    -30,    4,  -73,  0, 18,  0 }, {    -30,    4,  -74,  0, 18,  0 },
    {    -30,    4,  -75,  0, 18,  0 }, {    -30,    4,  -76,  0, 18,  0 }, {    -30,    3,  -77,  0, 18,  0 }, {    -30,    3,  -78,  0, 18,  0 }, {    -30,    3,  -79,  0, 18,  0 },
    {    -30,    3,  -80,  0, 18,  0 }, {    -30,    3,  -81,  0, 18,  0 }, {    -30,    3,  -82,  0, 18,  0 }, {    -30,    3,  -83,  0, 18,  0 }, {    -30,    3,  -84,  0, 19,  0 },
    {    -30,    3,  -85,  0, 19,  0 }, {    -29,    3,  -86,  0, 19,  0 }, {    -29,    2,  -87,  0, 19,  0 }, {    -29,    2,  -88,  0, 19,  0 }, {    -29,    2,  -89,  0, 19,  0 },
    {    -29,    2,  -90,  0, 19,  0 }, {    -29,    2,  -91,  0, 19,  0 }, {    -28,    2,  -92,  0, 19,  0 }, {    -28,    2,  -93,  0, 19,  0 }, {    -28,    2,  -94,  0, 19,  0 },
    {    -28,    2,  -95,  0, 19,  0 }, {    -28,    1,  -96,  0, 19,  0 }, {    -28,    1,  -97,  0, 19,  0 }, {    -27,    1,  -98,  0, 19,  0 }, {    -27,    1,  -99,  0, 19,  0 },
    {    -27,    1, -100,  0, 19,  0 }, {    -27,    1, -101,  0, 19,  0 }, {    -27,    1, -102,  0, 19,  0 }, {    -26,    1, -103,  0, 19,  0 }, {    -26,    1, -104,  0, 19,  0 },
    {    -26,    1, -105,  0, 19,  0 }, {    -26,    0, -106,  0, 19,  0 }, {    -25,    0, -107,  0, 19,  0 }, {    -25,    0, -108,  0, 19,  0 }, {    -25,    0, -109,  0, 19,  0 },
    {    -24,    0, -110,  0, 19,  0 }, {    -24,    0, -111,  0, 19,  0 }, {    -24,    0, -112,  0, 19,  0 }, {    -23,    0, -113,  0, 19,  0 }, {    -23,    0, -114,  0, 19,  0 },
    {    -23,    0, -115,  0, 19,  0 }, {    -23,   -1, -116,  0, 19,  0 }, {    -22,   -1, -117,  0, 20,  0 }, {    -22,   -1, -118,  0, 20,  0 }, {    -22,   -1, -119,  0, 20,  0 },
    {    -21,   -1, -120,  0, 20,  0 }, {    -21,   -1, -121,  0, 20,  0 }, {    -20,   -1, -122,  0, 20,  0 }, {    -20,   -1, -123,  0, 20,  0 }, {    -19,   -1, -124,  0, 20,  0 },
    {    -19,   -2, -125,  0, 20,  0 }, {    -19,   -2, -126,  0, 20,  0 }, {    -18,   -2, -127,  0, 20,  0 }, {    -18,   -2, -128,  0, 20,  0 }, {    -17,   -2, -129,  0, 20,  0 },
    {    -17,   -2, -130,  0, 20,  0 }, {    -17,   -2, -131,  0, 20,  0 }, {    -16,   -2, -132,  0, 20,  0 }, {    -16,   -2, -133,  0, 20,  0 }, {    -15,   -2, -134,  0, 20,  0 },
    {    -15,   -3, -135,  0, 20,  0 }, {    -14,   -3, -136,  0, 20,  0 }, {    -14,   -3, -137,  0, 20,  0 }, {    -14,   -3, -138,  0, 20,  0 }, {    -13,   -3, -139,  0, 20,  0 },
    {    -13,   -3, -140,  0, 20,  0 }, {    -12,   -3, -141,  0, 20,  0 }, {    -12,   -3, -142,  0, 20,  0 }, {    -11,   -3, -143,  0, 20,  0 }, {    -11,   -3, -144,  0, 20,  0 },
    {    -10,   -4, -145,  0, 20,  0 }, {    -10,   -4, -146,  0, 20,  0 }, {     -9,   -4, -147,  0, 20,  0 }, {     -8,   -4, -148,  0, 20,  0 }, {     -8,   -4, -149,  0, 20,  0 },
    {     -7,   -4, -150,  0, 20,  0 }, {     -7,   -4, -151,  0, 20,  0 }, {     -6,   -4, -152,  0, 20,  0 }, {     -5,   -4, -153,  0, 21,  0 }, {     -5,   -4, -154,  0, 21,  0 },
    {     -4,   -5, -155,  0, 21,  0 }, {     -4,   -5, -156,  0, 21,  0 }, {     -3,   -5, -157,  0, 21,  0 }, {     -2,   -5, -158,  0, 21,  0 }, {     -2,   -5, -159,  0, 21,  0 },
    {     -1,   -5, -160,  0, 21,  0 }, {      0,   -5, -161,  0, 21,  0 }, {      0,   -5, -162,  0, 21,  0 }, {      1,   -5, -163,  0, 21,  0 }, {      2,   -6, -164,  0, 21,  0 },
    {      3,   -6, -165,  0, 21,  0 }, {      3,   -6, -166,  0, 21,  0 }, {      4,   -6, -167,  0, 21,  0 }, {      5,   -6, -168,  0, 21,  0 }, {      5,   -6, -169,  0, 21,  0 },
    {      6,   -6, -170,  0, 21,  0 }, {      7,   -6, -171,  0, 21,  0 }, {      7,   -6, -172,  0, 21,  0 }, {      8,   -6, -173,  0, 21,  0 }, {      9,   -7, -174,  0, 21,  0 },
    {     10,   -7, -175,  0, 21,  0 }, {     11,   -7, -176,  0, 21,  0 }, {     12,   -7, -177,  0, 21,  0 }, {     13,   -7, -178,  0, 21,  0 }, {     14,   -7, -179,  0, 21,  0 },
    {     14,   -7, -180,  0, 21,  0 }, {     15,   -7, -181,  0, 21,  0 }, {     16,   -7, -182,  0, 21,  0 }, {     17,   -7, -183,  0, 21,  0 }, {     18,   -8, -184,  0, 21,  0 },
    {     19,   -8, -185,  0, 21,  0 }, {     20,   -8, -186,  0, 21,  0 }, {     21,   -8, -187,  0, 21,  0 }, {     22,   -8, -188,  0, 21,  0 }, {     23,   -8, -189,  0, 21,  0 },
    {     24,   -8, -190,  0, 21,  0 }, {     25,   -8, -190,  0, 21,  0 }, {     26,   -8, -191,  0, 21,  0 }, {     27,   -9, -192,  0, 21,  0 }, {     28,   -9, -193,  0, 21,  0 },
    {     29,   -9, -194,  0, 21,  0 }, {     30,   -9, -195,  0, 21,  0 }, {     31,   -9, -196,  0, 21,  0 }, {     32,   -9, -196,  0, 21,  0 }, {     33,   -9, -197,  0, 21,  0 },
    {     34,   -9, -198,  0, 22,  0 }, {     35,   -9, -199,  0, 22,  0 }, {     36,   -9, -199,  0, 22,  0 }, {     37,  -10, -200,  0, 22,  0 }, {     38,  -10, -201,  0, 22,  0 },
    {     39,  -10, -202,  0, 22,  0 }, {     40,  -10, -202,  0, 22,  0 }, {     41,  -10, -203,  0, 22,  0 }, {     42,  -10, -204,  0, 22,  0 }, {     43,  -10, -205,  0, 22,  0 },
    {     44,  -10, -205,  0, 22,  0 }, {     45,  -10, -206,  0, 22,  0 }, {     46,  -10, -207,  0, 22,  0 }, {     47,  -11, -207,  0, 22,  0 }, {     48,  -11, -208,  0, 22,  0 },
    {     49,  -11, -208,  0, 22,  0 }, {     50,  -11, -209,  0, 22,  0 }, {     51,  -11, -210,  0, 22,  0 }, {     52,  -11, -210,  0, 22,  0 }, {     53,  -11, -211,  0, 22,  0 },
    {     54,  -11, -211,  0, 22,  0 }, {     55,  -11, -212,  0, 22,  0 }, {     56,  -11, -213,  0, 22,  0 }, {     57,  -12, -213,  0, 22,  0 }, {     58,  -12, -214,  0, 22,  0 },
    {     59,  -12, -214,  0, 22,  0 }, {     60,  -12, -215,  0, 22,  0 }, {     61,  -12, -215,  0, 22,  0 }, {     62,  -12, -216,  0, 22,  0 }, {     63,  -12, -216,  0, 22,  0 },
    {     64,  -12, -217,  0, 22,  0 }, {     65,  -12, -217,  0, 22,  0 }, {     66,  -13, -218,  0, 22,  0 }, {     67,  -13, -218,  0, 22,  0 }, {     68,  -13, -219,  0, 22,  0 },
    {     69,  -13, -219,  0, 22,  0 }, {     70,  -13, -220,  0, 22,  0 }, {     71,  -13, -220,  0, 22,  0 }, {     72,  -13, -221,  0, 22,  0 }, {     73,  -13, -221,  0, 22,  0 },
    {     74,  -13, -222,  0, 22,  0 }, {     75,  -13, -222,  0, 22,  0 }, {     76,  -14, -223,  0, 22,  0 }, {     77,  -14, -223,  0, 22,  0 }, {     78,  -14, -224,  0, 22,  0 },
    {     79,  -14, -224,  0, 22,  0 }, {     80,  -14, -225,  0, 22,  0 }, {     81,  -14, -225,  0, 22,  0 }, {     82,  -14, -226,  0, 22,  0 }, {     83,  -14, -226,  0, 22,  0 },
    {     84,  -14, -227,  0, 22,  0 }, {     85,  -14, -227,  0, 22,  0 }, {     86,  -15, -228,  0, 22,  0 }, {     87,  -15, -228,  0, 22,  0 }, {     88,  -15, -229,  0, 22,  0 },
    {     89,  -15, -229,  0, 22,  0 }, {     90,  -15, -230,  0, 22,  0 }, {     91,  -15, -230,  0, 22,  0 }, {     92,  -15, -231,  0, 22,  0 }, {     93,  -15, -231,  0, 22,  0 },
    {     94,  -15, -232,  0, 22,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_LeftFlyerLargeHalfLoopUninvertedDown1, {
    {     16,    0,   32,  8,  0,  0 }, {     16,    1,   32,  8,  0,  0 }, {     16,    2,   32,  8,  0,  0 }, {     16,    3,   32,  8,  0,  0 }, {     16,    4,   32,  8,  0,  0 },
    {     16,    5,   32,  8,  0,  0 }, {     16,    6,   32,  8,  0,  0 }, {     16,    7,   32,  8,  0,  0 }, {     16,    8,   31,  8,  0,  0 }, {     16,    9,   31,  8,  0,  0 },
    {     15,   10,   31,  8,  0,  0 }, {     15,   11,   31,  8,  0,  0 }, {     15,   12,   30,  8,  0,  0 }, {     15,   13,   30,  8,  0,  0 }, {     15,   14,   30,  8,  0,  0 },
    {     15,   15,   29,  8,  5,  0 }, {     15,   16,   29,  8,  5,  0 }, {     15,   17,   28,  8,  5,  0 }, {     15,   18,   28,  8,  5,  0 }, {     15,   19,   27,  8,  5,  0 },
    {     14,   20,   27,  8,  5,  0 }, {     14,   21,   26,  8,  5,  0 }, {     14,   22,   26,  8,  5,  0 }, {     14,   23,   25,  8,  5,  0 }, {     14,   24,   24,  8,  5,  0 },
    {     14,   25,   24,  8,  5,  0 }, {     14,   26,   23,  8,  5,  0 }, {     14,   27,   22,  8,  5,  0 }, {     14,   28,   21,  8,  5,  0 }, {     14,   29,   21,  8,  5,  0 },
    {     13,   30,   20,  8,  6,  0 }, {     13,   31,   19,  8,  6,  0 }, {     13,   32,   18,  8,  6,  0 }, {     13,   33,   17,  8,  6,  0 }, {     13,   34,   16,  8,  6,  0 },
    {     13,   35,   15,  8,  6,  0 }, {     13,   36,   14,  8,  6,  0 }, {     13,   37,   13,  8,  6,  0 }, {     13,   38,   12,  8,  6,  0 }, {     12,   39,   11,  8,  6,  0 },
    {     12,   40,   10,  8,  6,  0 }, {     12,   40,    9,  8,  6,  0 }, {     12,   41,    8,  8,  6,  0 }, {     12,   42,    7,  8,  7,  0 }, {     12,   43,    6,  8,  7,  0 },
    {     12,   43,    5,  8,  7,  0 }, {     12,   44,    4,  8,  7,  0 }, {     12,   45,    3,  8,  7,  0 }, {     12,   45,    2,  8,  7,  0 }, {     11,   46,    1,  8,  7,  0 },
    {     11,   47,    0,  8,  7,  0 }, {     11,   47,   -1,  8,  7,  0 }, {     11,   48,   -2,  8,  7,  0 }, {     11,   48,   -3,  8,  7,  0 }, {     11,   49,   -4,  8,  7,  0 },
    {     11,   49,   -5,  8,  7,  0 }, {     11,   50,   -6,  8,  7,  0 }, {     11,   50,   -7,  8,  7,  0 }, {     11,   51,   -8,  8,  8,  0 }, {     10,   51,   -9,  8,  8,  0 },
    {     10,   52,  -10,  8,  8,  0 }, {     10,   52,  -11,  8,  8,  0 }, {     10,   53,  -12,  8,  8,  0 }, {     10,   53,  -13,  8,  8,  0 }, {     10,   53,  -14,  8,  8,  0 },
    {     10,   54,  -15,  8,  8,  0 }, {     10,   54,  -16,  8,  8,  0 }, {     10,   54,  -17,  8,  8,  0 }, {     10,   55,  -18,  8,  8,  0 }, {      9,   55,  -19,  8,  8,  0 },
    {      9,   56,  -20,  8,  8,  0 }, {      9,   56,  -21,  8,  8,  0 }, {      9,   56,  -22,  8,  8,  0 }, {      9,   57,  -23,  8, 17,  0 }, {      9,   57,  -24,  8, 17,  0 },
    {      9,   57,  -25,  8, 17,  0 }, {      9,   57,  -26,  8, 17,  0 }, {      9,   58,  -27,  8, 17,  0 }, {      8,   58,  -28,  8, 17,  0 }, {      8,   58,  -29,  8, 17,  0 },
    {      8,   58,  -30,  8, 17,  0 }, {      8,   59,  -31,  8, 17,  0 }, {      8,   59,  -32,  8, 17,  0 }, {      8,   59,  -33,  8, 17,  0 }, {      8,   59,  -34,  8, 17,  0 },
    {      8,   59,  -35,  8, 17,  0 }, {      8,   59,  -36,  8, 17,  0 }, {      8,   60,  -37,  8, 17,  0 }, {      7,   60,  -38,  8, 17,  0 }, {      7,   60,  -39,  8, 17,  0 },
    {      7,   60,  -40,  8, 17,  0 }, {      7,   60,  -41,  8, 17,  0 }, {      7,   60,  -42,  8, 17,  0 }, {      7,   60,  -43,  8, 17,  0 }, {      7,   60,  -44,  8, 17,  0 },
    {      7,   61,  -45,  8, 17,  0 }, {      7,   61,  -46,  8, 17,  0 }, {      7,   61,  -47,  8, 18,  0 }, {      6,   61,  -48,  8, 18,  0 }, {      6,   61,  -49,  8, 18,  0 },
    {      6,   61,  -50,  8, 18,  0 }, {      6,   61,  -51,  8, 18,  0 }, {      6,   61,  -52,  8, 18,  0 }, {      6,   61,  -53,  8, 18,  0 }, {      6,   61,  -54,  8, 18,  0 },
    {      6,   61,  -55,  8, 18,  0 }, {      6,   61,  -56,  8, 18,  0 }, {      5,   61,  -57,  8, 18,  0 }, {      5,   61,  -58,  8, 18,  0 }, {      5,   61,  -59,  8, 18,  0 },
    {      5,   61,  -60,  8, 18,  0 }, {      5,   61,  -61,  8, 18,  0 }, {      5,   61,  -62,  8, 18,  0 }, {      5,   61,  -63,  8, 18,  0 }, {      5,   61,  -64,  8, 18,  0 },
    {      5,   61,  -65,  8, 18,  0 }, {      5,   61,  -66,  8, 18,  0 }, {      4,   61,  -67,  8, 18,  0 }, {      4,   61,  -68,  8, 18,  0 }, {      4,   61,  -69,  8, 18,  0 },
    {      4,   61,  -70,  8, 18,  0 }, {      4,   61,  -71,  8, 18,  0 }, {      4,   61,  -72,  8, 18,  0 }, {      4,   61,  -73,  8, 18,  0 }, {      4,   61,  -74,  8, 18,  0 },
    {      4,   61,  -75,  8, 18,  0 }, {      4,   61,  -76,  8, 18,  0 }, {      3,   61,  -77,  8, 18,  0 }, {      3,   61,  -78,  8, 18,  0 }, {      3,   61,  -79,  8, 18,  0 },
    {      3,   61,  -80,  8, 18,  0 }, {      3,   61,  -81,  8, 18,  0 }, {      3,   61,  -82,  8, 18,  0 }, {      3,   61,  -83,  8, 18,  0 }, {      3,   61,  -84,  8, 19,  0 },
    {      3,   61,  -85,  8, 19,  0 }, {      3,   60,  -86,  8, 19,  0 }, {      2,   60,  -87,  8, 19,  0 }, {      2,   60,  -88,  8, 19,  0 }, {      2,   60,  -89,  8, 19,  0 },
    {      2,   60,  -90,  8, 19,  0 }, {      2,   60,  -91,  8, 19,  0 }, {      2,   59,  -92,  8, 19,  0 }, {      2,   59,  -93,  8, 19,  0 }, {      2,   59,  -94,  8, 19,  0 },
    {      2,   59,  -95,  8, 19,  0 }, {      1,   59,  -96,  8, 19,  0 }, {      1,   59,  -97,  8, 19,  0 }, {      1,   58,  -98,  8, 19,  0 }, {      1,   58,  -99,  8, 19,  0 },
    {      1,   58, -100,  8, 19,  0 }, {      1,   58, -101,  8, 19,  0 }, {      1,   58, -102,  8, 19,  0 }, {      1,   57, -103,  8, 19,  0 }, {      1,   57, -104,  8, 19,  0 },
    {      1,   57, -105,  8, 19,  0 }, {      0,   57, -106,  8, 19,  0 }, {      0,   56, -107,  8, 19,  0 }, {      0,   56, -108,  8, 19,  0 }, {      0,   56, -109,  8, 19,  0 },
    {      0,   55, -110,  8, 19,  0 }, {      0,   55, -111,  8, 19,  0 }, {      0,   55, -112,  8, 19,  0 }, {      0,   54, -113,  8, 19,  0 }, {      0,   54, -114,  8, 19,  0 },
    {      0,   54, -115,  8, 19,  0 }, {     -1,   54, -116,  8, 19,  0 }, {     -1,   53, -117,  8, 20,  0 }, {     -1,   53, -118,  8, 20,  0 }, {     -1,   53, -119,  8, 20,  0 },
    {     -1,   52, -120,  8, 20,  0 }, {     -1,   52, -121,  8, 20,  0 }, {     -1,   51, -122,  8, 20,  0 }, {     -1,   51, -123,  8, 20,  0 }, {     -1,   50, -124,  8, 20,  0 },
    {     -2,   50, -125,  8, 20,  0 }, {     -2,   50, -126,  8, 20,  0 }, {     -2,   49, -127,  8, 20,  0 }, {     -2,   49, -128,  8, 20,  0 }, {     -2,   48, -129,  8, 20,  0 },
    {     -2,   48, -130,  8, 20,  0 }, {     -2,   48, -131,  8, 20,  0 }, {     -2,   47, -132,  8, 20,  0 }, {     -2,   47, -133,  8, 20,  0 }, {     -2,   46, -134,  8, 20,  0 },
    {     -3,   46, -135,  8, 20,  0 }, {     -3,   45, -136,  8, 20,  0 }, {     -3,   45, -137,  8, 20,  0 }, {     -3,   45, -138,  8, 20,  0 }, {     -3,   44, -139,  8, 20,  0 },
    {     -3,   44, -140,  8, 20,  0 }, {     -3,   43, -141,  8, 20,  0 }, {     -3,   43, -142,  8, 20,  0 }, {     -3,   42, -143,  8, 20,  0 }, {     -3,   42, -144,  8, 20,  0 },
    {     -4,   41, -145,  8, 20,  0 }, {     -4,   41, -146,  8, 20,  0 }, {     -4,   40, -147,  8, 20,  0 }, {     -4,   39, -148,  8, 20,  0 }, {     -4,   39, -149,  8, 20,  0 },
    {     -4,   38, -150,  8, 20,  0 }, {     -4,   38, -151,  8, 20,  0 }, {     -4,   37, -152,  8, 20,  0 }, {     -4,   36, -153,  8, 21,  0 }, {     -4,   36, -154,  8, 21,  0 },
    {     -5,   35, -155,  8, 21,  0 }, {     -5,   35, -156,  8, 21,  0 }, {     -5,   34, -157,  8, 21,  0 }, {     -5,   33, -158,  8, 21,  0 }, {     -5,   33, -159,  8, 21,  0 },
    {     -5,   32, -160,  8, 21,  0 }, {     -5,   31, -161,  8, 21,  0 }, {     -5,   31, -162,  8, 21,  0 }, {     -5,   30, -163,  8, 21,  0 }, {     -6,   29, -164,  8, 21,  0 },
    {     -6,   28, -165,  8, 21,  0 }, {     -6,   28, -166,  8, 21,  0 }, {     -6,   27, -167,  8, 21,  0 }, {     -6,   26, -168,  8, 21,  0 }, {     -6,   26, -169,  8, 21,  0 },
    {     -6,   25, -170,  8, 21,  0 }, {     -6,   24, -171,  8, 21,  0 }, {     -6,   24, -172,  8, 21,  0 }, {     -6,   23, -173,  8, 21,  0 }, {     -7,   22, -174,  8, 21,  0 },
    {     -7,   21, -175,  8, 21,  0 }, {     -7,   20, -176,  8, 21,  0 }, {     -7,   19, -177,  8, 21,  0 }, {     -7,   18, -178,  8, 21,  0 }, {     -7,   17, -179,  8, 21,  0 },
    {     -7,   17, -180,  8, 21,  0 }, {     -7,   16, -181,  8, 21,  0 }, {     -7,   15, -182,  8, 21,  0 }, {     -7,   14, -183,  8, 21,  0 }, {     -8,   13, -184,  8, 21,  0 },
    {     -8,   12, -185,  8, 21,  0 }, {     -8,   11, -186,  8, 21,  0 }, {     -8,   10, -187,  8, 21,  0 }, {     -8,    9, -188,  8, 21,  0 }, {     -8,    8, -189,  8, 21,  0 },
    {     -8,    7, -190,  8, 21,  0 }, {     -8,    6, -190,  8, 21,  0 }, {     -8,    5, -191,  8, 21,  0 }, {     -9,    4, -192,  8, 21,  0 }, {     -9,    3, -193,  8, 21,  0 },
    {     -9,    2, -194,  8, 21,  0 }, {     -9,    1, -195,  8, 21,  0 }, {     -9,    0, -196,  8, 21,  0 }, {     -9,   -1, -196,  8, 21,  0 }, {     -9,   -2, -197,  8, 21,  0 },
    {     -9,   -3, -198,  8, 22,  0 }, {     -9,   -4, -199,  8, 22,  0 }, {     -9,   -5, -199,  8, 22,  0 }, {    -10,   -6, -200,  8, 22,  0 }, {    -10,   -7, -201,  8, 22,  0 },
    {    -10,   -8, -202,  8, 22,  0 }, {    -10,   -9, -202,  8, 22,  0 }, {    -10,  -10, -203,  8, 22,  0 }, {    -10,  -11, -204,  8, 22,  0 }, {    -10,  -12, -205,  8, 22,  0 },
    {    -10,  -13, -205,  8, 22,  0 }, {    -10,  -14, -206,  8, 22,  0 }, {    -10,  -15, -207,  8, 22,  0 }, {    -11,  -16, -207,  8, 22,  0 }, {    -11,  -17, -208,  8, 22,  0 },
    {    -11,  -18, -208,  8, 22,  0 }, {    -11,  -19, -209,  8, 22,  0 }, {    -11,  -20, -210,  8, 22,  0 }, {    -11,  -21, -210,  8, 22,  0 }, {    -11,  -22, -211,  8, 22,  0 },
    {    -11,  -23, -211,  8, 22,  0 }, {    -11,  -24, -212,  8, 22,  0 }, {    -11,  -25, -213,  8, 22,  0 }, {    -12,  -26, -213,  8, 22,  0 }, {    -12,  -27, -214,  8, 22,  0 },
    {    -12,  -28, -214,  8, 22,  0 }, {    -12,  -29, -215,  8, 22,  0 }, {    -12,  -30, -215,  8, 22,  0 }, {    -12,  -31, -216,  8, 22,  0 }, {    -12,  -32, -216,  8, 22,  0 },
    {    -12,  -33, -217,  8, 22,  0 }, {    -12,  -34, -217,  8, 22,  0 }, {    -13,  -35, -218,  8, 22,  0 }, {    -13,  -36, -218,  8, 22,  0 }, {    -13,  -37, -219,  8, 22,  0 },
    {    -13,  -38, -219,  8, 22,  0 }, {    -13,  -39, -220,  8, 22,  0 }, {    -13,  -40, -220,  8, 22,  0 }, {    -13,  -41, -221,  8, 22,  0 }, {    -13,  -42, -221,  8, 22,  0 },
    {    -13,  -43, -222,  8, 22,  0 }, {    -13,  -44, -222,  8, 22,  0 }, {    -14,  -45, -223,  8, 22,  0 }, {    -14,  -46, -223,  8, 22,  0 }, {    -14,  -47, -224,  8, 22,  0 },
    {    -14,  -48, -224,  8, 22,  0 }, {    -14,  -49, -225,  8, 22,  0 }, {    -14,  -50, -225,  8, 22,  0 }, {    -14,  -51, -226,  8, 22,  0 }, {    -14,  -52, -226,  8, 22,  0 },
    {    -14,  -53, -227,  8, 22,  0 }, {    -14,  -54, -227,  8, 22,  0 }, {    -15,  -55, -228,  8, 22,  0 }, {    -15,  -56, -228,  8, 22,  0 }, {    -15,  -57, -229,  8, 22,  0 },
    {    -15,  -58, -229,  8, 22,  0 }, {    -15,  -59, -230,  8, 22,  0 }, {    -15,  -60, -230,  8, 22,  0 }, {    -15,  -61, -231,  8, 22,  0 }, {    -15,  -62, -231,  8, 22,  0 },
    {    -15,  -63, -232,  8, 22,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_LeftFlyerLargeHalfLoopUninvertedDown2, {
    {      0,   16,   32, 16,  0,  0 }, {      1,   16,   32, 16,  0,  0 }, {      2,   16,   32, 16,  0,  0 }, {      3,   16,   32, 16,  0,  0 }, {      4,   16,   32, 16,  0,  0 },
    {      5,   16,   32, 16,  0,  0 }, {      6,   16,   32, 16,  0,  0 }, {      7,   16,   32, 16,  0,  0 }, {      8,   16,   31, 16,  0,  0 }, {      9,   16,   31, 16,  0,  0 },
    {     10,   17,   31, 16,  0,  0 }, {     11,   17,   31, 16,  0,  0 }, {     12,   17,   30, 16,  0,  0 }, {     13,   17,   30, 16,  0,  0 }, {     14,   17,   30, 16,  0,  0 },
    {     15,   17,   29, 16,  5,  0 }, {     16,   17,   29, 16,  5,  0 }, {     17,   17,   28, 16,  5,  0 }, {     18,   17,   28, 16,  5,  0 }, {     19,   17,   27, 16,  5,  0 },
    {     20,   18,   27, 16,  5,  0 }, {     21,   18,   26, 16,  5,  0 }, {     22,   18,   26, 16,  5,  0 }, {     23,   18,   25, 16,  5,  0 }, {     24,   18,   24, 16,  5,  0 },
    {     25,   18,   24, 16,  5,  0 }, {     26,   18,   23, 16,  5,  0 }, {     27,   18,   22, 16,  5,  0 }, {     28,   18,   21, 16,  5,  0 }, {     29,   18,   21, 16,  5,  0 },
    {     30,   19,   20, 16,  6,  0 }, {     31,   19,   19, 16,  6,  0 }, {     32,   19,   18, 16,  6,  0 }, {     33,   19,   17, 16,  6,  0 }, {     34,   19,   16, 16,  6,  0 },
    {     35,   19,   15, 16,  6,  0 }, {     36,   19,   14, 16,  6,  0 }, {     37,   19,   13, 16,  6,  0 }, {     38,   19,   12, 16,  6,  0 }, {     39,   20,   11, 16,  6,  0 },
    {     40,   20,   10, 16,  6,  0 }, {     40,   20,    9, 16,  6,  0 }, {     41,   20,    8, 16,  6,  0 }, {     42,   20,    7, 16,  7,  0 }, {     43,   20,    6, 16,  7,  0 },
    {     43,   20,    5, 16,  7,  0 }, {     44,   20,    4, 16,  7,  0 }, {     45,   20,    3, 16,  7,  0 }, {     45,   20,    2, 16,  7,  0 }, {     46,   21,    1, 16,  7,  0 },
    {     47,   21,    0, 16,  7,  0 }, {     47,   21,   -1, 16,  7,  0 }, {     48,   21,   -2, 16,  7,  0 }, {     48,   21,   -3, 16,  7,  0 }, {     49,   21,   -4, 16,  7,  0 },
    {     49,   21,   -5, 16,  7,  0 }, {     50,   21,   -6, 16,  7,  0 }, {     50,   21,   -7, 16,  7,  0 }, {     51,   21,   -8, 16,  8,  0 }, {     51,   22,   -9, 16,  8,  0 },
    {     52,   22,  -10, 16,  8,  0 }, {     52,   22,  -11, 16,  8,  0 }, {     53,   22,  -12, 16,  8,  0 }, {     53,   22,  -13, 16,  8,  0 }, {     53,   22,  -14, 16,  8,  0 },
    {     54,   22,  -15, 16,  8,  0 }, {     54,   22,  -16, 16,  8,  0 }, {     54,   22,  -17, 16,  8,  0 }, {     55,   22,  -18, 16,  8,  0 }, {     55,   23,  -19, 16,  8,  0 },
    {     56,   23,  -20, 16,  8,  0 }, {     56,   23,  -21, 16,  8,  0 }, {     56,   23,  -22, 16,  8,  0 }, {     57,   23,  -23, 16, 17,  0 }, {     57,   23,  -24, 16, 17,  0 },
    {     57,   23,  -25, 16, 17,  0 }, {     57,   23,  -26, 16, 17,  0 }, {     58,   23,  -27, 16, 17,  0 }, {     58,   24,  -28, 16, 17,  0 }, {     58,   24,  -29, 16, 17,  0 },
    {     58,   24,  -30, 16, 17,  0 }, {     59,   24,  -31, 16, 17,  0 }, {     59,   24,  -32, 16, 17,  0 }, {     59,   24,  -33, 16, 17,  0 }, {     59,   24,  -34, 16, 17,  0 },
    {     59,   24,  -35, 16, 17,  0 }, {     59,   24,  -36, 16, 17,  0 }, {     60,   24,  -37, 16, 17,  0 }, {     60,   25,  -38, 16, 17,  0 }, {     60,   25,  -39, 16, 17,  0 },
    {     60,   25,  -40, 16, 17,  0 }, {     60,   25,  -41, 16, 17,  0 }, {     60,   25,  -42, 16, 17,  0 }, {     60,   25,  -43, 16, 17,  0 }, {     60,   25,  -44, 16, 17,  0 },
    {     61,   25,  -45, 16, 17,  0 }, {     61,   25,  -46, 16, 17,  0 }, {     61,   25,  -47, 16, 18,  0 }, {     61,   26,  -48, 16, 18,  0 }, {     61,   26,  -49, 16, 18,  0 },
    {     61,   26,  -50, 16, 18,  0 }, {     61,   26,  -51, 16, 18,  0 }, {     61,   26,  -52, 16, 18,  0 }, {     61,   26,  -53, 16, 18,  0 }, {     61,   26,  -54, 16, 18,  0 },
    {     61,   26,  -55, 16, 18,  0 }, {     61,   26,  -56, 16, 18,  0 }, {     61,   27,  -57, 16, 18,  0 }, {     61,   27,  -58, 16, 18,  0 }, {     61,   27,  -59, 16, 18,  0 },
    {     61,   27,  -60, 16, 18,  0 }, {     61,   27,  -61, 16, 18,  0 }, {     61,   27,  -62, 16, 18,  0 }, {     61,   27,  -63, 16, 18,  0 }, {     61,   27,  -64, 16, 18,  0 },
    {     61,   27,  -65, 16, 18,  0 }, {     61,   27,  -66, 16, 18,  0 }, {     61,   28,  -67, 16, 18,  0 }, {     61,   28,  -68, 16, 18,  0 }, {     61,   28,  -69, 16, 18,  0 },
    {     61,   28,  -70, 16, 18,  0 }, {     61,   28,  -71, 16, 18,  0 }, {     61,   28,  -72, 16, 18,  0 }, {     61,   28,  -73, 16, 18,  0 }, {     61,   28,  -74, 16, 18,  0 },
    {     61,   28,  -75, 16, 18,  0 }, {     61,   28,  -76, 16, 18,  0 }, {     61,   29,  -77, 16, 18,  0 }, {     61,   29,  -78, 16, 18,  0 }, {     61,   29,  -79, 16, 18,  0 },
    {     61,   29,  -80, 16, 18,  0 }, {     61,   29,  -81, 16, 18,  0 }, {     61,   29,  -82, 16, 18,  0 }, {     61,   29,  -83, 16, 18,  0 }, {     61,   29,  -84, 16, 19,  0 },
    {     61,   29,  -85, 16, 19,  0 }, {     60,   29,  -86, 16, 19,  0 }, {     60,   30,  -87, 16, 19,  0 }, {     60,   30,  -88, 16, 19,  0 }, {     60,   30,  -89, 16, 19,  0 },
    {     60,   30,  -90, 16, 19,  0 }, {     60,   30,  -91, 16, 19,  0 }, {     59,   30,  -92, 16, 19,  0 }, {     59,   30,  -93, 16, 19,  0 }, {     59,   30,  -94, 16, 19,  0 },
    {     59,   30,  -95, 16, 19,  0 }, {     59,   31,  -96, 16, 19,  0 }, {     59,   31,  -97, 16, 19,  0 }, {     58,   31,  -98, 16, 19,  0 }, {     58,   31,  -99, 16, 19,  0 },
    {     58,   31, -100, 16, 19,  0 }, {     58,   31, -101, 16, 19,  0 }, {     58,   31, -102, 16, 19,  0 }, {     57,   31, -103, 16, 19,  0 }, {     57,   31, -104, 16, 19,  0 },
    {     57,   31, -105, 16, 19,  0 }, {     57,   32, -106, 16, 19,  0 }, {     56,   32, -107, 16, 19,  0 }, {     56,   32, -108, 16, 19,  0 }, {     56,   32, -109, 16, 19,  0 },
    {     55,   32, -110, 16, 19,  0 }, {     55,   32, -111, 16, 19,  0 }, {     55,   32, -112, 16, 19,  0 }, {     54,   32, -113, 16, 19,  0 }, {     54,   32, -114, 16, 19,  0 },
    {     54,   32, -115, 16, 19,  0 }, {     54,   33, -116, 16, 19,  0 }, {     53,   33, -117, 16, 20,  0 }, {     53,   33, -118, 16, 20,  0 }, {     53,   33, -119, 16, 20,  0 },
    {     52,   33, -120, 16, 20,  0 }, {     52,   33, -121, 16, 20,  0 }, {     51,   33, -122, 16, 20,  0 }, {     51,   33, -123, 16, 20,  0 }, {     50,   33, -124, 16, 20,  0 },
    {     50,   34, -125, 16, 20,  0 }, {     50,   34, -126, 16, 20,  0 }, {     49,   34, -127, 16, 20,  0 }, {     49,   34, -128, 16, 20,  0 }, {     48,   34, -129, 16, 20,  0 },
    {     48,   34, -130, 16, 20,  0 }, {     48,   34, -131, 16, 20,  0 }, {     47,   34, -132, 16, 20,  0 }, {     47,   34, -133, 16, 20,  0 }, {     46,   34, -134, 16, 20,  0 },
    {     46,   35, -135, 16, 20,  0 }, {     45,   35, -136, 16, 20,  0 }, {     45,   35, -137, 16, 20,  0 }, {     45,   35, -138, 16, 20,  0 }, {     44,   35, -139, 16, 20,  0 },
    {     44,   35, -140, 16, 20,  0 }, {     43,   35, -141, 16, 20,  0 }, {     43,   35, -142, 16, 20,  0 }, {     42,   35, -143, 16, 20,  0 }, {     42,   35, -144, 16, 20,  0 },
    {     41,   36, -145, 16, 20,  0 }, {     41,   36, -146, 16, 20,  0 }, {     40,   36, -147, 16, 20,  0 }, {     39,   36, -148, 16, 20,  0 }, {     39,   36, -149, 16, 20,  0 },
    {     38,   36, -150, 16, 20,  0 }, {     38,   36, -151, 16, 20,  0 }, {     37,   36, -152, 16, 20,  0 }, {     36,   36, -153, 16, 21,  0 }, {     36,   36, -154, 16, 21,  0 },
    {     35,   37, -155, 16, 21,  0 }, {     35,   37, -156, 16, 21,  0 }, {     34,   37, -157, 16, 21,  0 }, {     33,   37, -158, 16, 21,  0 }, {     33,   37, -159, 16, 21,  0 },
    {     32,   37, -160, 16, 21,  0 }, {     31,   37, -161, 16, 21,  0 }, {     31,   37, -162, 16, 21,  0 }, {     30,   37, -163, 16, 21,  0 }, {     29,   38, -164, 16, 21,  0 },
    {     28,   38, -165, 16, 21,  0 }, {     28,   38, -166, 16, 21,  0 }, {     27,   38, -167, 16, 21,  0 }, {     26,   38, -168, 16, 21,  0 }, {     26,   38, -169, 16, 21,  0 },
    {     25,   38, -170, 16, 21,  0 }, {     24,   38, -171, 16, 21,  0 }, {     24,   38, -172, 16, 21,  0 }, {     23,   38, -173, 16, 21,  0 }, {     22,   39, -174, 16, 21,  0 },
    {     21,   39, -175, 16, 21,  0 }, {     20,   39, -176, 16, 21,  0 }, {     19,   39, -177, 16, 21,  0 }, {     18,   39, -178, 16, 21,  0 }, {     17,   39, -179, 16, 21,  0 },
    {     17,   39, -180, 16, 21,  0 }, {     16,   39, -181, 16, 21,  0 }, {     15,   39, -182, 16, 21,  0 }, {     14,   39, -183, 16, 21,  0 }, {     13,   40, -184, 16, 21,  0 },
    {     12,   40, -185, 16, 21,  0 }, {     11,   40, -186, 16, 21,  0 }, {     10,   40, -187, 16, 21,  0 }, {      9,   40, -188, 16, 21,  0 }, {      8,   40, -189, 16, 21,  0 },
    {      7,   40, -190, 16, 21,  0 }, {      6,   40, -190, 16, 21,  0 }, {      5,   40, -191, 16, 21,  0 }, {      4,   41, -192, 16, 21,  0 }, {      3,   41, -193, 16, 21,  0 },
    {      2,   41, -194, 16, 21,  0 }, {      1,   41, -195, 16, 21,  0 }, {      0,   41, -196, 16, 21,  0 }, {     -1,   41, -196, 16, 21,  0 }, {     -2,   41, -197, 16, 21,  0 },
    {     -3,   41, -198, 16, 22,  0 }, {     -4,   41, -199, 16, 22,  0 }, {     -5,   41, -199, 16, 22,  0 }, {     -6,   42, -200, 16, 22,  0 }, {     -7,   42, -201, 16, 22,  0 },
    {     -8,   42, -202, 16, 22,  0 }, {     -9,   42, -202, 16, 22,  0 }, {    -10,   42, -203, 16, 22,  0 }, {    -11,   42, -204, 16, 22,  0 }, {    -12,   42, -205, 16, 22,  0 },
    {    -13,   42, -205, 16, 22,  0 }, {    -14,   42, -206, 16, 22,  0 }, {    -15,   42, -207, 16, 22,  0 }, {    -16,   43, -207, 16, 22,  0 }, {    -17,   43, -208, 16, 22,  0 },
    {    -18,   43, -208, 16, 22,  0 }, {    -19,   43, -209, 16, 22,  0 }, {    -20,   43, -210, 16, 22,  0 }, {    -21,   43, -210, 16, 22,  0 }, {    -22,   43, -211, 16, 22,  0 },
    {    -23,   43, -211, 16, 22,  0 }, {    -24,   43, -212, 16, 22,  0 }, {    -25,   43, -213, 16, 22,  0 }, {    -26,   44, -213, 16, 22,  0 }, {    -27,   44, -214, 16, 22,  0 },
    {    -28,   44, -214, 16, 22,  0 }, {    -29,   44, -215, 16, 22,  0 }, {    -30,   44, -215, 16, 22,  0 }, {    -31,   44, -216, 16, 22,  0 }, {    -32,   44, -216, 16, 22,  0 },
    {    -33,   44, -217, 16, 22,  0 }, {    -34,   44, -217, 16, 22,  0 }, {    -35,   45, -218, 16, 22,  0 }, {    -36,   45, -218, 16, 22,  0 }, {    -37,   45, -219, 16, 22,  0 },
    {    -38,   45, -219, 16, 22,  0 }, {    -39,   45, -220, 16, 22,  0 }, {    -40,   45, -220, 16, 22,  0 }, {    -41,   45, -221, 16, 22,  0 }, {    -42,   45, -221, 16, 22,  0 },
    {    -43,   45, -222, 16, 22,  0 }, {    -44,   45, -222, 16, 22,  0 }, {    -45,   46, -223, 16, 22,  0 }, {    -46,   46, -223, 16, 22,  0 }, {    -47,   46, -224, 16, 22,  0 },
    {    -48,   46, -224, 16, 22,  0 }, {    -49,   46, -225, 16, 22,  0 }, {    -50,   46, -225, 16, 22,  0 }, {    -51,   46, -226, 16, 22,  0 }, {    -52,   46, -226, 16, 22,  0 },
    {    -53,   46, -227, 16, 22,  0 }, {    -54,   46, -227, 16, 22,  0 }, {    -55,   47, -228, 16, 22,  0 }, {    -56,   47, -228, 16, 22,  0 }, {    -57,   47, -229, 16, 22,  0 },
    {    -58,   47, -229, 16, 22,  0 }, {    -59,   47, -230, 16, 22,  0 }, {    -60,   47, -230, 16, 22,  0 }, {    -61,   47, -231, 16, 22,  0 }, {    -62,   47, -231, 16, 22,  0 },
    {    -63,   47, -232, 16, 22,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_LeftFlyerLargeHalfLoopUninvertedDown3, {
    {     16,   31,   32, 24,  0,  0 }, {     16,   30,   32, 24,  0,  0 }, {     16,   29,   32, 24,  0,  0 }, {     16,   28,   32, 24,  0,  0 }, {     16,   27,   32, 24,  0,  0 },
    {     16,   26,   32, 24,  0,  0 }, {     16,   25,   32, 24,  0,  0 }, {     16,   24,   32, 24,  0,  0 }, {     16,   23,   31, 24,  0,  0 }, {     16,   22,   31, 24,  0,  0 },
    {     17,   21,   31, 24,  0,  0 }, {     17,   20,   31, 24,  0,  0 }, {     17,   19,   30, 24,  0,  0 }, {     17,   18,   30, 24,  0,  0 }, {     17,   17,   30, 24,  0,  0 },
    {     17,   16,   29, 24,  5,  0 }, {     17,   15,   29, 24,  5,  0 }, {     17,   14,   28, 24,  5,  0 }, {     17,   13,   28, 24,  5,  0 }, {     17,   12,   27, 24,  5,  0 },
    {     18,   11,   27, 24,  5,  0 }, {     18,   10,   26, 24,  5,  0 }, {     18,    9,   26, 24,  5,  0 }, {     18,    8,   25, 24,  5,  0 }, {     18,    7,   24, 24,  5,  0 },
    {     18,    6,   24, 24,  5,  0 }, {     18,    5,   23, 24,  5,  0 }, {     18,    4,   22, 24,  5,  0 }, {     18,    3,   21, 24,  5,  0 }, {     18,    2,   21, 24,  5,  0 },
    {     19,    1,   20, 24,  6,  0 }, {     19,    0,   19, 24,  6,  0 }, {     19,   -1,   18, 24,  6,  0 }, {     19,   -2,   17, 24,  6,  0 }, {     19,   -3,   16, 24,  6,  0 },
    {     19,   -4,   15, 24,  6,  0 }, {     19,   -5,   14, 24,  6,  0 }, {     19,   -6,   13, 24,  6,  0 }, {     19,   -7,   12, 24,  6,  0 }, {     20,   -8,   11, 24,  6,  0 },
    {     20,   -9,   10, 24,  6,  0 }, {     20,   -9,    9, 24,  6,  0 }, {     20,  -10,    8, 24,  6,  0 }, {     20,  -11,    7, 24,  7,  0 }, {     20,  -12,    6, 24,  7,  0 },
    {     20,  -12,    5, 24,  7,  0 }, {     20,  -13,    4, 24,  7,  0 }, {     20,  -14,    3, 24,  7,  0 }, {     20,  -14,    2, 24,  7,  0 }, {     21,  -15,    1, 24,  7,  0 },
    {     21,  -16,    0, 24,  7,  0 }, {     21,  -16,   -1, 24,  7,  0 }, {     21,  -17,   -2, 24,  7,  0 }, {     21,  -17,   -3, 24,  7,  0 }, {     21,  -18,   -4, 24,  7,  0 },
    {     21,  -18,   -5, 24,  7,  0 }, {     21,  -19,   -6, 24,  7,  0 }, {     21,  -19,   -7, 24,  7,  0 }, {     21,  -20,   -8, 24,  8,  0 }, {     22,  -20,   -9, 24,  8,  0 },
    {     22,  -21,  -10, 24,  8,  0 }, {     22,  -21,  -11, 24,  8,  0 }, {     22,  -22,  -12, 24,  8,  0 }, {     22,  -22,  -13, 24,  8,  0 }, {     22,  -22,  -14, 24,  8,  0 },
    {     22,  -23,  -15, 24,  8,  0 }, {     22,  -23,  -16, 24,  8,  0 }, {     22,  -23,  -17, 24,  8,  0 }, {     22,  -24,  -18, 24,  8,  0 }, {     23,  -24,  -19, 24,  8,  0 },
    {     23,  -25,  -20, 24,  8,  0 }, {     23,  -25,  -21, 24,  8,  0 }, {     23,  -25,  -22, 24,  8,  0 }, {     23,  -26,  -23, 24, 17,  0 }, {     23,  -26,  -24, 24, 17,  0 },
    {     23,  -26,  -25, 24, 17,  0 }, {     23,  -26,  -26, 24, 17,  0 }, {     23,  -27,  -27, 24, 17,  0 }, {     24,  -27,  -28, 24, 17,  0 }, {     24,  -27,  -29, 24, 17,  0 },
    {     24,  -27,  -30, 24, 17,  0 }, {     24,  -28,  -31, 24, 17,  0 }, {     24,  -28,  -32, 24, 17,  0 }, {     24,  -28,  -33, 24, 17,  0 }, {     24,  -28,  -34, 24, 17,  0 },
    {     24,  -28,  -35, 24, 17,  0 }, {     24,  -28,  -36, 24, 17,  0 }, {     24,  -29,  -37, 24, 17,  0 }, {     25,  -29,  -38, 24, 17,  0 }, {     25,  -29,  -39, 24, 17,  0 },
    {     25,  -29,  -40, 24, 17,  0 }, {     25,  -29,  -41, 24, 17,  0 }, {     25,  -29,  -42, 24, 17,  0 }, {     25,  -29,  -43, 24, 17,  0 }, {     25,  -29,  -44, 24, 17,  0 },
    {     25,  -30,  -45, 24, 17,  0 }, {     25,  -30,  -46, 24, 17,  0 }, {     25,  -30,  -47, 24, 18,  0 }, {     26,  -30,  -48, 24, 18,  0 }, {     26,  -30,  -49, 24, 18,  0 },
    {     26,  -30,  -50, 24, 18,  0 }, {     26,  -30,  -51, 24, 18,  0 }, {     26,  -30,  -52, 24, 18,  0 }, {     26,  -30,  -53, 24, 18,  0 }, {     26,  -30,  -54, 24, 18,  0 },
    {     26,  -30,  -55, 24, 18,  0 }, {     26,  -30,  -56, 24, 18,  0 }, {     27,  -30,  -57, 24, 18,  0 }, {     27,  -30,  -58, 24, 18,  0 }, {     27,  -30,  -59, 24, 18,  0 },
    {     27,  -30,  -60, 24, 18,  0 }, {     27,  -30,  -61, 24, 18,  0 }, {     27,  -30,  -62, 24, 18,  0 }, {     27,  -30,  -63, 24, 18,  0 }, {     27,  -30,  -64, 24, 18,  0 },
    {     27,  -30,  -65, 24, 18,  0 }, {     27,  -30,  -66, 24, 18,  0 }, {     28,  -30,  -67, 24, 18,  0 }, {     28,  -30,  -68, 24, 18,  0 }, {     28,  -30,  -69, 24, 18,  0 },
    {     28,  -30,  -70, 24, 18,  0 }, {     28,  -30,  -71, 24, 18,  0 }, {     28,  -30,  -72, 24, 18,  0 }, {     28,  -30,  -73, 24, 18,  0 }, {     28,  -30,  -74, 24, 18,  0 },
    {     28,  -30,  -75, 24, 18,  0 }, {     28,  -30,  -76, 24, 18,  0 }, {     29,  -30,  -77, 24, 18,  0 }, {     29,  -30,  -78, 24, 18,  0 }, {     29,  -30,  -79, 24, 18,  0 },
    {     29,  -30,  -80, 24, 18,  0 }, {     29,  -30,  -81, 24, 18,  0 }, {     29,  -30,  -82, 24, 18,  0 }, {     29,  -30,  -83, 24, 18,  0 }, {     29,  -30,  -84, 24, 19,  0 },
    {     29,  -30,  -85, 24, 19,  0 }, {     29,  -29,  -86, 24, 19,  0 }, {     30,  -29,  -87, 24, 19,  0 }, {     30,  -29,  -88, 24, 19,  0 }, {     30,  -29,  -89, 24, 19,  0 },
    {     30,  -29,  -90, 24, 19,  0 }, {     30,  -29,  -91, 24, 19,  0 }, {     30,  -28,  -92, 24, 19,  0 }, {     30,  -28,  -93, 24, 19,  0 }, {     30,  -28,  -94, 24, 19,  0 },
    {     30,  -28,  -95, 24, 19,  0 }, {     31,  -28,  -96, 24, 19,  0 }, {     31,  -28,  -97, 24, 19,  0 }, {     31,  -27,  -98, 24, 19,  0 }, {     31,  -27,  -99, 24, 19,  0 },
    {     31,  -27, -100, 24, 19,  0 }, {     31,  -27, -101, 24, 19,  0 }, {     31,  -27, -102, 24, 19,  0 }, {     31,  -26, -103, 24, 19,  0 }, {     31,  -26, -104, 24, 19,  0 },
    {     31,  -26, -105, 24, 19,  0 }, {     32,  -26, -106, 24, 19,  0 }, {     32,  -25, -107, 24, 19,  0 }, {     32,  -25, -108, 24, 19,  0 }, {     32,  -25, -109, 24, 19,  0 },
    {     32,  -24, -110, 24, 19,  0 }, {     32,  -24, -111, 24, 19,  0 }, {     32,  -24, -112, 24, 19,  0 }, {     32,  -23, -113, 24, 19,  0 }, {     32,  -23, -114, 24, 19,  0 },
    {     32,  -23, -115, 24, 19,  0 }, {     33,  -23, -116, 24, 19,  0 }, {     33,  -22, -117, 24, 20,  0 }, {     33,  -22, -118, 24, 20,  0 }, {     33,  -22, -119, 24, 20,  0 },
    {     33,  -21, -120, 24, 20,  0 }, {     33,  -21, -121, 24, 20,  0 }, {     33,  -20, -122, 24, 20,  0 }, {     33,  -20, -123, 24, 20,  0 }, {     33,  -19, -124, 24, 20,  0 },
    {     34,  -19, -125, 24, 20,  0 }, {     34,  -19, -126, 24, 20,  0 }, {     34,  -18, -127, 24, 20,  0 }, {     34,  -18, -128, 24, 20,  0 }, {     34,  -17, -129, 24, 20,  0 },
    {     34,  -17, -130, 24, 20,  0 }, {     34,  -17, -131, 24, 20,  0 }, {     34,  -16, -132, 24, 20,  0 }, {     34,  -16, -133, 24, 20,  0 }, {     34,  -15, -134, 24, 20,  0 },
    {     35,  -15, -135, 24, 20,  0 }, {     35,  -14, -136, 24, 20,  0 }, {     35,  -14, -137, 24, 20,  0 }, {     35,  -14, -138, 24, 20,  0 }, {     35,  -13, -139, 24, 20,  0 },
    {     35,  -13, -140, 24, 20,  0 }, {     35,  -12, -141, 24, 20,  0 }, {     35,  -12, -142, 24, 20,  0 }, {     35,  -11, -143, 24, 20,  0 }, {     35,  -11, -144, 24, 20,  0 },
    {     36,  -10, -145, 24, 20,  0 }, {     36,  -10, -146, 24, 20,  0 }, {     36,   -9, -147, 24, 20,  0 }, {     36,   -8, -148, 24, 20,  0 }, {     36,   -8, -149, 24, 20,  0 },
    {     36,   -7, -150, 24, 20,  0 }, {     36,   -7, -151, 24, 20,  0 }, {     36,   -6, -152, 24, 20,  0 }, {     36,   -5, -153, 24, 21,  0 }, {     36,   -5, -154, 24, 21,  0 },
    {     37,   -4, -155, 24, 21,  0 }, {     37,   -4, -156, 24, 21,  0 }, {     37,   -3, -157, 24, 21,  0 }, {     37,   -2, -158, 24, 21,  0 }, {     37,   -2, -159, 24, 21,  0 },
    {     37,   -1, -160, 24, 21,  0 }, {     37,    0, -161, 24, 21,  0 }, {     37,    0, -162, 24, 21,  0 }, {     37,    1, -163, 24, 21,  0 }, {     38,    2, -164, 24, 21,  0 },
    {     38,    3, -165, 24, 21,  0 }, {     38,    3, -166, 24, 21,  0 }, {     38,    4, -167, 24, 21,  0 }, {     38,    5, -168, 24, 21,  0 }, {     38,    5, -169, 24, 21,  0 },
    {     38,    6, -170, 24, 21,  0 }, {     38,    7, -171, 24, 21,  0 }, {     38,    7, -172, 24, 21,  0 }, {     38,    8, -173, 24, 21,  0 }, {     39,    9, -174, 24, 21,  0 },
    {     39,   10, -175, 24, 21,  0 }, {     39,   11, -176, 24, 21,  0 }, {     39,   12, -177, 24, 21,  0 }, {     39,   13, -178, 24, 21,  0 }, {     39,   14, -179, 24, 21,  0 },
    {     39,   14, -180, 24, 21,  0 }, {     39,   15, -181, 24, 21,  0 }, {     39,   16, -182, 24, 21,  0 }, {     39,   17, -183, 24, 21,  0 }, {     40,   18, -184, 24, 21,  0 },
    {     40,   19, -185, 24, 21,  0 }, {     40,   20, -186, 24, 21,  0 }, {     40,   21, -187, 24, 21,  0 }, {     40,   22, -188, 24, 21,  0 }, {     40,   23, -189, 24, 21,  0 },
    {     40,   24, -190, 24, 21,  0 }, {     40,   25, -190, 24, 21,  0 }, {     40,   26, -191, 24, 21,  0 }, {     41,   27, -192, 24, 21,  0 }, {     41,   28, -193, 24, 21,  0 },
    {     41,   29, -194, 24, 21,  0 }, {     41,   30, -195, 24, 21,  0 }, {     41,   31, -196, 24, 21,  0 }, {     41,   32, -196, 24, 21,  0 }, {     41,   33, -197, 24, 21,  0 },
    {     41,   34, -198, 24, 22,  0 }, {     41,   35, -199, 24, 22,  0 }, {     41,   36, -199, 24, 22,  0 }, {     42,   37, -200, 24, 22,  0 }, {     42,   38, -201, 24, 22,  0 },
    {     42,   39, -202, 24, 22,  0 }, {     42,   40, -202, 24, 22,  0 }, {     42,   41, -203, 24, 22,  0 }, {     42,   42, -204, 24, 22,  0 }, {     42,   43, -205, 24, 22,  0 },
    {     42,   44, -205, 24, 22,  0 }, {     42,   45, -206, 24, 22,  0 }, {     42,   46, -207, 24, 22,  0 }, {     43,   47, -207, 24, 22,  0 }, {     43,   48, -208, 24, 22,  0 },
    {     43,   49, -208, 24, 22,  0 }, {     43,   50, -209, 24, 22,  0 }, {     43,   51, -210, 24, 22,  0 }, {     43,   52, -210, 24, 22,  0 }, {     43,   53, -211, 24, 22,  0 },
    {     43,   54, -211, 24, 22,  0 }, {     43,   55, -212, 24, 22,  0 }, {     43,   56, -213, 24, 22,  0 }, {     44,   57, -213, 24, 22,  0 }, {     44,   58, -214, 24, 22,  0 },
    {     44,   59, -214, 24, 22,  0 }, {     44,   60, -215, 24, 22,  0 }, {     44,   61, -215, 24, 22,  0 }, {     44,   62, -216, 24, 22,  0 }, {     44,   63, -216, 24, 22,  0 },
    {     44,   64, -217, 24, 22,  0 }, {     44,   65, -217, 24, 22,  0 }, {     45,   66, -218, 24, 22,  0 }, {     45,   67, -218, 24, 22,  0 }, {     45,   68, -219, 24, 22,  0 },
    {     45,   69, -219, 24, 22,  0 }, {     45,   70, -220, 24, 22,  0 }, {     45,   71, -220, 24, 22,  0 }, {     45,   72, -221, 24, 22,  0 }, {     45,   73, -221, 24, 22,  0 },
    {     45,   74, -222, 24, 22,  0 }, {     45,   75, -222, 24, 22,  0 }, {     46,   76, -223, 24, 22,  0 }, {     46,   77, -223, 24, 22,  0 }, {     46,   78, -224, 24, 22,  0 },
    {     46,   79, -224, 24, 22,  0 }, {     46,   80, -225, 24, 22,  0 }, {     46,   81, -225, 24, 22,  0 }, {     46,   82, -226, 24, 22,  0 }, {     46,   83, -226, 24, 22,  0 },
    {     46,   84, -227, 24, 22,  0 }, {     46,   85, -227, 24, 22,  0 }, {     47,   86, -228, 24, 22,  0 }, {     47,   87, -228, 24, 22,  0 }, {     47,   88, -229, 24, 22,  0 },
    {     47,   89, -229, 24, 22,  0 }, {     47,   90, -230, 24, 22,  0 }, {     47,   91, -230, 24, 22,  0 }, {     47,   92, -231, 24, 22,  0 }, {     47,   93, -231, 24, 22,  0 },
    {     47,   94, -232, 24, 22,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_RightFlyerLargeHalfLoopUninvertedDown0, {
    {     31,   16,   32,  0,  0,  0 }, {     30,   16,   32,  0,  0,  0 }, {     29,   16,   32,  0,  0,  0 }, {     28,   16,   32,  0,  0,  0 }, {     27,   16,   32,  0,  0,  0 },
    {     26,   16,   32,  0,  0,  0 }, {     25,   16,   32,  0,  0,  0 }, {     24,   16,   32,  0,  0,  0 }, {     23,   16,   31,  0,  0,  0 }, {     22,   16,   31,  0,  0,  0 },
    {     21,   17,   31,  0,  0,  0 }, {     20,   17,   31,  0,  0,  0 }, {     19,   17,   30,  0,  0,  0 }, {     18,   17,   30,  0,  0,  0 }, {     17,   17,   30,  0,  0,  0 },
    {     16,   17,   29,  0,  5,  0 }, {     15,   17,   29,  0,  5,  0 }, {     14,   17,   28,  0,  5,  0 }, {     13,   17,   28,  0,  5,  0 }, {     12,   17,   27,  0,  5,  0 },
    {     11,   18,   27,  0,  5,  0 }, {     10,   18,   26,  0,  5,  0 }, {      9,   18,   26,  0,  5,  0 }, {      8,   18,   25,  0,  5,  0 }, {      7,   18,   24,  0,  5,  0 },
    {      6,   18,   24,  0,  5,  0 }, {      5,   18,   23,  0,  5,  0 }, {      4,   18,   22,  0,  5,  0 }, {      3,   18,   21,  0,  5,  0 }, {      2,   18,   21,  0,  5,  0 },
    {      1,   19,   20,  0,  6,  0 }, {      0,   19,   19,  0,  6,  0 }, {     -1,   19,   18,  0,  6,  0 }, {     -2,   19,   17,  0,  6,  0 }, {     -3,   19,   16,  0,  6,  0 },
    {     -4,   19,   15,  0,  6,  0 }, {     -5,   19,   14,  0,  6,  0 }, {     -6,   19,   13,  0,  6,  0 }, {     -7,   19,   12,  0,  6,  0 }, {     -8,   20,   11,  0,  6,  0 },
    {     -9,   20,   10,  0,  6,  0 }, {     -9,   20,    9,  0,  6,  0 }, {    -10,   20,    8,  0,  6,  0 }, {    -11,   20,    7,  0,  7,  0 }, {    -12,   20,    6,  0,  7,  0 },
    {    -12,   20,    5,  0,  7,  0 }, {    -13,   20,    4,  0,  7,  0 }, {    -14,   20,    3,  0,  7,  0 }, {    -14,   20,    2,  0,  7,  0 }, {    -15,   21,    1,  0,  7,  0 },
    {    -16,   21,    0,  0,  7,  0 }, {    -16,   21,   -1,  0,  7,  0 }, {    -17,   21,   -2,  0,  7,  0 }, {    -17,   21,   -3,  0,  7,  0 }, {    -18,   21,   -4,  0,  7,  0 },
    {    -18,   21,   -5,  0,  7,  0 }, {    -19,   21,   -6,  0,  7,  0 }, {    -19,   21,   -7,  0,  7,  0 }, {    -20,   21,   -8,  0,  8,  0 }, {    -20,   22,   -9,  0,  8,  0 },
    {    -21,   22,  -10,  0,  8,  0 }, {    -21,   22,  -11,  0,  8,  0 }, {    -22,   22,  -12,  0,  8,  0 }, {    -22,   22,  -13,  0,  8,  0 }, {    -22,   22,  -14,  0,  8,  0 },
    {    -23,   22,  -15,  0,  8,  0 }, {    -23,   22,  -16,  0,  8,  0 }, {    -23,   22,  -17,  0,  8,  0 }, {    -24,   22,  -18,  0,  8,  0 }, {    -24,   23,  -19,  0,  8,  0 },
    {    -25,   23,  -20,  0,  8,  0 }, {    -25,   23,  -21,  0,  8,  0 }, {    -25,   23,  -22,  0,  8,  0 }, {    -26,   23,  -23,  0, 17,  0 }, {    -26,   23,  -24,  0, 17,  0 },
    {    -26,   23,  -25,  0, 17,  0 }, {    -26,   23,  -26,  0, 17,  0 }, {    -27,   23,  -27,  0, 17,  0 }, {    -27,   24,  -28,  0, 17,  0 }, {    -27,   24,  -29,  0, 17,  0 },
    {    -27,   24,  -30,  0, 17,  0 }, {    -28,   24,  -31,  0, 17,  0 }, {    -28,   24,  -32,  0, 17,  0 }, {    -28,   24,  -33,  0, 17,  0 }, {    -28,   24,  -34,  0, 17,  0 },
    {    -28,   24,  -35,  0, 17,  0 }, {    -28,   24,  -36,  0, 17,  0 }, {    -29,   24,  -37,  0, 17,  0 }, {    -29,   25,  -38,  0, 17,  0 }, {    -29,   25,  -39,  0, 17,  0 },
    {    -29,   25,  -40,  0, 17,  0 }, {    -29,   25,  -41,  0, 17,  0 }, {    -29,   25,  -42,  0, 17,  0 }, {    -29,   25,  -43,  0, 17,  0 }, {    -29,   25,  -44,  0, 17,  0 },
    {    -30,   25,  -45,  0, 17,  0 }, {    -30,   25,  -46,  0, 17,  0 }, {    -30,   25,  -47,  0, 18,  0 }, {    -30,   26,  -48,  0, 18,  0 }, {    -30,   26,  -49,  0, 18,  0 },
    {    -30,   26,  -50,  0, 18,  0 }, {    -30,   26,  -51,  0, 18,  0 }, {    -30,   26,  -52,  0, 18,  0 }, {    -30,   26,  -53,  0, 18,  0 }, {    -30,   26,  -54,  0, 18,  0 },
    {    -30,   26,  -55,  0, 18,  0 }, {    -30,   26,  -56,  0, 18,  0 }, {    -30,   27,  -57,  0, 18,  0 }, {    -30,   27,  -58,  0, 18,  0 }, {    -30,   27,  -59,  0, 18,  0 },
    {    -30,   27,  -60,  0, 18,  0 }, {    -30,   27,  -61,  0, 18,  0 }, {    -30,   27,  -62,  0, 18,  0 }, {    -30,   27,  -63,  0, 18,  0 }, {    -30,   27,  -64,  0, 18,  0 },
    {    -30,   27,  -65,  0, 18,  0 }, {    -30,   27,  -66,  0, 18,  0 }, {    -30,   28,  -67,  0, 18,  0 }, {    -30,   28,  -68,  0, 18,  0 }, {    -30,   28,  -69,  0, 18,  0 },
    {    -30,   28,  -70,  0, 18,  0 }, {    -30,   28,  -71,  0, 18,  0 }, {    -30,   28,  -72,  0, 18,  0 }, {    -30,   28,  -73,  0, 18,  0 }, {    -30,   28,  -74,  0, 18,  0 },
    {    -30,   28,  -75,  0, 18,  0 }, {    -30,   28,  -76,  0, 18,  0 }, {    -30,   29,  -77,  0, 18,  0 }, {    -30,   29,  -78,  0, 18,  0 }, {    -30,   29,  -79,  0, 18,  0 },
    {    -30,   29,  -80,  0, 18,  0 }, {    -30,   29,  -81,  0, 18,  0 }, {    -30,   29,  -82,  0, 18,  0 }, {    -30,   29,  -83,  0, 18,  0 }, {    -30,   29,  -84,  0, 19,  0 },
    {    -30,   29,  -85,  0, 19,  0 }, {    -29,   29,  -86,  0, 19,  0 }, {    -29,   30,  -87,  0, 19,  0 }, {    -29,   30,  -88,  0, 19,  0 }, {    -29,   30,  -89,  0, 19,  0 },
    {    -29,   30,  -90,  0, 19,  0 }, {    -29,   30,  -91,  0, 19,  0 }, {    -28,   30,  -92,  0, 19,  0 }, {    -28,   30,  -93,  0, 19,  0 }, {    -28,   30,  -94,  0, 19,  0 },
    {    -28,   30,  -95,  0, 19,  0 }, {    -28,   31,  -96,  0, 19,  0 }, {    -28,   31,  -97,  0, 19,  0 }, {    -27,   31,  -98,  0, 19,  0 }, {    -27,   31,  -99,  0, 19,  0 },
    {    -27,   31, -100,  0, 19,  0 }, {    -27,   31, -101,  0, 19,  0 }, {    -27,   31, -102,  0, 19,  0 }, {    -26,   31, -103,  0, 19,  0 }, {    -26,   31, -104,  0, 19,  0 },
    {    -26,   31, -105,  0, 19,  0 }, {    -26,   32, -106,  0, 19,  0 }, {    -25,   32, -107,  0, 19,  0 }, {    -25,   32, -108,  0, 19,  0 }, {    -25,   32, -109,  0, 19,  0 },
    {    -24,   32, -110,  0, 19,  0 }, {    -24,   32, -111,  0, 19,  0 }, {    -24,   32, -112,  0, 19,  0 }, {    -23,   32, -113,  0, 19,  0 }, {    -23,   32, -114,  0, 19,  0 },
    {    -23,   32, -115,  0, 19,  0 }, {    -23,   33, -116,  0, 19,  0 }, {    -22,   33, -117,  0, 20,  0 }, {    -22,   33, -118,  0, 20,  0 }, {    -22,   33, -119,  0, 20,  0 },
    {    -21,   33, -120,  0, 20,  0 }, {    -21,   33, -121,  0, 20,  0 }, {    -20,   33, -122,  0, 20,  0 }, {    -20,   33, -123,  0, 20,  0 }, {    -19,   33, -124,  0, 20,  0 },
    {    -19,   34, -125,  0, 20,  0 }, {    -19,   34, -126,  0, 20,  0 }, {    -18,   34, -127,  0, 20,  0 }, {    -18,   34, -128,  0, 20,  0 }, {    -17,   34, -129,  0, 20,  0 },
    {    -17,   34, -130,  0, 20,  0 }, {    -17,   34, -131,  0, 20,  0 }, {    -16,   34, -132,  0, 20,  0 }, {    -16,   34, -133,  0, 20,  0 }, {    -15,   34, -134,  0, 20,  0 },
    {    -15,   35, -135,  0, 20,  0 }, {    -14,   35, -136,  0, 20,  0 }, {    -14,   35, -137,  0, 20,  0 }, {    -14,   35, -138,  0, 20,  0 }, {    -13,   35, -139,  0, 20,  0 },
    {    -13,   35, -140,  0, 20,  0 }, {    -12,   35, -141,  0, 20,  0 }, {    -12,   35, -142,  0, 20,  0 }, {    -11,   35, -143,  0, 20,  0 }, {    -11,   35, -144,  0, 20,  0 },
    {    -10,   36, -145,  0, 20,  0 }, {    -10,   36, -146,  0, 20,  0 }, {     -9,   36, -147,  0, 20,  0 }, {     -8,   36, -148,  0, 20,  0 }, {     -8,   36, -149,  0, 20,  0 },
    {     -7,   36, -150,  0, 20,  0 }, {     -7,   36, -151,  0, 20,  0 }, {     -6,   36, -152,  0, 20,  0 }, {     -5,   36, -153,  0, 21,  0 }, {     -5,   36, -154,  0, 21,  0 },
    {     -4,   37, -155,  0, 21,  0 }, {     -4,   37, -156,  0, 21,  0 }, {     -3,   37, -157,  0, 21,  0 }, {     -2,   37, -158,  0, 21,  0 }, {     -2,   37, -159,  0, 21,  0 },
    {     -1,   37, -160,  0, 21,  0 }, {      0,   37, -161,  0, 21,  0 }, {      0,   37, -162,  0, 21,  0 }, {      1,   37, -163,  0, 21,  0 }, {      2,   38, -164,  0, 21,  0 },
    {      3,   38, -165,  0, 21,  0 }, {      3,   38, -166,  0, 21,  0 }, {      4,   38, -167,  0, 21,  0 }, {      5,   38, -168,  0, 21,  0 }, {      5,   38, -169,  0, 21,  0 },
    {      6,   38, -170,  0, 21,  0 }, {      7,   38, -171,  0, 21,  0 }, {      7,   38, -172,  0, 21,  0 }, {      8,   38, -173,  0, 21,  0 }, {      9,   39, -174,  0, 21,  0 },
    {     10,   39, -175,  0, 21,  0 }, {     11,   39, -176,  0, 21,  0 }, {     12,   39, -177,  0, 21,  0 }, {     13,   39, -178,  0, 21,  0 }, {     14,   39, -179,  0, 21,  0 },
    {     14,   39, -180,  0, 21,  0 }, {     15,   39, -181,  0, 21,  0 }, {     16,   39, -182,  0, 21,  0 }, {     17,   39, -183,  0, 21,  0 }, {     18,   40, -184,  0, 21,  0 },
    {     19,   40, -185,  0, 21,  0 }, {     20,   40, -186,  0, 21,  0 }, {     21,   40, -187,  0, 21,  0 }, {     22,   40, -188,  0, 21,  0 }, {     23,   40, -189,  0, 21,  0 },
    {     24,   40, -190,  0, 21,  0 }, {     25,   40, -190,  0, 21,  0 }, {     26,   40, -191,  0, 21,  0 }, {     27,   41, -192,  0, 21,  0 }, {     28,   41, -193,  0, 21,  0 },
    {     29,   41, -194,  0, 21,  0 }, {     30,   41, -195,  0, 21,  0 }, {     31,   41, -196,  0, 21,  0 }, {     32,   41, -196,  0, 21,  0 }, {     33,   41, -197,  0, 21,  0 },
    {     34,   41, -198,  0, 22,  0 }, {     35,   41, -199,  0, 22,  0 }, {     36,   41, -199,  0, 22,  0 }, {     37,   42, -200,  0, 22,  0 }, {     38,   42, -201,  0, 22,  0 },
    {     39,   42, -202,  0, 22,  0 }, {     40,   42, -202,  0, 22,  0 }, {     41,   42, -203,  0, 22,  0 }, {     42,   42, -204,  0, 22,  0 }, {     43,   42, -205,  0, 22,  0 },
    {     44,   42, -205,  0, 22,  0 }, {     45,   42, -206,  0, 22,  0 }, {     46,   42, -207,  0, 22,  0 }, {     47,   43, -207,  0, 22,  0 }, {     48,   43, -208,  0, 22,  0 },
    {     49,   43, -208,  0, 22,  0 }, {     50,   43, -209,  0, 22,  0 }, {     51,   43, -210,  0, 22,  0 }, {     52,   43, -210,  0, 22,  0 }, {     53,   43, -211,  0, 22,  0 },
    {     54,   43, -211,  0, 22,  0 }, {     55,   43, -212,  0, 22,  0 }, {     56,   43, -213,  0, 22,  0 }, {     57,   44, -213,  0, 22,  0 }, {     58,   44, -214,  0, 22,  0 },
    {     59,   44, -214,  0, 22,  0 }, {     60,   44, -215,  0, 22,  0 }, {     61,   44, -215,  0, 22,  0 }, {     62,   44, -216,  0, 22,  0 }, {     63,   44, -216,  0, 22,  0 },
    {     64,   44, -217,  0, 22,  0 }, {     65,   44, -217,  0, 22,  0 }, {     66,   45, -218,  0, 22,  0 }, {     67,   45, -218,  0, 22,  0 }, {     68,   45, -219,  0, 22,  0 },
    {     69,   45, -219,  0, 22,  0 }, {     70,   45, -220,  0, 22,  0 }, {     71,   45, -220,  0, 22,  0 }, {     72,   45, -221,  0, 22,  0 }, {     73,   45, -221,  0, 22,  0 },
    {     74,   45, -222,  0, 22,  0 }, {     75,   45, -222,  0, 22,  0 }, {     76,   46, -223,  0, 22,  0 }, {     77,   46, -223,  0, 22,  0 }, {     78,   46, -224,  0, 22,  0 },
    {     79,   46, -224,  0, 22,  0 }, {     80,   46, -225,  0, 22,  0 }, {     81,   46, -225,  0, 22,  0 }, {     82,   46, -226,  0, 22,  0 }, {     83,   46, -226,  0, 22,  0 },
    {     84,   46, -227,  0, 22,  0 }, {     85,   46, -227,  0, 22,  0 }, {     86,   47, -228,  0, 22,  0 }, {     87,   47, -228,  0, 22,  0 }, {     88,   47, -229,  0, 22,  0 },
    {     89,   47, -229,  0, 22,  0 }, {     90,   47, -230,  0, 22,  0 }, {     91,   47, -230,  0, 22,  0 }, {     92,   47, -231,  0, 22,  0 }, {     93,   47, -231,  0, 22,  0 },
    {     94,   47, -232,  0, 22,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_RightFlyerLargeHalfLoopUninvertedDown1, {
    {     16,    0,   32,  8,  0,  0 }, {     16,    1,   32,  8,  0,  0 }, {     16,    2,   32,  8,  0,  0 }, {     16,    3,   32,  8,  0,  0 }, {     16,    4,   32,  8,  0,  0 },
    {     16,    5,   32,  8,  0,  0 }, {     16,    6,   32,  8,  0,  0 }, {     16,    7,   32,  8,  0,  0 }, {     16,    8,   31,  8,  0,  0 }, {     16,    9,   31,  8,  0,  0 },
    {     17,   10,   31,  8,  0,  0 }, {     17,   11,   31,  8,  0,  0 }, {     17,   12,   30,  8,  0,  0 }, {     17,   13,   30,  8,  0,  0 }, {     17,   14,   30,  8,  0,  0 },
    {     17,   15,   29,  8,  5,  0 }, {     17,   16,   29,  8,  5,  0 }, {     17,   17,   28,  8,  5,  0 }, {     17,   18,   28,  8,  5,  0 }, {     17,   19,   27,  8,  5,  0 },
    {     18,   20,   27,  8,  5,  0 }, {     18,   21,   26,  8,  5,  0 }, {     18,   22,   26,  8,  5,  0 }, {     18,   23,   25,  8,  5,  0 }, {     18,   24,   24,  8,  5,  0 },
    {     18,   25,   24,  8,  5,  0 }, {     18,   26,   23,  8,  5,  0 }, {     18,   27,   22,  8,  5,  0 }, {     18,   28,   21,  8,  5,  0 }, {     18,   29,   21,  8,  5,  0 },
    {     19,   30,   20,  8,  6,  0 }, {     19,   31,   19,  8,  6,  0 }, {     19,   32,   18,  8,  6,  0 }, {     19,   33,   17,  8,  6,  0 }, {     19,   34,   16,  8,  6,  0 },
    {     19,   35,   15,  8,  6,  0 }, {     19,   36,   14,  8,  6,  0 }, {     19,   37,   13,  8,  6,  0 }, {     19,   38,   12,  8,  6,  0 }, {     20,   39,   11,  8,  6,  0 },
    {     20,   40,   10,  8,  6,  0 }, {     20,   40,    9,  8,  6,  0 }, {     20,   41,    8,  8,  6,  0 }, {     20,   42,    7,  8,  7,  0 }, {     20,   43,    6,  8,  7,  0 },
    {     20,   43,    5,  8,  7,  0 }, {     20,   44,    4,  8,  7,  0 }, {     20,   45,    3,  8,  7,  0 }, {     20,   45,    2,  8,  7,  0 }, {     21,   46,    1,  8,  7,  0 },
    {     21,   47,    0,  8,  7,  0 }, {     21,   47,   -1,  8,  7,  0 }, {     21,   48,   -2,  8,  7,  0 }, {     21,   48,   -3,  8,  7,  0 }, {     21,   49,   -4,  8,  7,  0 },
    {     21,   49,   -5,  8,  7,  0 }, {     21,   50,   -6,  8,  7,  0 }, {     21,   50,   -7,  8,  7,  0 }, {     21,   51,   -8,  8,  8,  0 }, {     22,   51,   -9,  8,  8,  0 },
    {     22,   52,  -10,  8,  8,  0 }, {     22,   52,  -11,  8,  8,  0 }, {     22,   53,  -12,  8,  8,  0 }, {     22,   53,  -13,  8,  8,  0 }, {     22,   53,  -14,  8,  8,  0 },
    {     22,   54,  -15,  8,  8,  0 }, {     22,   54,  -16,  8,  8,  0 }, {     22,   54,  -17,  8,  8,  0 }, {     22,   55,  -18,  8,  8,  0 }, {     23,   55,  -19,  8,  8,  0 },
    {     23,   56,  -20,  8,  8,  0 }, {     23,   56,  -21,  8,  8,  0 }, {     23,   56,  -22,  8,  8,  0 }, {     23,   57,  -23,  8, 17,  0 }, {     23,   57,  -24,  8, 17,  0 },
    {     23,   57,  -25,  8, 17,  0 }, {     23,   57,  -26,  8, 17,  0 }, {     23,   58,  -27,  8, 17,  0 }, {     24,   58,  -28,  8, 17,  0 }, {     24,   58,  -29,  8, 17,  0 },
    {     24,   58,  -30,  8, 17,  0 }, {     24,   59,  -31,  8, 17,  0 }, {     24,   59,  -32,  8, 17,  0 }, {     24,   59,  -33,  8, 17,  0 }, {     24,   59,  -34,  8, 17,  0 },
    {     24,   59,  -35,  8, 17,  0 }, {     24,   59,  -36,  8, 17,  0 }, {     24,   60,  -37,  8, 17,  0 }, {     25,   60,  -38,  8, 17,  0 }, {     25,   60,  -39,  8, 17,  0 },
    {     25,   60,  -40,  8, 17,  0 }, {     25,   60,  -41,  8, 17,  0 }, {     25,   60,  -42,  8, 17,  0 }, {     25,   60,  -43,  8, 17,  0 }, {     25,   60,  -44,  8, 17,  0 },
    {     25,   61,  -45,  8, 17,  0 }, {     25,   61,  -46,  8, 17,  0 }, {     25,   61,  -47,  8, 18,  0 }, {     26,   61,  -48,  8, 18,  0 }, {     26,   61,  -49,  8, 18,  0 },
    {     26,   61,  -50,  8, 18,  0 }, {     26,   61,  -51,  8, 18,  0 }, {     26,   61,  -52,  8, 18,  0 }, {     26,   61,  -53,  8, 18,  0 }, {     26,   61,  -54,  8, 18,  0 },
    {     26,   61,  -55,  8, 18,  0 }, {     26,   61,  -56,  8, 18,  0 }, {     27,   61,  -57,  8, 18,  0 }, {     27,   61,  -58,  8, 18,  0 }, {     27,   61,  -59,  8, 18,  0 },
    {     27,   61,  -60,  8, 18,  0 }, {     27,   61,  -61,  8, 18,  0 }, {     27,   61,  -62,  8, 18,  0 }, {     27,   61,  -63,  8, 18,  0 }, {     27,   61,  -64,  8, 18,  0 },
    {     27,   61,  -65,  8, 18,  0 }, {     27,   61,  -66,  8, 18,  0 }, {     28,   61,  -67,  8, 18,  0 }, {     28,   61,  -68,  8, 18,  0 }, {     28,   61,  -69,  8, 18,  0 },
    {     28,   61,  -70,  8, 18,  0 }, {     28,   61,  -71,  8, 18,  0 }, {     28,   61,  -72,  8, 18,  0 }, {     28,   61,  -73,  8, 18,  0 }, {     28,   61,  -74,  8, 18,  0 },
    {     28,   61,  -75,  8, 18,  0 }, {     28,   61,  -76,  8, 18,  0 }, {     29,   61,  -77,  8, 18,  0 }, {     29,   61,  -78,  8, 18,  0 }, {     29,   61,  -79,  8, 18,  0 },
    {     29,   61,  -80,  8, 18,  0 }, {     29,   61,  -81,  8, 18,  0 }, {     29,   61,  -82,  8, 18,  0 }, {     29,   61,  -83,  8, 18,  0 }, {     29,   61,  -84,  8, 19,  0 },
    {     29,   61,  -85,  8, 19,  0 }, {     29,   60,  -86,  8, 19,  0 }, {     30,   60,  -87,  8, 19,  0 }, {     30,   60,  -88,  8, 19,  0 }, {     30,   60,  -89,  8, 19,  0 },
    {     30,   60,  -90,  8, 19,  0 }, {     30,   60,  -91,  8, 19,  0 }, {     30,   59,  -92,  8, 19,  0 }, {     30,   59,  -93,  8, 19,  0 }, {     30,   59,  -94,  8, 19,  0 },
    {     30,   59,  -95,  8, 19,  0 }, {     31,   59,  -96,  8, 19,  0 }, {     31,   59,  -97,  8, 19,  0 }, {     31,   58,  -98,  8, 19,  0 }, {     31,   58,  -99,  8, 19,  0 },
    {     31,   58, -100,  8, 19,  0 }, {     31,   58, -101,  8, 19,  0 }, {     31,   58, -102,  8, 19,  0 }, {     31,   57, -103,  8, 19,  0 }, {     31,   57, -104,  8, 19,  0 },
    {     31,   57, -105,  8, 19,  0 }, {     32,   57, -106,  8, 19,  0 }, {     32,   56, -107,  8, 19,  0 }, {     32,   56, -108,  8, 19,  0 }, {     32,   56, -109,  8, 19,  0 },
    {     32,   55, -110,  8, 19,  0 }, {     32,   55, -111,  8, 19,  0 }, {     32,   55, -112,  8, 19,  0 }, {     32,   54, -113,  8, 19,  0 }, {     32,   54, -114,  8, 19,  0 },
    {     32,   54, -115,  8, 19,  0 }, {     33,   54, -116,  8, 19,  0 }, {     33,   53, -117,  8, 20,  0 }, {     33,   53, -118,  8, 20,  0 }, {     33,   53, -119,  8, 20,  0 },
    {     33,   52, -120,  8, 20,  0 }, {     33,   52, -121,  8, 20,  0 }, {     33,   51, -122,  8, 20,  0 }, {     33,   51, -123,  8, 20,  0 }, {     33,   50, -124,  8, 20,  0 },
    {     34,   50, -125,  8, 20,  0 }, {     34,   50, -126,  8, 20,  0 }, {     34,   49, -127,  8, 20,  0 }, {     34,   49, -128,  8, 20,  0 }, {     34,   48, -129,  8, 20,  0 },
    {     34,   48, -130,  8, 20,  0 }, {     34,   48, -131,  8, 20,  0 }, {     34,   47, -132,  8, 20,  0 }, {     34,   47, -133,  8, 20,  0 }, {     34,   46, -134,  8, 20,  0 },
    {     35,   46, -135,  8, 20,  0 }, {     35,   45, -136,  8, 20,  0 }, {     35,   45, -137,  8, 20,  0 }, {     35,   45, -138,  8, 20,  0 }, {     35,   44, -139,  8, 20,  0 },
    {     35,   44, -140,  8, 20,  0 }, {     35,   43, -141,  8, 20,  0 }, {     35,   43, -142,  8, 20,  0 }, {     35,   42, -143,  8, 20,  0 }, {     35,   42, -144,  8, 20,  0 },
    {     36,   41, -145,  8, 20,  0 }, {     36,   41, -146,  8, 20,  0 }, {     36,   40, -147,  8, 20,  0 }, {     36,   39, -148,  8, 20,  0 }, {     36,   39, -149,  8, 20,  0 },
    {     36,   38, -150,  8, 20,  0 }, {     36,   38, -151,  8, 20,  0 }, {     36,   37, -152,  8, 20,  0 }, {     36,   36, -153,  8, 21,  0 }, {     36,   36, -154,  8, 21,  0 },
    {     37,   35, -155,  8, 21,  0 }, {     37,   35, -156,  8, 21,  0 }, {     37,   34, -157,  8, 21,  0 }, {     37,   33, -158,  8, 21,  0 }, {     37,   33, -159,  8, 21,  0 },
    {     37,   32, -160,  8, 21,  0 }, {     37,   31, -161,  8, 21,  0 }, {     37,   31, -162,  8, 21,  0 }, {     37,   30, -163,  8, 21,  0 }, {     38,   29, -164,  8, 21,  0 },
    {     38,   28, -165,  8, 21,  0 }, {     38,   28, -166,  8, 21,  0 }, {     38,   27, -167,  8, 21,  0 }, {     38,   26, -168,  8, 21,  0 }, {     38,   26, -169,  8, 21,  0 },
    {     38,   25, -170,  8, 21,  0 }, {     38,   24, -171,  8, 21,  0 }, {     38,   24, -172,  8, 21,  0 }, {     38,   23, -173,  8, 21,  0 }, {     39,   22, -174,  8, 21,  0 },
    {     39,   21, -175,  8, 21,  0 }, {     39,   20, -176,  8, 21,  0 }, {     39,   19, -177,  8, 21,  0 }, {     39,   18, -178,  8, 21,  0 }, {     39,   17, -179,  8, 21,  0 },
    {     39,   17, -180,  8, 21,  0 }, {     39,   16, -181,  8, 21,  0 }, {     39,   15, -182,  8, 21,  0 }, {     39,   14, -183,  8, 21,  0 }, {     40,   13, -184,  8, 21,  0 },
    {     40,   12, -185,  8, 21,  0 }, {     40,   11, -186,  8, 21,  0 }, {     40,   10, -187,  8, 21,  0 }, {     40,    9, -188,  8, 21,  0 }, {     40,    8, -189,  8, 21,  0 },
    {     40,    7, -190,  8, 21,  0 }, {     40,    6, -190,  8, 21,  0 }, {     40,    5, -191,  8, 21,  0 }, {     41,    4, -192,  8, 21,  0 }, {     41,    3, -193,  8, 21,  0 },
    {     41,    2, -194,  8, 21,  0 }, {     41,    1, -195,  8, 21,  0 }, {     41,    0, -196,  8, 21,  0 }, {     41,   -1, -196,  8, 21,  0 }, {     41,   -2, -197,  8, 21,  0 },
    {     41,   -3, -198,  8, 22,  0 }, {     41,   -4, -199,  8, 22,  0 }, {     41,   -5, -199,  8, 22,  0 }, {     42,   -6, -200,  8, 22,  0 }, {     42,   -7, -201,  8, 22,  0 },
    {     42,   -8, -202,  8, 22,  0 }, {     42,   -9, -202,  8, 22,  0 }, {     42,  -10, -203,  8, 22,  0 }, {     42,  -11, -204,  8, 22,  0 }, {     42,  -12, -205,  8, 22,  0 },
    {     42,  -13, -205,  8, 22,  0 }, {     42,  -14, -206,  8, 22,  0 }, {     42,  -15, -207,  8, 22,  0 }, {     43,  -16, -207,  8, 22,  0 }, {     43,  -17, -208,  8, 22,  0 },
    {     43,  -18, -208,  8, 22,  0 }, {     43,  -19, -209,  8, 22,  0 }, {     43,  -20, -210,  8, 22,  0 }, {     43,  -21, -210,  8, 22,  0 }, {     43,  -22, -211,  8, 22,  0 },
    {     43,  -23, -211,  8, 22,  0 }, {     43,  -24, -212,  8, 22,  0 }, {     43,  -25, -213,  8, 22,  0 }, {     44,  -26, -213,  8, 22,  0 }, {     44,  -27, -214,  8, 22,  0 },
    {     44,  -28, -214,  8, 22,  0 }, {     44,  -29, -215,  8, 22,  0 }, {     44,  -30, -215,  8, 22,  0 }, {     44,  -31, -216,  8, 22,  0 }, {     44,  -32, -216,  8, 22,  0 },
    {     44,  -33, -217,  8, 22,  0 }, {     44,  -34, -217,  8, 22,  0 }, {     45,  -35, -218,  8, 22,  0 }, {     45,  -36, -218,  8, 22,  0 }, {     45,  -37, -219,  8, 22,  0 },
    {     45,  -38, -219,  8, 22,  0 }, {     45,  -39, -220,  8, 22,  0 }, {     45,  -40, -220,  8, 22,  0 }, {     45,  -41, -221,  8, 22,  0 }, {     45,  -42, -221,  8, 22,  0 },
    {     45,  -43, -222,  8, 22,  0 }, {     45,  -44, -222,  8, 22,  0 }, {     46,  -45, -223,  8, 22,  0 }, {     46,  -46, -223,  8, 22,  0 }, {     46,  -47, -224,  8, 22,  0 },
    {     46,  -48, -224,  8, 22,  0 }, {     46,  -49, -225,  8, 22,  0 }, {     46,  -50, -225,  8, 22,  0 }, {     46,  -51, -226,  8, 22,  0 }, {     46,  -52, -226,  8, 22,  0 },
    {     46,  -53, -227,  8, 22,  0 }, {     46,  -54, -227,  8, 22,  0 }, {     47,  -55, -228,  8, 22,  0 }, {     47,  -56, -228,  8, 22,  0 }, {     47,  -57, -229,  8, 22,  0 },
    {     47,  -58, -229,  8, 22,  0 }, {     47,  -59, -230,  8, 22,  0 }, {     47,  -60, -230,  8, 22,  0 }, {     47,  -61, -231,  8, 22,  0 }, {     47,  -62, -231,  8, 22,  0 },
    {     47,  -63, -232,  8, 22,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_RightFlyerLargeHalfLoopUninvertedDown2, {
    {      0,   16,   32, 16,  0,  0 }, {      1,   16,   32, 16,  0,  0 }, {      2,   16,   32, 16,  0,  0 }, {      3,   16,   32, 16,  0,  0 }, {      4,   16,   32, 16,  0,  0 },
    {      5,   16,   32, 16,  0,  0 }, {      6,   16,   32, 16,  0,  0 }, {      7,   16,   32, 16,  0,  0 }, {      8,   16,   31, 16,  0,  0 }, {      9,   16,   31, 16,  0,  0 },
    {     10,   15,   31, 16,  0,  0 }, {     11,   15,   31, 16,  0,  0 }, {     12,   15,   30, 16,  0,  0 }, {     13,   15,   30, 16,  0,  0 }, {     14,   15,   30, 16,  0,  0 },
    {     15,   15,   29, 16,  5,  0 }, {     16,   15,   29, 16,  5,  0 }, {     17,   15,   28, 16,  5,  0 }, {     18,   15,   28, 16,  5,  0 }, {     19,   15,   27, 16,  5,  0 },
    {     20,   14,   27, 16,  5,  0 }, {     21,   14,   26, 16,  5,  0 }, {     22,   14,   26, 16,  5,  0 }, {     23,   14,   25, 16,  5,  0 }, {     24,   14,   24, 16,  5,  0 },
    {     25,   14,   24, 16,  5,  0 }, {     26,   14,   23, 16,  5,  0 }, {     27,   14,   22, 16,  5,  0 }, {     28,   14,   21, 16,  5,  0 }, {     29,   14,   21, 16,  5,  0 },
    {     30,   13,   20, 16,  6,  0 }, {     31,   13,   19, 16,  6,  0 }, {     32,   13,   18, 16,  6,  0 }, {     33,   13,   17, 16,  6,  0 }, {     34,   13,   16, 16,  6,  0 },
    {     35,   13,   15, 16,  6,  0 }, {     36,   13,   14, 16,  6,  0 }, {     37,   13,   13, 16,  6,  0 }, {     38,   13,   12, 16,  6,  0 }, {     39,   12,   11, 16,  6,  0 },
    {     40,   12,   10, 16,  6,  0 }, {     40,   12,    9, 16,  6,  0 }, {     41,   12,    8, 16,  6,  0 }, {     42,   12,    7, 16,  7,  0 }, {     43,   12,    6, 16,  7,  0 },
    {     43,   12,    5, 16,  7,  0 }, {     44,   12,    4, 16,  7,  0 }, {     45,   12,    3, 16,  7,  0 }, {     45,   12,    2, 16,  7,  0 }, {     46,   11,    1, 16,  7,  0 },
    {     47,   11,    0, 16,  7,  0 }, {     47,   11,   -1, 16,  7,  0 }, {     48,   11,   -2, 16,  7,  0 }, {     48,   11,   -3, 16,  7,  0 }, {     49,   11,   -4, 16,  7,  0 },
    {     49,   11,   -5, 16,  7,  0 }, {     50,   11,   -6, 16,  7,  0 }, {     50,   11,   -7, 16,  7,  0 }, {     51,   11,   -8, 16,  8,  0 }, {     51,   10,   -9, 16,  8,  0 },
    {     52,   10,  -10, 16,  8,  0 }, {     52,   10,  -11, 16,  8,  0 }, {     53,   10,  -12, 16,  8,  0 }, {     53,   10,  -13, 16,  8,  0 }, {     53,   10,  -14, 16,  8,  0 },
    {     54,   10,  -15, 16,  8,  0 }, {     54,   10,  -16, 16,  8,  0 }, {     54,   10,  -17, 16,  8,  0 }, {     55,   10,  -18, 16,  8,  0 }, {     55,    9,  -19, 16,  8,  0 },
    {     56,    9,  -20, 16,  8,  0 }, {     56,    9,  -21, 16,  8,  0 }, {     56,    9,  -22, 16,  8,  0 }, {     57,    9,  -23, 16, 17,  0 }, {     57,    9,  -24, 16, 17,  0 },
    {     57,    9,  -25, 16, 17,  0 }, {     57,    9,  -26, 16, 17,  0 }, {     58,    9,  -27, 16, 17,  0 }, {     58,    8,  -28, 16, 17,  0 }, {     58,    8,  -29, 16, 17,  0 },
    {     58,    8,  -30, 16, 17,  0 }, {     59,    8,  -31, 16, 17,  0 }, {     59,    8,  -32, 16, 17,  0 }, {     59,    8,  -33, 16, 17,  0 }, {     59,    8,  -34, 16, 17,  0 },
    {     59,    8,  -35, 16, 17,  0 }, {     59,    8,  -36, 16, 17,  0 }, {     60,    8,  -37, 16, 17,  0 }, {     60,    7,  -38, 16, 17,  0 }, {     60,    7,  -39, 16, 17,  0 },
    {     60,    7,  -40, 16, 17,  0 }, {     60,    7,  -41, 16, 17,  0 }, {     60,    7,  -42, 16, 17,  0 }, {     60,    7,  -43, 16, 17,  0 }, {     60,    7,  -44, 16, 17,  0 },
    {     61,    7,  -45, 16, 17,  0 }, {     61,    7,  -46, 16, 17,  0 }, {     61,    7,  -47, 16, 18,  0 }, {     61,    6,  -48, 16, 18,  0 }, {     61,    6,  -49, 16, 18,  0 },
    {     61,    6,  -50, 16, 18,  0 }, {     61,    6,  -51, 16, 18,  0 }, {     61,    6,  -52, 16, 18,  0 }, {     61,    6,  -53, 16, 18,  0 }, {     61,    6,  -54, 16, 18,  0 },
    {     61,    6,  -55, 16, 18,  0 }, {     61,    6,  -56, 16, 18,  0 }, {     61,    5,  -57, 16, 18,  0 }, {     61,    5,  -58, 16, 18,  0 }, {     61,    5,  -59, 16, 18,  0 },
    {     61,    5,  -60, 16, 18,  0 }, {     61,    5,  -61, 16, 18,  0 }, {     61,    5,  -62, 16, 18,  0 }, {     61,    5,  -63, 16, 18,  0 }, {     61,    5,  -64, 16, 18,  0 },
    {     61,    5,  -65, 16, 18,  0 }, {     61,    5,  -66, 16, 18,  0 }, {     61,    4,  -67, 16, 18,  0 }, {     61,    4,  -68, 16, 18,  0 }, {     61,    4,  -69, 16, 18,  0 },
    {     61,    4,  -70, 16, 18,  0 }, {     61,    4,  -71, 16, 18,  0 }, {     61,    4,  -72, 16, 18,  0 }, {     61,    4,  -73, 16, 18,  0 }, {     61,    4,  -74, 16, 18,  0 },
    {     61,    4,  -75, 16, 18,  0 }, {     61,    4,  -76, 16, 18,  0 }, {     61,    3,  -77, 16, 18,  0 }, {     61,    3,  -78, 16, 18,  0 }, {     61,    3,  -79, 16, 18,  0 },
    {     61,    3,  -80, 16, 18,  0 }, {     61,    3,  -81, 16, 18,  0 }, {     61,    3,  -82, 16, 18,  0 }, {     61,    3,  -83, 16, 18,  0 }, {     61,    3,  -84, 16, 19,  0 },
    {     61,    3,  -85, 16, 19,  0 }, {     60,    3,  -86, 16, 19,  0 }, {     60,    2,  -87, 16, 19,  0 }, {     60,    2,  -88, 16, 19,  0 }, {     60,    2,  -89, 16, 19,  0 },
    {     60,    2,  -90, 16, 19,  0 }, {     60,    2,  -91, 16, 19,  0 }, {     59,    2,  -92, 16, 19,  0 }, {     59,    2,  -93, 16, 19,  0 }, {     59,    2,  -94, 16, 19,  0 },
    {     59,    2,  -95, 16, 19,  0 }, {     59,    1,  -96, 16, 19,  0 }, {     59,    1,  -97, 16, 19,  0 }, {     58,    1,  -98, 16, 19,  0 }, {     58,    1,  -99, 16, 19,  0 },
    {     58,    1, -100, 16, 19,  0 }, {     58,    1, -101, 16, 19,  0 }, {     58,    1, -102, 16, 19,  0 }, {     57,    1, -103, 16, 19,  0 }, {     57,    1, -104, 16, 19,  0 },
    {     57,    1, -105, 16, 19,  0 }, {     57,    0, -106, 16, 19,  0 }, {     56,    0, -107, 16, 19,  0 }, {     56,    0, -108, 16, 19,  0 }, {     56,    0, -109, 16, 19,  0 },
    {     55,    0, -110, 16, 19,  0 }, {     55,    0, -111, 16, 19,  0 }, {     55,    0, -112, 16, 19,  0 }, {     54,    0, -113, 16, 19,  0 }, {     54,    0, -114, 16, 19,  0 },
    {     54,    0, -115, 16, 19,  0 }, {     54,   -1, -116, 16, 19,  0 }, {     53,   -1, -117, 16, 20,  0 }, {     53,   -1, -118, 16, 20,  0 }, {     53,   -1, -119, 16, 20,  0 },
    {     52,   -1, -120, 16, 20,  0 }, {     52,   -1, -121, 16, 20,  0 }, {     51,   -1, -122, 16, 20,  0 }, {     51,   -1, -123, 16, 20,  0 }, {     50,   -1, -124, 16, 20,  0 },
    {     50,   -2, -125, 16, 20,  0 }, {     50,   -2, -126, 16, 20,  0 }, {     49,   -2, -127, 16, 20,  0 }, {     49,   -2, -128, 16, 20,  0 }, {     48,   -2, -129, 16, 20,  0 },
    {     48,   -2, -130, 16, 20,  0 }, {     48,   -2, -131, 16, 20,  0 }, {     47,   -2, -132, 16, 20,  0 }, {     47,   -2, -133, 16, 20,  0 }, {     46,   -2, -134, 16, 20,  0 },
    {     46,   -3, -135, 16, 20,  0 }, {     45,   -3, -136, 16, 20,  0 }, {     45,   -3, -137, 16, 20,  0 }, {     45,   -3, -138, 16, 20,  0 }, {     44,   -3, -139, 16, 20,  0 },
    {     44,   -3, -140, 16, 20,  0 }, {     43,   -3, -141, 16, 20,  0 }, {     43,   -3, -142, 16, 20,  0 }, {     42,   -3, -143, 16, 20,  0 }, {     42,   -3, -144, 16, 20,  0 },
    {     41,   -4, -145, 16, 20,  0 }, {     41,   -4, -146, 16, 20,  0 }, {     40,   -4, -147, 16, 20,  0 }, {     39,   -4, -148, 16, 20,  0 }, {     39,   -4, -149, 16, 20,  0 },
    {     38,   -4, -150, 16, 20,  0 }, {     38,   -4, -151, 16, 20,  0 }, {     37,   -4, -152, 16, 20,  0 }, {     36,   -4, -153, 16, 21,  0 }, {     36,   -4, -154, 16, 21,  0 },
    {     35,   -5, -155, 16, 21,  0 }, {     35,   -5, -156, 16, 21,  0 }, {     34,   -5, -157, 16, 21,  0 }, {     33,   -5, -158, 16, 21,  0 }, {     33,   -5, -159, 16, 21,  0 },
    {     32,   -5, -160, 16, 21,  0 }, {     31,   -5, -161, 16, 21,  0 }, {     31,   -5, -162, 16, 21,  0 }, {     30,   -5, -163, 16, 21,  0 }, {     29,   -6, -164, 16, 21,  0 },
    {     28,   -6, -165, 16, 21,  0 }, {     28,   -6, -166, 16, 21,  0 }, {     27,   -6, -167, 16, 21,  0 }, {     26,   -6, -168, 16, 21,  0 }, {     26,   -6, -169, 16, 21,  0 },
    {     25,   -6, -170, 16, 21,  0 }, {     24,   -6, -171, 16, 21,  0 }, {     24,   -6, -172, 16, 21,  0 }, {     23,   -6, -173, 16, 21,  0 }, {     22,   -7, -174, 16, 21,  0 },
    {     21,   -7, -175, 16, 21,  0 }, {     20,   -7, -176, 16, 21,  0 }, {     19,   -7, -177, 16, 21,  0 }, {     18,   -7, -178, 16, 21,  0 }, {     17,   -7, -179, 16, 21,  0 },
    {     17,   -7, -180, 16, 21,  0 }, {     16,   -7, -181, 16, 21,  0 }, {     15,   -7, -182, 16, 21,  0 }, {     14,   -7, -183, 16, 21,  0 }, {     13,   -8, -184, 16, 21,  0 },
    {     12,   -8, -185, 16, 21,  0 }, {     11,   -8, -186, 16, 21,  0 }, {     10,   -8, -187, 16, 21,  0 }, {      9,   -8, -188, 16, 21,  0 }, {      8,   -8, -189, 16, 21,  0 },
    {      7,   -8, -190, 16, 21,  0 }, {      6,   -8, -190, 16, 21,  0 }, {      5,   -8, -191, 16, 21,  0 }, {      4,   -9, -192, 16, 21,  0 }, {      3,   -9, -193, 16, 21,  0 },
    {      2,   -9, -194, 16, 21,  0 }, {      1,   -9, -195, 16, 21,  0 }, {      0,   -9, -196, 16, 21,  0 }, {     -1,   -9, -196, 16, 21,  0 }, {     -2,   -9, -197, 16, 21,  0 },
    {     -3,   -9, -198, 16, 22,  0 }, {     -4,   -9, -199, 16, 22,  0 }, {     -5,   -9, -199, 16, 22,  0 }, {     -6,  -10, -200, 16, 22,  0 }, {     -7,  -10, -201, 16, 22,  0 },
    {     -8,  -10, -202, 16, 22,  0 }, {     -9,  -10, -202, 16, 22,  0 }, {    -10,  -10, -203, 16, 22,  0 }, {    -11,  -10, -204, 16, 22,  0 }, {    -12,  -10, -205, 16, 22,  0 },
    {    -13,  -10, -205, 16, 22,  0 }, {    -14,  -10, -206, 16, 22,  0 }, {    -15,  -10, -207, 16, 22,  0 }, {    -16,  -11, -207, 16, 22,  0 }, {    -17,  -11, -208, 16, 22,  0 },
    {    -18,  -11, -208, 16, 22,  0 }, {    -19,  -11, -209, 16, 22,  0 }, {    -20,  -11, -210, 16, 22,  0 }, {    -21,  -11, -210, 16, 22,  0 }, {    -22,  -11, -211, 16, 22,  0 },
    {    -23,  -11, -211, 16, 22,  0 }, {    -24,  -11, -212, 16, 22,  0 }, {    -25,  -11, -213, 16, 22,  0 }, {    -26,  -12, -213, 16, 22,  0 }, {    -27,  -12, -214, 16, 22,  0 },
    {    -28,  -12, -214, 16, 22,  0 }, {    -29,  -12, -215, 16, 22,  0 }, {    -30,  -12, -215, 16, 22,  0 }, {    -31,  -12, -216, 16, 22,  0 }, {    -32,  -12, -216, 16, 22,  0 },
    {    -33,  -12, -217, 16, 22,  0 }, {    -34,  -12, -217, 16, 22,  0 }, {    -35,  -13, -218, 16, 22,  0 }, {    -36,  -13, -218, 16, 22,  0 }, {    -37,  -13, -219, 16, 22,  0 },
    {    -38,  -13, -219, 16, 22,  0 }, {    -39,  -13, -220, 16, 22,  0 }, {    -40,  -13, -220, 16, 22,  0 }, {    -41,  -13, -221, 16, 22,  0 }, {    -42,  -13, -221, 16, 22,  0 },
    {    -43,  -13, -222, 16, 22,  0 }, {    -44,  -13, -222, 16, 22,  0 }, {    -45,  -14, -223, 16, 22,  0 }, {    -46,  -14, -223, 16, 22,  0 }, {    -47,  -14, -224, 16, 22,  0 },
    {    -48,  -14, -224, 16, 22,  0 }, {    -49,  -14, -225, 16, 22,  0 }, {    -50,  -14, -225, 16, 22,  0 }, {    -51,  -14, -226, 16, 22,  0 }, {    -52,  -14, -226, 16, 22,  0 },
    {    -53,  -14, -227, 16, 22,  0 }, {    -54,  -14, -227, 16, 22,  0 }, {    -55,  -15, -228, 16, 22,  0 }, {    -56,  -15, -228, 16, 22,  0 }, {    -57,  -15, -229, 16, 22,  0 },
    {    -58,  -15, -229, 16, 22,  0 }, {    -59,  -15, -230, 16, 22,  0 }, {    -60,  -15, -230, 16, 22,  0 }, {    -61,  -15, -231, 16, 22,  0 }, {    -62,  -15, -231, 16, 22,  0 },
    {    -63,  -15, -232, 16, 22,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_RightFlyerLargeHalfLoopUninvertedDown3, {
    {     16,   31,   32, 24,  0,  0 }, {     16,   30,   32, 24,  0,  0 }, {     16,   29,   32, 24,  0,  0 }, {     16,   28,   32, 24,  0,  0 }, {     16,   27,   32, 24,  0,  0 },
    {     16,   26,   32, 24,  0,  0 }, {     16,   25,   32, 24,  0,  0 }, {     16,   24,   32, 24,  0,  0 }, {     16,   23,   31, 24,  0,  0 }, {     16,   22,   31, 24,  0,  0 },
    {     15,   21,   31, 24,  0,  0 }, {     15,   20,   31, 24,  0,  0 }, {     15,   19,   30, 24,  0,  0 }, {     15,   18,   30, 24,  0,  0 }, {     15,   17,   30, 24,  0,  0 },
    {     15,   16,   29, 24,  5,  0 }, {     15,   15,   29, 24,  5,  0 }, {     15,   14,   28, 24,  5,  0 }, {     15,   13,   28, 24,  5,  0 }, {     15,   12,   27, 24,  5,  0 },
    {     14,   11,   27, 24,  5,  0 }, {     14,   10,   26, 24,  5,  0 }, {     14,    9,   26, 24,  5,  0 }, {     14,    8,   25, 24,  5,  0 }, {     14,    7,   24, 24,  5,  0 },
    {     14,    6,   24, 24,  5,  0 }, {     14,    5,   23, 24,  5,  0 }, {     14,    4,   22, 24,  5,  0 }, {     14,    3,   21, 24,  5,  0 }, {     14,    2,   21, 24,  5,  0 },
    {     13,    1,   20, 24,  6,  0 }, {     13,    0,   19, 24,  6,  0 }, {     13,   -1,   18, 24,  6,  0 }, {     13,   -2,   17, 24,  6,  0 }, {     13,   -3,   16, 24,  6,  0 },
    {     13,   -4,   15, 24,  6,  0 }, {     13,   -5,   14, 24,  6,  0 }, {     13,   -6,   13, 24,  6,  0 }, {     13,   -7,   12, 24,  6,  0 }, {     12,   -8,   11, 24,  6,  0 },
    {     12,   -9,   10, 24,  6,  0 }, {     12,   -9,    9, 24,  6,  0 }, {     12,  -10,    8, 24,  6,  0 }, {     12,  -11,    7, 24,  7,  0 }, {     12,  -12,    6, 24,  7,  0 },
    {     12,  -12,    5, 24,  7,  0 }, {     12,  -13,    4, 24,  7,  0 }, {     12,  -14,    3, 24,  7,  0 }, {     12,  -14,    2, 24,  7,  0 }, {     11,  -15,    1, 24,  7,  0 },
    {     11,  -16,    0, 24,  7,  0 }, {     11,  -16,   -1, 24,  7,  0 }, {     11,  -17,   -2, 24,  7,  0 }, {     11,  -17,   -3, 24,  7,  0 }, {     11,  -18,   -4, 24,  7,  0 },
    {     11,  -18,   -5, 24,  7,  0 }, {     11,  -19,   -6, 24,  7,  0 }, {     11,  -19,   -7, 24,  7,  0 }, {     11,  -20,   -8, 24,  8,  0 }, {     10,  -20,   -9, 24,  8,  0 },
    {     10,  -21,  -10, 24,  8,  0 }, {     10,  -21,  -11, 24,  8,  0 }, {     10,  -22,  -12, 24,  8,  0 }, {     10,  -22,  -13, 24,  8,  0 }, {     10,  -22,  -14, 24,  8,  0 },
    {     10,  -23,  -15, 24,  8,  0 }, {     10,  -23,  -16, 24,  8,  0 }, {     10,  -23,  -17, 24,  8,  0 }, {     10,  -24,  -18, 24,  8,  0 }, {      9,  -24,  -19, 24,  8,  0 },
    {      9,  -25,  -20, 24,  8,  0 }, {      9,  -25,  -21, 24,  8,  0 }, {      9,  -25,  -22, 24,  8,  0 }, {      9,  -26,  -23, 24, 17,  0 }, {      9,  -26,  -24, 24, 17,  0 },
    {      9,  -26,  -25, 24, 17,  0 }, {      9,  -26,  -26, 24, 17,  0 }, {      9,  -27,  -27, 24, 17,  0 }, {      8,  -27,  -28, 24, 17,  0 }, {      8,  -27,  -29, 24, 17,  0 },
    {      8,  -27,  -30, 24, 17,  0 }, {      8,  -28,  -31, 24, 17,  0 }, {      8,  -28,  -32, 24, 17,  0 }, {      8,  -28,  -33, 24, 17,  0 }, {      8,  -28,  -34, 24, 17,  0 },
    {      8,  -28,  -35, 24, 17,  0 }, {      8,  -28,  -36, 24, 17,  0 }, {      8,  -29,  -37, 24, 17,  0 }, {      7,  -29,  -38, 24, 17,  0 }, {      7,  -29,  -39, 24, 17,  0 },
    {      7,  -29,  -40, 24, 17,  0 }, {      7,  -29,  -41, 24, 17,  0 }, {      7,  -29,  -42, 24, 17,  0 }, {      7,  -29,  -43, 24, 17,  0 }, {      7,  -29,  -44, 24, 17,  0 },
    {      7,  -30,  -45, 24, 17,  0 }, {      7,  -30,  -46, 24, 17,  0 }, {      7,  -30,  -47, 24, 18,  0 }, {      6,  -30,  -48, 24, 18,  0 }, {      6,  -30,  -49, 24, 18,  0 },
    {      6,  -30,  -50, 24, 18,  0 }, {      6,  -30,  -51, 24, 18,  0 }, {      6,  -30,  -52, 24, 18,  0 }, {      6,  -30,  -53, 24, 18,  0 }, {      6,  -30,  -54, 24, 18,  0 },
    {      6,  -30,  -55, 24, 18,  0 }, {      6,  -30,  -56, 24, 18,  0 }, {      5,  -30,  -57, 24, 18,  0 }, {      5,  -30,  -58, 24, 18,  0 }, {      5,  -30,  -59, 24, 18,  0 },
    {      5,  -30,  -60, 24, 18,  0 }, {      5,  -30,  -61, 24, 18,  0 }, {      5,  -30,  -62, 24, 18,  0 }, {      5,  -30,  -63, 24, 18,  0 }, {      5,  -30,  -64, 24, 18,  0 },
    {      5,  -30,  -65, 24, 18,  0 }, {      5,  -30,  -66, 24, 18,  0 }, {      4,  -30,  -67, 24, 18,  0 }, {      4,  -30,  -68, 24, 18,  0 }, {      4,  -30,  -69, 24, 18,  0 },
    {      4,  -30,  -70, 24, 18,  0 }, {      4,  -30,  -71, 24, 18,  0 }, {      4,  -30,  -72, 24, 18,  0 }, {      4,  -30,  -73, 24, 18,  0 }, {      4,  -30,  -74, 24, 18,  0 },
    {      4,  -30,  -75, 24, 18,  0 }, {      4,  -30,  -76, 24, 18,  0 }, {      3,  -30,  -77, 24, 18,  0 }, {      3,  -30,  -78, 24, 18,  0 }, {      3,  -30,  -79, 24, 18,  0 },
    {      3,  -30,  -80, 24, 18,  0 }, {      3,  -30,  -81, 24, 18,  0 }, {      3,  -30,  -82, 24, 18,  0 }, {      3,  -30,  -83, 24, 18,  0 }, {      3,  -30,  -84, 24, 19,  0 },
    {      3,  -30,  -85, 24, 19,  0 }, {      3,  -29,  -86, 24, 19,  0 }, {      2,  -29,  -87, 24, 19,  0 }, {      2,  -29,  -88, 24, 19,  0 }, {      2,  -29,  -89, 24, 19,  0 },
    {      2,  -29,  -90, 24, 19,  0 }, {      2,  -29,  -91, 24, 19,  0 }, {      2,  -28,  -92, 24, 19,  0 }, {      2,  -28,  -93, 24, 19,  0 }, {      2,  -28,  -94, 24, 19,  0 },
    {      2,  -28,  -95, 24, 19,  0 }, {      1,  -28,  -96, 24, 19,  0 }, {      1,  -28,  -97, 24, 19,  0 }, {      1,  -27,  -98, 24, 19,  0 }, {      1,  -27,  -99, 24, 19,  0 },
    {      1,  -27, -100, 24, 19,  0 }, {      1,  -27, -101, 24, 19,  0 }, {      1,  -27, -102, 24, 19,  0 }, {      1,  -26, -103, 24, 19,  0 }, {      1,  -26, -104, 24, 19,  0 },
    {      1,  -26, -105, 24, 19,  0 }, {      0,  -26, -106, 24, 19,  0 }, {      0,  -25, -107, 24, 19,  0 }, {      0,  -25, -108, 24, 19,  0 }, {      0,  -25, -109, 24, 19,  0 },
    {      0,  -24, -110, 24, 19,  0 }, {      0,  -24, -111, 24, 19,  0 }, {      0,  -24, -112, 24, 19,  0 }, {      0,  -23, -113, 24, 19,  0 }, {      0,  -23, -114, 24, 19,  0 },
    {      0,  -23, -115, 24, 19,  0 }, {     -1,  -23, -116, 24, 19,  0 }, {     -1,  -22, -117, 24, 20,  0 }, {     -1,  -22, -118, 24, 20,  0 }, {     -1,  -22, -119, 24, 20,  0 },
    {     -1,  -21, -120, 24, 20,  0 }, {     -1,  -21, -121, 24, 20,  0 }, {     -1,  -20, -122, 24, 20,  0 }, {     -1,  -20, -123, 24, 20,  0 }, {     -1,  -19, -124, 24, 20,  0 },
    {     -2,  -19, -125, 24, 20,  0 }, {     -2,  -19, -126, 24, 20,  0 }, {     -2,  -18, -127, 24, 20,  0 }, {     -2,  -18, -128, 24, 20,  0 }, {     -2,  -17, -129, 24, 20,  0 },
    {     -2,  -17, -130, 24, 20,  0 }, {     -2,  -17, -131, 24, 20,  0 }, {     -2,  -16, -132, 24, 20,  0 }, {     -2,  -16, -133, 24, 20,  0 }, {     -2,  -15, -134, 24, 20,  0 },
    {     -3,  -15, -135, 24, 20,  0 }, {     -3,  -14, -136, 24, 20,  0 }, {     -3,  -14, -137, 24, 20,  0 }, {     -3,  -14, -138, 24, 20,  0 }, {     -3,  -13, -139, 24, 20,  0 },
    {     -3,  -13, -140, 24, 20,  0 }, {     -3,  -12, -141, 24, 20,  0 }, {     -3,  -12, -142, 24, 20,  0 }, {     -3,  -11, -143, 24, 20,  0 }, {     -3,  -11, -144, 24, 20,  0 },
    {     -4,  -10, -145, 24, 20,  0 }, {     -4,  -10, -146, 24, 20,  0 }, {     -4,   -9, -147, 24, 20,  0 }, {     -4,   -8, -148, 24, 20,  0 }, {     -4,   -8, -149, 24, 20,  0 },
    {     -4,   -7, -150, 24, 20,  0 }, {     -4,   -7, -151, 24, 20,  0 }, {     -4,   -6, -152, 24, 20,  0 }, {     -4,   -5, -153, 24, 21,  0 }, {     -4,   -5, -154, 24, 21,  0 },
    {     -5,   -4, -155, 24, 21,  0 }, {     -5,   -4, -156, 24, 21,  0 }, {     -5,   -3, -157, 24, 21,  0 }, {     -5,   -2, -158, 24, 21,  0 }, {     -5,   -2, -159, 24, 21,  0 },
    {     -5,   -1, -160, 24, 21,  0 }, {     -5,    0, -161, 24, 21,  0 }, {     -5,    0, -162, 24, 21,  0 }, {     -5,    1, -163, 24, 21,  0 }, {     -6,    2, -164, 24, 21,  0 },
    {     -6,    3, -165, 24, 21,  0 }, {     -6,    3, -166, 24, 21,  0 }, {     -6,    4, -167, 24, 21,  0 }, {     -6,    5, -168, 24, 21,  0 }, {     -6,    5, -169, 24, 21,  0 },
    {     -6,    6, -170, 24, 21,  0 }, {     -6,    7, -171, 24, 21,  0 }, {     -6,    7, -172, 24, 21,  0 }, {     -6,    8, -173, 24, 21,  0 }, {     -7,    9, -174, 24, 21,  0 },
    {     -7,   10, -175, 24, 21,  0 }, {     -7,   11, -176, 24, 21,  0 }, {     -7,   12, -177, 24, 21,  0 }, {     -7,   13, -178, 24, 21,  0 }, {     -7,   14, -179, 24, 21,  0 },
    {     -7,   14, -180, 24, 21,  0 }, {     -7,   15, -181, 24, 21,  0 }, {     -7,   16, -182, 24, 21,  0 }, {     -7,   17, -183, 24, 21,  0 }, {     -8,   18, -184, 24, 21,  0 },
    {     -8,   19, -185, 24, 21,  0 }, {     -8,   20, -186, 24, 21,  0 }, {     -8,   21, -187, 24, 21,  0 }, {     -8,   22, -188, 24, 21,  0 }, {     -8,   23, -189, 24, 21,  0 },
    {     -8,   24, -190, 24, 21,  0 }, {     -8,   25, -190, 24, 21,  0 }, {     -8,   26, -191, 24, 21,  0 }, {     -9,   27, -192, 24, 21,  0 }, {     -9,   28, -193, 24, 21,  0 },
    {     -9,   29, -194, 24, 21,  0 }, {     -9,   30, -195, 24, 21,  0 }, {     -9,   31, -196, 24, 21,  0 }, {     -9,   32, -196, 24, 21,  0 }, {     -9,   33, -197, 24, 21,  0 },
    {     -9,   34, -198, 24, 22,  0 }, {     -9,   35, -199, 24, 22,  0 }, {     -9,   36, -199, 24, 22,  0 }, {    -10,   37, -200, 24, 22,  0 }, {    -10,   38, -201, 24, 22,  0 },
    {    -10,   39, -202, 24, 22,  0 }, {    -10,   40, -202, 24, 22,  0 }, {    -10,   41, -203, 24, 22,  0 }, {    -10,   42, -204, 24, 22,  0 }, {    -10,   43, -205, 24, 22,  0 },
    {    -10,   44, -205, 24, 22,  0 }, {    -10,   45, -206, 24, 22,  0 }, {    -10,   46, -207, 24, 22,  0 }, {    -11,   47, -207, 24, 22,  0 }, {    -11,   48, -208, 24, 22,  0 },
    {    -11,   49, -208, 24, 22,  0 }, {    -11,   50, -209, 24, 22,  0 }, {    -11,   51, -210, 24, 22,  0 }, {    -11,   52, -210, 24, 22,  0 }, {    -11,   53, -211, 24, 22,  0 },
    {    -11,   54, -211, 24, 22,  0 }, {    -11,   55, -212, 24, 22,  0 }, {    -11,   56, -213, 24, 22,  0 }, {    -12,   57, -213, 24, 22,  0 }, {    -12,   58, -214, 24, 22,  0 },
    {    -12,   59, -214, 24, 22,  0 }, {    -12,   60, -215, 24, 22,  0 }, {    -12,   61, -215, 24, 22,  0 }, {    -12,   62, -216, 24, 22,  0 }, {    -12,   63, -216, 24, 22,  0 },
    {    -12,   64, -217, 24, 22,  0 }, {    -12,   65, -217, 24, 22,  0 }, {    -13,   66, -218, 24, 22,  0 }, {    -13,   67, -218, 24, 22,  0 }, {    -13,   68, -219, 24, 22,  0 },
    {    -13,   69, -219, 24, 22,  0 }, {    -13,   70, -220, 24, 22,  0 }, {    -13,   71, -220, 24, 22,  0 }, {    -13,   72, -221, 24, 22,  0 }, {    -13,   73, -221, 24, 22,  0 },
    {    -13,   74, -222, 24, 22,  0 }, {    -13,   75, -222, 24, 22,  0 }, {    -14,   76, -223, 24, 22,  0 }, {    -14,   77, -223, 24, 22,  0 }, {    -14,   78, -224, 24, 22,  0 },
    {    -14,   79, -224, 24, 22,  0 }, {    -14,   80, -225, 24, 22,  0 }, {    -14,   81, -225, 24, 22,  0 }, {    -14,   82, -226, 24, 22,  0 }, {    -14,   83, -226, 24, 22,  0 },
    {    -14,   84, -227, 24, 22,  0 }, {    -14,   85, -227, 24, 22,  0 }, {    -15,   86, -228, 24, 22,  0 }, {    -15,   87, -228, 24, 22,  0 }, {    -15,   88, -229, 24, 22,  0 },
    {    -15,   89, -229, 24, 22,  0 }, {    -15,   90, -230, 24, 22,  0 }, {    -15,   91, -230, 24, 22,  0 }, {    -15,   92, -231, 24, 22,  0 }, {    -15,   93, -231, 24, 22,  0 },
    {    -15,   94, -232, 24, 22,  0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_FlyerHalfLoopUninvertedDown0, {
    {     31,   16,   32,    0,    0,    0 }, {     30,   16,   32,    0,    0,    0 }, {     29,   16,   32,    0,    0,    0 }, {     28,   16,   32,    0,    0,    0 }, {     27,   16,   32,    0,    0,    0 },
    {     26,   16,   32,    0,    5,    0 }, {     25,   16,   31,    0,    5,    0 }, {     24,   16,   31,    0,    5,    0 }, {     23,   16,   31,    0,    5,    0 }, {     22,   16,   30,    0,    5,    0 },
    {     21,   16,   30,    0,    6,    0 }, {     20,   16,   29,    0,    6,    0 }, {     19,   16,   28,    0,    6,    0 }, {     18,   16,   27,    0,    6,    0 }, {     17,   16,   26,    0,    6,    0 },
    {     16,   16,   26,    0,    7,    0 }, {     15,   16,   25,    0,    7,    0 }, {     14,   16,   24,    0,    7,    0 }, {     13,   16,   23,    0,    7,    0 }, {     12,   16,   20,    0,    7,    0 },
    {     11,   16,   21,    0,    7,    0 }, {     10,   16,   22,    0,    7,    0 }, {     10,   16,   19,    0,    7,    0 }, {      9,   16,   18,    0,    8,    0 }, {      8,   16,   17,    0,    8,    0 },
    {      8,   16,   16,    0,    8,    0 }, {      7,   16,   15,    0,    8,    0 }, {      7,   16,   14,    0,    8,    0 }, {      6,   16,   13,    0,    8,    0 }, {      6,   16,   12,    0,    8,    0 },
    {      6,   16,   11,    0,    8,    0 }, {      5,   16,   10,    0,    8,    0 }, {      5,   16,    9,    0,   17,    0 }, {      4,   16,    8,    0,   17,    0 }, {      4,   16,    7,    0,   17,    0 },
    {      3,   16,    6,    0,   17,    0 }, {      3,   16,    5,    0,   17,    0 }, {      3,   16,    4,    0,   17,    0 }, {      2,   16,    3,    0,   17,    0 }, {      2,   16,    2,    0,   17,    0 },
    {      2,   16,    1,    0,   17,    0 }, {      2,   16,    0,    0,   17,    0 }, {      1,   16,   -1,    0,   17,    0 }, {      1,   16,   -2,    0,   17,    0 }, {      1,   16,   -3,    0,   17,    0 },
    {      1,   16,   -4,    0,   17,    0 }, {      1,   16,   -5,    0,   18,    0 }, {      0,   16,   -6,    0,   18,    0 }, {      0,   16,   -7,    0,   18,    0 }, {      0,   16,   -8,    0,   18,    0 },
    {      0,   16,   -9,    0,   18,    0 }, {      0,   16,  -10,    0,   18,    0 }, {      0,   16,  -11,    0,   18,    0 }, {      0,   16,  -12,    0,   18,    0 }, {      0,   16,  -13,    0,   18,    0 },
    {      0,   16,  -14,    0,   18,    0 }, {      0,   16,  -15,    0,   18,    0 }, {      0,   16,  -16,    0,   18,    0 }, {      0,   16,  -17,    0,   18,    0 }, {      0,   16,  -18,    0,   18,    0 },
    {      0,   16,  -19,    0,   18,    0 }, {      0,   16,  -22,    0,   18,    0 }, {      0,   16,  -21,    0,   18,    0 }, {      0,   16,  -20,    0,   18,    0 }, {      0,   16,  -23,    0,   18,    0 },
    {      0,   16,  -24,    0,   18,    0 }, {      0,   16,  -25,    0,   18,    0 }, {      0,   16,  -26,    0,   18,    0 }, {      0,   16,  -27,    0,   18,    0 }, {      0,   16,  -28,    0,   18,    0 },
    {      0,   16,  -29,    0,   18,    0 }, {      0,   16,  -30,    0,   18,    0 }, {      0,   16,  -31,    0,   18,    0 }, {      0,   16,  -32,    0,   18,    0 }, {      0,   16,  -33,    0,   18,    0 },
    {      1,   16,  -34,    0,   18,    0 }, {      1,   16,  -35,    0,   18,    0 }, {      1,   16,  -36,    0,   18,    0 }, {      1,   16,  -37,    0,   18,    0 }, {      1,   16,  -38,    0,   19,    0 },
    {      2,   16,  -39,    0,   19,    0 }, {      2,   16,  -40,    0,   19,    0 }, {      2,   16,  -41,    0,   19,    0 }, {      2,   16,  -42,    0,   19,    0 }, {      3,   16,  -43,    0,   19,    0 },
    {      3,   16,  -44,    0,   19,    0 }, {      3,   16,  -45,    0,   19,    0 }, {      4,   16,  -46,    0,   19,    0 }, {      4,   16,  -47,    0,   19,    0 }, {      4,   16,  -48,    0,   19,    0 },
    {      5,   16,  -49,    0,   19,    0 }, {      5,   16,  -50,    0,   19,    0 }, {      5,   16,  -51,    0,   19,    0 }, {      6,   16,  -52,    0,   19,    0 }, {      6,   16,  -53,    0,   19,    0 },
    {      6,   16,  -54,    0,   19,    0 }, {      7,   16,  -55,    0,   19,    0 }, {      7,   16,  -56,    0,   19,    0 }, {      7,   16,  -57,    0,   19,    0 }, {      8,   16,  -58,    0,   19,    0 },
    {      8,   16,  -59,    0,   20,    0 }, {      9,   16,  -60,    0,   20,    0 }, {     10,   16,  -61,    0,   20,    0 }, {     10,   16,  -62,    0,   20,    0 }, {     11,   16,  -63,    0,   20,    0 },
    {     12,   16,  -64,    0,   20,    0 }, {     12,   16,  -65,    0,   20,    0 }, {     13,   16,  -66,    0,   20,    0 }, {     13,   16,  -67,    0,   20,    0 }, {     14,   16,  -68,    0,   20,    0 },
    {     15,   16,  -69,    0,   20,    0 }, {     16,   16,  -70,    0,   20,    0 }, {     16,   16,  -71,    0,   20,    0 }, {     17,   16,  -72,    0,   20,    0 }, {     18,   16,  -73,    0,   20,    0 },
    {     19,   16,  -74,    0,   20,    0 }, {     19,   16,  -75,    0,   21,    0 }, {     20,   16,  -76,    0,   21,    0 }, {     21,   16,  -77,    0,   21,    0 }, {     22,   16,  -78,    0,   21,    0 },
    {     23,   16,  -79,    0,   21,    0 }, {     24,   16,  -80,    0,   21,    0 }, {     25,   16,  -81,    0,   21,    0 }, {     26,   16,  -82,    0,   21,    0 }, {     27,   16,  -83,    0,   21,    0 },
    {     28,   16,  -84,    0,   21,    0 }, {     29,   16,  -85,    0,   21,    0 }, {     30,   16,  -86,    0,   21,    0 }, {     31,   16,  -86,    0,   21,    0 }, {     32,   16,  -87,    0,   21,    0 },
    {     33,   16,  -88,    0,   21,    0 }, {     34,   16,  -89,    0,   21,    0 }, {     35,   16,  -89,    0,   21,    0 }, {     36,   16,  -90,    0,   21,    0 }, {     37,   16,  -91,    0,   21,    0 },
    {     38,   16,  -92,    0,   21,    0 }, {     39,   16,  -93,    0,   21,    0 }, {     40,   16,  -93,    0,   21,    0 }, {     41,   16,  -94,    0,   21,    0 }, {     42,   16,  -94,    0,   22,    0 },
    {     43,   16,  -95,    0,   22,    0 }, {     44,   16,  -95,    0,   22,    0 }, {     45,   16,  -96,    0,   22,    0 }, {     46,   16,  -96,    0,   22,    0 }, {     47,   16,  -97,    0,   22,    0 },
    {     48,   16,  -97,    0,   22,    0 }, {     49,   16,  -98,    0,   22,    0 }, {     50,   16,  -98,    0,   22,    0 }, {     51,   16,  -99,    0,   22,    0 }, {     52,   16,  -99,    0,   22,    0 },
    {     53,   16, -100,    0,   22,    0 }, {     54,   16, -100,    0,   22,    0 }, {     55,   16, -101,    0,   22,    0 }, {     56,   16, -101,    0,   22,    0 }, {     57,   16, -101,    0,   22,    0 },
    {     58,   16, -102,    0,   22,    0 }, {     59,   16, -102,    0,   22,    0 }, {     60,   16, -103,    0,   22,    0 }, {     61,   16, -103,    0,   22,    0 }, {     62,   16, -104,    0,   22,    0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_FlyerHalfLoopUninvertedDown1, {
    {     16,    0,   32,    8,    0,    0 }, {     16,    1,   32,    8,    0,    0 }, {     16,    2,   32,    8,    0,    0 }, {     16,    3,   32,    8,    0,    0 }, {     16,    4,   32,    8,    0,    0 },
    {     16,    5,   32,    8,    5,    0 }, {     16,    6,   31,    8,    5,    0 }, {     16,    7,   31,    8,    5,    0 }, {     16,    8,   31,    8,    5,    0 }, {     16,    9,   30,    8,    5,    0 },
    {     16,   10,   30,    8,    6,    0 }, {     16,   11,   29,    8,    6,    0 }, {     16,   12,   28,    8,    6,    0 }, {     16,   13,   27,    8,    6,    0 }, {     16,   14,   26,    8,    6,    0 },
    {     16,   15,   26,    8,    7,    0 }, {     16,   16,   25,    8,    7,    0 }, {     16,   17,   24,    8,    7,    0 }, {     16,   18,   23,    8,    7,    0 }, {     16,   19,   22,    8,    7,    0 },
    {     16,   20,   21,    8,    7,    0 }, {     16,   21,   20,    8,    7,    0 }, {     16,   21,   19,    8,    7,    0 }, {     16,   22,   18,    8,    8,    0 }, {     16,   23,   17,    8,    8,    0 },
    {     16,   23,   16,    8,    8,    0 }, {     16,   24,   15,    8,    8,    0 }, {     16,   24,   14,    8,    8,    0 }, {     16,   25,   13,    8,    8,    0 }, {     16,   25,   12,    8,    8,    0 },
    {     16,   25,   11,    8,    8,    0 }, {     16,   26,   10,    8,    8,    0 }, {     16,   26,    9,    8,   17,    0 }, {     16,   27,    8,    8,   17,    0 }, {     16,   27,    7,    8,   17,    0 },
    {     16,   28,    6,    8,   17,    0 }, {     16,   28,    5,    8,   17,    0 }, {     16,   28,    4,    8,   17,    0 }, {     16,   29,    3,    8,   17,    0 }, {     16,   29,    2,    8,   17,    0 },
    {     16,   29,    1,    8,   17,    0 }, {     16,   29,    0,    8,   17,    0 }, {     16,   30,   -1,    8,   17,    0 }, {     16,   30,   -2,    8,   17,    0 }, {     16,   30,   -3,    8,   17,    0 },
    {     16,   30,   -4,    8,   17,    0 }, {     16,   30,   -5,    8,   18,    0 }, {     16,   31,   -6,    8,   18,    0 }, {     16,   31,   -7,    8,   18,    0 }, {     16,   31,   -8,    8,   18,    0 },
    {     16,   31,   -9,    8,   18,    0 }, {     16,   31,  -10,    8,   18,    0 }, {     16,   31,  -11,    8,   18,    0 }, {     16,   31,  -12,    8,   18,    0 }, {     16,   31,  -13,    8,   18,    0 },
    {     16,   31,  -14,    8,   18,    0 }, {     16,   31,  -15,    8,   18,    0 }, {     16,   31,  -16,    8,   18,    0 }, {     16,   31,  -17,    8,   18,    0 }, {     16,   31,  -18,    8,   18,    0 },
    {     16,   31,  -19,    8,   18,    0 }, {     16,   31,  -20,    8,   18,    0 }, {     16,   31,  -21,    8,   18,    0 }, {     16,   31,  -22,    8,   18,    0 }, {     16,   31,  -23,    8,   18,    0 },
    {     16,   31,  -24,    8,   18,    0 }, {     16,   31,  -25,    8,   18,    0 }, {     16,   31,  -26,    8,   18,    0 }, {     16,   31,  -27,    8,   18,    0 }, {     16,   31,  -28,    8,   18,    0 },
    {     16,   31,  -29,    8,   18,    0 }, {     16,   31,  -30,    8,   18,    0 }, {     16,   31,  -31,    8,   18,    0 }, {     16,   31,  -32,    8,   18,    0 }, {     16,   31,  -33,    8,   18,    0 },
    {     16,   30,  -34,    8,   18,    0 }, {     16,   30,  -35,    8,   18,    0 }, {     16,   30,  -36,    8,   18,    0 }, {     16,   30,  -37,    8,   18,    0 }, {     16,   30,  -38,    8,   19,    0 },
    {     16,   29,  -39,    8,   19,    0 }, {     16,   29,  -40,    8,   19,    0 }, {     16,   29,  -41,    8,   19,    0 }, {     16,   29,  -42,    8,   19,    0 }, {     16,   28,  -43,    8,   19,    0 },
    {     16,   28,  -44,    8,   19,    0 }, {     16,   28,  -45,    8,   19,    0 }, {     16,   27,  -46,    8,   19,    0 }, {     16,   27,  -47,    8,   19,    0 }, {     16,   27,  -48,    8,   19,    0 },
    {     16,   26,  -49,    8,   19,    0 }, {     16,   26,  -50,    8,   19,    0 }, {     16,   26,  -51,    8,   19,    0 }, {     16,   25,  -52,    8,   19,    0 }, {     16,   25,  -53,    8,   19,    0 },
    {     16,   25,  -54,    8,   19,    0 }, {     16,   24,  -55,    8,   19,    0 }, {     16,   24,  -56,    8,   19,    0 }, {     16,   24,  -57,    8,   19,    0 }, {     16,   23,  -58,    8,   19,    0 },
    {     16,   23,  -59,    8,   20,    0 }, {     16,   22,  -60,    8,   20,    0 }, {     16,   21,  -61,    8,   20,    0 }, {     16,   21,  -62,    8,   20,    0 }, {     16,   20,  -63,    8,   20,    0 },
    {     16,   19,  -64,    8,   20,    0 }, {     16,   19,  -65,    8,   20,    0 }, {     16,   18,  -66,    8,   20,    0 }, {     16,   18,  -67,    8,   20,    0 }, {     16,   17,  -68,    8,   20,    0 },
    {     16,   16,  -69,    8,   20,    0 }, {     16,   15,  -70,    8,   20,    0 }, {     16,   15,  -71,    8,   20,    0 }, {     16,   14,  -72,    8,   20,    0 }, {     16,   13,  -73,    8,   20,    0 },
    {     16,   12,  -74,    8,   20,    0 }, {     16,   12,  -75,    8,   21,    0 }, {     16,   11,  -76,    8,   21,    0 }, {     16,   10,  -77,    8,   21,    0 }, {     16,    9,  -78,    8,   21,    0 },
    {     16,    8,  -79,    8,   21,    0 }, {     16,    7,  -80,    8,   21,    0 }, {     16,    6,  -81,    8,   21,    0 }, {     16,    5,  -82,    8,   21,    0 }, {     16,    4,  -83,    8,   21,    0 },
    {     16,    3,  -84,    8,   21,    0 }, {     16,    2,  -85,    8,   21,    0 }, {     16,    1,  -86,    8,   21,    0 }, {     16,    0,  -86,    8,   21,    0 }, {     16,   -1,  -87,    8,   21,    0 },
    {     16,   -2,  -88,    8,   21,    0 }, {     16,   -3,  -89,    8,   21,    0 }, {     16,   -4,  -89,    8,   21,    0 }, {     16,   -5,  -90,    8,   21,    0 }, {     16,   -6,  -91,    8,   21,    0 },
    {     16,   -7,  -92,    8,   21,    0 }, {     16,   -8,  -93,    8,   21,    0 }, {     16,   -9,  -93,    8,   21,    0 }, {     16,  -10,  -94,    8,   21,    0 }, {     16,  -11,  -94,    8,   22,    0 },
    {     16,  -12,  -95,    8,   22,    0 }, {     16,  -13,  -95,    8,   22,    0 }, {     16,  -14,  -96,    8,   22,    0 }, {     16,  -15,  -96,    8,   22,    0 }, {     16,  -16,  -97,    8,   22,    0 },
    {     16,  -17,  -97,    8,   22,    0 }, {     16,  -18,  -98,    8,   22,    0 }, {     16,  -19,  -98,    8,   22,    0 }, {     16,  -20,  -99,    8,   22,    0 }, {     16,  -21,  -99,    8,   22,    0 },
    {     16,  -22, -100,    8,   22,    0 }, {     16,  -23, -100,    8,   22,    0 }, {     16,  -24, -101,    8,   22,    0 }, {     16,  -25, -101,    8,   22,    0 }, {     16,  -26, -101,    8,   22,    0 },
    {     16,  -27, -102,    8,   22,    0 }, {     16,  -28, -102,    8,   22,    0 }, {     16,  -29, -103,    8,   22,    0 }, {     16,  -30, -103,    8,   22,    0 }, {     16,  -31, -104,    8,   22,    0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_FlyerHalfLoopUninvertedDown2, {
    {      0,   16,   32,   16,    0,    0 }, {      1,   16,   32,   16,    0,    0 }, {      2,   16,   32,   16,    0,    0 }, {      3,   16,   32,   16,    0,    0 }, {      4,   16,   32,   16,    0,    0 },
    {      5,   16,   32,   16,    5,    0 }, {      6,   16,   31,   16,    5,    0 }, {      7,   16,   31,   16,    5,    0 }, {      8,   16,   31,   16,    5,    0 }, {      9,   16,   30,   16,    5,    0 },
    {     10,   16,   30,   16,    6,    0 }, {     11,   16,   29,   16,    6,    0 }, {     12,   16,   28,   16,    6,    0 }, {     13,   16,   27,   16,    6,    0 }, {     14,   16,   26,   16,    6,    0 },
    {     15,   16,   26,   16,    7,    0 }, {     16,   16,   25,   16,    7,    0 }, {     17,   16,   24,   16,    7,    0 }, {     18,   16,   23,   16,    7,    0 }, {     19,   16,   22,   16,    7,    0 },
    {     20,   16,   21,   16,    7,    0 }, {     21,   16,   20,   16,    7,    0 }, {     21,   16,   19,   16,    7,    0 }, {     22,   16,   18,   16,    8,    0 }, {     23,   16,   17,   16,    8,    0 },
    {     23,   16,   16,   16,    8,    0 }, {     24,   16,   15,   16,    8,    0 }, {     24,   16,   14,   16,    8,    0 }, {     25,   16,   13,   16,    8,    0 }, {     25,   16,   12,   16,    8,    0 },
    {     25,   16,   11,   16,    8,    0 }, {     26,   16,   10,   16,    8,    0 }, {     26,   16,    9,   16,   17,    0 }, {     27,   16,    8,   16,   17,    0 }, {     27,   16,    7,   16,   17,    0 },
    {     28,   16,    6,   16,   17,    0 }, {     28,   16,    5,   16,   17,    0 }, {     28,   16,    4,   16,   17,    0 }, {     29,   16,    3,   16,   17,    0 }, {     29,   16,    2,   16,   17,    0 },
    {     29,   16,    1,   16,   17,    0 }, {     29,   16,    0,   16,   17,    0 }, {     30,   16,   -1,   16,   17,    0 }, {     30,   16,   -2,   16,   17,    0 }, {     30,   16,   -3,   16,   17,    0 },
    {     30,   16,   -4,   16,   17,    0 }, {     30,   16,   -5,   16,   18,    0 }, {     31,   16,   -6,   16,   18,    0 }, {     31,   16,   -7,   16,   18,    0 }, {     31,   16,   -8,   16,   18,    0 },
    {     31,   16,   -9,   16,   18,    0 }, {     31,   16,  -10,   16,   18,    0 }, {     31,   16,  -11,   16,   18,    0 }, {     31,   16,  -12,   16,   18,    0 }, {     31,   16,  -13,   16,   18,    0 },
    {     31,   16,  -14,   16,   18,    0 }, {     31,   16,  -15,   16,   18,    0 }, {     31,   16,  -16,   16,   18,    0 }, {     31,   16,  -17,   16,   18,    0 }, {     31,   16,  -18,   16,   18,    0 },
    {     31,   16,  -19,   16,   18,    0 }, {     31,   16,  -20,   16,   18,    0 }, {     31,   16,  -21,   16,   18,    0 }, {     31,   16,  -22,   16,   18,    0 }, {     31,   16,  -23,   16,   18,    0 },
    {     31,   16,  -24,   16,   18,    0 }, {     31,   16,  -25,   16,   18,    0 }, {     31,   16,  -26,   16,   18,    0 }, {     31,   16,  -27,   16,   18,    0 }, {     31,   16,  -28,   16,   18,    0 },
    {     31,   16,  -29,   16,   18,    0 }, {     31,   16,  -30,   16,   18,    0 }, {     31,   16,  -31,   16,   18,    0 }, {     31,   16,  -32,   16,   18,    0 }, {     31,   16,  -33,   16,   18,    0 },
    {     30,   16,  -34,   16,   18,    0 }, {     30,   16,  -35,   16,   18,    0 }, {     30,   16,  -36,   16,   18,    0 }, {     30,   16,  -37,   16,   18,    0 }, {     30,   16,  -38,   16,   19,    0 },
    {     29,   16,  -39,   16,   19,    0 }, {     29,   16,  -40,   16,   19,    0 }, {     29,   16,  -41,   16,   19,    0 }, {     29,   16,  -42,   16,   19,    0 }, {     28,   16,  -43,   16,   19,    0 },
    {     28,   16,  -44,   16,   19,    0 }, {     28,   16,  -45,   16,   19,    0 }, {     27,   16,  -46,   16,   19,    0 }, {     27,   16,  -47,   16,   19,    0 }, {     27,   16,  -48,   16,   19,    0 },
    {     26,   16,  -49,   16,   19,    0 }, {     26,   16,  -50,   16,   19,    0 }, {     26,   16,  -51,   16,   19,    0 }, {     25,   16,  -52,   16,   19,    0 }, {     25,   16,  -53,   16,   19,    0 },
    {     25,   16,  -54,   16,   19,    0 }, {     24,   16,  -55,   16,   19,    0 }, {     24,   16,  -56,   16,   19,    0 }, {     24,   16,  -57,   16,   19,    0 }, {     23,   16,  -58,   16,   19,    0 },
    {     23,   16,  -59,   16,   20,    0 }, {     22,   16,  -60,   16,   20,    0 }, {     21,   16,  -61,   16,   20,    0 }, {     21,   16,  -62,   16,   20,    0 }, {     20,   16,  -63,   16,   20,    0 },
    {     19,   16,  -64,   16,   20,    0 }, {     19,   16,  -65,   16,   20,    0 }, {     18,   16,  -66,   16,   20,    0 }, {     18,   16,  -67,   16,   20,    0 }, {     17,   16,  -68,   16,   20,    0 },
    {     16,   16,  -69,   16,   20,    0 }, {     15,   16,  -70,   16,   20,    0 }, {     15,   16,  -71,   16,   20,    0 }, {     14,   16,  -72,   16,   20,    0 }, {     13,   16,  -73,   16,   20,    0 },
    {     12,   16,  -74,   16,   20,    0 }, {     12,   16,  -75,   16,   21,    0 }, {     11,   16,  -76,   16,   21,    0 }, {     10,   16,  -77,   16,   21,    0 }, {      9,   16,  -78,   16,   21,    0 },
    {      8,   16,  -79,   16,   21,    0 }, {      7,   16,  -80,   16,   21,    0 }, {      6,   16,  -81,   16,   21,    0 }, {      5,   16,  -82,   16,   21,    0 }, {      4,   16,  -83,   16,   21,    0 },
    {      3,   16,  -84,   16,   21,    0 }, {      2,   16,  -85,   16,   21,    0 }, {      1,   16,  -86,   16,   21,    0 }, {      0,   16,  -86,   16,   21,    0 }, {     -1,   16,  -87,   16,   21,    0 },
    {     -2,   16,  -88,   16,   21,    0 }, {     -3,   16,  -89,   16,   21,    0 }, {     -4,   16,  -89,   16,   21,    0 }, {     -5,   16,  -90,   16,   21,    0 }, {     -6,   16,  -91,   16,   21,    0 },
    {     -7,   16,  -92,   16,   21,    0 }, {     -8,   16,  -93,   16,   21,    0 }, {     -9,   16,  -93,   16,   21,    0 }, {    -10,   16,  -94,   16,   21,    0 }, {    -11,   16,  -94,   16,   22,    0 },
    {    -12,   16,  -95,   16,   22,    0 }, {    -13,   16,  -95,   16,   22,    0 }, {    -14,   16,  -96,   16,   22,    0 }, {    -15,   16,  -96,   16,   22,    0 }, {    -16,   16,  -97,   16,   22,    0 },
    {    -17,   16,  -97,   16,   22,    0 }, {    -18,   16,  -98,   16,   22,    0 }, {    -19,   16,  -98,   16,   22,    0 }, {    -20,   16,  -99,   16,   22,    0 }, {    -21,   16,  -99,   16,   22,    0 },
    {    -22,   16, -100,   16,   22,    0 }, {    -23,   16, -100,   16,   22,    0 }, {    -24,   16, -101,   16,   22,    0 }, {    -25,   16, -101,   16,   22,    0 }, {    -26,   16, -101,   16,   22,    0 },
    {    -27,   16, -102,   16,   22,    0 }, {    -28,   16, -102,   16,   22,    0 }, {    -29,   16, -103,   16,   22,    0 }, {    -30,   16, -103,   16,   22,    0 }, {    -31,   16, -104,   16,   22,    0 }
})



CREATE_VEHICLE_INFO(TrackVehicleInfo_FlyerHalfLoopUninvertedDown3, {
    {     16,   31,   32,   24,    0,    0 }, {     16,   30,   32,   24,    0,    0 }, {     16,   29,   32,   24,    0,    0 }, {     16,   28,   32,   24,    0,    0 }, {     16,   27,   32,   24,    0,    0 },
    {     16,   26,   32,   24,    5,    0 }, {     16,   25,   31,   24,    5,    0 }, {     16,   24,   31,   24,    5,    0 }, {     16,   23,   31,   24,    5,    0 }, {     16,   22,   30,   24,    5,    0 },
    {     16,   21,   30,   24,    6,    0 }, {     16,   20,   29,   24,    6,    0 }, {     16,   19,   28,   24,    6,    0 }, {     16,   18,   27,   24,    6,    0 }, {     16,   17,   26,   24,    6,    0 },
    {     16,   16,   26,   24,    7,    0 }, {     16,   15,   25,   24,    7,    0 }, {     16,   14,   24,   24,    7,    0 }, {     16,   13,   23,   24,    7,    0 }, {     16,   12,   22,   24,    7,    0 },
    {     16,   11,   21,   24,    7,    0 }, {     16,   10,   20,   24,    7,    0 }, {     16,   10,   19,   24,    7,    0 }, {     16,    9,   18,   24,    8,    0 }, {     16,    8,   17,   24,    8,    0 },
    {     16,    8,   16,   24,    8,    0 }, {     16,    7,   15,   24,    8,    0 }, {     16,    7,   14,   24,    8,    0 }, {     16,    6,   13,   24,    8,    0 }, {     16,    6,   12,   24,    8,    0 },
    {     16,    6,   11,   24,    8,    0 }, {     16,    5,   10,   24,    8,    0 }, {     16,    5,    9,   24,   17,    0 }, {     16,    4,    8,   24,   17,    0 }, {     16,    4,    7,   24,   17,    0 },
    {     16,    3,    6,   24,   17,    0 }, {     16,    3,    5,   24,   17,    0 }, {     16,    3,    4,   24,   17,    0 }, {     16,    2,    3,   24,   17,    0 }, {     16,    2,    2,   24,   17,    0 },
    {     16,    2,    1,   24,   17,    0 }, {     16,    2,    0,   24,   17,    0 }, {     16,    1,   -1,   24,   17,    0 }, {     16,    1,   -2,   24,   17,    0 }, {     16,    1,   -3,   24,   17,    0 },
    {     16,    1,   -4,   24,   17,    0 }, {     16,    1,   -5,   24,   18,    0 }, {     16,    0,   -6,   24,   18,    0 }, {     16,    0,   -7,   24,   18,    0 }, {     16,    0,   -8,   24,   18,    0 },
    {     16,    0,   -9,   24,   18,    0 }, {     16,    0,  -10,   24,   18,    0 }, {     16,    0,  -11,   24,   18,    0 }, {     16,    0,  -12,   24,   18,    0 }, {     16,    0,  -13,   24,   18,    0 },
    {     16,    0,  -14,   24,   18,    0 }, {     16,    0,  -15,   24,   18,    0 }, {     16,    0,  -16,   24,   18,    0 }, {     16,    0,  -17,   24,   18,    0 }, {     16,    0,  -18,   24,   18,    0 },
    {     16,    0,  -19,   24,   18,    0 }, {     16,    0,  -20,   24,   18,    0 }, {     16,    0,  -21,   24,   18,    0 }, {     16,    0,  -22,   24,   18,    0 }, {     16,    0,  -23,   24,   18,    0 },
    {     16,    0,  -24,   24,   18,    0 }, {     16,    0,  -25,   24,   18,    0 }, {     16,    0,  -26,   24,   18,    0 }, {     16,    0,  -27,   24,   18,    0 }, {     16,    0,  -28,   24,   18,    0 },
    {     16,    0,  -29,   24,   18,    0 }, {     16,    0,  -30,   24,   18,    0 }, {     16,    0,  -31,   24,   18,    0 }, {     16,    0,  -32,   24,   18,    0 }, {     16,    0,  -33,   24,   18,    0 },
    {     16,    1,  -34,   24,   18,    0 }, {     16,    1,  -35,   24,   18,    0 }, {     16,    1,  -36,   24,   18,    0 }, {     16,    1,  -37,   24,   18,    0 }, {     16,    1,  -38,   24,   19,    0 },
    {     16,    2,  -39,   24,   19,    0 }, {     16,    2,  -40,   24,   19,    0 }, {     16,    2,  -41,   24,   19,    0 }, {     16,    2,  -42,   24,   19,    0 }, {     16,    3,  -43,   24,   19,    0 },
    {     16,    3,  -44,   24,   19,    0 }, {     16,    3,  -45,   24,   19,    0 }, {     16,    4,  -46,   24,   19,    0 }, {     16,    4,  -47,   24,   19,    0 }, {     16,    4,  -48,   24,   19,    0 },
    {     16,    5,  -49,   24,   19,    0 }, {     16,    5,  -50,   24,   19,    0 }, {     16,    5,  -51,   24,   19,    0 }, {     16,    6,  -52,   24,   19,    0 }, {     16,    6,  -53,   24,   19,    0 },
    {     16,    6,  -54,   24,   19,    0 }, {     16,    7,  -55,   24,   19,    0 }, {     16,    7,  -56,   24,   19,    0 }, {     16,    7,  -57,   24,   19,    0 }, {     16,    8,  -58,   24,   19,    0 },
    {     16,    8,  -59,   24,   20,    0 }, {     16,    9,  -60,   24,   20,    0 }, {     16,   10,  -61,   24,   20,    0 }, {     16,   10,  -62,   24,   20,    0 }, {     16,   11,  -63,   24,   20,    0 },
    {     16,   12,  -64,   24,   20,    0 }, {     16,   12,  -65,   24,   20,    0 }, {     16,   13,  -66,   24,   20,    0 }, {     16,   13,  -67,   24,   20,    0 }, {     16,   14,  -68,   24,   20,    0 },
    {     16,   15,  -69,   24,   20,    0 }, {     16,   16,  -70,   24,   20,    0 }, {     16,   16,  -71,   24,   20,    0 }, {     16,   17,  -72,   24,   20,    0 }, {     16,   18,  -73,   24,   20,    0 },
    {     16,   19,  -74,   24,   20,    0 }, {     16,   19,  -75,   24,   21,    0 }, {     16,   20,  -76,   24,   21,    0 }, {     16,   21,  -77,   24,   21,    0 }, {     16,   22,  -78,   24,   21,    0 },
    {     16,   23,  -79,   24,   21,    0 }, {     16,   24,  -80,   24,   21,    0 }, {     16,   25,  -81,   24,   21,    0 }, {     16,   26,  -82,   24,   21,    0 }, {     16,   27,  -83,   24,   21,    0 },
    {     16,   28,  -84,   24,   21,    0 }, {     16,   29,  -85,   24,   21,    0 }, {     16,   30,  -86,   24,   21,    0 }, {     16,   31,  -86,   24,   21,    0 }, {     16,   32,  -87,   24,   21,    0 },
    {     16,   33,  -88,   24,   21,    0 }, {     16,   34,  -89,   24,   21,    0 }, {     16,   35,  -89,   24,   21,    0 }, {     16,   36,  -90,   24,   21,    0 }, {     16,   37,  -91,   24,   21,    0 },
    {     16,   38,  -92,   24,   21,    0 }, {     16,   39,  -93,   24,   21,    0 }, {     16,   40,  -93,   24,   21,    0 }, {     16,   41,  -94,   24,   21,    0 }, {     16,   42,  -94,   24,   22,    0 },
    {     16,   43,  -95,   24,   22,    0 }, {     16,   44,  -95,   24,   22,    0 }, {     16,   45,  -96,   24,   22,    0 }, {     16,   46,  -96,   24,   22,    0 }, {     16,   47,  -97,   24,   22,    0 },
    {     16,   48,  -97,   24,   22,    0 }, {     16,   49,  -98,   24,   22,    0 }, {     16,   50,  -98,   24,   22,    0 }, {     16,   51,  -99,   24,   22,    0 }, {     16,   52,  -99,   24,   22,    0 },
    {     16,   53, -100,   24,   22,    0 }, {     16,   54, -100,   24,   22,    0 }, {     16,   55, -101,   24,   22,    0 }, {     16,   56, -101,   24,   22,    0 }, {     16,   57, -101,   24,   22,    0 },
    {     16,   58, -102,   24,   22,    0 }, {     16,   59, -102,   24,   22,    0 }, {     16,   60, -103,   24,   22,    0 }, {     16,   61, -103,   24,   22,    0 }, {     16,   62, -104,   24,   22,    0 }
})


CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToDiagUp250, {
    {     31,   16,    1,  0,  2,  0 }, {     30,   16,    1,  0,  2,  0 }, {     29,   16,    2,  0,  2,  0 }, {     28,   16,    3,  0,  2,  0 }, {     27,   16,    3,  0,  2,  0 },
    {     26,   16,    4,  0,  2,  0 }, {     25,   16,    4,  0,  2,  0 }, {     24,   16,    5,  0,  2,  0 }, {     23,   16,    6,  0,  2,  0 }, {     22,   15,    6,  0,  2,  0 },
    {     21,   15,    7, 31,  2,  0 }, {     20,   15,    7, 31,  2,  0 }, {     19,   15,    8, 31,  2,  0 }, {     18,   15,    8, 31,  2,  0 }, {     17,   15,    9, 31,  2,  0 },
    {     16,   15,   10, 31,  2,  0 }, {     15,   15,   10, 31,  2,  0 }, {     14,   14,   11, 31,  2,  0 }, {     13,   14,   11, 31,  2,  0 }, {     12,   14,   12, 31,  2,  0 },
    {     11,   14,   13, 31,  2,  0 }, {     10,   14,   13, 31,  2,  0 }, {      9,   13,   14, 31,  2,  0 }, {      8,   13,   14, 31,  2,  0 }, {      7,   13,   15, 31,  2,  0 },
    {      6,   13,   15, 31,  2,  0 }, {      5,   13,   16, 31,  2,  0 }, {      4,   12,   17, 31,  2,  0 }, {      3,   12,   17, 31,  2,  0 }, {      2,   12,   18, 31,  2,  0 },
    {      1,   11,   18, 31,  2,  0 }, {      0,   11,   19, 31,  2,  0 }, {     -1,   11,   19, 30,  2,  0 }, {     -2,   11,   20, 30,  2,  0 }, {     -3,   10,   21, 30,  2,  0 },
    {     -4,   10,   21, 30,  2,  0 }, {     -5,   10,   22, 30,  2,  0 }, {     -6,    9,   22, 30,  2,  0 }, {     -7,    9,   23, 30,  2,  0 }, {     -8,    8,   24, 30,  2,  0 },
    {     -9,    8,   24, 30,  2,  0 }, {    -10,    8,   25, 30,  2,  0 }, {    -11,    7,   25, 30,  2,  0 }, {    -12,    7,   26, 30,  2,  0 }, {    -13,    7,   26, 30,  2,  0 },
    {    -14,    6,   27, 30,  2,  0 }, {    -15,    6,   28, 30,  2,  0 }, {    -16,    5,   28, 30,  2,  0 }, {    -17,    5,   29, 30,  2,  0 }, {    -18,    4,   29, 30,  2,  0 },
    {    -19,    4,   30, 30,  2,  0 }, {    -20,    3,   31, 30,  2,  0 }, {    -21,    3,   31, 30,  2,  0 }, {    -22,    2,   32, 30,  2,  0 }, {    -23,    2,   32, 30,  2,  0 },
    {    -24,    1,   33, 29,  2,  0 }, {    -25,    1,   34, 29,  2,  0 }, {    -26,    0,   34, 29,  2,  0 }, {    -27,    0,   35, 29,  2,  0 }, {    -28,   -1,   35, 29,  2,  0 },
    {    -29,   -2,   36, 29,  2,  0 }, {    -30,   -2,   37, 29,  2,  0 }, {    -31,   -3,   37, 29,  2,  0 }, {    -32,   -4,   38, 29,  2,  0 }, {    -33,   -4,   38, 29,  2,  0 },
    {    -34,   -5,   39, 29,  2,  0 }, {    -35,   -6,   40, 29,  2,  0 }, {    -36,   -6,   40, 29,  2,  0 }, {    -37,   -7,   41, 29,  2,  0 }, {    -38,   -8,   42, 29,  2,  0 },
    {    -39,   -9,   42, 29,  2,  0 }, {    -40,   -9,   43, 29,  2,  0 }, {    -41,  -10,   44, 29,  2,  0 }, {    -42,  -11,   44, 28,  2,  0 }, {    -43,  -12,   45, 28,  2,  0 },
    {    -44,  -13,   46, 28,  2,  0 }, {    -45,  -14,   46, 28,  2,  0 }, {    -46,  -15,   47, 28,  2,  0 }, {    -47,  -15,   48, 28,  2,  0 }, {    -48,  -16,   48, 28,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToDiagUp251, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    1,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    2,  8,  2,  0 }, {     16,    4,    3,  8,  2,  0 },
    {     16,    5,    3,  8,  2,  0 }, {     16,    6,    4,  8,  2,  0 }, {     16,    7,    4,  8,  2,  0 }, {     16,    8,    5,  8,  2,  0 }, {     16,    9,    6,  8,  2,  0 },
    {     15,   10,    6,  8,  2,  0 }, {     15,   11,    7,  7,  2,  0 }, {     15,   12,    7,  7,  2,  0 }, {     15,   13,    8,  7,  2,  0 }, {     15,   14,    8,  7,  2,  0 },
    {     15,   15,    9,  7,  2,  0 }, {     15,   16,   10,  7,  2,  0 }, {     15,   17,   10,  7,  2,  0 }, {     14,   18,   11,  7,  2,  0 }, {     14,   19,   11,  7,  2,  0 },
    {     14,   20,   12,  7,  2,  0 }, {     14,   21,   13,  7,  2,  0 }, {     14,   22,   13,  7,  2,  0 }, {     13,   23,   14,  7,  2,  0 }, {     13,   24,   14,  7,  2,  0 },
    {     13,   25,   15,  7,  2,  0 }, {     13,   26,   15,  7,  2,  0 }, {     13,   27,   16,  7,  2,  0 }, {     12,   28,   17,  7,  2,  0 }, {     12,   29,   17,  7,  2,  0 },
    {     12,   30,   18,  7,  2,  0 }, {     11,   31,   18,  7,  2,  0 }, {     11,   32,   19,  7,  2,  0 }, {     11,   33,   19,  6,  2,  0 }, {     11,   34,   20,  6,  2,  0 },
    {     10,   35,   21,  6,  2,  0 }, {     10,   36,   21,  6,  2,  0 }, {     10,   37,   22,  6,  2,  0 }, {      9,   38,   22,  6,  2,  0 }, {      9,   39,   23,  6,  2,  0 },
    {      8,   40,   24,  6,  2,  0 }, {      8,   41,   24,  6,  2,  0 }, {      8,   42,   25,  6,  2,  0 }, {      7,   43,   25,  6,  2,  0 }, {      7,   44,   26,  6,  2,  0 },
    {      7,   45,   26,  6,  2,  0 }, {      6,   46,   27,  6,  2,  0 }, {      6,   47,   28,  6,  2,  0 }, {      5,   48,   28,  6,  2,  0 }, {      5,   49,   29,  6,  2,  0 },
    {      4,   50,   29,  6,  2,  0 }, {      4,   51,   30,  6,  2,  0 }, {      3,   52,   31,  6,  2,  0 }, {      3,   53,   31,  6,  2,  0 }, {      2,   54,   32,  6,  2,  0 },
    {      2,   55,   32,  6,  2,  0 }, {      1,   56,   33,  5,  2,  0 }, {      1,   57,   34,  5,  2,  0 }, {      0,   58,   34,  5,  2,  0 }, {      0,   59,   35,  5,  2,  0 },
    {     -1,   60,   35,  5,  2,  0 }, {     -2,   61,   36,  5,  2,  0 }, {     -2,   62,   37,  5,  2,  0 }, {     -3,   63,   37,  5,  2,  0 }, {     -4,   64,   38,  5,  2,  0 },
    {     -4,   65,   38,  5,  2,  0 }, {     -5,   66,   39,  5,  2,  0 }, {     -6,   67,   40,  5,  2,  0 }, {     -6,   68,   40,  5,  2,  0 }, {     -7,   69,   41,  5,  2,  0 },
    {     -8,   70,   42,  5,  2,  0 }, {     -9,   71,   42,  5,  2,  0 }, {     -9,   72,   43,  5,  2,  0 }, {    -10,   73,   44,  5,  2,  0 }, {    -11,   74,   44,  4,  2,  0 },
    {    -12,   75,   45,  4,  2,  0 }, {    -13,   76,   46,  4,  2,  0 }, {    -14,   77,   46,  4,  2,  0 }, {    -15,   78,   47,  4,  2,  0 }, {    -15,   79,   48,  4,  2,  0 },
    {    -16,   80,   48,  4,  2,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToDiagUp252, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    1, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    2, 16,  2,  0 }, {      4,   16,    3, 16,  2,  0 },
    {      5,   16,    3, 16,  2,  0 }, {      6,   16,    4, 16,  2,  0 }, {      7,   16,    4, 16,  2,  0 }, {      8,   16,    5, 16,  2,  0 }, {      9,   16,    6, 16,  2,  0 },
    {     10,   17,    6, 16,  2,  0 }, {     11,   17,    7, 15,  2,  0 }, {     12,   17,    7, 15,  2,  0 }, {     13,   17,    8, 15,  2,  0 }, {     14,   17,    8, 15,  2,  0 },
    {     15,   17,    9, 15,  2,  0 }, {     16,   17,   10, 15,  2,  0 }, {     17,   17,   10, 15,  2,  0 }, {     18,   18,   11, 15,  2,  0 }, {     19,   18,   11, 15,  2,  0 },
    {     20,   18,   12, 15,  2,  0 }, {     21,   18,   13, 15,  2,  0 }, {     22,   18,   13, 15,  2,  0 }, {     23,   19,   14, 15,  2,  0 }, {     24,   19,   14, 15,  2,  0 },
    {     25,   19,   15, 15,  2,  0 }, {     26,   19,   15, 15,  2,  0 }, {     27,   19,   16, 15,  2,  0 }, {     28,   20,   17, 15,  2,  0 }, {     29,   20,   17, 15,  2,  0 },
    {     30,   20,   18, 15,  2,  0 }, {     31,   21,   18, 15,  2,  0 }, {     32,   21,   19, 15,  2,  0 }, {     33,   21,   19, 14,  2,  0 }, {     34,   21,   20, 14,  2,  0 },
    {     35,   22,   21, 14,  2,  0 }, {     36,   22,   21, 14,  2,  0 }, {     37,   22,   22, 14,  2,  0 }, {     38,   23,   22, 14,  2,  0 }, {     39,   23,   23, 14,  2,  0 },
    {     40,   24,   24, 14,  2,  0 }, {     41,   24,   24, 14,  2,  0 }, {     42,   24,   25, 14,  2,  0 }, {     43,   25,   25, 14,  2,  0 }, {     44,   25,   26, 14,  2,  0 },
    {     45,   25,   26, 14,  2,  0 }, {     46,   26,   27, 14,  2,  0 }, {     47,   26,   28, 14,  2,  0 }, {     48,   27,   28, 14,  2,  0 }, {     49,   27,   29, 14,  2,  0 },
    {     50,   28,   29, 14,  2,  0 }, {     51,   28,   30, 14,  2,  0 }, {     52,   29,   31, 14,  2,  0 }, {     53,   29,   31, 14,  2,  0 }, {     54,   30,   32, 14,  2,  0 },
    {     55,   30,   32, 14,  2,  0 }, {     56,   31,   33, 13,  2,  0 }, {     57,   31,   34, 13,  2,  0 }, {     58,   32,   34, 13,  2,  0 }, {     59,   32,   35, 13,  2,  0 },
    {     60,   33,   35, 13,  2,  0 }, {     61,   34,   36, 13,  2,  0 }, {     62,   34,   37, 13,  2,  0 }, {     63,   35,   37, 13,  2,  0 }, {     64,   36,   38, 13,  2,  0 },
    {     65,   36,   38, 13,  2,  0 }, {     66,   37,   39, 13,  2,  0 }, {     67,   38,   40, 13,  2,  0 }, {     68,   38,   40, 13,  2,  0 }, {     69,   39,   41, 13,  2,  0 },
    {     70,   40,   42, 13,  2,  0 }, {     71,   41,   42, 13,  2,  0 }, {     72,   41,   43, 13,  2,  0 }, {     73,   42,   44, 13,  2,  0 }, {     74,   43,   44, 12,  2,  0 },
    {     75,   44,   45, 12,  2,  0 }, {     76,   45,   46, 12,  2,  0 }, {     77,   46,   46, 12,  2,  0 }, {     78,   47,   47, 12,  2,  0 }, {     79,   47,   48, 12,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToDiagUp253, {
    {     16,   31,    1, 24,  2,  0 }, {     16,   30,    1, 24,  2,  0 }, {     16,   29,    2, 24,  2,  0 }, {     16,   28,    3, 24,  2,  0 }, {     16,   27,    3, 24,  2,  0 },
    {     16,   26,    4, 24,  2,  0 }, {     16,   25,    4, 24,  2,  0 }, {     16,   24,    5, 24,  2,  0 }, {     16,   23,    6, 24,  2,  0 }, {     17,   22,    6, 24,  2,  0 },
    {     17,   21,    7, 23,  2,  0 }, {     17,   20,    7, 23,  2,  0 }, {     17,   19,    8, 23,  2,  0 }, {     17,   18,    8, 23,  2,  0 }, {     17,   17,    9, 23,  2,  0 },
    {     17,   16,   10, 23,  2,  0 }, {     17,   15,   10, 23,  2,  0 }, {     18,   14,   11, 23,  2,  0 }, {     18,   13,   11, 23,  2,  0 }, {     18,   12,   12, 23,  2,  0 },
    {     18,   11,   13, 23,  2,  0 }, {     18,   10,   13, 23,  2,  0 }, {     19,    9,   14, 23,  2,  0 }, {     19,    8,   14, 23,  2,  0 }, {     19,    7,   15, 23,  2,  0 },
    {     19,    6,   15, 23,  2,  0 }, {     19,    5,   16, 23,  2,  0 }, {     20,    4,   17, 23,  2,  0 }, {     20,    3,   17, 23,  2,  0 }, {     20,    2,   18, 23,  2,  0 },
    {     21,    1,   18, 23,  2,  0 }, {     21,    0,   19, 23,  2,  0 }, {     21,   -1,   19, 22,  2,  0 }, {     21,   -2,   20, 22,  2,  0 }, {     22,   -3,   21, 22,  2,  0 },
    {     22,   -4,   21, 22,  2,  0 }, {     22,   -5,   22, 22,  2,  0 }, {     23,   -6,   22, 22,  2,  0 }, {     23,   -7,   23, 22,  2,  0 }, {     24,   -8,   24, 22,  2,  0 },
    {     24,   -9,   24, 22,  2,  0 }, {     24,  -10,   25, 22,  2,  0 }, {     25,  -11,   25, 22,  2,  0 }, {     25,  -12,   26, 22,  2,  0 }, {     25,  -13,   26, 22,  2,  0 },
    {     26,  -14,   27, 22,  2,  0 }, {     26,  -15,   28, 22,  2,  0 }, {     27,  -16,   28, 22,  2,  0 }, {     27,  -17,   29, 22,  2,  0 }, {     28,  -18,   29, 22,  2,  0 },
    {     28,  -19,   30, 22,  2,  0 }, {     29,  -20,   31, 22,  2,  0 }, {     29,  -21,   31, 22,  2,  0 }, {     30,  -22,   32, 22,  2,  0 }, {     30,  -23,   32, 22,  2,  0 },
    {     31,  -24,   33, 21,  2,  0 }, {     31,  -25,   34, 21,  2,  0 }, {     32,  -26,   34, 21,  2,  0 }, {     32,  -27,   35, 21,  2,  0 }, {     33,  -28,   35, 21,  2,  0 },
    {     34,  -29,   36, 21,  2,  0 }, {     34,  -30,   37, 21,  2,  0 }, {     35,  -31,   37, 21,  2,  0 }, {     36,  -32,   38, 21,  2,  0 }, {     36,  -33,   38, 21,  2,  0 },
    {     37,  -34,   39, 21,  2,  0 }, {     38,  -35,   40, 21,  2,  0 }, {     38,  -36,   40, 21,  2,  0 }, {     39,  -37,   41, 21,  2,  0 }, {     40,  -38,   42, 21,  2,  0 },
    {     41,  -39,   42, 21,  2,  0 }, {     41,  -40,   43, 21,  2,  0 }, {     42,  -41,   44, 21,  2,  0 }, {     43,  -42,   44, 20,  2,  0 }, {     44,  -43,   45, 20,  2,  0 },
    {     45,  -44,   46, 20,  2,  0 }, {     46,  -45,   46, 20,  2,  0 }, {     47,  -46,   47, 20,  2,  0 }, {     47,  -47,   48, 20,  2,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToDiagUp250, {
    {     31,   16,    1,  0,  2,  0 }, {     30,   16,    1,  0,  2,  0 }, {     29,   16,    2,  0,  2,  0 }, {     28,   16,    3,  0,  2,  0 }, {     27,   16,    3,  0,  2,  0 },
    {     26,   16,    4,  0,  2,  0 }, {     25,   16,    4,  0,  2,  0 }, {     24,   16,    5,  0,  2,  0 }, {     23,   16,    6,  0,  2,  0 }, {     22,   17,    6,  0,  2,  0 },
    {     21,   17,    7,  1,  2,  0 }, {     20,   17,    7,  1,  2,  0 }, {     19,   17,    8,  1,  2,  0 }, {     18,   17,    8,  1,  2,  0 }, {     17,   17,    9,  1,  2,  0 },
    {     16,   17,   10,  1,  2,  0 }, {     15,   17,   10,  1,  2,  0 }, {     14,   18,   11,  1,  2,  0 }, {     13,   18,   11,  1,  2,  0 }, {     12,   18,   12,  1,  2,  0 },
    {     11,   18,   13,  1,  2,  0 }, {     10,   18,   13,  1,  2,  0 }, {      9,   19,   14,  1,  2,  0 }, {      8,   19,   14,  1,  2,  0 }, {      7,   19,   15,  1,  2,  0 },
    {      6,   19,   15,  1,  2,  0 }, {      5,   19,   16,  1,  2,  0 }, {      4,   20,   17,  1,  2,  0 }, {      3,   20,   17,  1,  2,  0 }, {      2,   20,   18,  1,  2,  0 },
    {      1,   21,   18,  1,  2,  0 }, {      0,   21,   19,  1,  2,  0 }, {     -1,   21,   19,  2,  2,  0 }, {     -2,   21,   20,  2,  2,  0 }, {     -3,   22,   21,  2,  2,  0 },
    {     -4,   22,   21,  2,  2,  0 }, {     -5,   22,   22,  2,  2,  0 }, {     -6,   23,   22,  2,  2,  0 }, {     -7,   23,   23,  2,  2,  0 }, {     -8,   24,   24,  2,  2,  0 },
    {     -9,   24,   24,  2,  2,  0 }, {    -10,   24,   25,  2,  2,  0 }, {    -11,   25,   25,  2,  2,  0 }, {    -12,   25,   26,  2,  2,  0 }, {    -13,   25,   26,  2,  2,  0 },
    {    -14,   26,   27,  2,  2,  0 }, {    -15,   26,   28,  2,  2,  0 }, {    -16,   27,   28,  2,  2,  0 }, {    -17,   27,   29,  2,  2,  0 }, {    -18,   28,   29,  2,  2,  0 },
    {    -19,   28,   30,  2,  2,  0 }, {    -20,   29,   31,  2,  2,  0 }, {    -21,   29,   31,  2,  2,  0 }, {    -22,   30,   32,  2,  2,  0 }, {    -23,   30,   32,  2,  2,  0 },
    {    -24,   31,   33,  3,  2,  0 }, {    -25,   31,   34,  3,  2,  0 }, {    -26,   32,   34,  3,  2,  0 }, {    -27,   32,   35,  3,  2,  0 }, {    -28,   33,   35,  3,  2,  0 },
    {    -29,   34,   36,  3,  2,  0 }, {    -30,   34,   37,  3,  2,  0 }, {    -31,   35,   37,  3,  2,  0 }, {    -32,   36,   38,  3,  2,  0 }, {    -33,   36,   38,  3,  2,  0 },
    {    -34,   37,   39,  3,  2,  0 }, {    -35,   38,   40,  3,  2,  0 }, {    -36,   38,   40,  3,  2,  0 }, {    -37,   39,   41,  3,  2,  0 }, {    -38,   40,   42,  3,  2,  0 },
    {    -39,   41,   42,  3,  2,  0 }, {    -40,   41,   43,  3,  2,  0 }, {    -41,   42,   44,  3,  2,  0 }, {    -42,   43,   44,  4,  2,  0 }, {    -43,   44,   45,  4,  2,  0 },
    {    -44,   45,   46,  4,  2,  0 }, {    -45,   46,   46,  4,  2,  0 }, {    -46,   47,   47,  4,  2,  0 }, {    -47,   47,   48,  4,  2,  0 }, {    -48,   48,   48,  4,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToDiagUp251, {
    {     16,    0,    0,  8,  2,  0 }, {     16,    1,    1,  8,  2,  0 }, {     16,    2,    1,  8,  2,  0 }, {     16,    3,    2,  8,  2,  0 }, {     16,    4,    3,  8,  2,  0 },
    {     16,    5,    3,  8,  2,  0 }, {     16,    6,    4,  8,  2,  0 }, {     16,    7,    4,  8,  2,  0 }, {     16,    8,    5,  8,  2,  0 }, {     16,    9,    6,  8,  2,  0 },
    {     17,   10,    6,  8,  2,  0 }, {     17,   11,    7,  9,  2,  0 }, {     17,   12,    7,  9,  2,  0 }, {     17,   13,    8,  9,  2,  0 }, {     17,   14,    8,  9,  2,  0 },
    {     17,   15,    9,  9,  2,  0 }, {     17,   16,   10,  9,  2,  0 }, {     17,   17,   10,  9,  2,  0 }, {     18,   18,   11,  9,  2,  0 }, {     18,   19,   11,  9,  2,  0 },
    {     18,   20,   12,  9,  2,  0 }, {     18,   21,   13,  9,  2,  0 }, {     18,   22,   13,  9,  2,  0 }, {     19,   23,   14,  9,  2,  0 }, {     19,   24,   14,  9,  2,  0 },
    {     19,   25,   15,  9,  2,  0 }, {     19,   26,   15,  9,  2,  0 }, {     19,   27,   16,  9,  2,  0 }, {     20,   28,   17,  9,  2,  0 }, {     20,   29,   17,  9,  2,  0 },
    {     20,   30,   18,  9,  2,  0 }, {     21,   31,   18,  9,  2,  0 }, {     21,   32,   19,  9,  2,  0 }, {     21,   33,   19, 10,  2,  0 }, {     21,   34,   20, 10,  2,  0 },
    {     22,   35,   21, 10,  2,  0 }, {     22,   36,   21, 10,  2,  0 }, {     22,   37,   22, 10,  2,  0 }, {     23,   38,   22, 10,  2,  0 }, {     23,   39,   23, 10,  2,  0 },
    {     24,   40,   24, 10,  2,  0 }, {     24,   41,   24, 10,  2,  0 }, {     24,   42,   25, 10,  2,  0 }, {     25,   43,   25, 10,  2,  0 }, {     25,   44,   26, 10,  2,  0 },
    {     25,   45,   26, 10,  2,  0 }, {     26,   46,   27, 10,  2,  0 }, {     26,   47,   28, 10,  2,  0 }, {     27,   48,   28, 10,  2,  0 }, {     27,   49,   29, 10,  2,  0 },
    {     28,   50,   29, 10,  2,  0 }, {     28,   51,   30, 10,  2,  0 }, {     29,   52,   31, 10,  2,  0 }, {     29,   53,   31, 10,  2,  0 }, {     30,   54,   32, 10,  2,  0 },
    {     30,   55,   32, 10,  2,  0 }, {     31,   56,   33, 11,  2,  0 }, {     31,   57,   34, 11,  2,  0 }, {     32,   58,   34, 11,  2,  0 }, {     32,   59,   35, 11,  2,  0 },
    {     33,   60,   35, 11,  2,  0 }, {     34,   61,   36, 11,  2,  0 }, {     34,   62,   37, 11,  2,  0 }, {     35,   63,   37, 11,  2,  0 }, {     36,   64,   38, 11,  2,  0 },
    {     36,   65,   38, 11,  2,  0 }, {     37,   66,   39, 11,  2,  0 }, {     38,   67,   40, 11,  2,  0 }, {     38,   68,   40, 11,  2,  0 }, {     39,   69,   41, 11,  2,  0 },
    {     40,   70,   42, 11,  2,  0 }, {     41,   71,   42, 11,  2,  0 }, {     41,   72,   43, 11,  2,  0 }, {     42,   73,   44, 11,  2,  0 }, {     43,   74,   44, 12,  2,  0 },
    {     44,   75,   45, 12,  2,  0 }, {     45,   76,   46, 12,  2,  0 }, {     46,   77,   46, 12,  2,  0 }, {     47,   78,   47, 12,  2,  0 }, {     47,   79,   48, 12,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToDiagUp252, {
    {      0,   16,    0, 16,  2,  0 }, {      1,   16,    1, 16,  2,  0 }, {      2,   16,    1, 16,  2,  0 }, {      3,   16,    2, 16,  2,  0 }, {      4,   16,    3, 16,  2,  0 },
    {      5,   16,    3, 16,  2,  0 }, {      6,   16,    4, 16,  2,  0 }, {      7,   16,    4, 16,  2,  0 }, {      8,   16,    5, 16,  2,  0 }, {      9,   16,    6, 16,  2,  0 },
    {     10,   15,    6, 16,  2,  0 }, {     11,   15,    7, 17,  2,  0 }, {     12,   15,    7, 17,  2,  0 }, {     13,   15,    8, 17,  2,  0 }, {     14,   15,    8, 17,  2,  0 },
    {     15,   15,    9, 17,  2,  0 }, {     16,   15,   10, 17,  2,  0 }, {     17,   15,   10, 17,  2,  0 }, {     18,   14,   11, 17,  2,  0 }, {     19,   14,   11, 17,  2,  0 },
    {     20,   14,   12, 17,  2,  0 }, {     21,   14,   13, 17,  2,  0 }, {     22,   14,   13, 17,  2,  0 }, {     23,   13,   14, 17,  2,  0 }, {     24,   13,   14, 17,  2,  0 },
    {     25,   13,   15, 17,  2,  0 }, {     26,   13,   15, 17,  2,  0 }, {     27,   13,   16, 17,  2,  0 }, {     28,   12,   17, 17,  2,  0 }, {     29,   12,   17, 17,  2,  0 },
    {     30,   12,   18, 17,  2,  0 }, {     31,   11,   18, 17,  2,  0 }, {     32,   11,   19, 17,  2,  0 }, {     33,   11,   19, 18,  2,  0 }, {     34,   11,   20, 18,  2,  0 },
    {     35,   10,   21, 18,  2,  0 }, {     36,   10,   21, 18,  2,  0 }, {     37,   10,   22, 18,  2,  0 }, {     38,    9,   22, 18,  2,  0 }, {     39,    9,   23, 18,  2,  0 },
    {     40,    8,   24, 18,  2,  0 }, {     41,    8,   24, 18,  2,  0 }, {     42,    8,   25, 18,  2,  0 }, {     43,    7,   25, 18,  2,  0 }, {     44,    7,   26, 18,  2,  0 },
    {     45,    7,   26, 18,  2,  0 }, {     46,    6,   27, 18,  2,  0 }, {     47,    6,   28, 18,  2,  0 }, {     48,    5,   28, 18,  2,  0 }, {     49,    5,   29, 18,  2,  0 },
    {     50,    4,   29, 18,  2,  0 }, {     51,    4,   30, 18,  2,  0 }, {     52,    3,   31, 18,  2,  0 }, {     53,    3,   31, 18,  2,  0 }, {     54,    2,   32, 18,  2,  0 },
    {     55,    2,   32, 18,  2,  0 }, {     56,    1,   33, 19,  2,  0 }, {     57,    1,   34, 19,  2,  0 }, {     58,    0,   34, 19,  2,  0 }, {     59,    0,   35, 19,  2,  0 },
    {     60,   -1,   35, 19,  2,  0 }, {     61,   -2,   36, 19,  2,  0 }, {     62,   -2,   37, 19,  2,  0 }, {     63,   -3,   37, 19,  2,  0 }, {     64,   -4,   38, 19,  2,  0 },
    {     65,   -4,   38, 19,  2,  0 }, {     66,   -5,   39, 19,  2,  0 }, {     67,   -6,   40, 19,  2,  0 }, {     68,   -6,   40, 19,  2,  0 }, {     69,   -7,   41, 19,  2,  0 },
    {     70,   -8,   42, 19,  2,  0 }, {     71,   -9,   42, 19,  2,  0 }, {     72,   -9,   43, 19,  2,  0 }, {     73,  -10,   44, 19,  2,  0 }, {     74,  -11,   44, 20,  2,  0 },
    {     75,  -12,   45, 20,  2,  0 }, {     76,  -13,   46, 20,  2,  0 }, {     77,  -14,   46, 20,  2,  0 }, {     78,  -15,   47, 20,  2,  0 }, {     79,  -15,   48, 20,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToDiagUp253, {
    {     16,   31,    1, 24,  2,  0 }, {     16,   30,    1, 24,  2,  0 }, {     16,   29,    2, 24,  2,  0 }, {     16,   28,    3, 24,  2,  0 }, {     16,   27,    3, 24,  2,  0 },
    {     16,   26,    4, 24,  2,  0 }, {     16,   25,    4, 24,  2,  0 }, {     16,   24,    5, 24,  2,  0 }, {     16,   23,    6, 24,  2,  0 }, {     15,   22,    6, 24,  2,  0 },
    {     15,   21,    7, 25,  2,  0 }, {     15,   20,    7, 25,  2,  0 }, {     15,   19,    8, 25,  2,  0 }, {     15,   18,    8, 25,  2,  0 }, {     15,   17,    9, 25,  2,  0 },
    {     15,   16,   10, 25,  2,  0 }, {     15,   15,   10, 25,  2,  0 }, {     14,   14,   11, 25,  2,  0 }, {     14,   13,   11, 25,  2,  0 }, {     14,   12,   12, 25,  2,  0 },
    {     14,   11,   13, 25,  2,  0 }, {     14,   10,   13, 25,  2,  0 }, {     13,    9,   14, 25,  2,  0 }, {     13,    8,   14, 25,  2,  0 }, {     13,    7,   15, 25,  2,  0 },
    {     13,    6,   15, 25,  2,  0 }, {     13,    5,   16, 25,  2,  0 }, {     12,    4,   17, 25,  2,  0 }, {     12,    3,   17, 25,  2,  0 }, {     12,    2,   18, 25,  2,  0 },
    {     11,    1,   18, 25,  2,  0 }, {     11,    0,   19, 25,  2,  0 }, {     11,   -1,   19, 26,  2,  0 }, {     11,   -2,   20, 26,  2,  0 }, {     10,   -3,   21, 26,  2,  0 },
    {     10,   -4,   21, 26,  2,  0 }, {     10,   -5,   22, 26,  2,  0 }, {      9,   -6,   22, 26,  2,  0 }, {      9,   -7,   23, 26,  2,  0 }, {      8,   -8,   24, 26,  2,  0 },
    {      8,   -9,   24, 26,  2,  0 }, {      8,  -10,   25, 26,  2,  0 }, {      7,  -11,   25, 26,  2,  0 }, {      7,  -12,   26, 26,  2,  0 }, {      7,  -13,   26, 26,  2,  0 },
    {      6,  -14,   27, 26,  2,  0 }, {      6,  -15,   28, 26,  2,  0 }, {      5,  -16,   28, 26,  2,  0 }, {      5,  -17,   29, 26,  2,  0 }, {      4,  -18,   29, 26,  2,  0 },
    {      4,  -19,   30, 26,  2,  0 }, {      3,  -20,   31, 26,  2,  0 }, {      3,  -21,   31, 26,  2,  0 }, {      2,  -22,   32, 26,  2,  0 }, {      2,  -23,   32, 26,  2,  0 },
    {      1,  -24,   33, 27,  2,  0 }, {      1,  -25,   34, 27,  2,  0 }, {      0,  -26,   34, 27,  2,  0 }, {      0,  -27,   35, 27,  2,  0 }, {     -1,  -28,   35, 27,  2,  0 },
    {     -2,  -29,   36, 27,  2,  0 }, {     -2,  -30,   37, 27,  2,  0 }, {     -3,  -31,   37, 27,  2,  0 }, {     -4,  -32,   38, 27,  2,  0 }, {     -4,  -33,   38, 27,  2,  0 },
    {     -5,  -34,   39, 27,  2,  0 }, {     -6,  -35,   40, 27,  2,  0 }, {     -6,  -36,   40, 27,  2,  0 }, {     -7,  -37,   41, 27,  2,  0 }, {     -8,  -38,   42, 27,  2,  0 },
    {     -9,  -39,   42, 27,  2,  0 }, {     -9,  -40,   43, 27,  2,  0 }, {    -10,  -41,   44, 27,  2,  0 }, {    -11,  -42,   44, 28,  2,  0 }, {    -12,  -43,   45, 28,  2,  0 },
    {    -13,  -44,   46, 28,  2,  0 }, {    -14,  -45,   46, 28,  2,  0 }, {    -15,  -46,   47, 28,  2,  0 }, {    -15,  -47,   48, 28,  2,  0 }, {    -16,  -48,   48, 28,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToDiagDown250, {
    {     31,   16,   15,  0,  6,  0 }, {     30,   16,   15,  0,  6,  0 }, {     29,   16,   14,  0,  6,  0 }, {     28,   16,   13,  0,  6,  0 }, {     27,   16,   13,  0,  6,  0 },
    {     26,   16,   12,  0,  6,  0 }, {     25,   16,   12,  0,  6,  0 }, {     24,   16,   11,  0,  6,  0 }, {     23,   16,   10,  0,  6,  0 }, {     22,   15,   10,  0,  6,  0 },
    {     21,   15,    9, 31,  6,  0 }, {     20,   15,    9, 31,  6,  0 }, {     19,   15,    8, 31,  6,  0 }, {     18,   15,    8, 31,  6,  0 }, {     17,   15,    7, 31,  6,  0 },
    {     16,   15,    6, 31,  6,  0 }, {     15,   15,    6, 31,  6,  0 }, {     14,   14,    5, 31,  6,  0 }, {     13,   14,    5, 31,  6,  0 }, {     12,   14,    4, 31,  6,  0 },
    {     11,   14,    3, 31,  6,  0 }, {     10,   14,    3, 31,  6,  0 }, {      9,   13,    2, 31,  6,  0 }, {      8,   13,    2, 31,  6,  0 }, {      7,   13,    1, 31,  6,  0 },
    {      6,   13,    1, 31,  6,  0 }, {      5,   13,    0, 31,  6,  0 }, {      4,   12,   -1, 31,  6,  0 }, {      3,   12,   -1, 31,  6,  0 }, {      2,   12,   -2, 31,  6,  0 },
    {      1,   11,   -2, 31,  6,  0 }, {      0,   11,   -3, 31,  6,  0 }, {     -1,   11,   -3, 30,  6,  0 }, {     -2,   11,   -4, 30,  6,  0 }, {     -3,   10,   -5, 30,  6,  0 },
    {     -4,   10,   -5, 30,  6,  0 }, {     -5,   10,   -6, 30,  6,  0 }, {     -6,    9,   -6, 30,  6,  0 }, {     -7,    9,   -7, 30,  6,  0 }, {     -8,    8,   -8, 30,  6,  0 },
    {     -9,    8,   -8, 30,  6,  0 }, {    -10,    8,   -9, 30,  6,  0 }, {    -11,    7,   -9, 30,  6,  0 }, {    -12,    7,  -10, 30,  6,  0 }, {    -13,    7,  -10, 30,  6,  0 },
    {    -14,    6,  -11, 30,  6,  0 }, {    -15,    6,  -12, 30,  6,  0 }, {    -16,    5,  -12, 30,  6,  0 }, {    -17,    5,  -13, 30,  6,  0 }, {    -18,    4,  -13, 30,  6,  0 },
    {    -19,    4,  -14, 30,  6,  0 }, {    -20,    3,  -15, 30,  6,  0 }, {    -21,    3,  -15, 30,  6,  0 }, {    -22,    2,  -16, 30,  6,  0 }, {    -23,    2,  -16, 30,  6,  0 },
    {    -24,    1,  -17, 29,  6,  0 }, {    -25,    1,  -18, 29,  6,  0 }, {    -26,    0,  -18, 29,  6,  0 }, {    -27,    0,  -19, 29,  6,  0 }, {    -28,   -1,  -19, 29,  6,  0 },
    {    -29,   -2,  -20, 29,  6,  0 }, {    -30,   -2,  -21, 29,  6,  0 }, {    -31,   -3,  -21, 29,  6,  0 }, {    -32,   -4,  -22, 29,  6,  0 }, {    -33,   -4,  -22, 29,  6,  0 },
    {    -34,   -5,  -23, 29,  6,  0 }, {    -35,   -6,  -24, 29,  6,  0 }, {    -36,   -6,  -24, 29,  6,  0 }, {    -37,   -7,  -25, 29,  6,  0 }, {    -38,   -8,  -26, 29,  6,  0 },
    {    -39,   -9,  -26, 29,  6,  0 }, {    -40,   -9,  -27, 29,  6,  0 }, {    -41,  -10,  -28, 29,  6,  0 }, {    -42,  -11,  -28, 28,  6,  0 }, {    -43,  -12,  -29, 28,  6,  0 },
    {    -44,  -13,  -30, 28,  6,  0 }, {    -45,  -14,  -30, 28,  6,  0 }, {    -46,  -15,  -31, 28,  6,  0 }, {    -47,  -15,  -32, 28,  6,  0 }, {    -48,  -16,  -32, 28,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToDiagDown251, {
    {     16,    0,   16,  8,  6,  0 }, {     16,    1,   15,  8,  6,  0 }, {     16,    2,   15,  8,  6,  0 }, {     16,    3,   14,  8,  6,  0 }, {     16,    4,   13,  8,  6,  0 },
    {     16,    5,   13,  8,  6,  0 }, {     16,    6,   12,  8,  6,  0 }, {     16,    7,   12,  8,  6,  0 }, {     16,    8,   11,  8,  6,  0 }, {     16,    9,   10,  8,  6,  0 },
    {     15,   10,   10,  8,  6,  0 }, {     15,   11,    9,  7,  6,  0 }, {     15,   12,    9,  7,  6,  0 }, {     15,   13,    8,  7,  6,  0 }, {     15,   14,    8,  7,  6,  0 },
    {     15,   15,    7,  7,  6,  0 }, {     15,   16,    6,  7,  6,  0 }, {     15,   17,    6,  7,  6,  0 }, {     14,   18,    5,  7,  6,  0 }, {     14,   19,    5,  7,  6,  0 },
    {     14,   20,    4,  7,  6,  0 }, {     14,   21,    3,  7,  6,  0 }, {     14,   22,    3,  7,  6,  0 }, {     13,   23,    2,  7,  6,  0 }, {     13,   24,    2,  7,  6,  0 },
    {     13,   25,    1,  7,  6,  0 }, {     13,   26,    1,  7,  6,  0 }, {     13,   27,    0,  7,  6,  0 }, {     12,   28,   -1,  7,  6,  0 }, {     12,   29,   -1,  7,  6,  0 },
    {     12,   30,   -2,  7,  6,  0 }, {     11,   31,   -2,  7,  6,  0 }, {     11,   32,   -3,  7,  6,  0 }, {     11,   33,   -3,  6,  6,  0 }, {     11,   34,   -4,  6,  6,  0 },
    {     10,   35,   -5,  6,  6,  0 }, {     10,   36,   -5,  6,  6,  0 }, {     10,   37,   -6,  6,  6,  0 }, {      9,   38,   -6,  6,  6,  0 }, {      9,   39,   -7,  6,  6,  0 },
    {      8,   40,   -8,  6,  6,  0 }, {      8,   41,   -8,  6,  6,  0 }, {      8,   42,   -9,  6,  6,  0 }, {      7,   43,   -9,  6,  6,  0 }, {      7,   44,  -10,  6,  6,  0 },
    {      7,   45,  -10,  6,  6,  0 }, {      6,   46,  -11,  6,  6,  0 }, {      6,   47,  -12,  6,  6,  0 }, {      5,   48,  -12,  6,  6,  0 }, {      5,   49,  -13,  6,  6,  0 },
    {      4,   50,  -13,  6,  6,  0 }, {      4,   51,  -14,  6,  6,  0 }, {      3,   52,  -15,  6,  6,  0 }, {      3,   53,  -15,  6,  6,  0 }, {      2,   54,  -16,  6,  6,  0 },
    {      2,   55,  -16,  6,  6,  0 }, {      1,   56,  -17,  5,  6,  0 }, {      1,   57,  -18,  5,  6,  0 }, {      0,   58,  -18,  5,  6,  0 }, {      0,   59,  -19,  5,  6,  0 },
    {     -1,   60,  -19,  5,  6,  0 }, {     -2,   61,  -20,  5,  6,  0 }, {     -2,   62,  -21,  5,  6,  0 }, {     -3,   63,  -21,  5,  6,  0 }, {     -4,   64,  -22,  5,  6,  0 },
    {     -4,   65,  -22,  5,  6,  0 }, {     -5,   66,  -23,  5,  6,  0 }, {     -6,   67,  -24,  5,  6,  0 }, {     -6,   68,  -24,  5,  6,  0 }, {     -7,   69,  -25,  5,  6,  0 },
    {     -8,   70,  -26,  5,  6,  0 }, {     -9,   71,  -26,  5,  6,  0 }, {     -9,   72,  -27,  5,  6,  0 }, {    -10,   73,  -28,  5,  6,  0 }, {    -11,   74,  -28,  4,  6,  0 },
    {    -12,   75,  -29,  4,  6,  0 }, {    -13,   76,  -30,  4,  6,  0 }, {    -14,   77,  -30,  4,  6,  0 }, {    -15,   78,  -31,  4,  6,  0 }, {    -15,   79,  -32,  4,  6,  0 },
    {    -16,   80,  -32,  4,  6,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToDiagDown252, {
    {      0,   16,   16, 16,  6,  0 }, {      1,   16,   15, 16,  6,  0 }, {      2,   16,   15, 16,  6,  0 }, {      3,   16,   14, 16,  6,  0 }, {      4,   16,   13, 16,  6,  0 },
    {      5,   16,   13, 16,  6,  0 }, {      6,   16,   12, 16,  6,  0 }, {      7,   16,   12, 16,  6,  0 }, {      8,   16,   11, 16,  6,  0 }, {      9,   16,   10, 16,  6,  0 },
    {     10,   17,   10, 16,  6,  0 }, {     11,   17,    9, 15,  6,  0 }, {     12,   17,    9, 15,  6,  0 }, {     13,   17,    8, 15,  6,  0 }, {     14,   17,    8, 15,  6,  0 },
    {     15,   17,    7, 15,  6,  0 }, {     16,   17,    6, 15,  6,  0 }, {     17,   17,    6, 15,  6,  0 }, {     18,   18,    5, 15,  6,  0 }, {     19,   18,    5, 15,  6,  0 },
    {     20,   18,    4, 15,  6,  0 }, {     21,   18,    3, 15,  6,  0 }, {     22,   18,    3, 15,  6,  0 }, {     23,   19,    2, 15,  6,  0 }, {     24,   19,    2, 15,  6,  0 },
    {     25,   19,    1, 15,  6,  0 }, {     26,   19,    1, 15,  6,  0 }, {     27,   19,    0, 15,  6,  0 }, {     28,   20,   -1, 15,  6,  0 }, {     29,   20,   -1, 15,  6,  0 },
    {     30,   20,   -2, 15,  6,  0 }, {     31,   21,   -2, 15,  6,  0 }, {     32,   21,   -3, 15,  6,  0 }, {     33,   21,   -3, 14,  6,  0 }, {     34,   21,   -4, 14,  6,  0 },
    {     35,   22,   -5, 14,  6,  0 }, {     36,   22,   -5, 14,  6,  0 }, {     37,   22,   -6, 14,  6,  0 }, {     38,   23,   -6, 14,  6,  0 }, {     39,   23,   -7, 14,  6,  0 },
    {     40,   24,   -8, 14,  6,  0 }, {     41,   24,   -8, 14,  6,  0 }, {     42,   24,   -9, 14,  6,  0 }, {     43,   25,   -9, 14,  6,  0 }, {     44,   25,  -10, 14,  6,  0 },
    {     45,   25,  -10, 14,  6,  0 }, {     46,   26,  -11, 14,  6,  0 }, {     47,   26,  -12, 14,  6,  0 }, {     48,   27,  -12, 14,  6,  0 }, {     49,   27,  -13, 14,  6,  0 },
    {     50,   28,  -13, 14,  6,  0 }, {     51,   28,  -14, 14,  6,  0 }, {     52,   29,  -15, 14,  6,  0 }, {     53,   29,  -15, 14,  6,  0 }, {     54,   30,  -16, 14,  6,  0 },
    {     55,   30,  -16, 14,  6,  0 }, {     56,   31,  -17, 13,  6,  0 }, {     57,   31,  -18, 13,  6,  0 }, {     58,   32,  -18, 13,  6,  0 }, {     59,   32,  -19, 13,  6,  0 },
    {     60,   33,  -19, 13,  6,  0 }, {     61,   34,  -20, 13,  6,  0 }, {     62,   34,  -21, 13,  6,  0 }, {     63,   35,  -21, 13,  6,  0 }, {     64,   36,  -22, 13,  6,  0 },
    {     65,   36,  -22, 13,  6,  0 }, {     66,   37,  -23, 13,  6,  0 }, {     67,   38,  -24, 13,  6,  0 }, {     68,   38,  -24, 13,  6,  0 }, {     69,   39,  -25, 13,  6,  0 },
    {     70,   40,  -26, 13,  6,  0 }, {     71,   41,  -26, 13,  6,  0 }, {     72,   41,  -27, 13,  6,  0 }, {     73,   42,  -28, 13,  6,  0 }, {     74,   43,  -28, 12,  6,  0 },
    {     75,   44,  -29, 12,  6,  0 }, {     76,   45,  -30, 12,  6,  0 }, {     77,   46,  -30, 12,  6,  0 }, {     78,   47,  -31, 12,  6,  0 }, {     79,   47,  -32, 12,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToDiagDown253, {
    {     16,   31,   15, 24,  6,  0 }, {     16,   30,   15, 24,  6,  0 }, {     16,   29,   14, 24,  6,  0 }, {     16,   28,   13, 24,  6,  0 }, {     16,   27,   13, 24,  6,  0 },
    {     16,   26,   12, 24,  6,  0 }, {     16,   25,   12, 24,  6,  0 }, {     16,   24,   11, 24,  6,  0 }, {     16,   23,   10, 24,  6,  0 }, {     17,   22,   10, 24,  6,  0 },
    {     17,   21,    9, 23,  6,  0 }, {     17,   20,    9, 23,  6,  0 }, {     17,   19,    8, 23,  6,  0 }, {     17,   18,    8, 23,  6,  0 }, {     17,   17,    7, 23,  6,  0 },
    {     17,   16,    6, 23,  6,  0 }, {     17,   15,    6, 23,  6,  0 }, {     18,   14,    5, 23,  6,  0 }, {     18,   13,    5, 23,  6,  0 }, {     18,   12,    4, 23,  6,  0 },
    {     18,   11,    3, 23,  6,  0 }, {     18,   10,    3, 23,  6,  0 }, {     19,    9,    2, 23,  6,  0 }, {     19,    8,    2, 23,  6,  0 }, {     19,    7,    1, 23,  6,  0 },
    {     19,    6,    1, 23,  6,  0 }, {     19,    5,    0, 23,  6,  0 }, {     20,    4,   -1, 23,  6,  0 }, {     20,    3,   -1, 23,  6,  0 }, {     20,    2,   -2, 23,  6,  0 },
    {     21,    1,   -2, 23,  6,  0 }, {     21,    0,   -3, 23,  6,  0 }, {     21,   -1,   -3, 22,  6,  0 }, {     21,   -2,   -4, 22,  6,  0 }, {     22,   -3,   -5, 22,  6,  0 },
    {     22,   -4,   -5, 22,  6,  0 }, {     22,   -5,   -6, 22,  6,  0 }, {     23,   -6,   -6, 22,  6,  0 }, {     23,   -7,   -7, 22,  6,  0 }, {     24,   -8,   -8, 22,  6,  0 },
    {     24,   -9,   -8, 22,  6,  0 }, {     24,  -10,   -9, 22,  6,  0 }, {     25,  -11,   -9, 22,  6,  0 }, {     25,  -12,  -10, 22,  6,  0 }, {     25,  -13,  -10, 22,  6,  0 },
    {     26,  -14,  -11, 22,  6,  0 }, {     26,  -15,  -12, 22,  6,  0 }, {     27,  -16,  -12, 22,  6,  0 }, {     27,  -17,  -13, 22,  6,  0 }, {     28,  -18,  -13, 22,  6,  0 },
    {     28,  -19,  -14, 22,  6,  0 }, {     29,  -20,  -15, 22,  6,  0 }, {     29,  -21,  -15, 22,  6,  0 }, {     30,  -22,  -16, 22,  6,  0 }, {     30,  -23,  -16, 22,  6,  0 },
    {     31,  -24,  -17, 21,  6,  0 }, {     31,  -25,  -18, 21,  6,  0 }, {     32,  -26,  -18, 21,  6,  0 }, {     32,  -27,  -19, 21,  6,  0 }, {     33,  -28,  -19, 21,  6,  0 },
    {     34,  -29,  -20, 21,  6,  0 }, {     34,  -30,  -21, 21,  6,  0 }, {     35,  -31,  -21, 21,  6,  0 }, {     36,  -32,  -22, 21,  6,  0 }, {     36,  -33,  -22, 21,  6,  0 },
    {     37,  -34,  -23, 21,  6,  0 }, {     38,  -35,  -24, 21,  6,  0 }, {     38,  -36,  -24, 21,  6,  0 }, {     39,  -37,  -25, 21,  6,  0 }, {     40,  -38,  -26, 21,  6,  0 },
    {     41,  -39,  -26, 21,  6,  0 }, {     41,  -40,  -27, 21,  6,  0 }, {     42,  -41,  -28, 21,  6,  0 }, {     43,  -42,  -28, 20,  6,  0 }, {     44,  -43,  -29, 20,  6,  0 },
    {     45,  -44,  -30, 20,  6,  0 }, {     46,  -45,  -30, 20,  6,  0 }, {     47,  -46,  -31, 20,  6,  0 }, {     47,  -47,  -32, 20,  6,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToDiagDown250, {
    {     31,   16,   15,  0,  6,  0 }, {     30,   16,   15,  0,  6,  0 }, {     29,   16,   14,  0,  6,  0 }, {     28,   16,   13,  0,  6,  0 }, {     27,   16,   13,  0,  6,  0 },
    {     26,   16,   12,  0,  6,  0 }, {     25,   16,   12,  0,  6,  0 }, {     24,   16,   11,  0,  6,  0 }, {     23,   16,   10,  0,  6,  0 }, {     22,   17,   10,  0,  6,  0 },
    {     21,   17,    9,  1,  6,  0 }, {     20,   17,    9,  1,  6,  0 }, {     19,   17,    8,  1,  6,  0 }, {     18,   17,    8,  1,  6,  0 }, {     17,   17,    7,  1,  6,  0 },
    {     16,   17,    6,  1,  6,  0 }, {     15,   17,    6,  1,  6,  0 }, {     14,   18,    5,  1,  6,  0 }, {     13,   18,    5,  1,  6,  0 }, {     12,   18,    4,  1,  6,  0 },
    {     11,   18,    3,  1,  6,  0 }, {     10,   18,    3,  1,  6,  0 }, {      9,   19,    2,  1,  6,  0 }, {      8,   19,    2,  1,  6,  0 }, {      7,   19,    1,  1,  6,  0 },
    {      6,   19,    1,  1,  6,  0 }, {      5,   19,    0,  1,  6,  0 }, {      4,   20,   -1,  1,  6,  0 }, {      3,   20,   -1,  1,  6,  0 }, {      2,   20,   -2,  1,  6,  0 },
    {      1,   21,   -2,  1,  6,  0 }, {      0,   21,   -3,  1,  6,  0 }, {     -1,   21,   -3,  2,  6,  0 }, {     -2,   21,   -4,  2,  6,  0 }, {     -3,   22,   -5,  2,  6,  0 },
    {     -4,   22,   -5,  2,  6,  0 }, {     -5,   22,   -6,  2,  6,  0 }, {     -6,   23,   -6,  2,  6,  0 }, {     -7,   23,   -7,  2,  6,  0 }, {     -8,   24,   -8,  2,  6,  0 },
    {     -9,   24,   -8,  2,  6,  0 }, {    -10,   24,   -9,  2,  6,  0 }, {    -11,   25,   -9,  2,  6,  0 }, {    -12,   25,  -10,  2,  6,  0 }, {    -13,   25,  -10,  2,  6,  0 },
    {    -14,   26,  -11,  2,  6,  0 }, {    -15,   26,  -12,  2,  6,  0 }, {    -16,   27,  -12,  2,  6,  0 }, {    -17,   27,  -13,  2,  6,  0 }, {    -18,   28,  -13,  2,  6,  0 },
    {    -19,   28,  -14,  2,  6,  0 }, {    -20,   29,  -15,  2,  6,  0 }, {    -21,   29,  -15,  2,  6,  0 }, {    -22,   30,  -16,  2,  6,  0 }, {    -23,   30,  -16,  2,  6,  0 },
    {    -24,   31,  -17,  3,  6,  0 }, {    -25,   31,  -18,  3,  6,  0 }, {    -26,   32,  -18,  3,  6,  0 }, {    -27,   32,  -19,  3,  6,  0 }, {    -28,   33,  -19,  3,  6,  0 },
    {    -29,   34,  -20,  3,  6,  0 }, {    -30,   34,  -21,  3,  6,  0 }, {    -31,   35,  -21,  3,  6,  0 }, {    -32,   36,  -22,  3,  6,  0 }, {    -33,   36,  -22,  3,  6,  0 },
    {    -34,   37,  -23,  3,  6,  0 }, {    -35,   38,  -24,  3,  6,  0 }, {    -36,   38,  -24,  3,  6,  0 }, {    -37,   39,  -25,  3,  6,  0 }, {    -38,   40,  -26,  3,  6,  0 },
    {    -39,   41,  -26,  3,  6,  0 }, {    -40,   41,  -27,  3,  6,  0 }, {    -41,   42,  -28,  3,  6,  0 }, {    -42,   43,  -28,  4,  6,  0 }, {    -43,   44,  -29,  4,  6,  0 },
    {    -44,   45,  -30,  4,  6,  0 }, {    -45,   46,  -30,  4,  6,  0 }, {    -46,   47,  -31,  4,  6,  0 }, {    -47,   47,  -32,  4,  6,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToDiagDown251, {
    {     16,    0,   16,  8,  6,  0 }, {     16,    1,   15,  8,  6,  0 }, {     16,    2,   15,  8,  6,  0 }, {     16,    3,   14,  8,  6,  0 }, {     16,    4,   13,  8,  6,  0 },
    {     16,    5,   13,  8,  6,  0 }, {     16,    6,   12,  8,  6,  0 }, {     16,    7,   12,  8,  6,  0 }, {     16,    8,   11,  8,  6,  0 }, {     16,    9,   10,  8,  6,  0 },
    {     17,   10,   10,  8,  6,  0 }, {     17,   11,    9,  9,  6,  0 }, {     17,   12,    9,  9,  6,  0 }, {     17,   13,    8,  9,  6,  0 }, {     17,   14,    8,  9,  6,  0 },
    {     17,   15,    7,  9,  6,  0 }, {     17,   16,    6,  9,  6,  0 }, {     17,   17,    6,  9,  6,  0 }, {     18,   18,    5,  9,  6,  0 }, {     18,   19,    5,  9,  6,  0 },
    {     18,   20,    4,  9,  6,  0 }, {     18,   21,    3,  9,  6,  0 }, {     18,   22,    3,  9,  6,  0 }, {     19,   23,    2,  9,  6,  0 }, {     19,   24,    2,  9,  6,  0 },
    {     19,   25,    1,  9,  6,  0 }, {     19,   26,    1,  9,  6,  0 }, {     19,   27,    0,  9,  6,  0 }, {     20,   28,   -1,  9,  6,  0 }, {     20,   29,   -1,  9,  6,  0 },
    {     20,   30,   -2,  9,  6,  0 }, {     21,   31,   -2,  9,  6,  0 }, {     21,   32,   -3,  9,  6,  0 }, {     21,   33,   -3, 10,  6,  0 }, {     21,   34,   -4, 10,  6,  0 },
    {     22,   35,   -5, 10,  6,  0 }, {     22,   36,   -5, 10,  6,  0 }, {     22,   37,   -6, 10,  6,  0 }, {     23,   38,   -6, 10,  6,  0 }, {     23,   39,   -7, 10,  6,  0 },
    {     24,   40,   -8, 10,  6,  0 }, {     24,   41,   -8, 10,  6,  0 }, {     24,   42,   -9, 10,  6,  0 }, {     25,   43,   -9, 10,  6,  0 }, {     25,   44,  -10, 10,  6,  0 },
    {     25,   45,  -10, 10,  6,  0 }, {     26,   46,  -11, 10,  6,  0 }, {     26,   47,  -12, 10,  6,  0 }, {     27,   48,  -12, 10,  6,  0 }, {     27,   49,  -13, 10,  6,  0 },
    {     28,   50,  -13, 10,  6,  0 }, {     28,   51,  -14, 10,  6,  0 }, {     29,   52,  -15, 10,  6,  0 }, {     29,   53,  -15, 10,  6,  0 }, {     30,   54,  -16, 10,  6,  0 },
    {     30,   55,  -16, 10,  6,  0 }, {     31,   56,  -17, 11,  6,  0 }, {     31,   57,  -18, 11,  6,  0 }, {     32,   58,  -18, 11,  6,  0 }, {     32,   59,  -19, 11,  6,  0 },
    {     33,   60,  -19, 11,  6,  0 }, {     34,   61,  -20, 11,  6,  0 }, {     34,   62,  -21, 11,  6,  0 }, {     35,   63,  -21, 11,  6,  0 }, {     36,   64,  -22, 11,  6,  0 },
    {     36,   65,  -22, 11,  6,  0 }, {     37,   66,  -23, 11,  6,  0 }, {     38,   67,  -24, 11,  6,  0 }, {     38,   68,  -24, 11,  6,  0 }, {     39,   69,  -25, 11,  6,  0 },
    {     40,   70,  -26, 11,  6,  0 }, {     41,   71,  -26, 11,  6,  0 }, {     41,   72,  -27, 11,  6,  0 }, {     42,   73,  -28, 11,  6,  0 }, {     43,   74,  -28, 12,  6,  0 },
    {     44,   75,  -29, 12,  6,  0 }, {     45,   76,  -30, 12,  6,  0 }, {     46,   77,  -30, 12,  6,  0 }, {     47,   78,  -31, 12,  6,  0 }, {     47,   79,  -32, 12,  6,  0 },
    {     48,   80,  -32, 12,  6,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToDiagDown252, {
    {      0,   16,   16, 16,  6,  0 }, {      1,   16,   15, 16,  6,  0 }, {      2,   16,   15, 16,  6,  0 }, {      3,   16,   14, 16,  6,  0 }, {      4,   16,   13, 16,  6,  0 },
    {      5,   16,   13, 16,  6,  0 }, {      6,   16,   12, 16,  6,  0 }, {      7,   16,   12, 16,  6,  0 }, {      8,   16,   11, 16,  6,  0 }, {      9,   16,   10, 16,  6,  0 },
    {     10,   15,   10, 16,  6,  0 }, {     11,   15,    9, 17,  6,  0 }, {     12,   15,    9, 17,  6,  0 }, {     13,   15,    8, 17,  6,  0 }, {     14,   15,    8, 17,  6,  0 },
    {     15,   15,    7, 17,  6,  0 }, {     16,   15,    6, 17,  6,  0 }, {     17,   15,    6, 17,  6,  0 }, {     18,   14,    5, 17,  6,  0 }, {     19,   14,    5, 17,  6,  0 },
    {     20,   14,    4, 17,  6,  0 }, {     21,   14,    3, 17,  6,  0 }, {     22,   14,    3, 17,  6,  0 }, {     23,   13,    2, 17,  6,  0 }, {     24,   13,    2, 17,  6,  0 },
    {     25,   13,    1, 17,  6,  0 }, {     26,   13,    1, 17,  6,  0 }, {     27,   13,    0, 17,  6,  0 }, {     28,   12,   -1, 17,  6,  0 }, {     29,   12,   -1, 17,  6,  0 },
    {     30,   12,   -2, 17,  6,  0 }, {     31,   11,   -2, 17,  6,  0 }, {     32,   11,   -3, 17,  6,  0 }, {     33,   11,   -3, 18,  6,  0 }, {     34,   11,   -4, 18,  6,  0 },
    {     35,   10,   -5, 18,  6,  0 }, {     36,   10,   -5, 18,  6,  0 }, {     37,   10,   -6, 18,  6,  0 }, {     38,    9,   -6, 18,  6,  0 }, {     39,    9,   -7, 18,  6,  0 },
    {     40,    8,   -8, 18,  6,  0 }, {     41,    8,   -8, 18,  6,  0 }, {     42,    8,   -9, 18,  6,  0 }, {     43,    7,   -9, 18,  6,  0 }, {     44,    7,  -10, 18,  6,  0 },
    {     45,    7,  -10, 18,  6,  0 }, {     46,    6,  -11, 18,  6,  0 }, {     47,    6,  -12, 18,  6,  0 }, {     48,    5,  -12, 18,  6,  0 }, {     49,    5,  -13, 18,  6,  0 },
    {     50,    4,  -13, 18,  6,  0 }, {     51,    4,  -14, 18,  6,  0 }, {     52,    3,  -15, 18,  6,  0 }, {     53,    3,  -15, 18,  6,  0 }, {     54,    2,  -16, 18,  6,  0 },
    {     55,    2,  -16, 18,  6,  0 }, {     56,    1,  -17, 19,  6,  0 }, {     57,    1,  -18, 19,  6,  0 }, {     58,    0,  -18, 19,  6,  0 }, {     59,    0,  -19, 19,  6,  0 },
    {     60,   -1,  -19, 19,  6,  0 }, {     61,   -2,  -20, 19,  6,  0 }, {     62,   -2,  -21, 19,  6,  0 }, {     63,   -3,  -21, 19,  6,  0 }, {     64,   -4,  -22, 19,  6,  0 },
    {     65,   -4,  -22, 19,  6,  0 }, {     66,   -5,  -23, 19,  6,  0 }, {     67,   -6,  -24, 19,  6,  0 }, {     68,   -6,  -24, 19,  6,  0 }, {     69,   -7,  -25, 19,  6,  0 },
    {     70,   -8,  -26, 19,  6,  0 }, {     71,   -9,  -26, 19,  6,  0 }, {     72,   -9,  -27, 19,  6,  0 }, {     73,  -10,  -28, 19,  6,  0 }, {     74,  -11,  -28, 20,  6,  0 },
    {     75,  -12,  -29, 20,  6,  0 }, {     76,  -13,  -30, 20,  6,  0 }, {     77,  -14,  -30, 20,  6,  0 }, {     78,  -15,  -31, 20,  6,  0 }, {     79,  -15,  -32, 20,  6,  0 },
    {     80,  -16,  -32, 20,  6,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToDiagDown253, {
    {     16,   31,   15, 24,  6,  0 }, {     16,   30,   15, 24,  6,  0 }, {     16,   29,   14, 24,  6,  0 }, {     16,   28,   13, 24,  6,  0 }, {     16,   27,   13, 24,  6,  0 },
    {     16,   26,   12, 24,  6,  0 }, {     16,   25,   12, 24,  6,  0 }, {     16,   24,   11, 24,  6,  0 }, {     16,   23,   10, 24,  6,  0 }, {     15,   22,   10, 24,  6,  0 },
    {     15,   21,    9, 25,  6,  0 }, {     15,   20,    9, 25,  6,  0 }, {     15,   19,    8, 25,  6,  0 }, {     15,   18,    8, 25,  6,  0 }, {     15,   17,    7, 25,  6,  0 },
    {     15,   16,    6, 25,  6,  0 }, {     15,   15,    6, 25,  6,  0 }, {     14,   14,    5, 25,  6,  0 }, {     14,   13,    5, 25,  6,  0 }, {     14,   12,    4, 25,  6,  0 },
    {     14,   11,    3, 25,  6,  0 }, {     14,   10,    3, 25,  6,  0 }, {     13,    9,    2, 25,  6,  0 }, {     13,    8,    2, 25,  6,  0 }, {     13,    7,    1, 25,  6,  0 },
    {     13,    6,    1, 25,  6,  0 }, {     13,    5,    0, 25,  6,  0 }, {     12,    4,   -1, 25,  6,  0 }, {     12,    3,   -1, 25,  6,  0 }, {     12,    2,   -2, 25,  6,  0 },
    {     11,    1,   -2, 25,  6,  0 }, {     11,    0,   -3, 25,  6,  0 }, {     11,   -1,   -3, 26,  6,  0 }, {     11,   -2,   -4, 26,  6,  0 }, {     10,   -3,   -5, 26,  6,  0 },
    {     10,   -4,   -5, 26,  6,  0 }, {     10,   -5,   -6, 26,  6,  0 }, {      9,   -6,   -6, 26,  6,  0 }, {      9,   -7,   -7, 26,  6,  0 }, {      8,   -8,   -8, 26,  6,  0 },
    {      8,   -9,   -8, 26,  6,  0 }, {      8,  -10,   -9, 26,  6,  0 }, {      7,  -11,   -9, 26,  6,  0 }, {      7,  -12,  -10, 26,  6,  0 }, {      7,  -13,  -10, 26,  6,  0 },
    {      6,  -14,  -11, 26,  6,  0 }, {      6,  -15,  -12, 26,  6,  0 }, {      5,  -16,  -12, 26,  6,  0 }, {      5,  -17,  -13, 26,  6,  0 }, {      4,  -18,  -13, 26,  6,  0 },
    {      4,  -19,  -14, 26,  6,  0 }, {      3,  -20,  -15, 26,  6,  0 }, {      3,  -21,  -15, 26,  6,  0 }, {      2,  -22,  -16, 26,  6,  0 }, {      2,  -23,  -16, 26,  6,  0 },
    {      1,  -24,  -17, 27,  6,  0 }, {      1,  -25,  -18, 27,  6,  0 }, {      0,  -26,  -18, 27,  6,  0 }, {      0,  -27,  -19, 27,  6,  0 }, {     -1,  -28,  -19, 27,  6,  0 },
    {     -2,  -29,  -20, 27,  6,  0 }, {     -2,  -30,  -21, 27,  6,  0 }, {     -3,  -31,  -21, 27,  6,  0 }, {     -4,  -32,  -22, 27,  6,  0 }, {     -4,  -33,  -22, 27,  6,  0 },
    {     -5,  -34,  -23, 27,  6,  0 }, {     -6,  -35,  -24, 27,  6,  0 }, {     -6,  -36,  -24, 27,  6,  0 }, {     -7,  -37,  -25, 27,  6,  0 }, {     -8,  -38,  -26, 27,  6,  0 },
    {     -9,  -39,  -26, 27,  6,  0 }, {     -9,  -40,  -27, 27,  6,  0 }, {    -10,  -41,  -28, 27,  6,  0 }, {    -11,  -42,  -28, 28,  6,  0 }, {    -12,  -43,  -29, 28,  6,  0 },
    {    -13,  -44,  -30, 28,  6,  0 }, {    -14,  -45,  -30, 28,  6,  0 }, {    -15,  -46,  -31, 28,  6,  0 }, {    -15,  -47,  -32, 28,  6,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToOrthogonalUp250, {
    {     15,   16,    1,  4,  2,  0 }, {     14,   17,    2,  4,  2,  0 }, {     13,   18,    2,  4,  2,  0 }, {     12,   19,    3,  4,  2,  0 }, {     11,   20,    4,  4,  2,  0 },
    {     10,   21,    4,  3,  2,  0 }, {      9,   22,    5,  3,  2,  0 }, {      8,   22,    6,  3,  2,  0 }, {      7,   23,    6,  3,  2,  0 }, {      6,   24,    7,  3,  2,  0 },
    {      5,   25,    8,  3,  2,  0 }, {      4,   25,    8,  3,  2,  0 }, {      3,   26,    9,  3,  2,  0 }, {      2,   27,    9,  3,  2,  0 }, {      1,   27,   10,  3,  2,  0 },
    {      0,   28,   11,  3,  2,  0 }, {     -1,   29,   11,  3,  2,  0 }, {     -2,   29,   12,  3,  2,  0 }, {     -3,   30,   13,  3,  2,  0 }, {     -4,   30,   13,  3,  2,  0 },
    {     -5,   31,   14,  3,  2,  0 }, {     -6,   32,   14,  3,  2,  0 }, {     -7,   32,   15,  3,  2,  0 }, {     -8,   33,   16,  2,  2,  0 }, {     -9,   33,   16,  2,  2,  0 },
    {    -10,   34,   17,  2,  2,  0 }, {    -11,   34,   17,  2,  2,  0 }, {    -12,   35,   18,  2,  2,  0 }, {    -13,   35,   19,  2,  2,  0 }, {    -14,   36,   19,  2,  2,  0 },
    {    -15,   36,   20,  2,  2,  0 }, {    -16,   37,   20,  2,  2,  0 }, {    -17,   37,   21,  2,  2,  0 }, {    -18,   37,   22,  2,  2,  0 }, {    -19,   38,   22,  2,  2,  0 },
    {    -20,   38,   23,  2,  2,  0 }, {    -21,   39,   23,  2,  2,  0 }, {    -22,   39,   24,  2,  2,  0 }, {    -23,   39,   24,  2,  2,  0 }, {    -24,   40,   25,  2,  2,  0 },
    {    -25,   40,   26,  2,  2,  0 }, {    -26,   41,   26,  2,  2,  0 }, {    -27,   41,   27,  2,  2,  0 }, {    -28,   41,   27,  2,  2,  0 }, {    -29,   42,   28,  2,  2,  0 },
    {    -30,   42,   29,  2,  2,  0 }, {    -31,   42,   29,  1,  2,  0 }, {    -32,   42,   30,  1,  2,  0 }, {    -33,   43,   30,  1,  2,  0 }, {    -34,   43,   31,  1,  2,  0 },
    {    -35,   43,   31,  1,  2,  0 }, {    -36,   44,   32,  1,  2,  0 }, {    -37,   44,   33,  1,  2,  0 }, {    -38,   44,   33,  1,  2,  0 }, {    -39,   44,   34,  1,  2,  0 },
    {    -40,   44,   34,  1,  2,  0 }, {    -41,   45,   35,  1,  2,  0 }, {    -42,   45,   35,  1,  2,  0 }, {    -43,   45,   36,  1,  2,  0 }, {    -44,   45,   37,  1,  2,  0 },
    {    -45,   45,   37,  1,  2,  0 }, {    -46,   46,   38,  1,  2,  0 }, {    -47,   46,   38,  1,  2,  0 }, {    -48,   46,   39,  1,  2,  0 }, {    -49,   46,   39,  1,  2,  0 },
    {    -50,   46,   40,  1,  2,  0 }, {    -51,   46,   41,  1,  2,  0 }, {    -52,   46,   41,  1,  2,  0 }, {    -53,   46,   42,  0,  2,  0 }, {    -54,   47,   42,  0,  2,  0 },
    {    -55,   47,   43,  0,  2,  0 }, {    -56,   47,   44,  0,  2,  0 }, {    -57,   47,   44,  0,  2,  0 }, {    -58,   47,   45,  0,  2,  0 }, {    -59,   47,   45,  0,  2,  0 },
    {    -60,   47,   46,  0,  2,  0 }, {    -61,   47,   47,  0,  2,  0 }, {    -62,   47,   47,  0,  2,  0 }, {    -63,   47,   48,  0,  2,  0 }, {    -64,   47,   48,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToOrthogonalUp251, {
    {     16,   16,    0, 12,  2,  0 }, {     17,   17,    1, 12,  2,  0 }, {     18,   18,    2, 12,  2,  0 }, {     19,   19,    2, 12,  2,  0 }, {     20,   20,    3, 12,  2,  0 },
    {     21,   21,    4, 12,  2,  0 }, {     22,   22,    4, 11,  2,  0 }, {     23,   23,    5, 11,  2,  0 }, {     23,   24,    6, 11,  2,  0 }, {     24,   25,    6, 11,  2,  0 },
    {     25,   26,    7, 11,  2,  0 }, {     26,   27,    8, 11,  2,  0 }, {     26,   28,    8, 11,  2,  0 }, {     27,   29,    9, 11,  2,  0 }, {     28,   30,    9, 11,  2,  0 },
    {     28,   31,   10, 11,  2,  0 }, {     29,   32,   11, 11,  2,  0 }, {     30,   33,   11, 11,  2,  0 }, {     30,   34,   12, 11,  2,  0 }, {     31,   35,   13, 11,  2,  0 },
    {     31,   36,   13, 11,  2,  0 }, {     32,   37,   14, 11,  2,  0 }, {     33,   38,   14, 11,  2,  0 }, {     33,   39,   15, 11,  2,  0 }, {     34,   40,   16, 10,  2,  0 },
    {     34,   41,   16, 10,  2,  0 }, {     35,   42,   17, 10,  2,  0 }, {     35,   43,   17, 10,  2,  0 }, {     36,   44,   18, 10,  2,  0 }, {     36,   45,   19, 10,  2,  0 },
    {     37,   46,   19, 10,  2,  0 }, {     37,   47,   20, 10,  2,  0 }, {     38,   48,   20, 10,  2,  0 }, {     38,   49,   21, 10,  2,  0 }, {     38,   50,   22, 10,  2,  0 },
    {     39,   51,   22, 10,  2,  0 }, {     39,   52,   23, 10,  2,  0 }, {     40,   53,   23, 10,  2,  0 }, {     40,   54,   24, 10,  2,  0 }, {     40,   55,   24, 10,  2,  0 },
    {     41,   56,   25, 10,  2,  0 }, {     41,   57,   26, 10,  2,  0 }, {     42,   58,   26, 10,  2,  0 }, {     42,   59,   27, 10,  2,  0 }, {     42,   60,   27, 10,  2,  0 },
    {     43,   61,   28, 10,  2,  0 }, {     43,   62,   29, 10,  2,  0 }, {     43,   63,   29,  9,  2,  0 }, {     43,   64,   30,  9,  2,  0 }, {     44,   65,   30,  9,  2,  0 },
    {     44,   66,   31,  9,  2,  0 }, {     44,   67,   31,  9,  2,  0 }, {     45,   68,   32,  9,  2,  0 }, {     45,   69,   33,  9,  2,  0 }, {     45,   70,   33,  9,  2,  0 },
    {     45,   71,   34,  9,  2,  0 }, {     45,   72,   34,  9,  2,  0 }, {     46,   73,   35,  9,  2,  0 }, {     46,   74,   35,  9,  2,  0 }, {     46,   75,   36,  9,  2,  0 },
    {     46,   76,   37,  9,  2,  0 }, {     46,   77,   37,  9,  2,  0 }, {     47,   78,   38,  9,  2,  0 }, {     47,   79,   38,  9,  2,  0 }, {     47,   80,   39,  9,  2,  0 },
    {     47,   81,   39,  9,  2,  0 }, {     47,   82,   40,  9,  2,  0 }, {     47,   83,   41,  9,  2,  0 }, {     47,   84,   41,  9,  2,  0 }, {     47,   85,   42,  8,  2,  0 },
    {     48,   86,   42,  8,  2,  0 }, {     48,   87,   43,  8,  2,  0 }, {     48,   88,   44,  8,  2,  0 }, {     48,   89,   44,  8,  2,  0 }, {     48,   90,   45,  8,  2,  0 },
    {     48,   91,   45,  8,  2,  0 }, {     48,   92,   46,  8,  2,  0 }, {     48,   93,   47,  8,  2,  0 }, {     48,   94,   47,  8,  2,  0 }, {     48,   95,   48,  8,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToOrthogonalUp252, {
    {     16,   15,    0, 20,  2,  0 }, {     17,   14,    1, 20,  2,  0 }, {     18,   13,    2, 20,  2,  0 }, {     19,   12,    2, 20,  2,  0 }, {     20,   11,    3, 20,  2,  0 },
    {     21,   10,    4, 20,  2,  0 }, {     22,    9,    4, 19,  2,  0 }, {     23,    8,    5, 19,  2,  0 }, {     24,    8,    6, 19,  2,  0 }, {     25,    7,    6, 19,  2,  0 },
    {     26,    6,    7, 19,  2,  0 }, {     27,    5,    8, 19,  2,  0 }, {     28,    5,    8, 19,  2,  0 }, {     29,    4,    9, 19,  2,  0 }, {     30,    3,    9, 19,  2,  0 },
    {     31,    3,   10, 19,  2,  0 }, {     32,    2,   11, 19,  2,  0 }, {     33,    1,   11, 19,  2,  0 }, {     34,    1,   12, 19,  2,  0 }, {     35,    0,   13, 19,  2,  0 },
    {     36,    0,   13, 19,  2,  0 }, {     37,   -1,   14, 19,  2,  0 }, {     38,   -2,   14, 19,  2,  0 }, {     39,   -2,   15, 19,  2,  0 }, {     40,   -3,   16, 18,  2,  0 },
    {     41,   -3,   16, 18,  2,  0 }, {     42,   -4,   17, 18,  2,  0 }, {     43,   -4,   17, 18,  2,  0 }, {     44,   -5,   18, 18,  2,  0 }, {     45,   -5,   19, 18,  2,  0 },
    {     46,   -6,   19, 18,  2,  0 }, {     47,   -6,   20, 18,  2,  0 }, {     48,   -7,   20, 18,  2,  0 }, {     49,   -7,   21, 18,  2,  0 }, {     50,   -7,   22, 18,  2,  0 },
    {     51,   -8,   22, 18,  2,  0 }, {     52,   -8,   23, 18,  2,  0 }, {     53,   -9,   23, 18,  2,  0 }, {     54,   -9,   24, 18,  2,  0 }, {     55,   -9,   24, 18,  2,  0 },
    {     56,  -10,   25, 18,  2,  0 }, {     57,  -10,   26, 18,  2,  0 }, {     58,  -11,   26, 18,  2,  0 }, {     59,  -11,   27, 18,  2,  0 }, {     60,  -11,   27, 18,  2,  0 },
    {     61,  -12,   28, 18,  2,  0 }, {     62,  -12,   29, 18,  2,  0 }, {     63,  -12,   29, 17,  2,  0 }, {     64,  -12,   30, 17,  2,  0 }, {     65,  -13,   30, 17,  2,  0 },
    {     66,  -13,   31, 17,  2,  0 }, {     67,  -13,   31, 17,  2,  0 }, {     68,  -14,   32, 17,  2,  0 }, {     69,  -14,   33, 17,  2,  0 }, {     70,  -14,   33, 17,  2,  0 },
    {     71,  -14,   34, 17,  2,  0 }, {     72,  -14,   34, 17,  2,  0 }, {     73,  -15,   35, 17,  2,  0 }, {     74,  -15,   35, 17,  2,  0 }, {     75,  -15,   36, 17,  2,  0 },
    {     76,  -15,   37, 17,  2,  0 }, {     77,  -15,   37, 17,  2,  0 }, {     78,  -16,   38, 17,  2,  0 }, {     79,  -16,   38, 17,  2,  0 }, {     80,  -16,   39, 17,  2,  0 },
    {     81,  -16,   39, 17,  2,  0 }, {     82,  -16,   40, 17,  2,  0 }, {     83,  -16,   41, 17,  2,  0 }, {     84,  -16,   41, 17,  2,  0 }, {     85,  -16,   42, 16,  2,  0 },
    {     86,  -17,   42, 16,  2,  0 }, {     87,  -17,   43, 16,  2,  0 }, {     88,  -17,   44, 16,  2,  0 }, {     89,  -17,   44, 16,  2,  0 }, {     90,  -17,   45, 16,  2,  0 },
    {     91,  -17,   45, 16,  2,  0 }, {     92,  -17,   46, 16,  2,  0 }, {     93,  -17,   47, 16,  2,  0 }, {     94,  -17,   47, 16,  2,  0 }, {     95,  -17,   48, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToOrthogonalUp253, {
    {     15,   15,    1, 28,  2,  0 }, {     14,   14,    2, 28,  2,  0 }, {     13,   13,    2, 28,  2,  0 }, {     12,   12,    3, 28,  2,  0 }, {     11,   11,    4, 28,  2,  0 },
    {     10,   10,    4, 27,  2,  0 }, {      9,    9,    5, 27,  2,  0 }, {      9,    8,    6, 27,  2,  0 }, {      8,    7,    6, 27,  2,  0 }, {      7,    6,    7, 27,  2,  0 },
    {      6,    5,    8, 27,  2,  0 }, {      6,    4,    8, 27,  2,  0 }, {      5,    3,    9, 27,  2,  0 }, {      4,    2,    9, 27,  2,  0 }, {      4,    1,   10, 27,  2,  0 },
    {      3,    0,   11, 27,  2,  0 }, {      2,   -1,   11, 27,  2,  0 }, {      2,   -2,   12, 27,  2,  0 }, {      1,   -3,   13, 27,  2,  0 }, {      1,   -4,   13, 27,  2,  0 },
    {      0,   -5,   14, 27,  2,  0 }, {     -1,   -6,   14, 27,  2,  0 }, {     -1,   -7,   15, 27,  2,  0 }, {     -2,   -8,   16, 26,  2,  0 }, {     -2,   -9,   16, 26,  2,  0 },
    {     -3,  -10,   17, 26,  2,  0 }, {     -3,  -11,   17, 26,  2,  0 }, {     -4,  -12,   18, 26,  2,  0 }, {     -4,  -13,   19, 26,  2,  0 }, {     -5,  -14,   19, 26,  2,  0 },
    {     -5,  -15,   20, 26,  2,  0 }, {     -6,  -16,   20, 26,  2,  0 }, {     -6,  -17,   21, 26,  2,  0 }, {     -6,  -18,   22, 26,  2,  0 }, {     -7,  -19,   22, 26,  2,  0 },
    {     -7,  -20,   23, 26,  2,  0 }, {     -8,  -21,   23, 26,  2,  0 }, {     -8,  -22,   24, 26,  2,  0 }, {     -8,  -23,   24, 26,  2,  0 }, {     -9,  -24,   25, 26,  2,  0 },
    {     -9,  -25,   26, 26,  2,  0 }, {    -10,  -26,   26, 26,  2,  0 }, {    -10,  -27,   27, 26,  2,  0 }, {    -10,  -28,   27, 26,  2,  0 }, {    -11,  -29,   28, 26,  2,  0 },
    {    -11,  -30,   29, 26,  2,  0 }, {    -11,  -31,   29, 25,  2,  0 }, {    -11,  -32,   30, 25,  2,  0 }, {    -12,  -33,   30, 25,  2,  0 }, {    -12,  -34,   31, 25,  2,  0 },
    {    -12,  -35,   31, 25,  2,  0 }, {    -13,  -36,   32, 25,  2,  0 }, {    -13,  -37,   33, 25,  2,  0 }, {    -13,  -38,   33, 25,  2,  0 }, {    -13,  -39,   34, 25,  2,  0 },
    {    -13,  -40,   34, 25,  2,  0 }, {    -14,  -41,   35, 25,  2,  0 }, {    -14,  -42,   35, 25,  2,  0 }, {    -14,  -43,   36, 25,  2,  0 }, {    -14,  -44,   37, 25,  2,  0 },
    {    -14,  -45,   37, 25,  2,  0 }, {    -15,  -46,   38, 25,  2,  0 }, {    -15,  -47,   38, 25,  2,  0 }, {    -15,  -48,   39, 25,  2,  0 }, {    -15,  -49,   39, 25,  2,  0 },
    {    -15,  -50,   40, 25,  2,  0 }, {    -15,  -51,   41, 25,  2,  0 }, {    -15,  -52,   41, 25,  2,  0 }, {    -15,  -53,   42, 24,  2,  0 }, {    -16,  -54,   42, 24,  2,  0 },
    {    -16,  -55,   43, 24,  2,  0 }, {    -16,  -56,   44, 24,  2,  0 }, {    -16,  -57,   44, 24,  2,  0 }, {    -16,  -58,   45, 24,  2,  0 }, {    -16,  -59,   45, 24,  2,  0 },
    {    -16,  -60,   46, 24,  2,  0 }, {    -16,  -61,   47, 24,  2,  0 }, {    -16,  -62,   47, 24,  2,  0 }, {    -16,  -63,   48, 24,  2,  0 }, {    -16,  -64,   48, 24,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToOrthogonalUp250, {
    {     15,   16,    1,  4,  2,  0 }, {     14,   17,    2,  4,  2,  0 }, {     13,   18,    2,  4,  2,  0 }, {     12,   19,    3,  4,  2,  0 }, {     11,   20,    4,  4,  2,  0 },
    {     10,   21,    4,  5,  2,  0 }, {      9,   22,    5,  5,  2,  0 }, {      9,   23,    6,  5,  2,  0 }, {      8,   24,    6,  5,  2,  0 }, {      7,   25,    7,  5,  2,  0 },
    {      6,   26,    8,  5,  2,  0 }, {      6,   27,    8,  5,  2,  0 }, {      5,   28,    9,  5,  2,  0 }, {      4,   29,    9,  5,  2,  0 }, {      4,   30,   10,  5,  2,  0 },
    {      3,   31,   11,  5,  2,  0 }, {      2,   32,   11,  5,  2,  0 }, {      2,   33,   12,  5,  2,  0 }, {      1,   34,   13,  5,  2,  0 }, {      1,   35,   13,  5,  2,  0 },
    {      0,   36,   14,  5,  2,  0 }, {     -1,   37,   14,  5,  2,  0 }, {     -1,   38,   15,  5,  2,  0 }, {     -2,   39,   16,  6,  2,  0 }, {     -2,   40,   16,  6,  2,  0 },
    {     -3,   41,   17,  6,  2,  0 }, {     -3,   42,   17,  6,  2,  0 }, {     -4,   43,   18,  6,  2,  0 }, {     -4,   44,   19,  6,  2,  0 }, {     -5,   45,   19,  6,  2,  0 },
    {     -5,   46,   20,  6,  2,  0 }, {     -6,   47,   20,  6,  2,  0 }, {     -6,   48,   21,  6,  2,  0 }, {     -6,   49,   22,  6,  2,  0 }, {     -7,   50,   22,  6,  2,  0 },
    {     -7,   51,   23,  6,  2,  0 }, {     -8,   52,   23,  6,  2,  0 }, {     -8,   53,   24,  6,  2,  0 }, {     -8,   54,   24,  6,  2,  0 }, {     -9,   55,   25,  6,  2,  0 },
    {     -9,   56,   26,  6,  2,  0 }, {    -10,   57,   26,  6,  2,  0 }, {    -10,   58,   27,  6,  2,  0 }, {    -10,   59,   27,  6,  2,  0 }, {    -11,   60,   28,  6,  2,  0 },
    {    -11,   61,   29,  6,  2,  0 }, {    -11,   62,   29,  7,  2,  0 }, {    -11,   63,   30,  7,  2,  0 }, {    -12,   64,   30,  7,  2,  0 }, {    -12,   65,   31,  7,  2,  0 },
    {    -12,   66,   31,  7,  2,  0 }, {    -13,   67,   32,  7,  2,  0 }, {    -13,   68,   33,  7,  2,  0 }, {    -13,   69,   33,  7,  2,  0 }, {    -13,   70,   34,  7,  2,  0 },
    {    -13,   71,   34,  7,  2,  0 }, {    -14,   72,   35,  7,  2,  0 }, {    -14,   73,   35,  7,  2,  0 }, {    -14,   74,   36,  7,  2,  0 }, {    -14,   75,   37,  7,  2,  0 },
    {    -14,   76,   37,  7,  2,  0 }, {    -15,   77,   38,  7,  2,  0 }, {    -15,   78,   38,  7,  2,  0 }, {    -15,   79,   39,  7,  2,  0 }, {    -15,   80,   39,  7,  2,  0 },
    {    -15,   81,   40,  7,  2,  0 }, {    -15,   82,   41,  7,  2,  0 }, {    -15,   83,   41,  7,  2,  0 }, {    -15,   84,   42,  8,  2,  0 }, {    -16,   85,   42,  8,  2,  0 },
    {    -16,   86,   43,  8,  2,  0 }, {    -16,   87,   44,  8,  2,  0 }, {    -16,   88,   44,  8,  2,  0 }, {    -16,   89,   45,  8,  2,  0 }, {    -16,   90,   45,  8,  2,  0 },
    {    -16,   91,   46,  8,  2,  0 }, {    -16,   92,   47,  8,  2,  0 }, {    -16,   93,   47,  8,  2,  0 }, {    -16,   94,   48,  8,  2,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToOrthogonalUp251, {
    {     16,   16,    0, 12,  2,  0 }, {     17,   17,    1, 12,  2,  0 }, {     18,   18,    2, 12,  2,  0 }, {     19,   19,    2, 12,  2,  0 }, {     20,   20,    3, 12,  2,  0 },
    {     21,   21,    4, 12,  2,  0 }, {     22,   22,    4, 13,  2,  0 }, {     23,   23,    5, 13,  2,  0 }, {     24,   23,    6, 13,  2,  0 }, {     25,   24,    6, 13,  2,  0 },
    {     26,   25,    7, 13,  2,  0 }, {     27,   26,    8, 13,  2,  0 }, {     28,   26,    8, 13,  2,  0 }, {     29,   27,    9, 13,  2,  0 }, {     30,   28,    9, 13,  2,  0 },
    {     31,   28,   10, 13,  2,  0 }, {     32,   29,   11, 13,  2,  0 }, {     33,   30,   11, 13,  2,  0 }, {     34,   30,   12, 13,  2,  0 }, {     35,   31,   13, 13,  2,  0 },
    {     36,   31,   13, 13,  2,  0 }, {     37,   32,   14, 13,  2,  0 }, {     38,   33,   14, 13,  2,  0 }, {     39,   33,   15, 13,  2,  0 }, {     40,   34,   16, 14,  2,  0 },
    {     41,   34,   16, 14,  2,  0 }, {     42,   35,   17, 14,  2,  0 }, {     43,   35,   17, 14,  2,  0 }, {     44,   36,   18, 14,  2,  0 }, {     45,   36,   19, 14,  2,  0 },
    {     46,   37,   19, 14,  2,  0 }, {     47,   37,   20, 14,  2,  0 }, {     48,   38,   20, 14,  2,  0 }, {     49,   38,   21, 14,  2,  0 }, {     50,   38,   22, 14,  2,  0 },
    {     51,   39,   22, 14,  2,  0 }, {     52,   39,   23, 14,  2,  0 }, {     53,   40,   23, 14,  2,  0 }, {     54,   40,   24, 14,  2,  0 }, {     55,   40,   24, 14,  2,  0 },
    {     56,   41,   25, 14,  2,  0 }, {     57,   41,   26, 14,  2,  0 }, {     58,   42,   26, 14,  2,  0 }, {     59,   42,   27, 14,  2,  0 }, {     60,   42,   27, 14,  2,  0 },
    {     61,   43,   28, 14,  2,  0 }, {     62,   43,   29, 14,  2,  0 }, {     63,   43,   29, 15,  2,  0 }, {     64,   43,   30, 15,  2,  0 }, {     65,   44,   30, 15,  2,  0 },
    {     66,   44,   31, 15,  2,  0 }, {     67,   44,   31, 15,  2,  0 }, {     68,   45,   32, 15,  2,  0 }, {     69,   45,   33, 15,  2,  0 }, {     70,   45,   33, 15,  2,  0 },
    {     71,   45,   34, 15,  2,  0 }, {     72,   45,   34, 15,  2,  0 }, {     73,   46,   35, 15,  2,  0 }, {     74,   46,   35, 15,  2,  0 }, {     75,   46,   36, 15,  2,  0 },
    {     76,   46,   37, 15,  2,  0 }, {     77,   46,   37, 15,  2,  0 }, {     78,   47,   38, 15,  2,  0 }, {     79,   47,   38, 15,  2,  0 }, {     80,   47,   39, 15,  2,  0 },
    {     81,   47,   39, 15,  2,  0 }, {     82,   47,   40, 15,  2,  0 }, {     83,   47,   41, 15,  2,  0 }, {     84,   47,   41, 15,  2,  0 }, {     85,   47,   42, 16,  2,  0 },
    {     86,   48,   42, 16,  2,  0 }, {     87,   48,   43, 16,  2,  0 }, {     88,   48,   44, 16,  2,  0 }, {     89,   48,   44, 16,  2,  0 }, {     90,   48,   45, 16,  2,  0 },
    {     91,   48,   45, 16,  2,  0 }, {     92,   48,   46, 16,  2,  0 }, {     93,   48,   47, 16,  2,  0 }, {     94,   48,   47, 16,  2,  0 }, {     95,   48,   48, 16,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToOrthogonalUp252, {
    {     16,   15,    0, 20,  2,  0 }, {     17,   14,    1, 20,  2,  0 }, {     18,   13,    2, 20,  2,  0 }, {     19,   12,    2, 20,  2,  0 }, {     20,   11,    3, 20,  2,  0 },
    {     21,   10,    4, 20,  2,  0 }, {     22,    9,    4, 21,  2,  0 }, {     23,    8,    5, 21,  2,  0 }, {     23,    7,    6, 21,  2,  0 }, {     24,    6,    6, 21,  2,  0 },
    {     25,    5,    7, 21,  2,  0 }, {     26,    4,    8, 21,  2,  0 }, {     26,    3,    8, 21,  2,  0 }, {     27,    2,    9, 21,  2,  0 }, {     28,    1,    9, 21,  2,  0 },
    {     28,    0,   10, 21,  2,  0 }, {     29,   -1,   11, 21,  2,  0 }, {     30,   -2,   11, 21,  2,  0 }, {     30,   -3,   12, 21,  2,  0 }, {     31,   -4,   13, 21,  2,  0 },
    {     31,   -5,   13, 21,  2,  0 }, {     32,   -6,   14, 21,  2,  0 }, {     33,   -7,   14, 21,  2,  0 }, {     33,   -8,   15, 21,  2,  0 }, {     34,   -9,   16, 22,  2,  0 },
    {     34,  -10,   16, 22,  2,  0 }, {     35,  -11,   17, 22,  2,  0 }, {     35,  -12,   17, 22,  2,  0 }, {     36,  -13,   18, 22,  2,  0 }, {     36,  -14,   19, 22,  2,  0 },
    {     37,  -15,   19, 22,  2,  0 }, {     37,  -16,   20, 22,  2,  0 }, {     38,  -17,   20, 22,  2,  0 }, {     38,  -18,   21, 22,  2,  0 }, {     38,  -19,   22, 22,  2,  0 },
    {     39,  -20,   22, 22,  2,  0 }, {     39,  -21,   23, 22,  2,  0 }, {     40,  -22,   23, 22,  2,  0 }, {     40,  -23,   24, 22,  2,  0 }, {     40,  -24,   24, 22,  2,  0 },
    {     41,  -25,   25, 22,  2,  0 }, {     41,  -26,   26, 22,  2,  0 }, {     42,  -27,   26, 22,  2,  0 }, {     42,  -28,   27, 22,  2,  0 }, {     42,  -29,   27, 22,  2,  0 },
    {     43,  -30,   28, 22,  2,  0 }, {     43,  -31,   29, 22,  2,  0 }, {     43,  -32,   29, 23,  2,  0 }, {     43,  -33,   30, 23,  2,  0 }, {     44,  -34,   30, 23,  2,  0 },
    {     44,  -35,   31, 23,  2,  0 }, {     44,  -36,   31, 23,  2,  0 }, {     45,  -37,   32, 23,  2,  0 }, {     45,  -38,   33, 23,  2,  0 }, {     45,  -39,   33, 23,  2,  0 },
    {     45,  -40,   34, 23,  2,  0 }, {     45,  -41,   34, 23,  2,  0 }, {     46,  -42,   35, 23,  2,  0 }, {     46,  -43,   35, 23,  2,  0 }, {     46,  -44,   36, 23,  2,  0 },
    {     46,  -45,   37, 23,  2,  0 }, {     46,  -46,   37, 23,  2,  0 }, {     47,  -47,   38, 23,  2,  0 }, {     47,  -48,   38, 23,  2,  0 }, {     47,  -49,   39, 23,  2,  0 },
    {     47,  -50,   39, 23,  2,  0 }, {     47,  -51,   40, 23,  2,  0 }, {     47,  -52,   41, 23,  2,  0 }, {     47,  -53,   41, 23,  2,  0 }, {     47,  -54,   42, 24,  2,  0 },
    {     48,  -55,   42, 24,  2,  0 }, {     48,  -56,   43, 24,  2,  0 }, {     48,  -57,   44, 24,  2,  0 }, {     48,  -58,   44, 24,  2,  0 }, {     48,  -59,   45, 24,  2,  0 },
    {     48,  -60,   45, 24,  2,  0 }, {     48,  -61,   46, 24,  2,  0 }, {     48,  -62,   47, 24,  2,  0 }, {     48,  -63,   47, 24,  2,  0 }, {     48,  -64,   48, 24,  2,  0 },
    {     48,  -65,   48, 24,  2,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToOrthogonalUp253, {
    {     15,   15,    1, 28,  2,  0 }, {     14,   14,    2, 28,  2,  0 }, {     13,   13,    2, 28,  2,  0 }, {     12,   12,    3, 28,  2,  0 }, {     11,   11,    4, 28,  2,  0 },
    {     10,   10,    4, 29,  2,  0 }, {      9,    9,    5, 29,  2,  0 }, {      8,    9,    6, 29,  2,  0 }, {      7,    8,    6, 29,  2,  0 }, {      6,    7,    7, 29,  2,  0 },
    {      5,    6,    8, 29,  2,  0 }, {      4,    6,    8, 29,  2,  0 }, {      3,    5,    9, 29,  2,  0 }, {      2,    4,    9, 29,  2,  0 }, {      1,    4,   10, 29,  2,  0 },
    {      0,    3,   11, 29,  2,  0 }, {     -1,    2,   11, 29,  2,  0 }, {     -2,    2,   12, 29,  2,  0 }, {     -3,    1,   13, 29,  2,  0 }, {     -4,    1,   13, 29,  2,  0 },
    {     -5,    0,   14, 29,  2,  0 }, {     -6,   -1,   14, 29,  2,  0 }, {     -7,   -1,   15, 29,  2,  0 }, {     -8,   -2,   16, 30,  2,  0 }, {     -9,   -2,   16, 30,  2,  0 },
    {    -10,   -3,   17, 30,  2,  0 }, {    -11,   -3,   17, 30,  2,  0 }, {    -12,   -4,   18, 30,  2,  0 }, {    -13,   -4,   19, 30,  2,  0 }, {    -14,   -5,   19, 30,  2,  0 },
    {    -15,   -5,   20, 30,  2,  0 }, {    -16,   -6,   20, 30,  2,  0 }, {    -17,   -6,   21, 30,  2,  0 }, {    -18,   -6,   22, 30,  2,  0 }, {    -19,   -7,   22, 30,  2,  0 },
    {    -20,   -7,   23, 30,  2,  0 }, {    -21,   -8,   23, 30,  2,  0 }, {    -22,   -8,   24, 30,  2,  0 }, {    -23,   -8,   24, 30,  2,  0 }, {    -24,   -9,   25, 30,  2,  0 },
    {    -25,   -9,   26, 30,  2,  0 }, {    -26,  -10,   26, 30,  2,  0 }, {    -27,  -10,   27, 30,  2,  0 }, {    -28,  -10,   27, 30,  2,  0 }, {    -29,  -11,   28, 30,  2,  0 },
    {    -30,  -11,   29, 30,  2,  0 }, {    -31,  -11,   29, 31,  2,  0 }, {    -32,  -11,   30, 31,  2,  0 }, {    -33,  -12,   30, 31,  2,  0 }, {    -34,  -12,   31, 31,  2,  0 },
    {    -35,  -12,   31, 31,  2,  0 }, {    -36,  -13,   32, 31,  2,  0 }, {    -37,  -13,   33, 31,  2,  0 }, {    -38,  -13,   33, 31,  2,  0 }, {    -39,  -13,   34, 31,  2,  0 },
    {    -40,  -13,   34, 31,  2,  0 }, {    -41,  -14,   35, 31,  2,  0 }, {    -42,  -14,   35, 31,  2,  0 }, {    -43,  -14,   36, 31,  2,  0 }, {    -44,  -14,   37, 31,  2,  0 },
    {    -45,  -14,   37, 31,  2,  0 }, {    -46,  -15,   38, 31,  2,  0 }, {    -47,  -15,   38, 31,  2,  0 }, {    -48,  -15,   39, 31,  2,  0 }, {    -49,  -15,   39, 31,  2,  0 },
    {    -50,  -15,   40, 31,  2,  0 }, {    -51,  -15,   41, 31,  2,  0 }, {    -52,  -15,   41, 31,  2,  0 }, {    -53,  -15,   42,  0,  2,  0 }, {    -54,  -16,   42,  0,  2,  0 },
    {    -55,  -16,   43,  0,  2,  0 }, {    -56,  -16,   44,  0,  2,  0 }, {    -57,  -16,   44,  0,  2,  0 }, {    -58,  -16,   45,  0,  2,  0 }, {    -59,  -16,   45,  0,  2,  0 },
    {    -60,  -16,   46,  0,  2,  0 }, {    -61,  -16,   47,  0,  2,  0 }, {    -62,  -16,   47,  0,  2,  0 }, {    -63,  -16,   48,  0,  2,  0 }, {    -64,  -16,   48,  0,  2,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToOrthogonalDown250, {
    {     15,   16,   15,  4,  6,  0 }, {     14,   17,   14,  4,  6,  0 }, {     13,   18,   14,  4,  6,  0 }, {     12,   19,   13,  4,  6,  0 }, {     11,   20,   12,  4,  6,  0 },
    {     10,   21,   12,  3,  6,  0 }, {      9,   22,   11,  3,  6,  0 }, {      8,   22,   10,  3,  6,  0 }, {      7,   23,   10,  3,  6,  0 }, {      6,   24,    9,  3,  6,  0 },
    {      5,   25,    8,  3,  6,  0 }, {      4,   25,    8,  3,  6,  0 }, {      3,   26,    7,  3,  6,  0 }, {      2,   27,    7,  3,  6,  0 }, {      1,   27,    6,  3,  6,  0 },
    {      0,   28,    5,  3,  6,  0 }, {     -1,   29,    5,  3,  6,  0 }, {     -2,   29,    4,  3,  6,  0 }, {     -3,   30,    3,  3,  6,  0 }, {     -4,   30,    3,  3,  6,  0 },
    {     -5,   31,    2,  3,  6,  0 }, {     -6,   32,    2,  3,  6,  0 }, {     -7,   32,    1,  3,  6,  0 }, {     -8,   33,    0,  2,  6,  0 }, {     -9,   33,    0,  2,  6,  0 },
    {    -10,   34,   -1,  2,  6,  0 }, {    -11,   34,   -1,  2,  6,  0 }, {    -12,   35,   -2,  2,  6,  0 }, {    -13,   35,   -3,  2,  6,  0 }, {    -14,   36,   -3,  2,  6,  0 },
    {    -15,   36,   -4,  2,  6,  0 }, {    -16,   37,   -4,  2,  6,  0 }, {    -17,   37,   -5,  2,  6,  0 }, {    -18,   37,   -6,  2,  6,  0 }, {    -19,   38,   -6,  2,  6,  0 },
    {    -20,   38,   -7,  2,  6,  0 }, {    -21,   39,   -7,  2,  6,  0 }, {    -22,   39,   -8,  2,  6,  0 }, {    -23,   39,   -8,  2,  6,  0 }, {    -24,   40,   -9,  2,  6,  0 },
    {    -25,   40,  -10,  2,  6,  0 }, {    -26,   41,  -10,  2,  6,  0 }, {    -27,   41,  -11,  2,  6,  0 }, {    -28,   41,  -11,  2,  6,  0 }, {    -29,   42,  -12,  2,  6,  0 },
    {    -30,   42,  -13,  2,  6,  0 }, {    -31,   42,  -13,  1,  6,  0 }, {    -32,   42,  -14,  1,  6,  0 }, {    -33,   43,  -14,  1,  6,  0 }, {    -34,   43,  -15,  1,  6,  0 },
    {    -35,   43,  -15,  1,  6,  0 }, {    -36,   44,  -16,  1,  6,  0 }, {    -37,   44,  -17,  1,  6,  0 }, {    -38,   44,  -17,  1,  6,  0 }, {    -39,   44,  -18,  1,  6,  0 },
    {    -40,   44,  -18,  1,  6,  0 }, {    -41,   45,  -19,  1,  6,  0 }, {    -42,   45,  -19,  1,  6,  0 }, {    -43,   45,  -20,  1,  6,  0 }, {    -44,   45,  -21,  1,  6,  0 },
    {    -45,   45,  -21,  1,  6,  0 }, {    -46,   46,  -22,  1,  6,  0 }, {    -47,   46,  -22,  1,  6,  0 }, {    -48,   46,  -23,  1,  6,  0 }, {    -49,   46,  -23,  1,  6,  0 },
    {    -50,   46,  -24,  1,  6,  0 }, {    -51,   46,  -25,  1,  6,  0 }, {    -52,   46,  -25,  1,  6,  0 }, {    -53,   46,  -26,  0,  6,  0 }, {    -54,   47,  -26,  0,  6,  0 },
    {    -55,   47,  -27,  0,  6,  0 }, {    -56,   47,  -28,  0,  6,  0 }, {    -57,   47,  -28,  0,  6,  0 }, {    -58,   47,  -29,  0,  6,  0 }, {    -59,   47,  -29,  0,  6,  0 },
    {    -60,   47,  -30,  0,  6,  0 }, {    -61,   47,  -31,  0,  6,  0 }, {    -62,   47,  -31,  0,  6,  0 }, {    -63,   47,  -32,  0,  6,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToOrthogonalDown251, {
    {     16,   16,   16, 12,  6,  0 }, {     17,   17,   15, 12,  6,  0 }, {     18,   18,   14, 12,  6,  0 }, {     19,   19,   14, 12,  6,  0 }, {     20,   20,   13, 12,  6,  0 },
    {     21,   21,   12, 12,  6,  0 }, {     22,   22,   12, 11,  6,  0 }, {     23,   23,   11, 11,  6,  0 }, {     23,   24,   10, 11,  6,  0 }, {     24,   25,   10, 11,  6,  0 },
    {     25,   26,    9, 11,  6,  0 }, {     26,   27,    8, 11,  6,  0 }, {     26,   28,    8, 11,  6,  0 }, {     27,   29,    7, 11,  6,  0 }, {     28,   30,    7, 11,  6,  0 },
    {     28,   31,    6, 11,  6,  0 }, {     29,   32,    5, 11,  6,  0 }, {     30,   33,    5, 11,  6,  0 }, {     30,   34,    4, 11,  6,  0 }, {     31,   35,    3, 11,  6,  0 },
    {     31,   36,    3, 11,  6,  0 }, {     32,   37,    2, 11,  6,  0 }, {     33,   38,    2, 11,  6,  0 }, {     33,   39,    1, 11,  6,  0 }, {     34,   40,    0, 10,  6,  0 },
    {     34,   41,    0, 10,  6,  0 }, {     35,   42,   -1, 10,  6,  0 }, {     35,   43,   -1, 10,  6,  0 }, {     36,   44,   -2, 10,  6,  0 }, {     36,   45,   -3, 10,  6,  0 },
    {     37,   46,   -3, 10,  6,  0 }, {     37,   47,   -4, 10,  6,  0 }, {     38,   48,   -4, 10,  6,  0 }, {     38,   49,   -5, 10,  6,  0 }, {     38,   50,   -6, 10,  6,  0 },
    {     39,   51,   -6, 10,  6,  0 }, {     39,   52,   -7, 10,  6,  0 }, {     40,   53,   -7, 10,  6,  0 }, {     40,   54,   -8, 10,  6,  0 }, {     40,   55,   -8, 10,  6,  0 },
    {     41,   56,   -9, 10,  6,  0 }, {     41,   57,  -10, 10,  6,  0 }, {     42,   58,  -10, 10,  6,  0 }, {     42,   59,  -11, 10,  6,  0 }, {     42,   60,  -11, 10,  6,  0 },
    {     43,   61,  -12, 10,  6,  0 }, {     43,   62,  -13, 10,  6,  0 }, {     43,   63,  -13,  9,  6,  0 }, {     43,   64,  -14,  9,  6,  0 }, {     44,   65,  -14,  9,  6,  0 },
    {     44,   66,  -15,  9,  6,  0 }, {     44,   67,  -15,  9,  6,  0 }, {     45,   68,  -16,  9,  6,  0 }, {     45,   69,  -17,  9,  6,  0 }, {     45,   70,  -17,  9,  6,  0 },
    {     45,   71,  -18,  9,  6,  0 }, {     45,   72,  -18,  9,  6,  0 }, {     46,   73,  -19,  9,  6,  0 }, {     46,   74,  -19,  9,  6,  0 }, {     46,   75,  -20,  9,  6,  0 },
    {     46,   76,  -21,  9,  6,  0 }, {     46,   77,  -21,  9,  6,  0 }, {     47,   78,  -22,  9,  6,  0 }, {     47,   79,  -22,  9,  6,  0 }, {     47,   80,  -23,  9,  6,  0 },
    {     47,   81,  -23,  9,  6,  0 }, {     47,   82,  -24,  9,  6,  0 }, {     47,   83,  -25,  9,  6,  0 }, {     47,   84,  -25,  9,  6,  0 }, {     47,   85,  -26,  8,  6,  0 },
    {     48,   86,  -26,  8,  6,  0 }, {     48,   87,  -27,  8,  6,  0 }, {     48,   88,  -28,  8,  6,  0 }, {     48,   89,  -28,  8,  6,  0 }, {     48,   90,  -29,  8,  6,  0 },
    {     48,   91,  -29,  8,  6,  0 }, {     48,   92,  -30,  8,  6,  0 }, {     48,   93,  -31,  8,  6,  0 }, {     48,   94,  -31,  8,  6,  0 }, {     48,   95,  -32,  8,  6,  0 },
    {     48,   96,  -32,  8,  6,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToOrthogonalDown252, {
    {     16,   15,   16, 20,  6,  0 }, {     17,   14,   15, 20,  6,  0 }, {     18,   13,   14, 20,  6,  0 }, {     19,   12,   14, 20,  6,  0 }, {     20,   11,   13, 20,  6,  0 },
    {     21,   10,   12, 20,  6,  0 }, {     22,    9,   12, 19,  6,  0 }, {     23,    8,   11, 19,  6,  0 }, {     24,    8,   10, 19,  6,  0 }, {     25,    7,   10, 19,  6,  0 },
    {     26,    6,    9, 19,  6,  0 }, {     27,    5,    8, 19,  6,  0 }, {     28,    5,    8, 19,  6,  0 }, {     29,    4,    7, 19,  6,  0 }, {     30,    3,    7, 19,  6,  0 },
    {     31,    3,    6, 19,  6,  0 }, {     32,    2,    5, 19,  6,  0 }, {     33,    1,    5, 19,  6,  0 }, {     34,    1,    4, 19,  6,  0 }, {     35,    0,    3, 19,  6,  0 },
    {     36,    0,    3, 19,  6,  0 }, {     37,   -1,    2, 19,  6,  0 }, {     38,   -2,    2, 19,  6,  0 }, {     39,   -2,    1, 19,  6,  0 }, {     40,   -3,    0, 18,  6,  0 },
    {     41,   -3,    0, 18,  6,  0 }, {     42,   -4,   -1, 18,  6,  0 }, {     43,   -4,   -1, 18,  6,  0 }, {     44,   -5,   -2, 18,  6,  0 }, {     45,   -5,   -3, 18,  6,  0 },
    {     46,   -6,   -3, 18,  6,  0 }, {     47,   -6,   -4, 18,  6,  0 }, {     48,   -7,   -4, 18,  6,  0 }, {     49,   -7,   -5, 18,  6,  0 }, {     50,   -7,   -6, 18,  6,  0 },
    {     51,   -8,   -6, 18,  6,  0 }, {     52,   -8,   -7, 18,  6,  0 }, {     53,   -9,   -7, 18,  6,  0 }, {     54,   -9,   -8, 18,  6,  0 }, {     55,   -9,   -8, 18,  6,  0 },
    {     56,  -10,   -9, 18,  6,  0 }, {     57,  -10,  -10, 18,  6,  0 }, {     58,  -11,  -10, 18,  6,  0 }, {     59,  -11,  -11, 18,  6,  0 }, {     60,  -11,  -11, 18,  6,  0 },
    {     61,  -12,  -12, 18,  6,  0 }, {     62,  -12,  -13, 18,  6,  0 }, {     63,  -12,  -13, 17,  6,  0 }, {     64,  -12,  -14, 17,  6,  0 }, {     65,  -13,  -14, 17,  6,  0 },
    {     66,  -13,  -15, 17,  6,  0 }, {     67,  -13,  -15, 17,  6,  0 }, {     68,  -14,  -16, 17,  6,  0 }, {     69,  -14,  -17, 17,  6,  0 }, {     70,  -14,  -17, 17,  6,  0 },
    {     71,  -14,  -18, 17,  6,  0 }, {     72,  -14,  -18, 17,  6,  0 }, {     73,  -15,  -19, 17,  6,  0 }, {     74,  -15,  -19, 17,  6,  0 }, {     75,  -15,  -20, 17,  6,  0 },
    {     76,  -15,  -21, 17,  6,  0 }, {     77,  -15,  -21, 17,  6,  0 }, {     78,  -16,  -22, 17,  6,  0 }, {     79,  -16,  -22, 17,  6,  0 }, {     80,  -16,  -23, 17,  6,  0 },
    {     81,  -16,  -23, 17,  6,  0 }, {     82,  -16,  -24, 17,  6,  0 }, {     83,  -16,  -25, 17,  6,  0 }, {     84,  -16,  -25, 17,  6,  0 }, {     85,  -16,  -26, 16,  6,  0 },
    {     86,  -17,  -26, 16,  6,  0 }, {     87,  -17,  -27, 16,  6,  0 }, {     88,  -17,  -28, 16,  6,  0 }, {     89,  -17,  -28, 16,  6,  0 }, {     90,  -17,  -29, 16,  6,  0 },
    {     91,  -17,  -29, 16,  6,  0 }, {     92,  -17,  -30, 16,  6,  0 }, {     93,  -17,  -31, 16,  6,  0 }, {     94,  -17,  -31, 16,  6,  0 }, {     95,  -17,  -32, 16,  6,  0 },
    {     96,  -17,  -32, 16,  6,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthToOrthogonalDown253, {
    {     15,   15,   15, 28,  6,  0 }, {     14,   14,   14, 28,  6,  0 }, {     13,   13,   14, 28,  6,  0 }, {     12,   12,   13, 28,  6,  0 }, {     11,   11,   12, 28,  6,  0 },
    {     10,   10,   12, 27,  6,  0 }, {      9,    9,   11, 27,  6,  0 }, {      9,    8,   10, 27,  6,  0 }, {      8,    7,   10, 27,  6,  0 }, {      7,    6,    9, 27,  6,  0 },
    {      6,    5,    8, 27,  6,  0 }, {      6,    4,    8, 27,  6,  0 }, {      5,    3,    7, 27,  6,  0 }, {      4,    2,    7, 27,  6,  0 }, {      4,    1,    6, 27,  6,  0 },
    {      3,    0,    5, 27,  6,  0 }, {      2,   -1,    5, 27,  6,  0 }, {      2,   -2,    4, 27,  6,  0 }, {      1,   -3,    3, 27,  6,  0 }, {      1,   -4,    3, 27,  6,  0 },
    {      0,   -5,    2, 27,  6,  0 }, {     -1,   -6,    2, 27,  6,  0 }, {     -1,   -7,    1, 27,  6,  0 }, {     -2,   -8,    0, 26,  6,  0 }, {     -2,   -9,    0, 26,  6,  0 },
    {     -3,  -10,   -1, 26,  6,  0 }, {     -3,  -11,   -1, 26,  6,  0 }, {     -4,  -12,   -2, 26,  6,  0 }, {     -4,  -13,   -3, 26,  6,  0 }, {     -5,  -14,   -3, 26,  6,  0 },
    {     -5,  -15,   -4, 26,  6,  0 }, {     -6,  -16,   -4, 26,  6,  0 }, {     -6,  -17,   -5, 26,  6,  0 }, {     -6,  -18,   -6, 26,  6,  0 }, {     -7,  -19,   -6, 26,  6,  0 },
    {     -7,  -20,   -7, 26,  6,  0 }, {     -8,  -21,   -7, 26,  6,  0 }, {     -8,  -22,   -8, 26,  6,  0 }, {     -8,  -23,   -8, 26,  6,  0 }, {     -9,  -24,   -9, 26,  6,  0 },
    {     -9,  -25,  -10, 26,  6,  0 }, {    -10,  -26,  -10, 26,  6,  0 }, {    -10,  -27,  -11, 26,  6,  0 }, {    -10,  -28,  -11, 26,  6,  0 }, {    -11,  -29,  -12, 26,  6,  0 },
    {    -11,  -30,  -13, 26,  6,  0 }, {    -11,  -31,  -13, 25,  6,  0 }, {    -11,  -32,  -14, 25,  6,  0 }, {    -12,  -33,  -14, 25,  6,  0 }, {    -12,  -34,  -15, 25,  6,  0 },
    {    -12,  -35,  -15, 25,  6,  0 }, {    -13,  -36,  -16, 25,  6,  0 }, {    -13,  -37,  -17, 25,  6,  0 }, {    -13,  -38,  -17, 25,  6,  0 }, {    -13,  -39,  -18, 25,  6,  0 },
    {    -13,  -40,  -18, 25,  6,  0 }, {    -14,  -41,  -19, 25,  6,  0 }, {    -14,  -42,  -19, 25,  6,  0 }, {    -14,  -43,  -20, 25,  6,  0 }, {    -14,  -44,  -21, 25,  6,  0 },
    {    -14,  -45,  -21, 25,  6,  0 }, {    -15,  -46,  -22, 25,  6,  0 }, {    -15,  -47,  -22, 25,  6,  0 }, {    -15,  -48,  -23, 25,  6,  0 }, {    -15,  -49,  -23, 25,  6,  0 },
    {    -15,  -50,  -24, 25,  6,  0 }, {    -15,  -51,  -25, 25,  6,  0 }, {    -15,  -52,  -25, 25,  6,  0 }, {    -15,  -53,  -26, 24,  6,  0 }, {    -16,  -54,  -26, 24,  6,  0 },
    {    -16,  -55,  -27, 24,  6,  0 }, {    -16,  -56,  -28, 24,  6,  0 }, {    -16,  -57,  -28, 24,  6,  0 }, {    -16,  -58,  -29, 24,  6,  0 }, {    -16,  -59,  -29, 24,  6,  0 },
    {    -16,  -60,  -30, 24,  6,  0 }, {    -16,  -61,  -31, 24,  6,  0 }, {    -16,  -62,  -31, 24,  6,  0 }, {    -16,  -63,  -32, 24,  6,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToOrthogonalDown250, {
    {     15,   16,   15,  4,  6,  0 }, {     14,   17,   14,  4,  6,  0 }, {     13,   18,   14,  4,  6,  0 }, {     12,   19,   13,  4,  6,  0 }, {     11,   20,   12,  4,  6,  0 },
    {     10,   21,   12,  5,  6,  0 }, {      9,   22,   11,  5,  6,  0 }, {      9,   23,   10,  5,  6,  0 }, {      8,   24,   10,  5,  6,  0 }, {      7,   25,    9,  5,  6,  0 },
    {      6,   26,    8,  5,  6,  0 }, {      6,   27,    8,  5,  6,  0 }, {      5,   28,    7,  5,  6,  0 }, {      4,   29,    7,  5,  6,  0 }, {      4,   30,    6,  5,  6,  0 },
    {      3,   31,    5,  5,  6,  0 }, {      2,   32,    5,  5,  6,  0 }, {      2,   33,    4,  5,  6,  0 }, {      1,   34,    3,  5,  6,  0 }, {      1,   35,    3,  5,  6,  0 },
    {      0,   36,    2,  5,  6,  0 }, {     -1,   37,    2,  5,  6,  0 }, {     -1,   38,    1,  5,  6,  0 }, {     -2,   39,    0,  6,  6,  0 }, {     -2,   40,    0,  6,  6,  0 },
    {     -3,   41,   -1,  6,  6,  0 }, {     -3,   42,   -1,  6,  6,  0 }, {     -4,   43,   -2,  6,  6,  0 }, {     -4,   44,   -3,  6,  6,  0 }, {     -5,   45,   -3,  6,  6,  0 },
    {     -5,   46,   -4,  6,  6,  0 }, {     -6,   47,   -4,  6,  6,  0 }, {     -6,   48,   -5,  6,  6,  0 }, {     -6,   49,   -6,  6,  6,  0 }, {     -7,   50,   -6,  6,  6,  0 },
    {     -7,   51,   -7,  6,  6,  0 }, {     -8,   52,   -7,  6,  6,  0 }, {     -8,   53,   -8,  6,  6,  0 }, {     -8,   54,   -8,  6,  6,  0 }, {     -9,   55,   -9,  6,  6,  0 },
    {     -9,   56,  -10,  6,  6,  0 }, {    -10,   57,  -10,  6,  6,  0 }, {    -10,   58,  -11,  6,  6,  0 }, {    -10,   59,  -11,  6,  6,  0 }, {    -11,   60,  -12,  6,  6,  0 },
    {    -11,   61,  -13,  6,  6,  0 }, {    -11,   62,  -13,  7,  6,  0 }, {    -11,   63,  -14,  7,  6,  0 }, {    -12,   64,  -14,  7,  6,  0 }, {    -12,   65,  -15,  7,  6,  0 },
    {    -12,   66,  -15,  7,  6,  0 }, {    -13,   67,  -16,  7,  6,  0 }, {    -13,   68,  -17,  7,  6,  0 }, {    -13,   69,  -17,  7,  6,  0 }, {    -13,   70,  -18,  7,  6,  0 },
    {    -13,   71,  -18,  7,  6,  0 }, {    -14,   72,  -19,  7,  6,  0 }, {    -14,   73,  -19,  7,  6,  0 }, {    -14,   74,  -20,  7,  6,  0 }, {    -14,   75,  -21,  7,  6,  0 },
    {    -14,   76,  -21,  7,  6,  0 }, {    -15,   77,  -22,  7,  6,  0 }, {    -15,   78,  -22,  7,  6,  0 }, {    -15,   79,  -23,  7,  6,  0 }, {    -15,   80,  -23,  7,  6,  0 },
    {    -15,   81,  -24,  7,  6,  0 }, {    -15,   82,  -25,  7,  6,  0 }, {    -15,   83,  -25,  7,  6,  0 }, {    -15,   84,  -26,  8,  6,  0 }, {    -16,   85,  -26,  8,  6,  0 },
    {    -16,   86,  -27,  8,  6,  0 }, {    -16,   87,  -28,  8,  6,  0 }, {    -16,   88,  -28,  8,  6,  0 }, {    -16,   89,  -29,  8,  6,  0 }, {    -16,   90,  -29,  8,  6,  0 },
    {    -16,   91,  -30,  8,  6,  0 }, {    -16,   92,  -31,  8,  6,  0 }, {    -16,   93,  -31,  8,  6,  0 }, {    -16,   94,  -32,  8,  6,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToOrthogonalDown251, {
    {     16,   16,   16, 12,  6,  0 }, {     17,   17,   15, 12,  6,  0 }, {     18,   18,   14, 12,  6,  0 }, {     19,   19,   14, 12,  6,  0 }, {     20,   20,   13, 12,  6,  0 },
    {     21,   21,   12, 12,  6,  0 }, {     22,   22,   12, 13,  6,  0 }, {     23,   23,   11, 13,  6,  0 }, {     24,   23,   10, 13,  6,  0 }, {     25,   24,   10, 13,  6,  0 },
    {     26,   25,    9, 13,  6,  0 }, {     27,   26,    8, 13,  6,  0 }, {     28,   26,    8, 13,  6,  0 }, {     29,   27,    7, 13,  6,  0 }, {     30,   28,    7, 13,  6,  0 },
    {     31,   28,    6, 13,  6,  0 }, {     32,   29,    5, 13,  6,  0 }, {     33,   30,    5, 13,  6,  0 }, {     34,   30,    4, 13,  6,  0 }, {     35,   31,    3, 13,  6,  0 },
    {     36,   31,    3, 13,  6,  0 }, {     37,   32,    2, 13,  6,  0 }, {     38,   33,    2, 13,  6,  0 }, {     39,   33,    1, 13,  6,  0 }, {     40,   34,    0, 14,  6,  0 },
    {     41,   34,    0, 14,  6,  0 }, {     42,   35,   -1, 14,  6,  0 }, {     43,   35,   -1, 14,  6,  0 }, {     44,   36,   -2, 14,  6,  0 }, {     45,   36,   -3, 14,  6,  0 },
    {     46,   37,   -3, 14,  6,  0 }, {     47,   37,   -4, 14,  6,  0 }, {     48,   38,   -4, 14,  6,  0 }, {     49,   38,   -5, 14,  6,  0 }, {     50,   38,   -6, 14,  6,  0 },
    {     51,   39,   -6, 14,  6,  0 }, {     52,   39,   -7, 14,  6,  0 }, {     53,   40,   -7, 14,  6,  0 }, {     54,   40,   -8, 14,  6,  0 }, {     55,   40,   -8, 14,  6,  0 },
    {     56,   41,   -9, 14,  6,  0 }, {     57,   41,  -10, 14,  6,  0 }, {     58,   42,  -10, 14,  6,  0 }, {     59,   42,  -11, 14,  6,  0 }, {     60,   42,  -11, 14,  6,  0 },
    {     61,   43,  -12, 14,  6,  0 }, {     62,   43,  -13, 14,  6,  0 }, {     63,   43,  -13, 15,  6,  0 }, {     64,   43,  -14, 15,  6,  0 }, {     65,   44,  -14, 15,  6,  0 },
    {     66,   44,  -15, 15,  6,  0 }, {     67,   44,  -15, 15,  6,  0 }, {     68,   45,  -16, 15,  6,  0 }, {     69,   45,  -17, 15,  6,  0 }, {     70,   45,  -17, 15,  6,  0 },
    {     71,   45,  -18, 15,  6,  0 }, {     72,   45,  -18, 15,  6,  0 }, {     73,   46,  -19, 15,  6,  0 }, {     74,   46,  -19, 15,  6,  0 }, {     75,   46,  -20, 15,  6,  0 },
    {     76,   46,  -21, 15,  6,  0 }, {     77,   46,  -21, 15,  6,  0 }, {     78,   47,  -22, 15,  6,  0 }, {     79,   47,  -22, 15,  6,  0 }, {     80,   47,  -23, 15,  6,  0 },
    {     81,   47,  -23, 15,  6,  0 }, {     82,   47,  -24, 15,  6,  0 }, {     83,   47,  -25, 15,  6,  0 }, {     84,   47,  -25, 15,  6,  0 }, {     85,   47,  -26, 16,  6,  0 },
    {     86,   48,  -26, 16,  6,  0 }, {     87,   48,  -27, 16,  6,  0 }, {     88,   48,  -28, 16,  6,  0 }, {     89,   48,  -28, 16,  6,  0 }, {     90,   48,  -29, 16,  6,  0 },
    {     91,   48,  -29, 16,  6,  0 }, {     92,   48,  -30, 16,  6,  0 }, {     93,   48,  -31, 16,  6,  0 }, {     94,   48,  -31, 16,  6,  0 }, {     95,   48,  -32, 16,  6,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToOrthogonalDown252, {
    {     16,   15,   16, 20,  6,  0 }, {     17,   14,   15, 20,  6,  0 }, {     18,   13,   14, 20,  6,  0 }, {     19,   12,   14, 20,  6,  0 }, {     20,   11,   13, 20,  6,  0 },
    {     21,   10,   12, 20,  6,  0 }, {     22,    9,   12, 21,  6,  0 }, {     23,    8,   11, 21,  6,  0 }, {     23,    7,   10, 21,  6,  0 }, {     24,    6,   10, 21,  6,  0 },
    {     25,    5,    9, 21,  6,  0 }, {     26,    4,    8, 21,  6,  0 }, {     26,    3,    8, 21,  6,  0 }, {     27,    2,    7, 21,  6,  0 }, {     28,    1,    7, 21,  6,  0 },
    {     28,    0,    6, 21,  6,  0 }, {     29,   -1,    5, 21,  6,  0 }, {     30,   -2,    5, 21,  6,  0 }, {     30,   -3,    4, 21,  6,  0 }, {     31,   -4,    3, 21,  6,  0 },
    {     31,   -5,    3, 21,  6,  0 }, {     32,   -6,    2, 21,  6,  0 }, {     33,   -7,    2, 21,  6,  0 }, {     33,   -8,    1, 21,  6,  0 }, {     34,   -9,    0, 22,  6,  0 },
    {     34,  -10,    0, 22,  6,  0 }, {     35,  -11,   -1, 22,  6,  0 }, {     35,  -12,   -1, 22,  6,  0 }, {     36,  -13,   -2, 22,  6,  0 }, {     36,  -14,   -3, 22,  6,  0 },
    {     37,  -15,   -3, 22,  6,  0 }, {     37,  -16,   -4, 22,  6,  0 }, {     38,  -17,   -4, 22,  6,  0 }, {     38,  -18,   -5, 22,  6,  0 }, {     38,  -19,   -6, 22,  6,  0 },
    {     39,  -20,   -6, 22,  6,  0 }, {     39,  -21,   -7, 22,  6,  0 }, {     40,  -22,   -7, 22,  6,  0 }, {     40,  -23,   -8, 22,  6,  0 }, {     40,  -24,   -8, 22,  6,  0 },
    {     41,  -25,   -9, 22,  6,  0 }, {     41,  -26,  -10, 22,  6,  0 }, {     42,  -27,  -10, 22,  6,  0 }, {     42,  -28,  -11, 22,  6,  0 }, {     42,  -29,  -11, 22,  6,  0 },
    {     43,  -30,  -12, 22,  6,  0 }, {     43,  -31,  -13, 22,  6,  0 }, {     43,  -32,  -13, 23,  6,  0 }, {     43,  -33,  -14, 23,  6,  0 }, {     44,  -34,  -14, 23,  6,  0 },
    {     44,  -35,  -15, 23,  6,  0 }, {     44,  -36,  -15, 23,  6,  0 }, {     45,  -37,  -16, 23,  6,  0 }, {     45,  -38,  -17, 23,  6,  0 }, {     45,  -39,  -17, 23,  6,  0 },
    {     45,  -40,  -18, 23,  6,  0 }, {     45,  -41,  -18, 23,  6,  0 }, {     46,  -42,  -19, 23,  6,  0 }, {     46,  -43,  -19, 23,  6,  0 }, {     46,  -44,  -20, 23,  6,  0 },
    {     46,  -45,  -21, 23,  6,  0 }, {     46,  -46,  -21, 23,  6,  0 }, {     47,  -47,  -22, 23,  6,  0 }, {     47,  -48,  -22, 23,  6,  0 }, {     47,  -49,  -23, 23,  6,  0 },
    {     47,  -50,  -23, 23,  6,  0 }, {     47,  -51,  -24, 23,  6,  0 }, {     47,  -52,  -25, 23,  6,  0 }, {     47,  -53,  -25, 23,  6,  0 }, {     47,  -54,  -26, 24,  6,  0 },
    {     48,  -55,  -26, 24,  6,  0 }, {     48,  -56,  -27, 24,  6,  0 }, {     48,  -57,  -28, 24,  6,  0 }, {     48,  -58,  -28, 24,  6,  0 }, {     48,  -59,  -29, 24,  6,  0 },
    {     48,  -60,  -29, 24,  6,  0 }, {     48,  -61,  -30, 24,  6,  0 }, {     48,  -62,  -31, 24,  6,  0 }, {     48,  -63,  -31, 24,  6,  0 }, {     48,  -64,  -32, 24,  6,  0 },
    {     48,  -65,  -32, 24,  6,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthToOrthogonalDown253, {
    {     15,   15,   15, 28,  6,  0 }, {     14,   14,   14, 28,  6,  0 }, {     13,   13,   14, 28,  6,  0 }, {     12,   12,   13, 28,  6,  0 }, {     11,   11,   12, 28,  6,  0 },
    {     10,   10,   12, 29,  6,  0 }, {      9,    9,   11, 29,  6,  0 }, {      8,    9,   10, 29,  6,  0 }, {      7,    8,   10, 29,  6,  0 }, {      6,    7,    9, 29,  6,  0 },
    {      5,    6,    8, 29,  6,  0 }, {      4,    6,    8, 29,  6,  0 }, {      3,    5,    7, 29,  6,  0 }, {      2,    4,    7, 29,  6,  0 }, {      1,    4,    6, 29,  6,  0 },
    {      0,    3,    5, 29,  6,  0 }, {     -1,    2,    5, 29,  6,  0 }, {     -2,    2,    4, 29,  6,  0 }, {     -3,    1,    3, 29,  6,  0 }, {     -4,    1,    3, 29,  6,  0 },
    {     -5,    0,    2, 29,  6,  0 }, {     -6,   -1,    2, 29,  6,  0 }, {     -7,   -1,    1, 29,  6,  0 }, {     -8,   -2,    0, 30,  6,  0 }, {     -9,   -2,    0, 30,  6,  0 },
    {    -10,   -3,   -1, 30,  6,  0 }, {    -11,   -3,   -1, 30,  6,  0 }, {    -12,   -4,   -2, 30,  6,  0 }, {    -13,   -4,   -3, 30,  6,  0 }, {    -14,   -5,   -3, 30,  6,  0 },
    {    -15,   -5,   -4, 30,  6,  0 }, {    -16,   -6,   -4, 30,  6,  0 }, {    -17,   -6,   -5, 30,  6,  0 }, {    -18,   -6,   -6, 30,  6,  0 }, {    -19,   -7,   -6, 30,  6,  0 },
    {    -20,   -7,   -7, 30,  6,  0 }, {    -21,   -8,   -7, 30,  6,  0 }, {    -22,   -8,   -8, 30,  6,  0 }, {    -23,   -8,   -8, 30,  6,  0 }, {    -24,   -9,   -9, 30,  6,  0 },
    {    -25,   -9,  -10, 30,  6,  0 }, {    -26,  -10,  -10, 30,  6,  0 }, {    -27,  -10,  -11, 30,  6,  0 }, {    -28,  -10,  -11, 30,  6,  0 }, {    -29,  -11,  -12, 30,  6,  0 },
    {    -30,  -11,  -13, 30,  6,  0 }, {    -31,  -11,  -13, 31,  6,  0 }, {    -32,  -11,  -14, 31,  6,  0 }, {    -33,  -12,  -14, 31,  6,  0 }, {    -34,  -12,  -15, 31,  6,  0 },
    {    -35,  -12,  -15, 31,  6,  0 }, {    -36,  -13,  -16, 31,  6,  0 }, {    -37,  -13,  -17, 31,  6,  0 }, {    -38,  -13,  -17, 31,  6,  0 }, {    -39,  -13,  -18, 31,  6,  0 },
    {    -40,  -13,  -18, 31,  6,  0 }, {    -41,  -14,  -19, 31,  6,  0 }, {    -42,  -14,  -19, 31,  6,  0 }, {    -43,  -14,  -20, 31,  6,  0 }, {    -44,  -14,  -21, 31,  6,  0 },
    {    -45,  -14,  -21, 31,  6,  0 }, {    -46,  -15,  -22, 31,  6,  0 }, {    -47,  -15,  -22, 31,  6,  0 }, {    -48,  -15,  -23, 31,  6,  0 }, {    -49,  -15,  -23, 31,  6,  0 },
    {    -50,  -15,  -24, 31,  6,  0 }, {    -51,  -15,  -25, 31,  6,  0 }, {    -52,  -15,  -25, 31,  6,  0 }, {    -53,  -15,  -26,  0,  6,  0 }, {    -54,  -16,  -26,  0,  6,  0 },
    {    -55,  -16,  -27,  0,  6,  0 }, {    -56,  -16,  -28,  0,  6,  0 }, {    -57,  -16,  -28,  0,  6,  0 }, {    -58,  -16,  -29,  0,  6,  0 }, {    -59,  -16,  -29,  0,  6,  0 },
    {    -60,  -16,  -30,  0,  6,  0 }, {    -61,  -16,  -31,  0,  6,  0 }, {    -62,  -16,  -31,  0,  6,  0 }, {    -63,  -16,  -32,  0,  6,  0 }, {    -64,  -16,  -32,  0,  6,  0 },
})




CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25ToLeftBankedUp250, {
    {     15,   16,    1,  4, 51,  0 }, {     14,   17,    1,  4, 51,  0 }, {     13,   18,    2,  4, 51,  0 }, {     12,   19,    2,  4, 51,  0 }, {     11,   20,    3,  4, 51,  0 },
    {     10,   21,    3,  4, 51,  0 }, {      9,   22,    4,  4, 51,  0 }, {      8,   23,    4,  4, 51,  1 }, {      7,   24,    5,  4, 51,  1 }, {      6,   25,    5,  4, 51,  1 },
    {      5,   26,    6,  4, 51,  1 }, {      4,   27,    6,  4, 51,  1 }, {      3,   28,    7,  4, 51,  1 }, {      2,   29,    7,  4, 51,  1 }, {      1,   30,    8,  4, 51,  1 },
    {      0,   31,    8,  4, 51,  1 }, {     -1,   32,    9,  4, 51,  1 }, {     -2,   33,    9,  4, 51,  1 }, {     -3,   34,   10,  4, 51,  1 }, {     -4,   35,   10,  4, 51,  1 },
    {     -5,   36,   11,  4, 51,  1 }, {     -6,   37,   11,  4, 51,  1 }, {     -7,   38,   12,  4, 51,  1 }, {     -8,   39,   12,  4, 51,  2 }, {     -9,   40,   13,  4, 51,  2 },
    {    -10,   41,   13,  4, 51,  2 }, {    -11,   42,   14,  4, 51,  2 }, {    -12,   43,   14,  4, 51,  2 }, {    -13,   44,   15,  4, 51,  2 }, {    -14,   45,   15,  4, 51,  2 },
    {    -15,   46,   16,  4, 51,  2 }, {    -16,   47,   16,  4, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25ToLeftBankedUp251, {
    {     16,   16,    0, 12, 51,  0 }, {     17,   17,    1, 12, 51,  0 }, {     18,   18,    1, 12, 51,  0 }, {     19,   19,    2, 12, 51,  0 }, {     20,   20,    2, 12, 51,  0 },
    {     21,   21,    3, 12, 51,  0 }, {     22,   22,    3, 12, 51,  0 }, {     23,   23,    4, 12, 51,  0 }, {     24,   24,    4, 12, 51,  1 }, {     25,   25,    5, 12, 51,  1 },
    {     26,   26,    5, 12, 51,  1 }, {     27,   27,    6, 12, 51,  1 }, {     28,   28,    6, 12, 51,  1 }, {     29,   29,    7, 12, 51,  1 }, {     30,   30,    7, 12, 51,  1 },
    {     31,   31,    8, 12, 51,  1 }, {     32,   32,    8, 12, 51,  1 }, {     33,   33,    9, 12, 51,  1 }, {     34,   34,    9, 12, 51,  1 }, {     35,   35,   10, 12, 51,  1 },
    {     36,   36,   10, 12, 51,  1 }, {     37,   37,   11, 12, 51,  1 }, {     38,   38,   11, 12, 51,  1 }, {     39,   39,   12, 12, 51,  1 }, {     40,   40,   12, 12, 51,  2 },
    {     41,   41,   13, 12, 51,  2 }, {     42,   42,   13, 12, 51,  2 }, {     43,   43,   14, 12, 51,  2 }, {     44,   44,   14, 12, 51,  2 }, {     45,   45,   15, 12, 51,  2 },
    {     46,   46,   15, 12, 51,  2 }, {     47,   47,   16, 12, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25ToLeftBankedUp252, {
    {     16,   15,    0, 20, 51,  0 }, {     17,   14,    1, 20, 51,  0 }, {     18,   13,    1, 20, 51,  0 }, {     19,   12,    2, 20, 51,  0 }, {     20,   11,    2, 20, 51,  0 },
    {     21,   10,    3, 20, 51,  0 }, {     22,    9,    3, 20, 51,  0 }, {     23,    8,    4, 20, 51,  0 }, {     24,    7,    4, 20, 51,  1 }, {     25,    6,    5, 20, 51,  1 },
    {     26,    5,    5, 20, 51,  1 }, {     27,    4,    6, 20, 51,  1 }, {     28,    3,    6, 20, 51,  1 }, {     29,    2,    7, 20, 51,  1 }, {     30,    1,    7, 20, 51,  1 },
    {     31,    0,    8, 20, 51,  1 }, {     32,   -1,    8, 20, 51,  1 }, {     33,   -2,    9, 20, 51,  1 }, {     34,   -3,    9, 20, 51,  1 }, {     35,   -4,   10, 20, 51,  1 },
    {     36,   -5,   10, 20, 51,  1 }, {     37,   -6,   11, 20, 51,  1 }, {     38,   -7,   11, 20, 51,  1 }, {     39,   -8,   12, 20, 51,  1 }, {     40,   -9,   12, 20, 51,  2 },
    {     41,  -10,   13, 20, 51,  2 }, {     42,  -11,   13, 20, 51,  2 }, {     43,  -12,   14, 20, 51,  2 }, {     44,  -13,   14, 20, 51,  2 }, {     45,  -14,   15, 20, 51,  2 },
    {     46,  -15,   15, 20, 51,  2 }, {     47,  -16,   16, 20, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25ToLeftBankedUp253, {
    {     15,   15,    1, 28, 51,  0 }, {     14,   14,    1, 28, 51,  0 }, {     13,   13,    2, 28, 51,  0 }, {     12,   12,    2, 28, 51,  0 }, {     11,   11,    3, 28, 51,  0 },
    {     10,   10,    3, 28, 51,  0 }, {      9,    9,    4, 28, 51,  0 }, {      8,    8,    4, 28, 51,  1 }, {      7,    7,    5, 28, 51,  1 }, {      6,    6,    5, 28, 51,  1 },
    {      5,    5,    6, 28, 51,  1 }, {      4,    4,    6, 28, 51,  1 }, {      3,    3,    7, 28, 51,  1 }, {      2,    2,    7, 28, 51,  1 }, {      1,    1,    8, 28, 51,  1 },
    {      0,    0,    8, 28, 51,  1 }, {     -1,   -1,    9, 28, 51,  1 }, {     -2,   -2,    9, 28, 51,  1 }, {     -3,   -3,   10, 28, 51,  1 }, {     -4,   -4,   10, 28, 51,  1 },
    {     -5,   -5,   11, 28, 51,  1 }, {     -6,   -6,   11, 28, 51,  1 }, {     -7,   -7,   12, 28, 51,  1 }, {     -8,   -8,   12, 28, 51,  2 }, {     -9,   -9,   13, 28, 51,  2 },
    {    -10,  -10,   13, 28, 51,  2 }, {    -11,  -11,   14, 28, 51,  2 }, {    -12,  -12,   14, 28, 51,  2 }, {    -13,  -13,   15, 28, 51,  2 }, {    -14,  -14,   15, 28, 51,  2 },
    {    -15,  -15,   16, 28, 51,  2 }, {    -16,  -16,   16, 28, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25ToRightBankedUp250, {
    {     15,   16,    1,  4, 51,  0 }, {     14,   17,    1,  4, 51,  0 }, {     13,   18,    2,  4, 51,  0 }, {     12,   19,    2,  4, 51,  0 }, {     11,   20,    3,  4, 51,  0 },
    {     10,   21,    3,  4, 51,  0 }, {      9,   22,    4,  4, 51,  0 }, {      8,   23,    4,  4, 51,  3 }, {      7,   24,    5,  4, 51,  3 }, {      6,   25,    5,  4, 51,  3 },
    {      5,   26,    6,  4, 51,  3 }, {      4,   27,    6,  4, 51,  3 }, {      3,   28,    7,  4, 51,  3 }, {      2,   29,    7,  4, 51,  3 }, {      1,   30,    8,  4, 51,  3 },
    {      0,   31,    8,  4, 51,  3 }, {     -1,   32,    9,  4, 51,  3 }, {     -2,   33,    9,  4, 51,  3 }, {     -3,   34,   10,  4, 51,  3 }, {     -4,   35,   10,  4, 51,  3 },
    {     -5,   36,   11,  4, 51,  3 }, {     -6,   37,   11,  4, 51,  3 }, {     -7,   38,   12,  4, 51,  3 }, {     -8,   39,   12,  4, 51,  4 }, {     -9,   40,   13,  4, 51,  4 },
    {    -10,   41,   13,  4, 51,  4 }, {    -11,   42,   14,  4, 51,  4 }, {    -12,   43,   14,  4, 51,  4 }, {    -13,   44,   15,  4, 51,  4 }, {    -14,   45,   15,  4, 51,  4 },
    {    -15,   46,   16,  4, 51,  4 }, {    -16,   47,   16,  4, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25ToRightBankedUp251, {
    {     16,   16,    0, 12, 51,  0 }, {     17,   17,    1, 12, 51,  0 }, {     18,   18,    1, 12, 51,  0 }, {     19,   19,    2, 12, 51,  0 }, {     20,   20,    2, 12, 51,  0 },
    {     21,   21,    3, 12, 51,  0 }, {     22,   22,    3, 12, 51,  0 }, {     23,   23,    4, 12, 51,  0 }, {     24,   24,    4, 12, 51,  3 }, {     25,   25,    5, 12, 51,  3 },
    {     26,   26,    5, 12, 51,  3 }, {     27,   27,    6, 12, 51,  3 }, {     28,   28,    6, 12, 51,  3 }, {     29,   29,    7, 12, 51,  3 }, {     30,   30,    7, 12, 51,  3 },
    {     31,   31,    8, 12, 51,  3 }, {     32,   32,    8, 12, 51,  3 }, {     33,   33,    9, 12, 51,  3 }, {     34,   34,    9, 12, 51,  3 }, {     35,   35,   10, 12, 51,  3 },
    {     36,   36,   10, 12, 51,  3 }, {     37,   37,   11, 12, 51,  3 }, {     38,   38,   11, 12, 51,  3 }, {     39,   39,   12, 12, 51,  3 }, {     40,   40,   12, 12, 51,  4 },
    {     41,   41,   13, 12, 51,  4 }, {     42,   42,   13, 12, 51,  4 }, {     43,   43,   14, 12, 51,  4 }, {     44,   44,   14, 12, 51,  4 }, {     45,   45,   15, 12, 51,  4 },
    {     46,   46,   15, 12, 51,  4 }, {     47,   47,   16, 12, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25ToRightBankedUp252, {
    {     16,   15,    0, 20, 51,  0 }, {     17,   14,    1, 20, 51,  0 }, {     18,   13,    1, 20, 51,  0 }, {     19,   12,    2, 20, 51,  0 }, {     20,   11,    2, 20, 51,  0 },
    {     21,   10,    3, 20, 51,  0 }, {     22,    9,    3, 20, 51,  0 }, {     23,    8,    4, 20, 51,  0 }, {     24,    7,    4, 20, 51,  3 }, {     25,    6,    5, 20, 51,  3 },
    {     26,    5,    5, 20, 51,  3 }, {     27,    4,    6, 20, 51,  3 }, {     28,    3,    6, 20, 51,  3 }, {     29,    2,    7, 20, 51,  3 }, {     30,    1,    7, 20, 51,  3 },
    {     31,    0,    8, 20, 51,  3 }, {     32,   -1,    8, 20, 51,  3 }, {     33,   -2,    9, 20, 51,  3 }, {     34,   -3,    9, 20, 51,  3 }, {     35,   -4,   10, 20, 51,  3 },
    {     36,   -5,   10, 20, 51,  3 }, {     37,   -6,   11, 20, 51,  3 }, {     38,   -7,   11, 20, 51,  3 }, {     39,   -8,   12, 20, 51,  3 }, {     40,   -9,   12, 20, 51,  4 },
    {     41,  -10,   13, 20, 51,  4 }, {     42,  -11,   13, 20, 51,  4 }, {     43,  -12,   14, 20, 51,  4 }, {     44,  -13,   14, 20, 51,  4 }, {     45,  -14,   15, 20, 51,  4 },
    {     46,  -15,   15, 20, 51,  4 }, {     47,  -16,   16, 20, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25ToRightBankedUp253, {
    {     15,   15,    1, 28, 51,  0 }, {     14,   14,    1, 28, 51,  0 }, {     13,   13,    2, 28, 51,  0 }, {     12,   12,    2, 28, 51,  0 }, {     11,   11,    3, 28, 51,  0 },
    {     10,   10,    3, 28, 51,  0 }, {      9,    9,    4, 28, 51,  0 }, {      8,    8,    4, 28, 51,  3 }, {      7,    7,    5, 28, 51,  3 }, {      6,    6,    5, 28, 51,  3 },
    {      5,    5,    6, 28, 51,  3 }, {      4,    4,    6, 28, 51,  3 }, {      3,    3,    7, 28, 51,  3 }, {      2,    2,    7, 28, 51,  3 }, {      1,    1,    8, 28, 51,  3 },
    {      0,    0,    8, 28, 51,  3 }, {     -1,   -1,    9, 28, 51,  3 }, {     -2,   -2,    9, 28, 51,  3 }, {     -3,   -3,   10, 28, 51,  3 }, {     -4,   -4,   10, 28, 51,  3 },
    {     -5,   -5,   11, 28, 51,  3 }, {     -6,   -6,   11, 28, 51,  3 }, {     -7,   -7,   12, 28, 51,  3 }, {     -8,   -8,   12, 28, 51,  4 }, {     -9,   -9,   13, 28, 51,  4 },
    {    -10,  -10,   13, 28, 51,  4 }, {    -11,  -11,   14, 28, 51,  4 }, {    -12,  -12,   14, 28, 51,  4 }, {    -13,  -13,   15, 28, 51,  4 }, {    -14,  -14,   15, 28, 51,  4 },
    {    -15,  -15,   16, 28, 51,  4 }, {    -16,  -16,   16, 28, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedUp25ToUp250, {
    {     15,   16,    1,  4, 51,  2 }, {     14,   17,    1,  4, 51,  2 }, {     13,   18,    2,  4, 51,  2 }, {     12,   19,    2,  4, 51,  2 }, {     11,   20,    3,  4, 51,  2 },
    {     10,   21,    3,  4, 51,  2 }, {      9,   22,    4,  4, 51,  2 }, {      8,   23,    4,  4, 51,  1 }, {      7,   24,    5,  4, 51,  1 }, {      6,   25,    5,  4, 51,  1 },
    {      5,   26,    6,  4, 51,  1 }, {      4,   27,    6,  4, 51,  1 }, {      3,   28,    7,  4, 51,  1 }, {      2,   29,    7,  4, 51,  1 }, {      1,   30,    8,  4, 51,  1 },
    {      0,   31,    8,  4, 51,  1 }, {     -1,   32,    9,  4, 51,  1 }, {     -2,   33,    9,  4, 51,  1 }, {     -3,   34,   10,  4, 51,  1 }, {     -4,   35,   10,  4, 51,  1 },
    {     -5,   36,   11,  4, 51,  1 }, {     -6,   37,   11,  4, 51,  1 }, {     -7,   38,   12,  4, 51,  1 }, {     -8,   39,   12,  4, 51,  0 }, {     -9,   40,   13,  4, 51,  0 },
    {    -10,   41,   13,  4, 51,  0 }, {    -11,   42,   14,  4, 51,  0 }, {    -12,   43,   14,  4, 51,  0 }, {    -13,   44,   15,  4, 51,  0 }, {    -14,   45,   15,  4, 51,  0 },
    {    -15,   46,   16,  4, 51,  0 }, {    -16,   47,   16,  4, 51,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedUp25ToUp251, {
    {     16,   16,    0, 12, 51,  2 }, {     17,   17,    1, 12, 51,  2 }, {     18,   18,    1, 12, 51,  2 }, {     19,   19,    2, 12, 51,  2 }, {     20,   20,    2, 12, 51,  2 },
    {     21,   21,    3, 12, 51,  2 }, {     22,   22,    3, 12, 51,  2 }, {     23,   23,    4, 12, 51,  2 }, {     24,   24,    4, 12, 51,  1 }, {     25,   25,    5, 12, 51,  1 },
    {     26,   26,    5, 12, 51,  1 }, {     27,   27,    6, 12, 51,  1 }, {     28,   28,    6, 12, 51,  1 }, {     29,   29,    7, 12, 51,  1 }, {     30,   30,    7, 12, 51,  1 },
    {     31,   31,    8, 12, 51,  1 }, {     32,   32,    8, 12, 51,  1 }, {     33,   33,    9, 12, 51,  1 }, {     34,   34,    9, 12, 51,  1 }, {     35,   35,   10, 12, 51,  1 },
    {     36,   36,   10, 12, 51,  1 }, {     37,   37,   11, 12, 51,  1 }, {     38,   38,   11, 12, 51,  1 }, {     39,   39,   12, 12, 51,  1 }, {     40,   40,   12, 12, 51,  0 },
    {     41,   41,   13, 12, 51,  0 }, {     42,   42,   13, 12, 51,  0 }, {     43,   43,   14, 12, 51,  0 }, {     44,   44,   14, 12, 51,  0 }, {     45,   45,   15, 12, 51,  0 },
    {     46,   46,   15, 12, 51,  0 }, {     47,   47,   16, 12, 51,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedUp25ToUp252, {
    {     16,   15,    0, 20, 51,  2 }, {     17,   14,    1, 20, 51,  2 }, {     18,   13,    1, 20, 51,  2 }, {     19,   12,    2, 20, 51,  2 }, {     20,   11,    2, 20, 51,  2 },
    {     21,   10,    3, 20, 51,  2 }, {     22,    9,    3, 20, 51,  2 }, {     23,    8,    4, 20, 51,  2 }, {     24,    7,    4, 20, 51,  1 }, {     25,    6,    5, 20, 51,  1 },
    {     26,    5,    5, 20, 51,  1 }, {     27,    4,    6, 20, 51,  1 }, {     28,    3,    6, 20, 51,  1 }, {     29,    2,    7, 20, 51,  1 }, {     30,    1,    7, 20, 51,  1 },
    {     31,    0,    8, 20, 51,  1 }, {     32,   -1,    8, 20, 51,  1 }, {     33,   -2,    9, 20, 51,  1 }, {     34,   -3,    9, 20, 51,  1 }, {     35,   -4,   10, 20, 51,  1 },
    {     36,   -5,   10, 20, 51,  1 }, {     37,   -6,   11, 20, 51,  1 }, {     38,   -7,   11, 20, 51,  1 }, {     39,   -8,   12, 20, 51,  1 }, {     40,   -9,   12, 20, 51,  0 },
    {     41,  -10,   13, 20, 51,  0 }, {     42,  -11,   13, 20, 51,  0 }, {     43,  -12,   14, 20, 51,  0 }, {     44,  -13,   14, 20, 51,  0 }, {     45,  -14,   15, 20, 51,  0 },
    {     46,  -15,   15, 20, 51,  0 }, {     47,  -16,   16, 20, 51,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedUp25ToUp253, {
    {     15,   15,    1, 28, 51,  2 }, {     14,   14,    1, 28, 51,  2 }, {     13,   13,    2, 28, 51,  2 }, {     12,   12,    2, 28, 51,  2 }, {     11,   11,    3, 28, 51,  2 },
    {     10,   10,    3, 28, 51,  2 }, {      9,    9,    4, 28, 51,  2 }, {      8,    8,    4, 28, 51,  1 }, {      7,    7,    5, 28, 51,  1 }, {      6,    6,    5, 28, 51,  1 },
    {      5,    5,    6, 28, 51,  1 }, {      4,    4,    6, 28, 51,  1 }, {      3,    3,    7, 28, 51,  1 }, {      2,    2,    7, 28, 51,  1 }, {      1,    1,    8, 28, 51,  1 },
    {      0,    0,    8, 28, 51,  1 }, {     -1,   -1,    9, 28, 51,  1 }, {     -2,   -2,    9, 28, 51,  1 }, {     -3,   -3,   10, 28, 51,  1 }, {     -4,   -4,   10, 28, 51,  1 },
    {     -5,   -5,   11, 28, 51,  1 }, {     -6,   -6,   11, 28, 51,  1 }, {     -7,   -7,   12, 28, 51,  1 }, {     -8,   -8,   12, 28, 51,  0 }, {     -9,   -9,   13, 28, 51,  0 },
    {    -10,  -10,   13, 28, 51,  0 }, {    -11,  -11,   14, 28, 51,  0 }, {    -12,  -12,   14, 28, 51,  0 }, {    -13,  -13,   15, 28, 51,  0 }, {    -14,  -14,   15, 28, 51,  0 },
    {    -15,  -15,   16, 28, 51,  0 }, {    -16,  -16,   16, 28, 51,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedUp25ToUp250, {
    {     15,   16,    1,  4, 51,  4 }, {     14,   17,    1,  4, 51,  4 }, {     13,   18,    2,  4, 51,  4 }, {     12,   19,    2,  4, 51,  4 }, {     11,   20,    3,  4, 51,  4 },
    {     10,   21,    3,  4, 51,  4 }, {      9,   22,    4,  4, 51,  4 }, {      8,   23,    4,  4, 51,  3 }, {      7,   24,    5,  4, 51,  3 }, {      6,   25,    5,  4, 51,  3 },
    {      5,   26,    6,  4, 51,  3 }, {      4,   27,    6,  4, 51,  3 }, {      3,   28,    7,  4, 51,  3 }, {      2,   29,    7,  4, 51,  3 }, {      1,   30,    8,  4, 51,  3 },
    {      0,   31,    8,  4, 51,  3 }, {     -1,   32,    9,  4, 51,  3 }, {     -2,   33,    9,  4, 51,  3 }, {     -3,   34,   10,  4, 51,  3 }, {     -4,   35,   10,  4, 51,  3 },
    {     -5,   36,   11,  4, 51,  3 }, {     -6,   37,   11,  4, 51,  3 }, {     -7,   38,   12,  4, 51,  3 }, {     -8,   39,   12,  4, 51,  0 }, {     -9,   40,   13,  4, 51,  0 },
    {    -10,   41,   13,  4, 51,  0 }, {    -11,   42,   14,  4, 51,  0 }, {    -12,   43,   14,  4, 51,  0 }, {    -13,   44,   15,  4, 51,  0 }, {    -14,   45,   15,  4, 51,  0 },
    {    -15,   46,   16,  4, 51,  0 }, {    -16,   47,   16,  4, 51,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedUp25ToUp251, {
    {     16,   16,    0, 12, 51,  4 }, {     17,   17,    1, 12, 51,  4 }, {     18,   18,    1, 12, 51,  4 }, {     19,   19,    2, 12, 51,  4 }, {     20,   20,    2, 12, 51,  4 },
    {     21,   21,    3, 12, 51,  4 }, {     22,   22,    3, 12, 51,  4 }, {     23,   23,    4, 12, 51,  4 }, {     24,   24,    4, 12, 51,  3 }, {     25,   25,    5, 12, 51,  3 },
    {     26,   26,    5, 12, 51,  3 }, {     27,   27,    6, 12, 51,  3 }, {     28,   28,    6, 12, 51,  3 }, {     29,   29,    7, 12, 51,  3 }, {     30,   30,    7, 12, 51,  3 },
    {     31,   31,    8, 12, 51,  3 }, {     32,   32,    8, 12, 51,  3 }, {     33,   33,    9, 12, 51,  3 }, {     34,   34,    9, 12, 51,  3 }, {     35,   35,   10, 12, 51,  3 },
    {     36,   36,   10, 12, 51,  3 }, {     37,   37,   11, 12, 51,  3 }, {     38,   38,   11, 12, 51,  3 }, {     39,   39,   12, 12, 51,  3 }, {     40,   40,   12, 12, 51,  0 },
    {     41,   41,   13, 12, 51,  0 }, {     42,   42,   13, 12, 51,  0 }, {     43,   43,   14, 12, 51,  0 }, {     44,   44,   14, 12, 51,  0 }, {     45,   45,   15, 12, 51,  0 },
    {     46,   46,   15, 12, 51,  0 }, {     47,   47,   16, 12, 51,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedUp25ToUp252, {
    {     16,   15,    0, 20, 51,  4 }, {     17,   14,    1, 20, 51,  4 }, {     18,   13,    1, 20, 51,  4 }, {     19,   12,    2, 20, 51,  4 }, {     20,   11,    2, 20, 51,  4 },
    {     21,   10,    3, 20, 51,  4 }, {     22,    9,    3, 20, 51,  4 }, {     23,    8,    4, 20, 51,  4 }, {     24,    7,    4, 20, 51,  3 }, {     25,    6,    5, 20, 51,  3 },
    {     26,    5,    5, 20, 51,  3 }, {     27,    4,    6, 20, 51,  3 }, {     28,    3,    6, 20, 51,  3 }, {     29,    2,    7, 20, 51,  3 }, {     30,    1,    7, 20, 51,  3 },
    {     31,    0,    8, 20, 51,  3 }, {     32,   -1,    8, 20, 51,  3 }, {     33,   -2,    9, 20, 51,  3 }, {     34,   -3,    9, 20, 51,  3 }, {     35,   -4,   10, 20, 51,  3 },
    {     36,   -5,   10, 20, 51,  3 }, {     37,   -6,   11, 20, 51,  3 }, {     38,   -7,   11, 20, 51,  3 }, {     39,   -8,   12, 20, 51,  3 }, {     40,   -9,   12, 20, 51,  0 },
    {     41,  -10,   13, 20, 51,  0 }, {     42,  -11,   13, 20, 51,  0 }, {     43,  -12,   14, 20, 51,  0 }, {     44,  -13,   14, 20, 51,  0 }, {     45,  -14,   15, 20, 51,  0 },
    {     46,  -15,   15, 20, 51,  0 }, {     47,  -16,   16, 20, 51,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedUp25ToUp253, {
    {     15,   15,    1, 28, 51,  4 }, {     14,   14,    1, 28, 51,  4 }, {     13,   13,    2, 28, 51,  4 }, {     12,   12,    2, 28, 51,  4 }, {     11,   11,    3, 28, 51,  4 },
    {     10,   10,    3, 28, 51,  4 }, {      9,    9,    4, 28, 51,  4 }, {      8,    8,    4, 28, 51,  3 }, {      7,    7,    5, 28, 51,  3 }, {      6,    6,    5, 28, 51,  3 },
    {      5,    5,    6, 28, 51,  3 }, {      4,    4,    6, 28, 51,  3 }, {      3,    3,    7, 28, 51,  3 }, {      2,    2,    7, 28, 51,  3 }, {      1,    1,    8, 28, 51,  3 },
    {      0,    0,    8, 28, 51,  3 }, {     -1,   -1,    9, 28, 51,  3 }, {     -2,   -2,    9, 28, 51,  3 }, {     -3,   -3,   10, 28, 51,  3 }, {     -4,   -4,   10, 28, 51,  3 },
    {     -5,   -5,   11, 28, 51,  3 }, {     -6,   -6,   11, 28, 51,  3 }, {     -7,   -7,   12, 28, 51,  3 }, {     -8,   -8,   12, 28, 51,  0 }, {     -9,   -9,   13, 28, 51,  0 },
    {    -10,  -10,   13, 28, 51,  0 }, {    -11,  -11,   14, 28, 51,  0 }, {    -12,  -12,   14, 28, 51,  0 }, {    -13,  -13,   15, 28, 51,  0 }, {    -14,  -14,   15, 28, 51,  0 },
    {    -15,  -15,   16, 28, 51,  0 }, {    -16,  -16,   16, 28, 51,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25ToLeftBankedDown250, {
    {     15,   16,   15,  4, 54,  0 }, {     14,   17,   15,  4, 54,  0 }, {     13,   18,   14,  4, 54,  0 }, {     12,   19,   14,  4, 54,  0 }, {     11,   20,   13,  4, 54,  0 },
    {     10,   21,   13,  4, 54,  0 }, {      9,   22,   12,  4, 54,  0 }, {      8,   23,   12,  4, 54,  1 }, {      7,   24,   11,  4, 54,  1 }, {      6,   25,   11,  4, 54,  1 },
    {      5,   26,   10,  4, 54,  1 }, {      4,   27,   10,  4, 54,  1 }, {      3,   28,    9,  4, 54,  1 }, {      2,   29,    9,  4, 54,  1 }, {      1,   30,    8,  4, 54,  1 },
    {      0,   31,    8,  4, 54,  1 }, {     -1,   32,    7,  4, 54,  1 }, {     -2,   33,    7,  4, 54,  1 }, {     -3,   34,    6,  4, 54,  1 }, {     -4,   35,    6,  4, 54,  1 },
    {     -5,   36,    5,  4, 54,  1 }, {     -6,   37,    5,  4, 54,  1 }, {     -7,   38,    4,  4, 54,  1 }, {     -8,   39,    4,  4, 54,  2 }, {     -9,   40,    3,  4, 54,  2 },
    {    -10,   41,    3,  4, 54,  2 }, {    -11,   42,    2,  4, 54,  2 }, {    -12,   43,    2,  4, 54,  2 }, {    -13,   44,    1,  4, 54,  2 }, {    -14,   45,    1,  4, 54,  2 },
    {    -15,   46,    0,  4, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25ToLeftBankedDown251, {
    {     16,   16,   16, 12, 54,  0 }, {     17,   17,   15, 12, 54,  0 }, {     18,   18,   15, 12, 54,  0 }, {     19,   19,   14, 12, 54,  0 }, {     20,   20,   14, 12, 54,  0 },
    {     21,   21,   13, 12, 54,  0 }, {     22,   22,   13, 12, 54,  0 }, {     23,   23,   12, 12, 54,  0 }, {     24,   24,   12, 12, 54,  1 }, {     25,   25,   11, 12, 54,  1 },
    {     26,   26,   11, 12, 54,  1 }, {     27,   27,   10, 12, 54,  1 }, {     28,   28,   10, 12, 54,  1 }, {     29,   29,    9, 12, 54,  1 }, {     30,   30,    9, 12, 54,  1 },
    {     31,   31,    8, 12, 54,  1 }, {     32,   32,    8, 12, 54,  1 }, {     33,   33,    7, 12, 54,  1 }, {     34,   34,    7, 12, 54,  1 }, {     35,   35,    6, 12, 54,  1 },
    {     36,   36,    6, 12, 54,  1 }, {     37,   37,    5, 12, 54,  1 }, {     38,   38,    5, 12, 54,  1 }, {     39,   39,    4, 12, 54,  1 }, {     40,   40,    4, 12, 54,  2 },
    {     41,   41,    3, 12, 54,  2 }, {     42,   42,    3, 12, 54,  2 }, {     43,   43,    2, 12, 54,  2 }, {     44,   44,    2, 12, 54,  2 }, {     45,   45,    1, 12, 54,  2 },
    {     46,   46,    1, 12, 54,  2 }, {     47,   47,    0, 12, 54,  2 }, {     48,   48,    0, 12, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25ToLeftBankedDown252, {
    {     16,   15,   16, 20, 54,  0 }, {     17,   14,   15, 20, 54,  0 }, {     18,   13,   15, 20, 54,  0 }, {     19,   12,   14, 20, 54,  0 }, {     20,   11,   14, 20, 54,  0 },
    {     21,   10,   13, 20, 54,  0 }, {     22,    9,   13, 20, 54,  0 }, {     23,    8,   12, 20, 54,  0 }, {     24,    7,   12, 20, 54,  1 }, {     25,    6,   11, 20, 54,  1 },
    {     26,    5,   11, 20, 54,  1 }, {     27,    4,   10, 20, 54,  1 }, {     28,    3,   10, 20, 54,  1 }, {     29,    2,    9, 20, 54,  1 }, {     30,    1,    9, 20, 54,  1 },
    {     31,    0,    8, 20, 54,  1 }, {     32,   -1,    8, 20, 54,  1 }, {     33,   -2,    7, 20, 54,  1 }, {     34,   -3,    7, 20, 54,  1 }, {     35,   -4,    6, 20, 54,  1 },
    {     36,   -5,    6, 20, 54,  1 }, {     37,   -6,    5, 20, 54,  1 }, {     38,   -7,    5, 20, 54,  1 }, {     39,   -8,    4, 20, 54,  1 }, {     40,   -9,    4, 20, 54,  2 },
    {     41,  -10,    3, 20, 54,  2 }, {     42,  -11,    3, 20, 54,  2 }, {     43,  -12,    2, 20, 54,  2 }, {     44,  -13,    2, 20, 54,  2 }, {     45,  -14,    1, 20, 54,  2 },
    {     46,  -15,    1, 20, 54,  2 }, {     47,  -16,    0, 20, 54,  2 }, {     48,  -17,    0, 20, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25ToLeftBankedDown253, {
    {     15,   15,   15, 28, 54,  0 }, {     14,   14,   15, 28, 54,  0 }, {     13,   13,   14, 28, 54,  0 }, {     12,   12,   14, 28, 54,  0 }, {     11,   11,   13, 28, 54,  0 },
    {     10,   10,   13, 28, 54,  0 }, {      9,    9,   12, 28, 54,  0 }, {      8,    8,   12, 28, 54,  1 }, {      7,    7,   11, 28, 54,  1 }, {      6,    6,   11, 28, 54,  1 },
    {      5,    5,   10, 28, 54,  1 }, {      4,    4,   10, 28, 54,  1 }, {      3,    3,    9, 28, 54,  1 }, {      2,    2,    9, 28, 54,  1 }, {      1,    1,    8, 28, 54,  1 },
    {      0,    0,    8, 28, 54,  1 }, {     -1,   -1,    7, 28, 54,  1 }, {     -2,   -2,    7, 28, 54,  1 }, {     -3,   -3,    6, 28, 54,  1 }, {     -4,   -4,    6, 28, 54,  1 },
    {     -5,   -5,    5, 28, 54,  1 }, {     -6,   -6,    5, 28, 54,  1 }, {     -7,   -7,    4, 28, 54,  1 }, {     -8,   -8,    4, 28, 54,  2 }, {     -9,   -9,    3, 28, 54,  2 },
    {    -10,  -10,    3, 28, 54,  2 }, {    -11,  -11,    2, 28, 54,  2 }, {    -12,  -12,    2, 28, 54,  2 }, {    -13,  -13,    1, 28, 54,  2 }, {    -14,  -14,    1, 28, 54,  2 },
    {    -15,  -15,    0, 28, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25ToRightBankedDown250, {
    {     15,   16,   15,  4, 54,  0 }, {     14,   17,   15,  4, 54,  0 }, {     13,   18,   14,  4, 54,  0 }, {     12,   19,   14,  4, 54,  0 }, {     11,   20,   13,  4, 54,  0 },
    {     10,   21,   13,  4, 54,  0 }, {      9,   22,   12,  4, 54,  0 }, {      8,   23,   12,  4, 54,  3 }, {      7,   24,   11,  4, 54,  3 }, {      6,   25,   11,  4, 54,  3 },
    {      5,   26,   10,  4, 54,  3 }, {      4,   27,   10,  4, 54,  3 }, {      3,   28,    9,  4, 54,  3 }, {      2,   29,    9,  4, 54,  3 }, {      1,   30,    8,  4, 54,  3 },
    {      0,   31,    8,  4, 54,  3 }, {     -1,   32,    7,  4, 54,  3 }, {     -2,   33,    7,  4, 54,  3 }, {     -3,   34,    6,  4, 54,  3 }, {     -4,   35,    6,  4, 54,  3 },
    {     -5,   36,    5,  4, 54,  3 }, {     -6,   37,    5,  4, 54,  3 }, {     -7,   38,    4,  4, 54,  3 }, {     -8,   39,    4,  4, 54,  4 }, {     -9,   40,    3,  4, 54,  4 },
    {    -10,   41,    3,  4, 54,  4 }, {    -11,   42,    2,  4, 54,  4 }, {    -12,   43,    2,  4, 54,  4 }, {    -13,   44,    1,  4, 54,  4 }, {    -14,   45,    1,  4, 54,  4 },
    {    -15,   46,    0,  4, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25ToRightBankedDown251, {
    {     16,   16,   16, 12, 54,  0 }, {     17,   17,   15, 12, 54,  0 }, {     18,   18,   15, 12, 54,  0 }, {     19,   19,   14, 12, 54,  0 }, {     20,   20,   14, 12, 54,  0 },
    {     21,   21,   13, 12, 54,  0 }, {     22,   22,   13, 12, 54,  0 }, {     23,   23,   12, 12, 54,  0 }, {     24,   24,   12, 12, 54,  3 }, {     25,   25,   11, 12, 54,  3 },
    {     26,   26,   11, 12, 54,  3 }, {     27,   27,   10, 12, 54,  3 }, {     28,   28,   10, 12, 54,  3 }, {     29,   29,    9, 12, 54,  3 }, {     30,   30,    9, 12, 54,  3 },
    {     31,   31,    8, 12, 54,  3 }, {     32,   32,    8, 12, 54,  3 }, {     33,   33,    7, 12, 54,  3 }, {     34,   34,    7, 12, 54,  3 }, {     35,   35,    6, 12, 54,  3 },
    {     36,   36,    6, 12, 54,  3 }, {     37,   37,    5, 12, 54,  3 }, {     38,   38,    5, 12, 54,  3 }, {     39,   39,    4, 12, 54,  3 }, {     40,   40,    4, 12, 54,  4 },
    {     41,   41,    3, 12, 54,  4 }, {     42,   42,    3, 12, 54,  4 }, {     43,   43,    2, 12, 54,  4 }, {     44,   44,    2, 12, 54,  4 }, {     45,   45,    1, 12, 54,  4 },
    {     46,   46,    1, 12, 54,  4 }, {     47,   47,    0, 12, 54,  4 }, {     48,   48,    0, 12, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25ToRightBankedDown252, {
    {     16,   15,   16, 20, 54,  0 }, {     17,   14,   15, 20, 54,  0 }, {     18,   13,   15, 20, 54,  0 }, {     19,   12,   14, 20, 54,  0 }, {     20,   11,   14, 20, 54,  0 },
    {     21,   10,   13, 20, 54,  0 }, {     22,    9,   13, 20, 54,  0 }, {     23,    8,   12, 20, 54,  0 }, {     24,    7,   12, 20, 54,  3 }, {     25,    6,   11, 20, 54,  3 },
    {     26,    5,   11, 20, 54,  3 }, {     27,    4,   10, 20, 54,  3 }, {     28,    3,   10, 20, 54,  3 }, {     29,    2,    9, 20, 54,  3 }, {     30,    1,    9, 20, 54,  3 },
    {     31,    0,    8, 20, 54,  3 }, {     32,   -1,    8, 20, 54,  3 }, {     33,   -2,    7, 20, 54,  3 }, {     34,   -3,    7, 20, 54,  3 }, {     35,   -4,    6, 20, 54,  3 },
    {     36,   -5,    6, 20, 54,  3 }, {     37,   -6,    5, 20, 54,  3 }, {     38,   -7,    5, 20, 54,  3 }, {     39,   -8,    4, 20, 54,  3 }, {     40,   -9,    4, 20, 54,  4 },
    {     41,  -10,    3, 20, 54,  4 }, {     42,  -11,    3, 20, 54,  4 }, {     43,  -12,    2, 20, 54,  4 }, {     44,  -13,    2, 20, 54,  4 }, {     45,  -14,    1, 20, 54,  4 },
    {     46,  -15,    1, 20, 54,  4 }, {     47,  -16,    0, 20, 54,  4 }, {     48,  -17,    0, 20, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25ToRightBankedDown253, {
    {     15,   15,   15, 28, 54,  0 }, {     14,   14,   15, 28, 54,  0 }, {     13,   13,   14, 28, 54,  0 }, {     12,   12,   14, 28, 54,  0 }, {     11,   11,   13, 28, 54,  0 },
    {     10,   10,   13, 28, 54,  0 }, {      9,    9,   12, 28, 54,  0 }, {      8,    8,   12, 28, 54,  3 }, {      7,    7,   11, 28, 54,  3 }, {      6,    6,   11, 28, 54,  3 },
    {      5,    5,   10, 28, 54,  3 }, {      4,    4,   10, 28, 54,  3 }, {      3,    3,    9, 28, 54,  3 }, {      2,    2,    9, 28, 54,  3 }, {      1,    1,    8, 28, 54,  3 },
    {      0,    0,    8, 28, 54,  3 }, {     -1,   -1,    7, 28, 54,  3 }, {     -2,   -2,    7, 28, 54,  3 }, {     -3,   -3,    6, 28, 54,  3 }, {     -4,   -4,    6, 28, 54,  3 },
    {     -5,   -5,    5, 28, 54,  3 }, {     -6,   -6,    5, 28, 54,  3 }, {     -7,   -7,    4, 28, 54,  3 }, {     -8,   -8,    4, 28, 54,  4 }, {     -9,   -9,    3, 28, 54,  4 },
    {    -10,  -10,    3, 28, 54,  4 }, {    -11,  -11,    2, 28, 54,  4 }, {    -12,  -12,    2, 28, 54,  4 }, {    -13,  -13,    1, 28, 54,  4 }, {    -14,  -14,    1, 28, 54,  4 },
    {    -15,  -15,    0, 28, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedDown25ToDown250, {
    {     15,   16,   15,  4, 54,  2 }, {     14,   17,   15,  4, 54,  2 }, {     13,   18,   14,  4, 54,  2 }, {     12,   19,   14,  4, 54,  2 }, {     11,   20,   13,  4, 54,  2 },
    {     10,   21,   13,  4, 54,  2 }, {      9,   22,   12,  4, 54,  2 }, {      8,   23,   12,  4, 54,  1 }, {      7,   24,   11,  4, 54,  1 }, {      6,   25,   11,  4, 54,  1 },
    {      5,   26,   10,  4, 54,  1 }, {      4,   27,   10,  4, 54,  1 }, {      3,   28,    9,  4, 54,  1 }, {      2,   29,    9,  4, 54,  1 }, {      1,   30,    8,  4, 54,  1 },
    {      0,   31,    8,  4, 54,  1 }, {     -1,   32,    7,  4, 54,  1 }, {     -2,   33,    7,  4, 54,  1 }, {     -3,   34,    6,  4, 54,  1 }, {     -4,   35,    6,  4, 54,  1 },
    {     -5,   36,    5,  4, 54,  1 }, {     -6,   37,    5,  4, 54,  1 }, {     -7,   38,    4,  4, 54,  1 }, {     -8,   39,    4,  4, 54,  0 }, {     -9,   40,    3,  4, 54,  0 },
    {    -10,   41,    3,  4, 54,  0 }, {    -11,   42,    2,  4, 54,  0 }, {    -12,   43,    2,  4, 54,  0 }, {    -13,   44,    1,  4, 54,  0 }, {    -14,   45,    1,  4, 54,  0 },
    {    -15,   46,    0,  4, 54,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedDown25ToDown251, {
    {     16,   16,   16, 12, 54,  2 }, {     17,   17,   15, 12, 54,  2 }, {     18,   18,   15, 12, 54,  2 }, {     19,   19,   14, 12, 54,  2 }, {     20,   20,   14, 12, 54,  2 },
    {     21,   21,   13, 12, 54,  2 }, {     22,   22,   13, 12, 54,  2 }, {     23,   23,   12, 12, 54,  2 }, {     24,   24,   12, 12, 54,  1 }, {     25,   25,   11, 12, 54,  1 },
    {     26,   26,   11, 12, 54,  1 }, {     27,   27,   10, 12, 54,  1 }, {     28,   28,   10, 12, 54,  1 }, {     29,   29,    9, 12, 54,  1 }, {     30,   30,    9, 12, 54,  1 },
    {     31,   31,    8, 12, 54,  1 }, {     32,   32,    8, 12, 54,  1 }, {     33,   33,    7, 12, 54,  1 }, {     34,   34,    7, 12, 54,  1 }, {     35,   35,    6, 12, 54,  1 },
    {     36,   36,    6, 12, 54,  1 }, {     37,   37,    5, 12, 54,  1 }, {     38,   38,    5, 12, 54,  1 }, {     39,   39,    4, 12, 54,  1 }, {     40,   40,    4, 12, 54,  0 },
    {     41,   41,    3, 12, 54,  0 }, {     42,   42,    3, 12, 54,  0 }, {     43,   43,    2, 12, 54,  0 }, {     44,   44,    2, 12, 54,  0 }, {     45,   45,    1, 12, 54,  0 },
    {     46,   46,    1, 12, 54,  0 }, {     47,   47,    0, 12, 54,  0 }, {     48,   48,    0, 12, 54,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedDown25ToDown252, {
    {     16,   15,   16, 20, 54,  2 }, {     17,   14,   15, 20, 54,  2 }, {     18,   13,   15, 20, 54,  2 }, {     19,   12,   14, 20, 54,  2 }, {     20,   11,   14, 20, 54,  2 },
    {     21,   10,   13, 20, 54,  2 }, {     22,    9,   13, 20, 54,  2 }, {     23,    8,   12, 20, 54,  2 }, {     24,    7,   12, 20, 54,  1 }, {     25,    6,   11, 20, 54,  1 },
    {     26,    5,   11, 20, 54,  1 }, {     27,    4,   10, 20, 54,  1 }, {     28,    3,   10, 20, 54,  1 }, {     29,    2,    9, 20, 54,  1 }, {     30,    1,    9, 20, 54,  1 },
    {     31,    0,    8, 20, 54,  1 }, {     32,   -1,    8, 20, 54,  1 }, {     33,   -2,    7, 20, 54,  1 }, {     34,   -3,    7, 20, 54,  1 }, {     35,   -4,    6, 20, 54,  1 },
    {     36,   -5,    6, 20, 54,  1 }, {     37,   -6,    5, 20, 54,  1 }, {     38,   -7,    5, 20, 54,  1 }, {     39,   -8,    4, 20, 54,  1 }, {     40,   -9,    4, 20, 54,  0 },
    {     41,  -10,    3, 20, 54,  0 }, {     42,  -11,    3, 20, 54,  0 }, {     43,  -12,    2, 20, 54,  0 }, {     44,  -13,    2, 20, 54,  0 }, {     45,  -14,    1, 20, 54,  0 },
    {     46,  -15,    1, 20, 54,  0 }, {     47,  -16,    0, 20, 54,  0 }, {     48,  -17,    0, 20, 54,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedDown25ToDown253, {
    {     15,   15,   15, 28, 54,  2 }, {     14,   14,   15, 28, 54,  2 }, {     13,   13,   14, 28, 54,  2 }, {     12,   12,   14, 28, 54,  2 }, {     11,   11,   13, 28, 54,  2 },
    {     10,   10,   13, 28, 54,  2 }, {      9,    9,   12, 28, 54,  2 }, {      8,    8,   12, 28, 54,  1 }, {      7,    7,   11, 28, 54,  1 }, {      6,    6,   11, 28, 54,  1 },
    {      5,    5,   10, 28, 54,  1 }, {      4,    4,   10, 28, 54,  1 }, {      3,    3,    9, 28, 54,  1 }, {      2,    2,    9, 28, 54,  1 }, {      1,    1,    8, 28, 54,  1 },
    {      0,    0,    8, 28, 54,  1 }, {     -1,   -1,    7, 28, 54,  1 }, {     -2,   -2,    7, 28, 54,  1 }, {     -3,   -3,    6, 28, 54,  1 }, {     -4,   -4,    6, 28, 54,  1 },
    {     -5,   -5,    5, 28, 54,  1 }, {     -6,   -6,    5, 28, 54,  1 }, {     -7,   -7,    4, 28, 54,  1 }, {     -8,   -8,    4, 28, 54,  0 }, {     -9,   -9,    3, 28, 54,  0 },
    {    -10,  -10,    3, 28, 54,  0 }, {    -11,  -11,    2, 28, 54,  0 }, {    -12,  -12,    2, 28, 54,  0 }, {    -13,  -13,    1, 28, 54,  0 }, {    -14,  -14,    1, 28, 54,  0 },
    {    -15,  -15,    0, 28, 54,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedDown25ToDown250, {
    {     15,   16,   15,  4, 54,  4 }, {     14,   17,   15,  4, 54,  4 }, {     13,   18,   14,  4, 54,  4 }, {     12,   19,   14,  4, 54,  4 }, {     11,   20,   13,  4, 54,  4 },
    {     10,   21,   13,  4, 54,  4 }, {      9,   22,   12,  4, 54,  4 }, {      8,   23,   12,  4, 54,  3 }, {      7,   24,   11,  4, 54,  3 }, {      6,   25,   11,  4, 54,  3 },
    {      5,   26,   10,  4, 54,  3 }, {      4,   27,   10,  4, 54,  3 }, {      3,   28,    9,  4, 54,  3 }, {      2,   29,    9,  4, 54,  3 }, {      1,   30,    8,  4, 54,  3 },
    {      0,   31,    8,  4, 54,  3 }, {     -1,   32,    7,  4, 54,  3 }, {     -2,   33,    7,  4, 54,  3 }, {     -3,   34,    6,  4, 54,  3 }, {     -4,   35,    6,  4, 54,  3 },
    {     -5,   36,    5,  4, 54,  3 }, {     -6,   37,    5,  4, 54,  3 }, {     -7,   38,    4,  4, 54,  3 }, {     -8,   39,    4,  4, 54,  0 }, {     -9,   40,    3,  4, 54,  0 },
    {    -10,   41,    3,  4, 54,  0 }, {    -11,   42,    2,  4, 54,  0 }, {    -12,   43,    2,  4, 54,  0 }, {    -13,   44,    1,  4, 54,  0 }, {    -14,   45,    1,  4, 54,  0 },
    {    -15,   46,    0,  4, 54,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedDown25ToDown251, {
    {     16,   16,   16, 12, 54,  4 }, {     17,   17,   15, 12, 54,  4 }, {     18,   18,   15, 12, 54,  4 }, {     19,   19,   14, 12, 54,  4 }, {     20,   20,   14, 12, 54,  4 },
    {     21,   21,   13, 12, 54,  4 }, {     22,   22,   13, 12, 54,  4 }, {     23,   23,   12, 12, 54,  4 }, {     24,   24,   12, 12, 54,  3 }, {     25,   25,   11, 12, 54,  3 },
    {     26,   26,   11, 12, 54,  3 }, {     27,   27,   10, 12, 54,  3 }, {     28,   28,   10, 12, 54,  3 }, {     29,   29,    9, 12, 54,  3 }, {     30,   30,    9, 12, 54,  3 },
    {     31,   31,    8, 12, 54,  3 }, {     32,   32,    8, 12, 54,  3 }, {     33,   33,    7, 12, 54,  3 }, {     34,   34,    7, 12, 54,  3 }, {     35,   35,    6, 12, 54,  3 },
    {     36,   36,    6, 12, 54,  3 }, {     37,   37,    5, 12, 54,  3 }, {     38,   38,    5, 12, 54,  3 }, {     39,   39,    4, 12, 54,  3 }, {     40,   40,    4, 12, 54,  0 },
    {     41,   41,    3, 12, 54,  0 }, {     42,   42,    3, 12, 54,  0 }, {     43,   43,    2, 12, 54,  0 }, {     44,   44,    2, 12, 54,  0 }, {     45,   45,    1, 12, 54,  0 },
    {     46,   46,    1, 12, 54,  0 }, {     47,   47,    0, 12, 54,  0 }, {     48,   48,    0, 12, 54,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedDown25ToDown252, {
    {     16,   15,   16, 20, 54,  4 }, {     17,   14,   15, 20, 54,  4 }, {     18,   13,   15, 20, 54,  4 }, {     19,   12,   14, 20, 54,  4 }, {     20,   11,   14, 20, 54,  4 },
    {     21,   10,   13, 20, 54,  4 }, {     22,    9,   13, 20, 54,  4 }, {     23,    8,   12, 20, 54,  4 }, {     24,    7,   12, 20, 54,  3 }, {     25,    6,   11, 20, 54,  3 },
    {     26,    5,   11, 20, 54,  3 }, {     27,    4,   10, 20, 54,  3 }, {     28,    3,   10, 20, 54,  3 }, {     29,    2,    9, 20, 54,  3 }, {     30,    1,    9, 20, 54,  3 },
    {     31,    0,    8, 20, 54,  3 }, {     32,   -1,    8, 20, 54,  3 }, {     33,   -2,    7, 20, 54,  3 }, {     34,   -3,    7, 20, 54,  3 }, {     35,   -4,    6, 20, 54,  3 },
    {     36,   -5,    6, 20, 54,  3 }, {     37,   -6,    5, 20, 54,  3 }, {     38,   -7,    5, 20, 54,  3 }, {     39,   -8,    4, 20, 54,  3 }, {     40,   -9,    4, 20, 54,  0 },
    {     41,  -10,    3, 20, 54,  0 }, {     42,  -11,    3, 20, 54,  0 }, {     43,  -12,    2, 20, 54,  0 }, {     44,  -13,    2, 20, 54,  0 }, {     45,  -14,    1, 20, 54,  0 },
    {     46,  -15,    1, 20, 54,  0 }, {     47,  -16,    0, 20, 54,  0 }, {     48,  -17,    0, 20, 54,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedDown25ToDown253, {
    {     15,   15,   15, 28, 54,  4 }, {     14,   14,   15, 28, 54,  4 }, {     13,   13,   14, 28, 54,  4 }, {     12,   12,   14, 28, 54,  4 }, {     11,   11,   13, 28, 54,  4 },
    {     10,   10,   13, 28, 54,  4 }, {      9,    9,   12, 28, 54,  4 }, {      8,    8,   12, 28, 54,  3 }, {      7,    7,   11, 28, 54,  3 }, {      6,    6,   11, 28, 54,  3 },
    {      5,    5,   10, 28, 54,  3 }, {      4,    4,   10, 28, 54,  3 }, {      3,    3,    9, 28, 54,  3 }, {      2,    2,    9, 28, 54,  3 }, {      1,    1,    8, 28, 54,  3 },
    {      0,    0,    8, 28, 54,  3 }, {     -1,   -1,    7, 28, 54,  3 }, {     -2,   -2,    7, 28, 54,  3 }, {     -3,   -3,    6, 28, 54,  3 }, {     -4,   -4,    6, 28, 54,  3 },
    {     -5,   -5,    5, 28, 54,  3 }, {     -6,   -6,    5, 28, 54,  3 }, {     -7,   -7,    4, 28, 54,  3 }, {     -8,   -8,    4, 28, 54,  0 }, {     -9,   -9,    3, 28, 54,  0 },
    {    -10,  -10,    3, 28, 54,  0 }, {    -11,  -11,    2, 28, 54,  0 }, {    -12,  -12,    2, 28, 54,  0 }, {    -13,  -13,    1, 28, 54,  0 }, {    -14,  -14,    1, 28, 54,  0 },
    {    -15,  -15,    0, 28, 54,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedFlatToLeftBankedUp250, {
    {     15,   16,    0,  4,  0,  2 }, {     14,   17,    0,  4,  0,  2 }, {     13,   18,    0,  4,  0,  2 }, {     12,   19,    0,  4,  0,  2 }, {     11,   20,    0,  4,  0,  2 },
    {     10,   21,    0,  4,  0,  2 }, {      9,   22,    0,  4,  0,  2 }, {      8,   23,    1,  4, 50,  2 }, {      7,   24,    1,  4, 50,  2 }, {      6,   25,    1,  4, 50,  2 },
    {      5,   26,    1,  4, 50,  2 }, {      4,   27,    1,  4, 50,  2 }, {      3,   28,    1,  4, 50,  2 }, {      2,   29,    2,  4, 50,  2 }, {      1,   30,    2,  4, 50,  2 },
    {      0,   31,    2,  4, 50,  2 }, {     -1,   32,    2,  4, 50,  2 }, {     -2,   33,    3,  4, 50,  2 }, {     -3,   34,    3,  4, 50,  2 }, {     -4,   35,    3,  4, 50,  2 },
    {     -5,   36,    4,  4, 50,  2 }, {     -6,   37,    4,  4, 50,  2 }, {     -7,   38,    4,  4, 50,  2 }, {     -8,   39,    5,  4, 51,  2 }, {     -9,   40,    5,  4, 51,  2 },
    {    -10,   41,    5,  4, 51,  2 }, {    -11,   42,    6,  4, 51,  2 }, {    -12,   43,    6,  4, 51,  2 }, {    -13,   44,    7,  4, 51,  2 }, {    -14,   45,    7,  4, 51,  2 },
    {    -15,   46,    8,  4, 51,  2 }, {    -16,   47,    8,  4, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedFlatToLeftBankedUp251, {
    {     16,   16,    0, 12,  0,  2 }, {     17,   17,    0, 12,  0,  2 }, {     18,   18,    0, 12,  0,  2 }, {     19,   19,    0, 12,  0,  2 }, {     20,   20,    0, 12,  0,  2 },
    {     21,   21,    0, 12,  0,  2 }, {     22,   22,    0, 12,  0,  2 }, {     23,   23,    0, 12,  0,  2 }, {     24,   24,    1, 12, 50,  2 }, {     25,   25,    1, 12, 50,  2 },
    {     26,   26,    1, 12, 50,  2 }, {     27,   27,    1, 12, 50,  2 }, {     28,   28,    1, 12, 50,  2 }, {     29,   29,    1, 12, 50,  2 }, {     30,   30,    2, 12, 50,  2 },
    {     31,   31,    2, 12, 50,  2 }, {     32,   32,    2, 12, 50,  2 }, {     33,   33,    2, 12, 50,  2 }, {     34,   34,    3, 12, 50,  2 }, {     35,   35,    3, 12, 50,  2 },
    {     36,   36,    3, 12, 50,  2 }, {     37,   37,    4, 12, 50,  2 }, {     38,   38,    4, 12, 50,  2 }, {     39,   39,    4, 12, 50,  2 }, {     40,   40,    5, 12, 51,  2 },
    {     41,   41,    5, 12, 51,  2 }, {     42,   42,    5, 12, 51,  2 }, {     43,   43,    6, 12, 51,  2 }, {     44,   44,    6, 12, 51,  2 }, {     45,   45,    7, 12, 51,  2 },
    {     46,   46,    7, 12, 51,  2 }, {     47,   47,    8, 12, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedFlatToLeftBankedUp252, {
    {     16,   15,    0, 20,  0,  2 }, {     17,   14,    0, 20,  0,  2 }, {     18,   13,    0, 20,  0,  2 }, {     19,   12,    0, 20,  0,  2 }, {     20,   11,    0, 20,  0,  2 },
    {     21,   10,    0, 20,  0,  2 }, {     22,    9,    0, 20,  0,  2 }, {     23,    8,    0, 20,  0,  2 }, {     24,    7,    1, 20, 50,  2 }, {     25,    6,    1, 20, 50,  2 },
    {     26,    5,    1, 20, 50,  2 }, {     27,    4,    1, 20, 50,  2 }, {     28,    3,    1, 20, 50,  2 }, {     29,    2,    1, 20, 50,  2 }, {     30,    1,    2, 20, 50,  2 },
    {     31,    0,    2, 20, 50,  2 }, {     32,   -1,    2, 20, 50,  2 }, {     33,   -2,    2, 20, 50,  2 }, {     34,   -3,    3, 20, 50,  2 }, {     35,   -4,    3, 20, 50,  2 },
    {     36,   -5,    3, 20, 50,  2 }, {     37,   -6,    4, 20, 50,  2 }, {     38,   -7,    4, 20, 50,  2 }, {     39,   -8,    4, 20, 50,  2 }, {     40,   -9,    5, 20, 51,  2 },
    {     41,  -10,    5, 20, 51,  2 }, {     42,  -11,    5, 20, 51,  2 }, {     43,  -12,    6, 20, 51,  2 }, {     44,  -13,    6, 20, 51,  2 }, {     45,  -14,    7, 20, 51,  2 },
    {     46,  -15,    7, 20, 51,  2 }, {     47,  -16,    8, 20, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedFlatToLeftBankedUp253, {
    {     15,   15,    0, 28,  0,  2 }, {     14,   14,    0, 28,  0,  2 }, {     13,   13,    0, 28,  0,  2 }, {     12,   12,    0, 28,  0,  2 }, {     11,   11,    0, 28,  0,  2 },
    {     10,   10,    0, 28,  0,  2 }, {      9,    9,    0, 28,  0,  2 }, {      8,    8,    1, 28, 50,  2 }, {      7,    7,    1, 28, 50,  2 }, {      6,    6,    1, 28, 50,  2 },
    {      5,    5,    1, 28, 50,  2 }, {      4,    4,    1, 28, 50,  2 }, {      3,    3,    1, 28, 50,  2 }, {      2,    2,    2, 28, 50,  2 }, {      1,    1,    2, 28, 50,  2 },
    {      0,    0,    2, 28, 50,  2 }, {     -1,   -1,    2, 28, 50,  2 }, {     -2,   -2,    3, 28, 50,  2 }, {     -3,   -3,    3, 28, 50,  2 }, {     -4,   -4,    3, 28, 50,  2 },
    {     -5,   -5,    4, 28, 50,  2 }, {     -6,   -6,    4, 28, 50,  2 }, {     -7,   -7,    4, 28, 50,  2 }, {     -8,   -8,    5, 28, 51,  2 }, {     -9,   -9,    5, 28, 51,  2 },
    {    -10,  -10,    5, 28, 51,  2 }, {    -11,  -11,    6, 28, 51,  2 }, {    -12,  -12,    6, 28, 51,  2 }, {    -13,  -13,    7, 28, 51,  2 }, {    -14,  -14,    7, 28, 51,  2 },
    {    -15,  -15,    8, 28, 51,  2 }, {    -16,  -16,    8, 28, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedFlatToRightBankedUp250, {
    {     15,   16,    0,  4,  0,  4 }, {     14,   17,    0,  4,  0,  4 }, {     13,   18,    0,  4,  0,  4 }, {     12,   19,    0,  4,  0,  4 }, {     11,   20,    0,  4,  0,  4 },
    {     10,   21,    0,  4,  0,  4 }, {      9,   22,    0,  4,  0,  4 }, {      8,   23,    1,  4, 50,  4 }, {      7,   24,    1,  4, 50,  4 }, {      6,   25,    1,  4, 50,  4 },
    {      5,   26,    1,  4, 50,  4 }, {      4,   27,    1,  4, 50,  4 }, {      3,   28,    1,  4, 50,  4 }, {      2,   29,    2,  4, 50,  4 }, {      1,   30,    2,  4, 50,  4 },
    {      0,   31,    2,  4, 50,  4 }, {     -1,   32,    2,  4, 50,  4 }, {     -2,   33,    3,  4, 50,  4 }, {     -3,   34,    3,  4, 50,  4 }, {     -4,   35,    3,  4, 50,  4 },
    {     -5,   36,    4,  4, 50,  4 }, {     -6,   37,    4,  4, 50,  4 }, {     -7,   38,    4,  4, 50,  4 }, {     -8,   39,    5,  4, 51,  4 }, {     -9,   40,    5,  4, 51,  4 },
    {    -10,   41,    5,  4, 51,  4 }, {    -11,   42,    6,  4, 51,  4 }, {    -12,   43,    6,  4, 51,  4 }, {    -13,   44,    7,  4, 51,  4 }, {    -14,   45,    7,  4, 51,  4 },
    {    -15,   46,    8,  4, 51,  4 }, {    -16,   47,    8,  4, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedFlatToRightBankedUp251, {
    {     16,   16,    0, 12,  0,  4 }, {     17,   17,    0, 12,  0,  4 }, {     18,   18,    0, 12,  0,  4 }, {     19,   19,    0, 12,  0,  4 }, {     20,   20,    0, 12,  0,  4 },
    {     21,   21,    0, 12,  0,  4 }, {     22,   22,    0, 12,  0,  4 }, {     23,   23,    0, 12,  0,  4 }, {     24,   24,    1, 12, 50,  4 }, {     25,   25,    1, 12, 50,  4 },
    {     26,   26,    1, 12, 50,  4 }, {     27,   27,    1, 12, 50,  4 }, {     28,   28,    1, 12, 50,  4 }, {     29,   29,    1, 12, 50,  4 }, {     30,   30,    2, 12, 50,  4 },
    {     31,   31,    2, 12, 50,  4 }, {     32,   32,    2, 12, 50,  4 }, {     33,   33,    2, 12, 50,  4 }, {     34,   34,    3, 12, 50,  4 }, {     35,   35,    3, 12, 50,  4 },
    {     36,   36,    3, 12, 50,  4 }, {     37,   37,    4, 12, 50,  4 }, {     38,   38,    4, 12, 50,  4 }, {     39,   39,    4, 12, 50,  4 }, {     40,   40,    5, 12, 51,  4 },
    {     41,   41,    5, 12, 51,  4 }, {     42,   42,    5, 12, 51,  4 }, {     43,   43,    6, 12, 51,  4 }, {     44,   44,    6, 12, 51,  4 }, {     45,   45,    7, 12, 51,  4 },
    {     46,   46,    7, 12, 51,  4 }, {     47,   47,    8, 12, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedFlatToRightBankedUp252, {
    {     16,   15,    0, 20,  0,  4 }, {     17,   14,    0, 20,  0,  4 }, {     18,   13,    0, 20,  0,  4 }, {     19,   12,    0, 20,  0,  4 }, {     20,   11,    0, 20,  0,  4 },
    {     21,   10,    0, 20,  0,  4 }, {     22,    9,    0, 20,  0,  4 }, {     23,    8,    0, 20,  0,  4 }, {     24,    7,    1, 20, 50,  4 }, {     25,    6,    1, 20, 50,  4 },
    {     26,    5,    1, 20, 50,  4 }, {     27,    4,    1, 20, 50,  4 }, {     28,    3,    1, 20, 50,  4 }, {     29,    2,    1, 20, 50,  4 }, {     30,    1,    2, 20, 50,  4 },
    {     31,    0,    2, 20, 50,  4 }, {     32,   -1,    2, 20, 50,  4 }, {     33,   -2,    2, 20, 50,  4 }, {     34,   -3,    3, 20, 50,  4 }, {     35,   -4,    3, 20, 50,  4 },
    {     36,   -5,    3, 20, 50,  4 }, {     37,   -6,    4, 20, 50,  4 }, {     38,   -7,    4, 20, 50,  4 }, {     39,   -8,    4, 20, 50,  4 }, {     40,   -9,    5, 20, 51,  4 },
    {     41,  -10,    5, 20, 51,  4 }, {     42,  -11,    5, 20, 51,  4 }, {     43,  -12,    6, 20, 51,  4 }, {     44,  -13,    6, 20, 51,  4 }, {     45,  -14,    7, 20, 51,  4 },
    {     46,  -15,    7, 20, 51,  4 }, {     47,  -16,    8, 20, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedFlatToRightBankedUp253, {
    {     15,   15,    0, 28,  0,  4 }, {     14,   14,    0, 28,  0,  4 }, {     13,   13,    0, 28,  0,  4 }, {     12,   12,    0, 28,  0,  4 }, {     11,   11,    0, 28,  0,  4 },
    {     10,   10,    0, 28,  0,  4 }, {      9,    9,    0, 28,  0,  4 }, {      8,    8,    1, 28, 50,  4 }, {      7,    7,    1, 28, 50,  4 }, {      6,    6,    1, 28, 50,  4 },
    {      5,    5,    1, 28, 50,  4 }, {      4,    4,    1, 28, 50,  4 }, {      3,    3,    1, 28, 50,  4 }, {      2,    2,    2, 28, 50,  4 }, {      1,    1,    2, 28, 50,  4 },
    {      0,    0,    2, 28, 50,  4 }, {     -1,   -1,    2, 28, 50,  4 }, {     -2,   -2,    3, 28, 50,  4 }, {     -3,   -3,    3, 28, 50,  4 }, {     -4,   -4,    3, 28, 50,  4 },
    {     -5,   -5,    4, 28, 50,  4 }, {     -6,   -6,    4, 28, 50,  4 }, {     -7,   -7,    4, 28, 50,  4 }, {     -8,   -8,    5, 28, 51,  4 }, {     -9,   -9,    5, 28, 51,  4 },
    {    -10,  -10,    5, 28, 51,  4 }, {    -11,  -11,    6, 28, 51,  4 }, {    -12,  -12,    6, 28, 51,  4 }, {    -13,  -13,    7, 28, 51,  4 }, {    -14,  -14,    7, 28, 51,  4 },
    {    -15,  -15,    8, 28, 51,  4 }, {    -16,  -16,    8, 28, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedUp25ToLeftBankedFlat0, {
    {     15,   16,    1,  4, 51,  2 }, {     14,   17,    1,  4, 51,  2 }, {     13,   18,    2,  4, 51,  2 }, {     12,   19,    2,  4, 51,  2 }, {     11,   20,    2,  4, 51,  2 },
    {     10,   21,    3,  4, 51,  2 }, {      9,   22,    3,  4, 51,  2 }, {      8,   23,    4,  4, 50,  2 }, {      7,   24,    4,  4, 50,  2 }, {      6,   25,    4,  4, 50,  2 },
    {      5,   26,    5,  4, 50,  2 }, {      4,   27,    5,  4, 50,  2 }, {      3,   28,    5,  4, 50,  2 }, {      2,   29,    6,  4, 50,  2 }, {      1,   30,    6,  4, 50,  2 },
    {      0,   31,    6,  4, 50,  2 }, {     -1,   32,    6,  4, 50,  2 }, {     -2,   33,    7,  4, 50,  2 }, {     -3,   34,    7,  4, 50,  2 }, {     -4,   35,    7,  4, 50,  2 },
    {     -5,   36,    7,  4, 50,  2 }, {     -6,   37,    7,  4, 50,  2 }, {     -7,   38,    7,  4, 50,  2 }, {     -8,   39,    8,  4,  0,  2 }, {     -9,   40,    8,  4,  0,  2 },
    {    -10,   41,    8,  4,  0,  2 }, {    -11,   42,    8,  4,  0,  2 }, {    -12,   43,    8,  4,  0,  2 }, {    -13,   44,    8,  4,  0,  2 }, {    -14,   45,    8,  4,  0,  2 },
    {    -15,   46,    8,  4,  0,  2 }, {    -16,   47,    8,  4,  0,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedUp25ToLeftBankedFlat1, {
    {     16,   16,    0, 12, 51,  2 }, {     17,   17,    1, 12, 51,  2 }, {     18,   18,    1, 12, 51,  2 }, {     19,   19,    2, 12, 51,  2 }, {     20,   20,    2, 12, 51,  2 },
    {     21,   21,    2, 12, 51,  2 }, {     22,   22,    3, 12, 51,  2 }, {     23,   23,    3, 12, 51,  2 }, {     24,   24,    4, 12, 50,  2 }, {     25,   25,    4, 12, 50,  2 },
    {     26,   26,    4, 12, 50,  2 }, {     27,   27,    5, 12, 50,  2 }, {     28,   28,    5, 12, 50,  2 }, {     29,   29,    5, 12, 50,  2 }, {     30,   30,    6, 12, 50,  2 },
    {     31,   31,    6, 12, 50,  2 }, {     32,   32,    6, 12, 50,  2 }, {     33,   33,    6, 12, 50,  2 }, {     34,   34,    7, 12, 50,  2 }, {     35,   35,    7, 12, 50,  2 },
    {     36,   36,    7, 12, 50,  2 }, {     37,   37,    7, 12, 50,  2 }, {     38,   38,    7, 12, 50,  2 }, {     39,   39,    7, 12, 50,  2 }, {     40,   40,    8, 12,  0,  2 },
    {     41,   41,    8, 12,  0,  2 }, {     42,   42,    8, 12,  0,  2 }, {     43,   43,    8, 12,  0,  2 }, {     44,   44,    8, 12,  0,  2 }, {     45,   45,    8, 12,  0,  2 },
    {     46,   46,    8, 12,  0,  2 }, {     47,   47,    8, 12,  0,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedUp25ToLeftBankedFlat2, {
    {     16,   15,    0, 20, 51,  2 }, {     17,   14,    1, 20, 51,  2 }, {     18,   13,    1, 20, 51,  2 }, {     19,   12,    2, 20, 51,  2 }, {     20,   11,    2, 20, 51,  2 },
    {     21,   10,    2, 20, 51,  2 }, {     22,    9,    3, 20, 51,  2 }, {     23,    8,    3, 20, 51,  2 }, {     24,    7,    4, 20, 50,  2 }, {     25,    6,    4, 20, 50,  2 },
    {     26,    5,    4, 20, 50,  2 }, {     27,    4,    5, 20, 50,  2 }, {     28,    3,    5, 20, 50,  2 }, {     29,    2,    5, 20, 50,  2 }, {     30,    1,    6, 20, 50,  2 },
    {     31,    0,    6, 20, 50,  2 }, {     32,   -1,    6, 20, 50,  2 }, {     33,   -2,    6, 20, 50,  2 }, {     34,   -3,    7, 20, 50,  2 }, {     35,   -4,    7, 20, 50,  2 },
    {     36,   -5,    7, 20, 50,  2 }, {     37,   -6,    7, 20, 50,  2 }, {     38,   -7,    7, 20, 50,  2 }, {     39,   -8,    7, 20, 50,  2 }, {     40,   -9,    8, 20,  0,  2 },
    {     41,  -10,    8, 20,  0,  2 }, {     42,  -11,    8, 20,  0,  2 }, {     43,  -12,    8, 20,  0,  2 }, {     44,  -13,    8, 20,  0,  2 }, {     45,  -14,    8, 20,  0,  2 },
    {     46,  -15,    8, 20,  0,  2 }, {     47,  -16,    8, 20,  0,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedUp25ToLeftBankedFlat3, {
    {     15,   15,    1, 28, 51,  2 }, {     14,   14,    1, 28, 51,  2 }, {     13,   13,    2, 28, 51,  2 }, {     12,   12,    2, 28, 51,  2 }, {     11,   11,    2, 28, 51,  2 },
    {     10,   10,    3, 28, 51,  2 }, {      9,    9,    3, 28, 51,  2 }, {      8,    8,    4, 28, 50,  2 }, {      7,    7,    4, 28, 50,  2 }, {      6,    6,    4, 28, 50,  2 },
    {      5,    5,    5, 28, 50,  2 }, {      4,    4,    5, 28, 50,  2 }, {      3,    3,    5, 28, 50,  2 }, {      2,    2,    6, 28, 50,  2 }, {      1,    1,    6, 28, 50,  2 },
    {      0,    0,    6, 28, 50,  2 }, {     -1,   -1,    6, 28, 50,  2 }, {     -2,   -2,    7, 28, 50,  2 }, {     -3,   -3,    7, 28, 50,  2 }, {     -4,   -4,    7, 28, 50,  2 },
    {     -5,   -5,    7, 28, 50,  2 }, {     -6,   -6,    7, 28, 50,  2 }, {     -7,   -7,    7, 28, 50,  2 }, {     -8,   -8,    8, 28,  0,  2 }, {     -9,   -9,    8, 28,  0,  2 },
    {    -10,  -10,    8, 28,  0,  2 }, {    -11,  -11,    8, 28,  0,  2 }, {    -12,  -12,    8, 28,  0,  2 }, {    -13,  -13,    8, 28,  0,  2 }, {    -14,  -14,    8, 28,  0,  2 },
    {    -15,  -15,    8, 28,  0,  2 }, {    -16,  -16,    8, 28,  0,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedUp25ToRightBankedFlat0, {
    {     15,   16,    1,  4, 51,  4 }, {     14,   17,    1,  4, 51,  4 }, {     13,   18,    2,  4, 51,  4 }, {     12,   19,    2,  4, 51,  4 }, {     11,   20,    2,  4, 51,  4 },
    {     10,   21,    3,  4, 51,  4 }, {      9,   22,    3,  4, 51,  4 }, {      8,   23,    4,  4, 50,  4 }, {      7,   24,    4,  4, 50,  4 }, {      6,   25,    4,  4, 50,  4 },
    {      5,   26,    5,  4, 50,  4 }, {      4,   27,    5,  4, 50,  4 }, {      3,   28,    5,  4, 50,  4 }, {      2,   29,    6,  4, 50,  4 }, {      1,   30,    6,  4, 50,  4 },
    {      0,   31,    6,  4, 50,  4 }, {     -1,   32,    6,  4, 50,  4 }, {     -2,   33,    7,  4, 50,  4 }, {     -3,   34,    7,  4, 50,  4 }, {     -4,   35,    7,  4, 50,  4 },
    {     -5,   36,    7,  4, 50,  4 }, {     -6,   37,    7,  4, 50,  4 }, {     -7,   38,    7,  4, 50,  4 }, {     -8,   39,    8,  4,  0,  4 }, {     -9,   40,    8,  4,  0,  4 },
    {    -10,   41,    8,  4,  0,  4 }, {    -11,   42,    8,  4,  0,  4 }, {    -12,   43,    8,  4,  0,  4 }, {    -13,   44,    8,  4,  0,  4 }, {    -14,   45,    8,  4,  0,  4 },
    {    -15,   46,    8,  4,  0,  4 }, {    -16,   47,    8,  4,  0,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedUp25ToRightBankedFlat1, {
    {     16,   16,    0, 12, 51,  4 }, {     17,   17,    1, 12, 51,  4 }, {     18,   18,    1, 12, 51,  4 }, {     19,   19,    2, 12, 51,  4 }, {     20,   20,    2, 12, 51,  4 },
    {     21,   21,    2, 12, 51,  4 }, {     22,   22,    3, 12, 51,  4 }, {     23,   23,    3, 12, 51,  4 }, {     24,   24,    4, 12, 50,  4 }, {     25,   25,    4, 12, 50,  4 },
    {     26,   26,    4, 12, 50,  4 }, {     27,   27,    5, 12, 50,  4 }, {     28,   28,    5, 12, 50,  4 }, {     29,   29,    5, 12, 50,  4 }, {     30,   30,    6, 12, 50,  4 },
    {     31,   31,    6, 12, 50,  4 }, {     32,   32,    6, 12, 50,  4 }, {     33,   33,    6, 12, 50,  4 }, {     34,   34,    7, 12, 50,  4 }, {     35,   35,    7, 12, 50,  4 },
    {     36,   36,    7, 12, 50,  4 }, {     37,   37,    7, 12, 50,  4 }, {     38,   38,    7, 12, 50,  4 }, {     39,   39,    7, 12, 50,  4 }, {     40,   40,    8, 12,  0,  4 },
    {     41,   41,    8, 12,  0,  4 }, {     42,   42,    8, 12,  0,  4 }, {     43,   43,    8, 12,  0,  4 }, {     44,   44,    8, 12,  0,  4 }, {     45,   45,    8, 12,  0,  4 },
    {     46,   46,    8, 12,  0,  4 }, {     47,   47,    8, 12,  0,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedUp25ToRightBankedFlat2, {
    {     16,   15,    0, 20, 51,  4 }, {     17,   14,    1, 20, 51,  4 }, {     18,   13,    1, 20, 51,  4 }, {     19,   12,    2, 20, 51,  4 }, {     20,   11,    2, 20, 51,  4 },
    {     21,   10,    2, 20, 51,  4 }, {     22,    9,    3, 20, 51,  4 }, {     23,    8,    3, 20, 51,  4 }, {     24,    7,    4, 20, 50,  4 }, {     25,    6,    4, 20, 50,  4 },
    {     26,    5,    4, 20, 50,  4 }, {     27,    4,    5, 20, 50,  4 }, {     28,    3,    5, 20, 50,  4 }, {     29,    2,    5, 20, 50,  4 }, {     30,    1,    6, 20, 50,  4 },
    {     31,    0,    6, 20, 50,  4 }, {     32,   -1,    6, 20, 50,  4 }, {     33,   -2,    6, 20, 50,  4 }, {     34,   -3,    7, 20, 50,  4 }, {     35,   -4,    7, 20, 50,  4 },
    {     36,   -5,    7, 20, 50,  4 }, {     37,   -6,    7, 20, 50,  4 }, {     38,   -7,    7, 20, 50,  4 }, {     39,   -8,    7, 20, 50,  4 }, {     40,   -9,    8, 20,  0,  4 },
    {     41,  -10,    8, 20,  0,  4 }, {     42,  -11,    8, 20,  0,  4 }, {     43,  -12,    8, 20,  0,  4 }, {     44,  -13,    8, 20,  0,  4 }, {     45,  -14,    8, 20,  0,  4 },
    {     46,  -15,    8, 20,  0,  4 }, {     47,  -16,    8, 20,  0,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedUp25ToRightBankedFlat3, {
    {     15,   15,    1, 28, 51,  4 }, {     14,   14,    1, 28, 51,  4 }, {     13,   13,    2, 28, 51,  4 }, {     12,   12,    2, 28, 51,  4 }, {     11,   11,    2, 28, 51,  4 },
    {     10,   10,    3, 28, 51,  4 }, {      9,    9,    3, 28, 51,  4 }, {      8,    8,    4, 28, 50,  4 }, {      7,    7,    4, 28, 50,  4 }, {      6,    6,    4, 28, 50,  4 },
    {      5,    5,    5, 28, 50,  4 }, {      4,    4,    5, 28, 50,  4 }, {      3,    3,    5, 28, 50,  4 }, {      2,    2,    6, 28, 50,  4 }, {      1,    1,    6, 28, 50,  4 },
    {      0,    0,    6, 28, 50,  4 }, {     -1,   -1,    6, 28, 50,  4 }, {     -2,   -2,    7, 28, 50,  4 }, {     -3,   -3,    7, 28, 50,  4 }, {     -4,   -4,    7, 28, 50,  4 },
    {     -5,   -5,    7, 28, 50,  4 }, {     -6,   -6,    7, 28, 50,  4 }, {     -7,   -7,    7, 28, 50,  4 }, {     -8,   -8,    8, 28,  0,  4 }, {     -9,   -9,    8, 28,  0,  4 },
    {    -10,  -10,    8, 28,  0,  4 }, {    -11,  -11,    8, 28,  0,  4 }, {    -12,  -12,    8, 28,  0,  4 }, {    -13,  -13,    8, 28,  0,  4 }, {    -14,  -14,    8, 28,  0,  4 },
    {    -15,  -15,    8, 28,  0,  4 }, {    -16,  -16,    8, 28,  0,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedFlatToLeftBankedDown250, {
    {     15,   16,    8,  4,  0,  2 }, {     14,   17,    8,  4,  0,  2 }, {     13,   18,    8,  4,  0,  2 }, {     12,   19,    8,  4,  0,  2 }, {     11,   20,    8,  4,  0,  2 },
    {     10,   21,    8,  4,  0,  2 }, {      9,   22,    8,  4,  0,  2 }, {      8,   23,    7,  4, 53,  2 }, {      7,   24,    7,  4, 53,  2 }, {      6,   25,    7,  4, 53,  2 },
    {      5,   26,    7,  4, 53,  2 }, {      4,   27,    7,  4, 53,  2 }, {      3,   28,    7,  4, 53,  2 }, {      2,   29,    6,  4, 53,  2 }, {      1,   30,    6,  4, 53,  2 },
    {      0,   31,    6,  4, 53,  2 }, {     -1,   32,    6,  4, 53,  2 }, {     -2,   33,    5,  4, 53,  2 }, {     -3,   34,    5,  4, 53,  2 }, {     -4,   35,    5,  4, 53,  2 },
    {     -5,   36,    4,  4, 53,  2 }, {     -6,   37,    4,  4, 53,  2 }, {     -7,   38,    4,  4, 53,  2 }, {     -8,   39,    3,  4, 54,  2 }, {     -9,   40,    3,  4, 54,  2 },
    {    -10,   41,    3,  4, 54,  2 }, {    -11,   42,    2,  4, 54,  2 }, {    -12,   43,    2,  4, 54,  2 }, {    -13,   44,    1,  4, 54,  2 }, {    -14,   45,    1,  4, 54,  2 },
    {    -15,   46,    0,  4, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedFlatToLeftBankedDown251, {
    {     16,   16,    8, 12,  0,  2 }, {     17,   17,    8, 12,  0,  2 }, {     18,   18,    8, 12,  0,  2 }, {     19,   19,    8, 12,  0,  2 }, {     20,   20,    8, 12,  0,  2 },
    {     21,   21,    8, 12,  0,  2 }, {     22,   22,    8, 12,  0,  2 }, {     23,   23,    8, 12,  0,  2 }, {     24,   24,    7, 12, 53,  2 }, {     25,   25,    7, 12, 53,  2 },
    {     26,   26,    7, 12, 53,  2 }, {     27,   27,    7, 12, 53,  2 }, {     28,   28,    7, 12, 53,  2 }, {     29,   29,    7, 12, 53,  2 }, {     30,   30,    6, 12, 53,  2 },
    {     31,   31,    6, 12, 53,  2 }, {     32,   32,    6, 12, 53,  2 }, {     33,   33,    6, 12, 53,  2 }, {     34,   34,    5, 12, 53,  2 }, {     35,   35,    5, 12, 53,  2 },
    {     36,   36,    5, 12, 53,  2 }, {     37,   37,    4, 12, 53,  2 }, {     38,   38,    4, 12, 53,  2 }, {     39,   39,    4, 12, 53,  2 }, {     40,   40,    3, 12, 54,  2 },
    {     41,   41,    3, 12, 54,  2 }, {     42,   42,    3, 12, 54,  2 }, {     43,   43,    2, 12, 54,  2 }, {     44,   44,    2, 12, 54,  2 }, {     45,   45,    1, 12, 54,  2 },
    {     46,   46,    1, 12, 54,  2 }, {     47,   47,    0, 12, 54,  2 }, {     48,   48,    0, 12, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedFlatToLeftBankedDown252, {
    {     16,   15,    8, 20,  0,  2 }, {     17,   14,    8, 20,  0,  2 }, {     18,   13,    8, 20,  0,  2 }, {     19,   12,    8, 20,  0,  2 }, {     20,   11,    8, 20,  0,  2 },
    {     21,   10,    8, 20,  0,  2 }, {     22,    9,    8, 20,  0,  2 }, {     23,    8,    8, 20,  0,  2 }, {     24,    7,    7, 20, 53,  2 }, {     25,    6,    7, 20, 53,  2 },
    {     26,    5,    7, 20, 53,  2 }, {     27,    4,    7, 20, 53,  2 }, {     28,    3,    7, 20, 53,  2 }, {     29,    2,    7, 20, 53,  2 }, {     30,    1,    6, 20, 53,  2 },
    {     31,    0,    6, 20, 53,  2 }, {     32,   -1,    6, 20, 53,  2 }, {     33,   -2,    6, 20, 53,  2 }, {     34,   -3,    5, 20, 53,  2 }, {     35,   -4,    5, 20, 53,  2 },
    {     36,   -5,    5, 20, 53,  2 }, {     37,   -6,    4, 20, 53,  2 }, {     38,   -7,    4, 20, 53,  2 }, {     39,   -8,    4, 20, 53,  2 }, {     40,   -9,    3, 20, 54,  2 },
    {     41,  -10,    3, 20, 54,  2 }, {     42,  -11,    3, 20, 54,  2 }, {     43,  -12,    2, 20, 54,  2 }, {     44,  -13,    2, 20, 54,  2 }, {     45,  -14,    1, 20, 54,  2 },
    {     46,  -15,    1, 20, 54,  2 }, {     47,  -16,    0, 20, 54,  2 }, {     48,  -17,    0, 20, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedFlatToLeftBankedDown253, {
    {     15,   15,    8, 28,  0,  2 }, {     14,   14,    8, 28,  0,  2 }, {     13,   13,    8, 28,  0,  2 }, {     12,   12,    8, 28,  0,  2 }, {     11,   11,    8, 28,  0,  2 },
    {     10,   10,    8, 28,  0,  2 }, {      9,    9,    8, 28,  0,  2 }, {      8,    8,    7, 28, 53,  2 }, {      7,    7,    7, 28, 53,  2 }, {      6,    6,    7, 28, 53,  2 },
    {      5,    5,    7, 28, 53,  2 }, {      4,    4,    7, 28, 53,  2 }, {      3,    3,    7, 28, 53,  2 }, {      2,    2,    6, 28, 53,  2 }, {      1,    1,    6, 28, 53,  2 },
    {      0,    0,    6, 28, 53,  2 }, {     -1,   -1,    6, 28, 53,  2 }, {     -2,   -2,    5, 28, 53,  2 }, {     -3,   -3,    5, 28, 53,  2 }, {     -4,   -4,    5, 28, 53,  2 },
    {     -5,   -5,    4, 28, 53,  2 }, {     -6,   -6,    4, 28, 53,  2 }, {     -7,   -7,    4, 28, 53,  2 }, {     -8,   -8,    3, 28, 54,  2 }, {     -9,   -9,    3, 28, 54,  2 },
    {    -10,  -10,    3, 28, 54,  2 }, {    -11,  -11,    2, 28, 54,  2 }, {    -12,  -12,    2, 28, 54,  2 }, {    -13,  -13,    1, 28, 54,  2 }, {    -14,  -14,    1, 28, 54,  2 },
    {    -15,  -15,    0, 28, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedFlatToRightBankedDown250, {
    {     15,   16,    8,  4,  0,  4 }, {     14,   17,    8,  4,  0,  4 }, {     13,   18,    8,  4,  0,  4 }, {     12,   19,    8,  4,  0,  4 }, {     11,   20,    8,  4,  0,  4 },
    {     10,   21,    8,  4,  0,  4 }, {      9,   22,    8,  4,  0,  4 }, {      8,   23,    7,  4, 53,  4 }, {      7,   24,    7,  4, 53,  4 }, {      6,   25,    7,  4, 53,  4 },
    {      5,   26,    7,  4, 53,  4 }, {      4,   27,    7,  4, 53,  4 }, {      3,   28,    7,  4, 53,  4 }, {      2,   29,    6,  4, 53,  4 }, {      1,   30,    6,  4, 53,  4 },
    {      0,   31,    6,  4, 53,  4 }, {     -1,   32,    6,  4, 53,  4 }, {     -2,   33,    5,  4, 53,  4 }, {     -3,   34,    5,  4, 53,  4 }, {     -4,   35,    5,  4, 53,  4 },
    {     -5,   36,    4,  4, 53,  4 }, {     -6,   37,    4,  4, 53,  4 }, {     -7,   38,    4,  4, 53,  4 }, {     -8,   39,    3,  4, 54,  4 }, {     -9,   40,    3,  4, 54,  4 },
    {    -10,   41,    3,  4, 54,  4 }, {    -11,   42,    2,  4, 54,  4 }, {    -12,   43,    2,  4, 54,  4 }, {    -13,   44,    1,  4, 54,  4 }, {    -14,   45,    1,  4, 54,  4 },
    {    -15,   46,    0,  4, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedFlatToRightBankedDown251, {
    {     16,   16,    8, 12,  0,  4 }, {     17,   17,    8, 12,  0,  4 }, {     18,   18,    8, 12,  0,  4 }, {     19,   19,    8, 12,  0,  4 }, {     20,   20,    8, 12,  0,  4 },
    {     21,   21,    8, 12,  0,  4 }, {     22,   22,    8, 12,  0,  4 }, {     23,   23,    8, 12,  0,  4 }, {     24,   24,    7, 12, 53,  4 }, {     25,   25,    7, 12, 53,  4 },
    {     26,   26,    7, 12, 53,  4 }, {     27,   27,    7, 12, 53,  4 }, {     28,   28,    7, 12, 53,  4 }, {     29,   29,    7, 12, 53,  4 }, {     30,   30,    6, 12, 53,  4 },
    {     31,   31,    6, 12, 53,  4 }, {     32,   32,    6, 12, 53,  4 }, {     33,   33,    6, 12, 53,  4 }, {     34,   34,    5, 12, 53,  4 }, {     35,   35,    5, 12, 53,  4 },
    {     36,   36,    5, 12, 53,  4 }, {     37,   37,    4, 12, 53,  4 }, {     38,   38,    4, 12, 53,  4 }, {     39,   39,    4, 12, 53,  4 }, {     40,   40,    3, 12, 54,  4 },
    {     41,   41,    3, 12, 54,  4 }, {     42,   42,    3, 12, 54,  4 }, {     43,   43,    2, 12, 54,  4 }, {     44,   44,    2, 12, 54,  4 }, {     45,   45,    1, 12, 54,  4 },
    {     46,   46,    1, 12, 54,  4 }, {     47,   47,    0, 12, 54,  4 }, {     48,   48,    0, 12, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedFlatToRightBankedDown252, {
    {     16,   15,    8, 20,  0,  4 }, {     17,   14,    8, 20,  0,  4 }, {     18,   13,    8, 20,  0,  4 }, {     19,   12,    8, 20,  0,  4 }, {     20,   11,    8, 20,  0,  4 },
    {     21,   10,    8, 20,  0,  4 }, {     22,    9,    8, 20,  0,  4 }, {     23,    8,    8, 20,  0,  4 }, {     24,    7,    7, 20, 53,  4 }, {     25,    6,    7, 20, 53,  4 },
    {     26,    5,    7, 20, 53,  4 }, {     27,    4,    7, 20, 53,  4 }, {     28,    3,    7, 20, 53,  4 }, {     29,    2,    7, 20, 53,  4 }, {     30,    1,    6, 20, 53,  4 },
    {     31,    0,    6, 20, 53,  4 }, {     32,   -1,    6, 20, 53,  4 }, {     33,   -2,    6, 20, 53,  4 }, {     34,   -3,    5, 20, 53,  4 }, {     35,   -4,    5, 20, 53,  4 },
    {     36,   -5,    5, 20, 53,  4 }, {     37,   -6,    4, 20, 53,  4 }, {     38,   -7,    4, 20, 53,  4 }, {     39,   -8,    4, 20, 53,  4 }, {     40,   -9,    3, 20, 54,  4 },
    {     41,  -10,    3, 20, 54,  4 }, {     42,  -11,    3, 20, 54,  4 }, {     43,  -12,    2, 20, 54,  4 }, {     44,  -13,    2, 20, 54,  4 }, {     45,  -14,    1, 20, 54,  4 },
    {     46,  -15,    1, 20, 54,  4 }, {     47,  -16,    0, 20, 54,  4 }, {     48,  -17,    0, 20, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedFlatToRightBankedDown253, {
    {     15,   15,    8, 28,  0,  4 }, {     14,   14,    8, 28,  0,  4 }, {     13,   13,    8, 28,  0,  4 }, {     12,   12,    8, 28,  0,  4 }, {     11,   11,    8, 28,  0,  4 },
    {     10,   10,    8, 28,  0,  4 }, {      9,    9,    8, 28,  0,  4 }, {      8,    8,    7, 28, 53,  4 }, {      7,    7,    7, 28, 53,  4 }, {      6,    6,    7, 28, 53,  4 },
    {      5,    5,    7, 28, 53,  4 }, {      4,    4,    7, 28, 53,  4 }, {      3,    3,    7, 28, 53,  4 }, {      2,    2,    6, 28, 53,  4 }, {      1,    1,    6, 28, 53,  4 },
    {      0,    0,    6, 28, 53,  4 }, {     -1,   -1,    6, 28, 53,  4 }, {     -2,   -2,    5, 28, 53,  4 }, {     -3,   -3,    5, 28, 53,  4 }, {     -4,   -4,    5, 28, 53,  4 },
    {     -5,   -5,    4, 28, 53,  4 }, {     -6,   -6,    4, 28, 53,  4 }, {     -7,   -7,    4, 28, 53,  4 }, {     -8,   -8,    3, 28, 54,  4 }, {     -9,   -9,    3, 28, 54,  4 },
    {    -10,  -10,    3, 28, 54,  4 }, {    -11,  -11,    2, 28, 54,  4 }, {    -12,  -12,    2, 28, 54,  4 }, {    -13,  -13,    1, 28, 54,  4 }, {    -14,  -14,    1, 28, 54,  4 },
    {    -15,  -15,    0, 28, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedDown25ToLeftBankedFlat0, {
    {     15,   16,    7,  4, 54,  2 }, {     14,   17,    7,  4, 54,  2 }, {     13,   18,    6,  4, 54,  2 }, {     12,   19,    6,  4, 54,  2 }, {     11,   20,    6,  4, 54,  2 },
    {     10,   21,    5,  4, 54,  2 }, {      9,   22,    5,  4, 54,  2 }, {      8,   23,    4,  4, 53,  2 }, {      7,   24,    4,  4, 53,  2 }, {      6,   25,    4,  4, 53,  2 },
    {      5,   26,    3,  4, 53,  2 }, {      4,   27,    3,  4, 53,  2 }, {      3,   28,    3,  4, 53,  2 }, {      2,   29,    2,  4, 53,  2 }, {      1,   30,    2,  4, 53,  2 },
    {      0,   31,    2,  4, 53,  2 }, {     -1,   32,    2,  4, 53,  2 }, {     -2,   33,    1,  4, 53,  2 }, {     -3,   34,    1,  4, 53,  2 }, {     -4,   35,    1,  4, 53,  2 },
    {     -5,   36,    1,  4, 53,  2 }, {     -6,   37,    1,  4, 53,  2 }, {     -7,   38,    1,  4, 53,  2 }, {     -8,   39,    0,  4,  0,  2 }, {     -9,   40,    0,  4,  0,  2 },
    {    -10,   41,    0,  4,  0,  2 }, {    -11,   42,    0,  4,  0,  2 }, {    -12,   43,    0,  4,  0,  2 }, {    -13,   44,    0,  4,  0,  2 }, {    -14,   45,    0,  4,  0,  2 },
    {    -15,   46,    0,  4,  0,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedDown25ToLeftBankedFlat1, {
    {     16,   16,    8, 12, 54,  2 }, {     17,   17,    7, 12, 54,  2 }, {     18,   18,    7, 12, 54,  2 }, {     19,   19,    6, 12, 54,  2 }, {     20,   20,    6, 12, 54,  2 },
    {     21,   21,    6, 12, 54,  2 }, {     22,   22,    5, 12, 54,  2 }, {     23,   23,    5, 12, 54,  2 }, {     24,   24,    4, 12, 53,  2 }, {     25,   25,    4, 12, 53,  2 },
    {     26,   26,    4, 12, 53,  2 }, {     27,   27,    3, 12, 53,  2 }, {     28,   28,    3, 12, 53,  2 }, {     29,   29,    3, 12, 53,  2 }, {     30,   30,    2, 12, 53,  2 },
    {     31,   31,    2, 12, 53,  2 }, {     32,   32,    2, 12, 53,  2 }, {     33,   33,    2, 12, 53,  2 }, {     34,   34,    1, 12, 53,  2 }, {     35,   35,    1, 12, 53,  2 },
    {     36,   36,    1, 12, 53,  2 }, {     37,   37,    1, 12, 53,  2 }, {     38,   38,    1, 12, 53,  2 }, {     39,   39,    1, 12, 53,  2 }, {     40,   40,    0, 12,  0,  2 },
    {     41,   41,    0, 12,  0,  2 }, {     42,   42,    0, 12,  0,  2 }, {     43,   43,    0, 12,  0,  2 }, {     44,   44,    0, 12,  0,  2 }, {     45,   45,    0, 12,  0,  2 },
    {     46,   46,    0, 12,  0,  2 }, {     47,   47,    0, 12,  0,  2 }, {     48,   48,    0, 12,  0,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedDown25ToLeftBankedFlat2, {
    {     16,   15,    8, 20, 54,  2 }, {     17,   14,    7, 20, 54,  2 }, {     18,   13,    7, 20, 54,  2 }, {     19,   12,    6, 20, 54,  2 }, {     20,   11,    6, 20, 54,  2 },
    {     21,   10,    6, 20, 54,  2 }, {     22,    9,    5, 20, 54,  2 }, {     23,    8,    5, 20, 54,  2 }, {     24,    7,    4, 20, 53,  2 }, {     25,    6,    4, 20, 53,  2 },
    {     26,    5,    4, 20, 53,  2 }, {     27,    4,    3, 20, 53,  2 }, {     28,    3,    3, 20, 53,  2 }, {     29,    2,    3, 20, 53,  2 }, {     30,    1,    2, 20, 53,  2 },
    {     31,    0,    2, 20, 53,  2 }, {     32,   -1,    2, 20, 53,  2 }, {     33,   -2,    2, 20, 53,  2 }, {     34,   -3,    1, 20, 53,  2 }, {     35,   -4,    1, 20, 53,  2 },
    {     36,   -5,    1, 20, 53,  2 }, {     37,   -6,    1, 20, 53,  2 }, {     38,   -7,    1, 20, 53,  2 }, {     39,   -8,    1, 20, 53,  2 }, {     40,   -9,    0, 20,  0,  2 },
    {     41,  -10,    0, 20,  0,  2 }, {     42,  -11,    0, 20,  0,  2 }, {     43,  -12,    0, 20,  0,  2 }, {     44,  -13,    0, 20,  0,  2 }, {     45,  -14,    0, 20,  0,  2 },
    {     46,  -15,    0, 20,  0,  2 }, {     47,  -16,    0, 20,  0,  2 }, {     48,  -17,    0, 20,  0,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedDown25ToLeftBankedFlat3, {
    {     15,   15,    7, 28, 54,  2 }, {     14,   14,    7, 28, 54,  2 }, {     13,   13,    6, 28, 54,  2 }, {     12,   12,    6, 28, 54,  2 }, {     11,   11,    6, 28, 54,  2 },
    {     10,   10,    5, 28, 54,  2 }, {      9,    9,    5, 28, 54,  2 }, {      8,    8,    4, 28, 53,  2 }, {      7,    7,    4, 28, 53,  2 }, {      6,    6,    4, 28, 53,  2 },
    {      5,    5,    3, 28, 53,  2 }, {      4,    4,    3, 28, 53,  2 }, {      3,    3,    3, 28, 53,  2 }, {      2,    2,    2, 28, 53,  2 }, {      1,    1,    2, 28, 53,  2 },
    {      0,    0,    2, 28, 53,  2 }, {     -1,   -1,    2, 28, 53,  2 }, {     -2,   -2,    1, 28, 53,  2 }, {     -3,   -3,    1, 28, 53,  2 }, {     -4,   -4,    1, 28, 53,  2 },
    {     -5,   -5,    1, 28, 53,  2 }, {     -6,   -6,    1, 28, 53,  2 }, {     -7,   -7,    1, 28, 53,  2 }, {     -8,   -8,    0, 28,  0,  2 }, {     -9,   -9,    0, 28,  0,  2 },
    {    -10,  -10,    0, 28,  0,  2 }, {    -11,  -11,    0, 28,  0,  2 }, {    -12,  -12,    0, 28,  0,  2 }, {    -13,  -13,    0, 28,  0,  2 }, {    -14,  -14,    0, 28,  0,  2 },
    {    -15,  -15,    0, 28,  0,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedDown25ToRightBankedFlat0, {
    {     15,   16,    7,  4, 54,  4 }, {     14,   17,    7,  4, 54,  4 }, {     13,   18,    6,  4, 54,  4 }, {     12,   19,    6,  4, 54,  4 }, {     11,   20,    6,  4, 54,  4 },
    {     10,   21,    5,  4, 54,  4 }, {      9,   22,    5,  4, 54,  4 }, {      8,   23,    4,  4, 53,  4 }, {      7,   24,    4,  4, 53,  4 }, {      6,   25,    4,  4, 53,  4 },
    {      5,   26,    3,  4, 53,  4 }, {      4,   27,    3,  4, 53,  4 }, {      3,   28,    3,  4, 53,  4 }, {      2,   29,    2,  4, 53,  4 }, {      1,   30,    2,  4, 53,  4 },
    {      0,   31,    2,  4, 53,  4 }, {     -1,   32,    2,  4, 53,  4 }, {     -2,   33,    1,  4, 53,  4 }, {     -3,   34,    1,  4, 53,  4 }, {     -4,   35,    1,  4, 53,  4 },
    {     -5,   36,    1,  4, 53,  4 }, {     -6,   37,    1,  4, 53,  4 }, {     -7,   38,    1,  4, 53,  4 }, {     -8,   39,    0,  4,  0,  4 }, {     -9,   40,    0,  4,  0,  4 },
    {    -10,   41,    0,  4,  0,  4 }, {    -11,   42,    0,  4,  0,  4 }, {    -12,   43,    0,  4,  0,  4 }, {    -13,   44,    0,  4,  0,  4 }, {    -14,   45,    0,  4,  0,  4 },
    {    -15,   46,    0,  4,  0,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedDown25ToRightBankedFlat1, {
    {     16,   16,    8, 12, 54,  4 }, {     17,   17,    7, 12, 54,  4 }, {     18,   18,    7, 12, 54,  4 }, {     19,   19,    6, 12, 54,  4 }, {     20,   20,    6, 12, 54,  4 },
    {     21,   21,    6, 12, 54,  4 }, {     22,   22,    5, 12, 54,  4 }, {     23,   23,    5, 12, 54,  4 }, {     24,   24,    4, 12, 53,  4 }, {     25,   25,    4, 12, 53,  4 },
    {     26,   26,    4, 12, 53,  4 }, {     27,   27,    3, 12, 53,  4 }, {     28,   28,    3, 12, 53,  4 }, {     29,   29,    3, 12, 53,  4 }, {     30,   30,    2, 12, 53,  4 },
    {     31,   31,    2, 12, 53,  4 }, {     32,   32,    2, 12, 53,  4 }, {     33,   33,    2, 12, 53,  4 }, {     34,   34,    1, 12, 53,  4 }, {     35,   35,    1, 12, 53,  4 },
    {     36,   36,    1, 12, 53,  4 }, {     37,   37,    1, 12, 53,  4 }, {     38,   38,    1, 12, 53,  4 }, {     39,   39,    1, 12, 53,  4 }, {     40,   40,    0, 12,  0,  4 },
    {     41,   41,    0, 12,  0,  4 }, {     42,   42,    0, 12,  0,  4 }, {     43,   43,    0, 12,  0,  4 }, {     44,   44,    0, 12,  0,  4 }, {     45,   45,    0, 12,  0,  4 },
    {     46,   46,    0, 12,  0,  4 }, {     47,   47,    0, 12,  0,  4 }, {     48,   48,    0, 12,  0,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedDown25ToRightBankedFlat2, {
    {     16,   15,    8, 20, 54,  4 }, {     17,   14,    7, 20, 54,  4 }, {     18,   13,    7, 20, 54,  4 }, {     19,   12,    6, 20, 54,  4 }, {     20,   11,    6, 20, 54,  4 },
    {     21,   10,    6, 20, 54,  4 }, {     22,    9,    5, 20, 54,  4 }, {     23,    8,    5, 20, 54,  4 }, {     24,    7,    4, 20, 53,  4 }, {     25,    6,    4, 20, 53,  4 },
    {     26,    5,    4, 20, 53,  4 }, {     27,    4,    3, 20, 53,  4 }, {     28,    3,    3, 20, 53,  4 }, {     29,    2,    3, 20, 53,  4 }, {     30,    1,    2, 20, 53,  4 },
    {     31,    0,    2, 20, 53,  4 }, {     32,   -1,    2, 20, 53,  4 }, {     33,   -2,    2, 20, 53,  4 }, {     34,   -3,    1, 20, 53,  4 }, {     35,   -4,    1, 20, 53,  4 },
    {     36,   -5,    1, 20, 53,  4 }, {     37,   -6,    1, 20, 53,  4 }, {     38,   -7,    1, 20, 53,  4 }, {     39,   -8,    1, 20, 53,  4 }, {     40,   -9,    0, 20,  0,  4 },
    {     41,  -10,    0, 20,  0,  4 }, {     42,  -11,    0, 20,  0,  4 }, {     43,  -12,    0, 20,  0,  4 }, {     44,  -13,    0, 20,  0,  4 }, {     45,  -14,    0, 20,  0,  4 },
    {     46,  -15,    0, 20,  0,  4 }, {     47,  -16,    0, 20,  0,  4 }, {     48,  -17,    0, 20,  0,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedDown25ToRightBankedFlat3, {
    {     15,   15,    7, 28, 54,  4 }, {     14,   14,    7, 28, 54,  4 }, {     13,   13,    6, 28, 54,  4 }, {     12,   12,    6, 28, 54,  4 }, {     11,   11,    6, 28, 54,  4 },
    {     10,   10,    5, 28, 54,  4 }, {      9,    9,    5, 28, 54,  4 }, {      8,    8,    4, 28, 53,  4 }, {      7,    7,    4, 28, 53,  4 }, {      6,    6,    4, 28, 53,  4 },
    {      5,    5,    3, 28, 53,  4 }, {      4,    4,    3, 28, 53,  4 }, {      3,    3,    3, 28, 53,  4 }, {      2,    2,    2, 28, 53,  4 }, {      1,    1,    2, 28, 53,  4 },
    {      0,    0,    2, 28, 53,  4 }, {     -1,   -1,    2, 28, 53,  4 }, {     -2,   -2,    1, 28, 53,  4 }, {     -3,   -3,    1, 28, 53,  4 }, {     -4,   -4,    1, 28, 53,  4 },
    {     -5,   -5,    1, 28, 53,  4 }, {     -6,   -6,    1, 28, 53,  4 }, {     -7,   -7,    1, 28, 53,  4 }, {     -8,   -8,    0, 28,  0,  4 }, {     -9,   -9,    0, 28,  0,  4 },
    {    -10,  -10,    0, 28,  0,  4 }, {    -11,  -11,    0, 28,  0,  4 }, {    -12,  -12,    0, 28,  0,  4 }, {    -13,  -13,    0, 28,  0,  4 }, {    -14,  -14,    0, 28,  0,  4 },
    {    -15,  -15,    0, 28,  0,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25LeftBanked0, {
    {     15,   16,    1,  4, 51,  2 }, {     14,   17,    1,  4, 51,  2 }, {     13,   18,    2,  4, 51,  2 }, {     12,   19,    2,  4, 51,  2 }, {     11,   20,    3,  4, 51,  2 },
    {     10,   21,    3,  4, 51,  2 }, {      9,   22,    4,  4, 51,  2 }, {      8,   23,    4,  4, 51,  2 }, {      7,   24,    5,  4, 51,  2 }, {      6,   25,    5,  4, 51,  2 },
    {      5,   26,    6,  4, 51,  2 }, {      4,   27,    6,  4, 51,  2 }, {      3,   28,    7,  4, 51,  2 }, {      2,   29,    7,  4, 51,  2 }, {      1,   30,    8,  4, 51,  2 },
    {      0,   31,    8,  4, 51,  2 }, {     -1,   32,    9,  4, 51,  2 }, {     -2,   33,    9,  4, 51,  2 }, {     -3,   34,   10,  4, 51,  2 }, {     -4,   35,   10,  4, 51,  2 },
    {     -5,   36,   11,  4, 51,  2 }, {     -6,   37,   11,  4, 51,  2 }, {     -7,   38,   12,  4, 51,  2 }, {     -8,   39,   12,  4, 51,  2 }, {     -9,   40,   13,  4, 51,  2 },
    {    -10,   41,   13,  4, 51,  2 }, {    -11,   42,   14,  4, 51,  2 }, {    -12,   43,   14,  4, 51,  2 }, {    -13,   44,   15,  4, 51,  2 }, {    -14,   45,   15,  4, 51,  2 },
    {    -15,   46,   16,  4, 51,  2 }, {    -16,   47,   16,  4, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25LeftBanked1, {
    {     16,   16,    0, 12, 51,  2 }, {     17,   17,    1, 12, 51,  2 }, {     18,   18,    1, 12, 51,  2 }, {     19,   19,    2, 12, 51,  2 }, {     20,   20,    2, 12, 51,  2 },
    {     21,   21,    3, 12, 51,  2 }, {     22,   22,    3, 12, 51,  2 }, {     23,   23,    4, 12, 51,  2 }, {     24,   24,    4, 12, 51,  2 }, {     25,   25,    5, 12, 51,  2 },
    {     26,   26,    5, 12, 51,  2 }, {     27,   27,    6, 12, 51,  2 }, {     28,   28,    6, 12, 51,  2 }, {     29,   29,    7, 12, 51,  2 }, {     30,   30,    7, 12, 51,  2 },
    {     31,   31,    8, 12, 51,  2 }, {     32,   32,    8, 12, 51,  2 }, {     33,   33,    9, 12, 51,  2 }, {     34,   34,    9, 12, 51,  2 }, {     35,   35,   10, 12, 51,  2 },
    {     36,   36,   10, 12, 51,  2 }, {     37,   37,   11, 12, 51,  2 }, {     38,   38,   11, 12, 51,  2 }, {     39,   39,   12, 12, 51,  2 }, {     40,   40,   12, 12, 51,  2 },
    {     41,   41,   13, 12, 51,  2 }, {     42,   42,   13, 12, 51,  2 }, {     43,   43,   14, 12, 51,  2 }, {     44,   44,   14, 12, 51,  2 }, {     45,   45,   15, 12, 51,  2 },
    {     46,   46,   15, 12, 51,  2 }, {     47,   47,   16, 12, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25LeftBanked2, {
    {     16,   15,    0, 20, 51,  2 }, {     17,   14,    1, 20, 51,  2 }, {     18,   13,    1, 20, 51,  2 }, {     19,   12,    2, 20, 51,  2 }, {     20,   11,    2, 20, 51,  2 },
    {     21,   10,    3, 20, 51,  2 }, {     22,    9,    3, 20, 51,  2 }, {     23,    8,    4, 20, 51,  2 }, {     24,    7,    4, 20, 51,  2 }, {     25,    6,    5, 20, 51,  2 },
    {     26,    5,    5, 20, 51,  2 }, {     27,    4,    6, 20, 51,  2 }, {     28,    3,    6, 20, 51,  2 }, {     29,    2,    7, 20, 51,  2 }, {     30,    1,    7, 20, 51,  2 },
    {     31,    0,    8, 20, 51,  2 }, {     32,   -1,    8, 20, 51,  2 }, {     33,   -2,    9, 20, 51,  2 }, {     34,   -3,    9, 20, 51,  2 }, {     35,   -4,   10, 20, 51,  2 },
    {     36,   -5,   10, 20, 51,  2 }, {     37,   -6,   11, 20, 51,  2 }, {     38,   -7,   11, 20, 51,  2 }, {     39,   -8,   12, 20, 51,  2 }, {     40,   -9,   12, 20, 51,  2 },
    {     41,  -10,   13, 20, 51,  2 }, {     42,  -11,   13, 20, 51,  2 }, {     43,  -12,   14, 20, 51,  2 }, {     44,  -13,   14, 20, 51,  2 }, {     45,  -14,   15, 20, 51,  2 },
    {     46,  -15,   15, 20, 51,  2 }, {     47,  -16,   16, 20, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25LeftBanked3, {
    {     15,   15,    1, 28, 51,  2 }, {     14,   14,    1, 28, 51,  2 }, {     13,   13,    2, 28, 51,  2 }, {     12,   12,    2, 28, 51,  2 }, {     11,   11,    3, 28, 51,  2 },
    {     10,   10,    3, 28, 51,  2 }, {      9,    9,    4, 28, 51,  2 }, {      8,    8,    4, 28, 51,  2 }, {      7,    7,    5, 28, 51,  2 }, {      6,    6,    5, 28, 51,  2 },
    {      5,    5,    6, 28, 51,  2 }, {      4,    4,    6, 28, 51,  2 }, {      3,    3,    7, 28, 51,  2 }, {      2,    2,    7, 28, 51,  2 }, {      1,    1,    8, 28, 51,  2 },
    {      0,    0,    8, 28, 51,  2 }, {     -1,   -1,    9, 28, 51,  2 }, {     -2,   -2,    9, 28, 51,  2 }, {     -3,   -3,   10, 28, 51,  2 }, {     -4,   -4,   10, 28, 51,  2 },
    {     -5,   -5,   11, 28, 51,  2 }, {     -6,   -6,   11, 28, 51,  2 }, {     -7,   -7,   12, 28, 51,  2 }, {     -8,   -8,   12, 28, 51,  2 }, {     -9,   -9,   13, 28, 51,  2 },
    {    -10,  -10,   13, 28, 51,  2 }, {    -11,  -11,   14, 28, 51,  2 }, {    -12,  -12,   14, 28, 51,  2 }, {    -13,  -13,   15, 28, 51,  2 }, {    -14,  -14,   15, 28, 51,  2 },
    {    -15,  -15,   16, 28, 51,  2 }, {    -16,  -16,   16, 28, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25RightBanked0, {
    {     15,   16,    1,  4, 51,  4 }, {     14,   17,    1,  4, 51,  4 }, {     13,   18,    2,  4, 51,  4 }, {     12,   19,    2,  4, 51,  4 }, {     11,   20,    3,  4, 51,  4 },
    {     10,   21,    3,  4, 51,  4 }, {      9,   22,    4,  4, 51,  4 }, {      8,   23,    4,  4, 51,  4 }, {      7,   24,    5,  4, 51,  4 }, {      6,   25,    5,  4, 51,  4 },
    {      5,   26,    6,  4, 51,  4 }, {      4,   27,    6,  4, 51,  4 }, {      3,   28,    7,  4, 51,  4 }, {      2,   29,    7,  4, 51,  4 }, {      1,   30,    8,  4, 51,  4 },
    {      0,   31,    8,  4, 51,  4 }, {     -1,   32,    9,  4, 51,  4 }, {     -2,   33,    9,  4, 51,  4 }, {     -3,   34,   10,  4, 51,  4 }, {     -4,   35,   10,  4, 51,  4 },
    {     -5,   36,   11,  4, 51,  4 }, {     -6,   37,   11,  4, 51,  4 }, {     -7,   38,   12,  4, 51,  4 }, {     -8,   39,   12,  4, 51,  4 }, {     -9,   40,   13,  4, 51,  4 },
    {    -10,   41,   13,  4, 51,  4 }, {    -11,   42,   14,  4, 51,  4 }, {    -12,   43,   14,  4, 51,  4 }, {    -13,   44,   15,  4, 51,  4 }, {    -14,   45,   15,  4, 51,  4 },
    {    -15,   46,   16,  4, 51,  4 }, {    -16,   47,   16,  4, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25RightBanked1, {
    {     16,   16,    0, 12, 51,  4 }, {     17,   17,    1, 12, 51,  4 }, {     18,   18,    1, 12, 51,  4 }, {     19,   19,    2, 12, 51,  4 }, {     20,   20,    2, 12, 51,  4 },
    {     21,   21,    3, 12, 51,  4 }, {     22,   22,    3, 12, 51,  4 }, {     23,   23,    4, 12, 51,  4 }, {     24,   24,    4, 12, 51,  4 }, {     25,   25,    5, 12, 51,  4 },
    {     26,   26,    5, 12, 51,  4 }, {     27,   27,    6, 12, 51,  4 }, {     28,   28,    6, 12, 51,  4 }, {     29,   29,    7, 12, 51,  4 }, {     30,   30,    7, 12, 51,  4 },
    {     31,   31,    8, 12, 51,  4 }, {     32,   32,    8, 12, 51,  4 }, {     33,   33,    9, 12, 51,  4 }, {     34,   34,    9, 12, 51,  4 }, {     35,   35,   10, 12, 51,  4 },
    {     36,   36,   10, 12, 51,  4 }, {     37,   37,   11, 12, 51,  4 }, {     38,   38,   11, 12, 51,  4 }, {     39,   39,   12, 12, 51,  4 }, {     40,   40,   12, 12, 51,  4 },
    {     41,   41,   13, 12, 51,  4 }, {     42,   42,   13, 12, 51,  4 }, {     43,   43,   14, 12, 51,  4 }, {     44,   44,   14, 12, 51,  4 }, {     45,   45,   15, 12, 51,  4 },
    {     46,   46,   15, 12, 51,  4 }, {     47,   47,   16, 12, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25RightBanked2, {
    {     16,   15,    0, 20, 51,  4 }, {     17,   14,    1, 20, 51,  4 }, {     18,   13,    1, 20, 51,  4 }, {     19,   12,    2, 20, 51,  4 }, {     20,   11,    2, 20, 51,  4 },
    {     21,   10,    3, 20, 51,  4 }, {     22,    9,    3, 20, 51,  4 }, {     23,    8,    4, 20, 51,  4 }, {     24,    7,    4, 20, 51,  4 }, {     25,    6,    5, 20, 51,  4 },
    {     26,    5,    5, 20, 51,  4 }, {     27,    4,    6, 20, 51,  4 }, {     28,    3,    6, 20, 51,  4 }, {     29,    2,    7, 20, 51,  4 }, {     30,    1,    7, 20, 51,  4 },
    {     31,    0,    8, 20, 51,  4 }, {     32,   -1,    8, 20, 51,  4 }, {     33,   -2,    9, 20, 51,  4 }, {     34,   -3,    9, 20, 51,  4 }, {     35,   -4,   10, 20, 51,  4 },
    {     36,   -5,   10, 20, 51,  4 }, {     37,   -6,   11, 20, 51,  4 }, {     38,   -7,   11, 20, 51,  4 }, {     39,   -8,   12, 20, 51,  4 }, {     40,   -9,   12, 20, 51,  4 },
    {     41,  -10,   13, 20, 51,  4 }, {     42,  -11,   13, 20, 51,  4 }, {     43,  -12,   14, 20, 51,  4 }, {     44,  -13,   14, 20, 51,  4 }, {     45,  -14,   15, 20, 51,  4 },
    {     46,  -15,   15, 20, 51,  4 }, {     47,  -16,   16, 20, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp25RightBanked3, {
    {     15,   15,    1, 28, 51,  4 }, {     14,   14,    1, 28, 51,  4 }, {     13,   13,    2, 28, 51,  4 }, {     12,   12,    2, 28, 51,  4 }, {     11,   11,    3, 28, 51,  4 },
    {     10,   10,    3, 28, 51,  4 }, {      9,    9,    4, 28, 51,  4 }, {      8,    8,    4, 28, 51,  4 }, {      7,    7,    5, 28, 51,  4 }, {      6,    6,    5, 28, 51,  4 },
    {      5,    5,    6, 28, 51,  4 }, {      4,    4,    6, 28, 51,  4 }, {      3,    3,    7, 28, 51,  4 }, {      2,    2,    7, 28, 51,  4 }, {      1,    1,    8, 28, 51,  4 },
    {      0,    0,    8, 28, 51,  4 }, {     -1,   -1,    9, 28, 51,  4 }, {     -2,   -2,    9, 28, 51,  4 }, {     -3,   -3,   10, 28, 51,  4 }, {     -4,   -4,   10, 28, 51,  4 },
    {     -5,   -5,   11, 28, 51,  4 }, {     -6,   -6,   11, 28, 51,  4 }, {     -7,   -7,   12, 28, 51,  4 }, {     -8,   -8,   12, 28, 51,  4 }, {     -9,   -9,   13, 28, 51,  4 },
    {    -10,  -10,   13, 28, 51,  4 }, {    -11,  -11,   14, 28, 51,  4 }, {    -12,  -12,   14, 28, 51,  4 }, {    -13,  -13,   15, 28, 51,  4 }, {    -14,  -14,   15, 28, 51,  4 },
    {    -15,  -15,   16, 28, 51,  4 }, {    -16,  -16,   16, 28, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25LeftBanked0, {
    {     15,   16,   15,  4, 54,  2 }, {     14,   17,   15,  4, 54,  2 }, {     13,   18,   14,  4, 54,  2 }, {     12,   19,   14,  4, 54,  2 }, {     11,   20,   13,  4, 54,  2 },
    {     10,   21,   13,  4, 54,  2 }, {      9,   22,   12,  4, 54,  2 }, {      8,   23,   12,  4, 54,  2 }, {      7,   24,   11,  4, 54,  2 }, {      6,   25,   11,  4, 54,  2 },
    {      5,   26,   10,  4, 54,  2 }, {      4,   27,   10,  4, 54,  2 }, {      3,   28,    9,  4, 54,  2 }, {      2,   29,    9,  4, 54,  2 }, {      1,   30,    8,  4, 54,  2 },
    {      0,   31,    8,  4, 54,  2 }, {     -1,   32,    7,  4, 54,  2 }, {     -2,   33,    7,  4, 54,  2 }, {     -3,   34,    6,  4, 54,  2 }, {     -4,   35,    6,  4, 54,  2 },
    {     -5,   36,    5,  4, 54,  2 }, {     -6,   37,    5,  4, 54,  2 }, {     -7,   38,    4,  4, 54,  2 }, {     -8,   39,    4,  4, 54,  2 }, {     -9,   40,    3,  4, 54,  2 },
    {    -10,   41,    3,  4, 54,  2 }, {    -11,   42,    2,  4, 54,  2 }, {    -12,   43,    2,  4, 54,  2 }, {    -13,   44,    1,  4, 54,  2 }, {    -14,   45,    1,  4, 54,  2 },
    {    -15,   46,    0,  4, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25LeftBanked1, {
    {     16,   16,   16, 12, 54,  2 }, {     17,   17,   15, 12, 54,  2 }, {     18,   18,   15, 12, 54,  2 }, {     19,   19,   14, 12, 54,  2 }, {     20,   20,   14, 12, 54,  2 },
    {     21,   21,   13, 12, 54,  2 }, {     22,   22,   13, 12, 54,  2 }, {     23,   23,   12, 12, 54,  2 }, {     24,   24,   12, 12, 54,  2 }, {     25,   25,   11, 12, 54,  2 },
    {     26,   26,   11, 12, 54,  2 }, {     27,   27,   10, 12, 54,  2 }, {     28,   28,   10, 12, 54,  2 }, {     29,   29,    9, 12, 54,  2 }, {     30,   30,    9, 12, 54,  2 },
    {     31,   31,    8, 12, 54,  2 }, {     32,   32,    8, 12, 54,  2 }, {     33,   33,    7, 12, 54,  2 }, {     34,   34,    7, 12, 54,  2 }, {     35,   35,    6, 12, 54,  2 },
    {     36,   36,    6, 12, 54,  2 }, {     37,   37,    5, 12, 54,  2 }, {     38,   38,    5, 12, 54,  2 }, {     39,   39,    4, 12, 54,  2 }, {     40,   40,    4, 12, 54,  2 },
    {     41,   41,    3, 12, 54,  2 }, {     42,   42,    3, 12, 54,  2 }, {     43,   43,    2, 12, 54,  2 }, {     44,   44,    2, 12, 54,  2 }, {     45,   45,    1, 12, 54,  2 },
    {     46,   46,    1, 12, 54,  2 }, {     47,   47,    0, 12, 54,  2 }, {     48,   48,    0, 12, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25LeftBanked2, {
    {     16,   15,   16, 20, 54,  2 }, {     17,   14,   15, 20, 54,  2 }, {     18,   13,   15, 20, 54,  2 }, {     19,   12,   14, 20, 54,  2 }, {     20,   11,   14, 20, 54,  2 },
    {     21,   10,   13, 20, 54,  2 }, {     22,    9,   13, 20, 54,  2 }, {     23,    8,   12, 20, 54,  2 }, {     24,    7,   12, 20, 54,  2 }, {     25,    6,   11, 20, 54,  2 },
    {     26,    5,   11, 20, 54,  2 }, {     27,    4,   10, 20, 54,  2 }, {     28,    3,   10, 20, 54,  2 }, {     29,    2,    9, 20, 54,  2 }, {     30,    1,    9, 20, 54,  2 },
    {     31,    0,    8, 20, 54,  2 }, {     32,   -1,    8, 20, 54,  2 }, {     33,   -2,    7, 20, 54,  2 }, {     34,   -3,    7, 20, 54,  2 }, {     35,   -4,    6, 20, 54,  2 },
    {     36,   -5,    6, 20, 54,  2 }, {     37,   -6,    5, 20, 54,  2 }, {     38,   -7,    5, 20, 54,  2 }, {     39,   -8,    4, 20, 54,  2 }, {     40,   -9,    4, 20, 54,  2 },
    {     41,  -10,    3, 20, 54,  2 }, {     42,  -11,    3, 20, 54,  2 }, {     43,  -12,    2, 20, 54,  2 }, {     44,  -13,    2, 20, 54,  2 }, {     45,  -14,    1, 20, 54,  2 },
    {     46,  -15,    1, 20, 54,  2 }, {     47,  -16,    0, 20, 54,  2 }, {     48,  -17,    0, 20, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25LeftBanked3, {
    {     15,   15,   15, 28, 54,  2 }, {     14,   14,   15, 28, 54,  2 }, {     13,   13,   14, 28, 54,  2 }, {     12,   12,   14, 28, 54,  2 }, {     11,   11,   13, 28, 54,  2 },
    {     10,   10,   13, 28, 54,  2 }, {      9,    9,   12, 28, 54,  2 }, {      8,    8,   12, 28, 54,  2 }, {      7,    7,   11, 28, 54,  2 }, {      6,    6,   11, 28, 54,  2 },
    {      5,    5,   10, 28, 54,  2 }, {      4,    4,   10, 28, 54,  2 }, {      3,    3,    9, 28, 54,  2 }, {      2,    2,    9, 28, 54,  2 }, {      1,    1,    8, 28, 54,  2 },
    {      0,    0,    8, 28, 54,  2 }, {     -1,   -1,    7, 28, 54,  2 }, {     -2,   -2,    7, 28, 54,  2 }, {     -3,   -3,    6, 28, 54,  2 }, {     -4,   -4,    6, 28, 54,  2 },
    {     -5,   -5,    5, 28, 54,  2 }, {     -6,   -6,    5, 28, 54,  2 }, {     -7,   -7,    4, 28, 54,  2 }, {     -8,   -8,    4, 28, 54,  2 }, {     -9,   -9,    3, 28, 54,  2 },
    {    -10,  -10,    3, 28, 54,  2 }, {    -11,  -11,    2, 28, 54,  2 }, {    -12,  -12,    2, 28, 54,  2 }, {    -13,  -13,    1, 28, 54,  2 }, {    -14,  -14,    1, 28, 54,  2 },
    {    -15,  -15,    0, 28, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25RightBanked0, {
    {     15,   16,   15,  4, 54,  4 }, {     14,   17,   15,  4, 54,  4 }, {     13,   18,   14,  4, 54,  4 }, {     12,   19,   14,  4, 54,  4 }, {     11,   20,   13,  4, 54,  4 },
    {     10,   21,   13,  4, 54,  4 }, {      9,   22,   12,  4, 54,  4 }, {      8,   23,   12,  4, 54,  4 }, {      7,   24,   11,  4, 54,  4 }, {      6,   25,   11,  4, 54,  4 },
    {      5,   26,   10,  4, 54,  4 }, {      4,   27,   10,  4, 54,  4 }, {      3,   28,    9,  4, 54,  4 }, {      2,   29,    9,  4, 54,  4 }, {      1,   30,    8,  4, 54,  4 },
    {      0,   31,    8,  4, 54,  4 }, {     -1,   32,    7,  4, 54,  4 }, {     -2,   33,    7,  4, 54,  4 }, {     -3,   34,    6,  4, 54,  4 }, {     -4,   35,    6,  4, 54,  4 },
    {     -5,   36,    5,  4, 54,  4 }, {     -6,   37,    5,  4, 54,  4 }, {     -7,   38,    4,  4, 54,  4 }, {     -8,   39,    4,  4, 54,  4 }, {     -9,   40,    3,  4, 54,  4 },
    {    -10,   41,    3,  4, 54,  4 }, {    -11,   42,    2,  4, 54,  4 }, {    -12,   43,    2,  4, 54,  4 }, {    -13,   44,    1,  4, 54,  4 }, {    -14,   45,    1,  4, 54,  4 },
    {    -15,   46,    0,  4, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25RightBanked1, {
    {     16,   16,   16, 12, 54,  4 }, {     17,   17,   15, 12, 54,  4 }, {     18,   18,   15, 12, 54,  4 }, {     19,   19,   14, 12, 54,  4 }, {     20,   20,   14, 12, 54,  4 },
    {     21,   21,   13, 12, 54,  4 }, {     22,   22,   13, 12, 54,  4 }, {     23,   23,   12, 12, 54,  4 }, {     24,   24,   12, 12, 54,  4 }, {     25,   25,   11, 12, 54,  4 },
    {     26,   26,   11, 12, 54,  4 }, {     27,   27,   10, 12, 54,  4 }, {     28,   28,   10, 12, 54,  4 }, {     29,   29,    9, 12, 54,  4 }, {     30,   30,    9, 12, 54,  4 },
    {     31,   31,    8, 12, 54,  4 }, {     32,   32,    8, 12, 54,  4 }, {     33,   33,    7, 12, 54,  4 }, {     34,   34,    7, 12, 54,  4 }, {     35,   35,    6, 12, 54,  4 },
    {     36,   36,    6, 12, 54,  4 }, {     37,   37,    5, 12, 54,  4 }, {     38,   38,    5, 12, 54,  4 }, {     39,   39,    4, 12, 54,  4 }, {     40,   40,    4, 12, 54,  4 },
    {     41,   41,    3, 12, 54,  4 }, {     42,   42,    3, 12, 54,  4 }, {     43,   43,    2, 12, 54,  4 }, {     44,   44,    2, 12, 54,  4 }, {     45,   45,    1, 12, 54,  4 },
    {     46,   46,    1, 12, 54,  4 }, {     47,   47,    0, 12, 54,  4 }, {     48,   48,    0, 12, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25RightBanked2, {
    {     16,   15,   16, 20, 54,  4 }, {     17,   14,   15, 20, 54,  4 }, {     18,   13,   15, 20, 54,  4 }, {     19,   12,   14, 20, 54,  4 }, {     20,   11,   14, 20, 54,  4 },
    {     21,   10,   13, 20, 54,  4 }, {     22,    9,   13, 20, 54,  4 }, {     23,    8,   12, 20, 54,  4 }, {     24,    7,   12, 20, 54,  4 }, {     25,    6,   11, 20, 54,  4 },
    {     26,    5,   11, 20, 54,  4 }, {     27,    4,   10, 20, 54,  4 }, {     28,    3,   10, 20, 54,  4 }, {     29,    2,    9, 20, 54,  4 }, {     30,    1,    9, 20, 54,  4 },
    {     31,    0,    8, 20, 54,  4 }, {     32,   -1,    8, 20, 54,  4 }, {     33,   -2,    7, 20, 54,  4 }, {     34,   -3,    7, 20, 54,  4 }, {     35,   -4,    6, 20, 54,  4 },
    {     36,   -5,    6, 20, 54,  4 }, {     37,   -6,    5, 20, 54,  4 }, {     38,   -7,    5, 20, 54,  4 }, {     39,   -8,    4, 20, 54,  4 }, {     40,   -9,    4, 20, 54,  4 },
    {     41,  -10,    3, 20, 54,  4 }, {     42,  -11,    3, 20, 54,  4 }, {     43,  -12,    2, 20, 54,  4 }, {     44,  -13,    2, 20, 54,  4 }, {     45,  -14,    1, 20, 54,  4 },
    {     46,  -15,    1, 20, 54,  4 }, {     47,  -16,    0, 20, 54,  4 }, {     48,  -17,    0, 20, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown25RightBanked3, {
    {     15,   15,   15, 28, 54,  4 }, {     14,   14,   15, 28, 54,  4 }, {     13,   13,   14, 28, 54,  4 }, {     12,   12,   14, 28, 54,  4 }, {     11,   11,   13, 28, 54,  4 },
    {     10,   10,   13, 28, 54,  4 }, {      9,    9,   12, 28, 54,  4 }, {      8,    8,   12, 28, 54,  4 }, {      7,    7,   11, 28, 54,  4 }, {      6,    6,   11, 28, 54,  4 },
    {      5,    5,   10, 28, 54,  4 }, {      4,    4,   10, 28, 54,  4 }, {      3,    3,    9, 28, 54,  4 }, {      2,    2,    9, 28, 54,  4 }, {      1,    1,    8, 28, 54,  4 },
    {      0,    0,    8, 28, 54,  4 }, {     -1,   -1,    7, 28, 54,  4 }, {     -2,   -2,    7, 28, 54,  4 }, {     -3,   -3,    6, 28, 54,  4 }, {     -4,   -4,    6, 28, 54,  4 },
    {     -5,   -5,    5, 28, 54,  4 }, {     -6,   -6,    5, 28, 54,  4 }, {     -7,   -7,    4, 28, 54,  4 }, {     -8,   -8,    4, 28, 54,  4 }, {     -9,   -9,    3, 28, 54,  4 },
    {    -10,  -10,    3, 28, 54,  4 }, {    -11,  -11,    2, 28, 54,  4 }, {    -12,  -12,    2, 28, 54,  4 }, {    -13,  -13,    1, 28, 54,  4 }, {    -14,  -14,    1, 28, 54,  4 },
    {    -15,  -15,    0, 28, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToLeftBankedUp250, {
    {     15,   16,    0,  4,  0,  0 }, {     14,   17,    0,  4,  0,  0 }, {     13,   18,    0,  4,  0,  0 }, {     12,   19,    0,  4,  0,  0 }, {     11,   20,    0,  4,  0,  0 },
    {     10,   21,    0,  4,  0,  0 }, {      9,   22,    0,  4,  0,  0 }, {      8,   23,    1,  4, 50,  1 }, {      7,   24,    1,  4, 50,  1 }, {      6,   25,    1,  4, 50,  1 },
    {      5,   26,    1,  4, 50,  1 }, {      4,   27,    1,  4, 50,  1 }, {      3,   28,    1,  4, 50,  1 }, {      2,   29,    2,  4, 50,  1 }, {      1,   30,    2,  4, 50,  1 },
    {      0,   31,    2,  4, 50,  1 }, {     -1,   32,    2,  4, 50,  1 }, {     -2,   33,    3,  4, 50,  1 }, {     -3,   34,    3,  4,  1,  1 }, {     -4,   35,    3,  4,  1,  1 },
    {     -5,   36,    4,  4,  1,  1 }, {     -6,   37,    4,  4,  1,  1 }, {     -7,   38,    4,  4,  1,  1 }, {     -8,   39,    5,  4, 51,  2 }, {     -9,   40,    5,  4, 51,  2 },
    {    -10,   41,    5,  4, 51,  2 }, {    -11,   42,    6,  4, 51,  2 }, {    -12,   43,    6,  4, 51,  2 }, {    -13,   44,    7,  4, 51,  2 }, {    -14,   45,    7,  4, 51,  2 },
    {    -15,   46,    8,  4, 51,  2 }, {    -16,   47,    8,  4, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToLeftBankedUp251, {
    {     16,   16,    0, 12,  0,  0 }, {     17,   17,    0, 12,  0,  0 }, {     18,   18,    0, 12,  0,  0 }, {     19,   19,    0, 12,  0,  0 }, {     20,   20,    0, 12,  0,  0 },
    {     21,   21,    0, 12,  0,  0 }, {     22,   22,    0, 12,  0,  0 }, {     23,   23,    0, 12,  0,  0 }, {     24,   24,    1, 12, 50,  1 }, {     25,   25,    1, 12, 50,  1 },
    {     26,   26,    1, 12, 50,  1 }, {     27,   27,    1, 12, 50,  1 }, {     28,   28,    1, 12, 50,  1 }, {     29,   29,    1, 12, 50,  1 }, {     30,   30,    2, 12, 50,  1 },
    {     31,   31,    2, 12, 50,  1 }, {     32,   32,    2, 12, 50,  1 }, {     33,   33,    2, 12, 50,  1 }, {     34,   34,    3, 12, 50,  1 }, {     35,   35,    3, 12,  1,  1 },
    {     36,   36,    3, 12,  1,  1 }, {     37,   37,    4, 12,  1,  1 }, {     38,   38,    4, 12,  1,  1 }, {     39,   39,    4, 12,  1,  1 }, {     40,   40,    5, 12, 51,  2 },
    {     41,   41,    5, 12, 51,  2 }, {     42,   42,    5, 12, 51,  2 }, {     43,   43,    6, 12, 51,  2 }, {     44,   44,    6, 12, 51,  2 }, {     45,   45,    7, 12, 51,  2 },
    {     46,   46,    7, 12, 51,  2 }, {     47,   47,    8, 12, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToLeftBankedUp252, {
    {     16,   15,    0, 20,  0,  0 }, {     17,   14,    0, 20,  0,  0 }, {     18,   13,    0, 20,  0,  0 }, {     19,   12,    0, 20,  0,  0 }, {     20,   11,    0, 20,  0,  0 },
    {     21,   10,    0, 20,  0,  0 }, {     22,    9,    0, 20,  0,  0 }, {     23,    8,    0, 20,  0,  0 }, {     24,    7,    1, 20, 50,  1 }, {     25,    6,    1, 20, 50,  1 },
    {     26,    5,    1, 20, 50,  1 }, {     27,    4,    1, 20, 50,  1 }, {     28,    3,    1, 20, 50,  1 }, {     29,    2,    1, 20, 50,  1 }, {     30,    1,    2, 20, 50,  1 },
    {     31,    0,    2, 20, 50,  1 }, {     32,   -1,    2, 20, 50,  1 }, {     33,   -2,    2, 20, 50,  1 }, {     34,   -3,    3, 20, 50,  1 }, {     35,   -4,    3, 20,  1,  1 },
    {     36,   -5,    3, 20,  1,  1 }, {     37,   -6,    4, 20,  1,  1 }, {     38,   -7,    4, 20,  1,  1 }, {     39,   -8,    4, 20,  1,  1 }, {     40,   -9,    5, 20, 51,  2 },
    {     41,  -10,    5, 20, 51,  2 }, {     42,  -11,    5, 20, 51,  2 }, {     43,  -12,    6, 20, 51,  2 }, {     44,  -13,    6, 20, 51,  2 }, {     45,  -14,    7, 20, 51,  2 },
    {     46,  -15,    7, 20, 51,  2 }, {     47,  -16,    8, 20, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToLeftBankedUp253, {
    {     15,   15,    0, 28,  0,  0 }, {     14,   14,    0, 28,  0,  0 }, {     13,   13,    0, 28,  0,  0 }, {     12,   12,    0, 28,  0,  0 }, {     11,   11,    0, 28,  0,  0 },
    {     10,   10,    0, 28,  0,  0 }, {      9,    9,    0, 28,  0,  0 }, {      8,    8,    1, 28, 50,  1 }, {      7,    7,    1, 28, 50,  1 }, {      6,    6,    1, 28, 50,  1 },
    {      5,    5,    1, 28, 50,  1 }, {      4,    4,    1, 28, 50,  1 }, {      3,    3,    1, 28, 50,  1 }, {      2,    2,    2, 28, 50,  1 }, {      1,    1,    2, 28, 50,  1 },
    {      0,    0,    2, 28, 50,  1 }, {     -1,   -1,    2, 28, 50,  1 }, {     -2,   -2,    3, 28, 50,  1 }, {     -3,   -3,    3, 28,  1,  1 }, {     -4,   -4,    3, 28,  1,  1 },
    {     -5,   -5,    4, 28,  1,  1 }, {     -6,   -6,    4, 28,  1,  1 }, {     -7,   -7,    4, 28,  1,  1 }, {     -8,   -8,    5, 28, 51,  2 }, {     -9,   -9,    5, 28, 51,  2 },
    {    -10,  -10,    5, 28, 51,  2 }, {    -11,  -11,    6, 28, 51,  2 }, {    -12,  -12,    6, 28, 51,  2 }, {    -13,  -13,    7, 28, 51,  2 }, {    -14,  -14,    7, 28, 51,  2 },
    {    -15,  -15,    8, 28, 51,  2 }, {    -16,  -16,    8, 28, 51,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToRightBankedUp250, {
    {     15,   16,    0,  4,  0,  0 }, {     14,   17,    0,  4,  0,  0 }, {     13,   18,    0,  4,  0,  0 }, {     12,   19,    0,  4,  0,  0 }, {     11,   20,    0,  4,  0,  0 },
    {     10,   21,    0,  4,  0,  0 }, {      9,   22,    0,  4,  0,  0 }, {      8,   23,    1,  4, 50,  3 }, {      7,   24,    1,  4, 50,  3 }, {      6,   25,    1,  4, 50,  3 },
    {      5,   26,    1,  4, 50,  3 }, {      4,   27,    1,  4, 50,  3 }, {      3,   28,    1,  4, 50,  3 }, {      2,   29,    2,  4, 50,  3 }, {      1,   30,    2,  4, 50,  3 },
    {      0,   31,    2,  4, 50,  3 }, {     -1,   32,    2,  4, 50,  3 }, {     -2,   33,    3,  4, 50,  3 }, {     -3,   34,    3,  4,  1,  3 }, {     -4,   35,    3,  4,  1,  3 },
    {     -5,   36,    4,  4,  1,  3 }, {     -6,   37,    4,  4,  1,  3 }, {     -7,   38,    4,  4,  1,  3 }, {     -8,   39,    5,  4, 51,  4 }, {     -9,   40,    5,  4, 51,  4 },
    {    -10,   41,    5,  4, 51,  4 }, {    -11,   42,    6,  4, 51,  4 }, {    -12,   43,    6,  4, 51,  4 }, {    -13,   44,    7,  4, 51,  4 }, {    -14,   45,    7,  4, 51,  4 },
    {    -15,   46,    8,  4, 51,  4 }, {    -16,   47,    8,  4, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToRightBankedUp251, {
    {     16,   16,    0, 12,  0,  0 }, {     17,   17,    0, 12,  0,  0 }, {     18,   18,    0, 12,  0,  0 }, {     19,   19,    0, 12,  0,  0 }, {     20,   20,    0, 12,  0,  0 },
    {     21,   21,    0, 12,  0,  0 }, {     22,   22,    0, 12,  0,  0 }, {     23,   23,    0, 12,  0,  0 }, {     24,   24,    1, 12, 50,  3 }, {     25,   25,    1, 12, 50,  3 },
    {     26,   26,    1, 12, 50,  3 }, {     27,   27,    1, 12, 50,  3 }, {     28,   28,    1, 12, 50,  3 }, {     29,   29,    1, 12, 50,  3 }, {     30,   30,    2, 12, 50,  3 },
    {     31,   31,    2, 12, 50,  3 }, {     32,   32,    2, 12, 50,  3 }, {     33,   33,    2, 12, 50,  3 }, {     34,   34,    3, 12, 50,  3 }, {     35,   35,    3, 12,  1,  3 },
    {     36,   36,    3, 12,  1,  3 }, {     37,   37,    4, 12,  1,  3 }, {     38,   38,    4, 12,  1,  3 }, {     39,   39,    4, 12,  1,  3 }, {     40,   40,    5, 12, 51,  4 },
    {     41,   41,    5, 12, 51,  4 }, {     42,   42,    5, 12, 51,  4 }, {     43,   43,    6, 12, 51,  4 }, {     44,   44,    6, 12, 51,  4 }, {     45,   45,    7, 12, 51,  4 },
    {     46,   46,    7, 12, 51,  4 }, {     47,   47,    8, 12, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToRightBankedUp252, {
    {     16,   15,    0, 20,  0,  0 }, {     17,   14,    0, 20,  0,  0 }, {     18,   13,    0, 20,  0,  0 }, {     19,   12,    0, 20,  0,  0 }, {     20,   11,    0, 20,  0,  0 },
    {     21,   10,    0, 20,  0,  0 }, {     22,    9,    0, 20,  0,  0 }, {     23,    8,    0, 20,  0,  0 }, {     24,    7,    1, 20, 50,  3 }, {     25,    6,    1, 20, 50,  3 },
    {     26,    5,    1, 20, 50,  3 }, {     27,    4,    1, 20, 50,  3 }, {     28,    3,    1, 20, 50,  3 }, {     29,    2,    1, 20, 50,  3 }, {     30,    1,    2, 20, 50,  3 },
    {     31,    0,    2, 20, 50,  3 }, {     32,   -1,    2, 20, 50,  3 }, {     33,   -2,    2, 20, 50,  3 }, {     34,   -3,    3, 20, 50,  3 }, {     35,   -4,    3, 20,  1,  3 },
    {     36,   -5,    3, 20,  1,  3 }, {     37,   -6,    4, 20,  1,  3 }, {     38,   -7,    4, 20,  1,  3 }, {     39,   -8,    4, 20,  1,  3 }, {     40,   -9,    5, 20, 51,  4 },
    {     41,  -10,    5, 20, 51,  4 }, {     42,  -11,    5, 20, 51,  4 }, {     43,  -12,    6, 20, 51,  4 }, {     44,  -13,    6, 20, 51,  4 }, {     45,  -14,    7, 20, 51,  4 },
    {     46,  -15,    7, 20, 51,  4 }, {     47,  -16,    8, 20, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToRightBankedUp253, {
    {     15,   15,    0, 28,  0,  0 }, {     14,   14,    0, 28,  0,  0 }, {     13,   13,    0, 28,  0,  0 }, {     12,   12,    0, 28,  0,  0 }, {     11,   11,    0, 28,  0,  0 },
    {     10,   10,    0, 28,  0,  0 }, {      9,    9,    0, 28,  0,  0 }, {      8,    8,    1, 28, 50,  3 }, {      7,    7,    1, 28, 50,  3 }, {      6,    6,    1, 28, 50,  3 },
    {      5,    5,    1, 28, 50,  3 }, {      4,    4,    1, 28, 50,  3 }, {      3,    3,    1, 28, 50,  3 }, {      2,    2,    2, 28, 50,  3 }, {      1,    1,    2, 28, 50,  3 },
    {      0,    0,    2, 28, 50,  3 }, {     -1,   -1,    2, 28, 50,  3 }, {     -2,   -2,    3, 28, 50,  3 }, {     -3,   -3,    3, 28,  1,  3 }, {     -4,   -4,    3, 28,  1,  3 },
    {     -5,   -5,    4, 28,  1,  3 }, {     -6,   -6,    4, 28,  1,  3 }, {     -7,   -7,    4, 28,  1,  3 }, {     -8,   -8,    5, 28, 51,  4 }, {     -9,   -9,    5, 28, 51,  4 },
    {    -10,  -10,    5, 28, 51,  4 }, {    -11,  -11,    6, 28, 51,  4 }, {    -12,  -12,    6, 28, 51,  4 }, {    -13,  -13,    7, 28, 51,  4 }, {    -14,  -14,    7, 28, 51,  4 },
    {    -15,  -15,    8, 28, 51,  4 }, {    -16,  -16,    8, 28, 51,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedUp25ToFlat0, {
    {     15,   16,    1,  4, 51,  2 }, {     14,   17,    1,  4, 51,  2 }, {     13,   18,    2,  4, 51,  2 }, {     12,   19,    2,  4, 51,  2 }, {     11,   20,    2,  4, 51,  2 },
    {     10,   21,    3,  4, 51,  2 }, {      9,   22,    3,  4, 51,  2 }, {      8,   23,    4,  4,  1,  1 }, {      7,   24,    4,  4,  1,  1 }, {      6,   25,    4,  4,  1,  1 },
    {      5,   26,    5,  4,  1,  1 }, {      4,   27,    5,  4,  1,  1 }, {      3,   28,    5,  4, 50,  1 }, {      2,   29,    6,  4, 50,  1 }, {      1,   30,    6,  4, 50,  1 },
    {      0,   31,    6,  4, 50,  1 }, {     -1,   32,    6,  4, 50,  1 }, {     -2,   33,    7,  4, 50,  1 }, {     -3,   34,    7,  4, 50,  1 }, {     -4,   35,    7,  4, 50,  1 },
    {     -5,   36,    7,  4, 50,  1 }, {     -6,   37,    7,  4, 50,  1 }, {     -7,   38,    7,  4, 50,  1 }, {     -8,   39,    8,  4,  0,  0 }, {     -9,   40,    8,  4,  0,  0 },
    {    -10,   41,    8,  4,  0,  0 }, {    -11,   42,    8,  4,  0,  0 }, {    -12,   43,    8,  4,  0,  0 }, {    -13,   44,    8,  4,  0,  0 }, {    -14,   45,    8,  4,  0,  0 },
    {    -15,   46,    8,  4,  0,  0 }, {    -16,   47,    8,  4,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedUp25ToFlat1, {
    {     16,   16,    0, 12, 51,  2 }, {     17,   17,    1, 12, 51,  2 }, {     18,   18,    1, 12, 51,  2 }, {     19,   19,    2, 12, 51,  2 }, {     20,   20,    2, 12, 51,  2 },
    {     21,   21,    2, 12, 51,  2 }, {     22,   22,    3, 12, 51,  2 }, {     23,   23,    3, 12, 51,  2 }, {     24,   24,    4, 12,  1,  1 }, {     25,   25,    4, 12,  1,  1 },
    {     26,   26,    4, 12,  1,  1 }, {     27,   27,    5, 12,  1,  1 }, {     28,   28,    5, 12,  1,  1 }, {     29,   29,    5, 12, 50,  1 }, {     30,   30,    6, 12, 50,  1 },
    {     31,   31,    6, 12, 50,  1 }, {     32,   32,    6, 12, 50,  1 }, {     33,   33,    6, 12, 50,  1 }, {     34,   34,    7, 12, 50,  1 }, {     35,   35,    7, 12, 50,  1 },
    {     36,   36,    7, 12, 50,  1 }, {     37,   37,    7, 12, 50,  1 }, {     38,   38,    7, 12, 50,  1 }, {     39,   39,    7, 12, 50,  1 }, {     40,   40,    8, 12,  0,  0 },
    {     41,   41,    8, 12,  0,  0 }, {     42,   42,    8, 12,  0,  0 }, {     43,   43,    8, 12,  0,  0 }, {     44,   44,    8, 12,  0,  0 }, {     45,   45,    8, 12,  0,  0 },
    {     46,   46,    8, 12,  0,  0 }, {     47,   47,    8, 12,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedUp25ToFlat2, {
    {     16,   15,    0, 20, 51,  2 }, {     17,   14,    1, 20, 51,  2 }, {     18,   13,    1, 20, 51,  2 }, {     19,   12,    2, 20, 51,  2 }, {     20,   11,    2, 20, 51,  2 },
    {     21,   10,    2, 20, 51,  2 }, {     22,    9,    3, 20, 51,  2 }, {     23,    8,    3, 20, 51,  2 }, {     24,    7,    4, 20,  1,  1 }, {     25,    6,    4, 20,  1,  1 },
    {     26,    5,    4, 20,  1,  1 }, {     27,    4,    5, 20,  1,  1 }, {     28,    3,    5, 20,  1,  1 }, {     29,    2,    5, 20, 50,  1 }, {     30,    1,    6, 20, 50,  1 },
    {     31,    0,    6, 20, 50,  1 }, {     32,   -1,    6, 20, 50,  1 }, {     33,   -2,    6, 20, 50,  1 }, {     34,   -3,    7, 20, 50,  1 }, {     35,   -4,    7, 20, 50,  1 },
    {     36,   -5,    7, 20, 50,  1 }, {     37,   -6,    7, 20, 50,  1 }, {     38,   -7,    7, 20, 50,  1 }, {     39,   -8,    7, 20, 50,  1 }, {     40,   -9,    8, 20,  0,  0 },
    {     41,  -10,    8, 20,  0,  0 }, {     42,  -11,    8, 20,  0,  0 }, {     43,  -12,    8, 20,  0,  0 }, {     44,  -13,    8, 20,  0,  0 }, {     45,  -14,    8, 20,  0,  0 },
    {     46,  -15,    8, 20,  0,  0 }, {     47,  -16,    8, 20,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedUp25ToFlat3, {
    {     15,   15,    1, 28, 51,  2 }, {     14,   14,    1, 28, 51,  2 }, {     13,   13,    2, 28, 51,  2 }, {     12,   12,    2, 28, 51,  2 }, {     11,   11,    2, 28, 51,  2 },
    {     10,   10,    3, 28, 51,  2 }, {      9,    9,    3, 28, 51,  2 }, {      8,    8,    4, 28,  1,  1 }, {      7,    7,    4, 28,  1,  1 }, {      6,    6,    4, 28,  1,  1 },
    {      5,    5,    5, 28,  1,  1 }, {      4,    4,    5, 28,  1,  1 }, {      3,    3,    5, 28, 50,  1 }, {      2,    2,    6, 28, 50,  1 }, {      1,    1,    6, 28, 50,  1 },
    {      0,    0,    6, 28, 50,  1 }, {     -1,   -1,    6, 28, 50,  1 }, {     -2,   -2,    7, 28, 50,  1 }, {     -3,   -3,    7, 28, 50,  1 }, {     -4,   -4,    7, 28, 50,  1 },
    {     -5,   -5,    7, 28, 50,  1 }, {     -6,   -6,    7, 28, 50,  1 }, {     -7,   -7,    7, 28, 50,  1 }, {     -8,   -8,    8, 28,  0,  0 }, {     -9,   -9,    8, 28,  0,  0 },
    {    -10,  -10,    8, 28,  0,  0 }, {    -11,  -11,    8, 28,  0,  0 }, {    -12,  -12,    8, 28,  0,  0 }, {    -13,  -13,    8, 28,  0,  0 }, {    -14,  -14,    8, 28,  0,  0 },
    {    -15,  -15,    8, 28,  0,  0 }, {    -16,  -16,    8, 28,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedUp25ToFlat0, {
    {     15,   16,    1,  4, 51,  4 }, {     14,   17,    1,  4, 51,  4 }, {     13,   18,    2,  4, 51,  4 }, {     12,   19,    2,  4, 51,  4 }, {     11,   20,    2,  4, 51,  4 },
    {     10,   21,    3,  4, 51,  4 }, {      9,   22,    3,  4, 51,  4 }, {      8,   23,    4,  4,  1,  3 }, {      7,   24,    4,  4,  1,  3 }, {      6,   25,    4,  4,  1,  3 },
    {      5,   26,    5,  4,  1,  3 }, {      4,   27,    5,  4,  1,  3 }, {      3,   28,    5,  4, 50,  3 }, {      2,   29,    6,  4, 50,  3 }, {      1,   30,    6,  4, 50,  3 },
    {      0,   31,    6,  4, 50,  3 }, {     -1,   32,    6,  4, 50,  3 }, {     -2,   33,    7,  4, 50,  3 }, {     -3,   34,    7,  4, 50,  3 }, {     -4,   35,    7,  4, 50,  3 },
    {     -5,   36,    7,  4, 50,  3 }, {     -6,   37,    7,  4, 50,  3 }, {     -7,   38,    7,  4, 50,  3 }, {     -8,   39,    8,  4,  0,  0 }, {     -9,   40,    8,  4,  0,  0 },
    {    -10,   41,    8,  4,  0,  0 }, {    -11,   42,    8,  4,  0,  0 }, {    -12,   43,    8,  4,  0,  0 }, {    -13,   44,    8,  4,  0,  0 }, {    -14,   45,    8,  4,  0,  0 },
    {    -15,   46,    8,  4,  0,  0 }, {    -16,   47,    8,  4,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedUp25ToFlat1, {
    {     16,   16,    0, 12, 51,  4 }, {     17,   17,    1, 12, 51,  4 }, {     18,   18,    1, 12, 51,  4 }, {     19,   19,    2, 12, 51,  4 }, {     20,   20,    2, 12, 51,  4 },
    {     21,   21,    2, 12, 51,  4 }, {     22,   22,    3, 12, 51,  4 }, {     23,   23,    3, 12, 51,  4 }, {     24,   24,    4, 12,  1,  3 }, {     25,   25,    4, 12,  1,  3 },
    {     26,   26,    4, 12,  1,  3 }, {     27,   27,    5, 12,  1,  3 }, {     28,   28,    5, 12,  1,  3 }, {     29,   29,    5, 12, 50,  3 }, {     30,   30,    6, 12, 50,  3 },
    {     31,   31,    6, 12, 50,  3 }, {     32,   32,    6, 12, 50,  3 }, {     33,   33,    6, 12, 50,  3 }, {     34,   34,    7, 12, 50,  3 }, {     35,   35,    7, 12, 50,  3 },
    {     36,   36,    7, 12, 50,  3 }, {     37,   37,    7, 12, 50,  3 }, {     38,   38,    7, 12, 50,  3 }, {     39,   39,    7, 12, 50,  3 }, {     40,   40,    8, 12,  0,  0 },
    {     41,   41,    8, 12,  0,  0 }, {     42,   42,    8, 12,  0,  0 }, {     43,   43,    8, 12,  0,  0 }, {     44,   44,    8, 12,  0,  0 }, {     45,   45,    8, 12,  0,  0 },
    {     46,   46,    8, 12,  0,  0 }, {     47,   47,    8, 12,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedUp25ToFlat2, {
    {     16,   15,    0, 20, 51,  4 }, {     17,   14,    1, 20, 51,  4 }, {     18,   13,    1, 20, 51,  4 }, {     19,   12,    2, 20, 51,  4 }, {     20,   11,    2, 20, 51,  4 },
    {     21,   10,    2, 20, 51,  4 }, {     22,    9,    3, 20, 51,  4 }, {     23,    8,    3, 20, 51,  4 }, {     24,    7,    4, 20,  1,  3 }, {     25,    6,    4, 20,  1,  3 },
    {     26,    5,    4, 20,  1,  3 }, {     27,    4,    5, 20,  1,  3 }, {     28,    3,    5, 20,  1,  3 }, {     29,    2,    5, 20, 50,  3 }, {     30,    1,    6, 20, 50,  3 },
    {     31,    0,    6, 20, 50,  3 }, {     32,   -1,    6, 20, 50,  3 }, {     33,   -2,    6, 20, 50,  3 }, {     34,   -3,    7, 20, 50,  3 }, {     35,   -4,    7, 20, 50,  3 },
    {     36,   -5,    7, 20, 50,  3 }, {     37,   -6,    7, 20, 50,  3 }, {     38,   -7,    7, 20, 50,  3 }, {     39,   -8,    7, 20, 50,  3 }, {     40,   -9,    8, 20,  0,  0 },
    {     41,  -10,    8, 20,  0,  0 }, {     42,  -11,    8, 20,  0,  0 }, {     43,  -12,    8, 20,  0,  0 }, {     44,  -13,    8, 20,  0,  0 }, {     45,  -14,    8, 20,  0,  0 },
    {     46,  -15,    8, 20,  0,  0 }, {     47,  -16,    8, 20,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedUp25ToFlat3, {
    {     15,   15,    1, 28, 51,  4 }, {     14,   14,    1, 28, 51,  4 }, {     13,   13,    2, 28, 51,  4 }, {     12,   12,    2, 28, 51,  4 }, {     11,   11,    2, 28, 51,  4 },
    {     10,   10,    3, 28, 51,  4 }, {      9,    9,    3, 28, 51,  4 }, {      8,    8,    4, 28,  1,  3 }, {      7,    7,    4, 28,  1,  3 }, {      6,    6,    4, 28,  1,  3 },
    {      5,    5,    5, 28,  1,  3 }, {      4,    4,    5, 28,  1,  3 }, {      3,    3,    5, 28, 50,  3 }, {      2,    2,    6, 28, 50,  3 }, {      1,    1,    6, 28, 50,  3 },
    {      0,    0,    6, 28, 50,  3 }, {     -1,   -1,    6, 28, 50,  3 }, {     -2,   -2,    7, 28, 50,  3 }, {     -3,   -3,    7, 28, 50,  3 }, {     -4,   -4,    7, 28, 50,  3 },
    {     -5,   -5,    7, 28, 50,  3 }, {     -6,   -6,    7, 28, 50,  3 }, {     -7,   -7,    7, 28, 50,  3 }, {     -8,   -8,    8, 28,  0,  0 }, {     -9,   -9,    8, 28,  0,  0 },
    {    -10,  -10,    8, 28,  0,  0 }, {    -11,  -11,    8, 28,  0,  0 }, {    -12,  -12,    8, 28,  0,  0 }, {    -13,  -13,    8, 28,  0,  0 }, {    -14,  -14,    8, 28,  0,  0 },
    {    -15,  -15,    8, 28,  0,  0 }, {    -16,  -16,    8, 28,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToLeftBankedDown250, {
    {     15,   16,    8,  4,  0,  0 }, {     14,   17,    8,  4,  0,  0 }, {     13,   18,    8,  4,  0,  0 }, {     12,   19,    8,  4,  0,  0 }, {     11,   20,    8,  4,  0,  0 },
    {     10,   21,    8,  4,  0,  0 }, {      9,   22,    8,  4,  0,  0 }, {      8,   23,    7,  4, 53,  1 }, {      7,   24,    7,  4, 53,  1 }, {      6,   25,    7,  4, 53,  1 },
    {      5,   26,    7,  4, 53,  1 }, {      4,   27,    7,  4, 53,  1 }, {      3,   28,    7,  4, 53,  1 }, {      2,   29,    6,  4, 53,  1 }, {      1,   30,    6,  4, 53,  1 },
    {      0,   31,    6,  4, 53,  1 }, {     -1,   32,    6,  4, 53,  1 }, {     -2,   33,    5,  4, 53,  1 }, {     -3,   34,    5,  4,  5,  1 }, {     -4,   35,    5,  4,  5,  1 },
    {     -5,   36,    4,  4,  5,  1 }, {     -6,   37,    4,  4,  5,  1 }, {     -7,   38,    4,  4,  5,  1 }, {     -8,   39,    3,  4, 54,  2 }, {     -9,   40,    3,  4, 54,  2 },
    {    -10,   41,    3,  4, 54,  2 }, {    -11,   42,    2,  4, 54,  2 }, {    -12,   43,    2,  4, 54,  2 }, {    -13,   44,    1,  4, 54,  2 }, {    -14,   45,    1,  4, 54,  2 },
    {    -15,   46,    0,  4, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToLeftBankedDown251, {
    {     16,   16,    8, 12,  0,  0 }, {     17,   17,    8, 12,  0,  0 }, {     18,   18,    8, 12,  0,  0 }, {     19,   19,    8, 12,  0,  0 }, {     20,   20,    8, 12,  0,  0 },
    {     21,   21,    8, 12,  0,  0 }, {     22,   22,    8, 12,  0,  0 }, {     23,   23,    8, 12,  0,  0 }, {     24,   24,    7, 12, 53,  1 }, {     25,   25,    7, 12, 53,  1 },
    {     26,   26,    7, 12, 53,  1 }, {     27,   27,    7, 12, 53,  1 }, {     28,   28,    7, 12, 53,  1 }, {     29,   29,    7, 12, 53,  1 }, {     30,   30,    6, 12, 53,  1 },
    {     31,   31,    6, 12, 53,  1 }, {     32,   32,    6, 12, 53,  1 }, {     33,   33,    6, 12, 53,  1 }, {     34,   34,    5, 12, 53,  1 }, {     35,   35,    5, 12,  5,  1 },
    {     36,   36,    5, 12,  5,  1 }, {     37,   37,    4, 12,  5,  1 }, {     38,   38,    4, 12,  5,  1 }, {     39,   39,    4, 12,  5,  1 }, {     40,   40,    3, 12, 54,  2 },
    {     41,   41,    3, 12, 54,  2 }, {     42,   42,    3, 12, 54,  2 }, {     43,   43,    2, 12, 54,  2 }, {     44,   44,    2, 12, 54,  2 }, {     45,   45,    1, 12, 54,  2 },
    {     46,   46,    1, 12, 54,  2 }, {     47,   47,    0, 12, 54,  2 }, {     48,   48,    0, 12, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToLeftBankedDown252, {
    {     16,   15,    8, 20,  0,  0 }, {     17,   14,    8, 20,  0,  0 }, {     18,   13,    8, 20,  0,  0 }, {     19,   12,    8, 20,  0,  0 }, {     20,   11,    8, 20,  0,  0 },
    {     21,   10,    8, 20,  0,  0 }, {     22,    9,    8, 20,  0,  0 }, {     23,    8,    8, 20,  0,  0 }, {     24,    7,    7, 20, 53,  1 }, {     25,    6,    7, 20, 53,  1 },
    {     26,    5,    7, 20, 53,  1 }, {     27,    4,    7, 20, 53,  1 }, {     28,    3,    7, 20, 53,  1 }, {     29,    2,    7, 20, 53,  1 }, {     30,    1,    6, 20, 53,  1 },
    {     31,    0,    6, 20, 53,  1 }, {     32,   -1,    6, 20, 53,  1 }, {     33,   -2,    6, 20, 53,  1 }, {     34,   -3,    5, 20, 53,  1 }, {     35,   -4,    5, 20,  5,  1 },
    {     36,   -5,    5, 20,  5,  1 }, {     37,   -6,    4, 20,  5,  1 }, {     38,   -7,    4, 20,  5,  1 }, {     39,   -8,    4, 20,  5,  1 }, {     40,   -9,    3, 20, 54,  2 },
    {     41,  -10,    3, 20, 54,  2 }, {     42,  -11,    3, 20, 54,  2 }, {     43,  -12,    2, 20, 54,  2 }, {     44,  -13,    2, 20, 54,  2 }, {     45,  -14,    1, 20, 54,  2 },
    {     46,  -15,    1, 20, 54,  2 }, {     47,  -16,    0, 20, 54,  2 }, {     48,  -17,    0, 20, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToLeftBankedDown253, {
    {     15,   15,    8, 28,  0,  0 }, {     14,   14,    8, 28,  0,  0 }, {     13,   13,    8, 28,  0,  0 }, {     12,   12,    8, 28,  0,  0 }, {     11,   11,    8, 28,  0,  0 },
    {     10,   10,    8, 28,  0,  0 }, {      9,    9,    8, 28,  0,  0 }, {      8,    8,    7, 28, 53,  1 }, {      7,    7,    7, 28, 53,  1 }, {      6,    6,    7, 28, 53,  1 },
    {      5,    5,    7, 28, 53,  1 }, {      4,    4,    7, 28, 53,  1 }, {      3,    3,    7, 28, 53,  1 }, {      2,    2,    6, 28, 53,  1 }, {      1,    1,    6, 28, 53,  1 },
    {      0,    0,    6, 28, 53,  1 }, {     -1,   -1,    6, 28, 53,  1 }, {     -2,   -2,    5, 28, 53,  1 }, {     -3,   -3,    5, 28,  5,  1 }, {     -4,   -4,    5, 28,  5,  1 },
    {     -5,   -5,    4, 28,  5,  1 }, {     -6,   -6,    4, 28,  5,  1 }, {     -7,   -7,    4, 28,  5,  1 }, {     -8,   -8,    3, 28, 54,  2 }, {     -9,   -9,    3, 28, 54,  2 },
    {    -10,  -10,    3, 28, 54,  2 }, {    -11,  -11,    2, 28, 54,  2 }, {    -12,  -12,    2, 28, 54,  2 }, {    -13,  -13,    1, 28, 54,  2 }, {    -14,  -14,    1, 28, 54,  2 },
    {    -15,  -15,    0, 28, 54,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToRightBankedDown250, {
    {     15,   16,    8,  4,  0,  0 }, {     14,   17,    8,  4,  0,  0 }, {     13,   18,    8,  4,  0,  0 }, {     12,   19,    8,  4,  0,  0 }, {     11,   20,    8,  4,  0,  0 },
    {     10,   21,    8,  4,  0,  0 }, {      9,   22,    8,  4,  0,  0 }, {      8,   23,    7,  4, 53,  3 }, {      7,   24,    7,  4, 53,  3 }, {      6,   25,    7,  4, 53,  3 },
    {      5,   26,    7,  4, 53,  3 }, {      4,   27,    7,  4, 53,  3 }, {      3,   28,    7,  4, 53,  3 }, {      2,   29,    6,  4, 53,  3 }, {      1,   30,    6,  4, 53,  3 },
    {      0,   31,    6,  4, 53,  3 }, {     -1,   32,    6,  4, 53,  3 }, {     -2,   33,    5,  4, 53,  3 }, {     -3,   34,    5,  4,  5,  3 }, {     -4,   35,    5,  4,  5,  3 },
    {     -5,   36,    4,  4,  5,  3 }, {     -6,   37,    4,  4,  5,  3 }, {     -7,   38,    4,  4,  5,  3 }, {     -8,   39,    3,  4, 54,  4 }, {     -9,   40,    3,  4, 54,  4 },
    {    -10,   41,    3,  4, 54,  4 }, {    -11,   42,    2,  4, 54,  4 }, {    -12,   43,    2,  4, 54,  4 }, {    -13,   44,    1,  4, 54,  4 }, {    -14,   45,    1,  4, 54,  4 },
    {    -15,   46,    0,  4, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToRightBankedDown251, {
    {     16,   16,    8, 12,  0,  0 }, {     17,   17,    8, 12,  0,  0 }, {     18,   18,    8, 12,  0,  0 }, {     19,   19,    8, 12,  0,  0 }, {     20,   20,    8, 12,  0,  0 },
    {     21,   21,    8, 12,  0,  0 }, {     22,   22,    8, 12,  0,  0 }, {     23,   23,    8, 12,  0,  0 }, {     24,   24,    7, 12, 53,  3 }, {     25,   25,    7, 12, 53,  3 },
    {     26,   26,    7, 12, 53,  3 }, {     27,   27,    7, 12, 53,  3 }, {     28,   28,    7, 12, 53,  3 }, {     29,   29,    7, 12, 53,  3 }, {     30,   30,    6, 12, 53,  3 },
    {     31,   31,    6, 12, 53,  3 }, {     32,   32,    6, 12, 53,  3 }, {     33,   33,    6, 12, 53,  3 }, {     34,   34,    5, 12, 53,  3 }, {     35,   35,    5, 12,  5,  3 },
    {     36,   36,    5, 12,  5,  3 }, {     37,   37,    4, 12,  5,  3 }, {     38,   38,    4, 12,  5,  3 }, {     39,   39,    4, 12,  5,  3 }, {     40,   40,    3, 12, 54,  4 },
    {     41,   41,    3, 12, 54,  4 }, {     42,   42,    3, 12, 54,  4 }, {     43,   43,    2, 12, 54,  4 }, {     44,   44,    2, 12, 54,  4 }, {     45,   45,    1, 12, 54,  4 },
    {     46,   46,    1, 12, 54,  4 }, {     47,   47,    0, 12, 54,  4 }, {     48,   48,    0, 12, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToRightBankedDown252, {
    {     16,   15,    8, 20,  0,  0 }, {     17,   14,    8, 20,  0,  0 }, {     18,   13,    8, 20,  0,  0 }, {     19,   12,    8, 20,  0,  0 }, {     20,   11,    8, 20,  0,  0 },
    {     21,   10,    8, 20,  0,  0 }, {     22,    9,    8, 20,  0,  0 }, {     23,    8,    8, 20,  0,  0 }, {     24,    7,    7, 20, 53,  3 }, {     25,    6,    7, 20, 53,  3 },
    {     26,    5,    7, 20, 53,  3 }, {     27,    4,    7, 20, 53,  3 }, {     28,    3,    7, 20, 53,  3 }, {     29,    2,    7, 20, 53,  3 }, {     30,    1,    6, 20, 53,  3 },
    {     31,    0,    6, 20, 53,  3 }, {     32,   -1,    6, 20, 53,  3 }, {     33,   -2,    6, 20, 53,  3 }, {     34,   -3,    5, 20, 53,  3 }, {     35,   -4,    5, 20,  5,  3 },
    {     36,   -5,    5, 20,  5,  3 }, {     37,   -6,    4, 20,  5,  3 }, {     38,   -7,    4, 20,  5,  3 }, {     39,   -8,    4, 20,  5,  3 }, {     40,   -9,    3, 20, 54,  4 },
    {     41,  -10,    3, 20, 54,  4 }, {     42,  -11,    3, 20, 54,  4 }, {     43,  -12,    2, 20, 54,  4 }, {     44,  -13,    2, 20, 54,  4 }, {     45,  -14,    1, 20, 54,  4 },
    {     46,  -15,    1, 20, 54,  4 }, {     47,  -16,    0, 20, 54,  4 }, {     48,  -17,    0, 20, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToRightBankedDown253, {
    {     15,   15,    8, 28,  0,  0 }, {     14,   14,    8, 28,  0,  0 }, {     13,   13,    8, 28,  0,  0 }, {     12,   12,    8, 28,  0,  0 }, {     11,   11,    8, 28,  0,  0 },
    {     10,   10,    8, 28,  0,  0 }, {      9,    9,    8, 28,  0,  0 }, {      8,    8,    7, 28, 53,  3 }, {      7,    7,    7, 28, 53,  3 }, {      6,    6,    7, 28, 53,  3 },
    {      5,    5,    7, 28, 53,  3 }, {      4,    4,    7, 28, 53,  3 }, {      3,    3,    7, 28, 53,  3 }, {      2,    2,    6, 28, 53,  3 }, {      1,    1,    6, 28, 53,  3 },
    {      0,    0,    6, 28, 53,  3 }, {     -1,   -1,    6, 28, 53,  3 }, {     -2,   -2,    5, 28, 53,  3 }, {     -3,   -3,    5, 28,  5,  3 }, {     -4,   -4,    5, 28,  5,  3 },
    {     -5,   -5,    4, 28,  5,  3 }, {     -6,   -6,    4, 28,  5,  3 }, {     -7,   -7,    4, 28,  5,  3 }, {     -8,   -8,    3, 28, 54,  4 }, {     -9,   -9,    3, 28, 54,  4 },
    {    -10,  -10,    3, 28, 54,  4 }, {    -11,  -11,    2, 28, 54,  4 }, {    -12,  -12,    2, 28, 54,  4 }, {    -13,  -13,    1, 28, 54,  4 }, {    -14,  -14,    1, 28, 54,  4 },
    {    -15,  -15,    0, 28, 54,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedDown25ToFlat0, {
    {     15,   16,    7,  4, 54,  2 }, {     14,   17,    7,  4, 54,  2 }, {     13,   18,    6,  4, 54,  2 }, {     12,   19,    6,  4, 54,  2 }, {     11,   20,    6,  4, 54,  2 },
    {     10,   21,    5,  4, 54,  2 }, {      9,   22,    5,  4, 54,  2 }, {      8,   23,    4,  4,  5,  1 }, {      7,   24,    4,  4,  5,  1 }, {      6,   25,    4,  4,  5,  1 },
    {      5,   26,    3,  4,  5,  1 }, {      4,   27,    3,  4,  5,  1 }, {      3,   28,    3,  4, 53,  1 }, {      2,   29,    2,  4, 53,  1 }, {      1,   30,    2,  4, 53,  1 },
    {      0,   31,    2,  4, 53,  1 }, {     -1,   32,    2,  4, 53,  1 }, {     -2,   33,    1,  4, 53,  1 }, {     -3,   34,    1,  4, 53,  1 }, {     -4,   35,    1,  4, 53,  1 },
    {     -5,   36,    1,  4, 53,  1 }, {     -6,   37,    1,  4, 53,  1 }, {     -7,   38,    1,  4, 53,  1 }, {     -8,   39,    0,  4,  0,  0 }, {     -9,   40,    0,  4,  0,  0 },
    {    -10,   41,    0,  4,  0,  0 }, {    -11,   42,    0,  4,  0,  0 }, {    -12,   43,    0,  4,  0,  0 }, {    -13,   44,    0,  4,  0,  0 }, {    -14,   45,    0,  4,  0,  0 },
    {    -15,   46,    0,  4,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedDown25ToFlat1, {
    {     16,   16,    8, 12, 54,  2 }, {     17,   17,    7, 12, 54,  2 }, {     18,   18,    7, 12, 54,  2 }, {     19,   19,    6, 12, 54,  2 }, {     20,   20,    6, 12, 54,  2 },
    {     21,   21,    6, 12, 54,  2 }, {     22,   22,    5, 12, 54,  2 }, {     23,   23,    5, 12, 54,  2 }, {     24,   24,    4, 12,  5,  1 }, {     25,   25,    4, 12,  5,  1 },
    {     26,   26,    4, 12,  5,  1 }, {     27,   27,    3, 12,  5,  1 }, {     28,   28,    3, 12,  5,  1 }, {     29,   29,    3, 12, 53,  1 }, {     30,   30,    2, 12, 53,  1 },
    {     31,   31,    2, 12, 53,  1 }, {     32,   32,    2, 12, 53,  1 }, {     33,   33,    2, 12, 53,  1 }, {     34,   34,    1, 12, 53,  1 }, {     35,   35,    1, 12, 53,  1 },
    {     36,   36,    1, 12, 53,  1 }, {     37,   37,    1, 12, 53,  1 }, {     38,   38,    1, 12, 53,  1 }, {     39,   39,    1, 12, 53,  1 }, {     40,   40,    0, 12,  0,  0 },
    {     41,   41,    0, 12,  0,  0 }, {     42,   42,    0, 12,  0,  0 }, {     43,   43,    0, 12,  0,  0 }, {     44,   44,    0, 12,  0,  0 }, {     45,   45,    0, 12,  0,  0 },
    {     46,   46,    0, 12,  0,  0 }, {     47,   47,    0, 12,  0,  0 }, {     48,   48,    0, 12,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedDown25ToFlat2, {
    {     16,   15,    8, 20, 54,  2 }, {     17,   14,    7, 20, 54,  2 }, {     18,   13,    7, 20, 54,  2 }, {     19,   12,    6, 20, 54,  2 }, {     20,   11,    6, 20, 54,  2 },
    {     21,   10,    6, 20, 54,  2 }, {     22,    9,    5, 20, 54,  2 }, {     23,    8,    5, 20, 54,  2 }, {     24,    7,    4, 20,  5,  1 }, {     25,    6,    4, 20,  5,  1 },
    {     26,    5,    4, 20,  5,  1 }, {     27,    4,    3, 20,  5,  1 }, {     28,    3,    3, 20,  5,  1 }, {     29,    2,    3, 20, 53,  1 }, {     30,    1,    2, 20, 53,  1 },
    {     31,    0,    2, 20, 53,  1 }, {     32,   -1,    2, 20, 53,  1 }, {     33,   -2,    2, 20, 53,  1 }, {     34,   -3,    1, 20, 53,  1 }, {     35,   -4,    1, 20, 53,  1 },
    {     36,   -5,    1, 20, 53,  1 }, {     37,   -6,    1, 20, 53,  1 }, {     38,   -7,    1, 20, 53,  1 }, {     39,   -8,    1, 20, 53,  1 }, {     40,   -9,    0, 20,  0,  0 },
    {     41,  -10,    0, 20,  0,  0 }, {     42,  -11,    0, 20,  0,  0 }, {     43,  -12,    0, 20,  0,  0 }, {     44,  -13,    0, 20,  0,  0 }, {     45,  -14,    0, 20,  0,  0 },
    {     46,  -15,    0, 20,  0,  0 }, {     47,  -16,    0, 20,  0,  0 }, {     48,  -17,    0, 20,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagLeftBankedDown25ToFlat3, {
    {     15,   15,    7, 28, 54,  2 }, {     14,   14,    7, 28, 54,  2 }, {     13,   13,    6, 28, 54,  2 }, {     12,   12,    6, 28, 54,  2 }, {     11,   11,    6, 28, 54,  2 },
    {     10,   10,    5, 28, 54,  2 }, {      9,    9,    5, 28, 54,  2 }, {      8,    8,    4, 28,  5,  1 }, {      7,    7,    4, 28,  5,  1 }, {      6,    6,    4, 28,  5,  1 },
    {      5,    5,    3, 28,  5,  1 }, {      4,    4,    3, 28,  5,  1 }, {      3,    3,    3, 28, 53,  1 }, {      2,    2,    2, 28, 53,  1 }, {      1,    1,    2, 28, 53,  1 },
    {      0,    0,    2, 28, 53,  1 }, {     -1,   -1,    2, 28, 53,  1 }, {     -2,   -2,    1, 28, 53,  1 }, {     -3,   -3,    1, 28, 53,  1 }, {     -4,   -4,    1, 28, 53,  1 },
    {     -5,   -5,    1, 28, 53,  1 }, {     -6,   -6,    1, 28, 53,  1 }, {     -7,   -7,    1, 28, 53,  1 }, {     -8,   -8,    0, 28,  0,  0 }, {     -9,   -9,    0, 28,  0,  0 },
    {    -10,  -10,    0, 28,  0,  0 }, {    -11,  -11,    0, 28,  0,  0 }, {    -12,  -12,    0, 28,  0,  0 }, {    -13,  -13,    0, 28,  0,  0 }, {    -14,  -14,    0, 28,  0,  0 },
    {    -15,  -15,    0, 28,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedDown25ToFlat0, {
    {     15,   16,    7,  4, 54,  4 }, {     14,   17,    7,  4, 54,  4 }, {     13,   18,    6,  4, 54,  4 }, {     12,   19,    6,  4, 54,  4 }, {     11,   20,    6,  4, 54,  4 },
    {     10,   21,    5,  4, 54,  4 }, {      9,   22,    5,  4, 54,  4 }, {      8,   23,    4,  4,  5,  3 }, {      7,   24,    4,  4,  5,  3 }, {      6,   25,    4,  4,  5,  3 },
    {      5,   26,    3,  4,  5,  3 }, {      4,   27,    3,  4,  5,  3 }, {      3,   28,    3,  4, 53,  3 }, {      2,   29,    2,  4, 53,  3 }, {      1,   30,    2,  4, 53,  3 },
    {      0,   31,    2,  4, 53,  3 }, {     -1,   32,    2,  4, 53,  3 }, {     -2,   33,    1,  4, 53,  3 }, {     -3,   34,    1,  4, 53,  3 }, {     -4,   35,    1,  4, 53,  3 },
    {     -5,   36,    1,  4, 53,  3 }, {     -6,   37,    1,  4, 53,  3 }, {     -7,   38,    1,  4, 53,  3 }, {     -8,   39,    0,  4,  0,  0 }, {     -9,   40,    0,  4,  0,  0 },
    {    -10,   41,    0,  4,  0,  0 }, {    -11,   42,    0,  4,  0,  0 }, {    -12,   43,    0,  4,  0,  0 }, {    -13,   44,    0,  4,  0,  0 }, {    -14,   45,    0,  4,  0,  0 },
    {    -15,   46,    0,  4,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedDown25ToFlat1, {
    {     16,   16,    8, 12, 54,  4 }, {     17,   17,    7, 12, 54,  4 }, {     18,   18,    7, 12, 54,  4 }, {     19,   19,    6, 12, 54,  4 }, {     20,   20,    6, 12, 54,  4 },
    {     21,   21,    6, 12, 54,  4 }, {     22,   22,    5, 12, 54,  4 }, {     23,   23,    5, 12, 54,  4 }, {     24,   24,    4, 12,  5,  3 }, {     25,   25,    4, 12,  5,  3 },
    {     26,   26,    4, 12,  5,  3 }, {     27,   27,    3, 12,  5,  3 }, {     28,   28,    3, 12,  5,  3 }, {     29,   29,    3, 12, 53,  3 }, {     30,   30,    2, 12, 53,  3 },
    {     31,   31,    2, 12, 53,  3 }, {     32,   32,    2, 12, 53,  3 }, {     33,   33,    2, 12, 53,  3 }, {     34,   34,    1, 12, 53,  3 }, {     35,   35,    1, 12, 53,  3 },
    {     36,   36,    1, 12, 53,  3 }, {     37,   37,    1, 12, 53,  3 }, {     38,   38,    1, 12, 53,  3 }, {     39,   39,    1, 12, 53,  3 }, {     40,   40,    0, 12,  0,  0 },
    {     41,   41,    0, 12,  0,  0 }, {     42,   42,    0, 12,  0,  0 }, {     43,   43,    0, 12,  0,  0 }, {     44,   44,    0, 12,  0,  0 }, {     45,   45,    0, 12,  0,  0 },
    {     46,   46,    0, 12,  0,  0 }, {     47,   47,    0, 12,  0,  0 }, {     48,   48,    0, 12,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedDown25ToFlat2, {
    {     16,   15,    8, 20, 54,  4 }, {     17,   14,    7, 20, 54,  4 }, {     18,   13,    7, 20, 54,  4 }, {     19,   12,    6, 20, 54,  4 }, {     20,   11,    6, 20, 54,  4 },
    {     21,   10,    6, 20, 54,  4 }, {     22,    9,    5, 20, 54,  4 }, {     23,    8,    5, 20, 54,  4 }, {     24,    7,    4, 20,  5,  3 }, {     25,    6,    4, 20,  5,  3 },
    {     26,    5,    4, 20,  5,  3 }, {     27,    4,    3, 20,  5,  3 }, {     28,    3,    3, 20,  5,  3 }, {     29,    2,    3, 20, 53,  3 }, {     30,    1,    2, 20, 53,  3 },
    {     31,    0,    2, 20, 53,  3 }, {     32,   -1,    2, 20, 53,  3 }, {     33,   -2,    2, 20, 53,  3 }, {     34,   -3,    1, 20, 53,  3 }, {     35,   -4,    1, 20, 53,  3 },
    {     36,   -5,    1, 20, 53,  3 }, {     37,   -6,    1, 20, 53,  3 }, {     38,   -7,    1, 20, 53,  3 }, {     39,   -8,    1, 20, 53,  3 }, {     40,   -9,    0, 20,  0,  0 },
    {     41,  -10,    0, 20,  0,  0 }, {     42,  -11,    0, 20,  0,  0 }, {     43,  -12,    0, 20,  0,  0 }, {     44,  -13,    0, 20,  0,  0 }, {     45,  -14,    0, 20,  0,  0 },
    {     46,  -15,    0, 20,  0,  0 }, {     47,  -16,    0, 20,  0,  0 }, {     48,  -17,    0, 20,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagRightBankedDown25ToFlat3, {
    {     15,   15,    7, 28, 54,  4 }, {     14,   14,    7, 28, 54,  4 }, {     13,   13,    6, 28, 54,  4 }, {     12,   12,    6, 28, 54,  4 }, {     11,   11,    6, 28, 54,  4 },
    {     10,   10,    5, 28, 54,  4 }, {      9,    9,    5, 28, 54,  4 }, {      8,    8,    4, 28,  5,  3 }, {      7,    7,    4, 28,  5,  3 }, {      6,    6,    4, 28,  5,  3 },
    {      5,    5,    3, 28,  5,  3 }, {      4,    4,    3, 28,  5,  3 }, {      3,    3,    3, 28, 53,  3 }, {      2,    2,    2, 28, 53,  3 }, {      1,    1,    2, 28, 53,  3 },
    {      0,    0,    2, 28, 53,  3 }, {     -1,   -1,    2, 28, 53,  3 }, {     -2,   -2,    1, 28, 53,  3 }, {     -3,   -3,    1, 28, 53,  3 }, {     -4,   -4,    1, 28, 53,  3 },
    {     -5,   -5,    1, 28, 53,  3 }, {     -6,   -6,    1, 28, 53,  3 }, {     -7,   -7,    1, 28, 53,  3 }, {     -8,   -8,    0, 28,  0,  0 }, {     -9,   -9,    0, 28,  0,  0 },
    {    -10,  -10,    0, 28,  0,  0 }, {    -11,  -11,    0, 28,  0,  0 }, {    -12,  -12,    0, 28,  0,  0 }, {    -13,  -13,    0, 28,  0,  0 }, {    -14,  -14,    0, 28,  0,  0 },
    {    -15,  -15,    0, 28,  0,  0 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToDiagUp250, {
    {     31,   16,    1,  0,  2,  2 }, {     30,   16,    1,  0,  2,  2 }, {     29,   16,    2,  0,  2,  2 }, {     28,   16,    2,  0,  2,  2 }, {     27,   16,    3,  0,  2,  2 },
    {     26,   16,    4,  0,  2,  2 }, {     25,   16,    4,  0,  2,  2 }, {     24,   16,    5,  0,  2,  2 }, {     23,   16,    5,  0,  2,  2 }, {     22,   15,    6,  0,  2,  2 },
    {     21,   15,    6, 31,  2,  2 }, {     20,   15,    7, 31,  2,  2 }, {     19,   15,    7, 31,  2,  2 }, {     18,   15,    8, 31,  2,  2 }, {     17,   15,    9, 31,  2,  2 },
    {     16,   15,    9, 31,  2,  2 }, {     15,   15,   10, 31,  2,  2 }, {     14,   14,   10, 31,  2,  2 }, {     13,   14,   11, 31,  2,  2 }, {     12,   14,   12, 31,  2,  2 },
    {     11,   14,   12, 31,  2,  2 }, {     10,   14,   13, 31,  2,  2 }, {      9,   13,   13, 31,  2,  2 }, {      8,   13,   14, 31,  2,  2 }, {      7,   13,   14, 31,  2,  2 },
    {      6,   13,   15, 31,  2,  2 }, {      5,   13,   16, 31,  2,  2 }, {      4,   12,   16, 31,  2,  2 }, {      3,   12,   17, 31,  2,  2 }, {      2,   12,   17, 31,  2,  2 },
    {      1,   11,   18, 31,  2,  2 }, {      0,   11,   19, 31,  2,  2 }, {     -1,   11,   19, 30,  2,  2 }, {     -2,   11,   20, 30,  2,  2 }, {     -3,   10,   20, 30,  2,  2 },
    {     -4,   10,   21, 30,  2,  2 }, {     -5,   10,   22, 30,  2,  2 }, {     -6,    9,   22, 30,  2,  2 }, {     -7,    9,   23, 30,  2,  2 }, {     -8,    8,   23, 30,  2,  2 },
    {     -9,    8,   24, 30,  2,  2 }, {    -10,    8,   25, 30,  2,  2 }, {    -11,    7,   25, 30,  2,  2 }, {    -12,    7,   26, 30,  2,  2 }, {    -13,    7,   26, 30,  2,  2 },
    {    -14,    6,   27, 30,  2,  2 }, {    -15,    6,   28, 30,  2,  2 }, {    -16,    5,   28, 30,  2,  2 }, {    -17,    5,   29, 30,  2,  2 }, {    -18,    4,   30, 30,  2,  2 },
    {    -19,    4,   30, 30,  2,  2 }, {    -20,    3,   31, 30,  2,  2 }, {    -21,    3,   31, 30,  2,  2 }, {    -22,    2,   32, 30,  2,  2 }, {    -23,    2,   33, 30,  2,  2 },
    {    -24,    1,   33, 29,  2,  2 }, {    -25,    1,   34, 29,  2,  2 }, {    -26,    0,   35, 29,  2,  2 }, {    -27,    0,   35, 29,  2,  2 }, {    -28,   -1,   36, 29,  2,  2 },
    {    -29,   -2,   36, 29,  2,  2 }, {    -30,   -2,   37, 29,  2,  2 }, {    -31,   -3,   38, 29,  2,  2 }, {    -32,   -4,   38, 29,  2,  2 }, {    -33,   -4,   39, 29,  2,  2 },
    {    -34,   -5,   39, 29,  2,  2 }, {    -35,   -6,   40, 29,  2,  2 }, {    -36,   -6,   41, 29,  2,  2 }, {    -37,   -7,   41, 29,  2,  2 }, {    -38,   -8,   42, 29,  2,  2 },
    {    -39,   -9,   43, 29,  2,  2 }, {    -40,   -9,   43, 29,  2,  2 }, {    -41,  -10,   44, 29,  2,  2 }, {    -42,  -11,   44, 28,  2,  2 }, {    -43,  -12,   45, 28,  2,  2 },
    {    -44,  -13,   46, 28,  2,  2 }, {    -45,  -14,   46, 28,  2,  2 }, {    -46,  -15,   47, 28,  2,  2 }, {    -47,  -15,   48, 28,  2,  2 }, {    -48,  -16,   48, 28,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToDiagUp251, {
    {     16,    0,    0,  8,  2,  2 }, {     16,    1,    1,  8,  2,  2 }, {     16,    2,    1,  8,  2,  2 }, {     16,    3,    2,  8,  2,  2 }, {     16,    4,    2,  8,  2,  2 },
    {     16,    5,    3,  8,  2,  2 }, {     16,    6,    4,  8,  2,  2 }, {     16,    7,    4,  8,  2,  2 }, {     16,    8,    5,  8,  2,  2 }, {     16,    9,    5,  8,  2,  2 },
    {     15,   10,    6,  8,  2,  2 }, {     15,   11,    6,  7,  2,  2 }, {     15,   12,    7,  7,  2,  2 }, {     15,   13,    7,  7,  2,  2 }, {     15,   14,    8,  7,  2,  2 },
    {     15,   15,    9,  7,  2,  2 }, {     15,   16,    9,  7,  2,  2 }, {     15,   17,   10,  7,  2,  2 }, {     14,   18,   10,  7,  2,  2 }, {     14,   19,   11,  7,  2,  2 },
    {     14,   20,   12,  7,  2,  2 }, {     14,   21,   12,  7,  2,  2 }, {     14,   22,   13,  7,  2,  2 }, {     13,   23,   13,  7,  2,  2 }, {     13,   24,   14,  7,  2,  2 },
    {     13,   25,   14,  7,  2,  2 }, {     13,   26,   15,  7,  2,  2 }, {     13,   27,   16,  7,  2,  2 }, {     12,   28,   16,  7,  2,  2 }, {     12,   29,   17,  7,  2,  2 },
    {     12,   30,   17,  7,  2,  2 }, {     11,   31,   18,  7,  2,  2 }, {     11,   32,   19,  7,  2,  2 }, {     11,   33,   19,  6,  2,  2 }, {     11,   34,   20,  6,  2,  2 },
    {     10,   35,   20,  6,  2,  2 }, {     10,   36,   21,  6,  2,  2 }, {     10,   37,   22,  6,  2,  2 }, {      9,   38,   22,  6,  2,  2 }, {      9,   39,   23,  6,  2,  2 },
    {      8,   40,   23,  6,  2,  2 }, {      8,   41,   24,  6,  2,  2 }, {      8,   42,   25,  6,  2,  2 }, {      7,   43,   25,  6,  2,  2 }, {      7,   44,   26,  6,  2,  2 },
    {      7,   45,   26,  6,  2,  2 }, {      6,   46,   27,  6,  2,  2 }, {      6,   47,   28,  6,  2,  2 }, {      5,   48,   28,  6,  2,  2 }, {      5,   49,   29,  6,  2,  2 },
    {      4,   50,   30,  6,  2,  2 }, {      4,   51,   30,  6,  2,  2 }, {      3,   52,   31,  6,  2,  2 }, {      3,   53,   31,  6,  2,  2 }, {      2,   54,   32,  6,  2,  2 },
    {      2,   55,   33,  6,  2,  2 }, {      1,   56,   33,  5,  2,  2 }, {      1,   57,   34,  5,  2,  2 }, {      0,   58,   35,  5,  2,  2 }, {      0,   59,   35,  5,  2,  2 },
    {     -1,   60,   36,  5,  2,  2 }, {     -2,   61,   36,  5,  2,  2 }, {     -2,   62,   37,  5,  2,  2 }, {     -3,   63,   38,  5,  2,  2 }, {     -4,   64,   38,  5,  2,  2 },
    {     -4,   65,   39,  5,  2,  2 }, {     -5,   66,   39,  5,  2,  2 }, {     -6,   67,   40,  5,  2,  2 }, {     -6,   68,   41,  5,  2,  2 }, {     -7,   69,   41,  5,  2,  2 },
    {     -8,   70,   42,  5,  2,  2 }, {     -9,   71,   43,  5,  2,  2 }, {     -9,   72,   43,  5,  2,  2 }, {    -10,   73,   44,  5,  2,  2 }, {    -11,   74,   44,  4,  2,  2 },
    {    -12,   75,   45,  4,  2,  2 }, {    -13,   76,   46,  4,  2,  2 }, {    -14,   77,   46,  4,  2,  2 }, {    -15,   78,   47,  4,  2,  2 }, {    -15,   79,   48,  4,  2,  2 },
    {    -16,   80,   48,  4,  2,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToDiagUp252, {
    {      0,   16,    0, 16,  2,  2 }, {      1,   16,    1, 16,  2,  2 }, {      2,   16,    1, 16,  2,  2 }, {      3,   16,    2, 16,  2,  2 }, {      4,   16,    2, 16,  2,  2 },
    {      5,   16,    3, 16,  2,  2 }, {      6,   16,    4, 16,  2,  2 }, {      7,   16,    4, 16,  2,  2 }, {      8,   16,    5, 16,  2,  2 }, {      9,   16,    5, 16,  2,  2 },
    {     10,   17,    6, 16,  2,  2 }, {     11,   17,    6, 15,  2,  2 }, {     12,   17,    7, 15,  2,  2 }, {     13,   17,    7, 15,  2,  2 }, {     14,   17,    8, 15,  2,  2 },
    {     15,   17,    9, 15,  2,  2 }, {     16,   17,    9, 15,  2,  2 }, {     17,   17,   10, 15,  2,  2 }, {     18,   18,   10, 15,  2,  2 }, {     19,   18,   11, 15,  2,  2 },
    {     20,   18,   12, 15,  2,  2 }, {     21,   18,   12, 15,  2,  2 }, {     22,   18,   13, 15,  2,  2 }, {     23,   19,   13, 15,  2,  2 }, {     24,   19,   14, 15,  2,  2 },
    {     25,   19,   14, 15,  2,  2 }, {     26,   19,   15, 15,  2,  2 }, {     27,   19,   16, 15,  2,  2 }, {     28,   20,   16, 15,  2,  2 }, {     29,   20,   17, 15,  2,  2 },
    {     30,   20,   17, 15,  2,  2 }, {     31,   21,   18, 15,  2,  2 }, {     32,   21,   19, 15,  2,  2 }, {     33,   21,   19, 14,  2,  2 }, {     34,   21,   20, 14,  2,  2 },
    {     35,   22,   20, 14,  2,  2 }, {     36,   22,   21, 14,  2,  2 }, {     37,   22,   22, 14,  2,  2 }, {     38,   23,   22, 14,  2,  2 }, {     39,   23,   23, 14,  2,  2 },
    {     40,   24,   23, 14,  2,  2 }, {     41,   24,   24, 14,  2,  2 }, {     42,   24,   25, 14,  2,  2 }, {     43,   25,   25, 14,  2,  2 }, {     44,   25,   26, 14,  2,  2 },
    {     45,   25,   26, 14,  2,  2 }, {     46,   26,   27, 14,  2,  2 }, {     47,   26,   28, 14,  2,  2 }, {     48,   27,   28, 14,  2,  2 }, {     49,   27,   29, 14,  2,  2 },
    {     50,   28,   30, 14,  2,  2 }, {     51,   28,   30, 14,  2,  2 }, {     52,   29,   31, 14,  2,  2 }, {     53,   29,   31, 14,  2,  2 }, {     54,   30,   32, 14,  2,  2 },
    {     55,   30,   33, 14,  2,  2 }, {     56,   31,   33, 13,  2,  2 }, {     57,   31,   34, 13,  2,  2 }, {     58,   32,   35, 13,  2,  2 }, {     59,   32,   35, 13,  2,  2 },
    {     60,   33,   36, 13,  2,  2 }, {     61,   34,   36, 13,  2,  2 }, {     62,   34,   37, 13,  2,  2 }, {     63,   35,   38, 13,  2,  2 }, {     64,   36,   38, 13,  2,  2 },
    {     65,   36,   39, 13,  2,  2 }, {     66,   37,   39, 13,  2,  2 }, {     67,   38,   40, 13,  2,  2 }, {     68,   38,   41, 13,  2,  2 }, {     69,   39,   41, 13,  2,  2 },
    {     70,   40,   42, 13,  2,  2 }, {     71,   41,   43, 13,  2,  2 }, {     72,   41,   43, 13,  2,  2 }, {     73,   42,   44, 13,  2,  2 }, {     74,   43,   44, 12,  2,  2 },
    {     75,   44,   45, 12,  2,  2 }, {     76,   45,   46, 12,  2,  2 }, {     77,   46,   46, 12,  2,  2 }, {     78,   47,   47, 12,  2,  2 }, {     79,   47,   48, 12,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToDiagUp253, {
    {     16,   31,    1, 24,  2,  2 }, {     16,   30,    1, 24,  2,  2 }, {     16,   29,    2, 24,  2,  2 }, {     16,   28,    2, 24,  2,  2 }, {     16,   27,    3, 24,  2,  2 },
    {     16,   26,    4, 24,  2,  2 }, {     16,   25,    4, 24,  2,  2 }, {     16,   24,    5, 24,  2,  2 }, {     16,   23,    5, 24,  2,  2 }, {     17,   22,    6, 24,  2,  2 },
    {     17,   21,    6, 23,  2,  2 }, {     17,   20,    7, 23,  2,  2 }, {     17,   19,    7, 23,  2,  2 }, {     17,   18,    8, 23,  2,  2 }, {     17,   17,    9, 23,  2,  2 },
    {     17,   16,    9, 23,  2,  2 }, {     17,   15,   10, 23,  2,  2 }, {     18,   14,   10, 23,  2,  2 }, {     18,   13,   11, 23,  2,  2 }, {     18,   12,   12, 23,  2,  2 },
    {     18,   11,   12, 23,  2,  2 }, {     18,   10,   13, 23,  2,  2 }, {     19,    9,   13, 23,  2,  2 }, {     19,    8,   14, 23,  2,  2 }, {     19,    7,   14, 23,  2,  2 },
    {     19,    6,   15, 23,  2,  2 }, {     19,    5,   16, 23,  2,  2 }, {     20,    4,   16, 23,  2,  2 }, {     20,    3,   17, 23,  2,  2 }, {     20,    2,   17, 23,  2,  2 },
    {     21,    1,   18, 23,  2,  2 }, {     21,    0,   19, 23,  2,  2 }, {     21,   -1,   19, 22,  2,  2 }, {     21,   -2,   20, 22,  2,  2 }, {     22,   -3,   20, 22,  2,  2 },
    {     22,   -4,   21, 22,  2,  2 }, {     22,   -5,   22, 22,  2,  2 }, {     23,   -6,   22, 22,  2,  2 }, {     23,   -7,   23, 22,  2,  2 }, {     24,   -8,   23, 22,  2,  2 },
    {     24,   -9,   24, 22,  2,  2 }, {     24,  -10,   25, 22,  2,  2 }, {     25,  -11,   25, 22,  2,  2 }, {     25,  -12,   26, 22,  2,  2 }, {     25,  -13,   26, 22,  2,  2 },
    {     26,  -14,   27, 22,  2,  2 }, {     26,  -15,   28, 22,  2,  2 }, {     27,  -16,   28, 22,  2,  2 }, {     27,  -17,   29, 22,  2,  2 }, {     28,  -18,   30, 22,  2,  2 },
    {     28,  -19,   30, 22,  2,  2 }, {     29,  -20,   31, 22,  2,  2 }, {     29,  -21,   31, 22,  2,  2 }, {     30,  -22,   32, 22,  2,  2 }, {     30,  -23,   33, 22,  2,  2 },
    {     31,  -24,   33, 21,  2,  2 }, {     31,  -25,   34, 21,  2,  2 }, {     32,  -26,   35, 21,  2,  2 }, {     32,  -27,   35, 21,  2,  2 }, {     33,  -28,   36, 21,  2,  2 },
    {     34,  -29,   36, 21,  2,  2 }, {     34,  -30,   37, 21,  2,  2 }, {     35,  -31,   38, 21,  2,  2 }, {     36,  -32,   38, 21,  2,  2 }, {     36,  -33,   39, 21,  2,  2 },
    {     37,  -34,   39, 21,  2,  2 }, {     38,  -35,   40, 21,  2,  2 }, {     38,  -36,   41, 21,  2,  2 }, {     39,  -37,   41, 21,  2,  2 }, {     40,  -38,   42, 21,  2,  2 },
    {     41,  -39,   43, 21,  2,  2 }, {     41,  -40,   43, 21,  2,  2 }, {     42,  -41,   44, 21,  2,  2 }, {     43,  -42,   44, 20,  2,  2 }, {     44,  -43,   45, 20,  2,  2 },
    {     45,  -44,   46, 20,  2,  2 }, {     46,  -45,   46, 20,  2,  2 }, {     47,  -46,   47, 20,  2,  2 }, {     47,  -47,   48, 20,  2,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToDiagUp250, {
    {     31,   16,    1,  0,  2,  4 }, {     30,   16,    1,  0,  2,  4 }, {     29,   16,    2,  0,  2,  4 }, {     28,   16,    2,  0,  2,  4 }, {     27,   16,    3,  0,  2,  4 },
    {     26,   16,    4,  0,  2,  4 }, {     25,   16,    4,  0,  2,  4 }, {     24,   16,    5,  0,  2,  4 }, {     23,   16,    5,  0,  2,  4 }, {     22,   17,    6,  0,  2,  4 },
    {     21,   17,    6,  1,  2,  4 }, {     20,   17,    7,  1,  2,  4 }, {     19,   17,    7,  1,  2,  4 }, {     18,   17,    8,  1,  2,  4 }, {     17,   17,    9,  1,  2,  4 },
    {     16,   17,    9,  1,  2,  4 }, {     15,   17,   10,  1,  2,  4 }, {     14,   18,   10,  1,  2,  4 }, {     13,   18,   11,  1,  2,  4 }, {     12,   18,   12,  1,  2,  4 },
    {     11,   18,   12,  1,  2,  4 }, {     10,   18,   13,  1,  2,  4 }, {      9,   19,   13,  1,  2,  4 }, {      8,   19,   14,  1,  2,  4 }, {      7,   19,   14,  1,  2,  4 },
    {      6,   19,   15,  1,  2,  4 }, {      5,   19,   16,  1,  2,  4 }, {      4,   20,   16,  1,  2,  4 }, {      3,   20,   17,  1,  2,  4 }, {      2,   20,   17,  1,  2,  4 },
    {      1,   21,   18,  1,  2,  4 }, {      0,   21,   19,  1,  2,  4 }, {     -1,   21,   19,  2,  2,  4 }, {     -2,   21,   20,  2,  2,  4 }, {     -3,   22,   20,  2,  2,  4 },
    {     -4,   22,   21,  2,  2,  4 }, {     -5,   22,   22,  2,  2,  4 }, {     -6,   23,   22,  2,  2,  4 }, {     -7,   23,   23,  2,  2,  4 }, {     -8,   24,   23,  2,  2,  4 },
    {     -9,   24,   24,  2,  2,  4 }, {    -10,   24,   25,  2,  2,  4 }, {    -11,   25,   25,  2,  2,  4 }, {    -12,   25,   26,  2,  2,  4 }, {    -13,   25,   26,  2,  2,  4 },
    {    -14,   26,   27,  2,  2,  4 }, {    -15,   26,   28,  2,  2,  4 }, {    -16,   27,   28,  2,  2,  4 }, {    -17,   27,   29,  2,  2,  4 }, {    -18,   28,   30,  2,  2,  4 },
    {    -19,   28,   30,  2,  2,  4 }, {    -20,   29,   31,  2,  2,  4 }, {    -21,   29,   31,  2,  2,  4 }, {    -22,   30,   32,  2,  2,  4 }, {    -23,   30,   33,  2,  2,  4 },
    {    -24,   31,   33,  3,  2,  4 }, {    -25,   31,   34,  3,  2,  4 }, {    -26,   32,   35,  3,  2,  4 }, {    -27,   32,   35,  3,  2,  4 }, {    -28,   33,   36,  3,  2,  4 },
    {    -29,   34,   36,  3,  2,  4 }, {    -30,   34,   37,  3,  2,  4 }, {    -31,   35,   38,  3,  2,  4 }, {    -32,   36,   38,  3,  2,  4 }, {    -33,   36,   39,  3,  2,  4 },
    {    -34,   37,   39,  3,  2,  4 }, {    -35,   38,   40,  3,  2,  4 }, {    -36,   38,   41,  3,  2,  4 }, {    -37,   39,   41,  3,  2,  4 }, {    -38,   40,   42,  3,  2,  4 },
    {    -39,   41,   43,  3,  2,  4 }, {    -40,   41,   43,  3,  2,  4 }, {    -41,   42,   44,  3,  2,  4 }, {    -42,   43,   44,  4,  2,  4 }, {    -43,   44,   45,  4,  2,  4 },
    {    -44,   45,   46,  4,  2,  4 }, {    -45,   46,   46,  4,  2,  4 }, {    -46,   47,   47,  4,  2,  4 }, {    -47,   47,   48,  4,  2,  4 }, {    -48,   48,   48,  4,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToDiagUp251, {
    {     16,    0,    0,  8,  2,  4 }, {     16,    1,    1,  8,  2,  4 }, {     16,    2,    1,  8,  2,  4 }, {     16,    3,    2,  8,  2,  4 }, {     16,    4,    2,  8,  2,  4 },
    {     16,    5,    3,  8,  2,  4 }, {     16,    6,    4,  8,  2,  4 }, {     16,    7,    4,  8,  2,  4 }, {     16,    8,    5,  8,  2,  4 }, {     16,    9,    5,  8,  2,  4 },
    {     17,   10,    6,  8,  2,  4 }, {     17,   11,    6,  9,  2,  4 }, {     17,   12,    7,  9,  2,  4 }, {     17,   13,    7,  9,  2,  4 }, {     17,   14,    8,  9,  2,  4 },
    {     17,   15,    9,  9,  2,  4 }, {     17,   16,    9,  9,  2,  4 }, {     17,   17,   10,  9,  2,  4 }, {     18,   18,   10,  9,  2,  4 }, {     18,   19,   11,  9,  2,  4 },
    {     18,   20,   12,  9,  2,  4 }, {     18,   21,   12,  9,  2,  4 }, {     18,   22,   13,  9,  2,  4 }, {     19,   23,   13,  9,  2,  4 }, {     19,   24,   14,  9,  2,  4 },
    {     19,   25,   14,  9,  2,  4 }, {     19,   26,   15,  9,  2,  4 }, {     19,   27,   16,  9,  2,  4 }, {     20,   28,   16,  9,  2,  4 }, {     20,   29,   17,  9,  2,  4 },
    {     20,   30,   17,  9,  2,  4 }, {     21,   31,   18,  9,  2,  4 }, {     21,   32,   19,  9,  2,  4 }, {     21,   33,   19, 10,  2,  4 }, {     21,   34,   20, 10,  2,  4 },
    {     22,   35,   20, 10,  2,  4 }, {     22,   36,   21, 10,  2,  4 }, {     22,   37,   22, 10,  2,  4 }, {     23,   38,   22, 10,  2,  4 }, {     23,   39,   23, 10,  2,  4 },
    {     24,   40,   23, 10,  2,  4 }, {     24,   41,   24, 10,  2,  4 }, {     24,   42,   25, 10,  2,  4 }, {     25,   43,   25, 10,  2,  4 }, {     25,   44,   26, 10,  2,  4 },
    {     25,   45,   26, 10,  2,  4 }, {     26,   46,   27, 10,  2,  4 }, {     26,   47,   28, 10,  2,  4 }, {     27,   48,   28, 10,  2,  4 }, {     27,   49,   29, 10,  2,  4 },
    {     28,   50,   30, 10,  2,  4 }, {     28,   51,   30, 10,  2,  4 }, {     29,   52,   31, 10,  2,  4 }, {     29,   53,   31, 10,  2,  4 }, {     30,   54,   32, 10,  2,  4 },
    {     30,   55,   33, 10,  2,  4 }, {     31,   56,   33, 11,  2,  4 }, {     31,   57,   34, 11,  2,  4 }, {     32,   58,   35, 11,  2,  4 }, {     32,   59,   35, 11,  2,  4 },
    {     33,   60,   36, 11,  2,  4 }, {     34,   61,   36, 11,  2,  4 }, {     34,   62,   37, 11,  2,  4 }, {     35,   63,   38, 11,  2,  4 }, {     36,   64,   38, 11,  2,  4 },
    {     36,   65,   39, 11,  2,  4 }, {     37,   66,   39, 11,  2,  4 }, {     38,   67,   40, 11,  2,  4 }, {     38,   68,   41, 11,  2,  4 }, {     39,   69,   41, 11,  2,  4 },
    {     40,   70,   42, 11,  2,  4 }, {     41,   71,   43, 11,  2,  4 }, {     41,   72,   43, 11,  2,  4 }, {     42,   73,   44, 11,  2,  4 }, {     43,   74,   44, 12,  2,  4 },
    {     44,   75,   45, 12,  2,  4 }, {     45,   76,   46, 12,  2,  4 }, {     46,   77,   46, 12,  2,  4 }, {     47,   78,   47, 12,  2,  4 }, {     47,   79,   48, 12,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToDiagUp252, {
    {      0,   16,    0, 16,  2,  4 }, {      1,   16,    1, 16,  2,  4 }, {      2,   16,    1, 16,  2,  4 }, {      3,   16,    2, 16,  2,  4 }, {      4,   16,    2, 16,  2,  4 },
    {      5,   16,    3, 16,  2,  4 }, {      6,   16,    4, 16,  2,  4 }, {      7,   16,    4, 16,  2,  4 }, {      8,   16,    5, 16,  2,  4 }, {      9,   16,    5, 16,  2,  4 },
    {     10,   15,    6, 16,  2,  4 }, {     11,   15,    6, 17,  2,  4 }, {     12,   15,    7, 17,  2,  4 }, {     13,   15,    7, 17,  2,  4 }, {     14,   15,    8, 17,  2,  4 },
    {     15,   15,    9, 17,  2,  4 }, {     16,   15,    9, 17,  2,  4 }, {     17,   15,   10, 17,  2,  4 }, {     18,   14,   10, 17,  2,  4 }, {     19,   14,   11, 17,  2,  4 },
    {     20,   14,   12, 17,  2,  4 }, {     21,   14,   12, 17,  2,  4 }, {     22,   14,   13, 17,  2,  4 }, {     23,   13,   13, 17,  2,  4 }, {     24,   13,   14, 17,  2,  4 },
    {     25,   13,   14, 17,  2,  4 }, {     26,   13,   15, 17,  2,  4 }, {     27,   13,   16, 17,  2,  4 }, {     28,   12,   16, 17,  2,  4 }, {     29,   12,   17, 17,  2,  4 },
    {     30,   12,   17, 17,  2,  4 }, {     31,   11,   18, 17,  2,  4 }, {     32,   11,   19, 17,  2,  4 }, {     33,   11,   19, 18,  2,  4 }, {     34,   11,   20, 18,  2,  4 },
    {     35,   10,   20, 18,  2,  4 }, {     36,   10,   21, 18,  2,  4 }, {     37,   10,   22, 18,  2,  4 }, {     38,    9,   22, 18,  2,  4 }, {     39,    9,   23, 18,  2,  4 },
    {     40,    8,   23, 18,  2,  4 }, {     41,    8,   24, 18,  2,  4 }, {     42,    8,   25, 18,  2,  4 }, {     43,    7,   25, 18,  2,  4 }, {     44,    7,   26, 18,  2,  4 },
    {     45,    7,   26, 18,  2,  4 }, {     46,    6,   27, 18,  2,  4 }, {     47,    6,   28, 18,  2,  4 }, {     48,    5,   28, 18,  2,  4 }, {     49,    5,   29, 18,  2,  4 },
    {     50,    4,   30, 18,  2,  4 }, {     51,    4,   30, 18,  2,  4 }, {     52,    3,   31, 18,  2,  4 }, {     53,    3,   31, 18,  2,  4 }, {     54,    2,   32, 18,  2,  4 },
    {     55,    2,   33, 18,  2,  4 }, {     56,    1,   33, 19,  2,  4 }, {     57,    1,   34, 19,  2,  4 }, {     58,    0,   35, 19,  2,  4 }, {     59,    0,   35, 19,  2,  4 },
    {     60,   -1,   36, 19,  2,  4 }, {     61,   -2,   36, 19,  2,  4 }, {     62,   -2,   37, 19,  2,  4 }, {     63,   -3,   38, 19,  2,  4 }, {     64,   -4,   38, 19,  2,  4 },
    {     65,   -4,   39, 19,  2,  4 }, {     66,   -5,   39, 19,  2,  4 }, {     67,   -6,   40, 19,  2,  4 }, {     68,   -6,   41, 19,  2,  4 }, {     69,   -7,   41, 19,  2,  4 },
    {     70,   -8,   42, 19,  2,  4 }, {     71,   -9,   43, 19,  2,  4 }, {     72,   -9,   43, 19,  2,  4 }, {     73,  -10,   44, 19,  2,  4 }, {     74,  -11,   44, 20,  2,  4 },
    {     75,  -12,   45, 20,  2,  4 }, {     76,  -13,   46, 20,  2,  4 }, {     77,  -14,   46, 20,  2,  4 }, {     78,  -15,   47, 20,  2,  4 }, {     79,  -15,   48, 20,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToDiagUp253, {
    {     16,   31,    1, 24,  2,  4 }, {     16,   30,    1, 24,  2,  4 }, {     16,   29,    2, 24,  2,  4 }, {     16,   28,    2, 24,  2,  4 }, {     16,   27,    3, 24,  2,  4 },
    {     16,   26,    4, 24,  2,  4 }, {     16,   25,    4, 24,  2,  4 }, {     16,   24,    5, 24,  2,  4 }, {     16,   23,    5, 24,  2,  4 }, {     15,   22,    6, 24,  2,  4 },
    {     15,   21,    6, 25,  2,  4 }, {     15,   20,    7, 25,  2,  4 }, {     15,   19,    7, 25,  2,  4 }, {     15,   18,    8, 25,  2,  4 }, {     15,   17,    9, 25,  2,  4 },
    {     15,   16,    9, 25,  2,  4 }, {     15,   15,   10, 25,  2,  4 }, {     14,   14,   10, 25,  2,  4 }, {     14,   13,   11, 25,  2,  4 }, {     14,   12,   12, 25,  2,  4 },
    {     14,   11,   12, 25,  2,  4 }, {     14,   10,   13, 25,  2,  4 }, {     13,    9,   13, 25,  2,  4 }, {     13,    8,   14, 25,  2,  4 }, {     13,    7,   14, 25,  2,  4 },
    {     13,    6,   15, 25,  2,  4 }, {     13,    5,   16, 25,  2,  4 }, {     12,    4,   16, 25,  2,  4 }, {     12,    3,   17, 25,  2,  4 }, {     12,    2,   17, 25,  2,  4 },
    {     11,    1,   18, 25,  2,  4 }, {     11,    0,   19, 25,  2,  4 }, {     11,   -1,   19, 26,  2,  4 }, {     11,   -2,   20, 26,  2,  4 }, {     10,   -3,   20, 26,  2,  4 },
    {     10,   -4,   21, 26,  2,  4 }, {     10,   -5,   22, 26,  2,  4 }, {      9,   -6,   22, 26,  2,  4 }, {      9,   -7,   23, 26,  2,  4 }, {      8,   -8,   23, 26,  2,  4 },
    {      8,   -9,   24, 26,  2,  4 }, {      8,  -10,   25, 26,  2,  4 }, {      7,  -11,   25, 26,  2,  4 }, {      7,  -12,   26, 26,  2,  4 }, {      7,  -13,   26, 26,  2,  4 },
    {      6,  -14,   27, 26,  2,  4 }, {      6,  -15,   28, 26,  2,  4 }, {      5,  -16,   28, 26,  2,  4 }, {      5,  -17,   29, 26,  2,  4 }, {      4,  -18,   30, 26,  2,  4 },
    {      4,  -19,   30, 26,  2,  4 }, {      3,  -20,   31, 26,  2,  4 }, {      3,  -21,   31, 26,  2,  4 }, {      2,  -22,   32, 26,  2,  4 }, {      2,  -23,   33, 26,  2,  4 },
    {      1,  -24,   33, 27,  2,  4 }, {      1,  -25,   34, 27,  2,  4 }, {      0,  -26,   35, 27,  2,  4 }, {      0,  -27,   35, 27,  2,  4 }, {     -1,  -28,   36, 27,  2,  4 },
    {     -2,  -29,   36, 27,  2,  4 }, {     -2,  -30,   37, 27,  2,  4 }, {     -3,  -31,   38, 27,  2,  4 }, {     -4,  -32,   38, 27,  2,  4 }, {     -4,  -33,   39, 27,  2,  4 },
    {     -5,  -34,   39, 27,  2,  4 }, {     -6,  -35,   40, 27,  2,  4 }, {     -6,  -36,   41, 27,  2,  4 }, {     -7,  -37,   41, 27,  2,  4 }, {     -8,  -38,   42, 27,  2,  4 },
    {     -9,  -39,   43, 27,  2,  4 }, {     -9,  -40,   43, 27,  2,  4 }, {    -10,  -41,   44, 27,  2,  4 }, {    -11,  -42,   44, 28,  2,  4 }, {    -12,  -43,   45, 28,  2,  4 },
    {    -13,  -44,   46, 28,  2,  4 }, {    -14,  -45,   46, 28,  2,  4 }, {    -15,  -46,   47, 28,  2,  4 }, {    -15,  -47,   48, 28,  2,  4 }, {    -16,  -48,   48, 28,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToDiagDown250, {
    {     31,   16,   15,  0,  6,  2 }, {     30,   16,   15,  0,  6,  2 }, {     29,   16,   14,  0,  6,  2 }, {     28,   16,   14,  0,  6,  2 }, {     27,   16,   13,  0,  6,  2 },
    {     26,   16,   12,  0,  6,  2 }, {     25,   16,   12,  0,  6,  2 }, {     24,   16,   11,  0,  6,  2 }, {     23,   16,   11,  0,  6,  2 }, {     22,   15,   10,  0,  6,  2 },
    {     21,   15,   10, 31,  6,  2 }, {     20,   15,    9, 31,  6,  2 }, {     19,   15,    9, 31,  6,  2 }, {     18,   15,    8, 31,  6,  2 }, {     17,   15,    7, 31,  6,  2 },
    {     16,   15,    7, 31,  6,  2 }, {     15,   15,    6, 31,  6,  2 }, {     14,   14,    6, 31,  6,  2 }, {     13,   14,    5, 31,  6,  2 }, {     12,   14,    4, 31,  6,  2 },
    {     11,   14,    4, 31,  6,  2 }, {     10,   14,    3, 31,  6,  2 }, {      9,   13,    3, 31,  6,  2 }, {      8,   13,    2, 31,  6,  2 }, {      7,   13,    2, 31,  6,  2 },
    {      6,   13,    1, 31,  6,  2 }, {      5,   13,    0, 31,  6,  2 }, {      4,   12,    0, 31,  6,  2 }, {      3,   12,   -1, 31,  6,  2 }, {      2,   12,   -1, 31,  6,  2 },
    {      1,   11,   -2, 31,  6,  2 }, {      0,   11,   -3, 31,  6,  2 }, {     -1,   11,   -3, 30,  6,  2 }, {     -2,   11,   -4, 30,  6,  2 }, {     -3,   10,   -4, 30,  6,  2 },
    {     -4,   10,   -5, 30,  6,  2 }, {     -5,   10,   -6, 30,  6,  2 }, {     -6,    9,   -6, 30,  6,  2 }, {     -7,    9,   -7, 30,  6,  2 }, {     -8,    8,   -7, 30,  6,  2 },
    {     -9,    8,   -8, 30,  6,  2 }, {    -10,    8,   -9, 30,  6,  2 }, {    -11,    7,   -9, 30,  6,  2 }, {    -12,    7,  -10, 30,  6,  2 }, {    -13,    7,  -10, 30,  6,  2 },
    {    -14,    6,  -11, 30,  6,  2 }, {    -15,    6,  -12, 30,  6,  2 }, {    -16,    5,  -12, 30,  6,  2 }, {    -17,    5,  -13, 30,  6,  2 }, {    -18,    4,  -14, 30,  6,  2 },
    {    -19,    4,  -14, 30,  6,  2 }, {    -20,    3,  -15, 30,  6,  2 }, {    -21,    3,  -15, 30,  6,  2 }, {    -22,    2,  -16, 30,  6,  2 }, {    -23,    2,  -17, 30,  6,  2 },
    {    -24,    1,  -17, 29,  6,  2 }, {    -25,    1,  -18, 29,  6,  2 }, {    -26,    0,  -19, 29,  6,  2 }, {    -27,    0,  -19, 29,  6,  2 }, {    -28,   -1,  -20, 29,  6,  2 },
    {    -29,   -2,  -20, 29,  6,  2 }, {    -30,   -2,  -21, 29,  6,  2 }, {    -31,   -3,  -22, 29,  6,  2 }, {    -32,   -4,  -22, 29,  6,  2 }, {    -33,   -4,  -23, 29,  6,  2 },
    {    -34,   -5,  -23, 29,  6,  2 }, {    -35,   -6,  -24, 29,  6,  2 }, {    -36,   -6,  -25, 29,  6,  2 }, {    -37,   -7,  -25, 29,  6,  2 }, {    -38,   -8,  -26, 29,  6,  2 },
    {    -39,   -9,  -27, 29,  6,  2 }, {    -40,   -9,  -27, 29,  6,  2 }, {    -41,  -10,  -28, 29,  6,  2 }, {    -42,  -11,  -28, 28,  6,  2 }, {    -43,  -12,  -29, 28,  6,  2 },
    {    -44,  -13,  -30, 28,  6,  2 }, {    -45,  -14,  -30, 28,  6,  2 }, {    -46,  -15,  -31, 28,  6,  2 }, {    -47,  -15,  -32, 28,  6,  2 }, {    -48,  -16,  -32, 28,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToDiagDown251, {
    {     16,    0,   16,  8,  6,  2 }, {     16,    1,   15,  8,  6,  2 }, {     16,    2,   15,  8,  6,  2 }, {     16,    3,   14,  8,  6,  2 }, {     16,    4,   14,  8,  6,  2 },
    {     16,    5,   13,  8,  6,  2 }, {     16,    6,   12,  8,  6,  2 }, {     16,    7,   12,  8,  6,  2 }, {     16,    8,   11,  8,  6,  2 }, {     16,    9,   11,  8,  6,  2 },
    {     15,   10,   10,  8,  6,  2 }, {     15,   11,   10,  7,  6,  2 }, {     15,   12,    9,  7,  6,  2 }, {     15,   13,    9,  7,  6,  2 }, {     15,   14,    8,  7,  6,  2 },
    {     15,   15,    7,  7,  6,  2 }, {     15,   16,    7,  7,  6,  2 }, {     15,   17,    6,  7,  6,  2 }, {     14,   18,    6,  7,  6,  2 }, {     14,   19,    5,  7,  6,  2 },
    {     14,   20,    4,  7,  6,  2 }, {     14,   21,    4,  7,  6,  2 }, {     14,   22,    3,  7,  6,  2 }, {     13,   23,    3,  7,  6,  2 }, {     13,   24,    2,  7,  6,  2 },
    {     13,   25,    2,  7,  6,  2 }, {     13,   26,    1,  7,  6,  2 }, {     13,   27,    0,  7,  6,  2 }, {     12,   28,    0,  7,  6,  2 }, {     12,   29,   -1,  7,  6,  2 },
    {     12,   30,   -1,  7,  6,  2 }, {     11,   31,   -2,  7,  6,  2 }, {     11,   32,   -3,  7,  6,  2 }, {     11,   33,   -3,  6,  6,  2 }, {     11,   34,   -4,  6,  6,  2 },
    {     10,   35,   -4,  6,  6,  2 }, {     10,   36,   -5,  6,  6,  2 }, {     10,   37,   -6,  6,  6,  2 }, {      9,   38,   -6,  6,  6,  2 }, {      9,   39,   -7,  6,  6,  2 },
    {      8,   40,   -7,  6,  6,  2 }, {      8,   41,   -8,  6,  6,  2 }, {      8,   42,   -9,  6,  6,  2 }, {      7,   43,   -9,  6,  6,  2 }, {      7,   44,  -10,  6,  6,  2 },
    {      7,   45,  -10,  6,  6,  2 }, {      6,   46,  -11,  6,  6,  2 }, {      6,   47,  -12,  6,  6,  2 }, {      5,   48,  -12,  6,  6,  2 }, {      5,   49,  -13,  6,  6,  2 },
    {      4,   50,  -14,  6,  6,  2 }, {      4,   51,  -14,  6,  6,  2 }, {      3,   52,  -15,  6,  6,  2 }, {      3,   53,  -15,  6,  6,  2 }, {      2,   54,  -16,  6,  6,  2 },
    {      2,   55,  -17,  6,  6,  2 }, {      1,   56,  -17,  5,  6,  2 }, {      1,   57,  -18,  5,  6,  2 }, {      0,   58,  -19,  5,  6,  2 }, {      0,   59,  -19,  5,  6,  2 },
    {     -1,   60,  -20,  5,  6,  2 }, {     -2,   61,  -20,  5,  6,  2 }, {     -2,   62,  -21,  5,  6,  2 }, {     -3,   63,  -22,  5,  6,  2 }, {     -4,   64,  -22,  5,  6,  2 },
    {     -4,   65,  -23,  5,  6,  2 }, {     -5,   66,  -23,  5,  6,  2 }, {     -6,   67,  -24,  5,  6,  2 }, {     -6,   68,  -25,  5,  6,  2 }, {     -7,   69,  -25,  5,  6,  2 },
    {     -8,   70,  -26,  5,  6,  2 }, {     -9,   71,  -27,  5,  6,  2 }, {     -9,   72,  -27,  5,  6,  2 }, {    -10,   73,  -28,  5,  6,  2 }, {    -11,   74,  -28,  4,  6,  2 },
    {    -12,   75,  -29,  4,  6,  2 }, {    -13,   76,  -30,  4,  6,  2 }, {    -14,   77,  -30,  4,  6,  2 }, {    -15,   78,  -31,  4,  6,  2 }, {    -15,   79,  -32,  4,  6,  2 },
    {    -16,   80,  -32,  4,  6,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToDiagDown252, {
    {      0,   16,   16, 16,  6,  2 }, {      1,   16,   15, 16,  6,  2 }, {      2,   16,   15, 16,  6,  2 }, {      3,   16,   14, 16,  6,  2 }, {      4,   16,   14, 16,  6,  2 },
    {      5,   16,   13, 16,  6,  2 }, {      6,   16,   12, 16,  6,  2 }, {      7,   16,   12, 16,  6,  2 }, {      8,   16,   11, 16,  6,  2 }, {      9,   16,   11, 16,  6,  2 },
    {     10,   17,   10, 16,  6,  2 }, {     11,   17,   10, 15,  6,  2 }, {     12,   17,    9, 15,  6,  2 }, {     13,   17,    9, 15,  6,  2 }, {     14,   17,    8, 15,  6,  2 },
    {     15,   17,    7, 15,  6,  2 }, {     16,   17,    7, 15,  6,  2 }, {     17,   17,    6, 15,  6,  2 }, {     18,   18,    6, 15,  6,  2 }, {     19,   18,    5, 15,  6,  2 },
    {     20,   18,    4, 15,  6,  2 }, {     21,   18,    4, 15,  6,  2 }, {     22,   18,    3, 15,  6,  2 }, {     23,   19,    3, 15,  6,  2 }, {     24,   19,    2, 15,  6,  2 },
    {     25,   19,    2, 15,  6,  2 }, {     26,   19,    1, 15,  6,  2 }, {     27,   19,    0, 15,  6,  2 }, {     28,   20,    0, 15,  6,  2 }, {     29,   20,   -1, 15,  6,  2 },
    {     30,   20,   -1, 15,  6,  2 }, {     31,   21,   -2, 15,  6,  2 }, {     32,   21,   -3, 15,  6,  2 }, {     33,   21,   -3, 14,  6,  2 }, {     34,   21,   -4, 14,  6,  2 },
    {     35,   22,   -4, 14,  6,  2 }, {     36,   22,   -5, 14,  6,  2 }, {     37,   22,   -6, 14,  6,  2 }, {     38,   23,   -6, 14,  6,  2 }, {     39,   23,   -7, 14,  6,  2 },
    {     40,   24,   -7, 14,  6,  2 }, {     41,   24,   -8, 14,  6,  2 }, {     42,   24,   -9, 14,  6,  2 }, {     43,   25,   -9, 14,  6,  2 }, {     44,   25,  -10, 14,  6,  2 },
    {     45,   25,  -10, 14,  6,  2 }, {     46,   26,  -11, 14,  6,  2 }, {     47,   26,  -12, 14,  6,  2 }, {     48,   27,  -12, 14,  6,  2 }, {     49,   27,  -13, 14,  6,  2 },
    {     50,   28,  -14, 14,  6,  2 }, {     51,   28,  -14, 14,  6,  2 }, {     52,   29,  -15, 14,  6,  2 }, {     53,   29,  -15, 14,  6,  2 }, {     54,   30,  -16, 14,  6,  2 },
    {     55,   30,  -17, 14,  6,  2 }, {     56,   31,  -17, 13,  6,  2 }, {     57,   31,  -18, 13,  6,  2 }, {     58,   32,  -19, 13,  6,  2 }, {     59,   32,  -19, 13,  6,  2 },
    {     60,   33,  -20, 13,  6,  2 }, {     61,   34,  -20, 13,  6,  2 }, {     62,   34,  -21, 13,  6,  2 }, {     63,   35,  -22, 13,  6,  2 }, {     64,   36,  -22, 13,  6,  2 },
    {     65,   36,  -23, 13,  6,  2 }, {     66,   37,  -23, 13,  6,  2 }, {     67,   38,  -24, 13,  6,  2 }, {     68,   38,  -25, 13,  6,  2 }, {     69,   39,  -25, 13,  6,  2 },
    {     70,   40,  -26, 13,  6,  2 }, {     71,   41,  -27, 13,  6,  2 }, {     72,   41,  -27, 13,  6,  2 }, {     73,   42,  -28, 13,  6,  2 }, {     74,   43,  -28, 12,  6,  2 },
    {     75,   44,  -29, 12,  6,  2 }, {     76,   45,  -30, 12,  6,  2 }, {     77,   46,  -30, 12,  6,  2 }, {     78,   47,  -31, 12,  6,  2 }, {     79,   47,  -32, 12,  6,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToDiagDown253, {
    {     16,   31,   15, 24,  6,  2 }, {     16,   30,   15, 24,  6,  2 }, {     16,   29,   14, 24,  6,  2 }, {     16,   28,   14, 24,  6,  2 }, {     16,   27,   13, 24,  6,  2 },
    {     16,   26,   12, 24,  6,  2 }, {     16,   25,   12, 24,  6,  2 }, {     16,   24,   11, 24,  6,  2 }, {     16,   23,   11, 24,  6,  2 }, {     17,   22,   10, 24,  6,  2 },
    {     17,   21,   10, 23,  6,  2 }, {     17,   20,    9, 23,  6,  2 }, {     17,   19,    9, 23,  6,  2 }, {     17,   18,    8, 23,  6,  2 }, {     17,   17,    7, 23,  6,  2 },
    {     17,   16,    7, 23,  6,  2 }, {     17,   15,    6, 23,  6,  2 }, {     18,   14,    6, 23,  6,  2 }, {     18,   13,    5, 23,  6,  2 }, {     18,   12,    4, 23,  6,  2 },
    {     18,   11,    4, 23,  6,  2 }, {     18,   10,    3, 23,  6,  2 }, {     19,    9,    3, 23,  6,  2 }, {     19,    8,    2, 23,  6,  2 }, {     19,    7,    2, 23,  6,  2 },
    {     19,    6,    1, 23,  6,  2 }, {     19,    5,    0, 23,  6,  2 }, {     20,    4,    0, 23,  6,  2 }, {     20,    3,   -1, 23,  6,  2 }, {     20,    2,   -1, 23,  6,  2 },
    {     21,    1,   -2, 23,  6,  2 }, {     21,    0,   -3, 23,  6,  2 }, {     21,   -1,   -3, 22,  6,  2 }, {     21,   -2,   -4, 22,  6,  2 }, {     22,   -3,   -4, 22,  6,  2 },
    {     22,   -4,   -5, 22,  6,  2 }, {     22,   -5,   -6, 22,  6,  2 }, {     23,   -6,   -6, 22,  6,  2 }, {     23,   -7,   -7, 22,  6,  2 }, {     24,   -8,   -7, 22,  6,  2 },
    {     24,   -9,   -8, 22,  6,  2 }, {     24,  -10,   -9, 22,  6,  2 }, {     25,  -11,   -9, 22,  6,  2 }, {     25,  -12,  -10, 22,  6,  2 }, {     25,  -13,  -10, 22,  6,  2 },
    {     26,  -14,  -11, 22,  6,  2 }, {     26,  -15,  -12, 22,  6,  2 }, {     27,  -16,  -12, 22,  6,  2 }, {     27,  -17,  -13, 22,  6,  2 }, {     28,  -18,  -14, 22,  6,  2 },
    {     28,  -19,  -14, 22,  6,  2 }, {     29,  -20,  -15, 22,  6,  2 }, {     29,  -21,  -15, 22,  6,  2 }, {     30,  -22,  -16, 22,  6,  2 }, {     30,  -23,  -17, 22,  6,  2 },
    {     31,  -24,  -17, 21,  6,  2 }, {     31,  -25,  -18, 21,  6,  2 }, {     32,  -26,  -19, 21,  6,  2 }, {     32,  -27,  -19, 21,  6,  2 }, {     33,  -28,  -20, 21,  6,  2 },
    {     34,  -29,  -20, 21,  6,  2 }, {     34,  -30,  -21, 21,  6,  2 }, {     35,  -31,  -22, 21,  6,  2 }, {     36,  -32,  -22, 21,  6,  2 }, {     36,  -33,  -23, 21,  6,  2 },
    {     37,  -34,  -23, 21,  6,  2 }, {     38,  -35,  -24, 21,  6,  2 }, {     38,  -36,  -25, 21,  6,  2 }, {     39,  -37,  -25, 21,  6,  2 }, {     40,  -38,  -26, 21,  6,  2 },
    {     41,  -39,  -27, 21,  6,  2 }, {     41,  -40,  -27, 21,  6,  2 }, {     42,  -41,  -28, 21,  6,  2 }, {     43,  -42,  -28, 20,  6,  2 }, {     44,  -43,  -29, 20,  6,  2 },
    {     45,  -44,  -30, 20,  6,  2 }, {     46,  -45,  -30, 20,  6,  2 }, {     47,  -46,  -31, 20,  6,  2 }, {     47,  -47,  -32, 20,  6,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToDiagDown250, {
    {     31,   16,   15,  0,  6,  4 }, {     30,   16,   15,  0,  6,  4 }, {     29,   16,   14,  0,  6,  4 }, {     28,   16,   14,  0,  6,  4 }, {     27,   16,   13,  0,  6,  4 },
    {     26,   16,   12,  0,  6,  4 }, {     25,   16,   12,  0,  6,  4 }, {     24,   16,   11,  0,  6,  4 }, {     23,   16,   11,  0,  6,  4 }, {     22,   17,   10,  0,  6,  4 },
    {     21,   17,   10,  1,  6,  4 }, {     20,   17,    9,  1,  6,  4 }, {     19,   17,    9,  1,  6,  4 }, {     18,   17,    8,  1,  6,  4 }, {     17,   17,    7,  1,  6,  4 },
    {     16,   17,    7,  1,  6,  4 }, {     15,   17,    6,  1,  6,  4 }, {     14,   18,    6,  1,  6,  4 }, {     13,   18,    5,  1,  6,  4 }, {     12,   18,    4,  1,  6,  4 },
    {     11,   18,    4,  1,  6,  4 }, {     10,   18,    3,  1,  6,  4 }, {      9,   19,    3,  1,  6,  4 }, {      8,   19,    2,  1,  6,  4 }, {      7,   19,    2,  1,  6,  4 },
    {      6,   19,    1,  1,  6,  4 }, {      5,   19,    0,  1,  6,  4 }, {      4,   20,    0,  1,  6,  4 }, {      3,   20,   -1,  1,  6,  4 }, {      2,   20,   -1,  1,  6,  4 },
    {      1,   21,   -2,  1,  6,  4 }, {      0,   21,   -3,  1,  6,  4 }, {     -1,   21,   -3,  2,  6,  4 }, {     -2,   21,   -4,  2,  6,  4 }, {     -3,   22,   -4,  2,  6,  4 },
    {     -4,   22,   -5,  2,  6,  4 }, {     -5,   22,   -6,  2,  6,  4 }, {     -6,   23,   -6,  2,  6,  4 }, {     -7,   23,   -7,  2,  6,  4 }, {     -8,   24,   -7,  2,  6,  4 },
    {     -9,   24,   -8,  2,  6,  4 }, {    -10,   24,   -9,  2,  6,  4 }, {    -11,   25,   -9,  2,  6,  4 }, {    -12,   25,  -10,  2,  6,  4 }, {    -13,   25,  -10,  2,  6,  4 },
    {    -14,   26,  -11,  2,  6,  4 }, {    -15,   26,  -12,  2,  6,  4 }, {    -16,   27,  -12,  2,  6,  4 }, {    -17,   27,  -13,  2,  6,  4 }, {    -18,   28,  -14,  2,  6,  4 },
    {    -19,   28,  -14,  2,  6,  4 }, {    -20,   29,  -15,  2,  6,  4 }, {    -21,   29,  -15,  2,  6,  4 }, {    -22,   30,  -16,  2,  6,  4 }, {    -23,   30,  -17,  2,  6,  4 },
    {    -24,   31,  -17,  3,  6,  4 }, {    -25,   31,  -18,  3,  6,  4 }, {    -26,   32,  -19,  3,  6,  4 }, {    -27,   32,  -19,  3,  6,  4 }, {    -28,   33,  -20,  3,  6,  4 },
    {    -29,   34,  -20,  3,  6,  4 }, {    -30,   34,  -21,  3,  6,  4 }, {    -31,   35,  -22,  3,  6,  4 }, {    -32,   36,  -22,  3,  6,  4 }, {    -33,   36,  -23,  3,  6,  4 },
    {    -34,   37,  -23,  3,  6,  4 }, {    -35,   38,  -24,  3,  6,  4 }, {    -36,   38,  -25,  3,  6,  4 }, {    -37,   39,  -25,  3,  6,  4 }, {    -38,   40,  -26,  3,  6,  4 },
    {    -39,   41,  -27,  3,  6,  4 }, {    -40,   41,  -27,  3,  6,  4 }, {    -41,   42,  -28,  3,  6,  4 }, {    -42,   43,  -28,  4,  6,  4 }, {    -43,   44,  -29,  4,  6,  4 },
    {    -44,   45,  -30,  4,  6,  4 }, {    -45,   46,  -30,  4,  6,  4 }, {    -46,   47,  -31,  4,  6,  4 }, {    -47,   47,  -32,  4,  6,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToDiagDown251, {
    {     16,    0,   16,  8,  6,  4 }, {     16,    1,   15,  8,  6,  4 }, {     16,    2,   15,  8,  6,  4 }, {     16,    3,   14,  8,  6,  4 }, {     16,    4,   14,  8,  6,  4 },
    {     16,    5,   13,  8,  6,  4 }, {     16,    6,   12,  8,  6,  4 }, {     16,    7,   12,  8,  6,  4 }, {     16,    8,   11,  8,  6,  4 }, {     16,    9,   11,  8,  6,  4 },
    {     17,   10,   10,  8,  6,  4 }, {     17,   11,   10,  9,  6,  4 }, {     17,   12,    9,  9,  6,  4 }, {     17,   13,    9,  9,  6,  4 }, {     17,   14,    8,  9,  6,  4 },
    {     17,   15,    7,  9,  6,  4 }, {     17,   16,    7,  9,  6,  4 }, {     17,   17,    6,  9,  6,  4 }, {     18,   18,    6,  9,  6,  4 }, {     18,   19,    5,  9,  6,  4 },
    {     18,   20,    4,  9,  6,  4 }, {     18,   21,    4,  9,  6,  4 }, {     18,   22,    3,  9,  6,  4 }, {     19,   23,    3,  9,  6,  4 }, {     19,   24,    2,  9,  6,  4 },
    {     19,   25,    2,  9,  6,  4 }, {     19,   26,    1,  9,  6,  4 }, {     19,   27,    0,  9,  6,  4 }, {     20,   28,    0,  9,  6,  4 }, {     20,   29,   -1,  9,  6,  4 },
    {     20,   30,   -1,  9,  6,  4 }, {     21,   31,   -2,  9,  6,  4 }, {     21,   32,   -3,  9,  6,  4 }, {     21,   33,   -3, 10,  6,  4 }, {     21,   34,   -4, 10,  6,  4 },
    {     22,   35,   -4, 10,  6,  4 }, {     22,   36,   -5, 10,  6,  4 }, {     22,   37,   -6, 10,  6,  4 }, {     23,   38,   -6, 10,  6,  4 }, {     23,   39,   -7, 10,  6,  4 },
    {     24,   40,   -7, 10,  6,  4 }, {     24,   41,   -8, 10,  6,  4 }, {     24,   42,   -9, 10,  6,  4 }, {     25,   43,   -9, 10,  6,  4 }, {     25,   44,  -10, 10,  6,  4 },
    {     25,   45,  -10, 10,  6,  4 }, {     26,   46,  -11, 10,  6,  4 }, {     26,   47,  -12, 10,  6,  4 }, {     27,   48,  -12, 10,  6,  4 }, {     27,   49,  -13, 10,  6,  4 },
    {     28,   50,  -14, 10,  6,  4 }, {     28,   51,  -14, 10,  6,  4 }, {     29,   52,  -15, 10,  6,  4 }, {     29,   53,  -15, 10,  6,  4 }, {     30,   54,  -16, 10,  6,  4 },
    {     30,   55,  -17, 10,  6,  4 }, {     31,   56,  -17, 11,  6,  4 }, {     31,   57,  -18, 11,  6,  4 }, {     32,   58,  -19, 11,  6,  4 }, {     32,   59,  -19, 11,  6,  4 },
    {     33,   60,  -20, 11,  6,  4 }, {     34,   61,  -20, 11,  6,  4 }, {     34,   62,  -21, 11,  6,  4 }, {     35,   63,  -22, 11,  6,  4 }, {     36,   64,  -22, 11,  6,  4 },
    {     36,   65,  -23, 11,  6,  4 }, {     37,   66,  -23, 11,  6,  4 }, {     38,   67,  -24, 11,  6,  4 }, {     38,   68,  -25, 11,  6,  4 }, {     39,   69,  -25, 11,  6,  4 },
    {     40,   70,  -26, 11,  6,  4 }, {     41,   71,  -27, 11,  6,  4 }, {     41,   72,  -27, 11,  6,  4 }, {     42,   73,  -28, 11,  6,  4 }, {     43,   74,  -28, 12,  6,  4 },
    {     44,   75,  -29, 12,  6,  4 }, {     45,   76,  -30, 12,  6,  4 }, {     46,   77,  -30, 12,  6,  4 }, {     47,   78,  -31, 12,  6,  4 }, {     47,   79,  -32, 12,  6,  4 },
    {     48,   80,  -32, 12,  6,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToDiagDown252, {
    {      0,   16,   16, 16,  6,  4 }, {      1,   16,   15, 16,  6,  4 }, {      2,   16,   15, 16,  6,  4 }, {      3,   16,   14, 16,  6,  4 }, {      4,   16,   14, 16,  6,  4 },
    {      5,   16,   13, 16,  6,  4 }, {      6,   16,   12, 16,  6,  4 }, {      7,   16,   12, 16,  6,  4 }, {      8,   16,   11, 16,  6,  4 }, {      9,   16,   11, 16,  6,  4 },
    {     10,   15,   10, 16,  6,  4 }, {     11,   15,   10, 17,  6,  4 }, {     12,   15,    9, 17,  6,  4 }, {     13,   15,    9, 17,  6,  4 }, {     14,   15,    8, 17,  6,  4 },
    {     15,   15,    7, 17,  6,  4 }, {     16,   15,    7, 17,  6,  4 }, {     17,   15,    6, 17,  6,  4 }, {     18,   14,    6, 17,  6,  4 }, {     19,   14,    5, 17,  6,  4 },
    {     20,   14,    4, 17,  6,  4 }, {     21,   14,    4, 17,  6,  4 }, {     22,   14,    3, 17,  6,  4 }, {     23,   13,    3, 17,  6,  4 }, {     24,   13,    2, 17,  6,  4 },
    {     25,   13,    2, 17,  6,  4 }, {     26,   13,    1, 17,  6,  4 }, {     27,   13,    0, 17,  6,  4 }, {     28,   12,    0, 17,  6,  4 }, {     29,   12,   -1, 17,  6,  4 },
    {     30,   12,   -1, 17,  6,  4 }, {     31,   11,   -2, 17,  6,  4 }, {     32,   11,   -3, 17,  6,  4 }, {     33,   11,   -3, 18,  6,  4 }, {     34,   11,   -4, 18,  6,  4 },
    {     35,   10,   -4, 18,  6,  4 }, {     36,   10,   -5, 18,  6,  4 }, {     37,   10,   -6, 18,  6,  4 }, {     38,    9,   -6, 18,  6,  4 }, {     39,    9,   -7, 18,  6,  4 },
    {     40,    8,   -7, 18,  6,  4 }, {     41,    8,   -8, 18,  6,  4 }, {     42,    8,   -9, 18,  6,  4 }, {     43,    7,   -9, 18,  6,  4 }, {     44,    7,  -10, 18,  6,  4 },
    {     45,    7,  -10, 18,  6,  4 }, {     46,    6,  -11, 18,  6,  4 }, {     47,    6,  -12, 18,  6,  4 }, {     48,    5,  -12, 18,  6,  4 }, {     49,    5,  -13, 18,  6,  4 },
    {     50,    4,  -14, 18,  6,  4 }, {     51,    4,  -14, 18,  6,  4 }, {     52,    3,  -15, 18,  6,  4 }, {     53,    3,  -15, 18,  6,  4 }, {     54,    2,  -16, 18,  6,  4 },
    {     55,    2,  -17, 18,  6,  4 }, {     56,    1,  -17, 19,  6,  4 }, {     57,    1,  -18, 19,  6,  4 }, {     58,    0,  -19, 19,  6,  4 }, {     59,    0,  -19, 19,  6,  4 },
    {     60,   -1,  -20, 19,  6,  4 }, {     61,   -2,  -20, 19,  6,  4 }, {     62,   -2,  -21, 19,  6,  4 }, {     63,   -3,  -22, 19,  6,  4 }, {     64,   -4,  -22, 19,  6,  4 },
    {     65,   -4,  -23, 19,  6,  4 }, {     66,   -5,  -23, 19,  6,  4 }, {     67,   -6,  -24, 19,  6,  4 }, {     68,   -6,  -25, 19,  6,  4 }, {     69,   -7,  -25, 19,  6,  4 },
    {     70,   -8,  -26, 19,  6,  4 }, {     71,   -9,  -27, 19,  6,  4 }, {     72,   -9,  -27, 19,  6,  4 }, {     73,  -10,  -28, 19,  6,  4 }, {     74,  -11,  -28, 20,  6,  4 },
    {     75,  -12,  -29, 20,  6,  4 }, {     76,  -13,  -30, 20,  6,  4 }, {     77,  -14,  -30, 20,  6,  4 }, {     78,  -15,  -31, 20,  6,  4 }, {     79,  -15,  -32, 20,  6,  4 },
    {     80,  -16,  -32, 20,  6,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToDiagDown253, {
    {     16,   31,   15, 24,  6,  4 }, {     16,   30,   15, 24,  6,  4 }, {     16,   29,   14, 24,  6,  4 }, {     16,   28,   14, 24,  6,  4 }, {     16,   27,   13, 24,  6,  4 },
    {     16,   26,   12, 24,  6,  4 }, {     16,   25,   12, 24,  6,  4 }, {     16,   24,   11, 24,  6,  4 }, {     16,   23,   11, 24,  6,  4 }, {     15,   22,   10, 24,  6,  4 },
    {     15,   21,   10, 25,  6,  4 }, {     15,   20,    9, 25,  6,  4 }, {     15,   19,    9, 25,  6,  4 }, {     15,   18,    8, 25,  6,  4 }, {     15,   17,    7, 25,  6,  4 },
    {     15,   16,    7, 25,  6,  4 }, {     15,   15,    6, 25,  6,  4 }, {     14,   14,    6, 25,  6,  4 }, {     14,   13,    5, 25,  6,  4 }, {     14,   12,    4, 25,  6,  4 },
    {     14,   11,    4, 25,  6,  4 }, {     14,   10,    3, 25,  6,  4 }, {     13,    9,    3, 25,  6,  4 }, {     13,    8,    2, 25,  6,  4 }, {     13,    7,    2, 25,  6,  4 },
    {     13,    6,    1, 25,  6,  4 }, {     13,    5,    0, 25,  6,  4 }, {     12,    4,    0, 25,  6,  4 }, {     12,    3,   -1, 25,  6,  4 }, {     12,    2,   -1, 25,  6,  4 },
    {     11,    1,   -2, 25,  6,  4 }, {     11,    0,   -3, 25,  6,  4 }, {     11,   -1,   -3, 26,  6,  4 }, {     11,   -2,   -4, 26,  6,  4 }, {     10,   -3,   -4, 26,  6,  4 },
    {     10,   -4,   -5, 26,  6,  4 }, {     10,   -5,   -6, 26,  6,  4 }, {      9,   -6,   -6, 26,  6,  4 }, {      9,   -7,   -7, 26,  6,  4 }, {      8,   -8,   -7, 26,  6,  4 },
    {      8,   -9,   -8, 26,  6,  4 }, {      8,  -10,   -9, 26,  6,  4 }, {      7,  -11,   -9, 26,  6,  4 }, {      7,  -12,  -10, 26,  6,  4 }, {      7,  -13,  -10, 26,  6,  4 },
    {      6,  -14,  -11, 26,  6,  4 }, {      6,  -15,  -12, 26,  6,  4 }, {      5,  -16,  -12, 26,  6,  4 }, {      5,  -17,  -13, 26,  6,  4 }, {      4,  -18,  -14, 26,  6,  4 },
    {      4,  -19,  -14, 26,  6,  4 }, {      3,  -20,  -15, 26,  6,  4 }, {      3,  -21,  -15, 26,  6,  4 }, {      2,  -22,  -16, 26,  6,  4 }, {      2,  -23,  -17, 26,  6,  4 },
    {      1,  -24,  -17, 27,  6,  4 }, {      1,  -25,  -18, 27,  6,  4 }, {      0,  -26,  -19, 27,  6,  4 }, {      0,  -27,  -19, 27,  6,  4 }, {     -1,  -28,  -20, 27,  6,  4 },
    {     -2,  -29,  -20, 27,  6,  4 }, {     -2,  -30,  -21, 27,  6,  4 }, {     -3,  -31,  -22, 27,  6,  4 }, {     -4,  -32,  -22, 27,  6,  4 }, {     -4,  -33,  -23, 27,  6,  4 },
    {     -5,  -34,  -23, 27,  6,  4 }, {     -6,  -35,  -24, 27,  6,  4 }, {     -6,  -36,  -25, 27,  6,  4 }, {     -7,  -37,  -25, 27,  6,  4 }, {     -8,  -38,  -26, 27,  6,  4 },
    {     -9,  -39,  -27, 27,  6,  4 }, {     -9,  -40,  -27, 27,  6,  4 }, {    -10,  -41,  -28, 27,  6,  4 }, {    -11,  -42,  -28, 28,  6,  4 }, {    -12,  -43,  -29, 28,  6,  4 },
    {    -13,  -44,  -30, 28,  6,  4 }, {    -14,  -45,  -30, 28,  6,  4 }, {    -15,  -46,  -31, 28,  6,  4 }, {    -15,  -47,  -32, 28,  6,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToOrthogonalUp250, {
    {     15,   16,    1,  4,  2,  2 }, {     14,   17,    2,  4,  2,  2 }, {     13,   18,    2,  4,  2,  2 }, {     12,   19,    3,  4,  2,  2 }, {     11,   20,    3,  4,  2,  2 },
    {     10,   21,    4,  3,  2,  2 }, {      9,   22,    5,  3,  2,  2 }, {      8,   22,    5,  3,  2,  2 }, {      7,   23,    6,  3,  2,  2 }, {      6,   24,    7,  3,  2,  2 },
    {      5,   25,    7,  3,  2,  2 }, {      4,   25,    8,  3,  2,  2 }, {      3,   26,    8,  3,  2,  2 }, {      2,   27,    9,  3,  2,  2 }, {      1,   27,   10,  3,  2,  2 },
    {      0,   28,   10,  3,  2,  2 }, {     -1,   29,   11,  3,  2,  2 }, {     -2,   29,   12,  3,  2,  2 }, {     -3,   30,   12,  3,  2,  2 }, {     -4,   30,   13,  3,  2,  2 },
    {     -5,   31,   13,  3,  2,  2 }, {     -6,   32,   14,  3,  2,  2 }, {     -7,   32,   15,  3,  2,  2 }, {     -8,   33,   15,  2,  2,  2 }, {     -9,   33,   16,  2,  2,  2 },
    {    -10,   34,   17,  2,  2,  2 }, {    -11,   34,   17,  2,  2,  2 }, {    -12,   35,   18,  2,  2,  2 }, {    -13,   35,   18,  2,  2,  2 }, {    -14,   36,   19,  2,  2,  2 },
    {    -15,   36,   20,  2,  2,  2 }, {    -16,   37,   20,  2,  2,  2 }, {    -17,   37,   21,  2,  2,  2 }, {    -18,   37,   21,  2,  2,  2 }, {    -19,   38,   22,  2,  2,  2 },
    {    -20,   38,   23,  2,  2,  2 }, {    -21,   39,   23,  2,  2,  2 }, {    -22,   39,   24,  2,  2,  2 }, {    -23,   39,   24,  2,  2,  2 }, {    -24,   40,   25,  2,  2,  2 },
    {    -25,   40,   26,  2,  2,  2 }, {    -26,   41,   26,  2,  2,  2 }, {    -27,   41,   27,  2,  2,  2 }, {    -28,   41,   28,  2,  2,  2 }, {    -29,   42,   28,  2,  2,  2 },
    {    -30,   42,   29,  2,  2,  2 }, {    -31,   42,   29,  1,  2,  2 }, {    -32,   42,   30,  1,  2,  2 }, {    -33,   43,   31,  1,  2,  2 }, {    -34,   43,   31,  1,  2,  2 },
    {    -35,   43,   32,  1,  2,  2 }, {    -36,   44,   32,  1,  2,  2 }, {    -37,   44,   33,  1,  2,  2 }, {    -38,   44,   33,  1,  2,  2 }, {    -39,   44,   34,  1,  2,  2 },
    {    -40,   44,   35,  1,  2,  2 }, {    -41,   45,   35,  1,  2,  2 }, {    -42,   45,   36,  1,  2,  2 }, {    -43,   45,   36,  1,  2,  2 }, {    -44,   45,   37,  1,  2,  2 },
    {    -45,   45,   38,  1,  2,  2 }, {    -46,   46,   38,  1,  2,  2 }, {    -47,   46,   39,  1,  2,  2 }, {    -48,   46,   39,  1,  2,  2 }, {    -49,   46,   40,  1,  2,  2 },
    {    -50,   46,   40,  1,  2,  2 }, {    -51,   46,   41,  1,  2,  2 }, {    -52,   46,   42,  1,  2,  2 }, {    -53,   46,   42,  0,  2,  2 }, {    -54,   47,   43,  0,  2,  2 },
    {    -55,   47,   43,  0,  2,  2 }, {    -56,   47,   44,  0,  2,  2 }, {    -57,   47,   44,  0,  2,  2 }, {    -58,   47,   45,  0,  2,  2 }, {    -59,   47,   46,  0,  2,  2 },
    {    -60,   47,   46,  0,  2,  2 }, {    -61,   47,   47,  0,  2,  2 }, {    -62,   47,   47,  0,  2,  2 }, {    -63,   47,   48,  0,  2,  2 }, {    -64,   47,   48,  0,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToOrthogonalUp251, {
    {     16,   16,    0, 12,  2,  2 }, {     17,   17,    1, 12,  2,  2 }, {     18,   18,    2, 12,  2,  2 }, {     19,   19,    2, 12,  2,  2 }, {     20,   20,    3, 12,  2,  2 },
    {     21,   21,    3, 12,  2,  2 }, {     22,   22,    4, 11,  2,  2 }, {     23,   23,    5, 11,  2,  2 }, {     23,   24,    5, 11,  2,  2 }, {     24,   25,    6, 11,  2,  2 },
    {     25,   26,    7, 11,  2,  2 }, {     26,   27,    7, 11,  2,  2 }, {     26,   28,    8, 11,  2,  2 }, {     27,   29,    8, 11,  2,  2 }, {     28,   30,    9, 11,  2,  2 },
    {     28,   31,   10, 11,  2,  2 }, {     29,   32,   10, 11,  2,  2 }, {     30,   33,   11, 11,  2,  2 }, {     30,   34,   12, 11,  2,  2 }, {     31,   35,   12, 11,  2,  2 },
    {     31,   36,   13, 11,  2,  2 }, {     32,   37,   13, 11,  2,  2 }, {     33,   38,   14, 11,  2,  2 }, {     33,   39,   15, 11,  2,  2 }, {     34,   40,   15, 10,  2,  2 },
    {     34,   41,   16, 10,  2,  2 }, {     35,   42,   17, 10,  2,  2 }, {     35,   43,   17, 10,  2,  2 }, {     36,   44,   18, 10,  2,  2 }, {     36,   45,   18, 10,  2,  2 },
    {     37,   46,   19, 10,  2,  2 }, {     37,   47,   20, 10,  2,  2 }, {     38,   48,   20, 10,  2,  2 }, {     38,   49,   21, 10,  2,  2 }, {     38,   50,   21, 10,  2,  2 },
    {     39,   51,   22, 10,  2,  2 }, {     39,   52,   23, 10,  2,  2 }, {     40,   53,   23, 10,  2,  2 }, {     40,   54,   24, 10,  2,  2 }, {     40,   55,   24, 10,  2,  2 },
    {     41,   56,   25, 10,  2,  2 }, {     41,   57,   26, 10,  2,  2 }, {     42,   58,   26, 10,  2,  2 }, {     42,   59,   27, 10,  2,  2 }, {     42,   60,   28, 10,  2,  2 },
    {     43,   61,   28, 10,  2,  2 }, {     43,   62,   29, 10,  2,  2 }, {     43,   63,   29,  9,  2,  2 }, {     43,   64,   30,  9,  2,  2 }, {     44,   65,   31,  9,  2,  2 },
    {     44,   66,   31,  9,  2,  2 }, {     44,   67,   32,  9,  2,  2 }, {     45,   68,   32,  9,  2,  2 }, {     45,   69,   33,  9,  2,  2 }, {     45,   70,   33,  9,  2,  2 },
    {     45,   71,   34,  9,  2,  2 }, {     45,   72,   35,  9,  2,  2 }, {     46,   73,   35,  9,  2,  2 }, {     46,   74,   36,  9,  2,  2 }, {     46,   75,   36,  9,  2,  2 },
    {     46,   76,   37,  9,  2,  2 }, {     46,   77,   38,  9,  2,  2 }, {     47,   78,   38,  9,  2,  2 }, {     47,   79,   39,  9,  2,  2 }, {     47,   80,   39,  9,  2,  2 },
    {     47,   81,   40,  9,  2,  2 }, {     47,   82,   40,  9,  2,  2 }, {     47,   83,   41,  9,  2,  2 }, {     47,   84,   42,  9,  2,  2 }, {     47,   85,   42,  8,  2,  2 },
    {     48,   86,   43,  8,  2,  2 }, {     48,   87,   43,  8,  2,  2 }, {     48,   88,   44,  8,  2,  2 }, {     48,   89,   44,  8,  2,  2 }, {     48,   90,   45,  8,  2,  2 },
    {     48,   91,   46,  8,  2,  2 }, {     48,   92,   46,  8,  2,  2 }, {     48,   93,   47,  8,  2,  2 }, {     48,   94,   47,  8,  2,  2 }, {     48,   95,   48,  8,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToOrthogonalUp252, {
    {     16,   15,    0, 20,  2,  2 }, {     17,   14,    1, 20,  2,  2 }, {     18,   13,    2, 20,  2,  2 }, {     19,   12,    2, 20,  2,  2 }, {     20,   11,    3, 20,  2,  2 },
    {     21,   10,    3, 20,  2,  2 }, {     22,    9,    4, 19,  2,  2 }, {     23,    8,    5, 19,  2,  2 }, {     24,    8,    5, 19,  2,  2 }, {     25,    7,    6, 19,  2,  2 },
    {     26,    6,    7, 19,  2,  2 }, {     27,    5,    7, 19,  2,  2 }, {     28,    5,    8, 19,  2,  2 }, {     29,    4,    8, 19,  2,  2 }, {     30,    3,    9, 19,  2,  2 },
    {     31,    3,   10, 19,  2,  2 }, {     32,    2,   10, 19,  2,  2 }, {     33,    1,   11, 19,  2,  2 }, {     34,    1,   12, 19,  2,  2 }, {     35,    0,   12, 19,  2,  2 },
    {     36,    0,   13, 19,  2,  2 }, {     37,   -1,   13, 19,  2,  2 }, {     38,   -2,   14, 19,  2,  2 }, {     39,   -2,   15, 19,  2,  2 }, {     40,   -3,   15, 18,  2,  2 },
    {     41,   -3,   16, 18,  2,  2 }, {     42,   -4,   17, 18,  2,  2 }, {     43,   -4,   17, 18,  2,  2 }, {     44,   -5,   18, 18,  2,  2 }, {     45,   -5,   18, 18,  2,  2 },
    {     46,   -6,   19, 18,  2,  2 }, {     47,   -6,   20, 18,  2,  2 }, {     48,   -7,   20, 18,  2,  2 }, {     49,   -7,   21, 18,  2,  2 }, {     50,   -7,   21, 18,  2,  2 },
    {     51,   -8,   22, 18,  2,  2 }, {     52,   -8,   23, 18,  2,  2 }, {     53,   -9,   23, 18,  2,  2 }, {     54,   -9,   24, 18,  2,  2 }, {     55,   -9,   24, 18,  2,  2 },
    {     56,  -10,   25, 18,  2,  2 }, {     57,  -10,   26, 18,  2,  2 }, {     58,  -11,   26, 18,  2,  2 }, {     59,  -11,   27, 18,  2,  2 }, {     60,  -11,   28, 18,  2,  2 },
    {     61,  -12,   28, 18,  2,  2 }, {     62,  -12,   29, 18,  2,  2 }, {     63,  -12,   29, 17,  2,  2 }, {     64,  -12,   30, 17,  2,  2 }, {     65,  -13,   31, 17,  2,  2 },
    {     66,  -13,   31, 17,  2,  2 }, {     67,  -13,   32, 17,  2,  2 }, {     68,  -14,   32, 17,  2,  2 }, {     69,  -14,   33, 17,  2,  2 }, {     70,  -14,   33, 17,  2,  2 },
    {     71,  -14,   34, 17,  2,  2 }, {     72,  -14,   35, 17,  2,  2 }, {     73,  -15,   35, 17,  2,  2 }, {     74,  -15,   36, 17,  2,  2 }, {     75,  -15,   36, 17,  2,  2 },
    {     76,  -15,   37, 17,  2,  2 }, {     77,  -15,   38, 17,  2,  2 }, {     78,  -16,   38, 17,  2,  2 }, {     79,  -16,   39, 17,  2,  2 }, {     80,  -16,   39, 17,  2,  2 },
    {     81,  -16,   40, 17,  2,  2 }, {     82,  -16,   40, 17,  2,  2 }, {     83,  -16,   41, 17,  2,  2 }, {     84,  -16,   42, 17,  2,  2 }, {     85,  -16,   42, 16,  2,  2 },
    {     86,  -17,   43, 16,  2,  2 }, {     87,  -17,   43, 16,  2,  2 }, {     88,  -17,   44, 16,  2,  2 }, {     89,  -17,   44, 16,  2,  2 }, {     90,  -17,   45, 16,  2,  2 },
    {     91,  -17,   46, 16,  2,  2 }, {     92,  -17,   46, 16,  2,  2 }, {     93,  -17,   47, 16,  2,  2 }, {     94,  -17,   47, 16,  2,  2 }, {     95,  -17,   48, 16,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToOrthogonalUp253, {
    {     15,   15,    1, 28,  2,  2 }, {     14,   14,    2, 28,  2,  2 }, {     13,   13,    2, 28,  2,  2 }, {     12,   12,    3, 28,  2,  2 }, {     11,   11,    3, 28,  2,  2 },
    {     10,   10,    4, 27,  2,  2 }, {      9,    9,    5, 27,  2,  2 }, {      9,    8,    5, 27,  2,  2 }, {      8,    7,    6, 27,  2,  2 }, {      7,    6,    7, 27,  2,  2 },
    {      6,    5,    7, 27,  2,  2 }, {      6,    4,    8, 27,  2,  2 }, {      5,    3,    8, 27,  2,  2 }, {      4,    2,    9, 27,  2,  2 }, {      4,    1,   10, 27,  2,  2 },
    {      3,    0,   10, 27,  2,  2 }, {      2,   -1,   11, 27,  2,  2 }, {      2,   -2,   12, 27,  2,  2 }, {      1,   -3,   12, 27,  2,  2 }, {      1,   -4,   13, 27,  2,  2 },
    {      0,   -5,   13, 27,  2,  2 }, {     -1,   -6,   14, 27,  2,  2 }, {     -1,   -7,   15, 27,  2,  2 }, {     -2,   -8,   15, 26,  2,  2 }, {     -2,   -9,   16, 26,  2,  2 },
    {     -3,  -10,   17, 26,  2,  2 }, {     -3,  -11,   17, 26,  2,  2 }, {     -4,  -12,   18, 26,  2,  2 }, {     -4,  -13,   18, 26,  2,  2 }, {     -5,  -14,   19, 26,  2,  2 },
    {     -5,  -15,   20, 26,  2,  2 }, {     -6,  -16,   20, 26,  2,  2 }, {     -6,  -17,   21, 26,  2,  2 }, {     -6,  -18,   21, 26,  2,  2 }, {     -7,  -19,   22, 26,  2,  2 },
    {     -7,  -20,   23, 26,  2,  2 }, {     -8,  -21,   23, 26,  2,  2 }, {     -8,  -22,   24, 26,  2,  2 }, {     -8,  -23,   24, 26,  2,  2 }, {     -9,  -24,   25, 26,  2,  2 },
    {     -9,  -25,   26, 26,  2,  2 }, {    -10,  -26,   26, 26,  2,  2 }, {    -10,  -27,   27, 26,  2,  2 }, {    -10,  -28,   28, 26,  2,  2 }, {    -11,  -29,   28, 26,  2,  2 },
    {    -11,  -30,   29, 26,  2,  2 }, {    -11,  -31,   29, 25,  2,  2 }, {    -11,  -32,   30, 25,  2,  2 }, {    -12,  -33,   31, 25,  2,  2 }, {    -12,  -34,   31, 25,  2,  2 },
    {    -12,  -35,   32, 25,  2,  2 }, {    -13,  -36,   32, 25,  2,  2 }, {    -13,  -37,   33, 25,  2,  2 }, {    -13,  -38,   33, 25,  2,  2 }, {    -13,  -39,   34, 25,  2,  2 },
    {    -13,  -40,   35, 25,  2,  2 }, {    -14,  -41,   35, 25,  2,  2 }, {    -14,  -42,   36, 25,  2,  2 }, {    -14,  -43,   36, 25,  2,  2 }, {    -14,  -44,   37, 25,  2,  2 },
    {    -14,  -45,   38, 25,  2,  2 }, {    -15,  -46,   38, 25,  2,  2 }, {    -15,  -47,   39, 25,  2,  2 }, {    -15,  -48,   39, 25,  2,  2 }, {    -15,  -49,   40, 25,  2,  2 },
    {    -15,  -50,   40, 25,  2,  2 }, {    -15,  -51,   41, 25,  2,  2 }, {    -15,  -52,   42, 25,  2,  2 }, {    -15,  -53,   42, 24,  2,  2 }, {    -16,  -54,   43, 24,  2,  2 },
    {    -16,  -55,   43, 24,  2,  2 }, {    -16,  -56,   44, 24,  2,  2 }, {    -16,  -57,   44, 24,  2,  2 }, {    -16,  -58,   45, 24,  2,  2 }, {    -16,  -59,   46, 24,  2,  2 },
    {    -16,  -60,   46, 24,  2,  2 }, {    -16,  -61,   47, 24,  2,  2 }, {    -16,  -62,   47, 24,  2,  2 }, {    -16,  -63,   48, 24,  2,  2 }, {    -16,  -64,   48, 24,  2,  2 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToOrthogonalUp250, {
    {     15,   16,    1,  4,  2,  4 }, {     14,   17,    2,  4,  2,  4 }, {     13,   18,    2,  4,  2,  4 }, {     12,   19,    3,  4,  2,  4 }, {     11,   20,    3,  4,  2,  4 },
    {     10,   21,    4,  5,  2,  4 }, {      9,   22,    5,  5,  2,  4 }, {      9,   23,    5,  5,  2,  4 }, {      8,   24,    6,  5,  2,  4 }, {      7,   25,    7,  5,  2,  4 },
    {      6,   26,    7,  5,  2,  4 }, {      6,   27,    8,  5,  2,  4 }, {      5,   28,    8,  5,  2,  4 }, {      4,   29,    9,  5,  2,  4 }, {      4,   30,   10,  5,  2,  4 },
    {      3,   31,   10,  5,  2,  4 }, {      2,   32,   11,  5,  2,  4 }, {      2,   33,   12,  5,  2,  4 }, {      1,   34,   12,  5,  2,  4 }, {      1,   35,   13,  5,  2,  4 },
    {      0,   36,   13,  5,  2,  4 }, {     -1,   37,   14,  5,  2,  4 }, {     -1,   38,   15,  5,  2,  4 }, {     -2,   39,   15,  6,  2,  4 }, {     -2,   40,   16,  6,  2,  4 },
    {     -3,   41,   17,  6,  2,  4 }, {     -3,   42,   17,  6,  2,  4 }, {     -4,   43,   18,  6,  2,  4 }, {     -4,   44,   18,  6,  2,  4 }, {     -5,   45,   19,  6,  2,  4 },
    {     -5,   46,   20,  6,  2,  4 }, {     -6,   47,   20,  6,  2,  4 }, {     -6,   48,   21,  6,  2,  4 }, {     -6,   49,   21,  6,  2,  4 }, {     -7,   50,   22,  6,  2,  4 },
    {     -7,   51,   23,  6,  2,  4 }, {     -8,   52,   23,  6,  2,  4 }, {     -8,   53,   24,  6,  2,  4 }, {     -8,   54,   24,  6,  2,  4 }, {     -9,   55,   25,  6,  2,  4 },
    {     -9,   56,   26,  6,  2,  4 }, {    -10,   57,   26,  6,  2,  4 }, {    -10,   58,   27,  6,  2,  4 }, {    -10,   59,   28,  6,  2,  4 }, {    -11,   60,   28,  6,  2,  4 },
    {    -11,   61,   29,  6,  2,  4 }, {    -11,   62,   29,  7,  2,  4 }, {    -11,   63,   30,  7,  2,  4 }, {    -12,   64,   31,  7,  2,  4 }, {    -12,   65,   31,  7,  2,  4 },
    {    -12,   66,   32,  7,  2,  4 }, {    -13,   67,   32,  7,  2,  4 }, {    -13,   68,   33,  7,  2,  4 }, {    -13,   69,   33,  7,  2,  4 }, {    -13,   70,   34,  7,  2,  4 },
    {    -13,   71,   35,  7,  2,  4 }, {    -14,   72,   35,  7,  2,  4 }, {    -14,   73,   36,  7,  2,  4 }, {    -14,   74,   36,  7,  2,  4 }, {    -14,   75,   37,  7,  2,  4 },
    {    -14,   76,   38,  7,  2,  4 }, {    -15,   77,   38,  7,  2,  4 }, {    -15,   78,   39,  7,  2,  4 }, {    -15,   79,   39,  7,  2,  4 }, {    -15,   80,   40,  7,  2,  4 },
    {    -15,   81,   40,  7,  2,  4 }, {    -15,   82,   41,  7,  2,  4 }, {    -15,   83,   42,  7,  2,  4 }, {    -15,   84,   42,  8,  2,  4 }, {    -16,   85,   43,  8,  2,  4 },
    {    -16,   86,   43,  8,  2,  4 }, {    -16,   87,   44,  8,  2,  4 }, {    -16,   88,   44,  8,  2,  4 }, {    -16,   89,   45,  8,  2,  4 }, {    -16,   90,   46,  8,  2,  4 },
    {    -16,   91,   46,  8,  2,  4 }, {    -16,   92,   47,  8,  2,  4 }, {    -16,   93,   47,  8,  2,  4 }, {    -16,   94,   48,  8,  2,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToOrthogonalUp251, {
    {     16,   16,    0, 12,  2,  4 }, {     17,   17,    1, 12,  2,  4 }, {     18,   18,    2, 12,  2,  4 }, {     19,   19,    2, 12,  2,  4 }, {     20,   20,    3, 12,  2,  4 },
    {     21,   21,    3, 12,  2,  4 }, {     22,   22,    4, 13,  2,  4 }, {     23,   23,    5, 13,  2,  4 }, {     24,   23,    5, 13,  2,  4 }, {     25,   24,    6, 13,  2,  4 },
    {     26,   25,    7, 13,  2,  4 }, {     27,   26,    7, 13,  2,  4 }, {     28,   26,    8, 13,  2,  4 }, {     29,   27,    8, 13,  2,  4 }, {     30,   28,    9, 13,  2,  4 },
    {     31,   28,   10, 13,  2,  4 }, {     32,   29,   10, 13,  2,  4 }, {     33,   30,   11, 13,  2,  4 }, {     34,   30,   12, 13,  2,  4 }, {     35,   31,   12, 13,  2,  4 },
    {     36,   31,   13, 13,  2,  4 }, {     37,   32,   13, 13,  2,  4 }, {     38,   33,   14, 13,  2,  4 }, {     39,   33,   15, 13,  2,  4 }, {     40,   34,   15, 14,  2,  4 },
    {     41,   34,   16, 14,  2,  4 }, {     42,   35,   17, 14,  2,  4 }, {     43,   35,   17, 14,  2,  4 }, {     44,   36,   18, 14,  2,  4 }, {     45,   36,   18, 14,  2,  4 },
    {     46,   37,   19, 14,  2,  4 }, {     47,   37,   20, 14,  2,  4 }, {     48,   38,   20, 14,  2,  4 }, {     49,   38,   21, 14,  2,  4 }, {     50,   38,   21, 14,  2,  4 },
    {     51,   39,   22, 14,  2,  4 }, {     52,   39,   23, 14,  2,  4 }, {     53,   40,   23, 14,  2,  4 }, {     54,   40,   24, 14,  2,  4 }, {     55,   40,   24, 14,  2,  4 },
    {     56,   41,   25, 14,  2,  4 }, {     57,   41,   26, 14,  2,  4 }, {     58,   42,   26, 14,  2,  4 }, {     59,   42,   27, 14,  2,  4 }, {     60,   42,   28, 14,  2,  4 },
    {     61,   43,   28, 14,  2,  4 }, {     62,   43,   29, 14,  2,  4 }, {     63,   43,   29, 15,  2,  4 }, {     64,   43,   30, 15,  2,  4 }, {     65,   44,   31, 15,  2,  4 },
    {     66,   44,   31, 15,  2,  4 }, {     67,   44,   32, 15,  2,  4 }, {     68,   45,   32, 15,  2,  4 }, {     69,   45,   33, 15,  2,  4 }, {     70,   45,   33, 15,  2,  4 },
    {     71,   45,   34, 15,  2,  4 }, {     72,   45,   35, 15,  2,  4 }, {     73,   46,   35, 15,  2,  4 }, {     74,   46,   36, 15,  2,  4 }, {     75,   46,   36, 15,  2,  4 },
    {     76,   46,   37, 15,  2,  4 }, {     77,   46,   38, 15,  2,  4 }, {     78,   47,   38, 15,  2,  4 }, {     79,   47,   39, 15,  2,  4 }, {     80,   47,   39, 15,  2,  4 },
    {     81,   47,   40, 15,  2,  4 }, {     82,   47,   40, 15,  2,  4 }, {     83,   47,   41, 15,  2,  4 }, {     84,   47,   42, 15,  2,  4 }, {     85,   47,   42, 16,  2,  4 },
    {     86,   48,   43, 16,  2,  4 }, {     87,   48,   43, 16,  2,  4 }, {     88,   48,   44, 16,  2,  4 }, {     89,   48,   44, 16,  2,  4 }, {     90,   48,   45, 16,  2,  4 },
    {     91,   48,   46, 16,  2,  4 }, {     92,   48,   46, 16,  2,  4 }, {     93,   48,   47, 16,  2,  4 }, {     94,   48,   47, 16,  2,  4 }, {     95,   48,   48, 16,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToOrthogonalUp252, {
    {     16,   15,    0, 20,  2,  4 }, {     17,   14,    1, 20,  2,  4 }, {     18,   13,    2, 20,  2,  4 }, {     19,   12,    2, 20,  2,  4 }, {     20,   11,    3, 20,  2,  4 },
    {     21,   10,    3, 20,  2,  4 }, {     22,    9,    4, 21,  2,  4 }, {     23,    8,    5, 21,  2,  4 }, {     23,    7,    5, 21,  2,  4 }, {     24,    6,    6, 21,  2,  4 },
    {     25,    5,    7, 21,  2,  4 }, {     26,    4,    7, 21,  2,  4 }, {     26,    3,    8, 21,  2,  4 }, {     27,    2,    8, 21,  2,  4 }, {     28,    1,    9, 21,  2,  4 },
    {     28,    0,   10, 21,  2,  4 }, {     29,   -1,   10, 21,  2,  4 }, {     30,   -2,   11, 21,  2,  4 }, {     30,   -3,   12, 21,  2,  4 }, {     31,   -4,   12, 21,  2,  4 },
    {     31,   -5,   13, 21,  2,  4 }, {     32,   -6,   13, 21,  2,  4 }, {     33,   -7,   14, 21,  2,  4 }, {     33,   -8,   15, 21,  2,  4 }, {     34,   -9,   15, 22,  2,  4 },
    {     34,  -10,   16, 22,  2,  4 }, {     35,  -11,   17, 22,  2,  4 }, {     35,  -12,   17, 22,  2,  4 }, {     36,  -13,   18, 22,  2,  4 }, {     36,  -14,   18, 22,  2,  4 },
    {     37,  -15,   19, 22,  2,  4 }, {     37,  -16,   20, 22,  2,  4 }, {     38,  -17,   20, 22,  2,  4 }, {     38,  -18,   21, 22,  2,  4 }, {     38,  -19,   21, 22,  2,  4 },
    {     39,  -20,   22, 22,  2,  4 }, {     39,  -21,   23, 22,  2,  4 }, {     40,  -22,   23, 22,  2,  4 }, {     40,  -23,   24, 22,  2,  4 }, {     40,  -24,   24, 22,  2,  4 },
    {     41,  -25,   25, 22,  2,  4 }, {     41,  -26,   26, 22,  2,  4 }, {     42,  -27,   26, 22,  2,  4 }, {     42,  -28,   27, 22,  2,  4 }, {     42,  -29,   28, 22,  2,  4 },
    {     43,  -30,   28, 22,  2,  4 }, {     43,  -31,   29, 22,  2,  4 }, {     43,  -32,   29, 23,  2,  4 }, {     43,  -33,   30, 23,  2,  4 }, {     44,  -34,   31, 23,  2,  4 },
    {     44,  -35,   31, 23,  2,  4 }, {     44,  -36,   32, 23,  2,  4 }, {     45,  -37,   32, 23,  2,  4 }, {     45,  -38,   33, 23,  2,  4 }, {     45,  -39,   33, 23,  2,  4 },
    {     45,  -40,   34, 23,  2,  4 }, {     45,  -41,   35, 23,  2,  4 }, {     46,  -42,   35, 23,  2,  4 }, {     46,  -43,   36, 23,  2,  4 }, {     46,  -44,   36, 23,  2,  4 },
    {     46,  -45,   37, 23,  2,  4 }, {     46,  -46,   38, 23,  2,  4 }, {     47,  -47,   38, 23,  2,  4 }, {     47,  -48,   39, 23,  2,  4 }, {     47,  -49,   39, 23,  2,  4 },
    {     47,  -50,   40, 23,  2,  4 }, {     47,  -51,   40, 23,  2,  4 }, {     47,  -52,   41, 23,  2,  4 }, {     47,  -53,   42, 23,  2,  4 }, {     47,  -54,   42, 24,  2,  4 },
    {     48,  -55,   43, 24,  2,  4 }, {     48,  -56,   43, 24,  2,  4 }, {     48,  -57,   44, 24,  2,  4 }, {     48,  -58,   44, 24,  2,  4 }, {     48,  -59,   45, 24,  2,  4 },
    {     48,  -60,   46, 24,  2,  4 }, {     48,  -61,   46, 24,  2,  4 }, {     48,  -62,   47, 24,  2,  4 }, {     48,  -63,   47, 24,  2,  4 }, {     48,  -64,   48, 24,  2,  4 },
    {     48,  -65,   48, 24,  2,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToOrthogonalUp253, {
    {     15,   15,    1, 28,  2,  4 }, {     14,   14,    2, 28,  2,  4 }, {     13,   13,    2, 28,  2,  4 }, {     12,   12,    3, 28,  2,  4 }, {     11,   11,    3, 28,  2,  4 },
    {     10,   10,    4, 29,  2,  4 }, {      9,    9,    5, 29,  2,  4 }, {      8,    9,    5, 29,  2,  4 }, {      7,    8,    6, 29,  2,  4 }, {      6,    7,    7, 29,  2,  4 },
    {      5,    6,    7, 29,  2,  4 }, {      4,    6,    8, 29,  2,  4 }, {      3,    5,    8, 29,  2,  4 }, {      2,    4,    9, 29,  2,  4 }, {      1,    4,   10, 29,  2,  4 },
    {      0,    3,   10, 29,  2,  4 }, {     -1,    2,   11, 29,  2,  4 }, {     -2,    2,   12, 29,  2,  4 }, {     -3,    1,   12, 29,  2,  4 }, {     -4,    1,   13, 29,  2,  4 },
    {     -5,    0,   13, 29,  2,  4 }, {     -6,   -1,   14, 29,  2,  4 }, {     -7,   -1,   15, 29,  2,  4 }, {     -8,   -2,   15, 30,  2,  4 }, {     -9,   -2,   16, 30,  2,  4 },
    {    -10,   -3,   17, 30,  2,  4 }, {    -11,   -3,   17, 30,  2,  4 }, {    -12,   -4,   18, 30,  2,  4 }, {    -13,   -4,   18, 30,  2,  4 }, {    -14,   -5,   19, 30,  2,  4 },
    {    -15,   -5,   20, 30,  2,  4 }, {    -16,   -6,   20, 30,  2,  4 }, {    -17,   -6,   21, 30,  2,  4 }, {    -18,   -6,   21, 30,  2,  4 }, {    -19,   -7,   22, 30,  2,  4 },
    {    -20,   -7,   23, 30,  2,  4 }, {    -21,   -8,   23, 30,  2,  4 }, {    -22,   -8,   24, 30,  2,  4 }, {    -23,   -8,   24, 30,  2,  4 }, {    -24,   -9,   25, 30,  2,  4 },
    {    -25,   -9,   26, 30,  2,  4 }, {    -26,  -10,   26, 30,  2,  4 }, {    -27,  -10,   27, 30,  2,  4 }, {    -28,  -10,   28, 30,  2,  4 }, {    -29,  -11,   28, 30,  2,  4 },
    {    -30,  -11,   29, 30,  2,  4 }, {    -31,  -11,   29, 31,  2,  4 }, {    -32,  -11,   30, 31,  2,  4 }, {    -33,  -12,   31, 31,  2,  4 }, {    -34,  -12,   31, 31,  2,  4 },
    {    -35,  -12,   32, 31,  2,  4 }, {    -36,  -13,   32, 31,  2,  4 }, {    -37,  -13,   33, 31,  2,  4 }, {    -38,  -13,   33, 31,  2,  4 }, {    -39,  -13,   34, 31,  2,  4 },
    {    -40,  -13,   35, 31,  2,  4 }, {    -41,  -14,   35, 31,  2,  4 }, {    -42,  -14,   36, 31,  2,  4 }, {    -43,  -14,   36, 31,  2,  4 }, {    -44,  -14,   37, 31,  2,  4 },
    {    -45,  -14,   38, 31,  2,  4 }, {    -46,  -15,   38, 31,  2,  4 }, {    -47,  -15,   39, 31,  2,  4 }, {    -48,  -15,   39, 31,  2,  4 }, {    -49,  -15,   40, 31,  2,  4 },
    {    -50,  -15,   40, 31,  2,  4 }, {    -51,  -15,   41, 31,  2,  4 }, {    -52,  -15,   42, 31,  2,  4 }, {    -53,  -15,   42,  0,  2,  4 }, {    -54,  -16,   43,  0,  2,  4 },
    {    -55,  -16,   43,  0,  2,  4 }, {    -56,  -16,   44,  0,  2,  4 }, {    -57,  -16,   44,  0,  2,  4 }, {    -58,  -16,   45,  0,  2,  4 }, {    -59,  -16,   46,  0,  2,  4 },
    {    -60,  -16,   46,  0,  2,  4 }, {    -61,  -16,   47,  0,  2,  4 }, {    -62,  -16,   47,  0,  2,  4 }, {    -63,  -16,   48,  0,  2,  4 }, {    -64,  -16,   48,  0,  2,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToOrthogonalDown250, {
    {     15,   16,   15,  4,  6,  2 }, {     14,   17,   14,  4,  6,  2 }, {     13,   18,   14,  4,  6,  2 }, {     12,   19,   13,  4,  6,  2 }, {     11,   20,   13,  4,  6,  2 },
    {     10,   21,   12,  3,  6,  2 }, {      9,   22,   11,  3,  6,  2 }, {      8,   22,   11,  3,  6,  2 }, {      7,   23,   10,  3,  6,  2 }, {      6,   24,    9,  3,  6,  2 },
    {      5,   25,    9,  3,  6,  2 }, {      4,   25,    8,  3,  6,  2 }, {      3,   26,    8,  3,  6,  2 }, {      2,   27,    7,  3,  6,  2 }, {      1,   27,    6,  3,  6,  2 },
    {      0,   28,    6,  3,  6,  2 }, {     -1,   29,    5,  3,  6,  2 }, {     -2,   29,    4,  3,  6,  2 }, {     -3,   30,    4,  3,  6,  2 }, {     -4,   30,    3,  3,  6,  2 },
    {     -5,   31,    3,  3,  6,  2 }, {     -6,   32,    2,  3,  6,  2 }, {     -7,   32,    1,  3,  6,  2 }, {     -8,   33,    1,  2,  6,  2 }, {     -9,   33,    0,  2,  6,  2 },
    {    -10,   34,   -1,  2,  6,  2 }, {    -11,   34,   -1,  2,  6,  2 }, {    -12,   35,   -2,  2,  6,  2 }, {    -13,   35,   -2,  2,  6,  2 }, {    -14,   36,   -3,  2,  6,  2 },
    {    -15,   36,   -4,  2,  6,  2 }, {    -16,   37,   -4,  2,  6,  2 }, {    -17,   37,   -5,  2,  6,  2 }, {    -18,   37,   -5,  2,  6,  2 }, {    -19,   38,   -6,  2,  6,  2 },
    {    -20,   38,   -7,  2,  6,  2 }, {    -21,   39,   -7,  2,  6,  2 }, {    -22,   39,   -8,  2,  6,  2 }, {    -23,   39,   -8,  2,  6,  2 }, {    -24,   40,   -9,  2,  6,  2 },
    {    -25,   40,  -10,  2,  6,  2 }, {    -26,   41,  -10,  2,  6,  2 }, {    -27,   41,  -11,  2,  6,  2 }, {    -28,   41,  -12,  2,  6,  2 }, {    -29,   42,  -12,  2,  6,  2 },
    {    -30,   42,  -13,  2,  6,  2 }, {    -31,   42,  -13,  1,  6,  2 }, {    -32,   42,  -14,  1,  6,  2 }, {    -33,   43,  -15,  1,  6,  2 }, {    -34,   43,  -15,  1,  6,  2 },
    {    -35,   43,  -16,  1,  6,  2 }, {    -36,   44,  -16,  1,  6,  2 }, {    -37,   44,  -17,  1,  6,  2 }, {    -38,   44,  -17,  1,  6,  2 }, {    -39,   44,  -18,  1,  6,  2 },
    {    -40,   44,  -19,  1,  6,  2 }, {    -41,   45,  -19,  1,  6,  2 }, {    -42,   45,  -20,  1,  6,  2 }, {    -43,   45,  -20,  1,  6,  2 }, {    -44,   45,  -21,  1,  6,  2 },
    {    -45,   45,  -22,  1,  6,  2 }, {    -46,   46,  -22,  1,  6,  2 }, {    -47,   46,  -23,  1,  6,  2 }, {    -48,   46,  -23,  1,  6,  2 }, {    -49,   46,  -24,  1,  6,  2 },
    {    -50,   46,  -24,  1,  6,  2 }, {    -51,   46,  -25,  1,  6,  2 }, {    -52,   46,  -26,  1,  6,  2 }, {    -53,   46,  -26,  0,  6,  2 }, {    -54,   47,  -27,  0,  6,  2 },
    {    -55,   47,  -27,  0,  6,  2 }, {    -56,   47,  -28,  0,  6,  2 }, {    -57,   47,  -28,  0,  6,  2 }, {    -58,   47,  -29,  0,  6,  2 }, {    -59,   47,  -30,  0,  6,  2 },
    {    -60,   47,  -30,  0,  6,  2 }, {    -61,   47,  -31,  0,  6,  2 }, {    -62,   47,  -31,  0,  6,  2 }, {    -63,   47,  -32,  0,  6,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToOrthogonalDown251, {
    {     16,   16,   16, 12,  6,  2 }, {     17,   17,   15, 12,  6,  2 }, {     18,   18,   14, 12,  6,  2 }, {     19,   19,   14, 12,  6,  2 }, {     20,   20,   13, 12,  6,  2 },
    {     21,   21,   13, 12,  6,  2 }, {     22,   22,   12, 11,  6,  2 }, {     23,   23,   11, 11,  6,  2 }, {     23,   24,   11, 11,  6,  2 }, {     24,   25,   10, 11,  6,  2 },
    {     25,   26,    9, 11,  6,  2 }, {     26,   27,    9, 11,  6,  2 }, {     26,   28,    8, 11,  6,  2 }, {     27,   29,    8, 11,  6,  2 }, {     28,   30,    7, 11,  6,  2 },
    {     28,   31,    6, 11,  6,  2 }, {     29,   32,    6, 11,  6,  2 }, {     30,   33,    5, 11,  6,  2 }, {     30,   34,    4, 11,  6,  2 }, {     31,   35,    4, 11,  6,  2 },
    {     31,   36,    3, 11,  6,  2 }, {     32,   37,    3, 11,  6,  2 }, {     33,   38,    2, 11,  6,  2 }, {     33,   39,    1, 11,  6,  2 }, {     34,   40,    1, 10,  6,  2 },
    {     34,   41,    0, 10,  6,  2 }, {     35,   42,   -1, 10,  6,  2 }, {     35,   43,   -1, 10,  6,  2 }, {     36,   44,   -2, 10,  6,  2 }, {     36,   45,   -2, 10,  6,  2 },
    {     37,   46,   -3, 10,  6,  2 }, {     37,   47,   -4, 10,  6,  2 }, {     38,   48,   -4, 10,  6,  2 }, {     38,   49,   -5, 10,  6,  2 }, {     38,   50,   -5, 10,  6,  2 },
    {     39,   51,   -6, 10,  6,  2 }, {     39,   52,   -7, 10,  6,  2 }, {     40,   53,   -7, 10,  6,  2 }, {     40,   54,   -8, 10,  6,  2 }, {     40,   55,   -8, 10,  6,  2 },
    {     41,   56,   -9, 10,  6,  2 }, {     41,   57,  -10, 10,  6,  2 }, {     42,   58,  -10, 10,  6,  2 }, {     42,   59,  -11, 10,  6,  2 }, {     42,   60,  -12, 10,  6,  2 },
    {     43,   61,  -12, 10,  6,  2 }, {     43,   62,  -13, 10,  6,  2 }, {     43,   63,  -13,  9,  6,  2 }, {     43,   64,  -14,  9,  6,  2 }, {     44,   65,  -15,  9,  6,  2 },
    {     44,   66,  -15,  9,  6,  2 }, {     44,   67,  -16,  9,  6,  2 }, {     45,   68,  -16,  9,  6,  2 }, {     45,   69,  -17,  9,  6,  2 }, {     45,   70,  -17,  9,  6,  2 },
    {     45,   71,  -18,  9,  6,  2 }, {     45,   72,  -19,  9,  6,  2 }, {     46,   73,  -19,  9,  6,  2 }, {     46,   74,  -20,  9,  6,  2 }, {     46,   75,  -20,  9,  6,  2 },
    {     46,   76,  -21,  9,  6,  2 }, {     46,   77,  -22,  9,  6,  2 }, {     47,   78,  -22,  9,  6,  2 }, {     47,   79,  -23,  9,  6,  2 }, {     47,   80,  -23,  9,  6,  2 },
    {     47,   81,  -24,  9,  6,  2 }, {     47,   82,  -24,  9,  6,  2 }, {     47,   83,  -25,  9,  6,  2 }, {     47,   84,  -26,  9,  6,  2 }, {     47,   85,  -26,  8,  6,  2 },
    {     48,   86,  -27,  8,  6,  2 }, {     48,   87,  -27,  8,  6,  2 }, {     48,   88,  -28,  8,  6,  2 }, {     48,   89,  -28,  8,  6,  2 }, {     48,   90,  -29,  8,  6,  2 },
    {     48,   91,  -30,  8,  6,  2 }, {     48,   92,  -30,  8,  6,  2 }, {     48,   93,  -31,  8,  6,  2 }, {     48,   94,  -31,  8,  6,  2 }, {     48,   95,  -32,  8,  6,  2 },
    {     48,   96,  -32,  8,  6,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToOrthogonalDown252, {
    {     16,   15,   16, 20,  6,  2 }, {     17,   14,   15, 20,  6,  2 }, {     18,   13,   14, 20,  6,  2 }, {     19,   12,   14, 20,  6,  2 }, {     20,   11,   13, 20,  6,  2 },
    {     21,   10,   13, 20,  6,  2 }, {     22,    9,   12, 19,  6,  2 }, {     23,    8,   11, 19,  6,  2 }, {     24,    8,   11, 19,  6,  2 }, {     25,    7,   10, 19,  6,  2 },
    {     26,    6,    9, 19,  6,  2 }, {     27,    5,    9, 19,  6,  2 }, {     28,    5,    8, 19,  6,  2 }, {     29,    4,    8, 19,  6,  2 }, {     30,    3,    7, 19,  6,  2 },
    {     31,    3,    6, 19,  6,  2 }, {     32,    2,    6, 19,  6,  2 }, {     33,    1,    5, 19,  6,  2 }, {     34,    1,    4, 19,  6,  2 }, {     35,    0,    4, 19,  6,  2 },
    {     36,    0,    3, 19,  6,  2 }, {     37,   -1,    3, 19,  6,  2 }, {     38,   -2,    2, 19,  6,  2 }, {     39,   -2,    1, 19,  6,  2 }, {     40,   -3,    1, 18,  6,  2 },
    {     41,   -3,    0, 18,  6,  2 }, {     42,   -4,   -1, 18,  6,  2 }, {     43,   -4,   -1, 18,  6,  2 }, {     44,   -5,   -2, 18,  6,  2 }, {     45,   -5,   -2, 18,  6,  2 },
    {     46,   -6,   -3, 18,  6,  2 }, {     47,   -6,   -4, 18,  6,  2 }, {     48,   -7,   -4, 18,  6,  2 }, {     49,   -7,   -5, 18,  6,  2 }, {     50,   -7,   -5, 18,  6,  2 },
    {     51,   -8,   -6, 18,  6,  2 }, {     52,   -8,   -7, 18,  6,  2 }, {     53,   -9,   -7, 18,  6,  2 }, {     54,   -9,   -8, 18,  6,  2 }, {     55,   -9,   -8, 18,  6,  2 },
    {     56,  -10,   -9, 18,  6,  2 }, {     57,  -10,  -10, 18,  6,  2 }, {     58,  -11,  -10, 18,  6,  2 }, {     59,  -11,  -11, 18,  6,  2 }, {     60,  -11,  -12, 18,  6,  2 },
    {     61,  -12,  -12, 18,  6,  2 }, {     62,  -12,  -13, 18,  6,  2 }, {     63,  -12,  -13, 17,  6,  2 }, {     64,  -12,  -14, 17,  6,  2 }, {     65,  -13,  -15, 17,  6,  2 },
    {     66,  -13,  -15, 17,  6,  2 }, {     67,  -13,  -16, 17,  6,  2 }, {     68,  -14,  -16, 17,  6,  2 }, {     69,  -14,  -17, 17,  6,  2 }, {     70,  -14,  -17, 17,  6,  2 },
    {     71,  -14,  -18, 17,  6,  2 }, {     72,  -14,  -19, 17,  6,  2 }, {     73,  -15,  -19, 17,  6,  2 }, {     74,  -15,  -20, 17,  6,  2 }, {     75,  -15,  -20, 17,  6,  2 },
    {     76,  -15,  -21, 17,  6,  2 }, {     77,  -15,  -22, 17,  6,  2 }, {     78,  -16,  -22, 17,  6,  2 }, {     79,  -16,  -23, 17,  6,  2 }, {     80,  -16,  -23, 17,  6,  2 },
    {     81,  -16,  -24, 17,  6,  2 }, {     82,  -16,  -24, 17,  6,  2 }, {     83,  -16,  -25, 17,  6,  2 }, {     84,  -16,  -26, 17,  6,  2 }, {     85,  -16,  -26, 16,  6,  2 },
    {     86,  -17,  -27, 16,  6,  2 }, {     87,  -17,  -27, 16,  6,  2 }, {     88,  -17,  -28, 16,  6,  2 }, {     89,  -17,  -28, 16,  6,  2 }, {     90,  -17,  -29, 16,  6,  2 },
    {     91,  -17,  -30, 16,  6,  2 }, {     92,  -17,  -30, 16,  6,  2 }, {     93,  -17,  -31, 16,  6,  2 }, {     94,  -17,  -31, 16,  6,  2 }, {     95,  -17,  -32, 16,  6,  2 },
    {     96,  -17,  -32, 16,  6,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthBankToOrthogonalDown253, {
    {     15,   15,   15, 28,  6,  2 }, {     14,   14,   14, 28,  6,  2 }, {     13,   13,   14, 28,  6,  2 }, {     12,   12,   13, 28,  6,  2 }, {     11,   11,   13, 28,  6,  2 },
    {     10,   10,   12, 27,  6,  2 }, {      9,    9,   11, 27,  6,  2 }, {      9,    8,   11, 27,  6,  2 }, {      8,    7,   10, 27,  6,  2 }, {      7,    6,    9, 27,  6,  2 },
    {      6,    5,    9, 27,  6,  2 }, {      6,    4,    8, 27,  6,  2 }, {      5,    3,    8, 27,  6,  2 }, {      4,    2,    7, 27,  6,  2 }, {      4,    1,    6, 27,  6,  2 },
    {      3,    0,    6, 27,  6,  2 }, {      2,   -1,    5, 27,  6,  2 }, {      2,   -2,    4, 27,  6,  2 }, {      1,   -3,    4, 27,  6,  2 }, {      1,   -4,    3, 27,  6,  2 },
    {      0,   -5,    3, 27,  6,  2 }, {     -1,   -6,    2, 27,  6,  2 }, {     -1,   -7,    1, 27,  6,  2 }, {     -2,   -8,    1, 26,  6,  2 }, {     -2,   -9,    0, 26,  6,  2 },
    {     -3,  -10,   -1, 26,  6,  2 }, {     -3,  -11,   -1, 26,  6,  2 }, {     -4,  -12,   -2, 26,  6,  2 }, {     -4,  -13,   -2, 26,  6,  2 }, {     -5,  -14,   -3, 26,  6,  2 },
    {     -5,  -15,   -4, 26,  6,  2 }, {     -6,  -16,   -4, 26,  6,  2 }, {     -6,  -17,   -5, 26,  6,  2 }, {     -6,  -18,   -5, 26,  6,  2 }, {     -7,  -19,   -6, 26,  6,  2 },
    {     -7,  -20,   -7, 26,  6,  2 }, {     -8,  -21,   -7, 26,  6,  2 }, {     -8,  -22,   -8, 26,  6,  2 }, {     -8,  -23,   -8, 26,  6,  2 }, {     -9,  -24,   -9, 26,  6,  2 },
    {     -9,  -25,  -10, 26,  6,  2 }, {    -10,  -26,  -10, 26,  6,  2 }, {    -10,  -27,  -11, 26,  6,  2 }, {    -10,  -28,  -12, 26,  6,  2 }, {    -11,  -29,  -12, 26,  6,  2 },
    {    -11,  -30,  -13, 26,  6,  2 }, {    -11,  -31,  -13, 25,  6,  2 }, {    -11,  -32,  -14, 25,  6,  2 }, {    -12,  -33,  -15, 25,  6,  2 }, {    -12,  -34,  -15, 25,  6,  2 },
    {    -12,  -35,  -16, 25,  6,  2 }, {    -13,  -36,  -16, 25,  6,  2 }, {    -13,  -37,  -17, 25,  6,  2 }, {    -13,  -38,  -17, 25,  6,  2 }, {    -13,  -39,  -18, 25,  6,  2 },
    {    -13,  -40,  -19, 25,  6,  2 }, {    -14,  -41,  -19, 25,  6,  2 }, {    -14,  -42,  -20, 25,  6,  2 }, {    -14,  -43,  -20, 25,  6,  2 }, {    -14,  -44,  -21, 25,  6,  2 },
    {    -14,  -45,  -22, 25,  6,  2 }, {    -15,  -46,  -22, 25,  6,  2 }, {    -15,  -47,  -23, 25,  6,  2 }, {    -15,  -48,  -23, 25,  6,  2 }, {    -15,  -49,  -24, 25,  6,  2 },
    {    -15,  -50,  -24, 25,  6,  2 }, {    -15,  -51,  -25, 25,  6,  2 }, {    -15,  -52,  -26, 25,  6,  2 }, {    -15,  -53,  -26, 24,  6,  2 }, {    -16,  -54,  -27, 24,  6,  2 },
    {    -16,  -55,  -27, 24,  6,  2 }, {    -16,  -56,  -28, 24,  6,  2 }, {    -16,  -57,  -28, 24,  6,  2 }, {    -16,  -58,  -29, 24,  6,  2 }, {    -16,  -59,  -30, 24,  6,  2 },
    {    -16,  -60,  -30, 24,  6,  2 }, {    -16,  -61,  -31, 24,  6,  2 }, {    -16,  -62,  -31, 24,  6,  2 }, {    -16,  -63,  -32, 24,  6,  2 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToOrthogonalDown250, {
    {     15,   16,   15,  4,  6,  4 }, {     14,   17,   14,  4,  6,  4 }, {     13,   18,   14,  4,  6,  4 }, {     12,   19,   13,  4,  6,  4 }, {     11,   20,   13,  4,  6,  4 },
    {     10,   21,   12,  5,  6,  4 }, {      9,   22,   11,  5,  6,  4 }, {      9,   23,   11,  5,  6,  4 }, {      8,   24,   10,  5,  6,  4 }, {      7,   25,    9,  5,  6,  4 },
    {      6,   26,    9,  5,  6,  4 }, {      6,   27,    8,  5,  6,  4 }, {      5,   28,    8,  5,  6,  4 }, {      4,   29,    7,  5,  6,  4 }, {      4,   30,    6,  5,  6,  4 },
    {      3,   31,    6,  5,  6,  4 }, {      2,   32,    5,  5,  6,  4 }, {      2,   33,    4,  5,  6,  4 }, {      1,   34,    4,  5,  6,  4 }, {      1,   35,    3,  5,  6,  4 },
    {      0,   36,    3,  5,  6,  4 }, {     -1,   37,    2,  5,  6,  4 }, {     -1,   38,    1,  5,  6,  4 }, {     -2,   39,    1,  6,  6,  4 }, {     -2,   40,    0,  6,  6,  4 },
    {     -3,   41,   -1,  6,  6,  4 }, {     -3,   42,   -1,  6,  6,  4 }, {     -4,   43,   -2,  6,  6,  4 }, {     -4,   44,   -2,  6,  6,  4 }, {     -5,   45,   -3,  6,  6,  4 },
    {     -5,   46,   -4,  6,  6,  4 }, {     -6,   47,   -4,  6,  6,  4 }, {     -6,   48,   -5,  6,  6,  4 }, {     -6,   49,   -5,  6,  6,  4 }, {     -7,   50,   -6,  6,  6,  4 },
    {     -7,   51,   -7,  6,  6,  4 }, {     -8,   52,   -7,  6,  6,  4 }, {     -8,   53,   -8,  6,  6,  4 }, {     -8,   54,   -8,  6,  6,  4 }, {     -9,   55,   -9,  6,  6,  4 },
    {     -9,   56,  -10,  6,  6,  4 }, {    -10,   57,  -10,  6,  6,  4 }, {    -10,   58,  -11,  6,  6,  4 }, {    -10,   59,  -12,  6,  6,  4 }, {    -11,   60,  -12,  6,  6,  4 },
    {    -11,   61,  -13,  6,  6,  4 }, {    -11,   62,  -13,  7,  6,  4 }, {    -11,   63,  -14,  7,  6,  4 }, {    -12,   64,  -15,  7,  6,  4 }, {    -12,   65,  -15,  7,  6,  4 },
    {    -12,   66,  -16,  7,  6,  4 }, {    -13,   67,  -16,  7,  6,  4 }, {    -13,   68,  -17,  7,  6,  4 }, {    -13,   69,  -17,  7,  6,  4 }, {    -13,   70,  -18,  7,  6,  4 },
    {    -13,   71,  -19,  7,  6,  4 }, {    -14,   72,  -19,  7,  6,  4 }, {    -14,   73,  -20,  7,  6,  4 }, {    -14,   74,  -20,  7,  6,  4 }, {    -14,   75,  -21,  7,  6,  4 },
    {    -14,   76,  -22,  7,  6,  4 }, {    -15,   77,  -22,  7,  6,  4 }, {    -15,   78,  -23,  7,  6,  4 }, {    -15,   79,  -23,  7,  6,  4 }, {    -15,   80,  -24,  7,  6,  4 },
    {    -15,   81,  -24,  7,  6,  4 }, {    -15,   82,  -25,  7,  6,  4 }, {    -15,   83,  -26,  7,  6,  4 }, {    -15,   84,  -26,  8,  6,  4 }, {    -16,   85,  -27,  8,  6,  4 },
    {    -16,   86,  -27,  8,  6,  4 }, {    -16,   87,  -28,  8,  6,  4 }, {    -16,   88,  -28,  8,  6,  4 }, {    -16,   89,  -29,  8,  6,  4 }, {    -16,   90,  -30,  8,  6,  4 },
    {    -16,   91,  -30,  8,  6,  4 }, {    -16,   92,  -31,  8,  6,  4 }, {    -16,   93,  -31,  8,  6,  4 }, {    -16,   94,  -32,  8,  6,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToOrthogonalDown251, {
    {     16,   16,   16, 12,  6,  4 }, {     17,   17,   15, 12,  6,  4 }, {     18,   18,   14, 12,  6,  4 }, {     19,   19,   14, 12,  6,  4 }, {     20,   20,   13, 12,  6,  4 },
    {     21,   21,   13, 12,  6,  4 }, {     22,   22,   12, 13,  6,  4 }, {     23,   23,   11, 13,  6,  4 }, {     24,   23,   11, 13,  6,  4 }, {     25,   24,   10, 13,  6,  4 },
    {     26,   25,    9, 13,  6,  4 }, {     27,   26,    9, 13,  6,  4 }, {     28,   26,    8, 13,  6,  4 }, {     29,   27,    8, 13,  6,  4 }, {     30,   28,    7, 13,  6,  4 },
    {     31,   28,    6, 13,  6,  4 }, {     32,   29,    6, 13,  6,  4 }, {     33,   30,    5, 13,  6,  4 }, {     34,   30,    4, 13,  6,  4 }, {     35,   31,    4, 13,  6,  4 },
    {     36,   31,    3, 13,  6,  4 }, {     37,   32,    3, 13,  6,  4 }, {     38,   33,    2, 13,  6,  4 }, {     39,   33,    1, 13,  6,  4 }, {     40,   34,    1, 14,  6,  4 },
    {     41,   34,    0, 14,  6,  4 }, {     42,   35,   -1, 14,  6,  4 }, {     43,   35,   -1, 14,  6,  4 }, {     44,   36,   -2, 14,  6,  4 }, {     45,   36,   -2, 14,  6,  4 },
    {     46,   37,   -3, 14,  6,  4 }, {     47,   37,   -4, 14,  6,  4 }, {     48,   38,   -4, 14,  6,  4 }, {     49,   38,   -5, 14,  6,  4 }, {     50,   38,   -5, 14,  6,  4 },
    {     51,   39,   -6, 14,  6,  4 }, {     52,   39,   -7, 14,  6,  4 }, {     53,   40,   -7, 14,  6,  4 }, {     54,   40,   -8, 14,  6,  4 }, {     55,   40,   -8, 14,  6,  4 },
    {     56,   41,   -9, 14,  6,  4 }, {     57,   41,  -10, 14,  6,  4 }, {     58,   42,  -10, 14,  6,  4 }, {     59,   42,  -11, 14,  6,  4 }, {     60,   42,  -12, 14,  6,  4 },
    {     61,   43,  -12, 14,  6,  4 }, {     62,   43,  -13, 14,  6,  4 }, {     63,   43,  -13, 15,  6,  4 }, {     64,   43,  -14, 15,  6,  4 }, {     65,   44,  -15, 15,  6,  4 },
    {     66,   44,  -15, 15,  6,  4 }, {     67,   44,  -16, 15,  6,  4 }, {     68,   45,  -16, 15,  6,  4 }, {     69,   45,  -17, 15,  6,  4 }, {     70,   45,  -17, 15,  6,  4 },
    {     71,   45,  -18, 15,  6,  4 }, {     72,   45,  -19, 15,  6,  4 }, {     73,   46,  -19, 15,  6,  4 }, {     74,   46,  -20, 15,  6,  4 }, {     75,   46,  -20, 15,  6,  4 },
    {     76,   46,  -21, 15,  6,  4 }, {     77,   46,  -22, 15,  6,  4 }, {     78,   47,  -22, 15,  6,  4 }, {     79,   47,  -23, 15,  6,  4 }, {     80,   47,  -23, 15,  6,  4 },
    {     81,   47,  -24, 15,  6,  4 }, {     82,   47,  -24, 15,  6,  4 }, {     83,   47,  -25, 15,  6,  4 }, {     84,   47,  -26, 15,  6,  4 }, {     85,   47,  -26, 16,  6,  4 },
    {     86,   48,  -27, 16,  6,  4 }, {     87,   48,  -27, 16,  6,  4 }, {     88,   48,  -28, 16,  6,  4 }, {     89,   48,  -28, 16,  6,  4 }, {     90,   48,  -29, 16,  6,  4 },
    {     91,   48,  -30, 16,  6,  4 }, {     92,   48,  -30, 16,  6,  4 }, {     93,   48,  -31, 16,  6,  4 }, {     94,   48,  -31, 16,  6,  4 }, {     95,   48,  -32, 16,  6,  4 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToOrthogonalDown252, {
    {     16,   15,   16, 20,  6,  4 }, {     17,   14,   15, 20,  6,  4 }, {     18,   13,   14, 20,  6,  4 }, {     19,   12,   14, 20,  6,  4 }, {     20,   11,   13, 20,  6,  4 },
    {     21,   10,   13, 20,  6,  4 }, {     22,    9,   12, 21,  6,  4 }, {     23,    8,   11, 21,  6,  4 }, {     23,    7,   11, 21,  6,  4 }, {     24,    6,   10, 21,  6,  4 },
    {     25,    5,    9, 21,  6,  4 }, {     26,    4,    9, 21,  6,  4 }, {     26,    3,    8, 21,  6,  4 }, {     27,    2,    8, 21,  6,  4 }, {     28,    1,    7, 21,  6,  4 },
    {     28,    0,    6, 21,  6,  4 }, {     29,   -1,    6, 21,  6,  4 }, {     30,   -2,    5, 21,  6,  4 }, {     30,   -3,    4, 21,  6,  4 }, {     31,   -4,    4, 21,  6,  4 },
    {     31,   -5,    3, 21,  6,  4 }, {     32,   -6,    3, 21,  6,  4 }, {     33,   -7,    2, 21,  6,  4 }, {     33,   -8,    1, 21,  6,  4 }, {     34,   -9,    1, 22,  6,  4 },
    {     34,  -10,    0, 22,  6,  4 }, {     35,  -11,   -1, 22,  6,  4 }, {     35,  -12,   -1, 22,  6,  4 }, {     36,  -13,   -2, 22,  6,  4 }, {     36,  -14,   -2, 22,  6,  4 },
    {     37,  -15,   -3, 22,  6,  4 }, {     37,  -16,   -4, 22,  6,  4 }, {     38,  -17,   -4, 22,  6,  4 }, {     38,  -18,   -5, 22,  6,  4 }, {     38,  -19,   -5, 22,  6,  4 },
    {     39,  -20,   -6, 22,  6,  4 }, {     39,  -21,   -7, 22,  6,  4 }, {     40,  -22,   -7, 22,  6,  4 }, {     40,  -23,   -8, 22,  6,  4 }, {     40,  -24,   -8, 22,  6,  4 },
    {     41,  -25,   -9, 22,  6,  4 }, {     41,  -26,  -10, 22,  6,  4 }, {     42,  -27,  -10, 22,  6,  4 }, {     42,  -28,  -11, 22,  6,  4 }, {     42,  -29,  -12, 22,  6,  4 },
    {     43,  -30,  -12, 22,  6,  4 }, {     43,  -31,  -13, 22,  6,  4 }, {     43,  -32,  -13, 23,  6,  4 }, {     43,  -33,  -14, 23,  6,  4 }, {     44,  -34,  -15, 23,  6,  4 },
    {     44,  -35,  -15, 23,  6,  4 }, {     44,  -36,  -16, 23,  6,  4 }, {     45,  -37,  -16, 23,  6,  4 }, {     45,  -38,  -17, 23,  6,  4 }, {     45,  -39,  -17, 23,  6,  4 },
    {     45,  -40,  -18, 23,  6,  4 }, {     45,  -41,  -19, 23,  6,  4 }, {     46,  -42,  -19, 23,  6,  4 }, {     46,  -43,  -20, 23,  6,  4 }, {     46,  -44,  -20, 23,  6,  4 },
    {     46,  -45,  -21, 23,  6,  4 }, {     46,  -46,  -22, 23,  6,  4 }, {     47,  -47,  -22, 23,  6,  4 }, {     47,  -48,  -23, 23,  6,  4 }, {     47,  -49,  -23, 23,  6,  4 },
    {     47,  -50,  -24, 23,  6,  4 }, {     47,  -51,  -24, 23,  6,  4 }, {     47,  -52,  -25, 23,  6,  4 }, {     47,  -53,  -26, 23,  6,  4 }, {     47,  -54,  -26, 24,  6,  4 },
    {     48,  -55,  -27, 24,  6,  4 }, {     48,  -56,  -27, 24,  6,  4 }, {     48,  -57,  -28, 24,  6,  4 }, {     48,  -58,  -28, 24,  6,  4 }, {     48,  -59,  -29, 24,  6,  4 },
    {     48,  -60,  -30, 24,  6,  4 }, {     48,  -61,  -30, 24,  6,  4 }, {     48,  -62,  -31, 24,  6,  4 }, {     48,  -63,  -31, 24,  6,  4 }, {     48,  -64,  -32, 24,  6,  4 },
    {     48,  -65,  -32, 24,  6,  4 }, })

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthBankToOrthogonalDown253, {
    {     15,   15,   15, 28,  6,  4 }, {     14,   14,   14, 28,  6,  4 }, {     13,   13,   14, 28,  6,  4 }, {     12,   12,   13, 28,  6,  4 }, {     11,   11,   13, 28,  6,  4 },
    {     10,   10,   12, 29,  6,  4 }, {      9,    9,   11, 29,  6,  4 }, {      8,    9,   11, 29,  6,  4 }, {      7,    8,   10, 29,  6,  4 }, {      6,    7,    9, 29,  6,  4 },
    {      5,    6,    9, 29,  6,  4 }, {      4,    6,    8, 29,  6,  4 }, {      3,    5,    8, 29,  6,  4 }, {      2,    4,    7, 29,  6,  4 }, {      1,    4,    6, 29,  6,  4 },
    {      0,    3,    6, 29,  6,  4 }, {     -1,    2,    5, 29,  6,  4 }, {     -2,    2,    4, 29,  6,  4 }, {     -3,    1,    4, 29,  6,  4 }, {     -4,    1,    3, 29,  6,  4 },
    {     -5,    0,    3, 29,  6,  4 }, {     -6,   -1,    2, 29,  6,  4 }, {     -7,   -1,    1, 29,  6,  4 }, {     -8,   -2,    1, 30,  6,  4 }, {     -9,   -2,    0, 30,  6,  4 },
    {    -10,   -3,   -1, 30,  6,  4 }, {    -11,   -3,   -1, 30,  6,  4 }, {    -12,   -4,   -2, 30,  6,  4 }, {    -13,   -4,   -2, 30,  6,  4 }, {    -14,   -5,   -3, 30,  6,  4 },
    {    -15,   -5,   -4, 30,  6,  4 }, {    -16,   -6,   -4, 30,  6,  4 }, {    -17,   -6,   -5, 30,  6,  4 }, {    -18,   -6,   -5, 30,  6,  4 }, {    -19,   -7,   -6, 30,  6,  4 },
    {    -20,   -7,   -7, 30,  6,  4 }, {    -21,   -8,   -7, 30,  6,  4 }, {    -22,   -8,   -8, 30,  6,  4 }, {    -23,   -8,   -8, 30,  6,  4 }, {    -24,   -9,   -9, 30,  6,  4 },
    {    -25,   -9,  -10, 30,  6,  4 }, {    -26,  -10,  -10, 30,  6,  4 }, {    -27,  -10,  -11, 30,  6,  4 }, {    -28,  -10,  -12, 30,  6,  4 }, {    -29,  -11,  -12, 30,  6,  4 },
    {    -30,  -11,  -13, 30,  6,  4 }, {    -31,  -11,  -13, 31,  6,  4 }, {    -32,  -11,  -14, 31,  6,  4 }, {    -33,  -12,  -15, 31,  6,  4 }, {    -34,  -12,  -15, 31,  6,  4 },
    {    -35,  -12,  -16, 31,  6,  4 }, {    -36,  -13,  -16, 31,  6,  4 }, {    -37,  -13,  -17, 31,  6,  4 }, {    -38,  -13,  -17, 31,  6,  4 }, {    -39,  -13,  -18, 31,  6,  4 },
    {    -40,  -13,  -19, 31,  6,  4 }, {    -41,  -14,  -19, 31,  6,  4 }, {    -42,  -14,  -20, 31,  6,  4 }, {    -43,  -14,  -20, 31,  6,  4 }, {    -44,  -14,  -21, 31,  6,  4 },
    {    -45,  -14,  -22, 31,  6,  4 }, {    -46,  -15,  -22, 31,  6,  4 }, {    -47,  -15,  -23, 31,  6,  4 }, {    -48,  -15,  -23, 31,  6,  4 }, {    -49,  -15,  -24, 31,  6,  4 },
    {    -50,  -15,  -24, 31,  6,  4 }, {    -51,  -15,  -25, 31,  6,  4 }, {    -52,  -15,  -26, 31,  6,  4 }, {    -53,  -15,  -26,  0,  6,  4 }, {    -54,  -16,  -27,  0,  6,  4 },
    {    -55,  -16,  -27,  0,  6,  4 }, {    -56,  -16,  -28,  0,  6,  4 }, {    -57,  -16,  -28,  0,  6,  4 }, {    -58,  -16,  -29,  0,  6,  4 }, {    -59,  -16,  -30,  0,  6,  4 },
    {    -60,  -16,  -30,  0,  6,  4 }, {    -61,  -16,  -31,  0,  6,  4 }, {    -62,  -16,  -31,  0,  6,  4 }, {    -63,  -16,  -32,  0,  6,  4 }, {    -64,  -16,  -32,  0,  6,  4 },
})


CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToUp60LongBase0,{
    {     15,   16,    0,  4,  0,  0 },{     14,   17,    0,  4,  0,  0 },{     13,   18,    0,  4,  0,  0 },{     12,   19,    0,  4,  0,  0 },{     11,   20,    0,  4,  0,  0 },
    {     10,   21,    0,  4,  0,  0 },{      9,   22,    0,  4, 50,  0 },{      8,   23,    1,  4, 50,  0 },{      7,   24,    1,  4, 50,  0 },{      6,   25,    1,  4, 50,  0 },
    {      5,   26,    1,  4, 50,  0 },{      4,   27,    1,  4, 50,  0 },{      3,   28,    2,  4, 50,  0 },{      2,   29,    2,  4, 50,  0 },{      1,   30,    2,  4, 50,  0 },
    {      0,   31,    2,  4, 50,  0 },{     -1,   32,    3,  4, 50,  0 },{     -2,   33,    3,  4, 50,  0 },{     -3,   34,    3,  4, 50,  0 },{     -4,   35,    4,  4, 50,  0 },
    {     -5,   36,    4,  4, 50,  0 },{     -6,   37,    4,  4, 51,  0 },{     -7,   38,    5,  4, 51,  0 },{     -8,   39,    5,  4, 51,  0 },{     -9,   40,    6,  4, 51,  0 },
    {    -10,   41,    6,  4, 51,  0 },{    -11,   42,    6,  4, 51,  0 },{    -12,   43,    7,  4, 51,  0 },{    -13,   44,    7,  4, 51,  0 },{    -14,   45,    8,  4, 51,  0 },
    {    -15,   46,    9,  4, 51,  0 },{    -16,   47,    9,  4, 51,  0 },{    -17,   48,   10,  4, 51,  0 },{    -18,   49,   10,  4,  2,  0 },{    -19,   50,   11,  4,  2,  0 },
    {    -20,   51,   12,  4,  2,  0 },{    -21,   52,   12,  4,  2,  0 },{    -22,   53,   13,  4,  2,  0 },{    -23,   54,   14,  4,  2,  0 },{    -24,   55,   14,  4,  2,  0 },
    {    -25,   56,   15,  4,  2,  0 },{    -26,   57,   16,  4,  2,  0 },{    -27,   58,   17,  4,  2,  0 },{    -28,   59,   17,  4,  2,  0 },{    -29,   60,   18,  4,  2,  0 },
    {    -30,   61,   19,  4,  2,  0 },{    -31,   62,   20,  4,  2,  0 },{    -32,   63,   21,  4,  2,  0 },{    -33,   64,   22,  4,  2,  0 },{    -34,   65,   23,  4,  2,  0 },
    {    -35,   66,   24,  4,  2,  0 },{    -36,   67,   24,  4,  2,  0 },{    -37,   68,   25,  4,  2,  0 },{    -38,   69,   26,  4,  2,  0 },{    -39,   70,   27,  4,  2,  0 },
    {    -40,   71,   28,  4,  2,  0 },{    -41,   72,   29,  4,  3,  0 },{    -42,   73,   30,  4,  3,  0 },{    -43,   74,   31,  4,  3,  0 },{    -44,   75,   32,  4,  3,  0 },
    {    -45,   76,   33,  4,  3,  0 },{    -46,   77,   34,  4,  3,  0 },{    -47,   78,   35,  4,  3,  0 },{    -48,   79,   36,  4,  3,  0 },{    -48,   79,   37,  4,  3,  0 },
    {    -49,   80,   38,  4,  3,  0 },{    -50,   81,   39,  4,  3,  0 },{    -51,   82,   40,  4,  3,  0 },{    -52,   83,   41,  4,  3,  0 },{    -52,   83,   42,  4,  3,  0 },
    {    -53,   84,   43,  4,  3,  0 },{    -54,   85,   44,  4,  3,  0 },{    -55,   86,   45,  4,  3,  0 },{    -55,   86,   46,  4,  3,  0 },{    -56,   87,   47,  4,  3,  0 },
    {    -57,   88,   48,  4,  3,  0 },{    -57,   88,   49,  4,  3,  0 },{    -58,   89,   50,  4,  3,  0 },{    -59,   90,   51,  4,  3,  0 },{    -59,   90,   52,  4,  3,  0 },
    {    -60,   91,   53,  4,  3,  0 },{    -61,   92,   54,  4,  3,  0 },{    -61,   92,   55,  4,  3,  0 },{    -62,   93,   56,  4,  3,  0 },{    -63,   94,   57,  4,  3,  0 },
    {    -63,   94,   58,  4,  3,  0 },{    -64,   95,   59,  4,  3,  0 },{    -65,   96,   60,  4,  3,  0 },{    -65,   96,   61,  4,  3,  0 },{    -66,   97,   62,  4,  3,  0 },
    {    -67,   98,   63,  4,  3,  0 },{    -67,   98,   64,  4,  3,  0 },{    -68,   99,   65,  4,  3,  0 },{    -68,   99,   66,  4,  3,  0 },{    -69,  100,   67,  4,  3,  0 },
    {    -70,  101,   68,  4, 52,  0 },{    -70,  101,   69,  4, 52,  0 },{    -71,  102,   70,  4, 52,  0 },{    -71,  102,   71,  4, 52,  0 },{    -72,  103,   72,  4, 52,  0 },
    {    -72,  103,   73,  4, 52,  0 },{    -73,  104,   74,  4, 52,  0 },{    -73,  104,   75,  4, 52,  0 },{    -74,  105,   76,  4, 52,  0 },{    -75,  106,   77,  4, 52,  0 },
    {    -75,  106,   78,  4, 52,  0 },{    -76,  107,   79,  4, 52,  0 },{    -76,  107,   80,  4, 52,  0 },{    -77,  108,   81,  4, 52,  0 },{    -77,  108,   82,  4, 52,  0 },
    {    -78,  109,   83,  4, 52,  0 },{    -78,  109,   84,  4, 52,  0 },{    -79,  110,   85,  4, 52,  0 },{    -79,  110,   86,  4, 52,  0 },{    -80,  111,   87,  4, 52,  0 },
    {    -80,  111,   88,  4, 52,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToUp60LongBase1,{
    {     16,   16,    0, 12,  0,  0 },{     17,   17,    0, 12,  0,  0 },{     18,   18,    0, 12,  0,  0 },{     19,   19,    0, 12,  0,  0 },{     20,   20,    0, 12,  0,  0 },
    {     21,   21,    0, 12,  0,  0 },{     22,   22,    0, 12,  0,  0 },{     23,   23,    0, 12, 50,  0 },{     24,   24,    1, 12, 50,  0 },{     25,   25,    1, 12, 50,  0 },
    {     26,   26,    1, 12, 50,  0 },{     27,   27,    1, 12, 50,  0 },{     28,   28,    1, 12, 50,  0 },{     29,   29,    2, 12, 50,  0 },{     30,   30,    2, 12, 50,  0 },
    {     31,   31,    2, 12, 50,  0 },{     32,   32,    2, 12, 50,  0 },{     33,   33,    3, 12, 50,  0 },{     34,   34,    3, 12, 50,  0 },{     35,   35,    3, 12, 50,  0 },
    {     36,   36,    4, 12, 50,  0 },{     37,   37,    4, 12, 50,  0 },{     38,   38,    4, 12, 51,  0 },{     39,   39,    5, 12, 51,  0 },{     40,   40,    5, 12, 51,  0 },
    {     41,   41,    6, 12, 51,  0 },{     42,   42,    6, 12, 51,  0 },{     43,   43,    6, 12, 51,  0 },{     44,   44,    7, 12, 51,  0 },{     45,   45,    7, 12, 51,  0 },
    {     46,   46,    8, 12, 51,  0 },{     47,   47,    9, 12, 51,  0 },{     48,   48,    9, 12, 51,  0 },{     49,   49,   10, 12, 51,  0 },{     50,   50,   10, 12,  2,  0 },
    {     51,   51,   11, 12,  2,  0 },{     52,   52,   12, 12,  2,  0 },{     53,   53,   12, 12,  2,  0 },{     54,   54,   13, 12,  2,  0 },{     55,   55,   14, 12,  2,  0 },
    {     56,   56,   14, 12,  2,  0 },{     57,   57,   15, 12,  2,  0 },{     58,   58,   16, 12,  2,  0 },{     59,   59,   17, 12,  2,  0 },{     60,   60,   17, 12,  2,  0 },
    {     61,   61,   18, 12,  2,  0 },{     62,   62,   19, 12,  2,  0 },{     63,   63,   20, 12,  2,  0 },{     64,   64,   21, 12,  2,  0 },{     65,   65,   22, 12,  2,  0 },
    {     66,   66,   23, 12,  2,  0 },{     67,   67,   24, 12,  2,  0 },{     68,   68,   24, 12,  2,  0 },{     69,   69,   25, 12,  2,  0 },{     70,   70,   26, 12,  2,  0 },
    {     71,   71,   27, 12,  2,  0 },{     72,   72,   28, 12,  2,  0 },{     73,   73,   29, 12,  3,  0 },{     74,   74,   30, 12,  3,  0 },{     75,   75,   31, 12,  3,  0 },
    {     76,   76,   32, 12,  3,  0 },{     77,   77,   33, 12,  3,  0 },{     78,   78,   34, 12,  3,  0 },{     79,   79,   35, 12,  3,  0 },{     80,   80,   36, 12,  3,  0 },
    {     80,   80,   37, 12,  3,  0 },{     81,   81,   38, 12,  3,  0 },{     82,   82,   39, 12,  3,  0 },{     83,   83,   40, 12,  3,  0 },{     84,   84,   41, 12,  3,  0 },
    {     84,   84,   42, 12,  3,  0 },{     85,   85,   43, 12,  3,  0 },{     86,   86,   44, 12,  3,  0 },{     87,   87,   45, 12,  3,  0 },{     87,   87,   46, 12,  3,  0 },
    {     88,   88,   47, 12,  3,  0 },{     89,   89,   48, 12,  3,  0 },{     89,   89,   49, 12,  3,  0 },{     90,   90,   50, 12,  3,  0 },{     91,   91,   51, 12,  3,  0 },
    {     91,   91,   52, 12,  3,  0 },{     92,   92,   53, 12,  3,  0 },{     93,   93,   54, 12,  3,  0 },{     93,   93,   55, 12,  3,  0 },{     94,   94,   56, 12,  3,  0 },
    {     95,   95,   57, 12,  3,  0 },{     95,   95,   58, 12,  3,  0 },{     96,   96,   59, 12,  3,  0 },{     97,   97,   60, 12,  3,  0 },{     97,   97,   61, 12,  3,  0 },
    {     98,   98,   62, 12,  3,  0 },{     99,   99,   63, 12,  3,  0 },{     99,   99,   64, 12,  3,  0 },{    100,  100,   65, 12,  3,  0 },{    100,  100,   66, 12,  3,  0 },
    {    101,  101,   67, 12,  3,  0 },{    102,  102,   68, 12, 52,  0 },{    102,  102,   69, 12, 52,  0 },{    103,  103,   70, 12, 52,  0 },{    103,  103,   71, 12, 52,  0 },
    {    104,  104,   72, 12, 52,  0 },{    104,  104,   73, 12, 52,  0 },{    105,  105,   74, 12, 52,  0 },{    105,  105,   75, 12, 52,  0 },{    106,  106,   76, 12, 52,  0 },
    {    107,  107,   77, 12, 52,  0 },{    107,  107,   78, 12, 52,  0 },{    108,  108,   79, 12, 52,  0 },{    108,  108,   80, 12, 52,  0 },{    109,  109,   81, 12, 52,  0 },
    {    109,  109,   82, 12, 52,  0 },{    110,  110,   83, 12, 52,  0 },{    110,  110,   84, 12, 52,  0 },{    111,  111,   85, 12, 52,  0 },{    111,  111,   86, 12, 52,  0 },
    {    112,  112,   87, 12, 52,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToUp60LongBase2,{
    {     16,   15,    0, 20,  0,  0 },{     17,   14,    0, 20,  0,  0 },{     18,   13,    0, 20,  0,  0 },{     19,   12,    0, 20,  0,  0 },{     20,   11,    0, 20,  0,  0 },
    {     21,   10,    0, 20,  0,  0 },{     22,    9,    0, 20,  0,  0 },{     23,    8,    0, 20, 50,  0 },{     24,    7,    1, 20, 50,  0 },{     25,    6,    1, 20, 50,  0 },
    {     26,    5,    1, 20, 50,  0 },{     27,    4,    1, 20, 50,  0 },{     28,    3,    1, 20, 50,  0 },{     29,    2,    2, 20, 50,  0 },{     30,    1,    2, 20, 50,  0 },
    {     31,    0,    2, 20, 50,  0 },{     32,   -1,    2, 20, 50,  0 },{     33,   -2,    3, 20, 50,  0 },{     34,   -3,    3, 20, 50,  0 },{     35,   -4,    3, 20, 50,  0 },
    {     36,   -5,    4, 20, 50,  0 },{     37,   -6,    4, 20, 50,  0 },{     38,   -7,    4, 20, 51,  0 },{     39,   -8,    5, 20, 51,  0 },{     40,   -9,    5, 20, 51,  0 },
    {     41,  -10,    6, 20, 51,  0 },{     42,  -11,    6, 20, 51,  0 },{     43,  -12,    6, 20, 51,  0 },{     44,  -13,    7, 20, 51,  0 },{     45,  -14,    7, 20, 51,  0 },
    {     46,  -15,    8, 20, 51,  0 },{     47,  -16,    9, 20, 51,  0 },{     48,  -17,    9, 20, 51,  0 },{     49,  -18,   10, 20, 51,  0 },{     50,  -19,   10, 20,  2,  0 },
    {     51,  -20,   11, 20,  2,  0 },{     52,  -21,   12, 20,  2,  0 },{     53,  -22,   12, 20,  2,  0 },{     54,  -23,   13, 20,  2,  0 },{     55,  -24,   14, 20,  2,  0 },
    {     56,  -25,   14, 20,  2,  0 },{     57,  -26,   15, 20,  2,  0 },{     58,  -27,   16, 20,  2,  0 },{     59,  -28,   17, 20,  2,  0 },{     60,  -29,   17, 20,  2,  0 },
    {     61,  -30,   18, 20,  2,  0 },{     62,  -31,   19, 20,  2,  0 },{     63,  -32,   20, 20,  2,  0 },{     64,  -33,   21, 20,  2,  0 },{     65,  -34,   22, 20,  2,  0 },
    {     66,  -35,   23, 20,  2,  0 },{     67,  -36,   24, 20,  2,  0 },{     68,  -37,   24, 20,  2,  0 },{     69,  -38,   25, 20,  2,  0 },{     70,  -39,   26, 20,  2,  0 },
    {     71,  -40,   27, 20,  2,  0 },{     72,  -41,   28, 20,  2,  0 },{     73,  -42,   29, 20,  3,  0 },{     74,  -43,   30, 20,  3,  0 },{     75,  -44,   31, 20,  3,  0 },
    {     76,  -45,   32, 20,  3,  0 },{     77,  -46,   33, 20,  3,  0 },{     78,  -47,   34, 20,  3,  0 },{     79,  -48,   35, 20,  3,  0 },{     80,  -49,   36, 20,  3,  0 },
    {     80,  -49,   37, 20,  3,  0 },{     81,  -50,   38, 20,  3,  0 },{     82,  -51,   39, 20,  3,  0 },{     83,  -52,   40, 20,  3,  0 },{     84,  -53,   41, 20,  3,  0 },
    {     84,  -53,   42, 20,  3,  0 },{     85,  -54,   43, 20,  3,  0 },{     86,  -55,   44, 20,  3,  0 },{     87,  -56,   45, 20,  3,  0 },{     87,  -56,   46, 20,  3,  0 },
    {     88,  -57,   47, 20,  3,  0 },{     89,  -58,   48, 20,  3,  0 },{     89,  -58,   49, 20,  3,  0 },{     90,  -59,   50, 20,  3,  0 },{     91,  -60,   51, 20,  3,  0 },
    {     91,  -60,   52, 20,  3,  0 },{     92,  -61,   53, 20,  3,  0 },{     93,  -62,   54, 20,  3,  0 },{     93,  -62,   55, 20,  3,  0 },{     94,  -63,   56, 20,  3,  0 },
    {     95,  -64,   57, 20,  3,  0 },{     95,  -64,   58, 20,  3,  0 },{     96,  -65,   59, 20,  3,  0 },{     97,  -66,   60, 20,  3,  0 },{     97,  -66,   61, 20,  3,  0 },
    {     98,  -67,   62, 20,  3,  0 },{     99,  -68,   63, 20,  3,  0 },{     99,  -68,   64, 20,  3,  0 },{    100,  -69,   65, 20,  3,  0 },{    100,  -69,   66, 20,  3,  0 },
    {    101,  -70,   67, 20,  3,  0 },{    102,  -71,   68, 20, 52,  0 },{    102,  -71,   69, 20, 52,  0 },{    103,  -72,   70, 20, 52,  0 },{    103,  -72,   71, 20, 52,  0 },
    {    104,  -73,   72, 20, 52,  0 },{    104,  -73,   73, 20, 52,  0 },{    105,  -74,   74, 20, 52,  0 },{    105,  -74,   75, 20, 52,  0 },{    106,  -75,   76, 20, 52,  0 },
    {    107,  -76,   77, 20, 52,  0 },{    107,  -76,   78, 20, 52,  0 },{    108,  -77,   79, 20, 52,  0 },{    108,  -77,   80, 20, 52,  0 },{    109,  -78,   81, 20, 52,  0 },
    {    109,  -78,   82, 20, 52,  0 },{    110,  -79,   83, 20, 52,  0 },{    110,  -79,   84, 20, 52,  0 },{    111,  -80,   85, 20, 52,  0 },{    111,  -80,   86, 20, 52,  0 },
    {    112,  -81,   87, 20, 52,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToUp60LongBase3,{
    {     15,   15,    0, 28,  0,  0 },{     14,   14,    0, 28,  0,  0 },{     13,   13,    0, 28,  0,  0 },{     12,   12,    0, 28,  0,  0 },{     11,   11,    0, 28,  0,  0 },
    {     10,   10,    0, 28,  0,  0 },{      9,    9,    0, 28, 50,  0 },{      8,    8,    1, 28, 50,  0 },{      7,    7,    1, 28, 50,  0 },{      6,    6,    1, 28, 50,  0 },
    {      5,    5,    1, 28, 50,  0 },{      4,    4,    1, 28, 50,  0 },{      3,    3,    2, 28, 50,  0 },{      2,    2,    2, 28, 50,  0 },{      1,    1,    2, 28, 50,  0 },
    {      0,    0,    2, 28, 50,  0 },{     -1,   -1,    3, 28, 50,  0 },{     -2,   -2,    3, 28, 50,  0 },{     -3,   -3,    3, 28, 50,  0 },{     -4,   -4,    4, 28, 50,  0 },
    {     -5,   -5,    4, 28, 50,  0 },{     -6,   -6,    4, 28, 51,  0 },{     -7,   -7,    5, 28, 51,  0 },{     -8,   -8,    5, 28, 51,  0 },{     -9,   -9,    6, 28, 51,  0 },
    {    -10,  -10,    6, 28, 51,  0 },{    -11,  -11,    6, 28, 51,  0 },{    -12,  -12,    7, 28, 51,  0 },{    -13,  -13,    7, 28, 51,  0 },{    -14,  -14,    8, 28, 51,  0 },
    {    -15,  -15,    9, 28, 51,  0 },{    -16,  -16,    9, 28, 51,  0 },{    -17,  -17,   10, 28, 51,  0 },{    -18,  -18,   10, 28,  2,  0 },{    -19,  -19,   11, 28,  2,  0 },
    {    -20,  -20,   12, 28,  2,  0 },{    -21,  -21,   12, 28,  2,  0 },{    -22,  -22,   13, 28,  2,  0 },{    -23,  -23,   14, 28,  2,  0 },{    -24,  -24,   14, 28,  2,  0 },
    {    -25,  -25,   15, 28,  2,  0 },{    -26,  -26,   16, 28,  2,  0 },{    -27,  -27,   17, 28,  2,  0 },{    -28,  -28,   17, 28,  2,  0 },{    -29,  -29,   18, 28,  2,  0 },
    {    -30,  -30,   19, 28,  2,  0 },{    -31,  -31,   20, 28,  2,  0 },{    -32,  -32,   21, 28,  2,  0 },{    -33,  -33,   22, 28,  2,  0 },{    -34,  -34,   23, 28,  2,  0 },
    {    -35,  -35,   24, 28,  2,  0 },{    -36,  -36,   24, 28,  2,  0 },{    -37,  -37,   25, 28,  2,  0 },{    -38,  -38,   26, 28,  2,  0 },{    -39,  -39,   27, 28,  2,  0 },
    {    -40,  -40,   28, 28,  2,  0 },{    -41,  -41,   29, 28,  3,  0 },{    -42,  -42,   30, 28,  3,  0 },{    -43,  -43,   31, 28,  3,  0 },{    -44,  -44,   32, 28,  3,  0 },
    {    -45,  -45,   33, 28,  3,  0 },{    -46,  -46,   34, 28,  3,  0 },{    -47,  -47,   35, 28,  3,  0 },{    -48,  -48,   36, 28,  3,  0 },{    -48,  -48,   37, 28,  3,  0 },
    {    -49,  -49,   38, 28,  3,  0 },{    -50,  -50,   39, 28,  3,  0 },{    -51,  -51,   40, 28,  3,  0 },{    -52,  -52,   41, 28,  3,  0 },{    -52,  -52,   42, 28,  3,  0 },
    {    -53,  -53,   43, 28,  3,  0 },{    -54,  -54,   44, 28,  3,  0 },{    -55,  -55,   45, 28,  3,  0 },{    -55,  -55,   46, 28,  3,  0 },{    -56,  -56,   47, 28,  3,  0 },
    {    -57,  -57,   48, 28,  3,  0 },{    -57,  -57,   49, 28,  3,  0 },{    -58,  -58,   50, 28,  3,  0 },{    -59,  -59,   51, 28,  3,  0 },{    -59,  -59,   52, 28,  3,  0 },
    {    -60,  -60,   53, 28,  3,  0 },{    -61,  -61,   54, 28,  3,  0 },{    -61,  -61,   55, 28,  3,  0 },{    -62,  -62,   56, 28,  3,  0 },{    -63,  -63,   57, 28,  3,  0 },
    {    -63,  -63,   58, 28,  3,  0 },{    -64,  -64,   59, 28,  3,  0 },{    -65,  -65,   60, 28,  3,  0 },{    -65,  -65,   61, 28,  3,  0 },{    -66,  -66,   62, 28,  3,  0 },
    {    -67,  -67,   63, 28,  3,  0 },{    -67,  -67,   64, 28,  3,  0 },{    -68,  -68,   65, 28,  3,  0 },{    -68,  -68,   66, 28,  3,  0 },{    -69,  -69,   67, 28,  3,  0 },
    {    -70,  -70,   68, 28, 52,  0 },{    -70,  -70,   69, 28, 52,  0 },{    -71,  -71,   70, 28, 52,  0 },{    -71,  -71,   71, 28, 52,  0 },{    -72,  -72,   72, 28, 52,  0 },
    {    -72,  -72,   73, 28, 52,  0 },{    -73,  -73,   74, 28, 52,  0 },{    -73,  -73,   75, 28, 52,  0 },{    -74,  -74,   76, 28, 52,  0 },{    -75,  -75,   77, 28, 52,  0 },
    {    -75,  -75,   78, 28, 52,  0 },{    -76,  -76,   79, 28, 52,  0 },{    -76,  -76,   80, 28, 52,  0 },{    -77,  -77,   81, 28, 52,  0 },{    -77,  -77,   82, 28, 52,  0 },
    {    -78,  -78,   83, 28, 52,  0 },{    -78,  -78,   84, 28, 52,  0 },{    -79,  -79,   85, 28, 52,  0 },{    -79,  -79,   86, 28, 52,  0 },{    -80,  -80,   87, 28, 52,  0 },
    {    -80,  -80,   88, 28, 52,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp60ToFlatLongBase0,{
    {     15,   16,    1,  4, 52,  0 },{     15,   16,    2,  4, 52,  0 },{     14,   17,    3,  4, 52,  0 },{     14,   17,    4,  4, 52,  0 },{     13,   18,    5,  4, 52,  0 },
    {     13,   18,    6,  4, 52,  0 },{     12,   19,    7,  4, 52,  0 },{     12,   19,    8,  4, 52,  0 },{     11,   20,    9,  4, 52,  0 },{     11,   20,   10,  4, 52,  0 },
    {     10,   21,   11,  4, 52,  0 },{      9,   22,   12,  4, 52,  0 },{      9,   22,   13,  4, 52,  0 },{      8,   23,   14,  4, 52,  0 },{      8,   23,   15,  4, 52,  0 },
    {      7,   24,   16,  4, 52,  0 },{      7,   24,   17,  4, 52,  0 },{      6,   25,   18,  4, 52,  0 },{      6,   25,   19,  4, 52,  0 },{      5,   26,   20,  4,  3,  0 },
    {      4,   27,   21,  4,  3,  0 },{      4,   27,   22,  4,  3,  0 },{      3,   28,   23,  4,  3,  0 },{      3,   28,   24,  4,  3,  0 },{      2,   29,   25,  4,  3,  0 },
    {      1,   30,   26,  4,  3,  0 },{      1,   30,   27,  4,  3,  0 },{      0,   31,   28,  4,  3,  0 },{     -1,   32,   29,  4,  3,  0 },{     -1,   32,   30,  4,  3,  0 },
    {     -2,   33,   31,  4,  3,  0 },{     -2,   33,   32,  4,  3,  0 },{     -3,   34,   33,  4,  3,  0 },{     -4,   35,   34,  4,  3,  0 },{     -4,   35,   35,  4,  3,  0 },
    {     -5,   36,   36,  4,  3,  0 },{     -6,   37,   37,  4,  3,  0 },{     -7,   38,   38,  4,  3,  0 },{     -7,   38,   39,  4,  3,  0 },{     -8,   39,   40,  4,  3,  0 },
    {     -9,   40,   41,  4,  3,  0 },{     -9,   40,   42,  4,  3,  0 },{    -10,   41,   43,  4,  3,  0 },{    -11,   42,   44,  4,  3,  0 },{    -12,   43,   45,  4,  3,  0 },
    {    -12,   43,   46,  4,  3,  0 },{    -13,   44,   47,  4,  3,  0 },{    -14,   45,   48,  4,  3,  0 },{    -15,   46,   49,  4,  3,  0 },{    -16,   47,   50,  4,  3,  0 },
    {    -16,   47,   51,  4,  3,  0 },{    -17,   48,   52,  4,  3,  0 },{    -18,   49,   53,  4,  3,  0 },{    -19,   50,   54,  4,  3,  0 },{    -20,   51,   55,  4,  3,  0 },
    {    -21,   52,   56,  4,  3,  0 },{    -22,   53,   57,  4,  3,  0 },{    -23,   54,   58,  4,  3,  0 },{    -23,   54,   59,  4,  3,  0 },{    -24,   55,   60,  4,  2,  0 },
    {    -25,   56,   61,  4,  2,  0 },{    -26,   57,   62,  4,  2,  0 },{    -27,   58,   63,  4,  2,  0 },{    -28,   59,   64,  4,  2,  0 },{    -29,   60,   65,  4,  2,  0 },
    {    -30,   61,   66,  4,  2,  0 },{    -31,   62,   67,  4,  2,  0 },{    -32,   63,   68,  4,  2,  0 },{    -33,   64,   69,  4,  2,  0 },{    -34,   65,   70,  4,  2,  0 },
    {    -35,   66,   71,  4,  2,  0 },{    -36,   67,   71,  4,  2,  0 },{    -37,   68,   72,  4,  2,  0 },{    -38,   69,   73,  4,  2,  0 },{    -39,   70,   74,  4,  2,  0 },
    {    -40,   71,   74,  4,  2,  0 },{    -41,   72,   75,  4,  2,  0 },{    -42,   73,   76,  4,  2,  0 },{    -43,   74,   76,  4,  2,  0 },{    -44,   75,   77,  4,  2,  0 },
    {    -45,   76,   78,  4,  2,  0 },{    -46,   77,   78,  4, 51,  0 },{    -47,   78,   79,  4, 51,  0 },{    -48,   79,   79,  4, 51,  0 },{    -49,   80,   80,  4, 51,  0 },
    {    -50,   81,   80,  4, 51,  0 },{    -51,   82,   81,  4, 51,  0 },{    -52,   83,   81,  4, 51,  0 },{    -53,   84,   82,  4, 51,  0 },{    -54,   85,   82,  4, 51,  0 },
    {    -55,   86,   83,  4, 51,  0 },{    -56,   87,   83,  4, 51,  0 },{    -57,   88,   84,  4, 51,  0 },{    -58,   89,   84,  4, 51,  0 },{    -59,   90,   84,  4, 50,  0 },
    {    -60,   91,   85,  4, 50,  0 },{    -61,   92,   85,  4, 50,  0 },{    -62,   93,   85,  4, 50,  0 },{    -63,   94,   86,  4, 50,  0 },{    -64,   95,   86,  4, 50,  0 },
    {    -65,   96,   86,  4, 50,  0 },{    -66,   97,   86,  4, 50,  0 },{    -67,   98,   87,  4, 50,  0 },{    -68,   99,   87,  4, 50,  0 },{    -69,  100,   87,  4, 50,  0 },
    {    -70,  101,   87,  4, 50,  0 },{    -71,  102,   87,  4, 50,  0 },{    -72,  103,   88,  4, 50,  0 },{    -73,  104,   88,  4,  0,  0 },{    -74,  105,   88,  4,  0,  0 },
    {    -75,  106,   88,  4,  0,  0 },{    -76,  107,   88,  4,  0,  0 },{    -77,  108,   88,  4,  0,  0 },{    -78,  109,   88,  4,  0,  0 },{    -79,  110,   88,  4,  0,  0 },
    {    -80,  111,   88,  4,  0,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp60ToFlatLongBase1,{
    {     16,   16,    0, 12, 52,  0 },{     17,   17,    1, 12, 52,  0 },{     17,   17,    2, 12, 52,  0 },{     18,   18,    3, 12, 52,  0 },{     18,   18,    4, 12, 52,  0 },
    {     19,   19,    5, 12, 52,  0 },{     19,   19,    6, 12, 52,  0 },{     20,   20,    7, 12, 52,  0 },{     20,   20,    8, 12, 52,  0 },{     21,   21,    9, 12, 52,  0 },
    {     21,   21,   10, 12, 52,  0 },{     22,   22,   11, 12, 52,  0 },{     23,   23,   12, 12, 52,  0 },{     23,   23,   13, 12, 52,  0 },{     24,   24,   14, 12, 52,  0 },
    {     24,   24,   15, 12, 52,  0 },{     25,   25,   16, 12, 52,  0 },{     25,   25,   17, 12, 52,  0 },{     26,   26,   18, 12, 52,  0 },{     26,   26,   19, 12, 52,  0 },
    {     27,   27,   20, 12,  3,  0 },{     28,   28,   21, 12,  3,  0 },{     28,   28,   22, 12,  3,  0 },{     29,   29,   23, 12,  3,  0 },{     29,   29,   24, 12,  3,  0 },
    {     30,   30,   25, 12,  3,  0 },{     31,   31,   26, 12,  3,  0 },{     31,   31,   27, 12,  3,  0 },{     32,   32,   28, 12,  3,  0 },{     33,   33,   29, 12,  3,  0 },
    {     33,   33,   30, 12,  3,  0 },{     34,   34,   31, 12,  3,  0 },{     34,   34,   32, 12,  3,  0 },{     35,   35,   33, 12,  3,  0 },{     36,   36,   34, 12,  3,  0 },
    {     36,   36,   35, 12,  3,  0 },{     37,   37,   36, 12,  3,  0 },{     38,   38,   37, 12,  3,  0 },{     39,   39,   38, 12,  3,  0 },{     39,   39,   39, 12,  3,  0 },
    {     40,   40,   40, 12,  3,  0 },{     41,   41,   41, 12,  3,  0 },{     41,   41,   42, 12,  3,  0 },{     42,   42,   43, 12,  3,  0 },{     43,   43,   44, 12,  3,  0 },
    {     44,   44,   45, 12,  3,  0 },{     44,   44,   46, 12,  3,  0 },{     45,   45,   47, 12,  3,  0 },{     46,   46,   48, 12,  3,  0 },{     47,   47,   49, 12,  3,  0 },
    {     48,   48,   50, 12,  3,  0 },{     48,   48,   51, 12,  3,  0 },{     49,   49,   52, 12,  3,  0 },{     50,   50,   53, 12,  3,  0 },{     51,   51,   54, 12,  3,  0 },
    {     52,   52,   55, 12,  3,  0 },{     53,   53,   56, 12,  3,  0 },{     54,   54,   57, 12,  3,  0 },{     55,   55,   58, 12,  3,  0 },{     55,   55,   59, 12,  3,  0 },
    {     56,   56,   60, 12,  2,  0 },{     57,   57,   61, 12,  2,  0 },{     58,   58,   62, 12,  2,  0 },{     59,   59,   63, 12,  2,  0 },{     60,   60,   64, 12,  2,  0 },
    {     61,   61,   65, 12,  2,  0 },{     62,   62,   66, 12,  2,  0 },{     63,   63,   67, 12,  2,  0 },{     64,   64,   68, 12,  2,  0 },{     65,   65,   69, 12,  2,  0 },
    {     66,   66,   70, 12,  2,  0 },{     67,   67,   71, 12,  2,  0 },{     68,   68,   71, 12,  2,  0 },{     69,   69,   72, 12,  2,  0 },{     70,   70,   73, 12,  2,  0 },
    {     71,   71,   74, 12,  2,  0 },{     72,   72,   74, 12,  2,  0 },{     73,   73,   75, 12,  2,  0 },{     74,   74,   76, 12,  2,  0 },{     75,   75,   76, 12,  2,  0 },
    {     76,   76,   77, 12,  2,  0 },{     77,   77,   78, 12,  2,  0 },{     78,   78,   78, 12, 51,  0 },{     79,   79,   79, 12, 51,  0 },{     80,   80,   79, 12, 51,  0 },
    {     81,   81,   80, 12, 51,  0 },{     82,   82,   80, 12, 51,  0 },{     83,   83,   81, 12, 51,  0 },{     84,   84,   81, 12, 51,  0 },{     85,   85,   82, 12, 51,  0 },
    {     86,   86,   82, 12, 51,  0 },{     87,   87,   83, 12, 51,  0 },{     88,   88,   83, 12, 51,  0 },{     89,   89,   84, 12, 51,  0 },{     90,   90,   84, 12, 51,  0 },
    {     91,   91,   84, 12, 50,  0 },{     92,   92,   85, 12, 50,  0 },{     93,   93,   85, 12, 50,  0 },{     94,   94,   85, 12, 50,  0 },{     95,   95,   86, 12, 50,  0 },
    {     96,   96,   86, 12, 50,  0 },{     97,   97,   86, 12, 50,  0 },{     98,   98,   86, 12, 50,  0 },{     99,   99,   87, 12, 50,  0 },{    100,  100,   87, 12, 50,  0 },
    {    101,  101,   87, 12, 50,  0 },{    102,  102,   87, 12, 50,  0 },{    103,  103,   87, 12, 50,  0 },{    104,  104,   88, 12, 50,  0 },{    105,  105,   88, 12,  0,  0 },
    {    106,  106,   88, 12,  0,  0 },{    107,  107,   88, 12,  0,  0 },{    108,  108,   88, 12,  0,  0 },{    109,  109,   88, 12,  0,  0 },{    110,  110,   88, 12,  0,  0 },
    {    111,  111,   88, 12,  0,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp60ToFlatLongBase2,{
    {     16,   15,    0, 20, 52,  0 },{     17,   14,    1, 20, 52,  0 },{     17,   14,    2, 20, 52,  0 },{     18,   13,    3, 20, 52,  0 },{     18,   13,    4, 20, 52,  0 },
    {     19,   12,    5, 20, 52,  0 },{     19,   12,    6, 20, 52,  0 },{     20,   11,    7, 20, 52,  0 },{     20,   11,    8, 20, 52,  0 },{     21,   10,    9, 20, 52,  0 },
    {     21,   10,   10, 20, 52,  0 },{     22,    9,   11, 20, 52,  0 },{     23,    8,   12, 20, 52,  0 },{     23,    8,   13, 20, 52,  0 },{     24,    7,   14, 20, 52,  0 },
    {     24,    7,   15, 20, 52,  0 },{     25,    6,   16, 20, 52,  0 },{     25,    6,   17, 20, 52,  0 },{     26,    5,   18, 20, 52,  0 },{     26,    5,   19, 20, 52,  0 },
    {     27,    4,   20, 20,  3,  0 },{     28,    3,   21, 20,  3,  0 },{     28,    3,   22, 20,  3,  0 },{     29,    2,   23, 20,  3,  0 },{     29,    2,   24, 20,  3,  0 },
    {     30,    1,   25, 20,  3,  0 },{     31,    0,   26, 20,  3,  0 },{     31,    0,   27, 20,  3,  0 },{     32,   -1,   28, 20,  3,  0 },{     33,   -2,   29, 20,  3,  0 },
    {     33,   -2,   30, 20,  3,  0 },{     34,   -3,   31, 20,  3,  0 },{     34,   -3,   32, 20,  3,  0 },{     35,   -4,   33, 20,  3,  0 },{     36,   -5,   34, 20,  3,  0 },
    {     36,   -5,   35, 20,  3,  0 },{     37,   -6,   36, 20,  3,  0 },{     38,   -7,   37, 20,  3,  0 },{     39,   -8,   38, 20,  3,  0 },{     39,   -8,   39, 20,  3,  0 },
    {     40,   -9,   40, 20,  3,  0 },{     41,  -10,   41, 20,  3,  0 },{     41,  -10,   42, 20,  3,  0 },{     42,  -11,   43, 20,  3,  0 },{     43,  -12,   44, 20,  3,  0 },
    {     44,  -13,   45, 20,  3,  0 },{     44,  -13,   46, 20,  3,  0 },{     45,  -14,   47, 20,  3,  0 },{     46,  -15,   48, 20,  3,  0 },{     47,  -16,   49, 20,  3,  0 },
    {     48,  -17,   50, 20,  3,  0 },{     48,  -17,   51, 20,  3,  0 },{     49,  -18,   52, 20,  3,  0 },{     50,  -19,   53, 20,  3,  0 },{     51,  -20,   54, 20,  3,  0 },
    {     52,  -21,   55, 20,  3,  0 },{     53,  -22,   56, 20,  3,  0 },{     54,  -23,   57, 20,  3,  0 },{     55,  -24,   58, 20,  3,  0 },{     55,  -24,   59, 20,  3,  0 },
    {     56,  -25,   60, 20,  2,  0 },{     57,  -26,   61, 20,  2,  0 },{     58,  -27,   62, 20,  2,  0 },{     59,  -28,   63, 20,  2,  0 },{     60,  -29,   64, 20,  2,  0 },
    {     61,  -30,   65, 20,  2,  0 },{     62,  -31,   66, 20,  2,  0 },{     63,  -32,   67, 20,  2,  0 },{     64,  -33,   68, 20,  2,  0 },{     65,  -34,   69, 20,  2,  0 },
    {     66,  -35,   70, 20,  2,  0 },{     67,  -36,   71, 20,  2,  0 },{     68,  -37,   71, 20,  2,  0 },{     69,  -38,   72, 20,  2,  0 },{     70,  -39,   73, 20,  2,  0 },
    {     71,  -40,   74, 20,  2,  0 },{     72,  -41,   74, 20,  2,  0 },{     73,  -42,   75, 20,  2,  0 },{     74,  -43,   76, 20,  2,  0 },{     75,  -44,   76, 20,  2,  0 },
    {     76,  -45,   77, 20,  2,  0 },{     77,  -46,   78, 20,  2,  0 },{     78,  -47,   78, 20, 51,  0 },{     79,  -48,   79, 20, 51,  0 },{     80,  -49,   79, 20, 51,  0 },
    {     81,  -50,   80, 20, 51,  0 },{     82,  -51,   80, 20, 51,  0 },{     83,  -52,   81, 20, 51,  0 },{     84,  -53,   81, 20, 51,  0 },{     85,  -54,   82, 20, 51,  0 },
    {     86,  -55,   82, 20, 51,  0 },{     87,  -56,   83, 20, 51,  0 },{     88,  -57,   83, 20, 51,  0 },{     89,  -58,   84, 20, 51,  0 },{     90,  -59,   84, 20, 51,  0 },
    {     91,  -60,   84, 20, 50,  0 },{     92,  -61,   85, 20, 50,  0 },{     93,  -62,   85, 20, 50,  0 },{     94,  -63,   85, 20, 50,  0 },{     95,  -64,   86, 20, 50,  0 },
    {     96,  -65,   86, 20, 50,  0 },{     97,  -66,   86, 20, 50,  0 },{     98,  -67,   86, 20, 50,  0 },{     99,  -68,   87, 20, 50,  0 },{    100,  -69,   87, 20, 50,  0 },
    {    101,  -70,   87, 20, 50,  0 },{    102,  -71,   87, 20, 50,  0 },{    103,  -72,   87, 20, 50,  0 },{    104,  -73,   88, 20, 50,  0 },{    105,  -74,   88, 20,  0,  0 },
    {    106,  -75,   88, 20,  0,  0 },{    107,  -76,   88, 20,  0,  0 },{    108,  -77,   88, 20,  0,  0 },{    109,  -78,   88, 20,  0,  0 },{    110,  -79,   88, 20,  0,  0 },
    {    111,  -80,   88, 20,  0,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagUp60ToFlatLongBase3,{
    {     15,   15,    1, 28, 52,  0 },{     15,   15,    2, 28, 52,  0 },{     14,   14,    3, 28, 52,  0 },{     14,   14,    4, 28, 52,  0 },{     13,   13,    5, 28, 52,  0 },
    {     13,   13,    6, 28, 52,  0 },{     12,   12,    7, 28, 52,  0 },{     12,   12,    8, 28, 52,  0 },{     11,   11,    9, 28, 52,  0 },{     11,   11,   10, 28, 52,  0 },
    {     10,   10,   11, 28, 52,  0 },{      9,    9,   12, 28, 52,  0 },{      9,    9,   13, 28, 52,  0 },{      8,    8,   14, 28, 52,  0 },{      8,    8,   15, 28, 52,  0 },
    {      7,    7,   16, 28, 52,  0 },{      7,    7,   17, 28, 52,  0 },{      6,    6,   18, 28, 52,  0 },{      6,    6,   19, 28, 52,  0 },{      5,    5,   20, 28,  3,  0 },
    {      4,    4,   21, 28,  3,  0 },{      4,    4,   22, 28,  3,  0 },{      3,    3,   23, 28,  3,  0 },{      3,    3,   24, 28,  3,  0 },{      2,    2,   25, 28,  3,  0 },
    {      1,    1,   26, 28,  3,  0 },{      1,    1,   27, 28,  3,  0 },{      0,    0,   28, 28,  3,  0 },{     -1,   -1,   29, 28,  3,  0 },{     -1,   -1,   30, 28,  3,  0 },
    {     -2,   -2,   31, 28,  3,  0 },{     -2,   -2,   32, 28,  3,  0 },{     -3,   -3,   33, 28,  3,  0 },{     -4,   -4,   34, 28,  3,  0 },{     -4,   -4,   35, 28,  3,  0 },
    {     -5,   -5,   36, 28,  3,  0 },{     -6,   -6,   37, 28,  3,  0 },{     -7,   -7,   38, 28,  3,  0 },{     -7,   -7,   39, 28,  3,  0 },{     -8,   -8,   40, 28,  3,  0 },
    {     -9,   -9,   41, 28,  3,  0 },{     -9,   -9,   42, 28,  3,  0 },{    -10,  -10,   43, 28,  3,  0 },{    -11,  -11,   44, 28,  3,  0 },{    -12,  -12,   45, 28,  3,  0 },
    {    -12,  -12,   46, 28,  3,  0 },{    -13,  -13,   47, 28,  3,  0 },{    -14,  -14,   48, 28,  3,  0 },{    -15,  -15,   49, 28,  3,  0 },{    -16,  -16,   50, 28,  3,  0 },
    {    -16,  -16,   51, 28,  3,  0 },{    -17,  -17,   52, 28,  3,  0 },{    -18,  -18,   53, 28,  3,  0 },{    -19,  -19,   54, 28,  3,  0 },{    -20,  -20,   55, 28,  3,  0 },
    {    -21,  -21,   56, 28,  3,  0 },{    -22,  -22,   57, 28,  3,  0 },{    -23,  -23,   58, 28,  3,  0 },{    -23,  -23,   59, 28,  3,  0 },{    -24,  -24,   60, 28,  2,  0 },
    {    -25,  -25,   61, 28,  2,  0 },{    -26,  -26,   62, 28,  2,  0 },{    -27,  -27,   63, 28,  2,  0 },{    -28,  -28,   64, 28,  2,  0 },{    -29,  -29,   65, 28,  2,  0 },
    {    -30,  -30,   66, 28,  2,  0 },{    -31,  -31,   67, 28,  2,  0 },{    -32,  -32,   68, 28,  2,  0 },{    -33,  -33,   69, 28,  2,  0 },{    -34,  -34,   70, 28,  2,  0 },
    {    -35,  -35,   71, 28,  2,  0 },{    -36,  -36,   71, 28,  2,  0 },{    -37,  -37,   72, 28,  2,  0 },{    -38,  -38,   73, 28,  2,  0 },{    -39,  -39,   74, 28,  2,  0 },
    {    -40,  -40,   74, 28,  2,  0 },{    -41,  -41,   75, 28,  2,  0 },{    -42,  -42,   76, 28,  2,  0 },{    -43,  -43,   76, 28,  2,  0 },{    -44,  -44,   77, 28,  2,  0 },
    {    -45,  -45,   78, 28,  2,  0 },{    -46,  -46,   78, 28, 51,  0 },{    -47,  -47,   79, 28, 51,  0 },{    -48,  -48,   79, 28, 51,  0 },{    -49,  -49,   80, 28, 51,  0 },
    {    -50,  -50,   80, 28, 51,  0 },{    -51,  -51,   81, 28, 51,  0 },{    -52,  -52,   81, 28, 51,  0 },{    -53,  -53,   82, 28, 51,  0 },{    -54,  -54,   82, 28, 51,  0 },
    {    -55,  -55,   83, 28, 51,  0 },{    -56,  -56,   83, 28, 51,  0 },{    -57,  -57,   84, 28, 51,  0 },{    -58,  -58,   84, 28, 51,  0 },{    -59,  -59,   84, 28, 50,  0 },
    {    -60,  -60,   85, 28, 50,  0 },{    -61,  -61,   85, 28, 50,  0 },{    -62,  -62,   85, 28, 50,  0 },{    -63,  -63,   86, 28, 50,  0 },{    -64,  -64,   86, 28, 50,  0 },
    {    -65,  -65,   86, 28, 50,  0 },{    -66,  -66,   86, 28, 50,  0 },{    -67,  -67,   87, 28, 50,  0 },{    -68,  -68,   87, 28, 50,  0 },{    -69,  -69,   87, 28, 50,  0 },
    {    -70,  -70,   87, 28, 50,  0 },{    -71,  -71,   87, 28, 50,  0 },{    -72,  -72,   88, 28, 50,  0 },{    -73,  -73,   88, 28,  0,  0 },{    -74,  -74,   88, 28,  0,  0 },
    {    -75,  -75,   88, 28,  0,  0 },{    -76,  -76,   88, 28,  0,  0 },{    -77,  -77,   88, 28,  0,  0 },{    -78,  -78,   88, 28,  0,  0 },{    -79,  -79,   88, 28,  0,  0 },
    {    -80,  -80,   88, 28,  0,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToDown60LongBase0,{
    {     15,   16,    8,  4,  0,  0 },{     14,   17,    8,  4,  0,  0 },{     13,   18,    8,  4,  0,  0 },{     12,   19,    8,  4,  0,  0 },{     11,   20,    8,  4,  0,  0 },
    {     10,   21,    8,  4,  0,  0 },{      9,   22,    8,  4, 53,  0 },{      8,   23,    7,  4, 53,  0 },{      7,   24,    7,  4, 53,  0 },{      6,   25,    7,  4, 53,  0 },
    {      5,   26,    7,  4, 53,  0 },{      4,   27,    7,  4, 53,  0 },{      3,   28,    6,  4, 53,  0 },{      2,   29,    6,  4, 53,  0 },{      1,   30,    6,  4, 53,  0 },
    {      0,   31,    6,  4, 53,  0 },{     -1,   32,    5,  4, 53,  0 },{     -2,   33,    5,  4, 53,  0 },{     -3,   34,    5,  4, 53,  0 },{     -4,   35,    4,  4, 53,  0 },
    {     -5,   36,    4,  4, 53,  0 },{     -6,   37,    4,  4, 54,  0 },{     -7,   38,    3,  4, 54,  0 },{     -8,   39,    3,  4, 54,  0 },{     -9,   40,    2,  4, 54,  0 },
    {    -10,   41,    2,  4, 54,  0 },{    -11,   42,    2,  4, 54,  0 },{    -12,   43,    1,  4, 54,  0 },{    -13,   44,    1,  4, 54,  0 },{    -14,   45,    0,  4, 54,  0 },
    {    -15,   46,   -1,  4, 54,  0 },{    -16,   47,   -1,  4, 54,  0 },{    -17,   48,   -2,  4, 54,  0 },{    -18,   49,   -2,  4,  6,  0 },{    -19,   50,   -3,  4,  6,  0 },
    {    -20,   51,   -4,  4,  6,  0 },{    -21,   52,   -4,  4,  6,  0 },{    -22,   53,   -5,  4,  6,  0 },{    -23,   54,   -6,  4,  6,  0 },{    -24,   55,   -6,  4,  6,  0 },
    {    -25,   56,   -7,  4,  6,  0 },{    -26,   57,   -8,  4,  6,  0 },{    -27,   58,   -9,  4,  6,  0 },{    -28,   59,   -9,  4,  6,  0 },{    -29,   60,  -10,  4,  6,  0 },
    {    -30,   61,  -11,  4,  6,  0 },{    -31,   62,  -12,  4,  6,  0 },{    -32,   63,  -13,  4,  6,  0 },{    -33,   64,  -14,  4,  6,  0 },{    -34,   65,  -15,  4,  6,  0 },
    {    -35,   66,  -16,  4,  6,  0 },{    -36,   67,  -16,  4,  6,  0 },{    -37,   68,  -17,  4,  6,  0 },{    -38,   69,  -18,  4,  6,  0 },{    -39,   70,  -19,  4,  6,  0 },
    {    -40,   71,  -20,  4,  6,  0 },{    -41,   72,  -21,  4,  7,  0 },{    -42,   73,  -22,  4,  7,  0 },{    -43,   74,  -23,  4,  7,  0 },{    -44,   75,  -24,  4,  7,  0 },
    {    -45,   76,  -25,  4,  7,  0 },{    -46,   77,  -26,  4,  7,  0 },{    -47,   78,  -27,  4,  7,  0 },{    -48,   79,  -28,  4,  7,  0 },{    -48,   79,  -29,  4,  7,  0 },
    {    -49,   80,  -30,  4,  7,  0 },{    -50,   81,  -31,  4,  7,  0 },{    -51,   82,  -32,  4,  7,  0 },{    -52,   83,  -33,  4,  7,  0 },{    -52,   83,  -34,  4,  7,  0 },
    {    -53,   84,  -35,  4,  7,  0 },{    -54,   85,  -36,  4,  7,  0 },{    -55,   86,  -37,  4,  7,  0 },{    -55,   86,  -38,  4,  7,  0 },{    -56,   87,  -39,  4,  7,  0 },
    {    -57,   88,  -40,  4,  7,  0 },{    -57,   88,  -41,  4,  7,  0 },{    -58,   89,  -42,  4,  7,  0 },{    -59,   90,  -43,  4,  7,  0 },{    -59,   90,  -44,  4,  7,  0 },
    {    -60,   91,  -45,  4,  7,  0 },{    -61,   92,  -46,  4,  7,  0 },{    -61,   92,  -47,  4,  7,  0 },{    -62,   93,  -48,  4,  7,  0 },{    -63,   94,  -49,  4,  7,  0 },
    {    -63,   94,  -50,  4,  7,  0 },{    -64,   95,  -51,  4,  7,  0 },{    -65,   96,  -52,  4,  7,  0 },{    -65,   96,  -53,  4,  7,  0 },{    -66,   97,  -54,  4,  7,  0 },
    {    -67,   98,  -55,  4,  7,  0 },{    -67,   98,  -56,  4,  7,  0 },{    -68,   99,  -57,  4,  7,  0 },{    -68,   99,  -58,  4,  7,  0 },{    -69,  100,  -59,  4,  7,  0 },
    {    -70,  101,  -60,  4, 55,  0 },{    -70,  101,  -61,  4, 55,  0 },{    -71,  102,  -62,  4, 55,  0 },{    -71,  102,  -63,  4, 55,  0 },{    -72,  103,  -64,  4, 55,  0 },
    {    -72,  103,  -65,  4, 55,  0 },{    -73,  104,  -66,  4, 55,  0 },{    -73,  104,  -67,  4, 55,  0 },{    -74,  105,  -68,  4, 55,  0 },{    -75,  106,  -69,  4, 55,  0 },
    {    -75,  106,  -70,  4, 55,  0 },{    -76,  107,  -71,  4, 55,  0 },{    -76,  107,  -72,  4, 55,  0 },{    -77,  108,  -73,  4, 55,  0 },{    -77,  108,  -74,  4, 55,  0 },
    {    -78,  109,  -75,  4, 55,  0 },{    -78,  109,  -76,  4, 55,  0 },{    -79,  110,  -77,  4, 55,  0 },{    -79,  110,  -78,  4, 55,  0 },{    -80,  111,  -79,  4, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToDown60LongBase1,{
    {     16,   16,    8, 12,  0,  0 },{     17,   17,    8, 12,  0,  0 },{     18,   18,    8, 12,  0,  0 },{     19,   19,    8, 12,  0,  0 },{     20,   20,    8, 12,  0,  0 },
    {     21,   21,    8, 12,  0,  0 },{     22,   22,    8, 12,  0,  0 },{     23,   23,    8, 12, 53,  0 },{     24,   24,    7, 12, 53,  0 },{     25,   25,    7, 12, 53,  0 },
    {     26,   26,    7, 12, 53,  0 },{     27,   27,    7, 12, 53,  0 },{     28,   28,    7, 12, 53,  0 },{     29,   29,    6, 12, 53,  0 },{     30,   30,    6, 12, 53,  0 },
    {     31,   31,    6, 12, 53,  0 },{     32,   32,    6, 12, 53,  0 },{     33,   33,    5, 12, 53,  0 },{     34,   34,    5, 12, 53,  0 },{     35,   35,    5, 12, 53,  0 },
    {     36,   36,    4, 12, 53,  0 },{     37,   37,    4, 12, 53,  0 },{     38,   38,    4, 12, 54,  0 },{     39,   39,    3, 12, 54,  0 },{     40,   40,    3, 12, 54,  0 },
    {     41,   41,    2, 12, 54,  0 },{     42,   42,    2, 12, 54,  0 },{     43,   43,    2, 12, 54,  0 },{     44,   44,    1, 12, 54,  0 },{     45,   45,    1, 12, 54,  0 },
    {     46,   46,    0, 12, 54,  0 },{     47,   47,   -1, 12, 54,  0 },{     48,   48,   -1, 12, 54,  0 },{     49,   49,   -2, 12, 54,  0 },{     50,   50,   -2, 12,  6,  0 },
    {     51,   51,   -3, 12,  6,  0 },{     52,   52,   -4, 12,  6,  0 },{     53,   53,   -4, 12,  6,  0 },{     54,   54,   -5, 12,  6,  0 },{     55,   55,   -6, 12,  6,  0 },
    {     56,   56,   -6, 12,  6,  0 },{     57,   57,   -7, 12,  6,  0 },{     58,   58,   -8, 12,  6,  0 },{     59,   59,   -9, 12,  6,  0 },{     60,   60,   -9, 12,  6,  0 },
    {     61,   61,  -10, 12,  6,  0 },{     62,   62,  -11, 12,  6,  0 },{     63,   63,  -12, 12,  6,  0 },{     64,   64,  -13, 12,  6,  0 },{     65,   65,  -14, 12,  6,  0 },
    {     66,   66,  -15, 12,  6,  0 },{     67,   67,  -16, 12,  6,  0 },{     68,   68,  -16, 12,  6,  0 },{     69,   69,  -17, 12,  6,  0 },{     70,   70,  -18, 12,  6,  0 },
    {     71,   71,  -19, 12,  6,  0 },{     72,   72,  -20, 12,  6,  0 },{     73,   73,  -21, 12,  7,  0 },{     74,   74,  -22, 12,  7,  0 },{     75,   75,  -23, 12,  7,  0 },
    {     76,   76,  -24, 12,  7,  0 },{     77,   77,  -25, 12,  7,  0 },{     78,   78,  -26, 12,  7,  0 },{     79,   79,  -27, 12,  7,  0 },{     80,   80,  -28, 12,  7,  0 },
    {     80,   80,  -29, 12,  7,  0 },{     81,   81,  -30, 12,  7,  0 },{     82,   82,  -31, 12,  7,  0 },{     83,   83,  -32, 12,  7,  0 },{     84,   84,  -33, 12,  7,  0 },
    {     84,   84,  -34, 12,  7,  0 },{     85,   85,  -35, 12,  7,  0 },{     86,   86,  -36, 12,  7,  0 },{     87,   87,  -37, 12,  7,  0 },{     87,   87,  -38, 12,  7,  0 },
    {     88,   88,  -39, 12,  7,  0 },{     89,   89,  -40, 12,  7,  0 },{     89,   89,  -41, 12,  7,  0 },{     90,   90,  -42, 12,  7,  0 },{     91,   91,  -43, 12,  7,  0 },
    {     91,   91,  -44, 12,  7,  0 },{     92,   92,  -45, 12,  7,  0 },{     93,   93,  -46, 12,  7,  0 },{     93,   93,  -47, 12,  7,  0 },{     94,   94,  -48, 12,  7,  0 },
    {     95,   95,  -49, 12,  7,  0 },{     95,   95,  -50, 12,  7,  0 },{     96,   96,  -51, 12,  7,  0 },{     97,   97,  -52, 12,  7,  0 },{     97,   97,  -53, 12,  7,  0 },
    {     98,   98,  -54, 12,  7,  0 },{     99,   99,  -55, 12,  7,  0 },{     99,   99,  -56, 12,  7,  0 },{    100,  100,  -57, 12,  7,  0 },{    100,  100,  -58, 12,  7,  0 },
    {    101,  101,  -59, 12,  7,  0 },{    102,  102,  -60, 12, 55,  0 },{    102,  102,  -61, 12, 55,  0 },{    103,  103,  -62, 12, 55,  0 },{    103,  103,  -63, 12, 55,  0 },
    {    104,  104,  -64, 12, 55,  0 },{    104,  104,  -65, 12, 55,  0 },{    105,  105,  -66, 12, 55,  0 },{    105,  105,  -67, 12, 55,  0 },{    106,  106,  -68, 12, 55,  0 },
    {    107,  107,  -69, 12, 55,  0 },{    107,  107,  -70, 12, 55,  0 },{    108,  108,  -71, 12, 55,  0 },{    108,  108,  -72, 12, 55,  0 },{    109,  109,  -73, 12, 55,  0 },
    {    109,  109,  -74, 12, 55,  0 },{    110,  110,  -75, 12, 55,  0 },{    110,  110,  -76, 12, 55,  0 },{    111,  111,  -77, 12, 55,  0 },{    111,  111,  -78, 12, 55,  0 },
    {    112,  112,  -79, 12, 55,  0 },{    112,  112,  -80, 12, 55,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToDown60LongBase2,{
    {     16,   15,    8, 20,  0,  0 },{     17,   14,    8, 20,  0,  0 },{     18,   13,    8, 20,  0,  0 },{     19,   12,    8, 20,  0,  0 },{     20,   11,    8, 20,  0,  0 },
    {     21,   10,    8, 20,  0,  0 },{     22,    9,    8, 20,  0,  0 },{     23,    8,    8, 20, 53,  0 },{     24,    7,    7, 20, 53,  0 },{     25,    6,    7, 20, 53,  0 },
    {     26,    5,    7, 20, 53,  0 },{     27,    4,    7, 20, 53,  0 },{     28,    3,    7, 20, 53,  0 },{     29,    2,    6, 20, 53,  0 },{     30,    1,    6, 20, 53,  0 },
    {     31,    0,    6, 20, 53,  0 },{     32,   -1,    6, 20, 53,  0 },{     33,   -2,    5, 20, 53,  0 },{     34,   -3,    5, 20, 53,  0 },{     35,   -4,    5, 20, 53,  0 },
    {     36,   -5,    4, 20, 53,  0 },{     37,   -6,    4, 20, 53,  0 },{     38,   -7,    4, 20, 54,  0 },{     39,   -8,    3, 20, 54,  0 },{     40,   -9,    3, 20, 54,  0 },
    {     41,  -10,    2, 20, 54,  0 },{     42,  -11,    2, 20, 54,  0 },{     43,  -12,    2, 20, 54,  0 },{     44,  -13,    1, 20, 54,  0 },{     45,  -14,    1, 20, 54,  0 },
    {     46,  -15,    0, 20, 54,  0 },{     47,  -16,   -1, 20, 54,  0 },{     48,  -17,   -1, 20, 54,  0 },{     49,  -18,   -2, 20, 54,  0 },{     50,  -19,   -2, 20,  6,  0 },
    {     51,  -20,   -3, 20,  6,  0 },{     52,  -21,   -4, 20,  6,  0 },{     53,  -22,   -4, 20,  6,  0 },{     54,  -23,   -5, 20,  6,  0 },{     55,  -24,   -6, 20,  6,  0 },
    {     56,  -25,   -6, 20,  6,  0 },{     57,  -26,   -7, 20,  6,  0 },{     58,  -27,   -8, 20,  6,  0 },{     59,  -28,   -9, 20,  6,  0 },{     60,  -29,   -9, 20,  6,  0 },
    {     61,  -30,  -10, 20,  6,  0 },{     62,  -31,  -11, 20,  6,  0 },{     63,  -32,  -12, 20,  6,  0 },{     64,  -33,  -13, 20,  6,  0 },{     65,  -34,  -14, 20,  6,  0 },
    {     66,  -35,  -15, 20,  6,  0 },{     67,  -36,  -16, 20,  6,  0 },{     68,  -37,  -16, 20,  6,  0 },{     69,  -38,  -17, 20,  6,  0 },{     70,  -39,  -18, 20,  6,  0 },
    {     71,  -40,  -19, 20,  6,  0 },{     72,  -41,  -20, 20,  6,  0 },{     73,  -42,  -21, 20,  7,  0 },{     74,  -43,  -22, 20,  7,  0 },{     75,  -44,  -23, 20,  7,  0 },
    {     76,  -45,  -24, 20,  7,  0 },{     77,  -46,  -25, 20,  7,  0 },{     78,  -47,  -26, 20,  7,  0 },{     79,  -48,  -27, 20,  7,  0 },{     80,  -49,  -28, 20,  7,  0 },
    {     80,  -49,  -29, 20,  7,  0 },{     81,  -50,  -30, 20,  7,  0 },{     82,  -51,  -31, 20,  7,  0 },{     83,  -52,  -32, 20,  7,  0 },{     84,  -53,  -33, 20,  7,  0 },
    {     84,  -53,  -34, 20,  7,  0 },{     85,  -54,  -35, 20,  7,  0 },{     86,  -55,  -36, 20,  7,  0 },{     87,  -56,  -37, 20,  7,  0 },{     87,  -56,  -38, 20,  7,  0 },
    {     88,  -57,  -39, 20,  7,  0 },{     89,  -58,  -40, 20,  7,  0 },{     89,  -58,  -41, 20,  7,  0 },{     90,  -59,  -42, 20,  7,  0 },{     91,  -60,  -43, 20,  7,  0 },
    {     91,  -60,  -44, 20,  7,  0 },{     92,  -61,  -45, 20,  7,  0 },{     93,  -62,  -46, 20,  7,  0 },{     93,  -62,  -47, 20,  7,  0 },{     94,  -63,  -48, 20,  7,  0 },
    {     95,  -64,  -49, 20,  7,  0 },{     95,  -64,  -50, 20,  7,  0 },{     96,  -65,  -51, 20,  7,  0 },{     97,  -66,  -52, 20,  7,  0 },{     97,  -66,  -53, 20,  7,  0 },
    {     98,  -67,  -54, 20,  7,  0 },{     99,  -68,  -55, 20,  7,  0 },{     99,  -68,  -56, 20,  7,  0 },{    100,  -69,  -57, 20,  7,  0 },{    100,  -69,  -58, 20,  7,  0 },
    {    101,  -70,  -59, 20,  7,  0 },{    102,  -71,  -60, 20, 55,  0 },{    102,  -71,  -61, 20, 55,  0 },{    103,  -72,  -62, 20, 55,  0 },{    103,  -72,  -63, 20, 55,  0 },
    {    104,  -73,  -64, 20, 55,  0 },{    104,  -73,  -65, 20, 55,  0 },{    105,  -74,  -66, 20, 55,  0 },{    105,  -74,  -67, 20, 55,  0 },{    106,  -75,  -68, 20, 55,  0 },
    {    107,  -76,  -69, 20, 55,  0 },{    107,  -76,  -70, 20, 55,  0 },{    108,  -77,  -71, 20, 55,  0 },{    108,  -77,  -72, 20, 55,  0 },{    109,  -78,  -73, 20, 55,  0 },
    {    109,  -78,  -74, 20, 55,  0 },{    110,  -79,  -75, 20, 55,  0 },{    110,  -79,  -76, 20, 55,  0 },{    111,  -80,  -77, 20, 55,  0 },{    111,  -80,  -78, 20, 55,  0 },
    {    112,  -81,  -79, 20, 55,  0 },{    112,  -81,  -80, 20, 55,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagFlatToDown60LongBase3,{
    {     15,   15,    8, 28,  0,  0 },{     14,   14,    8, 28,  0,  0 },{     13,   13,    8, 28,  0,  0 },{     12,   12,    8, 28,  0,  0 },{     11,   11,    8, 28,  0,  0 },
    {     10,   10,    8, 28,  0,  0 },{      9,    9,    8, 28, 53,  0 },{      8,    8,    7, 28, 53,  0 },{      7,    7,    7, 28, 53,  0 },{      6,    6,    7, 28, 53,  0 },
    {      5,    5,    7, 28, 53,  0 },{      4,    4,    7, 28, 53,  0 },{      3,    3,    6, 28, 53,  0 },{      2,    2,    6, 28, 53,  0 },{      1,    1,    6, 28, 53,  0 },
    {      0,    0,    6, 28, 53,  0 },{     -1,   -1,    5, 28, 53,  0 },{     -2,   -2,    5, 28, 53,  0 },{     -3,   -3,    5, 28, 53,  0 },{     -4,   -4,    4, 28, 53,  0 },
    {     -5,   -5,    4, 28, 53,  0 },{     -6,   -6,    4, 28, 54,  0 },{     -7,   -7,    3, 28, 54,  0 },{     -8,   -8,    3, 28, 54,  0 },{     -9,   -9,    2, 28, 54,  0 },
    {    -10,  -10,    2, 28, 54,  0 },{    -11,  -11,    2, 28, 54,  0 },{    -12,  -12,    1, 28, 54,  0 },{    -13,  -13,    1, 28, 54,  0 },{    -14,  -14,    0, 28, 54,  0 },
    {    -15,  -15,   -1, 28, 54,  0 },{    -16,  -16,   -1, 28, 54,  0 },{    -17,  -17,   -2, 28, 54,  0 },{    -18,  -18,   -2, 28,  6,  0 },{    -19,  -19,   -3, 28,  6,  0 },
    {    -20,  -20,   -4, 28,  6,  0 },{    -21,  -21,   -4, 28,  6,  0 },{    -22,  -22,   -5, 28,  6,  0 },{    -23,  -23,   -6, 28,  6,  0 },{    -24,  -24,   -6, 28,  6,  0 },
    {    -25,  -25,   -7, 28,  6,  0 },{    -26,  -26,   -8, 28,  6,  0 },{    -27,  -27,   -9, 28,  6,  0 },{    -28,  -28,   -9, 28,  6,  0 },{    -29,  -29,  -10, 28,  6,  0 },
    {    -30,  -30,  -11, 28,  6,  0 },{    -31,  -31,  -12, 28,  6,  0 },{    -32,  -32,  -13, 28,  6,  0 },{    -33,  -33,  -14, 28,  6,  0 },{    -34,  -34,  -15, 28,  6,  0 },
    {    -35,  -35,  -16, 28,  6,  0 },{    -36,  -36,  -16, 28,  6,  0 },{    -37,  -37,  -17, 28,  6,  0 },{    -38,  -38,  -18, 28,  6,  0 },{    -39,  -39,  -19, 28,  6,  0 },
    {    -40,  -40,  -20, 28,  6,  0 },{    -41,  -41,  -21, 28,  7,  0 },{    -42,  -42,  -22, 28,  7,  0 },{    -43,  -43,  -23, 28,  7,  0 },{    -44,  -44,  -24, 28,  7,  0 },
    {    -45,  -45,  -25, 28,  7,  0 },{    -46,  -46,  -26, 28,  7,  0 },{    -47,  -47,  -27, 28,  7,  0 },{    -48,  -48,  -28, 28,  7,  0 },{    -48,  -48,  -29, 28,  7,  0 },
    {    -49,  -49,  -30, 28,  7,  0 },{    -50,  -50,  -31, 28,  7,  0 },{    -51,  -51,  -32, 28,  7,  0 },{    -52,  -52,  -33, 28,  7,  0 },{    -52,  -52,  -34, 28,  7,  0 },
    {    -53,  -53,  -35, 28,  7,  0 },{    -54,  -54,  -36, 28,  7,  0 },{    -55,  -55,  -37, 28,  7,  0 },{    -55,  -55,  -38, 28,  7,  0 },{    -56,  -56,  -39, 28,  7,  0 },
    {    -57,  -57,  -40, 28,  7,  0 },{    -57,  -57,  -41, 28,  7,  0 },{    -58,  -58,  -42, 28,  7,  0 },{    -59,  -59,  -43, 28,  7,  0 },{    -59,  -59,  -44, 28,  7,  0 },
    {    -60,  -60,  -45, 28,  7,  0 },{    -61,  -61,  -46, 28,  7,  0 },{    -61,  -61,  -47, 28,  7,  0 },{    -62,  -62,  -48, 28,  7,  0 },{    -63,  -63,  -49, 28,  7,  0 },
    {    -63,  -63,  -50, 28,  7,  0 },{    -64,  -64,  -51, 28,  7,  0 },{    -65,  -65,  -52, 28,  7,  0 },{    -65,  -65,  -53, 28,  7,  0 },{    -66,  -66,  -54, 28,  7,  0 },
    {    -67,  -67,  -55, 28,  7,  0 },{    -67,  -67,  -56, 28,  7,  0 },{    -68,  -68,  -57, 28,  7,  0 },{    -68,  -68,  -58, 28,  7,  0 },{    -69,  -69,  -59, 28,  7,  0 },
    {    -70,  -70,  -60, 28, 55,  0 },{    -70,  -70,  -61, 28, 55,  0 },{    -71,  -71,  -62, 28, 55,  0 },{    -71,  -71,  -63, 28, 55,  0 },{    -72,  -72,  -64, 28, 55,  0 },
    {    -72,  -72,  -65, 28, 55,  0 },{    -73,  -73,  -66, 28, 55,  0 },{    -73,  -73,  -67, 28, 55,  0 },{    -74,  -74,  -68, 28, 55,  0 },{    -75,  -75,  -69, 28, 55,  0 },
    {    -75,  -75,  -70, 28, 55,  0 },{    -76,  -76,  -71, 28, 55,  0 },{    -76,  -76,  -72, 28, 55,  0 },{    -77,  -77,  -73, 28, 55,  0 },{    -77,  -77,  -74, 28, 55,  0 },
    {    -78,  -78,  -75, 28, 55,  0 },{    -78,  -78,  -76, 28, 55,  0 },{    -79,  -79,  -77, 28, 55,  0 },{    -79,  -79,  -78, 28, 55,  0 },{    -80,  -80,  -79, 28, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown60ToFlatLongBase0,{
    {     15,   16,   47,  4, 55,  0 },{     15,   16,   46,  4, 55,  0 },{     14,   17,   45,  4, 55,  0 },{     14,   17,   44,  4, 55,  0 },{     13,   18,   43,  4, 55,  0 },
    {     13,   18,   42,  4, 55,  0 },{     12,   19,   41,  4, 55,  0 },{     12,   19,   40,  4, 55,  0 },{     11,   20,   39,  4, 55,  0 },{     11,   20,   38,  4, 55,  0 },
    {     10,   21,   37,  4, 55,  0 },{      9,   22,   36,  4, 55,  0 },{      9,   22,   35,  4, 55,  0 },{      8,   23,   34,  4, 55,  0 },{      8,   23,   33,  4, 55,  0 },
    {      7,   24,   32,  4, 55,  0 },{      7,   24,   31,  4, 55,  0 },{      6,   25,   30,  4, 55,  0 },{      6,   25,   29,  4, 55,  0 },{      5,   26,   28,  4,  7,  0 },
    {      4,   27,   27,  4,  7,  0 },{      4,   27,   26,  4,  7,  0 },{      3,   28,   25,  4,  7,  0 },{      3,   28,   24,  4,  7,  0 },{      2,   29,   23,  4,  7,  0 },
    {      1,   30,   22,  4,  7,  0 },{      1,   30,   21,  4,  7,  0 },{      0,   31,   20,  4,  7,  0 },{     -1,   32,   19,  4,  7,  0 },{     -1,   32,   18,  4,  7,  0 },
    {     -2,   33,   17,  4,  7,  0 },{     -2,   33,   16,  4,  7,  0 },{     -3,   34,   15,  4,  7,  0 },{     -4,   35,   14,  4,  7,  0 },{     -4,   35,   13,  4,  7,  0 },
    {     -5,   36,   12,  4,  7,  0 },{     -6,   37,   11,  4,  7,  0 },{     -7,   38,   10,  4,  7,  0 },{     -7,   38,    9,  4,  7,  0 },{     -8,   39,    8,  4,  7,  0 },
    {     -9,   40,    7,  4,  7,  0 },{     -9,   40,    6,  4,  7,  0 },{    -10,   41,    5,  4,  7,  0 },{    -11,   42,    4,  4,  7,  0 },{    -12,   43,    3,  4,  7,  0 },
    {    -12,   43,    2,  4,  7,  0 },{    -13,   44,    1,  4,  7,  0 },{    -14,   45,    0,  4,  7,  0 },{    -15,   46,   -1,  4,  7,  0 },{    -16,   47,   -2,  4,  7,  0 },
    {    -16,   47,   -3,  4,  7,  0 },{    -17,   48,   -4,  4,  7,  0 },{    -18,   49,   -5,  4,  7,  0 },{    -19,   50,   -6,  4,  7,  0 },{    -20,   51,   -7,  4,  7,  0 },
    {    -21,   52,   -8,  4,  7,  0 },{    -22,   53,   -9,  4,  7,  0 },{    -23,   54,  -10,  4,  7,  0 },{    -23,   54,  -11,  4,  7,  0 },{    -24,   55,  -12,  4,  6,  0 },
    {    -25,   56,  -13,  4,  6,  0 },{    -26,   57,  -14,  4,  6,  0 },{    -27,   58,  -15,  4,  6,  0 },{    -28,   59,  -16,  4,  6,  0 },{    -29,   60,  -17,  4,  6,  0 },
    {    -30,   61,  -18,  4,  6,  0 },{    -31,   62,  -19,  4,  6,  0 },{    -32,   63,  -20,  4,  6,  0 },{    -33,   64,  -21,  4,  6,  0 },{    -34,   65,  -22,  4,  6,  0 },
    {    -35,   66,  -23,  4,  6,  0 },{    -36,   67,  -23,  4,  6,  0 },{    -37,   68,  -24,  4,  6,  0 },{    -38,   69,  -25,  4,  6,  0 },{    -39,   70,  -26,  4,  6,  0 },
    {    -40,   71,  -26,  4,  6,  0 },{    -41,   72,  -27,  4,  6,  0 },{    -42,   73,  -28,  4,  6,  0 },{    -43,   74,  -28,  4,  6,  0 },{    -44,   75,  -29,  4,  6,  0 },
    {    -45,   76,  -30,  4,  6,  0 },{    -46,   77,  -30,  4, 54,  0 },{    -47,   78,  -31,  4, 54,  0 },{    -48,   79,  -31,  4, 54,  0 },{    -49,   80,  -32,  4, 54,  0 },
    {    -50,   81,  -32,  4, 54,  0 },{    -51,   82,  -33,  4, 54,  0 },{    -52,   83,  -33,  4, 54,  0 },{    -53,   84,  -34,  4, 54,  0 },{    -54,   85,  -34,  4, 54,  0 },
    {    -55,   86,  -35,  4, 54,  0 },{    -56,   87,  -35,  4, 54,  0 },{    -57,   88,  -36,  4, 54,  0 },{    -58,   89,  -36,  4, 54,  0 },{    -59,   90,  -36,  4, 53,  0 },
    {    -60,   91,  -37,  4, 53,  0 },{    -61,   92,  -37,  4, 53,  0 },{    -62,   93,  -37,  4, 53,  0 },{    -63,   94,  -38,  4, 53,  0 },{    -64,   95,  -38,  4, 53,  0 },
    {    -65,   96,  -38,  4, 53,  0 },{    -66,   97,  -38,  4, 53,  0 },{    -67,   98,  -39,  4, 53,  0 },{    -68,   99,  -39,  4, 53,  0 },{    -69,  100,  -39,  4, 53,  0 },
    {    -70,  101,  -39,  4, 53,  0 },{    -71,  102,  -39,  4, 53,  0 },{    -72,  103,  -40,  4, 53,  0 },{    -73,  104,  -40,  4,  0,  0 },{    -74,  105,  -40,  4,  0,  0 },
    {    -75,  106,  -40,  4,  0,  0 },{    -76,  107,  -40,  4,  0,  0 },{    -77,  108,  -40,  4,  0,  0 },{    -78,  109,  -40,  4,  0,  0 },{    -79,  110,  -40,  4,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown60ToFlatLongBase1,{
    {     16,   16,   48, 12, 55,  0 },{     17,   17,   47, 12, 55,  0 },{     17,   17,   46, 12, 55,  0 },{     18,   18,   45, 12, 55,  0 },{     18,   18,   44, 12, 55,  0 },
    {     19,   19,   43, 12, 55,  0 },{     19,   19,   42, 12, 55,  0 },{     20,   20,   41, 12, 55,  0 },{     20,   20,   40, 12, 55,  0 },{     21,   21,   39, 12, 55,  0 },
    {     21,   21,   38, 12, 55,  0 },{     22,   22,   37, 12, 55,  0 },{     23,   23,   36, 12, 55,  0 },{     23,   23,   35, 12, 55,  0 },{     24,   24,   34, 12, 55,  0 },
    {     24,   24,   33, 12, 55,  0 },{     25,   25,   32, 12, 55,  0 },{     25,   25,   31, 12, 55,  0 },{     26,   26,   30, 12, 55,  0 },{     26,   26,   29, 12, 55,  0 },
    {     27,   27,   28, 12,  7,  0 },{     28,   28,   27, 12,  7,  0 },{     28,   28,   26, 12,  7,  0 },{     29,   29,   25, 12,  7,  0 },{     29,   29,   24, 12,  7,  0 },
    {     30,   30,   23, 12,  7,  0 },{     31,   31,   22, 12,  7,  0 },{     31,   31,   21, 12,  7,  0 },{     32,   32,   20, 12,  7,  0 },{     33,   33,   19, 12,  7,  0 },
    {     33,   33,   18, 12,  7,  0 },{     34,   34,   17, 12,  7,  0 },{     34,   34,   16, 12,  7,  0 },{     35,   35,   15, 12,  7,  0 },{     36,   36,   14, 12,  7,  0 },
    {     36,   36,   13, 12,  7,  0 },{     37,   37,   12, 12,  7,  0 },{     38,   38,   11, 12,  7,  0 },{     39,   39,   10, 12,  7,  0 },{     39,   39,    9, 12,  7,  0 },
    {     40,   40,    8, 12,  7,  0 },{     41,   41,    7, 12,  7,  0 },{     41,   41,    6, 12,  7,  0 },{     42,   42,    5, 12,  7,  0 },{     43,   43,    4, 12,  7,  0 },
    {     44,   44,    3, 12,  7,  0 },{     44,   44,    2, 12,  7,  0 },{     45,   45,    1, 12,  7,  0 },{     46,   46,    0, 12,  7,  0 },{     47,   47,   -1, 12,  7,  0 },
    {     48,   48,   -2, 12,  7,  0 },{     48,   48,   -3, 12,  7,  0 },{     49,   49,   -4, 12,  7,  0 },{     50,   50,   -5, 12,  7,  0 },{     51,   51,   -6, 12,  7,  0 },
    {     52,   52,   -7, 12,  7,  0 },{     53,   53,   -8, 12,  7,  0 },{     54,   54,   -9, 12,  7,  0 },{     55,   55,  -10, 12,  7,  0 },{     55,   55,  -11, 12,  7,  0 },
    {     56,   56,  -12, 12,  6,  0 },{     57,   57,  -13, 12,  6,  0 },{     58,   58,  -14, 12,  6,  0 },{     59,   59,  -15, 12,  6,  0 },{     60,   60,  -16, 12,  6,  0 },
    {     61,   61,  -17, 12,  6,  0 },{     62,   62,  -18, 12,  6,  0 },{     63,   63,  -19, 12,  6,  0 },{     64,   64,  -20, 12,  6,  0 },{     65,   65,  -21, 12,  6,  0 },
    {     66,   66,  -22, 12,  6,  0 },{     67,   67,  -23, 12,  6,  0 },{     68,   68,  -23, 12,  6,  0 },{     69,   69,  -24, 12,  6,  0 },{     70,   70,  -25, 12,  6,  0 },
    {     71,   71,  -26, 12,  6,  0 },{     72,   72,  -26, 12,  6,  0 },{     73,   73,  -27, 12,  6,  0 },{     74,   74,  -28, 12,  6,  0 },{     75,   75,  -28, 12,  6,  0 },
    {     76,   76,  -29, 12,  6,  0 },{     77,   77,  -30, 12,  6,  0 },{     78,   78,  -30, 12, 54,  0 },{     79,   79,  -31, 12, 54,  0 },{     80,   80,  -31, 12, 54,  0 },
    {     81,   81,  -32, 12, 54,  0 },{     82,   82,  -32, 12, 54,  0 },{     83,   83,  -33, 12, 54,  0 },{     84,   84,  -33, 12, 54,  0 },{     85,   85,  -34, 12, 54,  0 },
    {     86,   86,  -34, 12, 54,  0 },{     87,   87,  -35, 12, 54,  0 },{     88,   88,  -35, 12, 54,  0 },{     89,   89,  -36, 12, 54,  0 },{     90,   90,  -36, 12, 54,  0 },
    {     91,   91,  -36, 12, 53,  0 },{     92,   92,  -37, 12, 53,  0 },{     93,   93,  -37, 12, 53,  0 },{     94,   94,  -37, 12, 53,  0 },{     95,   95,  -38, 12, 53,  0 },
    {     96,   96,  -38, 12, 53,  0 },{     97,   97,  -38, 12, 53,  0 },{     98,   98,  -38, 12, 53,  0 },{     99,   99,  -39, 12, 53,  0 },{    100,  100,  -39, 12, 53,  0 },
    {    101,  101,  -39, 12, 53,  0 },{    102,  102,  -39, 12, 53,  0 },{    103,  103,  -39, 12, 53,  0 },{    104,  104,  -40, 12, 53,  0 },{    105,  105,  -40, 12,  0,  0 },
    {    106,  106,  -40, 12,  0,  0 },{    107,  107,  -40, 12,  0,  0 },{    108,  108,  -40, 12,  0,  0 },{    109,  109,  -40, 12,  0,  0 },{    110,  110,  -40, 12,  0,  0 },
    {    111,  111,  -40, 12,  0,  0 },{    112,  112,  -40, 12,  0,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown60ToFlatLongBase2,{
    {     16,   15,   48, 20, 55,  0 },{     17,   14,   47, 20, 55,  0 },{     17,   14,   46, 20, 55,  0 },{     18,   13,   45, 20, 55,  0 },{     18,   13,   44, 20, 55,  0 },
    {     19,   12,   43, 20, 55,  0 },{     19,   12,   42, 20, 55,  0 },{     20,   11,   41, 20, 55,  0 },{     20,   11,   40, 20, 55,  0 },{     21,   10,   39, 20, 55,  0 },
    {     21,   10,   38, 20, 55,  0 },{     22,    9,   37, 20, 55,  0 },{     23,    8,   36, 20, 55,  0 },{     23,    8,   35, 20, 55,  0 },{     24,    7,   34, 20, 55,  0 },
    {     24,    7,   33, 20, 55,  0 },{     25,    6,   32, 20, 55,  0 },{     25,    6,   31, 20, 55,  0 },{     26,    5,   30, 20, 55,  0 },{     26,    5,   29, 20, 55,  0 },
    {     27,    4,   28, 20,  7,  0 },{     28,    3,   27, 20,  7,  0 },{     28,    3,   26, 20,  7,  0 },{     29,    2,   25, 20,  7,  0 },{     29,    2,   24, 20,  7,  0 },
    {     30,    1,   23, 20,  7,  0 },{     31,    0,   22, 20,  7,  0 },{     31,    0,   21, 20,  7,  0 },{     32,   -1,   20, 20,  7,  0 },{     33,   -2,   19, 20,  7,  0 },
    {     33,   -2,   18, 20,  7,  0 },{     34,   -3,   17, 20,  7,  0 },{     34,   -3,   16, 20,  7,  0 },{     35,   -4,   15, 20,  7,  0 },{     36,   -5,   14, 20,  7,  0 },
    {     36,   -5,   13, 20,  7,  0 },{     37,   -6,   12, 20,  7,  0 },{     38,   -7,   11, 20,  7,  0 },{     39,   -8,   10, 20,  7,  0 },{     39,   -8,    9, 20,  7,  0 },
    {     40,   -9,    8, 20,  7,  0 },{     41,  -10,    7, 20,  7,  0 },{     41,  -10,    6, 20,  7,  0 },{     42,  -11,    5, 20,  7,  0 },{     43,  -12,    4, 20,  7,  0 },
    {     44,  -13,    3, 20,  7,  0 },{     44,  -13,    2, 20,  7,  0 },{     45,  -14,    1, 20,  7,  0 },{     46,  -15,    0, 20,  7,  0 },{     47,  -16,   -1, 20,  7,  0 },
    {     48,  -17,   -2, 20,  7,  0 },{     48,  -17,   -3, 20,  7,  0 },{     49,  -18,   -4, 20,  7,  0 },{     50,  -19,   -5, 20,  7,  0 },{     51,  -20,   -6, 20,  7,  0 },
    {     52,  -21,   -7, 20,  7,  0 },{     53,  -22,   -8, 20,  7,  0 },{     54,  -23,   -9, 20,  7,  0 },{     55,  -24,  -10, 20,  7,  0 },{     55,  -24,  -11, 20,  7,  0 },
    {     56,  -25,  -12, 20,  6,  0 },{     57,  -26,  -13, 20,  6,  0 },{     58,  -27,  -14, 20,  6,  0 },{     59,  -28,  -15, 20,  6,  0 },{     60,  -29,  -16, 20,  6,  0 },
    {     61,  -30,  -17, 20,  6,  0 },{     62,  -31,  -18, 20,  6,  0 },{     63,  -32,  -19, 20,  6,  0 },{     64,  -33,  -20, 20,  6,  0 },{     65,  -34,  -21, 20,  6,  0 },
    {     66,  -35,  -22, 20,  6,  0 },{     67,  -36,  -23, 20,  6,  0 },{     68,  -37,  -23, 20,  6,  0 },{     69,  -38,  -24, 20,  6,  0 },{     70,  -39,  -25, 20,  6,  0 },
    {     71,  -40,  -26, 20,  6,  0 },{     72,  -41,  -26, 20,  6,  0 },{     73,  -42,  -27, 20,  6,  0 },{     74,  -43,  -28, 20,  6,  0 },{     75,  -44,  -28, 20,  6,  0 },
    {     76,  -45,  -29, 20,  6,  0 },{     77,  -46,  -30, 20,  6,  0 },{     78,  -47,  -30, 20, 54,  0 },{     79,  -48,  -31, 20, 54,  0 },{     80,  -49,  -31, 20, 54,  0 },
    {     81,  -50,  -32, 20, 54,  0 },{     82,  -51,  -32, 20, 54,  0 },{     83,  -52,  -33, 20, 54,  0 },{     84,  -53,  -33, 20, 54,  0 },{     85,  -54,  -34, 20, 54,  0 },
    {     86,  -55,  -34, 20, 54,  0 },{     87,  -56,  -35, 20, 54,  0 },{     88,  -57,  -35, 20, 54,  0 },{     89,  -58,  -36, 20, 54,  0 },{     90,  -59,  -36, 20, 54,  0 },
    {     91,  -60,  -36, 20, 53,  0 },{     92,  -61,  -37, 20, 53,  0 },{     93,  -62,  -37, 20, 53,  0 },{     94,  -63,  -37, 20, 53,  0 },{     95,  -64,  -38, 20, 53,  0 },
    {     96,  -65,  -38, 20, 53,  0 },{     97,  -66,  -38, 20, 53,  0 },{     98,  -67,  -38, 20, 53,  0 },{     99,  -68,  -39, 20, 53,  0 },{    100,  -69,  -39, 20, 53,  0 },
    {    101,  -70,  -39, 20, 53,  0 },{    102,  -71,  -39, 20, 53,  0 },{    103,  -72,  -39, 20, 53,  0 },{    104,  -73,  -40, 20, 53,  0 },{    105,  -74,  -40, 20,  0,  0 },
    {    106,  -75,  -40, 20,  0,  0 },{    107,  -76,  -40, 20,  0,  0 },{    108,  -77,  -40, 20,  0,  0 },{    109,  -78,  -40, 20,  0,  0 },{    110,  -79,  -40, 20,  0,  0 },
    {    111,  -80,  -40, 20,  0,  0 },{    112,  -81,  -40, 20,  0,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoDiagDown60ToFlatLongBase3,{
    {     15,   15,   47, 28, 55,  0 },{     15,   15,   46, 28, 55,  0 },{     14,   14,   45, 28, 55,  0 },{     14,   14,   44, 28, 55,  0 },{     13,   13,   43, 28, 55,  0 },
    {     13,   13,   42, 28, 55,  0 },{     12,   12,   41, 28, 55,  0 },{     12,   12,   40, 28, 55,  0 },{     11,   11,   39, 28, 55,  0 },{     11,   11,   38, 28, 55,  0 },
    {     10,   10,   37, 28, 55,  0 },{      9,    9,   36, 28, 55,  0 },{      9,    9,   35, 28, 55,  0 },{      8,    8,   34, 28, 55,  0 },{      8,    8,   33, 28, 55,  0 },
    {      7,    7,   32, 28, 55,  0 },{      7,    7,   31, 28, 55,  0 },{      6,    6,   30, 28, 55,  0 },{      6,    6,   29, 28, 55,  0 },{      5,    5,   28, 28,  7,  0 },
    {      4,    4,   27, 28,  7,  0 },{      4,    4,   26, 28,  7,  0 },{      3,    3,   25, 28,  7,  0 },{      3,    3,   24, 28,  7,  0 },{      2,    2,   23, 28,  7,  0 },
    {      1,    1,   22, 28,  7,  0 },{      1,    1,   21, 28,  7,  0 },{      0,    0,   20, 28,  7,  0 },{     -1,   -1,   19, 28,  7,  0 },{     -1,   -1,   18, 28,  7,  0 },
    {     -2,   -2,   17, 28,  7,  0 },{     -2,   -2,   16, 28,  7,  0 },{     -3,   -3,   15, 28,  7,  0 },{     -4,   -4,   14, 28,  7,  0 },{     -4,   -4,   13, 28,  7,  0 },
    {     -5,   -5,   12, 28,  7,  0 },{     -6,   -6,   11, 28,  7,  0 },{     -7,   -7,   10, 28,  7,  0 },{     -7,   -7,    9, 28,  7,  0 },{     -8,   -8,    8, 28,  7,  0 },
    {     -9,   -9,    7, 28,  7,  0 },{     -9,   -9,    6, 28,  7,  0 },{    -10,  -10,    5, 28,  7,  0 },{    -11,  -11,    4, 28,  7,  0 },{    -12,  -12,    3, 28,  7,  0 },
    {    -12,  -12,    2, 28,  7,  0 },{    -13,  -13,    1, 28,  7,  0 },{    -14,  -14,    0, 28,  7,  0 },{    -15,  -15,   -1, 28,  7,  0 },{    -16,  -16,   -2, 28,  7,  0 },
    {    -16,  -16,   -3, 28,  7,  0 },{    -17,  -17,   -4, 28,  7,  0 },{    -18,  -18,   -5, 28,  7,  0 },{    -19,  -19,   -6, 28,  7,  0 },{    -20,  -20,   -7, 28,  7,  0 },
    {    -21,  -21,   -8, 28,  7,  0 },{    -22,  -22,   -9, 28,  7,  0 },{    -23,  -23,  -10, 28,  7,  0 },{    -23,  -23,  -11, 28,  7,  0 },{    -24,  -24,  -12, 28,  6,  0 },
    {    -25,  -25,  -13, 28,  6,  0 },{    -26,  -26,  -14, 28,  6,  0 },{    -27,  -27,  -15, 28,  6,  0 },{    -28,  -28,  -16, 28,  6,  0 },{    -29,  -29,  -17, 28,  6,  0 },
    {    -30,  -30,  -18, 28,  6,  0 },{    -31,  -31,  -19, 28,  6,  0 },{    -32,  -32,  -20, 28,  6,  0 },{    -33,  -33,  -21, 28,  6,  0 },{    -34,  -34,  -22, 28,  6,  0 },
    {    -35,  -35,  -23, 28,  6,  0 },{    -36,  -36,  -23, 28,  6,  0 },{    -37,  -37,  -24, 28,  6,  0 },{    -38,  -38,  -25, 28,  6,  0 },{    -39,  -39,  -26, 28,  6,  0 },
    {    -40,  -40,  -26, 28,  6,  0 },{    -41,  -41,  -27, 28,  6,  0 },{    -42,  -42,  -28, 28,  6,  0 },{    -43,  -43,  -28, 28,  6,  0 },{    -44,  -44,  -29, 28,  6,  0 },
    {    -45,  -45,  -30, 28,  6,  0 },{    -46,  -46,  -30, 28, 54,  0 },{    -47,  -47,  -31, 28, 54,  0 },{    -48,  -48,  -31, 28, 54,  0 },{    -49,  -49,  -32, 28, 54,  0 },
    {    -50,  -50,  -32, 28, 54,  0 },{    -51,  -51,  -33, 28, 54,  0 },{    -52,  -52,  -33, 28, 54,  0 },{    -53,  -53,  -34, 28, 54,  0 },{    -54,  -54,  -34, 28, 54,  0 },
    {    -55,  -55,  -35, 28, 54,  0 },{    -56,  -56,  -35, 28, 54,  0 },{    -57,  -57,  -36, 28, 54,  0 },{    -58,  -58,  -36, 28, 54,  0 },{    -59,  -59,  -36, 28, 53,  0 },
    {    -60,  -60,  -37, 28, 53,  0 },{    -61,  -61,  -37, 28, 53,  0 },{    -62,  -62,  -37, 28, 53,  0 },{    -63,  -63,  -38, 28, 53,  0 },{    -64,  -64,  -38, 28, 53,  0 },
    {    -65,  -65,  -38, 28, 53,  0 },{    -66,  -66,  -38, 28, 53,  0 },{    -67,  -67,  -39, 28, 53,  0 },{    -68,  -68,  -39, 28, 53,  0 },{    -69,  -69,  -39, 28, 53,  0 },
    {    -70,  -70,  -39, 28, 53,  0 },{    -71,  -71,  -39, 28, 53,  0 },{    -72,  -72,  -40, 28, 53,  0 },{    -73,  -73,  -40, 28,  0,  0 },{    -74,  -74,  -40, 28,  0,  0 },
    {    -75,  -75,  -40, 28,  0,  0 },{    -76,  -76,  -40, 28,  0,  0 },{    -77,  -77,  -40, 28,  0,  0 },{    -78,  -78,  -40, 28,  0,  0 },{    -79,  -79,  -40, 28,  0,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthDiveLoopUpToOrthogonal0,{
    {     15,   16,    1,  4, 52,  0 },{     15,   16,    2,  4, 52,  0 },{     14,   17,    3,  4, 52,  0 },{     14,   17,    4,  4, 52,  0 },{     13,   18,    5,  4, 52,  0 },
    {     13,   18,    6,  4, 52,  0 },{     12,   19,    7,  4, 52,  0 },{     12,   19,    8,  4, 52,  0 },{     11,   19,    9,  4, 52,  0 },{     11,   20,   10,  4, 52,  0 },
    {     10,   20,   11,  4, 52,  0 },{     10,   21,   12,  4, 52,  0 },{      9,   21,   13,  4, 52,  0 },{      9,   22,   14,  4, 52,  0 },{      8,   22,   15,  4, 52,  0 },
    {      8,   22,   16,  4, 52,  0 },{      7,   23,   17,  4, 52,  0 },{      7,   23,   18,  4, 52,  0 },{      6,   24,   19,  4, 52,  0 },{      6,   24,   20,  4, 52,  0 },
    {      5,   24,   21,  4, 52,  0 },{      5,   25,   22,  4, 52,  0 },{      4,   25,   23,  4, 52,  0 },{      4,   26,   24,  4, 52,  0 },{      3,   26,   25,  4, 52,  0 },
    {      3,   26,   26,  4,  4,  1 },{      2,   27,   27,  4,  4,  1 },{      2,   27,   28,  4,  4,  1 },{      1,   27,   29,  4,  4,  1 },{      1,   28,   30,  4,  4,  1 },
    {      0,   28,   31,  4,  4,  1 },{      0,   28,   32,  4,  4,  1 },{     -1,   29,   33,  4,  4,  1 },{     -1,   29,   34,  4,  4,  1 },{     -2,   29,   35,  4,  4,  1 },
    {     -2,   30,   36,  4,  4,  1 },{     -3,   30,   37,  4,  4,  1 },{     -3,   30,   38,  4,  4,  1 },{     -4,   31,   39,  4,  4,  1 },{     -4,   31,   40,  4,  4,  1 },
    {     -5,   31,   41,  2, 52,  2 },{     -5,   32,   42,  2, 52,  2 },{     -6,   32,   43,  2, 52,  2 },{     -6,   32,   44,  2, 52,  2 },{     -7,   33,   45,  2, 52,  2 },
    {     -7,   33,   46,  2, 52,  2 },{     -8,   33,   47,  2, 52,  2 },{     -8,   33,   48,  2, 52,  2 },{     -9,   34,   49,  2, 52,  2 },{     -9,   34,   50,  2, 52,  2 },
    {    -10,   34,   51,  2, 52,  2 },{    -10,   35,   52,  2, 52,  2 },{    -11,   35,   53,  2, 52,  2 },{    -11,   35,   54,  2, 52,  2 },{    -12,   35,   55,  2, 52,  5 },
    {    -12,   36,   56,  2, 52,  5 },{    -13,   36,   57,  2, 52,  5 },{    -13,   36,   58,  2, 52,  5 },{    -14,   36,   59,  2, 52,  5 },{    -14,   37,   60,  2, 52,  5 },
    {    -15,   37,   61,  2, 52,  5 },{    -16,   37,   62,  2, 52,  5 },{    -16,   37,   63,  2, 52,  5 },{    -17,   38,   64,  2, 52,  5 },{    -17,   38,   65,  2, 52,  5 },
    {    -18,   38,   66,  2, 52,  5 },{    -18,   38,   67,  2, 52,  5 },{    -19,   38,   68,  2, 52,  5 },{    -19,   39,   69,  2, 52,  5 },{    -20,   39,   70,  2, 52,  5 },
    {    -21,   39,   71,  2, 52,  5 },{    -21,   39,   72,  2, 52,  5 },{    -22,   39,   73,  2, 52,  6 },{    -22,   40,   74,  2, 52,  6 },{    -23,   40,   75,  2, 52,  6 },
    {    -23,   40,   76,  2, 52,  6 },{    -24,   40,   77,  2, 52,  6 },{    -25,   40,   78,  2, 52,  6 },{    -25,   41,   79,  2, 52,  6 },{    -26,   41,   80,  2, 52,  6 },
    {    -26,   41,   81,  2, 52,  6 },{    -27,   41,   82,  2, 52,  6 },{    -28,   41,   83,  2, 52,  6 },{    -28,   42,   84,  2, 52,  6 },{    -29,   42,   85,  2, 52,  6 },
    {    -30,   42,   86,  2, 52,  6 },{    -30,   42,   87,  2, 52,  6 },{    -31,   42,   88,  2, 52,  6 },{    -31,   42,   89,  2, 52,  6 },{    -32,   43,   90,  2, 52,  6 },
    {    -33,   43,   91,  2, 52,  6 },{    -33,   43,   92,  2, 52,  6 },{    -34,   43,   93,  2, 52,  6 },{    -35,   43,   94,  2, 52,  6 },{    -35,   43,   95,  2, 52,  6 },
    {    -36,   43,   96,  2, 52,  6 },{    -37,   44,   97,  2, 52,  6 },{    -38,   44,   98,  2, 52,  6 },{    -38,   44,   99,  2,  3,  8 },{    -39,   44,  100,  2,  3,  8 },
    {    -40,   44,  101,  2,  3,  8 },{    -41,   44,  102,  2,  3,  8 },{    -41,   44,  103,  2,  3,  8 },{    -42,   45,  104,  2,  3,  8 },{    -43,   45,  105,  2,  3,  8 },
    {    -44,   45,  106,  2,  3,  8 },{    -44,   45,  107,  2,  3,  8 },{    -45,   45,  108,  2,  3,  8 },{    -46,   45,  109,  2,  3,  8 },{    -47,   45,  110,  2,  3,  8 },
    {    -48,   45,  111,  2,  3,  8 },{    -49,   45,  112,  2,  3,  8 },{    -49,   45,  113,  2,  3,  8 },{    -50,   46,  114,  2,  3,  8 },{    -51,   46,  115,  2,  3,  8 },
    {    -52,   46,  116,  2,  3,  8 },{    -53,   46,  117,  2,  3,  8 },{    -54,   46,  118,  2,  3,  8 },{    -55,   46,  119,  2,  3,  8 },{    -56,   46,  120,  0,  2,  9 },
    {    -57,   46,  121,  0,  2,  9 },{    -58,   46,  122,  0,  2,  9 },{    -59,   46,  123,  0,  2,  9 },{    -60,   46,  124,  0,  2,  9 },{    -61,   46,  125,  0,  2,  9 },
    {    -62,   46,  126,  0,  2,  9 },{    -63,   47,  127,  0,  2,  9 },{    -64,   47,  127,  0,  2,  9 },{    -65,   47,  128,  0,  2,  9 },{    -66,   47,  129,  0,  2,  9 },
    {    -67,   47,  129,  0,  2,  9 },{    -68,   47,  130,  0,  2,  9 },{    -69,   47,  131,  0,  2,  9 },{    -70,   47,  131,  0,  2,  9 },{    -71,   47,  132, 16, 14,  0 },
    {    -72,   47,  132, 16, 14,  0 },{    -73,   47,  133, 16, 14,  0 },{    -74,   47,  133, 16, 15,  0 },{    -75,   47,  134, 16, 15,  0 },{    -76,   47,  134, 16, 15,  0 },
    {    -77,   47,  135, 16, 15,  0 },{    -78,   47,  135, 16, 15,  0 },{    -79,   47,  136, 16, 15,  0 },{    -80,   47,  136, 16, 15,  0 },{    -81,   47,  136, 16, 15,  0 },
    {    -82,   47,  137, 16, 15,  0 },{    -83,   47,  137, 16, 15,  0 },{    -84,   47,  137, 16, 15,  0 },{    -85,   47,  137, 16, 15,  0 },{    -86,   47,  138, 16, 15,  0 },
    {    -87,   47,  138, 16, 15,  0 },{    -88,   47,  138, 16, 15,  0 },{    -89,   47,  138, 16, 16,  0 },{    -90,   47,  138, 16, 16,  0 },{    -91,   47,  138, 16, 16,  0 },
    {    -92,   47,  139, 16, 16,  0 },{    -93,   47,  139, 16, 16,  0 },{    -94,   47,  139, 16, 16,  0 },{    -95,   47,  139, 16, 16,  0 },{    -96,   47,  139, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthDiveLoopUpToOrthogonal1,{
    {     16,   16,    0, 12, 52,  0 },{     17,   17,    1, 12, 52,  0 },{     17,   17,    2, 12, 52,  0 },{     18,   18,    3, 12, 52,  0 },{     18,   18,    4, 12, 52,  0 },
    {     19,   19,    5, 12, 52,  0 },{     19,   19,    6, 12, 52,  0 },{     20,   20,    7, 12, 52,  0 },{     20,   20,    8, 12, 52,  0 },{     20,   21,    9, 12, 52,  0 },
    {     21,   21,   10, 12, 52,  0 },{     21,   22,   11, 12, 52,  0 },{     22,   22,   12, 12, 52,  0 },{     22,   23,   13, 12, 52,  0 },{     23,   23,   14, 12, 52,  0 },
    {     23,   24,   15, 12, 52,  0 },{     23,   24,   16, 12, 52,  0 },{     24,   25,   17, 12, 52,  0 },{     24,   25,   18, 12, 52,  0 },{     25,   26,   19, 12, 52,  0 },
    {     25,   26,   20, 12, 52,  0 },{     25,   27,   21, 12, 52,  0 },{     26,   27,   22, 12, 52,  0 },{     26,   28,   23, 12, 52,  0 },{     27,   28,   24, 12, 52,  0 },
    {     27,   29,   25, 12, 52,  0 },{     27,   29,   26, 12,  4,  1 },{     28,   30,   27, 12,  4,  1 },{     28,   30,   28, 12,  4,  1 },{     28,   31,   29, 12,  4,  1 },
    {     29,   31,   30, 12,  4,  1 },{     29,   32,   31, 12,  4,  1 },{     29,   32,   32, 12,  4,  1 },{     30,   33,   33, 12,  4,  1 },{     30,   33,   34, 12,  4,  1 },
    {     30,   34,   35, 12,  4,  1 },{     31,   34,   36, 12,  4,  1 },{     31,   35,   37, 12,  4,  1 },{     31,   35,   38, 12,  4,  1 },{     32,   36,   39, 12,  4,  1 },
    {     32,   36,   40, 12,  4,  1 },{     32,   37,   41, 10, 52,  2 },{     33,   37,   42, 10, 52,  2 },{     33,   38,   43, 10, 52,  2 },{     33,   38,   44, 10, 52,  2 },
    {     34,   39,   45, 10, 52,  2 },{     34,   39,   46, 10, 52,  2 },{     34,   40,   47, 10, 52,  2 },{     34,   40,   48, 10, 52,  2 },{     35,   41,   49, 10, 52,  2 },
    {     35,   41,   50, 10, 52,  2 },{     35,   42,   51, 10, 52,  2 },{     36,   42,   52, 10, 52,  2 },{     36,   43,   53, 10, 52,  2 },{     36,   43,   54, 10, 52,  2 },
    {     36,   44,   55, 10, 52,  5 },{     37,   44,   56, 10, 52,  5 },{     37,   45,   57, 10, 52,  5 },{     37,   45,   58, 10, 52,  5 },{     37,   46,   59, 10, 52,  5 },
    {     38,   46,   60, 10, 52,  5 },{     38,   47,   61, 10, 52,  5 },{     38,   48,   62, 10, 52,  5 },{     38,   48,   63, 10, 52,  5 },{     39,   49,   64, 10, 52,  5 },
    {     39,   49,   65, 10, 52,  5 },{     39,   50,   66, 10, 52,  5 },{     39,   50,   67, 10, 52,  5 },{     39,   51,   68, 10, 52,  5 },{     40,   51,   69, 10, 52,  5 },
    {     40,   52,   70, 10, 52,  5 },{     40,   53,   71, 10, 52,  5 },{     40,   53,   72, 10, 52,  5 },{     40,   54,   73, 10, 52,  6 },{     41,   54,   74, 10, 52,  6 },
    {     41,   55,   75, 10, 52,  6 },{     41,   55,   76, 10, 52,  6 },{     41,   56,   77, 10, 52,  6 },{     41,   57,   78, 10, 52,  6 },{     42,   57,   79, 10, 52,  6 },
    {     42,   58,   80, 10, 52,  6 },{     42,   58,   81, 10, 52,  6 },{     42,   59,   82, 10, 52,  6 },{     42,   60,   83, 10, 52,  6 },{     43,   60,   84, 10, 52,  6 },
    {     43,   61,   85, 10, 52,  6 },{     43,   62,   86, 10, 52,  6 },{     43,   62,   87, 10, 52,  6 },{     43,   63,   88, 10, 52,  6 },{     43,   63,   89, 10, 52,  6 },
    {     44,   64,   90, 10, 52,  6 },{     44,   65,   91, 10, 52,  6 },{     44,   65,   92, 10, 52,  6 },{     44,   66,   93, 10, 52,  6 },{     44,   67,   94, 10, 52,  6 },
    {     44,   67,   95, 10, 52,  6 },{     44,   68,   96, 10, 52,  6 },{     45,   69,   97, 10, 52,  6 },{     45,   70,   98, 10, 52,  6 },{     45,   70,   99, 10,  3,  8 },
    {     45,   71,  100, 10,  3,  8 },{     45,   72,  101, 10,  3,  8 },{     45,   73,  102, 10,  3,  8 },{     45,   73,  103, 10,  3,  8 },{     46,   74,  104, 10,  3,  8 },
    {     46,   75,  105, 10,  3,  8 },{     46,   76,  106, 10,  3,  8 },{     46,   76,  107, 10,  3,  8 },{     46,   77,  108, 10,  3,  8 },{     46,   78,  109, 10,  3,  8 },
    {     46,   79,  110, 10,  3,  8 },{     46,   80,  111, 10,  3,  8 },{     46,   81,  112, 10,  3,  8 },{     46,   81,  113, 10,  3,  8 },{     47,   82,  114, 10,  3,  8 },
    {     47,   83,  115, 10,  3,  8 },{     47,   84,  116, 10,  3,  8 },{     47,   85,  117, 10,  3,  8 },{     47,   86,  118, 10,  3,  8 },{     47,   87,  119, 10,  3,  8 },
    {     47,   88,  120,  8,  2,  9 },{     47,   89,  121,  8,  2,  9 },{     47,   90,  122,  8,  2,  9 },{     47,   91,  123,  8,  2,  9 },{     47,   92,  124,  8,  2,  9 },
    {     47,   93,  125,  8,  2,  9 },{     47,   94,  126,  8,  2,  9 },{     48,   95,  127,  8,  2,  9 },{     48,   96,  127,  8,  2,  9 },{     48,   97,  128,  8,  2,  9 },
    {     48,   98,  129,  8,  2,  9 },{     48,   99,  129,  8,  2,  9 },{     48,  100,  130,  8,  2,  9 },{     48,  101,  131,  8,  2,  9 },{     48,  102,  131,  8,  2,  9 },
    {     48,  103,  132, 24, 14,  0 },{     48,  104,  132, 24, 14,  0 },{     48,  105,  133, 24, 14,  0 },{     48,  106,  133, 24, 15,  0 },{     48,  107,  134, 24, 15,  0 },
    {     48,  108,  134, 24, 15,  0 },{     48,  109,  135, 24, 15,  0 },{     48,  110,  135, 24, 15,  0 },{     48,  111,  136, 24, 15,  0 },{     48,  112,  136, 24, 15,  0 },
    {     48,  113,  136, 24, 15,  0 },{     48,  114,  137, 24, 15,  0 },{     48,  115,  137, 24, 15,  0 },{     48,  116,  137, 24, 15,  0 },{     48,  117,  137, 24, 15,  0 },
    {     48,  118,  138, 24, 15,  0 },{     48,  119,  138, 24, 15,  0 },{     48,  120,  138, 24, 15,  0 },{     48,  121,  138, 24, 16,  0 },{     48,  122,  138, 24, 16,  0 },
    {     48,  123,  138, 24, 16,  0 },{     48,  124,  139, 24, 16,  0 },{     48,  125,  139, 24, 16,  0 },{     48,  126,  139, 24, 16,  0 },{     48,  127,  139, 24, 16,  0 },
    {     48,  128,  139, 24, 16,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthDiveLoopUpToOrthogonal2,{
    {     16,   15,    0, 20, 52,  0 },{     17,   14,    1, 20, 52,  0 },{     17,   14,    2, 20, 52,  0 },{     18,   13,    3, 20, 52,  0 },{     18,   13,    4, 20, 52,  0 },
    {     19,   12,    5, 20, 52,  0 },{     19,   12,    6, 20, 52,  0 },{     20,   11,    7, 20, 52,  0 },{     20,   11,    8, 20, 52,  0 },{     21,   11,    9, 20, 52,  0 },
    {     21,   10,   10, 20, 52,  0 },{     22,   10,   11, 20, 52,  0 },{     22,    9,   12, 20, 52,  0 },{     23,    9,   13, 20, 52,  0 },{     23,    8,   14, 20, 52,  0 },
    {     24,    8,   15, 20, 52,  0 },{     24,    8,   16, 20, 52,  0 },{     25,    7,   17, 20, 52,  0 },{     25,    7,   18, 20, 52,  0 },{     26,    6,   19, 20, 52,  0 },
    {     26,    6,   20, 20, 52,  0 },{     27,    6,   21, 20, 52,  0 },{     27,    5,   22, 20, 52,  0 },{     28,    5,   23, 20, 52,  0 },{     28,    4,   24, 20, 52,  0 },
    {     29,    4,   25, 20, 52,  0 },{     29,    4,   26, 20,  4,  1 },{     30,    3,   27, 20,  4,  1 },{     30,    3,   28, 20,  4,  1 },{     31,    3,   29, 20,  4,  1 },
    {     31,    2,   30, 20,  4,  1 },{     32,    2,   31, 20,  4,  1 },{     32,    2,   32, 20,  4,  1 },{     33,    1,   33, 20,  4,  1 },{     33,    1,   34, 20,  4,  1 },
    {     34,    1,   35, 20,  4,  1 },{     34,    0,   36, 20,  4,  1 },{     35,    0,   37, 20,  4,  1 },{     35,    0,   38, 20,  4,  1 },{     36,   -1,   39, 20,  4,  1 },
    {     36,   -1,   40, 20,  4,  1 },{     37,   -1,   41, 18, 52,  2 },{     37,   -2,   42, 18, 52,  2 },{     38,   -2,   43, 18, 52,  2 },{     38,   -2,   44, 18, 52,  2 },
    {     39,   -3,   45, 18, 52,  2 },{     39,   -3,   46, 18, 52,  2 },{     40,   -3,   47, 18, 52,  2 },{     40,   -3,   48, 18, 52,  2 },{     41,   -4,   49, 18, 52,  2 },
    {     41,   -4,   50, 18, 52,  2 },{     42,   -4,   51, 18, 52,  2 },{     42,   -5,   52, 18, 52,  2 },{     43,   -5,   53, 18, 52,  2 },{     43,   -5,   54, 18, 52,  2 },
    {     44,   -5,   55, 18, 52,  5 },{     44,   -6,   56, 18, 52,  5 },{     45,   -6,   57, 18, 52,  5 },{     45,   -6,   58, 18, 52,  5 },{     46,   -6,   59, 18, 52,  5 },
    {     46,   -7,   60, 18, 52,  5 },{     47,   -7,   61, 18, 52,  5 },{     48,   -7,   62, 18, 52,  5 },{     48,   -7,   63, 18, 52,  5 },{     49,   -8,   64, 18, 52,  5 },
    {     49,   -8,   65, 18, 52,  5 },{     50,   -8,   66, 18, 52,  5 },{     50,   -8,   67, 18, 52,  5 },{     51,   -8,   68, 18, 52,  5 },{     51,   -9,   69, 18, 52,  5 },
    {     52,   -9,   70, 18, 52,  5 },{     53,   -9,   71, 18, 52,  5 },{     53,   -9,   72, 18, 52,  5 },{     54,   -9,   73, 18, 52,  6 },{     54,  -10,   74, 18, 52,  6 },
    {     55,  -10,   75, 18, 52,  6 },{     55,  -10,   76, 18, 52,  6 },{     56,  -10,   77, 18, 52,  6 },{     57,  -10,   78, 18, 52,  6 },{     57,  -11,   79, 18, 52,  6 },
    {     58,  -11,   80, 18, 52,  6 },{     58,  -11,   81, 18, 52,  6 },{     59,  -11,   82, 18, 52,  6 },{     60,  -11,   83, 18, 52,  6 },{     60,  -12,   84, 18, 52,  6 },
    {     61,  -12,   85, 18, 52,  6 },{     62,  -12,   86, 18, 52,  6 },{     62,  -12,   87, 18, 52,  6 },{     63,  -12,   88, 18, 52,  6 },{     63,  -12,   89, 18, 52,  6 },
    {     64,  -13,   90, 18, 52,  6 },{     65,  -13,   91, 18, 52,  6 },{     65,  -13,   92, 18, 52,  6 },{     66,  -13,   93, 18, 52,  6 },{     67,  -13,   94, 18, 52,  6 },
    {     67,  -13,   95, 18, 52,  6 },{     68,  -13,   96, 18, 52,  6 },{     69,  -14,   97, 18, 52,  6 },{     70,  -14,   98, 18, 52,  6 },{     70,  -14,   99, 18,  3,  8 },
    {     71,  -14,  100, 18,  3,  8 },{     72,  -14,  101, 18,  3,  8 },{     73,  -14,  102, 18,  3,  8 },{     73,  -14,  103, 18,  3,  8 },{     74,  -15,  104, 18,  3,  8 },
    {     75,  -15,  105, 18,  3,  8 },{     76,  -15,  106, 18,  3,  8 },{     76,  -15,  107, 18,  3,  8 },{     77,  -15,  108, 18,  3,  8 },{     78,  -15,  109, 18,  3,  8 },
    {     79,  -15,  110, 18,  3,  8 },{     80,  -15,  111, 18,  3,  8 },{     81,  -15,  112, 18,  3,  8 },{     81,  -15,  113, 18,  3,  8 },{     82,  -16,  114, 18,  3,  8 },
    {     83,  -16,  115, 18,  3,  8 },{     84,  -16,  116, 18,  3,  8 },{     85,  -16,  117, 18,  3,  8 },{     86,  -16,  118, 18,  3,  8 },{     87,  -16,  119, 18,  3,  8 },
    {     88,  -16,  120, 16,  2,  9 },{     89,  -16,  121, 16,  2,  9 },{     90,  -16,  122, 16,  2,  9 },{     91,  -16,  123, 16,  2,  9 },{     92,  -16,  124, 16,  2,  9 },
    {     93,  -16,  125, 16,  2,  9 },{     94,  -16,  126, 16,  2,  9 },{     95,  -17,  127, 16,  2,  9 },{     96,  -17,  127, 16,  2,  9 },{     97,  -17,  128, 16,  2,  9 },
    {     98,  -17,  129, 16,  2,  9 },{     99,  -17,  129, 16,  2,  9 },{    100,  -17,  130, 16,  2,  9 },{    101,  -17,  131, 16,  2,  9 },{    102,  -17,  131, 16,  2,  9 },
    {    103,  -17,  132,  0, 14,  0 },{    104,  -17,  132,  0, 14,  0 },{    105,  -17,  133,  0, 14,  0 },{    106,  -17,  133,  0, 15,  0 },{    107,  -17,  134,  0, 15,  0 },
    {    108,  -17,  134,  0, 15,  0 },{    109,  -17,  135,  0, 15,  0 },{    110,  -17,  135,  0, 15,  0 },{    111,  -17,  136,  0, 15,  0 },{    112,  -17,  136,  0, 15,  0 },
    {    113,  -17,  136,  0, 15,  0 },{    114,  -17,  137,  0, 15,  0 },{    115,  -17,  137,  0, 15,  0 },{    116,  -17,  137,  0, 15,  0 },{    117,  -17,  137,  0, 15,  0 },
    {    118,  -17,  138,  0, 15,  0 },{    119,  -17,  138,  0, 15,  0 },{    120,  -17,  138,  0, 15,  0 },{    121,  -17,  138,  0, 16,  0 },{    122,  -17,  138,  0, 16,  0 },
    {    123,  -17,  138,  0, 16,  0 },{    124,  -17,  139,  0, 16,  0 },{    125,  -17,  139,  0, 16,  0 },{    126,  -17,  139,  0, 16,  0 },{    127,  -17,  139,  0, 16,  0 },
    {    128,  -17,  139,  0, 16,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthDiveLoopUpToOrthogonal3,{
    {     15,   15,    1, 28, 52,  0 },{     15,   15,    2, 28, 52,  0 },{     14,   14,    3, 28, 52,  0 },{     14,   14,    4, 28, 52,  0 },{     13,   13,    5, 28, 52,  0 },
    {     13,   13,    6, 28, 52,  0 },{     12,   12,    7, 28, 52,  0 },{     12,   12,    8, 28, 52,  0 },{     12,   11,    9, 28, 52,  0 },{     11,   11,   10, 28, 52,  0 },
    {     11,   10,   11, 28, 52,  0 },{     10,   10,   12, 28, 52,  0 },{     10,    9,   13, 28, 52,  0 },{      9,    9,   14, 28, 52,  0 },{      9,    8,   15, 28, 52,  0 },
    {      9,    8,   16, 28, 52,  0 },{      8,    7,   17, 28, 52,  0 },{      8,    7,   18, 28, 52,  0 },{      7,    6,   19, 28, 52,  0 },{      7,    6,   20, 28, 52,  0 },
    {      7,    5,   21, 28, 52,  0 },{      6,    5,   22, 28, 52,  0 },{      6,    4,   23, 28, 52,  0 },{      5,    4,   24, 28, 52,  0 },{      5,    3,   25, 28, 52,  0 },
    {      5,    3,   26, 28,  4,  1 },{      4,    2,   27, 28,  4,  1 },{      4,    2,   28, 28,  4,  1 },{      4,    1,   29, 28,  4,  1 },{      3,    1,   30, 28,  4,  1 },
    {      3,    0,   31, 28,  4,  1 },{      3,    0,   32, 28,  4,  1 },{      2,   -1,   33, 28,  4,  1 },{      2,   -1,   34, 28,  4,  1 },{      2,   -2,   35, 28,  4,  1 },
    {      1,   -2,   36, 28,  4,  1 },{      1,   -3,   37, 28,  4,  1 },{      1,   -3,   38, 28,  4,  1 },{      0,   -4,   39, 28,  4,  1 },{      0,   -4,   40, 28,  4,  1 },
    {      0,   -5,   41, 26, 52,  2 },{     -1,   -5,   42, 26, 52,  2 },{     -1,   -6,   43, 26, 52,  2 },{     -1,   -6,   44, 26, 52,  2 },{     -2,   -7,   45, 26, 52,  2 },
    {     -2,   -7,   46, 26, 52,  2 },{     -2,   -8,   47, 26, 52,  2 },{     -2,   -8,   48, 26, 52,  2 },{     -3,   -9,   49, 26, 52,  2 },{     -3,   -9,   50, 26, 52,  2 },
    {     -3,  -10,   51, 26, 52,  2 },{     -4,  -10,   52, 26, 52,  2 },{     -4,  -11,   53, 26, 52,  2 },{     -4,  -11,   54, 26, 52,  2 },{     -4,  -12,   55, 26, 52,  5 },
    {     -5,  -12,   56, 26, 52,  5 },{     -5,  -13,   57, 26, 52,  5 },{     -5,  -13,   58, 26, 52,  5 },{     -5,  -14,   59, 26, 52,  5 },{     -6,  -14,   60, 26, 52,  5 },
    {     -6,  -15,   61, 26, 52,  5 },{     -6,  -16,   62, 26, 52,  5 },{     -6,  -16,   63, 26, 52,  5 },{     -7,  -17,   64, 26, 52,  5 },{     -7,  -17,   65, 26, 52,  5 },
    {     -7,  -18,   66, 26, 52,  5 },{     -7,  -18,   67, 26, 52,  5 },{     -7,  -19,   68, 26, 52,  5 },{     -8,  -19,   69, 26, 52,  5 },{     -8,  -20,   70, 26, 52,  5 },
    {     -8,  -21,   71, 26, 52,  5 },{     -8,  -21,   72, 26, 52,  5 },{     -8,  -22,   73, 26, 52,  6 },{     -9,  -22,   74, 26, 52,  6 },{     -9,  -23,   75, 26, 52,  6 },
    {     -9,  -23,   76, 26, 52,  6 },{     -9,  -24,   77, 26, 52,  6 },{     -9,  -25,   78, 26, 52,  6 },{    -10,  -25,   79, 26, 52,  6 },{    -10,  -26,   80, 26, 52,  6 },
    {    -10,  -26,   81, 26, 52,  6 },{    -10,  -27,   82, 26, 52,  6 },{    -10,  -28,   83, 26, 52,  6 },{    -11,  -28,   84, 26, 52,  6 },{    -11,  -29,   85, 26, 52,  6 },
    {    -11,  -30,   86, 26, 52,  6 },{    -11,  -30,   87, 26, 52,  6 },{    -11,  -31,   88, 26, 52,  6 },{    -11,  -31,   89, 26, 52,  6 },{    -12,  -32,   90, 26, 52,  6 },
    {    -12,  -33,   91, 26, 52,  6 },{    -12,  -33,   92, 26, 52,  6 },{    -12,  -34,   93, 26, 52,  6 },{    -12,  -35,   94, 26, 52,  6 },{    -12,  -35,   95, 26, 52,  6 },
    {    -12,  -36,   96, 26, 52,  6 },{    -13,  -37,   97, 26, 52,  6 },{    -13,  -38,   98, 26, 52,  6 },{    -13,  -38,   99, 26,  3,  8 },{    -13,  -39,  100, 26,  3,  8 },
    {    -13,  -40,  101, 26,  3,  8 },{    -13,  -41,  102, 26,  3,  8 },{    -13,  -41,  103, 26,  3,  8 },{    -14,  -42,  104, 26,  3,  8 },{    -14,  -43,  105, 26,  3,  8 },
    {    -14,  -44,  106, 26,  3,  8 },{    -14,  -44,  107, 26,  3,  8 },{    -14,  -45,  108, 26,  3,  8 },{    -14,  -46,  109, 26,  3,  8 },{    -14,  -47,  110, 26,  3,  8 },
    {    -14,  -48,  111, 26,  3,  8 },{    -14,  -49,  112, 26,  3,  8 },{    -14,  -49,  113, 26,  3,  8 },{    -15,  -50,  114, 26,  3,  8 },{    -15,  -51,  115, 26,  3,  8 },
    {    -15,  -52,  116, 26,  3,  8 },{    -15,  -53,  117, 26,  3,  8 },{    -15,  -54,  118, 26,  3,  8 },{    -15,  -55,  119, 26,  3,  8 },{    -15,  -56,  120, 24,  2,  9 },
    {    -15,  -57,  121, 24,  2,  9 },{    -15,  -58,  122, 24,  2,  9 },{    -15,  -59,  123, 24,  2,  9 },{    -15,  -60,  124, 24,  2,  9 },{    -15,  -61,  125, 24,  2,  9 },
    {    -15,  -62,  126, 24,  2,  9 },{    -16,  -63,  127, 24,  2,  9 },{    -16,  -64,  127, 24,  2,  9 },{    -16,  -65,  128, 24,  2,  9 },{    -16,  -66,  129, 24,  2,  9 },
    {    -16,  -67,  129, 24,  2,  9 },{    -16,  -68,  130, 24,  2,  9 },{    -16,  -69,  131, 24,  2,  9 },{    -16,  -70,  131, 24,  2,  9 },{    -16,  -71,  132,  8, 14,  0 },
    {    -16,  -72,  132,  8, 14,  0 },{    -16,  -73,  133,  8, 14,  0 },{    -16,  -74,  133,  8, 15,  0 },{    -16,  -75,  134,  8, 15,  0 },{    -16,  -76,  134,  8, 15,  0 },
    {    -16,  -77,  135,  8, 15,  0 },{    -16,  -78,  135,  8, 15,  0 },{    -16,  -79,  136,  8, 15,  0 },{    -16,  -80,  136,  8, 15,  0 },{    -16,  -81,  136,  8, 15,  0 },
    {    -16,  -82,  137,  8, 15,  0 },{    -16,  -83,  137,  8, 15,  0 },{    -16,  -84,  137,  8, 15,  0 },{    -16,  -85,  137,  8, 15,  0 },{    -16,  -86,  138,  8, 15,  0 },
    {    -16,  -87,  138,  8, 15,  0 },{    -16,  -88,  138,  8, 15,  0 },{    -16,  -89,  138,  8, 16,  0 },{    -16,  -90,  138,  8, 16,  0 },{    -16,  -91,  138,  8, 16,  0 },
    {    -16,  -92,  139,  8, 16,  0 },{    -16,  -93,  139,  8, 16,  0 },{    -16,  -94,  139,  8, 16,  0 },{    -16,  -95,  139,  8, 16,  0 },{    -16,  -96,  139,  8, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthDiveLoopUpToOrthogonal0,{
    {     15,   16,    1,  4, 52,  0 },{     15,   16,    2,  4, 52,  0 },{     14,   17,    3,  4, 52,  0 },{     14,   17,    4,  4, 52,  0 },{     13,   18,    5,  4, 52,  0 },
    {     13,   18,    6,  4, 52,  0 },{     12,   19,    7,  4, 52,  0 },{     12,   19,    8,  4, 52,  0 },{     12,   20,    9,  4, 52,  0 },{     11,   20,   10,  4, 52,  0 },
    {     11,   21,   11,  4, 52,  0 },{     10,   21,   12,  4, 52,  0 },{     10,   22,   13,  4, 52,  0 },{      9,   22,   14,  4, 52,  0 },{      9,   23,   15,  4, 52,  0 },
    {      9,   23,   16,  4, 52,  0 },{      8,   24,   17,  4, 52,  0 },{      8,   24,   18,  4, 52,  0 },{      7,   25,   19,  4, 52,  0 },{      7,   25,   20,  4, 52,  0 },
    {      7,   26,   21,  4, 52,  0 },{      6,   26,   22,  4, 52,  0 },{      6,   27,   23,  4, 52,  0 },{      5,   27,   24,  4, 52,  0 },{      5,   28,   25,  4, 52,  0 },
    {      5,   28,   26,  4,  4,  3 },{      4,   29,   27,  4,  4,  3 },{      4,   29,   28,  4,  4,  3 },{      4,   30,   29,  4,  4,  3 },{      3,   30,   30,  4,  4,  3 },
    {      3,   31,   31,  4,  4,  3 },{      3,   31,   32,  4,  4,  3 },{      2,   32,   33,  4,  4,  3 },{      2,   32,   34,  4,  4,  3 },{      2,   33,   35,  4,  4,  3 },
    {      1,   33,   36,  4,  4,  3 },{      1,   34,   37,  4,  4,  3 },{      1,   34,   38,  4,  4,  3 },{      0,   35,   39,  4,  4,  3 },{      0,   35,   40,  4,  4,  3 },
    {      0,   36,   41,  6, 52,  4 },{     -1,   36,   42,  6, 52,  4 },{     -1,   37,   43,  6, 52,  4 },{     -1,   37,   44,  6, 52,  4 },{     -2,   38,   45,  6, 52,  4 },
    {     -2,   38,   46,  6, 52,  4 },{     -2,   39,   47,  6, 52,  4 },{     -2,   39,   48,  6, 52,  4 },{     -3,   40,   49,  6, 52,  4 },{     -3,   40,   50,  6, 52,  4 },
    {     -3,   41,   51,  6, 52,  4 },{     -4,   41,   52,  6, 52,  4 },{     -4,   42,   53,  6, 52,  4 },{     -4,   42,   54,  6, 52,  4 },{     -4,   43,   55,  6, 52, 10 },
    {     -5,   43,   56,  6, 52, 10 },{     -5,   44,   57,  6, 52, 10 },{     -5,   44,   58,  6, 52, 10 },{     -5,   45,   59,  6, 52, 10 },{     -6,   45,   60,  6, 52, 10 },
    {     -6,   46,   61,  6, 52, 10 },{     -6,   47,   62,  6, 52, 10 },{     -6,   47,   63,  6, 52, 10 },{     -7,   48,   64,  6, 52, 10 },{     -7,   48,   65,  6, 52, 10 },
    {     -7,   49,   66,  6, 52, 10 },{     -7,   49,   67,  6, 52, 10 },{     -7,   50,   68,  6, 52, 10 },{     -8,   50,   69,  6, 52, 10 },{     -8,   51,   70,  6, 52, 10 },
    {     -8,   52,   71,  6, 52, 10 },{     -8,   52,   72,  6, 52, 10 },{     -8,   53,   73,  6, 52, 11 },{     -9,   53,   74,  6, 52, 11 },{     -9,   54,   75,  6, 52, 11 },
    {     -9,   54,   76,  6, 52, 11 },{     -9,   55,   77,  6, 52, 11 },{     -9,   56,   78,  6, 52, 11 },{    -10,   56,   79,  6, 52, 11 },{    -10,   57,   80,  6, 52, 11 },
    {    -10,   57,   81,  6, 52, 11 },{    -10,   58,   82,  6, 52, 11 },{    -10,   59,   83,  6, 52, 11 },{    -11,   59,   84,  6, 52, 11 },{    -11,   60,   85,  6, 52, 11 },
    {    -11,   61,   86,  6, 52, 11 },{    -11,   61,   87,  6, 52, 11 },{    -11,   62,   88,  6, 52, 11 },{    -11,   62,   89,  6, 52, 11 },{    -12,   63,   90,  6, 52, 11 },
    {    -12,   64,   91,  6, 52, 11 },{    -12,   64,   92,  6, 52, 11 },{    -12,   65,   93,  6, 52, 11 },{    -12,   66,   94,  6, 52, 11 },{    -12,   66,   95,  6, 52, 11 },
    {    -12,   67,   96,  6, 52, 11 },{    -13,   68,   97,  6, 52, 11 },{    -13,   69,   98,  6, 52, 11 },{    -13,   69,   99,  6,  3, 13 },{    -13,   70,  100,  6,  3, 13 },
    {    -13,   71,  101,  6,  3, 13 },{    -13,   72,  102,  6,  3, 13 },{    -13,   72,  103,  6,  3, 13 },{    -14,   73,  104,  6,  3, 13 },{    -14,   74,  105,  6,  3, 13 },
    {    -14,   75,  106,  6,  3, 13 },{    -14,   75,  107,  6,  3, 13 },{    -14,   76,  108,  6,  3, 13 },{    -14,   77,  109,  6,  3, 13 },{    -14,   78,  110,  6,  3, 13 },
    {    -14,   79,  111,  6,  3, 13 },{    -14,   80,  112,  6,  3, 13 },{    -14,   80,  113,  6,  3, 13 },{    -15,   81,  114,  6,  3, 13 },{    -15,   82,  115,  6,  3, 13 },
    {    -15,   83,  116,  6,  3, 13 },{    -15,   84,  117,  6,  3, 13 },{    -15,   85,  118,  6,  3, 13 },{    -15,   86,  119,  6,  3, 13 },{    -15,   87,  120,  8,  2, 14 },
    {    -15,   88,  121,  8,  2, 14 },{    -15,   89,  122,  8,  2, 14 },{    -15,   90,  123,  8,  2, 14 },{    -15,   91,  124,  8,  2, 14 },{    -15,   92,  125,  8,  2, 14 },
    {    -15,   93,  126,  8,  2, 14 },{    -16,   94,  127,  8,  2, 14 },{    -16,   95,  127,  8,  2, 14 },{    -16,   96,  128,  8,  2, 14 },{    -16,   97,  129,  8,  2, 14 },
    {    -16,   98,  129,  8,  2, 14 },{    -16,   99,  130,  8,  2, 14 },{    -16,  100,  131,  8,  2, 14 },{    -16,  101,  131,  8,  2, 14 },{    -16,  102,  132, 24, 14,  0 },
    {    -16,  103,  132, 24, 14,  0 },{    -16,  104,  133, 24, 14,  0 },{    -16,  105,  133, 24, 15,  0 },{    -16,  106,  134, 24, 15,  0 },{    -16,  107,  134, 24, 15,  0 },
    {    -16,  108,  135, 24, 15,  0 },{    -16,  109,  135, 24, 15,  0 },{    -16,  110,  136, 24, 15,  0 },{    -16,  111,  136, 24, 15,  0 },{    -16,  112,  136, 24, 15,  0 },
    {    -16,  113,  137, 24, 15,  0 },{    -16,  114,  137, 24, 15,  0 },{    -16,  115,  137, 24, 15,  0 },{    -16,  116,  137, 24, 15,  0 },{    -16,  117,  138, 24, 15,  0 },
    {    -16,  118,  138, 24, 15,  0 },{    -16,  119,  138, 24, 15,  0 },{    -16,  120,  138, 24, 16,  0 },{    -16,  121,  138, 24, 16,  0 },{    -16,  122,  138, 24, 16,  0 },
    {    -16,  123,  139, 24, 16,  0 },{    -16,  124,  139, 24, 16,  0 },{    -16,  125,  139, 24, 16,  0 },{    -16,  126,  139, 24, 16,  0 },{    -16,  127,  139, 24, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthDiveLoopUpToOrthogonal1,{
    {     16,   16,    0, 12, 52,  0 },{     17,   17,    1, 12, 52,  0 },{     17,   17,    2, 12, 52,  0 },{     18,   18,    3, 12, 52,  0 },{     18,   18,    4, 12, 52,  0 },
    {     19,   19,    5, 12, 52,  0 },{     19,   19,    6, 12, 52,  0 },{     20,   20,    7, 12, 52,  0 },{     20,   20,    8, 12, 52,  0 },{     21,   20,    9, 12, 52,  0 },
    {     21,   21,   10, 12, 52,  0 },{     22,   21,   11, 12, 52,  0 },{     22,   22,   12, 12, 52,  0 },{     23,   22,   13, 12, 52,  0 },{     23,   23,   14, 12, 52,  0 },
    {     24,   23,   15, 12, 52,  0 },{     24,   23,   16, 12, 52,  0 },{     25,   24,   17, 12, 52,  0 },{     25,   24,   18, 12, 52,  0 },{     26,   25,   19, 12, 52,  0 },
    {     26,   25,   20, 12, 52,  0 },{     27,   25,   21, 12, 52,  0 },{     27,   26,   22, 12, 52,  0 },{     28,   26,   23, 12, 52,  0 },{     28,   27,   24, 12, 52,  0 },
    {     29,   27,   25, 12, 52,  0 },{     29,   27,   26, 12,  4,  3 },{     30,   28,   27, 12,  4,  3 },{     30,   28,   28, 12,  4,  3 },{     31,   28,   29, 12,  4,  3 },
    {     31,   29,   30, 12,  4,  3 },{     32,   29,   31, 12,  4,  3 },{     32,   29,   32, 12,  4,  3 },{     33,   30,   33, 12,  4,  3 },{     33,   30,   34, 12,  4,  3 },
    {     34,   30,   35, 12,  4,  3 },{     34,   31,   36, 12,  4,  3 },{     35,   31,   37, 12,  4,  3 },{     35,   31,   38, 12,  4,  3 },{     36,   32,   39, 12,  4,  3 },
    {     36,   32,   40, 12,  4,  3 },{     37,   32,   41, 14, 52,  4 },{     37,   33,   42, 14, 52,  4 },{     38,   33,   43, 14, 52,  4 },{     38,   33,   44, 14, 52,  4 },
    {     39,   34,   45, 14, 52,  4 },{     39,   34,   46, 14, 52,  4 },{     40,   34,   47, 14, 52,  4 },{     40,   34,   48, 14, 52,  4 },{     41,   35,   49, 14, 52,  4 },
    {     41,   35,   50, 14, 52,  4 },{     42,   35,   51, 14, 52,  4 },{     42,   36,   52, 14, 52,  4 },{     43,   36,   53, 14, 52,  4 },{     43,   36,   54, 14, 52,  4 },
    {     44,   36,   55, 14, 52, 10 },{     44,   37,   56, 14, 52, 10 },{     45,   37,   57, 14, 52, 10 },{     45,   37,   58, 14, 52, 10 },{     46,   37,   59, 14, 52, 10 },
    {     46,   38,   60, 14, 52, 10 },{     47,   38,   61, 14, 52, 10 },{     48,   38,   62, 14, 52, 10 },{     48,   38,   63, 14, 52, 10 },{     49,   39,   64, 14, 52, 10 },
    {     49,   39,   65, 14, 52, 10 },{     50,   39,   66, 14, 52, 10 },{     50,   39,   67, 14, 52, 10 },{     51,   39,   68, 14, 52, 10 },{     51,   40,   69, 14, 52, 10 },
    {     52,   40,   70, 14, 52, 10 },{     53,   40,   71, 14, 52, 10 },{     53,   40,   72, 14, 52, 10 },{     54,   40,   73, 14, 52, 11 },{     54,   41,   74, 14, 52, 11 },
    {     55,   41,   75, 14, 52, 11 },{     55,   41,   76, 14, 52, 11 },{     56,   41,   77, 14, 52, 11 },{     57,   41,   78, 14, 52, 11 },{     57,   42,   79, 14, 52, 11 },
    {     58,   42,   80, 14, 52, 11 },{     58,   42,   81, 14, 52, 11 },{     59,   42,   82, 14, 52, 11 },{     60,   42,   83, 14, 52, 11 },{     60,   43,   84, 14, 52, 11 },
    {     61,   43,   85, 14, 52, 11 },{     62,   43,   86, 14, 52, 11 },{     62,   43,   87, 14, 52, 11 },{     63,   43,   88, 14, 52, 11 },{     63,   43,   89, 14, 52, 11 },
    {     64,   44,   90, 14, 52, 11 },{     65,   44,   91, 14, 52, 11 },{     65,   44,   92, 14, 52, 11 },{     66,   44,   93, 14, 52, 11 },{     67,   44,   94, 14, 52, 11 },
    {     67,   44,   95, 14, 52, 11 },{     68,   44,   96, 14, 52, 11 },{     69,   45,   97, 14, 52, 11 },{     70,   45,   98, 14, 52, 11 },{     70,   45,   99, 14,  3, 13 },
    {     71,   45,  100, 14,  3, 13 },{     72,   45,  101, 14,  3, 13 },{     73,   45,  102, 14,  3, 13 },{     73,   45,  103, 14,  3, 13 },{     74,   46,  104, 14,  3, 13 },
    {     75,   46,  105, 14,  3, 13 },{     76,   46,  106, 14,  3, 13 },{     76,   46,  107, 14,  3, 13 },{     77,   46,  108, 14,  3, 13 },{     78,   46,  109, 14,  3, 13 },
    {     79,   46,  110, 14,  3, 13 },{     80,   46,  111, 14,  3, 13 },{     81,   46,  112, 14,  3, 13 },{     81,   46,  113, 14,  3, 13 },{     82,   47,  114, 14,  3, 13 },
    {     83,   47,  115, 14,  3, 13 },{     84,   47,  116, 14,  3, 13 },{     85,   47,  117, 14,  3, 13 },{     86,   47,  118, 14,  3, 13 },{     87,   47,  119, 14,  3, 13 },
    {     88,   47,  120, 16,  2, 14 },{     89,   47,  121, 16,  2, 14 },{     90,   47,  122, 16,  2, 14 },{     91,   47,  123, 16,  2, 14 },{     92,   47,  124, 16,  2, 14 },
    {     93,   47,  125, 16,  2, 14 },{     94,   47,  126, 16,  2, 14 },{     95,   48,  127, 16,  2, 14 },{     96,   48,  127, 16,  2, 14 },{     97,   48,  128, 16,  2, 14 },
    {     98,   48,  129, 16,  2, 14 },{     99,   48,  129, 16,  2, 14 },{    100,   48,  130, 16,  2, 14 },{    101,   48,  131, 16,  2, 14 },{    102,   48,  131, 16,  2, 14 },
    {    103,   48,  132,  0, 14,  0 },{    104,   48,  132,  0, 14,  0 },{    105,   48,  133,  0, 14,  0 },{    106,   48,  133,  0, 15,  0 },{    107,   48,  134,  0, 15,  0 },
    {    108,   48,  134,  0, 15,  0 },{    109,   48,  135,  0, 15,  0 },{    110,   48,  135,  0, 15,  0 },{    111,   48,  136,  0, 15,  0 },{    112,   48,  136,  0, 15,  0 },
    {    113,   48,  136,  0, 15,  0 },{    114,   48,  137,  0, 15,  0 },{    115,   48,  137,  0, 15,  0 },{    116,   48,  137,  0, 15,  0 },{    117,   48,  137,  0, 15,  0 },
    {    118,   48,  138,  0, 15,  0 },{    119,   48,  138,  0, 15,  0 },{    120,   48,  138,  0, 15,  0 },{    121,   48,  138,  0, 16,  0 },{    122,   48,  138,  0, 16,  0 },
    {    123,   48,  138,  0, 16,  0 },{    124,   48,  139,  0, 16,  0 },{    125,   48,  139,  0, 16,  0 },{    126,   48,  139,  0, 16,  0 },{    127,   48,  139,  0, 16,  0 },
    {    128,   48,  139,  0, 16,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthDiveLoopUpToOrthogonal2,{
    {     16,   15,    0, 20, 52,  0 },{     17,   14,    1, 20, 52,  0 },{     17,   14,    2, 20, 52,  0 },{     18,   13,    3, 20, 52,  0 },{     18,   13,    4, 20, 52,  0 },
    {     19,   12,    5, 20, 52,  0 },{     19,   12,    6, 20, 52,  0 },{     20,   11,    7, 20, 52,  0 },{     20,   11,    8, 20, 52,  0 },{     20,   10,    9, 20, 52,  0 },
    {     21,   10,   10, 20, 52,  0 },{     21,    9,   11, 20, 52,  0 },{     22,    9,   12, 20, 52,  0 },{     22,    8,   13, 20, 52,  0 },{     23,    8,   14, 20, 52,  0 },
    {     23,    7,   15, 20, 52,  0 },{     23,    7,   16, 20, 52,  0 },{     24,    6,   17, 20, 52,  0 },{     24,    6,   18, 20, 52,  0 },{     25,    5,   19, 20, 52,  0 },
    {     25,    5,   20, 20, 52,  0 },{     25,    4,   21, 20, 52,  0 },{     26,    4,   22, 20, 52,  0 },{     26,    3,   23, 20, 52,  0 },{     27,    3,   24, 20, 52,  0 },
    {     27,    2,   25, 20, 52,  0 },{     27,    2,   26, 20,  4,  3 },{     28,    1,   27, 20,  4,  3 },{     28,    1,   28, 20,  4,  3 },{     28,    0,   29, 20,  4,  3 },
    {     29,    0,   30, 20,  4,  3 },{     29,   -1,   31, 20,  4,  3 },{     29,   -1,   32, 20,  4,  3 },{     30,   -2,   33, 20,  4,  3 },{     30,   -2,   34, 20,  4,  3 },
    {     30,   -3,   35, 20,  4,  3 },{     31,   -3,   36, 20,  4,  3 },{     31,   -4,   37, 20,  4,  3 },{     31,   -4,   38, 20,  4,  3 },{     32,   -5,   39, 20,  4,  3 },
    {     32,   -5,   40, 20,  4,  3 },{     32,   -6,   41, 22, 52,  4 },{     33,   -6,   42, 22, 52,  4 },{     33,   -7,   43, 22, 52,  4 },{     33,   -7,   44, 22, 52,  4 },
    {     34,   -8,   45, 22, 52,  4 },{     34,   -8,   46, 22, 52,  4 },{     34,   -9,   47, 22, 52,  4 },{     34,   -9,   48, 22, 52,  4 },{     35,  -10,   49, 22, 52,  4 },
    {     35,  -10,   50, 22, 52,  4 },{     35,  -11,   51, 22, 52,  4 },{     36,  -11,   52, 22, 52,  4 },{     36,  -12,   53, 22, 52,  4 },{     36,  -12,   54, 22, 52,  4 },
    {     36,  -13,   55, 22, 52, 10 },{     37,  -13,   56, 22, 52, 10 },{     37,  -14,   57, 22, 52, 10 },{     37,  -14,   58, 22, 52, 10 },{     37,  -15,   59, 22, 52, 10 },
    {     38,  -15,   60, 22, 52, 10 },{     38,  -16,   61, 22, 52, 10 },{     38,  -17,   62, 22, 52, 10 },{     38,  -17,   63, 22, 52, 10 },{     39,  -18,   64, 22, 52, 10 },
    {     39,  -18,   65, 22, 52, 10 },{     39,  -19,   66, 22, 52, 10 },{     39,  -19,   67, 22, 52, 10 },{     39,  -20,   68, 22, 52, 10 },{     40,  -20,   69, 22, 52, 10 },
    {     40,  -21,   70, 22, 52, 10 },{     40,  -22,   71, 22, 52, 10 },{     40,  -22,   72, 22, 52, 10 },{     40,  -23,   73, 22, 52, 11 },{     41,  -23,   74, 22, 52, 11 },
    {     41,  -24,   75, 22, 52, 11 },{     41,  -24,   76, 22, 52, 11 },{     41,  -25,   77, 22, 52, 11 },{     41,  -26,   78, 22, 52, 11 },{     42,  -26,   79, 22, 52, 11 },
    {     42,  -27,   80, 22, 52, 11 },{     42,  -27,   81, 22, 52, 11 },{     42,  -28,   82, 22, 52, 11 },{     42,  -29,   83, 22, 52, 11 },{     43,  -29,   84, 22, 52, 11 },
    {     43,  -30,   85, 22, 52, 11 },{     43,  -31,   86, 22, 52, 11 },{     43,  -31,   87, 22, 52, 11 },{     43,  -32,   88, 22, 52, 11 },{     43,  -32,   89, 22, 52, 11 },
    {     44,  -33,   90, 22, 52, 11 },{     44,  -34,   91, 22, 52, 11 },{     44,  -34,   92, 22, 52, 11 },{     44,  -35,   93, 22, 52, 11 },{     44,  -36,   94, 22, 52, 11 },
    {     44,  -36,   95, 22, 52, 11 },{     44,  -37,   96, 22, 52, 11 },{     45,  -38,   97, 22, 52, 11 },{     45,  -39,   98, 22, 52, 11 },{     45,  -39,   99, 22,  3, 13 },
    {     45,  -40,  100, 22,  3, 13 },{     45,  -41,  101, 22,  3, 13 },{     45,  -42,  102, 22,  3, 13 },{     45,  -42,  103, 22,  3, 13 },{     46,  -43,  104, 22,  3, 13 },
    {     46,  -44,  105, 22,  3, 13 },{     46,  -45,  106, 22,  3, 13 },{     46,  -45,  107, 22,  3, 13 },{     46,  -46,  108, 22,  3, 13 },{     46,  -47,  109, 22,  3, 13 },
    {     46,  -48,  110, 22,  3, 13 },{     46,  -49,  111, 22,  3, 13 },{     46,  -50,  112, 22,  3, 13 },{     46,  -50,  113, 22,  3, 13 },{     47,  -51,  114, 22,  3, 13 },
    {     47,  -52,  115, 22,  3, 13 },{     47,  -53,  116, 22,  3, 13 },{     47,  -54,  117, 22,  3, 13 },{     47,  -55,  118, 22,  3, 13 },{     47,  -56,  119, 22,  3, 13 },
    {     47,  -57,  120, 24,  2, 14 },{     47,  -58,  121, 24,  2, 14 },{     47,  -59,  122, 24,  2, 14 },{     47,  -60,  123, 24,  2, 14 },{     47,  -61,  124, 24,  2, 14 },
    {     47,  -62,  125, 24,  2, 14 },{     47,  -63,  126, 24,  2, 14 },{     48,  -64,  127, 24,  2, 14 },{     48,  -65,  127, 24,  2, 14 },{     48,  -66,  128, 24,  2, 14 },
    {     48,  -67,  129, 24,  2, 14 },{     48,  -68,  129, 24,  2, 14 },{     48,  -69,  130, 24,  2, 14 },{     48,  -70,  131, 24,  2, 14 },{     48,  -71,  131, 24,  2, 14 },
    {     48,  -72,  132,  8, 14,  0 },{     48,  -73,  132,  8, 14,  0 },{     48,  -74,  133,  8, 14,  0 },{     48,  -75,  133,  8, 15,  0 },{     48,  -76,  134,  8, 15,  0 },
    {     48,  -77,  134,  8, 15,  0 },{     48,  -78,  135,  8, 15,  0 },{     48,  -79,  135,  8, 15,  0 },{     48,  -80,  136,  8, 15,  0 },{     48,  -81,  136,  8, 15,  0 },
    {     48,  -82,  136,  8, 15,  0 },{     48,  -83,  137,  8, 15,  0 },{     48,  -84,  137,  8, 15,  0 },{     48,  -85,  137,  8, 15,  0 },{     48,  -86,  137,  8, 15,  0 },
    {     48,  -87,  138,  8, 15,  0 },{     48,  -88,  138,  8, 15,  0 },{     48,  -89,  138,  8, 15,  0 },{     48,  -90,  138,  8, 16,  0 },{     48,  -91,  138,  8, 16,  0 },
    {     48,  -92,  138,  8, 16,  0 },{     48,  -93,  139,  8, 16,  0 },{     48,  -94,  139,  8, 16,  0 },{     48,  -95,  139,  8, 16,  0 },{     48,  -96,  139,  8, 16,  0 },
    {     48,  -97,  139,  8, 16,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthDiveLoopUpToOrthogonal3,{
    {     15,   15,    1, 28, 52,  0 },{     15,   15,    2, 28, 52,  0 },{     14,   14,    3, 28, 52,  0 },{     14,   14,    4, 28, 52,  0 },{     13,   13,    5, 28, 52,  0 },
    {     13,   13,    6, 28, 52,  0 },{     12,   12,    7, 28, 52,  0 },{     12,   12,    8, 28, 52,  0 },{     11,   12,    9, 28, 52,  0 },{     11,   11,   10, 28, 52,  0 },
    {     10,   11,   11, 28, 52,  0 },{     10,   10,   12, 28, 52,  0 },{      9,   10,   13, 28, 52,  0 },{      9,    9,   14, 28, 52,  0 },{      8,    9,   15, 28, 52,  0 },
    {      8,    9,   16, 28, 52,  0 },{      7,    8,   17, 28, 52,  0 },{      7,    8,   18, 28, 52,  0 },{      6,    7,   19, 28, 52,  0 },{      6,    7,   20, 28, 52,  0 },
    {      5,    7,   21, 28, 52,  0 },{      5,    6,   22, 28, 52,  0 },{      4,    6,   23, 28, 52,  0 },{      4,    5,   24, 28, 52,  0 },{      3,    5,   25, 28, 52,  0 },
    {      3,    5,   26, 28,  4,  3 },{      2,    4,   27, 28,  4,  3 },{      2,    4,   28, 28,  4,  3 },{      1,    4,   29, 28,  4,  3 },{      1,    3,   30, 28,  4,  3 },
    {      0,    3,   31, 28,  4,  3 },{      0,    3,   32, 28,  4,  3 },{     -1,    2,   33, 28,  4,  3 },{     -1,    2,   34, 28,  4,  3 },{     -2,    2,   35, 28,  4,  3 },
    {     -2,    1,   36, 28,  4,  3 },{     -3,    1,   37, 28,  4,  3 },{     -3,    1,   38, 28,  4,  3 },{     -4,    0,   39, 28,  4,  3 },{     -4,    0,   40, 28,  4,  3 },
    {     -5,    0,   41, 30, 52,  4 },{     -5,   -1,   42, 30, 52,  4 },{     -6,   -1,   43, 30, 52,  4 },{     -6,   -1,   44, 30, 52,  4 },{     -7,   -2,   45, 30, 52,  4 },
    {     -7,   -2,   46, 30, 52,  4 },{     -8,   -2,   47, 30, 52,  4 },{     -8,   -2,   48, 30, 52,  4 },{     -9,   -3,   49, 30, 52,  4 },{     -9,   -3,   50, 30, 52,  4 },
    {    -10,   -3,   51, 30, 52,  4 },{    -10,   -4,   52, 30, 52,  4 },{    -11,   -4,   53, 30, 52,  4 },{    -11,   -4,   54, 30, 52,  4 },{    -12,   -4,   55, 30, 52, 10 },
    {    -12,   -5,   56, 30, 52, 10 },{    -13,   -5,   57, 30, 52, 10 },{    -13,   -5,   58, 30, 52, 10 },{    -14,   -5,   59, 30, 52, 10 },{    -14,   -6,   60, 30, 52, 10 },
    {    -15,   -6,   61, 30, 52, 10 },{    -16,   -6,   62, 30, 52, 10 },{    -16,   -6,   63, 30, 52, 10 },{    -17,   -7,   64, 30, 52, 10 },{    -17,   -7,   65, 30, 52, 10 },
    {    -18,   -7,   66, 30, 52, 10 },{    -18,   -7,   67, 30, 52, 10 },{    -19,   -7,   68, 30, 52, 10 },{    -19,   -8,   69, 30, 52, 10 },{    -20,   -8,   70, 30, 52, 10 },
    {    -21,   -8,   71, 30, 52, 10 },{    -21,   -8,   72, 30, 52, 10 },{    -22,   -8,   73, 30, 52, 11 },{    -22,   -9,   74, 30, 52, 11 },{    -23,   -9,   75, 30, 52, 11 },
    {    -23,   -9,   76, 30, 52, 11 },{    -24,   -9,   77, 30, 52, 11 },{    -25,   -9,   78, 30, 52, 11 },{    -25,  -10,   79, 30, 52, 11 },{    -26,  -10,   80, 30, 52, 11 },
    {    -26,  -10,   81, 30, 52, 11 },{    -27,  -10,   82, 30, 52, 11 },{    -28,  -10,   83, 30, 52, 11 },{    -28,  -11,   84, 30, 52, 11 },{    -29,  -11,   85, 30, 52, 11 },
    {    -30,  -11,   86, 30, 52, 11 },{    -30,  -11,   87, 30, 52, 11 },{    -31,  -11,   88, 30, 52, 11 },{    -31,  -11,   89, 30, 52, 11 },{    -32,  -12,   90, 30, 52, 11 },
    {    -33,  -12,   91, 30, 52, 11 },{    -33,  -12,   92, 30, 52, 11 },{    -34,  -12,   93, 30, 52, 11 },{    -35,  -12,   94, 30, 52, 11 },{    -35,  -12,   95, 30, 52, 11 },
    {    -36,  -12,   96, 30, 52, 11 },{    -37,  -13,   97, 30, 52, 11 },{    -38,  -13,   98, 30, 52, 11 },{    -38,  -13,   99, 30,  3, 13 },{    -39,  -13,  100, 30,  3, 13 },
    {    -40,  -13,  101, 30,  3, 13 },{    -41,  -13,  102, 30,  3, 13 },{    -41,  -13,  103, 30,  3, 13 },{    -42,  -14,  104, 30,  3, 13 },{    -43,  -14,  105, 30,  3, 13 },
    {    -44,  -14,  106, 30,  3, 13 },{    -44,  -14,  107, 30,  3, 13 },{    -45,  -14,  108, 30,  3, 13 },{    -46,  -14,  109, 30,  3, 13 },{    -47,  -14,  110, 30,  3, 13 },
    {    -48,  -14,  111, 30,  3, 13 },{    -49,  -14,  112, 30,  3, 13 },{    -49,  -14,  113, 30,  3, 13 },{    -50,  -15,  114, 30,  3, 13 },{    -51,  -15,  115, 30,  3, 13 },
    {    -52,  -15,  116, 30,  3, 13 },{    -53,  -15,  117, 30,  3, 13 },{    -54,  -15,  118, 30,  3, 13 },{    -55,  -15,  119, 30,  3, 13 },{    -56,  -15,  120,  0,  2, 14 },
    {    -57,  -15,  121,  0,  2, 14 },{    -58,  -15,  122,  0,  2, 14 },{    -59,  -15,  123,  0,  2, 14 },{    -60,  -15,  124,  0,  2, 14 },{    -61,  -15,  125,  0,  2, 14 },
    {    -62,  -15,  126,  0,  2, 14 },{    -63,  -16,  127,  0,  2, 14 },{    -64,  -16,  127,  0,  2, 14 },{    -65,  -16,  128,  0,  2, 14 },{    -66,  -16,  129,  0,  2, 14 },
    {    -67,  -16,  129,  0,  2, 14 },{    -68,  -16,  130,  0,  2, 14 },{    -69,  -16,  131,  0,  2, 14 },{    -70,  -16,  131,  0,  2, 14 },{    -71,  -16,  132, 16, 14,  0 },
    {    -72,  -16,  132, 16, 14,  0 },{    -73,  -16,  133, 16, 14,  0 },{    -74,  -16,  133, 16, 15,  0 },{    -75,  -16,  134, 16, 15,  0 },{    -76,  -16,  134, 16, 15,  0 },
    {    -77,  -16,  135, 16, 15,  0 },{    -78,  -16,  135, 16, 15,  0 },{    -79,  -16,  136, 16, 15,  0 },{    -80,  -16,  136, 16, 15,  0 },{    -81,  -16,  136, 16, 15,  0 },
    {    -82,  -16,  137, 16, 15,  0 },{    -83,  -16,  137, 16, 15,  0 },{    -84,  -16,  137, 16, 15,  0 },{    -85,  -16,  137, 16, 15,  0 },{    -86,  -16,  138, 16, 15,  0 },
    {    -87,  -16,  138, 16, 15,  0 },{    -88,  -16,  138, 16, 15,  0 },{    -89,  -16,  138, 16, 16,  0 },{    -90,  -16,  138, 16, 16,  0 },{    -91,  -16,  138, 16, 16,  0 },
    {    -92,  -16,  139, 16, 16,  0 },{    -93,  -16,  139, 16, 16,  0 },{    -94,  -16,  139, 16, 16,  0 },{    -95,  -16,  139, 16, 16,  0 },{    -96,  -16,  139, 16, 16,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthDiveLoopDownToOrthogonal0,{
    {     31,   16,   27, 16, 16,  0 },{     30,   16,   27, 16, 16,  0 },{     29,   16,   27, 16, 16,  0 },{     28,   16,   27, 16, 16,  0 },{     27,   16,   26, 16, 16,  0 },
    {     26,   16,   26, 16, 16,  0 },{     25,   16,   26, 16, 16,  0 },{     24,   16,   26, 16, 23,  0 },{     23,   16,   26, 16, 23,  0 },{     22,   16,   26, 16, 23,  0 },
    {     21,   16,   25, 16, 23,  0 },{     20,   16,   25, 16, 23,  0 },{     19,   16,   25, 16, 23,  0 },{     18,   16,   25, 16, 23,  0 },{     17,   16,   24, 16, 23,  0 },
    {     16,   16,   24, 16, 23,  0 },{     15,   16,   24, 16, 23,  0 },{     14,   16,   23, 16, 23,  0 },{     13,   16,   23, 16, 23,  0 },{     12,   16,   22, 16, 23,  0 },
    {     11,   16,   22, 16, 23,  0 },{     10,   16,   21, 16, 23,  0 },{      9,   16,   21, 16, 22,  0 },{      8,   16,   20, 16, 22,  0 },{      7,   16,   20, 16, 22,  0 },
    {      6,   16,   19,  0,  6,  9 },{      5,   16,   19,  0,  6,  9 },{      4,   16,   18,  0,  6,  9 },{      3,   16,   17,  0,  6,  9 },{      2,   16,   17,  0,  6,  9 },
    {      1,   16,   16,  0,  6,  9 },{      0,   16,   15,  0,  6,  9 },{     -1,   16,   15,  0,  6,  9 },{     -2,   15,   14,  0,  6,  9 },{     -3,   15,   13,  0,  6,  9 },
    {     -4,   15,   12,  0,  6,  9 },{     -5,   15,   11,  0,  6,  9 },{     -6,   15,   10,  0,  6,  9 },{     -7,   15,    9,  0,  6,  9 },{     -8,   15,    8,  0,  6,  9 },
    {     -9,   15,    7, 30,  7,  8 },{    -10,   15,    6, 30,  7,  8 },{    -11,   15,    5, 30,  7,  8 },{    -12,   15,    4, 30,  7,  8 },{    -13,   15,    3, 30,  7,  8 },
    {    -14,   15,    2, 30,  7,  8 },{    -15,   14,    1, 30,  7,  8 },{    -15,   14,    0, 30,  7,  8 },{    -16,   14,   -1, 30,  7,  8 },{    -17,   14,   -2, 30,  7,  8 },
    {    -18,   14,   -3, 30,  7,  8 },{    -19,   14,   -4, 30,  7,  8 },{    -20,   14,   -5, 30,  7,  8 },{    -20,   14,   -6, 30,  7,  8 },{    -21,   14,   -7, 30,  7,  8 },
    {    -22,   14,   -8, 30,  7,  8 },{    -23,   13,   -9, 30,  7,  8 },{    -23,   13,  -10, 30,  7,  8 },{    -24,   13,  -11, 30,  7,  8 },{    -25,   13,  -12, 30,  7,  8 },
    {    -26,   13,  -13, 30,  7,  8 },{    -26,   13,  -14, 30, 55,  6 },{    -27,   13,  -15, 30, 55,  6 },{    -28,   12,  -16, 30, 55,  6 },{    -29,   12,  -17, 30, 55,  6 },
    {    -29,   12,  -18, 30, 55,  6 },{    -30,   12,  -19, 30, 55,  6 },{    -31,   12,  -20, 30, 55,  6 },{    -31,   12,  -21, 30, 55,  6 },{    -32,   12,  -22, 30, 55,  6 },
    {    -33,   11,  -23, 30, 55,  6 },{    -33,   11,  -24, 30, 55,  6 },{    -34,   11,  -25, 30, 55,  6 },{    -34,   11,  -26, 30, 55,  6 },{    -35,   11,  -27, 30, 55,  6 },
    {    -36,   11,  -28, 30, 55,  6 },{    -36,   10,  -29, 30, 55,  6 },{    -37,   10,  -30, 30, 55,  6 },{    -38,   10,  -31, 30, 55,  6 },{    -38,   10,  -32, 30, 55,  6 },
    {    -39,   10,  -33, 30, 55,  6 },{    -39,    9,  -34, 30, 55,  6 },{    -40,    9,  -35, 30, 55,  6 },{    -41,    9,  -36, 30, 55,  6 },{    -41,    9,  -37, 30, 55,  6 },
    {    -42,    9,  -38, 30, 55,  6 },{    -42,    8,  -39, 30, 55,  6 },{    -43,    8,  -40, 30, 55,  5 },{    -43,    8,  -41, 30, 55,  5 },{    -44,    8,  -42, 30, 55,  5 },
    {    -45,    8,  -43, 30, 55,  5 },{    -45,    7,  -44, 30, 55,  5 },{    -46,    7,  -45, 30, 55,  5 },{    -46,    7,  -46, 30, 55,  5 },{    -47,    7,  -47, 30, 55,  5 },
    {    -47,    7,  -48, 30, 55,  5 },{    -48,    6,  -49, 30, 55,  5 },{    -48,    6,  -50, 30, 55,  5 },{    -49,    6,  -51, 30, 55,  5 },{    -50,    6,  -52, 30, 55,  5 },
    {    -50,    5,  -53, 30, 55,  5 },{    -51,    5,  -54, 30, 55,  5 },{    -51,    5,  -55, 30, 55,  5 },{    -52,    5,  -56, 30, 55,  5 },{    -52,    4,  -57, 30, 55,  5 },
    {    -53,    4,  -58, 30, 55,  2 },{    -53,    4,  -59, 30, 55,  2 },{    -54,    4,  -60, 30, 55,  2 },{    -54,    3,  -61, 30, 55,  2 },{    -55,    3,  -62, 30, 55,  2 },
    {    -55,    3,  -63, 30, 55,  2 },{    -56,    2,  -64, 30, 55,  2 },{    -56,    2,  -65, 30, 55,  2 },{    -57,    2,  -66, 30, 55,  2 },{    -57,    2,  -67, 30, 55,  2 },
    {    -58,    1,  -68, 30, 55,  2 },{    -58,    1,  -69, 30, 55,  2 },{    -59,    1,  -70, 30, 55,  2 },{    -59,    0,  -71, 30, 55,  2 },{    -60,    0,  -72, 28,  8,  1 },
    {    -60,    0,  -73, 28,  8,  1 },{    -61,   -1,  -74, 28,  8,  1 },{    -61,   -1,  -75, 28,  8,  1 },{    -62,   -1,  -76, 28,  8,  1 },{    -62,   -2,  -77, 28,  8,  1 },
    {    -63,   -2,  -78, 28,  8,  1 },{    -63,   -2,  -79, 28,  8,  1 },{    -64,   -3,  -80, 28,  8,  1 },{    -64,   -3,  -81, 28,  8,  1 },{    -65,   -3,  -82, 28,  8,  1 },
    {    -65,   -4,  -83, 28,  8,  1 },{    -66,   -4,  -84, 28,  8,  1 },{    -66,   -4,  -85, 28,  8,  1 },{    -67,   -5,  -86, 28,  8,  1 },{    -67,   -5,  -87, 28, 55,  0 },
    {    -68,   -5,  -88, 28, 55,  0 },{    -68,   -6,  -89, 28, 55,  0 },{    -69,   -6,  -90, 28, 55,  0 },{    -69,   -7,  -91, 28, 55,  0 },{    -70,   -7,  -92, 28, 55,  0 },
    {    -70,   -7,  -93, 28, 55,  0 },{    -71,   -8,  -94, 28, 55,  0 },{    -71,   -8,  -95, 28, 55,  0 },{    -72,   -9,  -96, 28, 55,  0 },{    -72,   -9,  -97, 28, 55,  0 },
    {    -73,   -9,  -98, 28, 55,  0 },{    -73,  -10,  -99, 28, 55,  0 },{    -74,  -10, -100, 28, 55,  0 },{    -74,  -11, -101, 28, 55,  0 },{    -75,  -11, -102, 28, 55,  0 },
    {    -75,  -12, -103, 28, 55,  0 },{    -76,  -12, -104, 28, 55,  0 },{    -76,  -12, -105, 28, 55,  0 },{    -77,  -13, -106, 28, 55,  0 },{    -77,  -13, -107, 28, 55,  0 },
    {    -78,  -14, -108, 28, 55,  0 },{    -78,  -14, -109, 28, 55,  0 },{    -79,  -15, -110, 28, 55,  0 },{    -79,  -15, -111, 28, 55,  0 },{    -80,  -16, -112, 28, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthDiveLoopDownToOrthogonal1,{
    {     16,    0,   27, 24, 16,  0 },{     16,    1,   27, 24, 16,  0 },{     16,    2,   27, 24, 16,  0 },{     16,    3,   27, 24, 16,  0 },{     16,    4,   27, 24, 16,  0 },
    {     16,    5,   26, 24, 16,  0 },{     16,    6,   26, 24, 16,  0 },{     16,    7,   26, 24, 16,  0 },{     16,    8,   26, 24, 23,  0 },{     16,    9,   26, 24, 23,  0 },
    {     16,   10,   26, 24, 23,  0 },{     16,   11,   25, 24, 23,  0 },{     16,   12,   25, 24, 23,  0 },{     16,   13,   25, 24, 23,  0 },{     16,   14,   25, 24, 23,  0 },
    {     16,   15,   24, 24, 23,  0 },{     16,   16,   24, 24, 23,  0 },{     16,   17,   24, 24, 23,  0 },{     16,   18,   23, 24, 23,  0 },{     16,   19,   23, 24, 23,  0 },
    {     16,   20,   22, 24, 23,  0 },{     16,   21,   22, 24, 23,  0 },{     16,   22,   21, 24, 23,  0 },{     16,   23,   21, 24, 22,  0 },{     16,   24,   20, 24, 22,  0 },
    {     16,   25,   20, 24, 22,  0 },{     16,   26,   19,  8,  6,  9 },{     16,   27,   19,  8,  6,  9 },{     16,   28,   18,  8,  6,  9 },{     16,   29,   17,  8,  6,  9 },
    {     16,   30,   17,  8,  6,  9 },{     16,   31,   16,  8,  6,  9 },{     16,   32,   15,  8,  6,  9 },{     16,   33,   15,  8,  6,  9 },{     15,   34,   14,  8,  6,  9 },
    {     15,   35,   13,  8,  6,  9 },{     15,   36,   12,  8,  6,  9 },{     15,   37,   11,  8,  6,  9 },{     15,   38,   10,  8,  6,  9 },{     15,   39,    9,  8,  6,  9 },
    {     15,   40,    8,  8,  6,  9 },{     15,   41,    7,  6,  7,  8 },{     15,   42,    6,  6,  7,  8 },{     15,   43,    5,  6,  7,  8 },{     15,   44,    4,  6,  7,  8 },
    {     15,   45,    3,  6,  7,  8 },{     15,   46,    2,  6,  7,  8 },{     14,   47,    1,  6,  7,  8 },{     14,   47,    0,  6,  7,  8 },{     14,   48,   -1,  6,  7,  8 },
    {     14,   49,   -2,  6,  7,  8 },{     14,   50,   -3,  6,  7,  8 },{     14,   51,   -4,  6,  7,  8 },{     14,   52,   -5,  6,  7,  8 },{     14,   52,   -6,  6,  7,  8 },
    {     14,   53,   -7,  6,  7,  8 },{     14,   54,   -8,  6,  7,  8 },{     13,   55,   -9,  6,  7,  8 },{     13,   55,  -10,  6,  7,  8 },{     13,   56,  -11,  6,  7,  8 },
    {     13,   57,  -12,  6,  7,  8 },{     13,   58,  -13,  6,  7,  8 },{     13,   58,  -14,  6, 55,  6 },{     13,   59,  -15,  6, 55,  6 },{     12,   60,  -16,  6, 55,  6 },
    {     12,   61,  -17,  6, 55,  6 },{     12,   61,  -18,  6, 55,  6 },{     12,   62,  -19,  6, 55,  6 },{     12,   63,  -20,  6, 55,  6 },{     12,   63,  -21,  6, 55,  6 },
    {     12,   64,  -22,  6, 55,  6 },{     11,   65,  -23,  6, 55,  6 },{     11,   65,  -24,  6, 55,  6 },{     11,   66,  -25,  6, 55,  6 },{     11,   66,  -26,  6, 55,  6 },
    {     11,   67,  -27,  6, 55,  6 },{     11,   68,  -28,  6, 55,  6 },{     10,   68,  -29,  6, 55,  6 },{     10,   69,  -30,  6, 55,  6 },{     10,   70,  -31,  6, 55,  6 },
    {     10,   70,  -32,  6, 55,  6 },{     10,   71,  -33,  6, 55,  6 },{      9,   71,  -34,  6, 55,  6 },{      9,   72,  -35,  6, 55,  6 },{      9,   73,  -36,  6, 55,  6 },
    {      9,   73,  -37,  6, 55,  6 },{      9,   74,  -38,  6, 55,  6 },{      8,   74,  -39,  6, 55,  6 },{      8,   75,  -40,  6, 55,  5 },{      8,   75,  -41,  6, 55,  5 },
    {      8,   76,  -42,  6, 55,  5 },{      8,   77,  -43,  6, 55,  5 },{      7,   77,  -44,  6, 55,  5 },{      7,   78,  -45,  6, 55,  5 },{      7,   78,  -46,  6, 55,  5 },
    {      7,   79,  -47,  6, 55,  5 },{      7,   79,  -48,  6, 55,  5 },{      6,   80,  -49,  6, 55,  5 },{      6,   80,  -50,  6, 55,  5 },{      6,   81,  -51,  6, 55,  5 },
    {      6,   82,  -52,  6, 55,  5 },{      5,   82,  -53,  6, 55,  5 },{      5,   83,  -54,  6, 55,  5 },{      5,   83,  -55,  6, 55,  5 },{      5,   84,  -56,  6, 55,  5 },
    {      4,   84,  -57,  6, 55,  5 },{      4,   85,  -58,  6, 55,  2 },{      4,   85,  -59,  6, 55,  2 },{      4,   86,  -60,  6, 55,  2 },{      3,   86,  -61,  6, 55,  2 },
    {      3,   87,  -62,  6, 55,  2 },{      3,   87,  -63,  6, 55,  2 },{      2,   88,  -64,  6, 55,  2 },{      2,   88,  -65,  6, 55,  2 },{      2,   89,  -66,  6, 55,  2 },
    {      2,   89,  -67,  6, 55,  2 },{      1,   90,  -68,  6, 55,  2 },{      1,   90,  -69,  6, 55,  2 },{      1,   91,  -70,  6, 55,  2 },{      0,   91,  -71,  6, 55,  2 },
    {      0,   92,  -72,  4,  8,  1 },{      0,   92,  -73,  4,  8,  1 },{     -1,   93,  -74,  4,  8,  1 },{     -1,   93,  -75,  4,  8,  1 },{     -1,   94,  -76,  4,  8,  1 },
    {     -2,   94,  -77,  4,  8,  1 },{     -2,   95,  -78,  4,  8,  1 },{     -2,   95,  -79,  4,  8,  1 },{     -3,   96,  -80,  4,  8,  1 },{     -3,   96,  -81,  4,  8,  1 },
    {     -3,   97,  -82,  4,  8,  1 },{     -4,   97,  -83,  4,  8,  1 },{     -4,   98,  -84,  4,  8,  1 },{     -4,   98,  -85,  4,  8,  1 },{     -5,   99,  -86,  4,  8,  1 },
    {     -5,   99,  -87,  4, 55,  0 },{     -5,  100,  -88,  4, 55,  0 },{     -6,  100,  -89,  4, 55,  0 },{     -6,  101,  -90,  4, 55,  0 },{     -7,  101,  -91,  4, 55,  0 },
    {     -7,  102,  -92,  4, 55,  0 },{     -7,  102,  -93,  4, 55,  0 },{     -8,  103,  -94,  4, 55,  0 },{     -8,  103,  -95,  4, 55,  0 },{     -9,  104,  -96,  4, 55,  0 },
    {     -9,  104,  -97,  4, 55,  0 },{     -9,  105,  -98,  4, 55,  0 },{    -10,  105,  -99,  4, 55,  0 },{    -10,  106, -100,  4, 55,  0 },{    -11,  106, -101,  4, 55,  0 },
    {    -11,  107, -102,  4, 55,  0 },{    -12,  107, -103,  4, 55,  0 },{    -12,  108, -104,  4, 55,  0 },{    -12,  108, -105,  4, 55,  0 },{    -13,  109, -106,  4, 55,  0 },
    {    -13,  109, -107,  4, 55,  0 },{    -14,  110, -108,  4, 55,  0 },{    -14,  110, -109,  4, 55,  0 },{    -15,  111, -110,  4, 55,  0 },{    -15,  111, -111,  4, 55,  0 },
    {    -16,  112, -112,  4, 55,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthDiveLoopDownToOrthogonal2,{
    {      0,   16,   27,  0, 16,  0 },{      1,   16,   27,  0, 16,  0 },{      2,   16,   27,  0, 16,  0 },{      3,   16,   27,  0, 16,  0 },{      4,   16,   27,  0, 16,  0 },
    {      5,   16,   26,  0, 16,  0 },{      6,   16,   26,  0, 16,  0 },{      7,   16,   26,  0, 16,  0 },{      8,   16,   26,  0, 23,  0 },{      9,   16,   26,  0, 23,  0 },
    {     10,   16,   26,  0, 23,  0 },{     11,   16,   25,  0, 23,  0 },{     12,   16,   25,  0, 23,  0 },{     13,   16,   25,  0, 23,  0 },{     14,   16,   25,  0, 23,  0 },
    {     15,   16,   24,  0, 23,  0 },{     16,   16,   24,  0, 23,  0 },{     17,   16,   24,  0, 23,  0 },{     18,   16,   23,  0, 23,  0 },{     19,   16,   23,  0, 23,  0 },
    {     20,   16,   22,  0, 23,  0 },{     21,   16,   22,  0, 23,  0 },{     22,   16,   21,  0, 23,  0 },{     23,   16,   21,  0, 22,  0 },{     24,   16,   20,  0, 22,  0 },
    {     25,   16,   20,  0, 22,  0 },{     26,   16,   19, 16,  6,  9 },{     27,   16,   19, 16,  6,  9 },{     28,   16,   18, 16,  6,  9 },{     29,   16,   17, 16,  6,  9 },
    {     30,   16,   17, 16,  6,  9 },{     31,   16,   16, 16,  6,  9 },{     32,   16,   15, 16,  6,  9 },{     33,   16,   15, 16,  6,  9 },{     34,   17,   14, 16,  6,  9 },
    {     35,   17,   13, 16,  6,  9 },{     36,   17,   12, 16,  6,  9 },{     37,   17,   11, 16,  6,  9 },{     38,   17,   10, 16,  6,  9 },{     39,   17,    9, 16,  6,  9 },
    {     40,   17,    8, 16,  6,  9 },{     41,   17,    7, 14,  7,  8 },{     42,   17,    6, 14,  7,  8 },{     43,   17,    5, 14,  7,  8 },{     44,   17,    4, 14,  7,  8 },
    {     45,   17,    3, 14,  7,  8 },{     46,   17,    2, 14,  7,  8 },{     47,   18,    1, 14,  7,  8 },{     47,   18,    0, 14,  7,  8 },{     48,   18,   -1, 14,  7,  8 },
    {     49,   18,   -2, 14,  7,  8 },{     50,   18,   -3, 14,  7,  8 },{     51,   18,   -4, 14,  7,  8 },{     52,   18,   -5, 14,  7,  8 },{     52,   18,   -6, 14,  7,  8 },
    {     53,   18,   -7, 14,  7,  8 },{     54,   18,   -8, 14,  7,  8 },{     55,   19,   -9, 14,  7,  8 },{     55,   19,  -10, 14,  7,  8 },{     56,   19,  -11, 14,  7,  8 },
    {     57,   19,  -12, 14,  7,  8 },{     58,   19,  -13, 14,  7,  8 },{     58,   19,  -14, 14, 55,  6 },{     59,   19,  -15, 14, 55,  6 },{     60,   20,  -16, 14, 55,  6 },
    {     61,   20,  -17, 14, 55,  6 },{     61,   20,  -18, 14, 55,  6 },{     62,   20,  -19, 14, 55,  6 },{     63,   20,  -20, 14, 55,  6 },{     63,   20,  -21, 14, 55,  6 },
    {     64,   20,  -22, 14, 55,  6 },{     65,   21,  -23, 14, 55,  6 },{     65,   21,  -24, 14, 55,  6 },{     66,   21,  -25, 14, 55,  6 },{     66,   21,  -26, 14, 55,  6 },
    {     67,   21,  -27, 14, 55,  6 },{     68,   21,  -28, 14, 55,  6 },{     68,   22,  -29, 14, 55,  6 },{     69,   22,  -30, 14, 55,  6 },{     70,   22,  -31, 14, 55,  6 },
    {     70,   22,  -32, 14, 55,  6 },{     71,   22,  -33, 14, 55,  6 },{     71,   23,  -34, 14, 55,  6 },{     72,   23,  -35, 14, 55,  6 },{     73,   23,  -36, 14, 55,  6 },
    {     73,   23,  -37, 14, 55,  6 },{     74,   23,  -38, 14, 55,  6 },{     74,   24,  -39, 14, 55,  6 },{     75,   24,  -40, 14, 55,  5 },{     75,   24,  -41, 14, 55,  5 },
    {     76,   24,  -42, 14, 55,  5 },{     77,   24,  -43, 14, 55,  5 },{     77,   25,  -44, 14, 55,  5 },{     78,   25,  -45, 14, 55,  5 },{     78,   25,  -46, 14, 55,  5 },
    {     79,   25,  -47, 14, 55,  5 },{     79,   25,  -48, 14, 55,  5 },{     80,   26,  -49, 14, 55,  5 },{     80,   26,  -50, 14, 55,  5 },{     81,   26,  -51, 14, 55,  5 },
    {     82,   26,  -52, 14, 55,  5 },{     82,   27,  -53, 14, 55,  5 },{     83,   27,  -54, 14, 55,  5 },{     83,   27,  -55, 14, 55,  5 },{     84,   27,  -56, 14, 55,  5 },
    {     84,   28,  -57, 14, 55,  5 },{     85,   28,  -58, 14, 55,  2 },{     85,   28,  -59, 14, 55,  2 },{     86,   28,  -60, 14, 55,  2 },{     86,   29,  -61, 14, 55,  2 },
    {     87,   29,  -62, 14, 55,  2 },{     87,   29,  -63, 14, 55,  2 },{     88,   30,  -64, 14, 55,  2 },{     88,   30,  -65, 14, 55,  2 },{     89,   30,  -66, 14, 55,  2 },
    {     89,   30,  -67, 14, 55,  2 },{     90,   31,  -68, 14, 55,  2 },{     90,   31,  -69, 14, 55,  2 },{     91,   31,  -70, 14, 55,  2 },{     91,   32,  -71, 14, 55,  2 },
    {     92,   32,  -72, 12,  8,  1 },{     92,   32,  -73, 12,  8,  1 },{     93,   33,  -74, 12,  8,  1 },{     93,   33,  -75, 12,  8,  1 },{     94,   33,  -76, 12,  8,  1 },
    {     94,   34,  -77, 12,  8,  1 },{     95,   34,  -78, 12,  8,  1 },{     95,   34,  -79, 12,  8,  1 },{     96,   35,  -80, 12,  8,  1 },{     96,   35,  -81, 12,  8,  1 },
    {     97,   35,  -82, 12,  8,  1 },{     97,   36,  -83, 12,  8,  1 },{     98,   36,  -84, 12,  8,  1 },{     98,   36,  -85, 12,  8,  1 },{     99,   37,  -86, 12,  8,  1 },
    {     99,   37,  -87, 12, 55,  0 },{    100,   37,  -88, 12, 55,  0 },{    100,   38,  -89, 12, 55,  0 },{    101,   38,  -90, 12, 55,  0 },{    101,   39,  -91, 12, 55,  0 },
    {    102,   39,  -92, 12, 55,  0 },{    102,   39,  -93, 12, 55,  0 },{    103,   40,  -94, 12, 55,  0 },{    103,   40,  -95, 12, 55,  0 },{    104,   41,  -96, 12, 55,  0 },
    {    104,   41,  -97, 12, 55,  0 },{    105,   41,  -98, 12, 55,  0 },{    105,   42,  -99, 12, 55,  0 },{    106,   42, -100, 12, 55,  0 },{    106,   43, -101, 12, 55,  0 },
    {    107,   43, -102, 12, 55,  0 },{    107,   44, -103, 12, 55,  0 },{    108,   44, -104, 12, 55,  0 },{    108,   44, -105, 12, 55,  0 },{    109,   45, -106, 12, 55,  0 },
    {    109,   45, -107, 12, 55,  0 },{    110,   46, -108, 12, 55,  0 },{    110,   46, -109, 12, 55,  0 },{    111,   47, -110, 12, 55,  0 },{    111,   47, -111, 12, 55,  0 },
    {    112,   48, -112, 12, 55,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoLeftEighthDiveLoopDownToOrthogonal3,{
    {     16,   31,   27,  8, 16,  0 },{     16,   30,   27,  8, 16,  0 },{     16,   29,   27,  8, 16,  0 },{     16,   28,   27,  8, 16,  0 },{     16,   27,   26,  8, 16,  0 },
    {     16,   26,   26,  8, 16,  0 },{     16,   25,   26,  8, 16,  0 },{     16,   24,   26,  8, 23,  0 },{     16,   23,   26,  8, 23,  0 },{     16,   22,   26,  8, 23,  0 },
    {     16,   21,   25,  8, 23,  0 },{     16,   20,   25,  8, 23,  0 },{     16,   19,   25,  8, 23,  0 },{     16,   18,   25,  8, 23,  0 },{     16,   17,   24,  8, 23,  0 },
    {     16,   16,   24,  8, 23,  0 },{     16,   15,   24,  8, 23,  0 },{     16,   14,   23,  8, 23,  0 },{     16,   13,   23,  8, 23,  0 },{     16,   12,   22,  8, 23,  0 },
    {     16,   11,   22,  8, 23,  0 },{     16,   10,   21,  8, 23,  0 },{     16,    9,   21,  8, 22,  0 },{     16,    8,   20,  8, 22,  0 },{     16,    7,   20,  8, 22,  0 },
    {     16,    6,   19, 24,  6,  9 },{     16,    5,   19, 24,  6,  9 },{     16,    4,   18, 24,  6,  9 },{     16,    3,   17, 24,  6,  9 },{     16,    2,   17, 24,  6,  9 },
    {     16,    1,   16, 24,  6,  9 },{     16,    0,   15, 24,  6,  9 },{     16,   -1,   15, 24,  6,  9 },{     17,   -2,   14, 24,  6,  9 },{     17,   -3,   13, 24,  6,  9 },
    {     17,   -4,   12, 24,  6,  9 },{     17,   -5,   11, 24,  6,  9 },{     17,   -6,   10, 24,  6,  9 },{     17,   -7,    9, 24,  6,  9 },{     17,   -8,    8, 24,  6,  9 },
    {     17,   -9,    7, 22,  7,  8 },{     17,  -10,    6, 22,  7,  8 },{     17,  -11,    5, 22,  7,  8 },{     17,  -12,    4, 22,  7,  8 },{     17,  -13,    3, 22,  7,  8 },
    {     17,  -14,    2, 22,  7,  8 },{     18,  -15,    1, 22,  7,  8 },{     18,  -15,    0, 22,  7,  8 },{     18,  -16,   -1, 22,  7,  8 },{     18,  -17,   -2, 22,  7,  8 },
    {     18,  -18,   -3, 22,  7,  8 },{     18,  -19,   -4, 22,  7,  8 },{     18,  -20,   -5, 22,  7,  8 },{     18,  -20,   -6, 22,  7,  8 },{     18,  -21,   -7, 22,  7,  8 },
    {     18,  -22,   -8, 22,  7,  8 },{     19,  -23,   -9, 22,  7,  8 },{     19,  -23,  -10, 22,  7,  8 },{     19,  -24,  -11, 22,  7,  8 },{     19,  -25,  -12, 22,  7,  8 },
    {     19,  -26,  -13, 22,  7,  8 },{     19,  -26,  -14, 22, 55,  6 },{     19,  -27,  -15, 22, 55,  6 },{     20,  -28,  -16, 22, 55,  6 },{     20,  -29,  -17, 22, 55,  6 },
    {     20,  -29,  -18, 22, 55,  6 },{     20,  -30,  -19, 22, 55,  6 },{     20,  -31,  -20, 22, 55,  6 },{     20,  -31,  -21, 22, 55,  6 },{     20,  -32,  -22, 22, 55,  6 },
    {     21,  -33,  -23, 22, 55,  6 },{     21,  -33,  -24, 22, 55,  6 },{     21,  -34,  -25, 22, 55,  6 },{     21,  -34,  -26, 22, 55,  6 },{     21,  -35,  -27, 22, 55,  6 },
    {     21,  -36,  -28, 22, 55,  6 },{     22,  -36,  -29, 22, 55,  6 },{     22,  -37,  -30, 22, 55,  6 },{     22,  -38,  -31, 22, 55,  6 },{     22,  -38,  -32, 22, 55,  6 },
    {     22,  -39,  -33, 22, 55,  6 },{     23,  -39,  -34, 22, 55,  6 },{     23,  -40,  -35, 22, 55,  6 },{     23,  -41,  -36, 22, 55,  6 },{     23,  -41,  -37, 22, 55,  6 },
    {     23,  -42,  -38, 22, 55,  6 },{     24,  -42,  -39, 22, 55,  6 },{     24,  -43,  -40, 22, 55,  5 },{     24,  -43,  -41, 22, 55,  5 },{     24,  -44,  -42, 22, 55,  5 },
    {     24,  -45,  -43, 22, 55,  5 },{     25,  -45,  -44, 22, 55,  5 },{     25,  -46,  -45, 22, 55,  5 },{     25,  -46,  -46, 22, 55,  5 },{     25,  -47,  -47, 22, 55,  5 },
    {     25,  -47,  -48, 22, 55,  5 },{     26,  -48,  -49, 22, 55,  5 },{     26,  -48,  -50, 22, 55,  5 },{     26,  -49,  -51, 22, 55,  5 },{     26,  -50,  -52, 22, 55,  5 },
    {     27,  -50,  -53, 22, 55,  5 },{     27,  -51,  -54, 22, 55,  5 },{     27,  -51,  -55, 22, 55,  5 },{     27,  -52,  -56, 22, 55,  5 },{     28,  -52,  -57, 22, 55,  5 },
    {     28,  -53,  -58, 22, 55,  2 },{     28,  -53,  -59, 22, 55,  2 },{     28,  -54,  -60, 22, 55,  2 },{     29,  -54,  -61, 22, 55,  2 },{     29,  -55,  -62, 22, 55,  2 },
    {     29,  -55,  -63, 22, 55,  2 },{     30,  -56,  -64, 22, 55,  2 },{     30,  -56,  -65, 22, 55,  2 },{     30,  -57,  -66, 22, 55,  2 },{     30,  -57,  -67, 22, 55,  2 },
    {     31,  -58,  -68, 22, 55,  2 },{     31,  -58,  -69, 22, 55,  2 },{     31,  -59,  -70, 22, 55,  2 },{     32,  -59,  -71, 22, 55,  2 },{     32,  -60,  -72, 20,  8,  1 },
    {     32,  -60,  -73, 20,  8,  1 },{     33,  -61,  -74, 20,  8,  1 },{     33,  -61,  -75, 20,  8,  1 },{     33,  -62,  -76, 20,  8,  1 },{     34,  -62,  -77, 20,  8,  1 },
    {     34,  -63,  -78, 20,  8,  1 },{     34,  -63,  -79, 20,  8,  1 },{     35,  -64,  -80, 20,  8,  1 },{     35,  -64,  -81, 20,  8,  1 },{     35,  -65,  -82, 20,  8,  1 },
    {     36,  -65,  -83, 20,  8,  1 },{     36,  -66,  -84, 20,  8,  1 },{     36,  -66,  -85, 20,  8,  1 },{     37,  -67,  -86, 20,  8,  1 },{     37,  -67,  -87, 20, 55,  0 },
    {     37,  -68,  -88, 20, 55,  0 },{     38,  -68,  -89, 20, 55,  0 },{     38,  -69,  -90, 20, 55,  0 },{     39,  -69,  -91, 20, 55,  0 },{     39,  -70,  -92, 20, 55,  0 },
    {     39,  -70,  -93, 20, 55,  0 },{     40,  -71,  -94, 20, 55,  0 },{     40,  -71,  -95, 20, 55,  0 },{     41,  -72,  -96, 20, 55,  0 },{     41,  -72,  -97, 20, 55,  0 },
    {     41,  -73,  -98, 20, 55,  0 },{     42,  -73,  -99, 20, 55,  0 },{     42,  -74, -100, 20, 55,  0 },{     43,  -74, -101, 20, 55,  0 },{     43,  -75, -102, 20, 55,  0 },
    {     44,  -75, -103, 20, 55,  0 },{     44,  -76, -104, 20, 55,  0 },{     44,  -76, -105, 20, 55,  0 },{     45,  -77, -106, 20, 55,  0 },{     45,  -77, -107, 20, 55,  0 },
    {     46,  -78, -108, 20, 55,  0 },{     46,  -78, -109, 20, 55,  0 },{     47,  -79, -110, 20, 55,  0 },{     47,  -79, -111, 20, 55,  0 },{     48,  -80, -112, 20, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthDiveLoopDownToOrthogonal0,{
    {     31,   16,   27, 16, 16,  0 },{     30,   16,   27, 16, 16,  0 },{     29,   16,   27, 16, 16,  0 },{     28,   16,   27, 16, 16,  0 },{     27,   16,   26, 16, 16,  0 },
    {     26,   16,   26, 16, 16,  0 },{     25,   16,   26, 16, 16,  0 },{     24,   16,   26, 16, 23,  0 },{     23,   16,   26, 16, 23,  0 },{     22,   16,   26, 16, 23,  0 },
    {     21,   16,   25, 16, 23,  0 },{     20,   16,   25, 16, 23,  0 },{     19,   16,   25, 16, 23,  0 },{     18,   16,   25, 16, 23,  0 },{     17,   16,   24, 16, 23,  0 },
    {     16,   16,   24, 16, 23,  0 },{     15,   16,   24, 16, 23,  0 },{     14,   16,   23, 16, 23,  0 },{     13,   16,   23, 16, 23,  0 },{     12,   16,   22, 16, 23,  0 },
    {     11,   16,   22, 16, 23,  0 },{     10,   16,   21, 16, 23,  0 },{      9,   16,   21, 16, 22,  0 },{      8,   16,   20, 16, 22,  0 },{      7,   16,   20, 16, 22,  0 },
    {      6,   16,   19,  0,  6, 14 },{      5,   16,   19,  0,  6, 14 },{      4,   16,   18,  0,  6, 14 },{      3,   16,   17,  0,  6, 14 },{      2,   16,   17,  0,  6, 14 },
    {      1,   16,   16,  0,  6, 14 },{      0,   16,   15,  0,  6, 14 },{     -1,   16,   15,  0,  6, 14 },{     -2,   17,   14,  0,  6, 14 },{     -3,   17,   13,  0,  6, 14 },
    {     -4,   17,   12,  0,  6, 14 },{     -5,   17,   11,  0,  6, 14 },{     -6,   17,   10,  0,  6, 14 },{     -7,   17,    9,  0,  6, 14 },{     -8,   17,    8,  0,  6, 14 },
    {     -9,   17,    7,  2,  7, 13 },{    -10,   17,    6,  2,  7, 13 },{    -11,   17,    5,  2,  7, 13 },{    -12,   17,    4,  2,  7, 13 },{    -13,   17,    3,  2,  7, 13 },
    {    -14,   17,    2,  2,  7, 13 },{    -15,   18,    1,  2,  7, 13 },{    -15,   18,    0,  2,  7, 13 },{    -16,   18,   -1,  2,  7, 13 },{    -17,   18,   -2,  2,  7, 13 },
    {    -18,   18,   -3,  2,  7, 13 },{    -19,   18,   -4,  2,  7, 13 },{    -20,   18,   -5,  2,  7, 13 },{    -20,   18,   -6,  2,  7, 13 },{    -21,   18,   -7,  2,  7, 13 },
    {    -22,   18,   -8,  2,  7, 13 },{    -23,   19,   -9,  2,  7, 13 },{    -23,   19,  -10,  2,  7, 13 },{    -24,   19,  -11,  2,  7, 13 },{    -25,   19,  -12,  2,  7, 13 },
    {    -26,   19,  -13,  2,  7, 13 },{    -26,   19,  -14,  2, 55, 11 },{    -27,   19,  -15,  2, 55, 11 },{    -28,   20,  -16,  2, 55, 11 },{    -29,   20,  -17,  2, 55, 11 },
    {    -29,   20,  -18,  2, 55, 11 },{    -30,   20,  -19,  2, 55, 11 },{    -31,   20,  -20,  2, 55, 11 },{    -31,   20,  -21,  2, 55, 11 },{    -32,   20,  -22,  2, 55, 11 },
    {    -33,   21,  -23,  2, 55, 11 },{    -33,   21,  -24,  2, 55, 11 },{    -34,   21,  -25,  2, 55, 11 },{    -34,   21,  -26,  2, 55, 11 },{    -35,   21,  -27,  2, 55, 11 },
    {    -36,   21,  -28,  2, 55, 11 },{    -36,   22,  -29,  2, 55, 11 },{    -37,   22,  -30,  2, 55, 11 },{    -38,   22,  -31,  2, 55, 11 },{    -38,   22,  -32,  2, 55, 11 },
    {    -39,   22,  -33,  2, 55, 11 },{    -39,   23,  -34,  2, 55, 11 },{    -40,   23,  -35,  2, 55, 11 },{    -41,   23,  -36,  2, 55, 11 },{    -41,   23,  -37,  2, 55, 11 },
    {    -42,   23,  -38,  2, 55, 11 },{    -42,   24,  -39,  2, 55, 11 },{    -43,   24,  -40,  2, 55, 10 },{    -43,   24,  -41,  2, 55, 10 },{    -44,   24,  -42,  2, 55, 10 },
    {    -45,   24,  -43,  2, 55, 10 },{    -45,   25,  -44,  2, 55, 10 },{    -46,   25,  -45,  2, 55, 10 },{    -46,   25,  -46,  2, 55, 10 },{    -47,   25,  -47,  2, 55, 10 },
    {    -47,   25,  -48,  2, 55, 10 },{    -48,   26,  -49,  2, 55, 10 },{    -48,   26,  -50,  2, 55, 10 },{    -49,   26,  -51,  2, 55, 10 },{    -50,   26,  -52,  2, 55, 10 },
    {    -50,   27,  -53,  2, 55, 10 },{    -51,   27,  -54,  2, 55, 10 },{    -51,   27,  -55,  2, 55, 10 },{    -52,   27,  -56,  2, 55, 10 },{    -52,   28,  -57,  2, 55, 10 },
    {    -53,   28,  -58,  2, 55,  4 },{    -53,   28,  -59,  2, 55,  4 },{    -54,   28,  -60,  2, 55,  4 },{    -54,   29,  -61,  2, 55,  4 },{    -55,   29,  -62,  2, 55,  4 },
    {    -55,   29,  -63,  2, 55,  4 },{    -56,   30,  -64,  2, 55,  4 },{    -56,   30,  -65,  2, 55,  4 },{    -57,   30,  -66,  2, 55,  4 },{    -57,   30,  -67,  2, 55,  4 },
    {    -58,   31,  -68,  2, 55,  4 },{    -58,   31,  -69,  2, 55,  4 },{    -59,   31,  -70,  2, 55,  4 },{    -59,   32,  -71,  2, 55,  4 },{    -60,   32,  -72,  4,  8,  3 },
    {    -60,   32,  -73,  4,  8,  3 },{    -61,   33,  -74,  4,  8,  3 },{    -61,   33,  -75,  4,  8,  3 },{    -62,   33,  -76,  4,  8,  3 },{    -62,   34,  -77,  4,  8,  3 },
    {    -63,   34,  -78,  4,  8,  3 },{    -63,   34,  -79,  4,  8,  3 },{    -64,   35,  -80,  4,  8,  3 },{    -64,   35,  -81,  4,  8,  3 },{    -65,   35,  -82,  4,  8,  3 },
    {    -65,   36,  -83,  4,  8,  3 },{    -66,   36,  -84,  4,  8,  3 },{    -66,   36,  -85,  4,  8,  3 },{    -67,   37,  -86,  4,  8,  3 },{    -67,   37,  -87,  4, 55,  0 },
    {    -68,   37,  -88,  4, 55,  0 },{    -68,   38,  -89,  4, 55,  0 },{    -69,   38,  -90,  4, 55,  0 },{    -69,   39,  -91,  4, 55,  0 },{    -70,   39,  -92,  4, 55,  0 },
    {    -70,   39,  -93,  4, 55,  0 },{    -71,   40,  -94,  4, 55,  0 },{    -71,   40,  -95,  4, 55,  0 },{    -72,   41,  -96,  4, 55,  0 },{    -72,   41,  -97,  4, 55,  0 },
    {    -73,   41,  -98,  4, 55,  0 },{    -73,   42,  -99,  4, 55,  0 },{    -74,   42, -100,  4, 55,  0 },{    -74,   43, -101,  4, 55,  0 },{    -75,   43, -102,  4, 55,  0 },
    {    -75,   44, -103,  4, 55,  0 },{    -76,   44, -104,  4, 55,  0 },{    -76,   44, -105,  4, 55,  0 },{    -77,   45, -106,  4, 55,  0 },{    -77,   45, -107,  4, 55,  0 },
    {    -78,   46, -108,  4, 55,  0 },{    -78,   46, -109,  4, 55,  0 },{    -79,   47, -110,  4, 55,  0 },{    -79,   47, -111,  4, 55,  0 },{    -80,   48, -112,  4, 55,  0 },
})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthDiveLoopDownToOrthogonal1,{
    {     16,    0,   27, 24, 16,  0 },{     16,    1,   27, 24, 16,  0 },{     16,    2,   27, 24, 16,  0 },{     16,    3,   27, 24, 16,  0 },{     16,    4,   27, 24, 16,  0 },
    {     16,    5,   26, 24, 16,  0 },{     16,    6,   26, 24, 16,  0 },{     16,    7,   26, 24, 16,  0 },{     16,    8,   26, 24, 23,  0 },{     16,    9,   26, 24, 23,  0 },
    {     16,   10,   26, 24, 23,  0 },{     16,   11,   25, 24, 23,  0 },{     16,   12,   25, 24, 23,  0 },{     16,   13,   25, 24, 23,  0 },{     16,   14,   25, 24, 23,  0 },
    {     16,   15,   24, 24, 23,  0 },{     16,   16,   24, 24, 23,  0 },{     16,   17,   24, 24, 23,  0 },{     16,   18,   23, 24, 23,  0 },{     16,   19,   23, 24, 23,  0 },
    {     16,   20,   22, 24, 23,  0 },{     16,   21,   22, 24, 23,  0 },{     16,   22,   21, 24, 23,  0 },{     16,   23,   21, 24, 22,  0 },{     16,   24,   20, 24, 22,  0 },
    {     16,   25,   20, 24, 22,  0 },{     16,   26,   19,  8,  6, 14 },{     16,   27,   19,  8,  6, 14 },{     16,   28,   18,  8,  6, 14 },{     16,   29,   17,  8,  6, 14 },
    {     16,   30,   17,  8,  6, 14 },{     16,   31,   16,  8,  6, 14 },{     16,   32,   15,  8,  6, 14 },{     16,   33,   15,  8,  6, 14 },{     17,   34,   14,  8,  6, 14 },
    {     17,   35,   13,  8,  6, 14 },{     17,   36,   12,  8,  6, 14 },{     17,   37,   11,  8,  6, 14 },{     17,   38,   10,  8,  6, 14 },{     17,   39,    9,  8,  6, 14 },
    {     17,   40,    8,  8,  6, 14 },{     17,   41,    7, 10,  7, 13 },{     17,   42,    6, 10,  7, 13 },{     17,   43,    5, 10,  7, 13 },{     17,   44,    4, 10,  7, 13 },
    {     17,   45,    3, 10,  7, 13 },{     17,   46,    2, 10,  7, 13 },{     18,   47,    1, 10,  7, 13 },{     18,   47,    0, 10,  7, 13 },{     18,   48,   -1, 10,  7, 13 },
    {     18,   49,   -2, 10,  7, 13 },{     18,   50,   -3, 10,  7, 13 },{     18,   51,   -4, 10,  7, 13 },{     18,   52,   -5, 10,  7, 13 },{     18,   52,   -6, 10,  7, 13 },
    {     18,   53,   -7, 10,  7, 13 },{     18,   54,   -8, 10,  7, 13 },{     19,   55,   -9, 10,  7, 13 },{     19,   55,  -10, 10,  7, 13 },{     19,   56,  -11, 10,  7, 13 },
    {     19,   57,  -12, 10,  7, 13 },{     19,   58,  -13, 10,  7, 13 },{     19,   58,  -14, 10, 55, 11 },{     19,   59,  -15, 10, 55, 11 },{     20,   60,  -16, 10, 55, 11 },
    {     20,   61,  -17, 10, 55, 11 },{     20,   61,  -18, 10, 55, 11 },{     20,   62,  -19, 10, 55, 11 },{     20,   63,  -20, 10, 55, 11 },{     20,   63,  -21, 10, 55, 11 },
    {     20,   64,  -22, 10, 55, 11 },{     21,   65,  -23, 10, 55, 11 },{     21,   65,  -24, 10, 55, 11 },{     21,   66,  -25, 10, 55, 11 },{     21,   66,  -26, 10, 55, 11 },
    {     21,   67,  -27, 10, 55, 11 },{     21,   68,  -28, 10, 55, 11 },{     22,   68,  -29, 10, 55, 11 },{     22,   69,  -30, 10, 55, 11 },{     22,   70,  -31, 10, 55, 11 },
    {     22,   70,  -32, 10, 55, 11 },{     22,   71,  -33, 10, 55, 11 },{     23,   71,  -34, 10, 55, 11 },{     23,   72,  -35, 10, 55, 11 },{     23,   73,  -36, 10, 55, 11 },
    {     23,   73,  -37, 10, 55, 11 },{     23,   74,  -38, 10, 55, 11 },{     24,   74,  -39, 10, 55, 11 },{     24,   75,  -40, 10, 55, 10 },{     24,   75,  -41, 10, 55, 10 },
    {     24,   76,  -42, 10, 55, 10 },{     24,   77,  -43, 10, 55, 10 },{     25,   77,  -44, 10, 55, 10 },{     25,   78,  -45, 10, 55, 10 },{     25,   78,  -46, 10, 55, 10 },
    {     25,   79,  -47, 10, 55, 10 },{     25,   79,  -48, 10, 55, 10 },{     26,   80,  -49, 10, 55, 10 },{     26,   80,  -50, 10, 55, 10 },{     26,   81,  -51, 10, 55, 10 },
    {     26,   82,  -52, 10, 55, 10 },{     27,   82,  -53, 10, 55, 10 },{     27,   83,  -54, 10, 55, 10 },{     27,   83,  -55, 10, 55, 10 },{     27,   84,  -56, 10, 55, 10 },
    {     28,   84,  -57, 10, 55, 10 },{     28,   85,  -58, 10, 55,  4 },{     28,   85,  -59, 10, 55,  4 },{     28,   86,  -60, 10, 55,  4 },{     29,   86,  -61, 10, 55,  4 },
    {     29,   87,  -62, 10, 55,  4 },{     29,   87,  -63, 10, 55,  4 },{     30,   88,  -64, 10, 55,  4 },{     30,   88,  -65, 10, 55,  4 },{     30,   89,  -66, 10, 55,  4 },
    {     30,   89,  -67, 10, 55,  4 },{     31,   90,  -68, 10, 55,  4 },{     31,   90,  -69, 10, 55,  4 },{     31,   91,  -70, 10, 55,  4 },{     32,   91,  -71, 10, 55,  4 },
    {     32,   92,  -72, 12,  8,  3 },{     32,   92,  -73, 12,  8,  3 },{     33,   93,  -74, 12,  8,  3 },{     33,   93,  -75, 12,  8,  3 },{     33,   94,  -76, 12,  8,  3 },
    {     34,   94,  -77, 12,  8,  3 },{     34,   95,  -78, 12,  8,  3 },{     34,   95,  -79, 12,  8,  3 },{     35,   96,  -80, 12,  8,  3 },{     35,   96,  -81, 12,  8,  3 },
    {     35,   97,  -82, 12,  8,  3 },{     36,   97,  -83, 12,  8,  3 },{     36,   98,  -84, 12,  8,  3 },{     36,   98,  -85, 12,  8,  3 },{     37,   99,  -86, 12,  8,  3 },
    {     37,   99,  -87, 12, 55,  0 },{     37,  100,  -88, 12, 55,  0 },{     38,  100,  -89, 12, 55,  0 },{     38,  101,  -90, 12, 55,  0 },{     39,  101,  -91, 12, 55,  0 },
    {     39,  102,  -92, 12, 55,  0 },{     39,  102,  -93, 12, 55,  0 },{     40,  103,  -94, 12, 55,  0 },{     40,  103,  -95, 12, 55,  0 },{     41,  104,  -96, 12, 55,  0 },
    {     41,  104,  -97, 12, 55,  0 },{     41,  105,  -98, 12, 55,  0 },{     42,  105,  -99, 12, 55,  0 },{     42,  106, -100, 12, 55,  0 },{     43,  106, -101, 12, 55,  0 },
    {     43,  107, -102, 12, 55,  0 },{     44,  107, -103, 12, 55,  0 },{     44,  108, -104, 12, 55,  0 },{     44,  108, -105, 12, 55,  0 },{     45,  109, -106, 12, 55,  0 },
    {     45,  109, -107, 12, 55,  0 },{     46,  110, -108, 12, 55,  0 },{     46,  110, -109, 12, 55,  0 },{     47,  111, -110, 12, 55,  0 },{     47,  111, -111, 12, 55,  0 },
    {     48,  112, -112, 12, 55,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthDiveLoopDownToOrthogonal2,{
    {      0,   16,   27,  0, 16,  0 },{      1,   16,   27,  0, 16,  0 },{      2,   16,   27,  0, 16,  0 },{      3,   16,   27,  0, 16,  0 },{      4,   16,   27,  0, 16,  0 },
    {      5,   16,   26,  0, 16,  0 },{      6,   16,   26,  0, 16,  0 },{      7,   16,   26,  0, 16,  0 },{      8,   16,   26,  0, 23,  0 },{      9,   16,   26,  0, 23,  0 },
    {     10,   16,   26,  0, 23,  0 },{     11,   16,   25,  0, 23,  0 },{     12,   16,   25,  0, 23,  0 },{     13,   16,   25,  0, 23,  0 },{     14,   16,   25,  0, 23,  0 },
    {     15,   16,   24,  0, 23,  0 },{     16,   16,   24,  0, 23,  0 },{     17,   16,   24,  0, 23,  0 },{     18,   16,   23,  0, 23,  0 },{     19,   16,   23,  0, 23,  0 },
    {     20,   16,   22,  0, 23,  0 },{     21,   16,   22,  0, 23,  0 },{     22,   16,   21,  0, 23,  0 },{     23,   16,   21,  0, 22,  0 },{     24,   16,   20,  0, 22,  0 },
    {     25,   16,   20,  0, 22,  0 },{     26,   16,   19, 16,  6, 14 },{     27,   16,   19, 16,  6, 14 },{     28,   16,   18, 16,  6, 14 },{     29,   16,   17, 16,  6, 14 },
    {     30,   16,   17, 16,  6, 14 },{     31,   16,   16, 16,  6, 14 },{     32,   16,   15, 16,  6, 14 },{     33,   16,   15, 16,  6, 14 },{     34,   15,   14, 16,  6, 14 },
    {     35,   15,   13, 16,  6, 14 },{     36,   15,   12, 16,  6, 14 },{     37,   15,   11, 16,  6, 14 },{     38,   15,   10, 16,  6, 14 },{     39,   15,    9, 16,  6, 14 },
    {     40,   15,    8, 16,  6, 14 },{     41,   15,    7, 18,  7, 13 },{     42,   15,    6, 18,  7, 13 },{     43,   15,    5, 18,  7, 13 },{     44,   15,    4, 18,  7, 13 },
    {     45,   15,    3, 18,  7, 13 },{     46,   15,    2, 18,  7, 13 },{     47,   14,    1, 18,  7, 13 },{     47,   14,    0, 18,  7, 13 },{     48,   14,   -1, 18,  7, 13 },
    {     49,   14,   -2, 18,  7, 13 },{     50,   14,   -3, 18,  7, 13 },{     51,   14,   -4, 18,  7, 13 },{     52,   14,   -5, 18,  7, 13 },{     52,   14,   -6, 18,  7, 13 },
    {     53,   14,   -7, 18,  7, 13 },{     54,   14,   -8, 18,  7, 13 },{     55,   13,   -9, 18,  7, 13 },{     55,   13,  -10, 18,  7, 13 },{     56,   13,  -11, 18,  7, 13 },
    {     57,   13,  -12, 18,  7, 13 },{     58,   13,  -13, 18,  7, 13 },{     58,   13,  -14, 18, 55, 11 },{     59,   13,  -15, 18, 55, 11 },{     60,   12,  -16, 18, 55, 11 },
    {     61,   12,  -17, 18, 55, 11 },{     61,   12,  -18, 18, 55, 11 },{     62,   12,  -19, 18, 55, 11 },{     63,   12,  -20, 18, 55, 11 },{     63,   12,  -21, 18, 55, 11 },
    {     64,   12,  -22, 18, 55, 11 },{     65,   11,  -23, 18, 55, 11 },{     65,   11,  -24, 18, 55, 11 },{     66,   11,  -25, 18, 55, 11 },{     66,   11,  -26, 18, 55, 11 },
    {     67,   11,  -27, 18, 55, 11 },{     68,   11,  -28, 18, 55, 11 },{     68,   10,  -29, 18, 55, 11 },{     69,   10,  -30, 18, 55, 11 },{     70,   10,  -31, 18, 55, 11 },
    {     70,   10,  -32, 18, 55, 11 },{     71,   10,  -33, 18, 55, 11 },{     71,    9,  -34, 18, 55, 11 },{     72,    9,  -35, 18, 55, 11 },{     73,    9,  -36, 18, 55, 11 },
    {     73,    9,  -37, 18, 55, 11 },{     74,    9,  -38, 18, 55, 11 },{     74,    8,  -39, 18, 55, 11 },{     75,    8,  -40, 18, 55, 10 },{     75,    8,  -41, 18, 55, 10 },
    {     76,    8,  -42, 18, 55, 10 },{     77,    8,  -43, 18, 55, 10 },{     77,    7,  -44, 18, 55, 10 },{     78,    7,  -45, 18, 55, 10 },{     78,    7,  -46, 18, 55, 10 },
    {     79,    7,  -47, 18, 55, 10 },{     79,    7,  -48, 18, 55, 10 },{     80,    6,  -49, 18, 55, 10 },{     80,    6,  -50, 18, 55, 10 },{     81,    6,  -51, 18, 55, 10 },
    {     82,    6,  -52, 18, 55, 10 },{     82,    5,  -53, 18, 55, 10 },{     83,    5,  -54, 18, 55, 10 },{     83,    5,  -55, 18, 55, 10 },{     84,    5,  -56, 18, 55, 10 },
    {     84,    4,  -57, 18, 55, 10 },{     85,    4,  -58, 18, 55,  4 },{     85,    4,  -59, 18, 55,  4 },{     86,    4,  -60, 18, 55,  4 },{     86,    3,  -61, 18, 55,  4 },
    {     87,    3,  -62, 18, 55,  4 },{     87,    3,  -63, 18, 55,  4 },{     88,    2,  -64, 18, 55,  4 },{     88,    2,  -65, 18, 55,  4 },{     89,    2,  -66, 18, 55,  4 },
    {     89,    2,  -67, 18, 55,  4 },{     90,    1,  -68, 18, 55,  4 },{     90,    1,  -69, 18, 55,  4 },{     91,    1,  -70, 18, 55,  4 },{     91,    0,  -71, 18, 55,  4 },
    {     92,    0,  -72, 20,  8,  3 },{     92,    0,  -73, 20,  8,  3 },{     93,   -1,  -74, 20,  8,  3 },{     93,   -1,  -75, 20,  8,  3 },{     94,   -1,  -76, 20,  8,  3 },
    {     94,   -2,  -77, 20,  8,  3 },{     95,   -2,  -78, 20,  8,  3 },{     95,   -2,  -79, 20,  8,  3 },{     96,   -3,  -80, 20,  8,  3 },{     96,   -3,  -81, 20,  8,  3 },
    {     97,   -3,  -82, 20,  8,  3 },{     97,   -4,  -83, 20,  8,  3 },{     98,   -4,  -84, 20,  8,  3 },{     98,   -4,  -85, 20,  8,  3 },{     99,   -5,  -86, 20,  8,  3 },
    {     99,   -5,  -87, 20, 55,  0 },{    100,   -5,  -88, 20, 55,  0 },{    100,   -6,  -89, 20, 55,  0 },{    101,   -6,  -90, 20, 55,  0 },{    101,   -7,  -91, 20, 55,  0 },
    {    102,   -7,  -92, 20, 55,  0 },{    102,   -7,  -93, 20, 55,  0 },{    103,   -8,  -94, 20, 55,  0 },{    103,   -8,  -95, 20, 55,  0 },{    104,   -9,  -96, 20, 55,  0 },
    {    104,   -9,  -97, 20, 55,  0 },{    105,   -9,  -98, 20, 55,  0 },{    105,  -10,  -99, 20, 55,  0 },{    106,  -10, -100, 20, 55,  0 },{    106,  -11, -101, 20, 55,  0 },
    {    107,  -11, -102, 20, 55,  0 },{    107,  -12, -103, 20, 55,  0 },{    108,  -12, -104, 20, 55,  0 },{    108,  -12, -105, 20, 55,  0 },{    109,  -13, -106, 20, 55,  0 },
    {    109,  -13, -107, 20, 55,  0 },{    110,  -14, -108, 20, 55,  0 },{    110,  -14, -109, 20, 55,  0 },{    111,  -15, -110, 20, 55,  0 },{    111,  -15, -111, 20, 55,  0 },
    {    112,  -16, -112, 20, 55,  0 },})

CREATE_VEHICLE_INFO(TrackVehicleInfoRightEighthDiveLoopDownToOrthogonal3,{
    {     16,   31,   27,  8, 16,  0 },{     16,   30,   27,  8, 16,  0 },{     16,   29,   27,  8, 16,  0 },{     16,   28,   27,  8, 16,  0 },{     16,   27,   26,  8, 16,  0 },
    {     16,   26,   26,  8, 16,  0 },{     16,   25,   26,  8, 16,  0 },{     16,   24,   26,  8, 23,  0 },{     16,   23,   26,  8, 23,  0 },{     16,   22,   26,  8, 23,  0 },
    {     16,   21,   25,  8, 23,  0 },{     16,   20,   25,  8, 23,  0 },{     16,   19,   25,  8, 23,  0 },{     16,   18,   25,  8, 23,  0 },{     16,   17,   24,  8, 23,  0 },
    {     16,   16,   24,  8, 23,  0 },{     16,   15,   24,  8, 23,  0 },{     16,   14,   23,  8, 23,  0 },{     16,   13,   23,  8, 23,  0 },{     16,   12,   22,  8, 23,  0 },
    {     16,   11,   22,  8, 23,  0 },{     16,   10,   21,  8, 23,  0 },{     16,    9,   21,  8, 22,  0 },{     16,    8,   20,  8, 22,  0 },{     16,    7,   20,  8, 22,  0 },
    {     16,    6,   19, 24,  6, 14 },{     16,    5,   19, 24,  6, 14 },{     16,    4,   18, 24,  6, 14 },{     16,    3,   17, 24,  6, 14 },{     16,    2,   17, 24,  6, 14 },
    {     16,    1,   16, 24,  6, 14 },{     16,    0,   15, 24,  6, 14 },{     16,   -1,   15, 24,  6, 14 },{     15,   -2,   14, 24,  6, 14 },{     15,   -3,   13, 24,  6, 14 },
    {     15,   -4,   12, 24,  6, 14 },{     15,   -5,   11, 24,  6, 14 },{     15,   -6,   10, 24,  6, 14 },{     15,   -7,    9, 24,  6, 14 },{     15,   -8,    8, 24,  6, 14 },
    {     15,   -9,    7, 26,  7, 13 },{     15,  -10,    6, 26,  7, 13 },{     15,  -11,    5, 26,  7, 13 },{     15,  -12,    4, 26,  7, 13 },{     15,  -13,    3, 26,  7, 13 },
    {     15,  -14,    2, 26,  7, 13 },{     14,  -15,    1, 26,  7, 13 },{     14,  -15,    0, 26,  7, 13 },{     14,  -16,   -1, 26,  7, 13 },{     14,  -17,   -2, 26,  7, 13 },
    {     14,  -18,   -3, 26,  7, 13 },{     14,  -19,   -4, 26,  7, 13 },{     14,  -20,   -5, 26,  7, 13 },{     14,  -20,   -6, 26,  7, 13 },{     14,  -21,   -7, 26,  7, 13 },
    {     14,  -22,   -8, 26,  7, 13 },{     13,  -23,   -9, 26,  7, 13 },{     13,  -23,  -10, 26,  7, 13 },{     13,  -24,  -11, 26,  7, 13 },{     13,  -25,  -12, 26,  7, 13 },
    {     13,  -26,  -13, 26,  7, 13 },{     13,  -26,  -14, 26, 55, 11 },{     13,  -27,  -15, 26, 55, 11 },{     12,  -28,  -16, 26, 55, 11 },{     12,  -29,  -17, 26, 55, 11 },
    {     12,  -29,  -18, 26, 55, 11 },{     12,  -30,  -19, 26, 55, 11 },{     12,  -31,  -20, 26, 55, 11 },{     12,  -31,  -21, 26, 55, 11 },{     12,  -32,  -22, 26, 55, 11 },
    {     11,  -33,  -23, 26, 55, 11 },{     11,  -33,  -24, 26, 55, 11 },{     11,  -34,  -25, 26, 55, 11 },{     11,  -34,  -26, 26, 55, 11 },{     11,  -35,  -27, 26, 55, 11 },
    {     11,  -36,  -28, 26, 55, 11 },{     10,  -36,  -29, 26, 55, 11 },{     10,  -37,  -30, 26, 55, 11 },{     10,  -38,  -31, 26, 55, 11 },{     10,  -38,  -32, 26, 55, 11 },
    {     10,  -39,  -33, 26, 55, 11 },{      9,  -39,  -34, 26, 55, 11 },{      9,  -40,  -35, 26, 55, 11 },{      9,  -41,  -36, 26, 55, 11 },{      9,  -41,  -37, 26, 55, 11 },
    {      9,  -42,  -38, 26, 55, 11 },{      8,  -42,  -39, 26, 55, 11 },{      8,  -43,  -40, 26, 55, 10 },{      8,  -43,  -41, 26, 55, 10 },{      8,  -44,  -42, 26, 55, 10 },
    {      8,  -45,  -43, 26, 55, 10 },{      7,  -45,  -44, 26, 55, 10 },{      7,  -46,  -45, 26, 55, 10 },{      7,  -46,  -46, 26, 55, 10 },{      7,  -47,  -47, 26, 55, 10 },
    {      7,  -47,  -48, 26, 55, 10 },{      6,  -48,  -49, 26, 55, 10 },{      6,  -48,  -50, 26, 55, 10 },{      6,  -49,  -51, 26, 55, 10 },{      6,  -50,  -52, 26, 55, 10 },
    {      5,  -50,  -53, 26, 55, 10 },{      5,  -51,  -54, 26, 55, 10 },{      5,  -51,  -55, 26, 55, 10 },{      5,  -52,  -56, 26, 55, 10 },{      4,  -52,  -57, 26, 55, 10 },
    {      4,  -53,  -58, 26, 55,  4 },{      4,  -53,  -59, 26, 55,  4 },{      4,  -54,  -60, 26, 55,  4 },{      3,  -54,  -61, 26, 55,  4 },{      3,  -55,  -62, 26, 55,  4 },
    {      3,  -55,  -63, 26, 55,  4 },{      2,  -56,  -64, 26, 55,  4 },{      2,  -56,  -65, 26, 55,  4 },{      2,  -57,  -66, 26, 55,  4 },{      2,  -57,  -67, 26, 55,  4 },
    {      1,  -58,  -68, 26, 55,  4 },{      1,  -58,  -69, 26, 55,  4 },{      1,  -59,  -70, 26, 55,  4 },{      0,  -59,  -71, 26, 55,  4 },{      0,  -60,  -72, 28,  8,  3 },
    {      0,  -60,  -73, 28,  8,  3 },{     -1,  -61,  -74, 28,  8,  3 },{     -1,  -61,  -75, 28,  8,  3 },{     -1,  -62,  -76, 28,  8,  3 },{     -2,  -62,  -77, 28,  8,  3 },
    {     -2,  -63,  -78, 28,  8,  3 },{     -2,  -63,  -79, 28,  8,  3 },{     -3,  -64,  -80, 28,  8,  3 },{     -3,  -64,  -81, 28,  8,  3 },{     -3,  -65,  -82, 28,  8,  3 },
    {     -4,  -65,  -83, 28,  8,  3 },{     -4,  -66,  -84, 28,  8,  3 },{     -4,  -66,  -85, 28,  8,  3 },{     -5,  -67,  -86, 28,  8,  3 },{     -5,  -67,  -87, 28, 55,  0 },
    {     -5,  -68,  -88, 28, 55,  0 },{     -6,  -68,  -89, 28, 55,  0 },{     -6,  -69,  -90, 28, 55,  0 },{     -7,  -69,  -91, 28, 55,  0 },{     -7,  -70,  -92, 28, 55,  0 },
    {     -7,  -70,  -93, 28, 55,  0 },{     -8,  -71,  -94, 28, 55,  0 },{     -8,  -71,  -95, 28, 55,  0 },{     -9,  -72,  -96, 28, 55,  0 },{     -9,  -72,  -97, 28, 55,  0 },
    {     -9,  -73,  -98, 28, 55,  0 },{    -10,  -73,  -99, 28, 55,  0 },{    -10,  -74, -100, 28, 55,  0 },{    -11,  -74, -101, 28, 55,  0 },{    -11,  -75, -102, 28, 55,  0 },
    {    -12,  -75, -103, 28, 55,  0 },{    -12,  -76, -104, 28, 55,  0 },{    -12,  -76, -105, 28, 55,  0 },{    -13,  -77, -106, 28, 55,  0 },{    -13,  -77, -107, 28, 55,  0 },
    {    -14,  -78, -108, 28, 55,  0 },{    -14,  -78, -109, 28, 55,  0 },{    -15,  -79, -110, 28, 55,  0 },{    -15,  -79, -111, 28, 55,  0 },{    -16,  -80, -112, 28, 55,  0 },
})


namespace OpenRCT2::LeftLane
{
    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles0, {
        {     31,    9,    0,  0,  0,  0 }, {     30,    9,    0, 31,  0,  0 }, {     29,    9,    0, 31,  0,  0 }, {     28,    9,    0, 31,  0,  0 }, {     27,    9,    0, 31,  0,  0 },
        {     26,    9,    0, 31,  0,  0 }, {     25,    9,    0, 31,  0,  0 }, {     24,    9,    0, 31,  0,  0 }, {     23,    9,    0, 31,  0,  0 }, {     22,    8,    0, 31,  0,  0 },
        {     21,    8,    0, 31,  0,  0 }, {     20,    8,    0, 31,  0,  0 }, {     19,    8,    0, 31,  0,  0 }, {     18,    8,    0, 31,  0,  0 }, {     17,    8,    0, 31,  0,  0 },
        {     16,    7,    0, 30,  0,  0 }, {     15,    7,    0, 30,  0,  0 }, {     14,    7,    0, 30,  0,  0 }, {     13,    7,    0, 30,  0,  0 }, {     12,    6,    0, 30,  0,  0 },
        {     11,    6,    0, 30,  0,  0 }, {     10,    6,    0, 30,  0,  0 }, {      9,    6,    0, 30,  0,  0 }, {      8,    5,    0, 30,  0,  0 }, {      7,    5,    0, 30,  0,  0 },
        {      6,    5,    0, 30,  0,  0 }, {      5,    4,    0, 30,  0,  0 }, {      4,    4,    0, 30,  0,  0 }, {      3,    3,    0, 29,  0,  0 }, {      2,    3,    0, 29,  0,  0 },
        {      1,    3,    0, 29,  0,  0 }, {      0,    2,    0, 29,  0,  0 }, {     -1,    2,    0, 29,  0,  0 }, {     -2,    1,    0, 29,  0,  0 }, {     -3,    1,    0, 29,  0,  0 },
        {     -4,    0,    0, 29,  0,  0 }, {     -5,   -1,    0, 29,  0,  0 }, {     -6,   -1,    0, 29,  0,  0 }, {     -7,   -2,    0, 29,  0,  0 }, {     -8,   -2,    0, 29,  0,  0 },
        {     -9,   -3,    0, 29,  0,  0 }, {    -10,   -4,    0, 28,  0,  0 }, {    -11,   -4,    0, 28,  0,  0 }, {    -12,   -5,    0, 28,  0,  0 }, {    -13,   -6,    0, 28,  0,  0 },
        {    -14,   -7,    0, 28,  0,  0 }, {    -15,   -7,    0, 28,  0,  0 }, {    -16,   -8,    0, 28,  0,  0 }, {    -17,   -9,    0, 28,  0,  0 }, {    -18,  -10,    0, 28,  0,  0 },
        {    -19,  -11,    0, 28,  0,  0 }, {    -20,  -12,    0, 28,  0,  0 }, {    -21,  -13,    0, 27,  0,  0 }, {    -22,  -14,    0, 27,  0,  0 }, {    -23,  -15,    0, 27,  0,  0 },
        {    -24,  -16,    0, 27,  0,  0 }, {    -25,  -17,    0, 27,  0,  0 }, {    -25,  -18,    0, 27,  0,  0 }, {    -26,  -19,    0, 27,  0,  0 }, {    -27,  -20,    0, 27,  0,  0 },
        {    -28,  -21,    0, 27,  0,  0 }, {    -28,  -22,    0, 27,  0,  0 }, {    -29,  -23,    0, 26,  0,  0 }, {    -30,  -24,    0, 26,  0,  0 }, {    -30,  -25,    0, 26,  0,  0 },
        {    -31,  -26,    0, 26,  0,  0 }, {    -31,  -27,    0, 26,  0,  0 }, {    -32,  -28,    0, 26,  0,  0 }, {    -33,  -29,    0, 26,  0,  0 }, {    -33,  -30,    0, 26,  0,  0 },
        {    -34,  -31,    0, 26,  0,  0 }, {    -34,  -32,    0, 26,  0,  0 }, {    -35,  -33,    0, 26,  0,  0 }, {    -35,  -34,    0, 26,  0,  0 }, {    -35,  -35,    0, 26,  0,  0 },
        {    -36,  -36,    0, 25,  0,  0 }, {    -36,  -37,    0, 25,  0,  0 }, {    -37,  -38,    0, 25,  0,  0 }, {    -37,  -39,    0, 25,  0,  0 }, {    -37,  -40,    0, 25,  0,  0 },
        {    -38,  -41,    0, 25,  0,  0 }, {    -38,  -42,    0, 25,  0,  0 }, {    -38,  -43,    0, 25,  0,  0 }, {    -38,  -44,    0, 25,  0,  0 }, {    -39,  -45,    0, 25,  0,  0 },
        {    -39,  -46,    0, 25,  0,  0 }, {    -39,  -47,    0, 25,  0,  0 }, {    -39,  -48,    0, 25,  0,  0 }, {    -40,  -49,    0, 24,  0,  0 }, {    -40,  -50,    0, 24,  0,  0 },
        {    -40,  -51,    0, 24,  0,  0 }, {    -40,  -52,    0, 24,  0,  0 }, {    -40,  -53,    0, 24,  0,  0 }, {    -40,  -54,    0, 24,  0,  0 }, {    -41,  -55,    0, 24,  0,  0 },
        {    -41,  -56,    0, 24,  0,  0 }, {    -41,  -57,    0, 24,  0,  0 }, {    -41,  -58,    0, 24,  0,  0 }, {    -41,  -59,    0, 24,  0,  0 }, {    -41,  -60,    0, 24,  0,  0 },
        {    -41,  -61,    0, 24,  0,  0 }, {    -41,  -62,    0, 24,  0,  0 }, {    -41,  -63,    0, 24,  0,  0 }, {    -41,  -64,    0, 23,  0,  0 }, {    -40,  -64,    0, 23,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles1, {
        {      9,    1,    0,  8,  0,  0 }, {      9,    2,    0,  7,  0,  0 }, {      9,    3,    0,  7,  0,  0 }, {      9,    4,    0,  7,  0,  0 }, {      9,    5,    0,  7,  0,  0 },
        {      9,    6,    0,  7,  0,  0 }, {      9,    7,    0,  7,  0,  0 }, {      9,    8,    0,  7,  0,  0 }, {      9,    9,    0,  7,  0,  0 }, {      8,   10,    0,  7,  0,  0 },
        {      8,   11,    0,  7,  0,  0 }, {      8,   12,    0,  7,  0,  0 }, {      8,   13,    0,  7,  0,  0 }, {      8,   14,    0,  7,  0,  0 }, {      8,   15,    0,  7,  0,  0 },
        {      7,   16,    0,  6,  0,  0 }, {      7,   17,    0,  6,  0,  0 }, {      7,   18,    0,  6,  0,  0 }, {      7,   19,    0,  6,  0,  0 }, {      6,   20,    0,  6,  0,  0 },
        {      6,   21,    0,  6,  0,  0 }, {      6,   22,    0,  6,  0,  0 }, {      6,   23,    0,  6,  0,  0 }, {      5,   24,    0,  6,  0,  0 }, {      5,   25,    0,  6,  0,  0 },
        {      5,   26,    0,  6,  0,  0 }, {      4,   27,    0,  6,  0,  0 }, {      4,   28,    0,  6,  0,  0 }, {      3,   29,    0,  5,  0,  0 }, {      3,   30,    0,  5,  0,  0 },
        {      3,   31,    0,  5,  0,  0 }, {      2,   32,    0,  5,  0,  0 }, {      2,   33,    0,  5,  0,  0 }, {      1,   34,    0,  5,  0,  0 }, {      1,   35,    0,  5,  0,  0 },
        {      0,   36,    0,  5,  0,  0 }, {     -1,   37,    0,  5,  0,  0 }, {     -1,   38,    0,  5,  0,  0 }, {     -2,   39,    0,  5,  0,  0 }, {     -2,   40,    0,  5,  0,  0 },
        {     -3,   41,    0,  5,  0,  0 }, {     -4,   42,    0,  4,  0,  0 }, {     -4,   43,    0,  4,  0,  0 }, {     -5,   44,    0,  4,  0,  0 }, {     -6,   45,    0,  4,  0,  0 },
        {     -7,   46,    0,  4,  0,  0 }, {     -7,   47,    0,  4,  0,  0 }, {     -8,   48,    0,  4,  0,  0 }, {     -9,   49,    0,  4,  0,  0 }, {    -10,   50,    0,  4,  0,  0 },
        {    -11,   51,    0,  4,  0,  0 }, {    -12,   52,    0,  4,  0,  0 }, {    -13,   53,    0,  3,  0,  0 }, {    -14,   54,    0,  3,  0,  0 }, {    -15,   55,    0,  3,  0,  0 },
        {    -16,   56,    0,  3,  0,  0 }, {    -17,   57,    0,  3,  0,  0 }, {    -18,   57,    0,  3,  0,  0 }, {    -19,   58,    0,  3,  0,  0 }, {    -20,   59,    0,  3,  0,  0 },
        {    -21,   60,    0,  3,  0,  0 }, {    -22,   60,    0,  3,  0,  0 }, {    -23,   61,    0,  2,  0,  0 }, {    -24,   62,    0,  2,  0,  0 }, {    -25,   62,    0,  2,  0,  0 },
        {    -26,   63,    0,  2,  0,  0 }, {    -27,   63,    0,  2,  0,  0 }, {    -28,   64,    0,  2,  0,  0 }, {    -29,   65,    0,  2,  0,  0 }, {    -30,   65,    0,  2,  0,  0 },
        {    -31,   66,    0,  2,  0,  0 }, {    -32,   66,    0,  2,  0,  0 }, {    -33,   67,    0,  2,  0,  0 }, {    -34,   67,    0,  2,  0,  0 }, {    -35,   67,    0,  2,  0,  0 },
        {    -36,   68,    0,  1,  0,  0 }, {    -37,   68,    0,  1,  0,  0 }, {    -38,   69,    0,  1,  0,  0 }, {    -39,   69,    0,  1,  0,  0 }, {    -40,   69,    0,  1,  0,  0 },
        {    -41,   70,    0,  1,  0,  0 }, {    -42,   70,    0,  1,  0,  0 }, {    -43,   70,    0,  1,  0,  0 }, {    -44,   70,    0,  1,  0,  0 }, {    -45,   71,    0,  1,  0,  0 },
        {    -46,   71,    0,  1,  0,  0 }, {    -47,   71,    0,  1,  0,  0 }, {    -48,   71,    0,  1,  0,  0 }, {    -49,   72,    0,  0,  0,  0 }, {    -50,   72,    0,  0,  0,  0 },
        {    -51,   72,    0,  0,  0,  0 }, {    -52,   72,    0,  0,  0,  0 }, {    -53,   72,    0,  0,  0,  0 }, {    -54,   72,    0,  0,  0,  0 }, {    -55,   73,    0,  0,  0,  0 },
        {    -56,   73,    0,  0,  0,  0 }, {    -57,   73,    0,  0,  0,  0 }, {    -58,   73,    0,  0,  0,  0 }, {    -59,   73,    0,  0,  0,  0 }, {    -60,   73,    0,  0,  0,  0 },
        {    -61,   73,    0,  0,  0,  0 }, {    -62,   73,    0,  0,  0,  0 }, {    -63,   73,    0,  0,  0,  0 }, {    -64,   73,    0, 31,  0,  0 }, {    -64,   72,    0, 31,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles2, {
        {      1,   23,    0, 16,  0,  0 }, {      2,   23,    0, 15,  0,  0 }, {      3,   23,    0, 15,  0,  0 }, {      4,   23,    0, 15,  0,  0 }, {      5,   23,    0, 15,  0,  0 },
        {      6,   23,    0, 15,  0,  0 }, {      7,   23,    0, 15,  0,  0 }, {      8,   23,    0, 15,  0,  0 }, {      9,   23,    0, 15,  0,  0 }, {     10,   24,    0, 15,  0,  0 },
        {     11,   24,    0, 15,  0,  0 }, {     12,   24,    0, 15,  0,  0 }, {     13,   24,    0, 15,  0,  0 }, {     14,   24,    0, 15,  0,  0 }, {     15,   24,    0, 15,  0,  0 },
        {     16,   25,    0, 14,  0,  0 }, {     17,   25,    0, 14,  0,  0 }, {     18,   25,    0, 14,  0,  0 }, {     19,   25,    0, 14,  0,  0 }, {     20,   26,    0, 14,  0,  0 },
        {     21,   26,    0, 14,  0,  0 }, {     22,   26,    0, 14,  0,  0 }, {     23,   26,    0, 14,  0,  0 }, {     24,   27,    0, 14,  0,  0 }, {     25,   27,    0, 14,  0,  0 },
        {     26,   27,    0, 14,  0,  0 }, {     27,   28,    0, 14,  0,  0 }, {     28,   28,    0, 14,  0,  0 }, {     29,   29,    0, 13,  0,  0 }, {     30,   29,    0, 13,  0,  0 },
        {     31,   29,    0, 13,  0,  0 }, {     32,   30,    0, 13,  0,  0 }, {     33,   30,    0, 13,  0,  0 }, {     34,   31,    0, 13,  0,  0 }, {     35,   31,    0, 13,  0,  0 },
        {     36,   32,    0, 13,  0,  0 }, {     37,   33,    0, 13,  0,  0 }, {     38,   33,    0, 13,  0,  0 }, {     39,   34,    0, 13,  0,  0 }, {     40,   34,    0, 13,  0,  0 },
        {     41,   35,    0, 13,  0,  0 }, {     42,   36,    0, 12,  0,  0 }, {     43,   36,    0, 12,  0,  0 }, {     44,   37,    0, 12,  0,  0 }, {     45,   38,    0, 12,  0,  0 },
        {     46,   39,    0, 12,  0,  0 }, {     47,   39,    0, 12,  0,  0 }, {     48,   40,    0, 12,  0,  0 }, {     49,   41,    0, 12,  0,  0 }, {     50,   42,    0, 12,  0,  0 },
        {     51,   43,    0, 12,  0,  0 }, {     52,   44,    0, 12,  0,  0 }, {     53,   45,    0, 11,  0,  0 }, {     54,   46,    0, 11,  0,  0 }, {     55,   47,    0, 11,  0,  0 },
        {     56,   48,    0, 11,  0,  0 }, {     57,   49,    0, 11,  0,  0 }, {     57,   50,    0, 11,  0,  0 }, {     58,   51,    0, 11,  0,  0 }, {     59,   52,    0, 11,  0,  0 },
        {     60,   53,    0, 11,  0,  0 }, {     60,   54,    0, 11,  0,  0 }, {     61,   55,    0, 10,  0,  0 }, {     62,   56,    0, 10,  0,  0 }, {     62,   57,    0, 10,  0,  0 },
        {     63,   58,    0, 10,  0,  0 }, {     63,   59,    0, 10,  0,  0 }, {     64,   60,    0, 10,  0,  0 }, {     65,   61,    0, 10,  0,  0 }, {     65,   62,    0, 10,  0,  0 },
        {     66,   63,    0, 10,  0,  0 }, {     66,   64,    0, 10,  0,  0 }, {     67,   65,    0, 10,  0,  0 }, {     67,   66,    0, 10,  0,  0 }, {     67,   67,    0, 10,  0,  0 },
        {     68,   68,    0,  9,  0,  0 }, {     68,   69,    0,  9,  0,  0 }, {     69,   70,    0,  9,  0,  0 }, {     69,   71,    0,  9,  0,  0 }, {     69,   72,    0,  9,  0,  0 },
        {     70,   73,    0,  9,  0,  0 }, {     70,   74,    0,  9,  0,  0 }, {     70,   75,    0,  9,  0,  0 }, {     70,   76,    0,  9,  0,  0 }, {     71,   77,    0,  9,  0,  0 },
        {     71,   78,    0,  9,  0,  0 }, {     71,   79,    0,  9,  0,  0 }, {     71,   80,    0,  9,  0,  0 }, {     72,   81,    0,  8,  0,  0 }, {     72,   82,    0,  8,  0,  0 },
        {     72,   83,    0,  8,  0,  0 }, {     72,   84,    0,  8,  0,  0 }, {     72,   85,    0,  8,  0,  0 }, {     72,   86,    0,  8,  0,  0 }, {     73,   87,    0,  8,  0,  0 },
        {     73,   88,    0,  8,  0,  0 }, {     73,   89,    0,  8,  0,  0 }, {     73,   90,    0,  8,  0,  0 }, {     73,   91,    0,  8,  0,  0 }, {     73,   92,    0,  8,  0,  0 },
        {     73,   93,    0,  8,  0,  0 }, {     73,   94,    0,  8,  0,  0 }, {     73,   95,    0,  8,  0,  0 }, {     73,   96,    0,  7,  0,  0 }, {     72,   96,    0,  7,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles3, {
        {     23,   31,    0, 24,  0,  0 }, {     23,   30,    0, 23,  0,  0 }, {     23,   29,    0, 23,  0,  0 }, {     23,   28,    0, 23,  0,  0 }, {     23,   27,    0, 23,  0,  0 },
        {     23,   26,    0, 23,  0,  0 }, {     23,   25,    0, 23,  0,  0 }, {     23,   24,    0, 23,  0,  0 }, {     23,   23,    0, 23,  0,  0 }, {     24,   22,    0, 23,  0,  0 },
        {     24,   21,    0, 23,  0,  0 }, {     24,   20,    0, 23,  0,  0 }, {     24,   19,    0, 23,  0,  0 }, {     24,   18,    0, 23,  0,  0 }, {     24,   17,    0, 23,  0,  0 },
        {     25,   16,    0, 22,  0,  0 }, {     25,   15,    0, 22,  0,  0 }, {     25,   14,    0, 22,  0,  0 }, {     25,   13,    0, 22,  0,  0 }, {     26,   12,    0, 22,  0,  0 },
        {     26,   11,    0, 22,  0,  0 }, {     26,   10,    0, 22,  0,  0 }, {     26,    9,    0, 22,  0,  0 }, {     27,    8,    0, 22,  0,  0 }, {     27,    7,    0, 22,  0,  0 },
        {     27,    6,    0, 22,  0,  0 }, {     28,    5,    0, 22,  0,  0 }, {     28,    4,    0, 22,  0,  0 }, {     29,    3,    0, 21,  0,  0 }, {     29,    2,    0, 21,  0,  0 },
        {     29,    1,    0, 21,  0,  0 }, {     30,    0,    0, 21,  0,  0 }, {     30,   -1,    0, 21,  0,  0 }, {     31,   -2,    0, 21,  0,  0 }, {     31,   -3,    0, 21,  0,  0 },
        {     32,   -4,    0, 21,  0,  0 }, {     33,   -5,    0, 21,  0,  0 }, {     33,   -6,    0, 21,  0,  0 }, {     34,   -7,    0, 21,  0,  0 }, {     34,   -8,    0, 21,  0,  0 },
        {     35,   -9,    0, 21,  0,  0 }, {     36,  -10,    0, 20,  0,  0 }, {     36,  -11,    0, 20,  0,  0 }, {     37,  -12,    0, 20,  0,  0 }, {     38,  -13,    0, 20,  0,  0 },
        {     39,  -14,    0, 20,  0,  0 }, {     39,  -15,    0, 20,  0,  0 }, {     40,  -16,    0, 20,  0,  0 }, {     41,  -17,    0, 20,  0,  0 }, {     42,  -18,    0, 20,  0,  0 },
        {     43,  -19,    0, 20,  0,  0 }, {     44,  -20,    0, 20,  0,  0 }, {     45,  -21,    0, 19,  0,  0 }, {     46,  -22,    0, 19,  0,  0 }, {     47,  -23,    0, 19,  0,  0 },
        {     48,  -24,    0, 19,  0,  0 }, {     49,  -25,    0, 19,  0,  0 }, {     50,  -25,    0, 19,  0,  0 }, {     51,  -26,    0, 19,  0,  0 }, {     52,  -27,    0, 19,  0,  0 },
        {     53,  -28,    0, 19,  0,  0 }, {     54,  -28,    0, 19,  0,  0 }, {     55,  -29,    0, 18,  0,  0 }, {     56,  -30,    0, 18,  0,  0 }, {     57,  -30,    0, 18,  0,  0 },
        {     58,  -31,    0, 18,  0,  0 }, {     59,  -31,    0, 18,  0,  0 }, {     60,  -32,    0, 18,  0,  0 }, {     61,  -33,    0, 18,  0,  0 }, {     62,  -33,    0, 18,  0,  0 },
        {     63,  -34,    0, 18,  0,  0 }, {     64,  -34,    0, 18,  0,  0 }, {     65,  -35,    0, 18,  0,  0 }, {     66,  -35,    0, 18,  0,  0 }, {     67,  -35,    0, 18,  0,  0 },
        {     68,  -36,    0, 17,  0,  0 }, {     69,  -36,    0, 17,  0,  0 }, {     70,  -37,    0, 17,  0,  0 }, {     71,  -37,    0, 17,  0,  0 }, {     72,  -37,    0, 17,  0,  0 },
        {     73,  -38,    0, 17,  0,  0 }, {     74,  -38,    0, 17,  0,  0 }, {     75,  -38,    0, 17,  0,  0 }, {     76,  -38,    0, 17,  0,  0 }, {     77,  -39,    0, 17,  0,  0 },
        {     78,  -39,    0, 17,  0,  0 }, {     79,  -39,    0, 17,  0,  0 }, {     80,  -39,    0, 17,  0,  0 }, {     81,  -40,    0, 16,  0,  0 }, {     82,  -40,    0, 16,  0,  0 },
        {     83,  -40,    0, 16,  0,  0 }, {     84,  -40,    0, 16,  0,  0 }, {     85,  -40,    0, 16,  0,  0 }, {     86,  -40,    0, 16,  0,  0 }, {     87,  -41,    0, 16,  0,  0 },
        {     88,  -41,    0, 16,  0,  0 }, {     89,  -41,    0, 16,  0,  0 }, {     90,  -41,    0, 16,  0,  0 }, {     91,  -41,    0, 16,  0,  0 }, {     92,  -41,    0, 16,  0,  0 },
        {     93,  -41,    0, 16,  0,  0 }, {     94,  -41,    0, 16,  0,  0 }, {     95,  -41,    0, 16,  0,  0 }, {     96,  -41,    0, 15,  0,  0 }, {     96,  -40,    0, 15,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles0, {
        {     31,    9,    0,  0,  0,  0 }, {     30,    9,    0,  1,  0,  0 }, {     29,    9,    0,  1,  0,  0 }, {     28,    9,    0,  1,  0,  0 }, {     27,    9,    0,  1,  0,  0 },
        {     26,    9,    0,  1,  0,  0 }, {     25,    9,    0,  1,  0,  0 }, {     24,    9,    0,  1,  0,  0 }, {     23,    9,    0,  1,  0,  0 }, {     22,    9,    0,  1,  0,  0 },
        {     21,   10,    0,  1,  0,  0 }, {     20,   10,    0,  1,  0,  0 }, {     19,   10,    0,  1,  0,  0 }, {     18,   10,    0,  1,  0,  0 }, {     17,   10,    0,  1,  0,  0 },
        {     16,   10,    0,  1,  0,  0 }, {     15,   10,    0,  1,  0,  0 }, {     14,   11,    0,  2,  0,  0 }, {     13,   11,    0,  2,  0,  0 }, {     12,   11,    0,  2,  0,  0 },
        {     11,   11,    0,  2,  0,  0 }, {     10,   12,    0,  2,  0,  0 }, {      9,   12,    0,  2,  0,  0 }, {      8,   12,    0,  2,  0,  0 }, {      7,   12,    0,  2,  0,  0 },
        {      6,   13,    0,  2,  0,  0 }, {      5,   13,    0,  2,  0,  0 }, {      4,   13,    0,  2,  0,  0 }, {      3,   14,    0,  2,  0,  0 }, {      2,   14,    0,  2,  0,  0 },
        {      1,   14,    0,  2,  0,  0 }, {      0,   15,    0,  2,  0,  0 }, {     -1,   15,    0,  2,  0,  0 }, {     -2,   16,    0,  3,  0,  0 }, {     -3,   16,    0,  3,  0,  0 },
        {     -4,   16,    0,  3,  0,  0 }, {     -5,   17,    0,  3,  0,  0 }, {     -6,   17,    0,  3,  0,  0 }, {     -7,   18,    0,  3,  0,  0 }, {     -8,   18,    0,  3,  0,  0 },
        {     -9,   19,    0,  3,  0,  0 }, {    -10,   19,    0,  3,  0,  0 }, {    -11,   20,    0,  3,  0,  0 }, {    -12,   20,    0,  3,  0,  0 }, {    -13,   21,    0,  3,  0,  0 },
        {    -14,   22,    0,  3,  0,  0 }, {    -15,   22,    0,  3,  0,  0 }, {    -16,   23,    0,  3,  0,  0 }, {    -17,   24,    0,  4,  0,  0 }, {    -18,   24,    0,  4,  0,  0 },
        {    -19,   25,    0,  4,  0,  0 }, {    -20,   26,    0,  4,  0,  0 }, {    -21,   26,    0,  4,  0,  0 }, {    -22,   27,    0,  4,  0,  0 }, {    -23,   28,    0,  4,  0,  0 },
        {    -24,   29,    0,  4,  0,  0 }, {    -25,   30,    0,  4,  0,  0 }, {    -26,   30,    0,  4,  0,  0 }, {    -27,   31,    0,  4,  0,  0 }, {    -28,   32,    0,  4,  0,  0 },
        {    -29,   33,    0,  4,  0,  0 }, {    -30,   34,    0,  4,  0,  0 }, {    -31,   35,    0,  5,  0,  0 }, {    -32,   36,    0,  5,  0,  0 }, {    -33,   37,    0,  5,  0,  0 },
        {    -34,   38,    0,  5,  0,  0 }, {    -34,   39,    0,  5,  0,  0 }, {    -35,   40,    0,  5,  0,  0 }, {    -36,   41,    0,  5,  0,  0 }, {    -37,   42,    0,  5,  0,  0 },
        {    -38,   43,    0,  5,  0,  0 }, {    -38,   44,    0,  5,  0,  0 }, {    -39,   45,    0,  5,  0,  0 }, {    -40,   46,    0,  5,  0,  0 }, {    -40,   47,    0,  5,  0,  0 },
        {    -41,   48,    0,  6,  0,  0 }, {    -42,   49,    0,  6,  0,  0 }, {    -42,   50,    0,  6,  0,  0 }, {    -43,   51,    0,  6,  0,  0 }, {    -44,   52,    0,  6,  0,  0 },
        {    -44,   53,    0,  6,  0,  0 }, {    -45,   54,    0,  6,  0,  0 }, {    -45,   55,    0,  6,  0,  0 }, {    -46,   56,    0,  6,  0,  0 }, {    -46,   57,    0,  6,  0,  0 },
        {    -47,   58,    0,  6,  0,  0 }, {    -47,   59,    0,  6,  0,  0 }, {    -48,   60,    0,  6,  0,  0 }, {    -48,   61,    0,  6,  0,  0 }, {    -48,   62,    0,  6,  0,  0 },
        {    -49,   63,    0,  7,  0,  0 }, {    -49,   64,    0,  7,  0,  0 }, {    -50,   65,    0,  7,  0,  0 }, {    -50,   66,    0,  7,  0,  0 }, {    -50,   67,    0,  7,  0,  0 },
        {    -51,   68,    0,  7,  0,  0 }, {    -51,   69,    0,  7,  0,  0 }, {    -51,   70,    0,  7,  0,  0 }, {    -52,   71,    0,  7,  0,  0 }, {    -52,   72,    0,  7,  0,  0 },
        {    -52,   73,    0,  7,  0,  0 }, {    -52,   74,    0,  7,  0,  0 }, {    -53,   75,    0,  7,  0,  0 }, {    -53,   76,    0,  7,  0,  0 }, {    -53,   77,    0,  7,  0,  0 },
        {    -53,   78,    0,  7,  0,  0 }, {    -54,   79,    0,  8,  0,  0 }, {    -54,   80,    0,  8,  0,  0 }, {    -54,   81,    0,  8,  0,  0 }, {    -54,   82,    0,  8,  0,  0 },
        {    -54,   83,    0,  8,  0,  0 }, {    -54,   84,    0,  8,  0,  0 }, {    -54,   85,    0,  8,  0,  0 }, {    -55,   86,    0,  8,  0,  0 }, {    -55,   87,    0,  8,  0,  0 },
        {    -55,   88,    0,  8,  0,  0 }, {    -55,   89,    0,  8,  0,  0 }, {    -55,   90,    0,  8,  0,  0 }, {    -55,   91,    0,  8,  0,  0 }, {    -55,   92,    0,  8,  0,  0 },
        {    -55,   93,    0,  8,  0,  0 }, {    -55,   94,    0,  8,  0,  0 }, {    -55,   95,    0,  8,  0,  0 }, {    -55,   96,    0,  9,  0,  0 }, {    -54,   96,    0,  9,  0,  0 },
        {    -53,   96,    0,  9,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles1, {
        {      9,    1,    0,  8,  0,  0 }, {      9,    2,    0,  9,  0,  0 }, {      9,    3,    0,  9,  0,  0 }, {      9,    4,    0,  9,  0,  0 }, {      9,    5,    0,  9,  0,  0 },
        {      9,    6,    0,  9,  0,  0 }, {      9,    7,    0,  9,  0,  0 }, {      9,    8,    0,  9,  0,  0 }, {      9,    9,    0,  9,  0,  0 }, {      9,   10,    0,  9,  0,  0 },
        {     10,   11,    0,  9,  0,  0 }, {     10,   12,    0,  9,  0,  0 }, {     10,   13,    0,  9,  0,  0 }, {     10,   14,    0,  9,  0,  0 }, {     10,   15,    0,  9,  0,  0 },
        {     10,   16,    0,  9,  0,  0 }, {     10,   17,    0,  9,  0,  0 }, {     11,   18,    0, 10,  0,  0 }, {     11,   19,    0, 10,  0,  0 }, {     11,   20,    0, 10,  0,  0 },
        {     11,   21,    0, 10,  0,  0 }, {     12,   22,    0, 10,  0,  0 }, {     12,   23,    0, 10,  0,  0 }, {     12,   24,    0, 10,  0,  0 }, {     12,   25,    0, 10,  0,  0 },
        {     13,   26,    0, 10,  0,  0 }, {     13,   27,    0, 10,  0,  0 }, {     13,   28,    0, 10,  0,  0 }, {     14,   29,    0, 10,  0,  0 }, {     14,   30,    0, 10,  0,  0 },
        {     14,   31,    0, 10,  0,  0 }, {     15,   32,    0, 10,  0,  0 }, {     15,   33,    0, 10,  0,  0 }, {     16,   34,    0, 11,  0,  0 }, {     16,   35,    0, 11,  0,  0 },
        {     16,   36,    0, 11,  0,  0 }, {     17,   37,    0, 11,  0,  0 }, {     17,   38,    0, 11,  0,  0 }, {     18,   39,    0, 11,  0,  0 }, {     18,   40,    0, 11,  0,  0 },
        {     19,   41,    0, 11,  0,  0 }, {     19,   42,    0, 11,  0,  0 }, {     20,   43,    0, 11,  0,  0 }, {     20,   44,    0, 11,  0,  0 }, {     21,   45,    0, 11,  0,  0 },
        {     22,   46,    0, 11,  0,  0 }, {     22,   47,    0, 11,  0,  0 }, {     23,   48,    0, 11,  0,  0 }, {     24,   49,    0, 12,  0,  0 }, {     24,   50,    0, 12,  0,  0 },
        {     25,   51,    0, 12,  0,  0 }, {     26,   52,    0, 12,  0,  0 }, {     26,   53,    0, 12,  0,  0 }, {     27,   54,    0, 12,  0,  0 }, {     28,   55,    0, 12,  0,  0 },
        {     29,   56,    0, 12,  0,  0 }, {     30,   57,    0, 12,  0,  0 }, {     30,   58,    0, 12,  0,  0 }, {     31,   59,    0, 12,  0,  0 }, {     32,   60,    0, 12,  0,  0 },
        {     33,   61,    0, 12,  0,  0 }, {     34,   62,    0, 12,  0,  0 }, {     35,   63,    0, 13,  0,  0 }, {     36,   64,    0, 13,  0,  0 }, {     37,   65,    0, 13,  0,  0 },
        {     38,   66,    0, 13,  0,  0 }, {     39,   66,    0, 13,  0,  0 }, {     40,   67,    0, 13,  0,  0 }, {     41,   68,    0, 13,  0,  0 }, {     42,   69,    0, 13,  0,  0 },
        {     43,   70,    0, 13,  0,  0 }, {     44,   70,    0, 13,  0,  0 }, {     45,   71,    0, 13,  0,  0 }, {     46,   72,    0, 13,  0,  0 }, {     47,   72,    0, 13,  0,  0 },
        {     48,   73,    0, 14,  0,  0 }, {     49,   74,    0, 14,  0,  0 }, {     50,   74,    0, 14,  0,  0 }, {     51,   75,    0, 14,  0,  0 }, {     52,   76,    0, 14,  0,  0 },
        {     53,   76,    0, 14,  0,  0 }, {     54,   77,    0, 14,  0,  0 }, {     55,   77,    0, 14,  0,  0 }, {     56,   78,    0, 14,  0,  0 }, {     57,   78,    0, 14,  0,  0 },
        {     58,   79,    0, 14,  0,  0 }, {     59,   79,    0, 14,  0,  0 }, {     60,   80,    0, 14,  0,  0 }, {     61,   80,    0, 14,  0,  0 }, {     62,   80,    0, 14,  0,  0 },
        {     63,   81,    0, 15,  0,  0 }, {     64,   81,    0, 15,  0,  0 }, {     65,   82,    0, 15,  0,  0 }, {     66,   82,    0, 15,  0,  0 }, {     67,   82,    0, 15,  0,  0 },
        {     68,   83,    0, 15,  0,  0 }, {     69,   83,    0, 15,  0,  0 }, {     70,   83,    0, 15,  0,  0 }, {     71,   84,    0, 15,  0,  0 }, {     72,   84,    0, 15,  0,  0 },
        {     73,   84,    0, 15,  0,  0 }, {     74,   84,    0, 15,  0,  0 }, {     75,   85,    0, 15,  0,  0 }, {     76,   85,    0, 15,  0,  0 }, {     77,   85,    0, 15,  0,  0 },
        {     78,   85,    0, 15,  0,  0 }, {     79,   86,    0, 16,  0,  0 }, {     80,   86,    0, 16,  0,  0 }, {     81,   86,    0, 16,  0,  0 }, {     82,   86,    0, 16,  0,  0 },
        {     83,   86,    0, 16,  0,  0 }, {     84,   86,    0, 16,  0,  0 }, {     85,   86,    0, 16,  0,  0 }, {     86,   87,    0, 16,  0,  0 }, {     87,   87,    0, 16,  0,  0 },
        {     88,   87,    0, 16,  0,  0 }, {     89,   87,    0, 16,  0,  0 }, {     90,   87,    0, 16,  0,  0 }, {     91,   87,    0, 16,  0,  0 }, {     92,   87,    0, 16,  0,  0 },
        {     93,   87,    0, 16,  0,  0 }, {     94,   87,    0, 16,  0,  0 }, {     95,   87,    0, 16,  0,  0 }, {     96,   87,    0, 17,  0,  0 }, {     96,   86,    0, 17,  0,  0 },
        {     96,   85,    0, 17,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles2, {
        {      1,   23,    0, 16,  0,  0 }, {      2,   23,    0, 17,  0,  0 }, {      3,   23,    0, 17,  0,  0 }, {      4,   23,    0, 17,  0,  0 }, {      5,   23,    0, 17,  0,  0 },
        {      6,   23,    0, 17,  0,  0 }, {      7,   23,    0, 17,  0,  0 }, {      8,   23,    0, 17,  0,  0 }, {      9,   23,    0, 17,  0,  0 }, {     10,   23,    0, 17,  0,  0 },
        {     11,   22,    0, 17,  0,  0 }, {     12,   22,    0, 17,  0,  0 }, {     13,   22,    0, 17,  0,  0 }, {     14,   22,    0, 17,  0,  0 }, {     15,   22,    0, 17,  0,  0 },
        {     16,   22,    0, 17,  0,  0 }, {     17,   22,    0, 17,  0,  0 }, {     18,   21,    0, 18,  0,  0 }, {     19,   21,    0, 18,  0,  0 }, {     20,   21,    0, 18,  0,  0 },
        {     21,   21,    0, 18,  0,  0 }, {     22,   20,    0, 18,  0,  0 }, {     23,   20,    0, 18,  0,  0 }, {     24,   20,    0, 18,  0,  0 }, {     25,   20,    0, 18,  0,  0 },
        {     26,   19,    0, 18,  0,  0 }, {     27,   19,    0, 18,  0,  0 }, {     28,   19,    0, 18,  0,  0 }, {     29,   18,    0, 18,  0,  0 }, {     30,   18,    0, 18,  0,  0 },
        {     31,   18,    0, 18,  0,  0 }, {     32,   17,    0, 18,  0,  0 }, {     33,   17,    0, 18,  0,  0 }, {     34,   16,    0, 19,  0,  0 }, {     35,   16,    0, 19,  0,  0 },
        {     36,   16,    0, 19,  0,  0 }, {     37,   15,    0, 19,  0,  0 }, {     38,   15,    0, 19,  0,  0 }, {     39,   14,    0, 19,  0,  0 }, {     40,   14,    0, 19,  0,  0 },
        {     41,   13,    0, 19,  0,  0 }, {     42,   13,    0, 19,  0,  0 }, {     43,   12,    0, 19,  0,  0 }, {     44,   12,    0, 19,  0,  0 }, {     45,   11,    0, 19,  0,  0 },
        {     46,   10,    0, 19,  0,  0 }, {     47,   10,    0, 19,  0,  0 }, {     48,    9,    0, 19,  0,  0 }, {     49,    8,    0, 20,  0,  0 }, {     50,    8,    0, 20,  0,  0 },
        {     51,    7,    0, 20,  0,  0 }, {     52,    6,    0, 20,  0,  0 }, {     53,    6,    0, 20,  0,  0 }, {     54,    5,    0, 20,  0,  0 }, {     55,    4,    0, 20,  0,  0 },
        {     56,    3,    0, 20,  0,  0 }, {     57,    2,    0, 20,  0,  0 }, {     58,    2,    0, 20,  0,  0 }, {     59,    1,    0, 20,  0,  0 }, {     60,    0,    0, 20,  0,  0 },
        {     61,   -1,    0, 20,  0,  0 }, {     62,   -2,    0, 20,  0,  0 }, {     63,   -3,    0, 21,  0,  0 }, {     64,   -4,    0, 21,  0,  0 }, {     65,   -5,    0, 21,  0,  0 },
        {     66,   -6,    0, 21,  0,  0 }, {     66,   -7,    0, 21,  0,  0 }, {     67,   -8,    0, 21,  0,  0 }, {     68,   -9,    0, 21,  0,  0 }, {     69,  -10,    0, 21,  0,  0 },
        {     70,  -11,    0, 21,  0,  0 }, {     70,  -12,    0, 21,  0,  0 }, {     71,  -13,    0, 21,  0,  0 }, {     72,  -14,    0, 21,  0,  0 }, {     72,  -15,    0, 21,  0,  0 },
        {     73,  -16,    0, 22,  0,  0 }, {     74,  -17,    0, 22,  0,  0 }, {     74,  -18,    0, 22,  0,  0 }, {     75,  -19,    0, 22,  0,  0 }, {     76,  -20,    0, 22,  0,  0 },
        {     76,  -21,    0, 22,  0,  0 }, {     77,  -22,    0, 22,  0,  0 }, {     77,  -23,    0, 22,  0,  0 }, {     78,  -24,    0, 22,  0,  0 }, {     78,  -25,    0, 22,  0,  0 },
        {     79,  -26,    0, 22,  0,  0 }, {     79,  -27,    0, 22,  0,  0 }, {     80,  -28,    0, 22,  0,  0 }, {     80,  -29,    0, 22,  0,  0 }, {     80,  -30,    0, 22,  0,  0 },
        {     81,  -31,    0, 23,  0,  0 }, {     81,  -32,    0, 23,  0,  0 }, {     82,  -33,    0, 23,  0,  0 }, {     82,  -34,    0, 23,  0,  0 }, {     82,  -35,    0, 23,  0,  0 },
        {     83,  -36,    0, 23,  0,  0 }, {     83,  -37,    0, 23,  0,  0 }, {     83,  -38,    0, 23,  0,  0 }, {     84,  -39,    0, 23,  0,  0 }, {     84,  -40,    0, 23,  0,  0 },
        {     84,  -41,    0, 23,  0,  0 }, {     84,  -42,    0, 23,  0,  0 }, {     85,  -43,    0, 23,  0,  0 }, {     85,  -44,    0, 23,  0,  0 }, {     85,  -45,    0, 23,  0,  0 },
        {     85,  -46,    0, 23,  0,  0 }, {     86,  -47,    0, 24,  0,  0 }, {     86,  -48,    0, 24,  0,  0 }, {     86,  -49,    0, 24,  0,  0 }, {     86,  -50,    0, 24,  0,  0 },
        {     86,  -51,    0, 24,  0,  0 }, {     86,  -52,    0, 24,  0,  0 }, {     86,  -53,    0, 24,  0,  0 }, {     87,  -54,    0, 24,  0,  0 }, {     87,  -55,    0, 24,  0,  0 },
        {     87,  -56,    0, 24,  0,  0 }, {     87,  -57,    0, 24,  0,  0 }, {     87,  -58,    0, 24,  0,  0 }, {     87,  -59,    0, 24,  0,  0 }, {     87,  -60,    0, 24,  0,  0 },
        {     87,  -61,    0, 24,  0,  0 }, {     87,  -62,    0, 24,  0,  0 }, {     87,  -63,    0, 24,  0,  0 }, {     87,  -64,    0, 25,  0,  0 }, {     86,  -64,    0, 25,  0,  0 },
        {     85,  -64,    0, 25,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles3, {
        {     23,   31,    0, 24,  0,  0 }, {     23,   30,    0, 25,  0,  0 }, {     23,   29,    0, 25,  0,  0 }, {     23,   28,    0, 25,  0,  0 }, {     23,   27,    0, 25,  0,  0 },
        {     23,   26,    0, 25,  0,  0 }, {     23,   25,    0, 25,  0,  0 }, {     23,   24,    0, 25,  0,  0 }, {     23,   23,    0, 25,  0,  0 }, {     23,   22,    0, 25,  0,  0 },
        {     22,   21,    0, 25,  0,  0 }, {     22,   20,    0, 25,  0,  0 }, {     22,   19,    0, 25,  0,  0 }, {     22,   18,    0, 25,  0,  0 }, {     22,   17,    0, 25,  0,  0 },
        {     22,   16,    0, 25,  0,  0 }, {     22,   15,    0, 25,  0,  0 }, {     21,   14,    0, 26,  0,  0 }, {     21,   13,    0, 26,  0,  0 }, {     21,   12,    0, 26,  0,  0 },
        {     21,   11,    0, 26,  0,  0 }, {     20,   10,    0, 26,  0,  0 }, {     20,    9,    0, 26,  0,  0 }, {     20,    8,    0, 26,  0,  0 }, {     20,    7,    0, 26,  0,  0 },
        {     19,    6,    0, 26,  0,  0 }, {     19,    5,    0, 26,  0,  0 }, {     19,    4,    0, 26,  0,  0 }, {     18,    3,    0, 26,  0,  0 }, {     18,    2,    0, 26,  0,  0 },
        {     18,    1,    0, 26,  0,  0 }, {     17,    0,    0, 26,  0,  0 }, {     17,   -1,    0, 26,  0,  0 }, {     16,   -2,    0, 27,  0,  0 }, {     16,   -3,    0, 27,  0,  0 },
        {     16,   -4,    0, 27,  0,  0 }, {     15,   -5,    0, 27,  0,  0 }, {     15,   -6,    0, 27,  0,  0 }, {     14,   -7,    0, 27,  0,  0 }, {     14,   -8,    0, 27,  0,  0 },
        {     13,   -9,    0, 27,  0,  0 }, {     13,  -10,    0, 27,  0,  0 }, {     12,  -11,    0, 27,  0,  0 }, {     12,  -12,    0, 27,  0,  0 }, {     11,  -13,    0, 27,  0,  0 },
        {     10,  -14,    0, 27,  0,  0 }, {     10,  -15,    0, 27,  0,  0 }, {      9,  -16,    0, 27,  0,  0 }, {      8,  -17,    0, 28,  0,  0 }, {      8,  -18,    0, 28,  0,  0 },
        {      7,  -19,    0, 28,  0,  0 }, {      6,  -20,    0, 28,  0,  0 }, {      6,  -21,    0, 28,  0,  0 }, {      5,  -22,    0, 28,  0,  0 }, {      4,  -23,    0, 28,  0,  0 },
        {      3,  -24,    0, 28,  0,  0 }, {      2,  -25,    0, 28,  0,  0 }, {      2,  -26,    0, 28,  0,  0 }, {      1,  -27,    0, 28,  0,  0 }, {      0,  -28,    0, 28,  0,  0 },
        {     -1,  -29,    0, 28,  0,  0 }, {     -2,  -30,    0, 28,  0,  0 }, {     -3,  -31,    0, 29,  0,  0 }, {     -4,  -32,    0, 29,  0,  0 }, {     -5,  -33,    0, 29,  0,  0 },
        {     -6,  -34,    0, 29,  0,  0 }, {     -7,  -34,    0, 29,  0,  0 }, {     -8,  -35,    0, 29,  0,  0 }, {     -9,  -36,    0, 29,  0,  0 }, {    -10,  -37,    0, 29,  0,  0 },
        {    -11,  -38,    0, 29,  0,  0 }, {    -12,  -38,    0, 29,  0,  0 }, {    -13,  -39,    0, 29,  0,  0 }, {    -14,  -40,    0, 29,  0,  0 }, {    -15,  -40,    0, 29,  0,  0 },
        {    -16,  -41,    0, 30,  0,  0 }, {    -17,  -42,    0, 30,  0,  0 }, {    -18,  -42,    0, 30,  0,  0 }, {    -19,  -43,    0, 30,  0,  0 }, {    -20,  -44,    0, 30,  0,  0 },
        {    -21,  -44,    0, 30,  0,  0 }, {    -22,  -45,    0, 30,  0,  0 }, {    -23,  -45,    0, 30,  0,  0 }, {    -24,  -46,    0, 30,  0,  0 }, {    -25,  -46,    0, 30,  0,  0 },
        {    -26,  -47,    0, 30,  0,  0 }, {    -27,  -47,    0, 30,  0,  0 }, {    -28,  -48,    0, 30,  0,  0 }, {    -29,  -48,    0, 30,  0,  0 }, {    -30,  -48,    0, 30,  0,  0 },
        {    -31,  -49,    0, 31,  0,  0 }, {    -32,  -49,    0, 31,  0,  0 }, {    -33,  -50,    0, 31,  0,  0 }, {    -34,  -50,    0, 31,  0,  0 }, {    -35,  -50,    0, 31,  0,  0 },
        {    -36,  -51,    0, 31,  0,  0 }, {    -37,  -51,    0, 31,  0,  0 }, {    -38,  -51,    0, 31,  0,  0 }, {    -39,  -52,    0, 31,  0,  0 }, {    -40,  -52,    0, 31,  0,  0 },
        {    -41,  -52,    0, 31,  0,  0 }, {    -42,  -52,    0, 31,  0,  0 }, {    -43,  -53,    0, 31,  0,  0 }, {    -44,  -53,    0, 31,  0,  0 }, {    -45,  -53,    0, 31,  0,  0 },
        {    -46,  -53,    0, 31,  0,  0 }, {    -47,  -54,    0,  0,  0,  0 }, {    -48,  -54,    0,  0,  0,  0 }, {    -49,  -54,    0,  0,  0,  0 }, {    -50,  -54,    0,  0,  0,  0 },
        {    -51,  -54,    0,  0,  0,  0 }, {    -52,  -54,    0,  0,  0,  0 }, {    -53,  -54,    0,  0,  0,  0 }, {    -54,  -55,    0,  0,  0,  0 }, {    -55,  -55,    0,  0,  0,  0 },
        {    -56,  -55,    0,  0,  0,  0 }, {    -57,  -55,    0,  0,  0,  0 }, {    -58,  -55,    0,  0,  0,  0 }, {    -59,  -55,    0,  0,  0,  0 }, {    -60,  -55,    0,  0,  0,  0 },
        {    -61,  -55,    0,  0,  0,  0 }, {    -62,  -55,    0,  0,  0,  0 }, {    -63,  -55,    0,  0,  0,  0 }, {    -64,  -55,    0,  1,  0,  0 }, {    -64,  -54,    0,  1,  0,  0 },
        {    -64,  -53,    0,  1,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp0, {
        {     31,    9,    0,  0,  2,  0 }, {     30,    9,    1, 31,  2,  0 }, {     29,    9,    1, 31,  2,  0 }, {     28,    9,    2, 31,  2,  0 }, {     27,    9,    2, 31,  2,  0 },
        {     26,    9,    3, 31,  2,  0 }, {     25,    9,    4, 31,  2,  0 }, {     24,    9,    4, 31,  2,  0 }, {     23,    9,    5, 31,  2,  0 }, {     22,    8,    5, 31,  2,  0 },
        {     21,    8,    6, 31,  2,  0 }, {     20,    8,    7, 31,  2,  0 }, {     19,    8,    7, 31,  2,  0 }, {     18,    8,    8, 31,  2,  0 }, {     17,    8,    9, 31,  2,  0 },
        {     16,    7,    9, 30,  2,  0 }, {     15,    7,   10, 30,  2,  0 }, {     14,    7,   10, 30,  2,  0 }, {     13,    7,   11, 30,  2,  0 }, {     12,    6,   12, 30,  2,  0 },
        {     11,    6,   12, 30,  2,  0 }, {     10,    6,   13, 30,  2,  0 }, {      9,    6,   13, 30,  2,  0 }, {      8,    5,   14, 30,  2,  0 }, {      7,    5,   15, 30,  2,  0 },
        {      6,    5,   15, 30,  2,  0 }, {      5,    4,   16, 30,  2,  0 }, {      4,    4,   16, 30,  2,  0 }, {      3,    3,   17, 29,  2,  0 }, {      2,    3,   18, 29,  2,  0 },
        {      1,    3,   18, 29,  2,  0 }, {      0,    2,   19, 29,  2,  0 }, {     -1,    2,   20, 29,  2,  0 }, {     -2,    1,   20, 29,  2,  0 }, {     -3,    1,   21, 29,  2,  0 },
        {     -4,    0,   21, 29,  2,  0 }, {     -5,   -1,   22, 29,  2,  0 }, {     -6,   -1,   23, 29,  2,  0 }, {     -7,   -2,   23, 29,  2,  0 }, {     -8,   -2,   24, 29,  2,  0 },
        {     -9,   -3,   24, 29,  2,  0 }, {    -10,   -4,   25, 28,  2,  0 }, {    -11,   -4,   26, 28,  2,  0 }, {    -12,   -5,   26, 28,  2,  0 }, {    -13,   -6,   27, 28,  2,  0 },
        {    -14,   -7,   27, 28,  2,  0 }, {    -15,   -7,   28, 28,  2,  0 }, {    -16,   -8,   29, 28,  2,  0 }, {    -17,   -9,   29, 28,  2,  0 }, {    -18,  -10,   30, 28,  2,  0 },
        {    -19,  -11,   30, 28,  2,  0 }, {    -20,  -12,   31, 28,  2,  0 }, {    -21,  -13,   32, 27,  2,  0 }, {    -22,  -14,   32, 27,  2,  0 }, {    -23,  -15,   33, 27,  2,  0 },
        {    -24,  -16,   34, 27,  2,  0 }, {    -25,  -17,   34, 27,  2,  0 }, {    -25,  -18,   35, 27,  2,  0 }, {    -26,  -19,   35, 27,  2,  0 }, {    -27,  -20,   36, 27,  2,  0 },
        {    -28,  -21,   37, 27,  2,  0 }, {    -28,  -22,   37, 27,  2,  0 }, {    -29,  -23,   38, 26,  2,  0 }, {    -30,  -24,   38, 26,  2,  0 }, {    -30,  -25,   39, 26,  2,  0 },
        {    -31,  -26,   40, 26,  2,  0 }, {    -31,  -27,   40, 26,  2,  0 }, {    -32,  -28,   41, 26,  2,  0 }, {    -33,  -29,   41, 26,  2,  0 }, {    -33,  -30,   42, 26,  2,  0 },
        {    -34,  -31,   43, 26,  2,  0 }, {    -34,  -32,   43, 26,  2,  0 }, {    -35,  -33,   44, 26,  2,  0 }, {    -35,  -34,   44, 26,  2,  0 }, {    -35,  -35,   45, 26,  2,  0 },
        {    -36,  -36,   46, 25,  2,  0 }, {    -36,  -37,   46, 25,  2,  0 }, {    -37,  -38,   47, 25,  2,  0 }, {    -37,  -39,   48, 25,  2,  0 }, {    -37,  -40,   48, 25,  2,  0 },
        {    -38,  -41,   49, 25,  2,  0 }, {    -38,  -42,   49, 25,  2,  0 }, {    -38,  -43,   50, 25,  2,  0 }, {    -38,  -44,   51, 25,  2,  0 }, {    -39,  -45,   51, 25,  2,  0 },
        {    -39,  -46,   52, 25,  2,  0 }, {    -39,  -47,   52, 25,  2,  0 }, {    -39,  -48,   53, 25,  2,  0 }, {    -40,  -49,   54, 24,  2,  0 }, {    -40,  -50,   54, 24,  2,  0 },
        {    -40,  -51,   55, 24,  2,  0 }, {    -40,  -52,   55, 24,  2,  0 }, {    -40,  -53,   56, 24,  2,  0 }, {    -40,  -54,   57, 24,  2,  0 }, {    -41,  -55,   57, 24,  2,  0 },
        {    -41,  -56,   58, 24,  2,  0 }, {    -41,  -57,   59, 24,  2,  0 }, {    -41,  -58,   59, 24,  2,  0 }, {    -41,  -59,   60, 24,  2,  0 }, {    -41,  -60,   60, 24,  2,  0 },
        {    -41,  -61,   61, 24,  2,  0 }, {    -41,  -62,   62, 24,  2,  0 }, {    -41,  -63,   62, 24,  2,  0 }, {    -41,  -64,   63, 23,  2,  0 }, {    -40,  -64,   63, 23,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp1, {
        {      9,    1,    0,  8,  2,  0 }, {      9,    2,    1,  7,  2,  0 }, {      9,    3,    1,  7,  2,  0 }, {      9,    4,    2,  7,  2,  0 }, {      9,    5,    2,  7,  2,  0 },
        {      9,    6,    3,  7,  2,  0 }, {      9,    7,    4,  7,  2,  0 }, {      9,    8,    4,  7,  2,  0 }, {      9,    9,    5,  7,  2,  0 }, {      8,   10,    5,  7,  2,  0 },
        {      8,   11,    6,  7,  2,  0 }, {      8,   12,    7,  7,  2,  0 }, {      8,   13,    7,  7,  2,  0 }, {      8,   14,    8,  7,  2,  0 }, {      8,   15,    9,  7,  2,  0 },
        {      7,   16,    9,  6,  2,  0 }, {      7,   17,   10,  6,  2,  0 }, {      7,   18,   10,  6,  2,  0 }, {      7,   19,   11,  6,  2,  0 }, {      6,   20,   12,  6,  2,  0 },
        {      6,   21,   12,  6,  2,  0 }, {      6,   22,   13,  6,  2,  0 }, {      6,   23,   13,  6,  2,  0 }, {      5,   24,   14,  6,  2,  0 }, {      5,   25,   15,  6,  2,  0 },
        {      5,   26,   15,  6,  2,  0 }, {      4,   27,   16,  6,  2,  0 }, {      4,   28,   16,  6,  2,  0 }, {      3,   29,   17,  5,  2,  0 }, {      3,   30,   18,  5,  2,  0 },
        {      3,   31,   18,  5,  2,  0 }, {      2,   32,   19,  5,  2,  0 }, {      2,   33,   20,  5,  2,  0 }, {      1,   34,   20,  5,  2,  0 }, {      1,   35,   21,  5,  2,  0 },
        {      0,   36,   21,  5,  2,  0 }, {     -1,   37,   22,  5,  2,  0 }, {     -1,   38,   23,  5,  2,  0 }, {     -2,   39,   23,  5,  2,  0 }, {     -2,   40,   24,  5,  2,  0 },
        {     -3,   41,   24,  5,  2,  0 }, {     -4,   42,   25,  4,  2,  0 }, {     -4,   43,   26,  4,  2,  0 }, {     -5,   44,   26,  4,  2,  0 }, {     -6,   45,   27,  4,  2,  0 },
        {     -7,   46,   27,  4,  2,  0 }, {     -7,   47,   28,  4,  2,  0 }, {     -8,   48,   29,  4,  2,  0 }, {     -9,   49,   29,  4,  2,  0 }, {    -10,   50,   30,  4,  2,  0 },
        {    -11,   51,   30,  4,  2,  0 }, {    -12,   52,   31,  4,  2,  0 }, {    -13,   53,   32,  3,  2,  0 }, {    -14,   54,   32,  3,  2,  0 }, {    -15,   55,   33,  3,  2,  0 },
        {    -16,   56,   34,  3,  2,  0 }, {    -17,   57,   34,  3,  2,  0 }, {    -18,   57,   35,  3,  2,  0 }, {    -19,   58,   35,  3,  2,  0 }, {    -20,   59,   36,  3,  2,  0 },
        {    -21,   60,   37,  3,  2,  0 }, {    -22,   60,   37,  3,  2,  0 }, {    -23,   61,   38,  2,  2,  0 }, {    -24,   62,   38,  2,  2,  0 }, {    -25,   62,   39,  2,  2,  0 },
        {    -26,   63,   40,  2,  2,  0 }, {    -27,   63,   40,  2,  2,  0 }, {    -28,   64,   41,  2,  2,  0 }, {    -29,   65,   41,  2,  2,  0 }, {    -30,   65,   42,  2,  2,  0 },
        {    -31,   66,   43,  2,  2,  0 }, {    -32,   66,   43,  2,  2,  0 }, {    -33,   67,   44,  2,  2,  0 }, {    -34,   67,   44,  2,  2,  0 }, {    -35,   67,   45,  2,  2,  0 },
        {    -36,   68,   46,  1,  2,  0 }, {    -37,   68,   46,  1,  2,  0 }, {    -38,   69,   47,  1,  2,  0 }, {    -39,   69,   48,  1,  2,  0 }, {    -40,   69,   48,  1,  2,  0 },
        {    -41,   70,   49,  1,  2,  0 }, {    -42,   70,   49,  1,  2,  0 }, {    -43,   70,   50,  1,  2,  0 }, {    -44,   70,   51,  1,  2,  0 }, {    -45,   71,   51,  1,  2,  0 },
        {    -46,   71,   52,  1,  2,  0 }, {    -47,   71,   52,  1,  2,  0 }, {    -48,   71,   53,  1,  2,  0 }, {    -49,   72,   54,  0,  2,  0 }, {    -50,   72,   54,  0,  2,  0 },
        {    -51,   72,   55,  0,  2,  0 }, {    -52,   72,   55,  0,  2,  0 }, {    -53,   72,   56,  0,  2,  0 }, {    -54,   72,   57,  0,  2,  0 }, {    -55,   73,   57,  0,  2,  0 },
        {    -56,   73,   58,  0,  2,  0 }, {    -57,   73,   59,  0,  2,  0 }, {    -58,   73,   59,  0,  2,  0 }, {    -59,   73,   60,  0,  2,  0 }, {    -60,   73,   60,  0,  2,  0 },
        {    -61,   73,   61,  0,  2,  0 }, {    -62,   73,   62,  0,  2,  0 }, {    -63,   73,   62,  0,  2,  0 }, {    -64,   73,   63, 31,  2,  0 }, {    -64,   72,   63, 31,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp2, {
        {      1,   23,    0, 16,  2,  0 }, {      2,   23,    1, 15,  2,  0 }, {      3,   23,    1, 15,  2,  0 }, {      4,   23,    2, 15,  2,  0 }, {      5,   23,    2, 15,  2,  0 },
        {      6,   23,    3, 15,  2,  0 }, {      7,   23,    4, 15,  2,  0 }, {      8,   23,    4, 15,  2,  0 }, {      9,   23,    5, 15,  2,  0 }, {     10,   24,    5, 15,  2,  0 },
        {     11,   24,    6, 15,  2,  0 }, {     12,   24,    7, 15,  2,  0 }, {     13,   24,    7, 15,  2,  0 }, {     14,   24,    8, 15,  2,  0 }, {     15,   24,    9, 15,  2,  0 },
        {     16,   25,    9, 14,  2,  0 }, {     17,   25,   10, 14,  2,  0 }, {     18,   25,   10, 14,  2,  0 }, {     19,   25,   11, 14,  2,  0 }, {     20,   26,   12, 14,  2,  0 },
        {     21,   26,   12, 14,  2,  0 }, {     22,   26,   13, 14,  2,  0 }, {     23,   26,   13, 14,  2,  0 }, {     24,   27,   14, 14,  2,  0 }, {     25,   27,   15, 14,  2,  0 },
        {     26,   27,   15, 14,  2,  0 }, {     27,   28,   16, 14,  2,  0 }, {     28,   28,   16, 14,  2,  0 }, {     29,   29,   17, 13,  2,  0 }, {     30,   29,   18, 13,  2,  0 },
        {     31,   29,   18, 13,  2,  0 }, {     32,   30,   19, 13,  2,  0 }, {     33,   30,   20, 13,  2,  0 }, {     34,   31,   20, 13,  2,  0 }, {     35,   31,   21, 13,  2,  0 },
        {     36,   32,   21, 13,  2,  0 }, {     37,   33,   22, 13,  2,  0 }, {     38,   33,   23, 13,  2,  0 }, {     39,   34,   23, 13,  2,  0 }, {     40,   34,   24, 13,  2,  0 },
        {     41,   35,   24, 13,  2,  0 }, {     42,   36,   25, 12,  2,  0 }, {     43,   36,   26, 12,  2,  0 }, {     44,   37,   26, 12,  2,  0 }, {     45,   38,   27, 12,  2,  0 },
        {     46,   39,   27, 12,  2,  0 }, {     47,   39,   28, 12,  2,  0 }, {     48,   40,   29, 12,  2,  0 }, {     49,   41,   29, 12,  2,  0 }, {     50,   42,   30, 12,  2,  0 },
        {     51,   43,   30, 12,  2,  0 }, {     52,   44,   31, 12,  2,  0 }, {     53,   45,   32, 11,  2,  0 }, {     54,   46,   32, 11,  2,  0 }, {     55,   47,   33, 11,  2,  0 },
        {     56,   48,   34, 11,  2,  0 }, {     57,   49,   34, 11,  2,  0 }, {     57,   50,   35, 11,  2,  0 }, {     58,   51,   35, 11,  2,  0 }, {     59,   52,   36, 11,  2,  0 },
        {     60,   53,   37, 11,  2,  0 }, {     60,   54,   37, 11,  2,  0 }, {     61,   55,   38, 10,  2,  0 }, {     62,   56,   38, 10,  2,  0 }, {     62,   57,   39, 10,  2,  0 },
        {     63,   58,   40, 10,  2,  0 }, {     63,   59,   40, 10,  2,  0 }, {     64,   60,   41, 10,  2,  0 }, {     65,   61,   41, 10,  2,  0 }, {     65,   62,   42, 10,  2,  0 },
        {     66,   63,   43, 10,  2,  0 }, {     66,   64,   43, 10,  2,  0 }, {     67,   65,   44, 10,  2,  0 }, {     67,   66,   44, 10,  2,  0 }, {     67,   67,   45, 10,  2,  0 },
        {     68,   68,   46,  9,  2,  0 }, {     68,   69,   46,  9,  2,  0 }, {     69,   70,   47,  9,  2,  0 }, {     69,   71,   48,  9,  2,  0 }, {     69,   72,   48,  9,  2,  0 },
        {     70,   73,   49,  9,  2,  0 }, {     70,   74,   49,  9,  2,  0 }, {     70,   75,   50,  9,  2,  0 }, {     70,   76,   51,  9,  2,  0 }, {     71,   77,   51,  9,  2,  0 },
        {     71,   78,   52,  9,  2,  0 }, {     71,   79,   52,  9,  2,  0 }, {     71,   80,   53,  9,  2,  0 }, {     72,   81,   54,  8,  2,  0 }, {     72,   82,   54,  8,  2,  0 },
        {     72,   83,   55,  8,  2,  0 }, {     72,   84,   55,  8,  2,  0 }, {     72,   85,   56,  8,  2,  0 }, {     72,   86,   57,  8,  2,  0 }, {     73,   87,   57,  8,  2,  0 },
        {     73,   88,   58,  8,  2,  0 }, {     73,   89,   59,  8,  2,  0 }, {     73,   90,   59,  8,  2,  0 }, {     73,   91,   60,  8,  2,  0 }, {     73,   92,   60,  8,  2,  0 },
        {     73,   93,   61,  8,  2,  0 }, {     73,   94,   62,  8,  2,  0 }, {     73,   95,   62,  8,  2,  0 }, {     73,   96,   63,  7,  2,  0 }, {     72,   96,   63,  7,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp3, {
        {     23,   31,    0, 24,  2,  0 }, {     23,   30,    1, 23,  2,  0 }, {     23,   29,    1, 23,  2,  0 }, {     23,   28,    2, 23,  2,  0 }, {     23,   27,    2, 23,  2,  0 },
        {     23,   26,    3, 23,  2,  0 }, {     23,   25,    4, 23,  2,  0 }, {     23,   24,    4, 23,  2,  0 }, {     23,   23,    5, 23,  2,  0 }, {     24,   22,    5, 23,  2,  0 },
        {     24,   21,    6, 23,  2,  0 }, {     24,   20,    7, 23,  2,  0 }, {     24,   19,    7, 23,  2,  0 }, {     24,   18,    8, 23,  2,  0 }, {     24,   17,    9, 23,  2,  0 },
        {     25,   16,    9, 22,  2,  0 }, {     25,   15,   10, 22,  2,  0 }, {     25,   14,   10, 22,  2,  0 }, {     25,   13,   11, 22,  2,  0 }, {     26,   12,   12, 22,  2,  0 },
        {     26,   11,   12, 22,  2,  0 }, {     26,   10,   13, 22,  2,  0 }, {     26,    9,   13, 22,  2,  0 }, {     27,    8,   14, 22,  2,  0 }, {     27,    7,   15, 22,  2,  0 },
        {     27,    6,   15, 22,  2,  0 }, {     28,    5,   16, 22,  2,  0 }, {     28,    4,   16, 22,  2,  0 }, {     29,    3,   17, 21,  2,  0 }, {     29,    2,   18, 21,  2,  0 },
        {     29,    1,   18, 21,  2,  0 }, {     30,    0,   19, 21,  2,  0 }, {     30,   -1,   20, 21,  2,  0 }, {     31,   -2,   20, 21,  2,  0 }, {     31,   -3,   21, 21,  2,  0 },
        {     32,   -4,   21, 21,  2,  0 }, {     33,   -5,   22, 21,  2,  0 }, {     33,   -6,   23, 21,  2,  0 }, {     34,   -7,   23, 21,  2,  0 }, {     34,   -8,   24, 21,  2,  0 },
        {     35,   -9,   24, 21,  2,  0 }, {     36,  -10,   25, 20,  2,  0 }, {     36,  -11,   26, 20,  2,  0 }, {     37,  -12,   26, 20,  2,  0 }, {     38,  -13,   27, 20,  2,  0 },
        {     39,  -14,   27, 20,  2,  0 }, {     39,  -15,   28, 20,  2,  0 }, {     40,  -16,   29, 20,  2,  0 }, {     41,  -17,   29, 20,  2,  0 }, {     42,  -18,   30, 20,  2,  0 },
        {     43,  -19,   30, 20,  2,  0 }, {     44,  -20,   31, 20,  2,  0 }, {     45,  -21,   32, 19,  2,  0 }, {     46,  -22,   32, 19,  2,  0 }, {     47,  -23,   33, 19,  2,  0 },
        {     48,  -24,   34, 19,  2,  0 }, {     49,  -25,   34, 19,  2,  0 }, {     50,  -25,   35, 19,  2,  0 }, {     51,  -26,   35, 19,  2,  0 }, {     52,  -27,   36, 19,  2,  0 },
        {     53,  -28,   37, 19,  2,  0 }, {     54,  -28,   37, 19,  2,  0 }, {     55,  -29,   38, 18,  2,  0 }, {     56,  -30,   38, 18,  2,  0 }, {     57,  -30,   39, 18,  2,  0 },
        {     58,  -31,   40, 18,  2,  0 }, {     59,  -31,   40, 18,  2,  0 }, {     60,  -32,   41, 18,  2,  0 }, {     61,  -33,   41, 18,  2,  0 }, {     62,  -33,   42, 18,  2,  0 },
        {     63,  -34,   43, 18,  2,  0 }, {     64,  -34,   43, 18,  2,  0 }, {     65,  -35,   44, 18,  2,  0 }, {     66,  -35,   44, 18,  2,  0 }, {     67,  -35,   45, 18,  2,  0 },
        {     68,  -36,   46, 17,  2,  0 }, {     69,  -36,   46, 17,  2,  0 }, {     70,  -37,   47, 17,  2,  0 }, {     71,  -37,   48, 17,  2,  0 }, {     72,  -37,   48, 17,  2,  0 },
        {     73,  -38,   49, 17,  2,  0 }, {     74,  -38,   49, 17,  2,  0 }, {     75,  -38,   50, 17,  2,  0 }, {     76,  -38,   51, 17,  2,  0 }, {     77,  -39,   51, 17,  2,  0 },
        {     78,  -39,   52, 17,  2,  0 }, {     79,  -39,   52, 17,  2,  0 }, {     80,  -39,   53, 17,  2,  0 }, {     81,  -40,   54, 16,  2,  0 }, {     82,  -40,   54, 16,  2,  0 },
        {     83,  -40,   55, 16,  2,  0 }, {     84,  -40,   55, 16,  2,  0 }, {     85,  -40,   56, 16,  2,  0 }, {     86,  -40,   57, 16,  2,  0 }, {     87,  -41,   57, 16,  2,  0 },
        {     88,  -41,   58, 16,  2,  0 }, {     89,  -41,   59, 16,  2,  0 }, {     90,  -41,   59, 16,  2,  0 }, {     91,  -41,   60, 16,  2,  0 }, {     92,  -41,   60, 16,  2,  0 },
        {     93,  -41,   61, 16,  2,  0 }, {     94,  -41,   62, 16,  2,  0 }, {     95,  -41,   62, 16,  2,  0 }, {     96,  -41,   63, 15,  2,  0 }, {     96,  -40,   63, 15,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegUp0, {
        {     31,    9,    0,  0,  2,  0 }, {     30,    9,    1,  1,  2,  0 }, {     29,    9,    1,  1,  2,  0 }, {     28,    9,    2,  1,  2,  0 }, {     27,    9,    2,  1,  2,  0 },
        {     26,    9,    3,  1,  2,  0 }, {     25,    9,    3,  1,  2,  0 }, {     24,    9,    4,  1,  2,  0 }, {     23,    9,    4,  1,  2,  0 }, {     22,    9,    5,  1,  2,  0 },
        {     21,   10,    5,  1,  2,  0 }, {     20,   10,    6,  1,  2,  0 }, {     19,   10,    6,  1,  2,  0 }, {     18,   10,    7,  1,  2,  0 }, {     17,   10,    7,  1,  2,  0 },
        {     16,   10,    8,  1,  2,  0 }, {     15,   10,    8,  1,  2,  0 }, {     14,   11,    9,  2,  2,  0 }, {     13,   11,    9,  2,  2,  0 }, {     12,   11,   10,  2,  2,  0 },
        {     11,   11,   10,  2,  2,  0 }, {     10,   12,   11,  2,  2,  0 }, {      9,   12,   11,  2,  2,  0 }, {      8,   12,   12,  2,  2,  0 }, {      7,   12,   12,  2,  2,  0 },
        {      6,   13,   13,  2,  2,  0 }, {      5,   13,   13,  2,  2,  0 }, {      4,   13,   14,  2,  2,  0 }, {      3,   14,   14,  2,  2,  0 }, {      2,   14,   15,  2,  2,  0 },
        {      1,   14,   15,  2,  2,  0 }, {      0,   15,   16,  2,  2,  0 }, {     -1,   15,   16,  2,  2,  0 }, {     -2,   16,   17,  3,  2,  0 }, {     -3,   16,   17,  3,  2,  0 },
        {     -4,   16,   18,  3,  2,  0 }, {     -5,   17,   18,  3,  2,  0 }, {     -6,   17,   19,  3,  2,  0 }, {     -7,   18,   19,  3,  2,  0 }, {     -8,   18,   20,  3,  2,  0 },
        {     -9,   19,   20,  3,  2,  0 }, {    -10,   19,   21,  3,  2,  0 }, {    -11,   20,   21,  3,  2,  0 }, {    -12,   20,   22,  3,  2,  0 }, {    -13,   21,   22,  3,  2,  0 },
        {    -14,   22,   23,  3,  2,  0 }, {    -15,   22,   23,  3,  2,  0 }, {    -16,   23,   24,  3,  2,  0 }, {    -17,   24,   24,  4,  2,  0 }, {    -18,   24,   25,  4,  2,  0 },
        {    -19,   25,   25,  4,  2,  0 }, {    -20,   26,   26,  4,  2,  0 }, {    -21,   26,   26,  4,  2,  0 }, {    -22,   27,   27,  4,  2,  0 }, {    -23,   28,   27,  4,  2,  0 },
        {    -24,   29,   28,  4,  2,  0 }, {    -25,   30,   28,  4,  2,  0 }, {    -26,   30,   29,  4,  2,  0 }, {    -27,   31,   29,  4,  2,  0 }, {    -28,   32,   30,  4,  2,  0 },
        {    -29,   33,   30,  4,  2,  0 }, {    -30,   34,   31,  4,  2,  0 }, {    -31,   35,   31,  5,  2,  0 }, {    -32,   36,   32,  5,  2,  0 }, {    -33,   37,   33,  5,  2,  0 },
        {    -34,   38,   33,  5,  2,  0 }, {    -34,   39,   34,  5,  2,  0 }, {    -35,   40,   34,  5,  2,  0 }, {    -36,   41,   35,  5,  2,  0 }, {    -37,   42,   35,  5,  2,  0 },
        {    -38,   43,   36,  5,  2,  0 }, {    -38,   44,   36,  5,  2,  0 }, {    -39,   45,   37,  5,  2,  0 }, {    -40,   46,   37,  5,  2,  0 }, {    -40,   47,   38,  5,  2,  0 },
        {    -41,   48,   38,  6,  2,  0 }, {    -42,   49,   39,  6,  2,  0 }, {    -42,   50,   39,  6,  2,  0 }, {    -43,   51,   40,  6,  2,  0 }, {    -44,   52,   40,  6,  2,  0 },
        {    -44,   53,   41,  6,  2,  0 }, {    -45,   54,   41,  6,  2,  0 }, {    -45,   55,   42,  6,  2,  0 }, {    -46,   56,   42,  6,  2,  0 }, {    -46,   57,   43,  6,  2,  0 },
        {    -47,   58,   43,  6,  2,  0 }, {    -47,   59,   44,  6,  2,  0 }, {    -48,   60,   44,  6,  2,  0 }, {    -48,   61,   45,  6,  2,  0 }, {    -48,   62,   45,  6,  2,  0 },
        {    -49,   63,   46,  7,  2,  0 }, {    -49,   64,   46,  7,  2,  0 }, {    -50,   65,   47,  7,  2,  0 }, {    -50,   66,   47,  7,  2,  0 }, {    -50,   67,   48,  7,  2,  0 },
        {    -51,   68,   48,  7,  2,  0 }, {    -51,   69,   49,  7,  2,  0 }, {    -51,   70,   49,  7,  2,  0 }, {    -52,   71,   50,  7,  2,  0 }, {    -52,   72,   50,  7,  2,  0 },
        {    -52,   73,   51,  7,  2,  0 }, {    -52,   74,   51,  7,  2,  0 }, {    -53,   75,   52,  7,  2,  0 }, {    -53,   76,   52,  7,  2,  0 }, {    -53,   77,   53,  7,  2,  0 },
        {    -53,   78,   53,  7,  2,  0 }, {    -54,   79,   54,  8,  2,  0 }, {    -54,   80,   54,  8,  2,  0 }, {    -54,   81,   55,  8,  2,  0 }, {    -54,   82,   55,  8,  2,  0 },
        {    -54,   83,   56,  8,  2,  0 }, {    -54,   84,   56,  8,  2,  0 }, {    -54,   85,   57,  8,  2,  0 }, {    -55,   86,   57,  8,  2,  0 }, {    -55,   87,   58,  8,  2,  0 },
        {    -55,   88,   58,  8,  2,  0 }, {    -55,   89,   59,  8,  2,  0 }, {    -55,   90,   59,  8,  2,  0 }, {    -55,   91,   60,  8,  2,  0 }, {    -55,   92,   60,  8,  2,  0 },
        {    -55,   93,   61,  8,  2,  0 }, {    -55,   94,   61,  8,  2,  0 }, {    -55,   95,   62,  8,  2,  0 }, {    -55,   96,   62,  9,  2,  0 }, {    -54,   96,   63,  9,  2,  0 },
        {    -53,   96,   63,  9,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegUp1, {
        {      9,    1,    0,  8,  2,  0 }, {      9,    2,    1,  9,  2,  0 }, {      9,    3,    1,  9,  2,  0 }, {      9,    4,    2,  9,  2,  0 }, {      9,    5,    2,  9,  2,  0 },
        {      9,    6,    3,  9,  2,  0 }, {      9,    7,    3,  9,  2,  0 }, {      9,    8,    4,  9,  2,  0 }, {      9,    9,    4,  9,  2,  0 }, {      9,   10,    5,  9,  2,  0 },
        {     10,   11,    5,  9,  2,  0 }, {     10,   12,    6,  9,  2,  0 }, {     10,   13,    6,  9,  2,  0 }, {     10,   14,    7,  9,  2,  0 }, {     10,   15,    7,  9,  2,  0 },
        {     10,   16,    8,  9,  2,  0 }, {     10,   17,    8,  9,  2,  0 }, {     11,   18,    9, 10,  2,  0 }, {     11,   19,    9, 10,  2,  0 }, {     11,   20,   10, 10,  2,  0 },
        {     11,   21,   10, 10,  2,  0 }, {     12,   22,   11, 10,  2,  0 }, {     12,   23,   11, 10,  2,  0 }, {     12,   24,   12, 10,  2,  0 }, {     12,   25,   12, 10,  2,  0 },
        {     13,   26,   13, 10,  2,  0 }, {     13,   27,   13, 10,  2,  0 }, {     13,   28,   14, 10,  2,  0 }, {     14,   29,   14, 10,  2,  0 }, {     14,   30,   15, 10,  2,  0 },
        {     14,   31,   15, 10,  2,  0 }, {     15,   32,   16, 10,  2,  0 }, {     15,   33,   16, 10,  2,  0 }, {     16,   34,   17, 11,  2,  0 }, {     16,   35,   17, 11,  2,  0 },
        {     16,   36,   18, 11,  2,  0 }, {     17,   37,   18, 11,  2,  0 }, {     17,   38,   19, 11,  2,  0 }, {     18,   39,   19, 11,  2,  0 }, {     18,   40,   20, 11,  2,  0 },
        {     19,   41,   20, 11,  2,  0 }, {     19,   42,   21, 11,  2,  0 }, {     20,   43,   21, 11,  2,  0 }, {     20,   44,   22, 11,  2,  0 }, {     21,   45,   22, 11,  2,  0 },
        {     22,   46,   23, 11,  2,  0 }, {     22,   47,   23, 11,  2,  0 }, {     23,   48,   24, 11,  2,  0 }, {     24,   49,   24, 12,  2,  0 }, {     24,   50,   25, 12,  2,  0 },
        {     25,   51,   25, 12,  2,  0 }, {     26,   52,   26, 12,  2,  0 }, {     26,   53,   26, 12,  2,  0 }, {     27,   54,   27, 12,  2,  0 }, {     28,   55,   27, 12,  2,  0 },
        {     29,   56,   28, 12,  2,  0 }, {     30,   57,   28, 12,  2,  0 }, {     30,   58,   29, 12,  2,  0 }, {     31,   59,   29, 12,  2,  0 }, {     32,   60,   30, 12,  2,  0 },
        {     33,   61,   30, 12,  2,  0 }, {     34,   62,   31, 12,  2,  0 }, {     35,   63,   31, 13,  2,  0 }, {     36,   64,   32, 13,  2,  0 }, {     37,   65,   33, 13,  2,  0 },
        {     38,   66,   33, 13,  2,  0 }, {     39,   66,   34, 13,  2,  0 }, {     40,   67,   34, 13,  2,  0 }, {     41,   68,   35, 13,  2,  0 }, {     42,   69,   35, 13,  2,  0 },
        {     43,   70,   36, 13,  2,  0 }, {     44,   70,   36, 13,  2,  0 }, {     45,   71,   37, 13,  2,  0 }, {     46,   72,   37, 13,  2,  0 }, {     47,   72,   38, 13,  2,  0 },
        {     48,   73,   38, 14,  2,  0 }, {     49,   74,   39, 14,  2,  0 }, {     50,   74,   39, 14,  2,  0 }, {     51,   75,   40, 14,  2,  0 }, {     52,   76,   40, 14,  2,  0 },
        {     53,   76,   41, 14,  2,  0 }, {     54,   77,   41, 14,  2,  0 }, {     55,   77,   42, 14,  2,  0 }, {     56,   78,   42, 14,  2,  0 }, {     57,   78,   43, 14,  2,  0 },
        {     58,   79,   43, 14,  2,  0 }, {     59,   79,   44, 14,  2,  0 }, {     60,   80,   44, 14,  2,  0 }, {     61,   80,   45, 14,  2,  0 }, {     62,   80,   45, 14,  2,  0 },
        {     63,   81,   46, 15,  2,  0 }, {     64,   81,   46, 15,  2,  0 }, {     65,   82,   47, 15,  2,  0 }, {     66,   82,   47, 15,  2,  0 }, {     67,   82,   48, 15,  2,  0 },
        {     68,   83,   48, 15,  2,  0 }, {     69,   83,   49, 15,  2,  0 }, {     70,   83,   49, 15,  2,  0 }, {     71,   84,   50, 15,  2,  0 }, {     72,   84,   50, 15,  2,  0 },
        {     73,   84,   51, 15,  2,  0 }, {     74,   84,   51, 15,  2,  0 }, {     75,   85,   52, 15,  2,  0 }, {     76,   85,   52, 15,  2,  0 }, {     77,   85,   53, 15,  2,  0 },
        {     78,   85,   53, 15,  2,  0 }, {     79,   86,   54, 16,  2,  0 }, {     80,   86,   54, 16,  2,  0 }, {     81,   86,   55, 16,  2,  0 }, {     82,   86,   55, 16,  2,  0 },
        {     83,   86,   56, 16,  2,  0 }, {     84,   86,   56, 16,  2,  0 }, {     85,   86,   57, 16,  2,  0 }, {     86,   87,   57, 16,  2,  0 }, {     87,   87,   58, 16,  2,  0 },
        {     88,   87,   58, 16,  2,  0 }, {     89,   87,   59, 16,  2,  0 }, {     90,   87,   59, 16,  2,  0 }, {     91,   87,   60, 16,  2,  0 }, {     92,   87,   60, 16,  2,  0 },
        {     93,   87,   61, 16,  2,  0 }, {     94,   87,   61, 16,  2,  0 }, {     95,   87,   62, 16,  2,  0 }, {     96,   87,   62, 17,  2,  0 }, {     96,   86,   63, 17,  2,  0 },
        {     96,   85,   63, 17,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegUp2, {
        {      1,   23,    0, 16,  2,  0 }, {      2,   23,    1, 17,  2,  0 }, {      3,   23,    1, 17,  2,  0 }, {      4,   23,    2, 17,  2,  0 }, {      5,   23,    2, 17,  2,  0 },
        {      6,   23,    3, 17,  2,  0 }, {      7,   23,    3, 17,  2,  0 }, {      8,   23,    4, 17,  2,  0 }, {      9,   23,    4, 17,  2,  0 }, {     10,   23,    5, 17,  2,  0 },
        {     11,   22,    5, 17,  2,  0 }, {     12,   22,    6, 17,  2,  0 }, {     13,   22,    6, 17,  2,  0 }, {     14,   22,    7, 17,  2,  0 }, {     15,   22,    7, 17,  2,  0 },
        {     16,   22,    8, 17,  2,  0 }, {     17,   22,    8, 17,  2,  0 }, {     18,   21,    9, 18,  2,  0 }, {     19,   21,    9, 18,  2,  0 }, {     20,   21,   10, 18,  2,  0 },
        {     21,   21,   10, 18,  2,  0 }, {     22,   20,   11, 18,  2,  0 }, {     23,   20,   11, 18,  2,  0 }, {     24,   20,   12, 18,  2,  0 }, {     25,   20,   12, 18,  2,  0 },
        {     26,   19,   13, 18,  2,  0 }, {     27,   19,   13, 18,  2,  0 }, {     28,   19,   14, 18,  2,  0 }, {     29,   18,   14, 18,  2,  0 }, {     30,   18,   15, 18,  2,  0 },
        {     31,   18,   15, 18,  2,  0 }, {     32,   17,   16, 18,  2,  0 }, {     33,   17,   16, 18,  2,  0 }, {     34,   16,   17, 19,  2,  0 }, {     35,   16,   17, 19,  2,  0 },
        {     36,   16,   18, 19,  2,  0 }, {     37,   15,   18, 19,  2,  0 }, {     38,   15,   19, 19,  2,  0 }, {     39,   14,   19, 19,  2,  0 }, {     40,   14,   20, 19,  2,  0 },
        {     41,   13,   20, 19,  2,  0 }, {     42,   13,   21, 19,  2,  0 }, {     43,   12,   21, 19,  2,  0 }, {     44,   12,   22, 19,  2,  0 }, {     45,   11,   22, 19,  2,  0 },
        {     46,   10,   23, 19,  2,  0 }, {     47,   10,   23, 19,  2,  0 }, {     48,    9,   24, 19,  2,  0 }, {     49,    8,   24, 20,  2,  0 }, {     50,    8,   25, 20,  2,  0 },
        {     51,    7,   25, 20,  2,  0 }, {     52,    6,   26, 20,  2,  0 }, {     53,    6,   26, 20,  2,  0 }, {     54,    5,   27, 20,  2,  0 }, {     55,    4,   27, 20,  2,  0 },
        {     56,    3,   28, 20,  2,  0 }, {     57,    2,   28, 20,  2,  0 }, {     58,    2,   29, 20,  2,  0 }, {     59,    1,   29, 20,  2,  0 }, {     60,    0,   30, 20,  2,  0 },
        {     61,   -1,   30, 20,  2,  0 }, {     62,   -2,   31, 20,  2,  0 }, {     63,   -3,   31, 21,  2,  0 }, {     64,   -4,   32, 21,  2,  0 }, {     65,   -5,   33, 21,  2,  0 },
        {     66,   -6,   33, 21,  2,  0 }, {     66,   -7,   34, 21,  2,  0 }, {     67,   -8,   34, 21,  2,  0 }, {     68,   -9,   35, 21,  2,  0 }, {     69,  -10,   35, 21,  2,  0 },
        {     70,  -11,   36, 21,  2,  0 }, {     70,  -12,   36, 21,  2,  0 }, {     71,  -13,   37, 21,  2,  0 }, {     72,  -14,   37, 21,  2,  0 }, {     72,  -15,   38, 21,  2,  0 },
        {     73,  -16,   38, 22,  2,  0 }, {     74,  -17,   39, 22,  2,  0 }, {     74,  -18,   39, 22,  2,  0 }, {     75,  -19,   40, 22,  2,  0 }, {     76,  -20,   40, 22,  2,  0 },
        {     76,  -21,   41, 22,  2,  0 }, {     77,  -22,   41, 22,  2,  0 }, {     77,  -23,   42, 22,  2,  0 }, {     78,  -24,   42, 22,  2,  0 }, {     78,  -25,   43, 22,  2,  0 },
        {     79,  -26,   43, 22,  2,  0 }, {     79,  -27,   44, 22,  2,  0 }, {     80,  -28,   44, 22,  2,  0 }, {     80,  -29,   45, 22,  2,  0 }, {     80,  -30,   45, 22,  2,  0 },
        {     81,  -31,   46, 23,  2,  0 }, {     81,  -32,   46, 23,  2,  0 }, {     82,  -33,   47, 23,  2,  0 }, {     82,  -34,   47, 23,  2,  0 }, {     82,  -35,   48, 23,  2,  0 },
        {     83,  -36,   48, 23,  2,  0 }, {     83,  -37,   49, 23,  2,  0 }, {     83,  -38,   49, 23,  2,  0 }, {     84,  -39,   50, 23,  2,  0 }, {     84,  -40,   50, 23,  2,  0 },
        {     84,  -41,   51, 23,  2,  0 }, {     84,  -42,   51, 23,  2,  0 }, {     85,  -43,   52, 23,  2,  0 }, {     85,  -44,   52, 23,  2,  0 }, {     85,  -45,   53, 23,  2,  0 },
        {     85,  -46,   53, 23,  2,  0 }, {     86,  -47,   54, 24,  2,  0 }, {     86,  -48,   54, 24,  2,  0 }, {     86,  -49,   55, 24,  2,  0 }, {     86,  -50,   55, 24,  2,  0 },
        {     86,  -51,   56, 24,  2,  0 }, {     86,  -52,   56, 24,  2,  0 }, {     86,  -53,   57, 24,  2,  0 }, {     87,  -54,   57, 24,  2,  0 }, {     87,  -55,   58, 24,  2,  0 },
        {     87,  -56,   58, 24,  2,  0 }, {     87,  -57,   59, 24,  2,  0 }, {     87,  -58,   59, 24,  2,  0 }, {     87,  -59,   60, 24,  2,  0 }, {     87,  -60,   60, 24,  2,  0 },
        {     87,  -61,   61, 24,  2,  0 }, {     87,  -62,   61, 24,  2,  0 }, {     87,  -63,   62, 24,  2,  0 }, {     87,  -64,   62, 25,  2,  0 }, {     86,  -64,   63, 25,  2,  0 },
        {     85,  -64,   63, 25,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegUp3, {
        {     23,   31,    0, 24,  2,  0 }, {     23,   30,    1, 25,  2,  0 }, {     23,   29,    1, 25,  2,  0 }, {     23,   28,    2, 25,  2,  0 }, {     23,   27,    2, 25,  2,  0 },
        {     23,   26,    3, 25,  2,  0 }, {     23,   25,    3, 25,  2,  0 }, {     23,   24,    4, 25,  2,  0 }, {     23,   23,    4, 25,  2,  0 }, {     23,   22,    5, 25,  2,  0 },
        {     22,   21,    5, 25,  2,  0 }, {     22,   20,    6, 25,  2,  0 }, {     22,   19,    6, 25,  2,  0 }, {     22,   18,    7, 25,  2,  0 }, {     22,   17,    7, 25,  2,  0 },
        {     22,   16,    8, 25,  2,  0 }, {     22,   15,    8, 25,  2,  0 }, {     21,   14,    9, 26,  2,  0 }, {     21,   13,    9, 26,  2,  0 }, {     21,   12,   10, 26,  2,  0 },
        {     21,   11,   10, 26,  2,  0 }, {     20,   10,   11, 26,  2,  0 }, {     20,    9,   11, 26,  2,  0 }, {     20,    8,   12, 26,  2,  0 }, {     20,    7,   12, 26,  2,  0 },
        {     19,    6,   13, 26,  2,  0 }, {     19,    5,   13, 26,  2,  0 }, {     19,    4,   14, 26,  2,  0 }, {     18,    3,   14, 26,  2,  0 }, {     18,    2,   15, 26,  2,  0 },
        {     18,    1,   15, 26,  2,  0 }, {     17,    0,   16, 26,  2,  0 }, {     17,   -1,   16, 26,  2,  0 }, {     16,   -2,   17, 27,  2,  0 }, {     16,   -3,   17, 27,  2,  0 },
        {     16,   -4,   18, 27,  2,  0 }, {     15,   -5,   18, 27,  2,  0 }, {     15,   -6,   19, 27,  2,  0 }, {     14,   -7,   19, 27,  2,  0 }, {     14,   -8,   20, 27,  2,  0 },
        {     13,   -9,   20, 27,  2,  0 }, {     13,  -10,   21, 27,  2,  0 }, {     12,  -11,   21, 27,  2,  0 }, {     12,  -12,   22, 27,  2,  0 }, {     11,  -13,   22, 27,  2,  0 },
        {     10,  -14,   23, 27,  2,  0 }, {     10,  -15,   23, 27,  2,  0 }, {      9,  -16,   24, 27,  2,  0 }, {      8,  -17,   24, 28,  2,  0 }, {      8,  -18,   25, 28,  2,  0 },
        {      7,  -19,   25, 28,  2,  0 }, {      6,  -20,   26, 28,  2,  0 }, {      6,  -21,   26, 28,  2,  0 }, {      5,  -22,   27, 28,  2,  0 }, {      4,  -23,   27, 28,  2,  0 },
        {      3,  -24,   28, 28,  2,  0 }, {      2,  -25,   28, 28,  2,  0 }, {      2,  -26,   29, 28,  2,  0 }, {      1,  -27,   29, 28,  2,  0 }, {      0,  -28,   30, 28,  2,  0 },
        {     -1,  -29,   30, 28,  2,  0 }, {     -2,  -30,   31, 28,  2,  0 }, {     -3,  -31,   31, 29,  2,  0 }, {     -4,  -32,   32, 29,  2,  0 }, {     -5,  -33,   33, 29,  2,  0 },
        {     -6,  -34,   33, 29,  2,  0 }, {     -7,  -34,   34, 29,  2,  0 }, {     -8,  -35,   34, 29,  2,  0 }, {     -9,  -36,   35, 29,  2,  0 }, {    -10,  -37,   35, 29,  2,  0 },
        {    -11,  -38,   36, 29,  2,  0 }, {    -12,  -38,   36, 29,  2,  0 }, {    -13,  -39,   37, 29,  2,  0 }, {    -14,  -40,   37, 29,  2,  0 }, {    -15,  -40,   38, 29,  2,  0 },
        {    -16,  -41,   38, 30,  2,  0 }, {    -17,  -42,   39, 30,  2,  0 }, {    -18,  -42,   39, 30,  2,  0 }, {    -19,  -43,   40, 30,  2,  0 }, {    -20,  -44,   40, 30,  2,  0 },
        {    -21,  -44,   41, 30,  2,  0 }, {    -22,  -45,   41, 30,  2,  0 }, {    -23,  -45,   42, 30,  2,  0 }, {    -24,  -46,   42, 30,  2,  0 }, {    -25,  -46,   43, 30,  2,  0 },
        {    -26,  -47,   43, 30,  2,  0 }, {    -27,  -47,   44, 30,  2,  0 }, {    -28,  -48,   44, 30,  2,  0 }, {    -29,  -48,   45, 30,  2,  0 }, {    -30,  -48,   45, 30,  2,  0 },
        {    -31,  -49,   46, 31,  2,  0 }, {    -32,  -49,   46, 31,  2,  0 }, {    -33,  -50,   47, 31,  2,  0 }, {    -34,  -50,   47, 31,  2,  0 }, {    -35,  -50,   48, 31,  2,  0 },
        {    -36,  -51,   48, 31,  2,  0 }, {    -37,  -51,   49, 31,  2,  0 }, {    -38,  -51,   49, 31,  2,  0 }, {    -39,  -52,   50, 31,  2,  0 }, {    -40,  -52,   50, 31,  2,  0 },
        {    -41,  -52,   51, 31,  2,  0 }, {    -42,  -52,   51, 31,  2,  0 }, {    -43,  -53,   52, 31,  2,  0 }, {    -44,  -53,   52, 31,  2,  0 }, {    -45,  -53,   53, 31,  2,  0 },
        {    -46,  -53,   53, 31,  2,  0 }, {    -47,  -54,   54,  0,  2,  0 }, {    -48,  -54,   54,  0,  2,  0 }, {    -49,  -54,   55,  0,  2,  0 }, {    -50,  -54,   55,  0,  2,  0 },
        {    -51,  -54,   56,  0,  2,  0 }, {    -52,  -54,   56,  0,  2,  0 }, {    -53,  -54,   57,  0,  2,  0 }, {    -54,  -55,   57,  0,  2,  0 }, {    -55,  -55,   58,  0,  2,  0 },
        {    -56,  -55,   58,  0,  2,  0 }, {    -57,  -55,   59,  0,  2,  0 }, {    -58,  -55,   59,  0,  2,  0 }, {    -59,  -55,   60,  0,  2,  0 }, {    -60,  -55,   60,  0,  2,  0 },
        {    -61,  -55,   61,  0,  2,  0 }, {    -62,  -55,   61,  0,  2,  0 }, {    -63,  -55,   62,  0,  2,  0 }, {    -64,  -55,   62,  1,  2,  0 }, {    -64,  -54,   63,  1,  2,  0 },
        {    -64,  -53,   63,  1,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown0, {
        {     31,    9,   15,  0,  6,  0 }, {     30,    9,   14, 31,  6,  0 }, {     29,    9,   14, 31,  6,  0 }, {     28,    9,   13, 31,  6,  0 }, {     27,    9,   13, 31,  6,  0 },
        {     26,    9,   12, 31,  6,  0 }, {     25,    9,   11, 31,  6,  0 }, {     24,    9,   11, 31,  6,  0 }, {     23,    9,   10, 31,  6,  0 }, {     22,    8,   10, 31,  6,  0 },
        {     21,    8,    9, 31,  6,  0 }, {     20,    8,    8, 31,  6,  0 }, {     19,    8,    8, 31,  6,  0 }, {     18,    8,    7, 31,  6,  0 }, {     17,    8,    6, 31,  6,  0 },
        {     16,    7,    6, 30,  6,  0 }, {     15,    7,    5, 30,  6,  0 }, {     14,    7,    5, 30,  6,  0 }, {     13,    7,    4, 30,  6,  0 }, {     12,    6,    3, 30,  6,  0 },
        {     11,    6,    3, 30,  6,  0 }, {     10,    6,    2, 30,  6,  0 }, {      9,    6,    2, 30,  6,  0 }, {      8,    5,    1, 30,  6,  0 }, {      7,    5,    0, 30,  6,  0 },
        {      6,    5,    0, 30,  6,  0 }, {      5,    4,   -1, 30,  6,  0 }, {      4,    4,   -1, 30,  6,  0 }, {      3,    3,   -2, 29,  6,  0 }, {      2,    3,   -3, 29,  6,  0 },
        {      1,    3,   -3, 29,  6,  0 }, {      0,    2,   -4, 29,  6,  0 }, {     -1,    2,   -5, 29,  6,  0 }, {     -2,    1,   -5, 29,  6,  0 }, {     -3,    1,   -6, 29,  6,  0 },
        {     -4,    0,   -6, 29,  6,  0 }, {     -5,   -1,   -7, 29,  6,  0 }, {     -6,   -1,   -8, 29,  6,  0 }, {     -7,   -2,   -8, 29,  6,  0 }, {     -8,   -2,   -9, 29,  6,  0 },
        {     -9,   -3,   -9, 29,  6,  0 }, {    -10,   -4,  -10, 28,  6,  0 }, {    -11,   -4,  -11, 28,  6,  0 }, {    -12,   -5,  -11, 28,  6,  0 }, {    -13,   -6,  -12, 28,  6,  0 },
        {    -14,   -7,  -12, 28,  6,  0 }, {    -15,   -7,  -13, 28,  6,  0 }, {    -16,   -8,  -14, 28,  6,  0 }, {    -17,   -9,  -14, 28,  6,  0 }, {    -18,  -10,  -15, 28,  6,  0 },
        {    -19,  -11,  -15, 28,  6,  0 }, {    -20,  -12,  -16, 28,  6,  0 }, {    -21,  -13,  -17, 27,  6,  0 }, {    -22,  -14,  -17, 27,  6,  0 }, {    -23,  -15,  -18, 27,  6,  0 },
        {    -24,  -16,  -19, 27,  6,  0 }, {    -25,  -17,  -19, 27,  6,  0 }, {    -25,  -18,  -20, 27,  6,  0 }, {    -26,  -19,  -20, 27,  6,  0 }, {    -27,  -20,  -21, 27,  6,  0 },
        {    -28,  -21,  -22, 27,  6,  0 }, {    -28,  -22,  -22, 27,  6,  0 }, {    -29,  -23,  -23, 26,  6,  0 }, {    -30,  -24,  -23, 26,  6,  0 }, {    -30,  -25,  -24, 26,  6,  0 },
        {    -31,  -26,  -25, 26,  6,  0 }, {    -31,  -27,  -25, 26,  6,  0 }, {    -32,  -28,  -26, 26,  6,  0 }, {    -33,  -29,  -26, 26,  6,  0 }, {    -33,  -30,  -27, 26,  6,  0 },
        {    -34,  -31,  -28, 26,  6,  0 }, {    -34,  -32,  -28, 26,  6,  0 }, {    -35,  -33,  -29, 26,  6,  0 }, {    -35,  -34,  -29, 26,  6,  0 }, {    -35,  -35,  -30, 26,  6,  0 },
        {    -36,  -36,  -31, 25,  6,  0 }, {    -36,  -37,  -31, 25,  6,  0 }, {    -37,  -38,  -32, 25,  6,  0 }, {    -37,  -39,  -33, 25,  6,  0 }, {    -37,  -40,  -33, 25,  6,  0 },
        {    -38,  -41,  -34, 25,  6,  0 }, {    -38,  -42,  -34, 25,  6,  0 }, {    -38,  -43,  -35, 25,  6,  0 }, {    -38,  -44,  -36, 25,  6,  0 }, {    -39,  -45,  -36, 25,  6,  0 },
        {    -39,  -46,  -37, 25,  6,  0 }, {    -39,  -47,  -37, 25,  6,  0 }, {    -39,  -48,  -38, 25,  6,  0 }, {    -40,  -49,  -39, 24,  6,  0 }, {    -40,  -50,  -39, 24,  6,  0 },
        {    -40,  -51,  -40, 24,  6,  0 }, {    -40,  -52,  -40, 24,  6,  0 }, {    -40,  -53,  -41, 24,  6,  0 }, {    -40,  -54,  -42, 24,  6,  0 }, {    -41,  -55,  -42, 24,  6,  0 },
        {    -41,  -56,  -43, 24,  6,  0 }, {    -41,  -57,  -44, 24,  6,  0 }, {    -41,  -58,  -44, 24,  6,  0 }, {    -41,  -59,  -45, 24,  6,  0 }, {    -41,  -60,  -45, 24,  6,  0 },
        {    -41,  -61,  -46, 24,  6,  0 }, {    -41,  -62,  -47, 24,  6,  0 }, {    -41,  -63,  -47, 24,  6,  0 }, {    -41,  -64,  -48, 23,  6,  0 }, {    -40,  -64,  -48, 23,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown1, {
        {      9,    1,   15,  8,  6,  0 }, {      9,    2,   14,  7,  6,  0 }, {      9,    3,   14,  7,  6,  0 }, {      9,    4,   13,  7,  6,  0 }, {      9,    5,   13,  7,  6,  0 },
        {      9,    6,   12,  7,  6,  0 }, {      9,    7,   11,  7,  6,  0 }, {      9,    8,   11,  7,  6,  0 }, {      9,    9,   10,  7,  6,  0 }, {      8,   10,   10,  7,  6,  0 },
        {      8,   11,    9,  7,  6,  0 }, {      8,   12,    8,  7,  6,  0 }, {      8,   13,    8,  7,  6,  0 }, {      8,   14,    7,  7,  6,  0 }, {      8,   15,    6,  7,  6,  0 },
        {      7,   16,    6,  6,  6,  0 }, {      7,   17,    5,  6,  6,  0 }, {      7,   18,    5,  6,  6,  0 }, {      7,   19,    4,  6,  6,  0 }, {      6,   20,    3,  6,  6,  0 },
        {      6,   21,    3,  6,  6,  0 }, {      6,   22,    2,  6,  6,  0 }, {      6,   23,    2,  6,  6,  0 }, {      5,   24,    1,  6,  6,  0 }, {      5,   25,    0,  6,  6,  0 },
        {      5,   26,    0,  6,  6,  0 }, {      4,   27,   -1,  6,  6,  0 }, {      4,   28,   -1,  6,  6,  0 }, {      3,   29,   -2,  5,  6,  0 }, {      3,   30,   -3,  5,  6,  0 },
        {      3,   31,   -3,  5,  6,  0 }, {      2,   32,   -4,  5,  6,  0 }, {      2,   33,   -5,  5,  6,  0 }, {      1,   34,   -5,  5,  6,  0 }, {      1,   35,   -6,  5,  6,  0 },
        {      0,   36,   -6,  5,  6,  0 }, {     -1,   37,   -7,  5,  6,  0 }, {     -1,   38,   -8,  5,  6,  0 }, {     -2,   39,   -8,  5,  6,  0 }, {     -2,   40,   -9,  5,  6,  0 },
        {     -3,   41,   -9,  5,  6,  0 }, {     -4,   42,  -10,  4,  6,  0 }, {     -4,   43,  -11,  4,  6,  0 }, {     -5,   44,  -11,  4,  6,  0 }, {     -6,   45,  -12,  4,  6,  0 },
        {     -7,   46,  -12,  4,  6,  0 }, {     -7,   47,  -13,  4,  6,  0 }, {     -8,   48,  -14,  4,  6,  0 }, {     -9,   49,  -14,  4,  6,  0 }, {    -10,   50,  -15,  4,  6,  0 },
        {    -11,   51,  -15,  4,  6,  0 }, {    -12,   52,  -16,  4,  6,  0 }, {    -13,   53,  -17,  3,  6,  0 }, {    -14,   54,  -17,  3,  6,  0 }, {    -15,   55,  -18,  3,  6,  0 },
        {    -16,   56,  -19,  3,  6,  0 }, {    -17,   57,  -19,  3,  6,  0 }, {    -18,   57,  -20,  3,  6,  0 }, {    -19,   58,  -20,  3,  6,  0 }, {    -20,   59,  -21,  3,  6,  0 },
        {    -21,   60,  -22,  3,  6,  0 }, {    -22,   60,  -22,  3,  6,  0 }, {    -23,   61,  -23,  2,  6,  0 }, {    -24,   62,  -23,  2,  6,  0 }, {    -25,   62,  -24,  2,  6,  0 },
        {    -26,   63,  -25,  2,  6,  0 }, {    -27,   63,  -25,  2,  6,  0 }, {    -28,   64,  -26,  2,  6,  0 }, {    -29,   65,  -26,  2,  6,  0 }, {    -30,   65,  -27,  2,  6,  0 },
        {    -31,   66,  -28,  2,  6,  0 }, {    -32,   66,  -28,  2,  6,  0 }, {    -33,   67,  -29,  2,  6,  0 }, {    -34,   67,  -29,  2,  6,  0 }, {    -35,   67,  -30,  2,  6,  0 },
        {    -36,   68,  -31,  1,  6,  0 }, {    -37,   68,  -31,  1,  6,  0 }, {    -38,   69,  -32,  1,  6,  0 }, {    -39,   69,  -33,  1,  6,  0 }, {    -40,   69,  -33,  1,  6,  0 },
        {    -41,   70,  -34,  1,  6,  0 }, {    -42,   70,  -34,  1,  6,  0 }, {    -43,   70,  -35,  1,  6,  0 }, {    -44,   70,  -36,  1,  6,  0 }, {    -45,   71,  -36,  1,  6,  0 },
        {    -46,   71,  -37,  1,  6,  0 }, {    -47,   71,  -37,  1,  6,  0 }, {    -48,   71,  -38,  1,  6,  0 }, {    -49,   72,  -39,  0,  6,  0 }, {    -50,   72,  -39,  0,  6,  0 },
        {    -51,   72,  -40,  0,  6,  0 }, {    -52,   72,  -40,  0,  6,  0 }, {    -53,   72,  -41,  0,  6,  0 }, {    -54,   72,  -42,  0,  6,  0 }, {    -55,   73,  -42,  0,  6,  0 },
        {    -56,   73,  -43,  0,  6,  0 }, {    -57,   73,  -44,  0,  6,  0 }, {    -58,   73,  -44,  0,  6,  0 }, {    -59,   73,  -45,  0,  6,  0 }, {    -60,   73,  -45,  0,  6,  0 },
        {    -61,   73,  -46,  0,  6,  0 }, {    -62,   73,  -47,  0,  6,  0 }, {    -63,   73,  -47,  0,  6,  0 }, {    -64,   73,  -48, 31,  6,  0 }, {    -64,   72,  -48, 31,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown2, {
        {      1,   23,   15, 16,  6,  0 }, {      2,   23,   14, 15,  6,  0 }, {      3,   23,   14, 15,  6,  0 }, {      4,   23,   13, 15,  6,  0 }, {      5,   23,   13, 15,  6,  0 },
        {      6,   23,   12, 15,  6,  0 }, {      7,   23,   11, 15,  6,  0 }, {      8,   23,   11, 15,  6,  0 }, {      9,   23,   10, 15,  6,  0 }, {     10,   24,   10, 15,  6,  0 },
        {     11,   24,    9, 15,  6,  0 }, {     12,   24,    8, 15,  6,  0 }, {     13,   24,    8, 15,  6,  0 }, {     14,   24,    7, 15,  6,  0 }, {     15,   24,    6, 15,  6,  0 },
        {     16,   25,    6, 14,  6,  0 }, {     17,   25,    5, 14,  6,  0 }, {     18,   25,    5, 14,  6,  0 }, {     19,   25,    4, 14,  6,  0 }, {     20,   26,    3, 14,  6,  0 },
        {     21,   26,    3, 14,  6,  0 }, {     22,   26,    2, 14,  6,  0 }, {     23,   26,    2, 14,  6,  0 }, {     24,   27,    1, 14,  6,  0 }, {     25,   27,    0, 14,  6,  0 },
        {     26,   27,    0, 14,  6,  0 }, {     27,   28,   -1, 14,  6,  0 }, {     28,   28,   -1, 14,  6,  0 }, {     29,   29,   -2, 13,  6,  0 }, {     30,   29,   -3, 13,  6,  0 },
        {     31,   29,   -3, 13,  6,  0 }, {     32,   30,   -4, 13,  6,  0 }, {     33,   30,   -5, 13,  6,  0 }, {     34,   31,   -5, 13,  6,  0 }, {     35,   31,   -6, 13,  6,  0 },
        {     36,   32,   -6, 13,  6,  0 }, {     37,   33,   -7, 13,  6,  0 }, {     38,   33,   -8, 13,  6,  0 }, {     39,   34,   -8, 13,  6,  0 }, {     40,   34,   -9, 13,  6,  0 },
        {     41,   35,   -9, 13,  6,  0 }, {     42,   36,  -10, 12,  6,  0 }, {     43,   36,  -11, 12,  6,  0 }, {     44,   37,  -11, 12,  6,  0 }, {     45,   38,  -12, 12,  6,  0 },
        {     46,   39,  -12, 12,  6,  0 }, {     47,   39,  -13, 12,  6,  0 }, {     48,   40,  -14, 12,  6,  0 }, {     49,   41,  -14, 12,  6,  0 }, {     50,   42,  -15, 12,  6,  0 },
        {     51,   43,  -15, 12,  6,  0 }, {     52,   44,  -16, 12,  6,  0 }, {     53,   45,  -17, 11,  6,  0 }, {     54,   46,  -17, 11,  6,  0 }, {     55,   47,  -18, 11,  6,  0 },
        {     56,   48,  -19, 11,  6,  0 }, {     57,   49,  -19, 11,  6,  0 }, {     57,   50,  -20, 11,  6,  0 }, {     58,   51,  -20, 11,  6,  0 }, {     59,   52,  -21, 11,  6,  0 },
        {     60,   53,  -22, 11,  6,  0 }, {     60,   54,  -22, 11,  6,  0 }, {     61,   55,  -23, 10,  6,  0 }, {     62,   56,  -23, 10,  6,  0 }, {     62,   57,  -24, 10,  6,  0 },
        {     63,   58,  -25, 10,  6,  0 }, {     63,   59,  -25, 10,  6,  0 }, {     64,   60,  -26, 10,  6,  0 }, {     65,   61,  -26, 10,  6,  0 }, {     65,   62,  -27, 10,  6,  0 },
        {     66,   63,  -28, 10,  6,  0 }, {     66,   64,  -28, 10,  6,  0 }, {     67,   65,  -29, 10,  6,  0 }, {     67,   66,  -29, 10,  6,  0 }, {     67,   67,  -30, 10,  6,  0 },
        {     68,   68,  -31,  9,  6,  0 }, {     68,   69,  -31,  9,  6,  0 }, {     69,   70,  -32,  9,  6,  0 }, {     69,   71,  -33,  9,  6,  0 }, {     69,   72,  -33,  9,  6,  0 },
        {     70,   73,  -34,  9,  6,  0 }, {     70,   74,  -34,  9,  6,  0 }, {     70,   75,  -35,  9,  6,  0 }, {     70,   76,  -36,  9,  6,  0 }, {     71,   77,  -36,  9,  6,  0 },
        {     71,   78,  -37,  9,  6,  0 }, {     71,   79,  -37,  9,  6,  0 }, {     71,   80,  -38,  9,  6,  0 }, {     72,   81,  -39,  8,  6,  0 }, {     72,   82,  -39,  8,  6,  0 },
        {     72,   83,  -40,  8,  6,  0 }, {     72,   84,  -40,  8,  6,  0 }, {     72,   85,  -41,  8,  6,  0 }, {     72,   86,  -42,  8,  6,  0 }, {     73,   87,  -42,  8,  6,  0 },
        {     73,   88,  -43,  8,  6,  0 }, {     73,   89,  -44,  8,  6,  0 }, {     73,   90,  -44,  8,  6,  0 }, {     73,   91,  -45,  8,  6,  0 }, {     73,   92,  -45,  8,  6,  0 },
        {     73,   93,  -46,  8,  6,  0 }, {     73,   94,  -47,  8,  6,  0 }, {     73,   95,  -47,  8,  6,  0 }, {     73,   96,  -48,  7,  6,  0 }, {     72,   96,  -48,  7,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown3, {
        {     23,   31,   15, 24,  6,  0 }, {     23,   30,   14, 23,  6,  0 }, {     23,   29,   14, 23,  6,  0 }, {     23,   28,   13, 23,  6,  0 }, {     23,   27,   13, 23,  6,  0 },
        {     23,   26,   12, 23,  6,  0 }, {     23,   25,   11, 23,  6,  0 }, {     23,   24,   11, 23,  6,  0 }, {     23,   23,   10, 23,  6,  0 }, {     24,   22,   10, 23,  6,  0 },
        {     24,   21,    9, 23,  6,  0 }, {     24,   20,    8, 23,  6,  0 }, {     24,   19,    8, 23,  6,  0 }, {     24,   18,    7, 23,  6,  0 }, {     24,   17,    6, 23,  6,  0 },
        {     25,   16,    6, 22,  6,  0 }, {     25,   15,    5, 22,  6,  0 }, {     25,   14,    5, 22,  6,  0 }, {     25,   13,    4, 22,  6,  0 }, {     26,   12,    3, 22,  6,  0 },
        {     26,   11,    3, 22,  6,  0 }, {     26,   10,    2, 22,  6,  0 }, {     26,    9,    2, 22,  6,  0 }, {     27,    8,    1, 22,  6,  0 }, {     27,    7,    0, 22,  6,  0 },
        {     27,    6,    0, 22,  6,  0 }, {     28,    5,   -1, 22,  6,  0 }, {     28,    4,   -1, 22,  6,  0 }, {     29,    3,   -2, 21,  6,  0 }, {     29,    2,   -3, 21,  6,  0 },
        {     29,    1,   -3, 21,  6,  0 }, {     30,    0,   -4, 21,  6,  0 }, {     30,   -1,   -5, 21,  6,  0 }, {     31,   -2,   -5, 21,  6,  0 }, {     31,   -3,   -6, 21,  6,  0 },
        {     32,   -4,   -6, 21,  6,  0 }, {     33,   -5,   -7, 21,  6,  0 }, {     33,   -6,   -8, 21,  6,  0 }, {     34,   -7,   -8, 21,  6,  0 }, {     34,   -8,   -9, 21,  6,  0 },
        {     35,   -9,   -9, 21,  6,  0 }, {     36,  -10,  -10, 20,  6,  0 }, {     36,  -11,  -11, 20,  6,  0 }, {     37,  -12,  -11, 20,  6,  0 }, {     38,  -13,  -12, 20,  6,  0 },
        {     39,  -14,  -12, 20,  6,  0 }, {     39,  -15,  -13, 20,  6,  0 }, {     40,  -16,  -14, 20,  6,  0 }, {     41,  -17,  -14, 20,  6,  0 }, {     42,  -18,  -15, 20,  6,  0 },
        {     43,  -19,  -15, 20,  6,  0 }, {     44,  -20,  -16, 20,  6,  0 }, {     45,  -21,  -17, 19,  6,  0 }, {     46,  -22,  -17, 19,  6,  0 }, {     47,  -23,  -18, 19,  6,  0 },
        {     48,  -24,  -19, 19,  6,  0 }, {     49,  -25,  -19, 19,  6,  0 }, {     50,  -25,  -20, 19,  6,  0 }, {     51,  -26,  -20, 19,  6,  0 }, {     52,  -27,  -21, 19,  6,  0 },
        {     53,  -28,  -22, 19,  6,  0 }, {     54,  -28,  -22, 19,  6,  0 }, {     55,  -29,  -23, 18,  6,  0 }, {     56,  -30,  -23, 18,  6,  0 }, {     57,  -30,  -24, 18,  6,  0 },
        {     58,  -31,  -25, 18,  6,  0 }, {     59,  -31,  -25, 18,  6,  0 }, {     60,  -32,  -26, 18,  6,  0 }, {     61,  -33,  -26, 18,  6,  0 }, {     62,  -33,  -27, 18,  6,  0 },
        {     63,  -34,  -28, 18,  6,  0 }, {     64,  -34,  -28, 18,  6,  0 }, {     65,  -35,  -29, 18,  6,  0 }, {     66,  -35,  -29, 18,  6,  0 }, {     67,  -35,  -30, 18,  6,  0 },
        {     68,  -36,  -31, 17,  6,  0 }, {     69,  -36,  -31, 17,  6,  0 }, {     70,  -37,  -32, 17,  6,  0 }, {     71,  -37,  -33, 17,  6,  0 }, {     72,  -37,  -33, 17,  6,  0 },
        {     73,  -38,  -34, 17,  6,  0 }, {     74,  -38,  -34, 17,  6,  0 }, {     75,  -38,  -35, 17,  6,  0 }, {     76,  -38,  -36, 17,  6,  0 }, {     77,  -39,  -36, 17,  6,  0 },
        {     78,  -39,  -37, 17,  6,  0 }, {     79,  -39,  -37, 17,  6,  0 }, {     80,  -39,  -38, 17,  6,  0 }, {     81,  -40,  -39, 16,  6,  0 }, {     82,  -40,  -39, 16,  6,  0 },
        {     83,  -40,  -40, 16,  6,  0 }, {     84,  -40,  -40, 16,  6,  0 }, {     85,  -40,  -41, 16,  6,  0 }, {     86,  -40,  -42, 16,  6,  0 }, {     87,  -41,  -42, 16,  6,  0 },
        {     88,  -41,  -43, 16,  6,  0 }, {     89,  -41,  -44, 16,  6,  0 }, {     90,  -41,  -44, 16,  6,  0 }, {     91,  -41,  -45, 16,  6,  0 }, {     92,  -41,  -45, 16,  6,  0 },
        {     93,  -41,  -46, 16,  6,  0 }, {     94,  -41,  -47, 16,  6,  0 }, {     95,  -41,  -47, 16,  6,  0 }, {     96,  -41,  -48, 15,  6,  0 }, {     96,  -40,  -48, 15,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegDown0, {
        {     31,    9,   15,  0,  6,  0 }, {     30,    9,   14,  1,  6,  0 }, {     29,    9,   14,  1,  6,  0 }, {     28,    9,   13,  1,  6,  0 }, {     27,    9,   13,  1,  6,  0 },
        {     26,    9,   12,  1,  6,  0 }, {     25,    9,   12,  1,  6,  0 }, {     24,    9,   11,  1,  6,  0 }, {     23,    9,   11,  1,  6,  0 }, {     22,    9,   10,  1,  6,  0 },
        {     21,   10,   10,  1,  6,  0 }, {     20,   10,    9,  1,  6,  0 }, {     19,   10,    9,  1,  6,  0 }, {     18,   10,    8,  1,  6,  0 }, {     17,   10,    8,  1,  6,  0 },
        {     16,   10,    7,  1,  6,  0 }, {     15,   10,    7,  1,  6,  0 }, {     14,   11,    6,  2,  6,  0 }, {     13,   11,    6,  2,  6,  0 }, {     12,   11,    5,  2,  6,  0 },
        {     11,   11,    5,  2,  6,  0 }, {     10,   12,    4,  2,  6,  0 }, {      9,   12,    4,  2,  6,  0 }, {      8,   12,    3,  2,  6,  0 }, {      7,   12,    3,  2,  6,  0 },
        {      6,   13,    2,  2,  6,  0 }, {      5,   13,    2,  2,  6,  0 }, {      4,   13,    1,  2,  6,  0 }, {      3,   14,    1,  2,  6,  0 }, {      2,   14,    0,  2,  6,  0 },
        {      1,   14,    0,  2,  6,  0 }, {      0,   15,   -1,  2,  6,  0 }, {     -1,   15,   -1,  2,  6,  0 }, {     -2,   16,   -2,  3,  6,  0 }, {     -3,   16,   -2,  3,  6,  0 },
        {     -4,   16,   -3,  3,  6,  0 }, {     -5,   17,   -3,  3,  6,  0 }, {     -6,   17,   -4,  3,  6,  0 }, {     -7,   18,   -4,  3,  6,  0 }, {     -8,   18,   -5,  3,  6,  0 },
        {     -9,   19,   -5,  3,  6,  0 }, {    -10,   19,   -6,  3,  6,  0 }, {    -11,   20,   -6,  3,  6,  0 }, {    -12,   20,   -7,  3,  6,  0 }, {    -13,   21,   -7,  3,  6,  0 },
        {    -14,   22,   -8,  3,  6,  0 }, {    -15,   22,   -8,  3,  6,  0 }, {    -16,   23,   -9,  3,  6,  0 }, {    -17,   24,   -9,  4,  6,  0 }, {    -18,   24,  -10,  4,  6,  0 },
        {    -19,   25,  -10,  4,  6,  0 }, {    -20,   26,  -11,  4,  6,  0 }, {    -21,   26,  -11,  4,  6,  0 }, {    -22,   27,  -12,  4,  6,  0 }, {    -23,   28,  -12,  4,  6,  0 },
        {    -24,   29,  -13,  4,  6,  0 }, {    -25,   30,  -13,  4,  6,  0 }, {    -26,   30,  -14,  4,  6,  0 }, {    -27,   31,  -14,  4,  6,  0 }, {    -28,   32,  -15,  4,  6,  0 },
        {    -29,   33,  -15,  4,  6,  0 }, {    -30,   34,  -16,  4,  6,  0 }, {    -31,   35,  -16,  5,  6,  0 }, {    -32,   36,  -17,  5,  6,  0 }, {    -33,   37,  -18,  5,  6,  0 },
        {    -34,   38,  -18,  5,  6,  0 }, {    -34,   39,  -19,  5,  6,  0 }, {    -35,   40,  -19,  5,  6,  0 }, {    -36,   41,  -20,  5,  6,  0 }, {    -37,   42,  -20,  5,  6,  0 },
        {    -38,   43,  -21,  5,  6,  0 }, {    -38,   44,  -21,  5,  6,  0 }, {    -39,   45,  -22,  5,  6,  0 }, {    -40,   46,  -22,  5,  6,  0 }, {    -40,   47,  -23,  5,  6,  0 },
        {    -41,   48,  -23,  6,  6,  0 }, {    -42,   49,  -24,  6,  6,  0 }, {    -42,   50,  -24,  6,  6,  0 }, {    -43,   51,  -25,  6,  6,  0 }, {    -44,   52,  -25,  6,  6,  0 },
        {    -44,   53,  -26,  6,  6,  0 }, {    -45,   54,  -26,  6,  6,  0 }, {    -45,   55,  -27,  6,  6,  0 }, {    -46,   56,  -27,  6,  6,  0 }, {    -46,   57,  -28,  6,  6,  0 },
        {    -47,   58,  -28,  6,  6,  0 }, {    -47,   59,  -29,  6,  6,  0 }, {    -48,   60,  -29,  6,  6,  0 }, {    -48,   61,  -30,  6,  6,  0 }, {    -48,   62,  -30,  6,  6,  0 },
        {    -49,   63,  -31,  7,  6,  0 }, {    -49,   64,  -31,  7,  6,  0 }, {    -50,   65,  -32,  7,  6,  0 }, {    -50,   66,  -32,  7,  6,  0 }, {    -50,   67,  -33,  7,  6,  0 },
        {    -51,   68,  -33,  7,  6,  0 }, {    -51,   69,  -34,  7,  6,  0 }, {    -51,   70,  -34,  7,  6,  0 }, {    -52,   71,  -35,  7,  6,  0 }, {    -52,   72,  -35,  7,  6,  0 },
        {    -52,   73,  -36,  7,  6,  0 }, {    -52,   74,  -36,  7,  6,  0 }, {    -53,   75,  -37,  7,  6,  0 }, {    -53,   76,  -37,  7,  6,  0 }, {    -53,   77,  -38,  7,  6,  0 },
        {    -53,   78,  -38,  7,  6,  0 }, {    -54,   79,  -39,  8,  6,  0 }, {    -54,   80,  -39,  8,  6,  0 }, {    -54,   81,  -40,  8,  6,  0 }, {    -54,   82,  -40,  8,  6,  0 },
        {    -54,   83,  -41,  8,  6,  0 }, {    -54,   84,  -41,  8,  6,  0 }, {    -54,   85,  -42,  8,  6,  0 }, {    -55,   86,  -42,  8,  6,  0 }, {    -55,   87,  -43,  8,  6,  0 },
        {    -55,   88,  -43,  8,  6,  0 }, {    -55,   89,  -44,  8,  6,  0 }, {    -55,   90,  -44,  8,  6,  0 }, {    -55,   91,  -45,  8,  6,  0 }, {    -55,   92,  -45,  8,  6,  0 },
        {    -55,   93,  -46,  8,  6,  0 }, {    -55,   94,  -46,  8,  6,  0 }, {    -55,   95,  -47,  8,  6,  0 }, {    -55,   96,  -47,  9,  6,  0 }, {    -54,   96,  -48,  9,  6,  0 },
        {    -53,   96,  -48,  9,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegDown1, {
        {      9,    1,   15,  8,  6,  0 }, {      9,    2,   14,  9,  6,  0 }, {      9,    3,   14,  9,  6,  0 }, {      9,    4,   13,  9,  6,  0 }, {      9,    5,   13,  9,  6,  0 },
        {      9,    6,   12,  9,  6,  0 }, {      9,    7,   12,  9,  6,  0 }, {      9,    8,   11,  9,  6,  0 }, {      9,    9,   11,  9,  6,  0 }, {      9,   10,   10,  9,  6,  0 },
        {     10,   11,   10,  9,  6,  0 }, {     10,   12,    9,  9,  6,  0 }, {     10,   13,    9,  9,  6,  0 }, {     10,   14,    8,  9,  6,  0 }, {     10,   15,    8,  9,  6,  0 },
        {     10,   16,    7,  9,  6,  0 }, {     10,   17,    7,  9,  6,  0 }, {     11,   18,    6, 10,  6,  0 }, {     11,   19,    6, 10,  6,  0 }, {     11,   20,    5, 10,  6,  0 },
        {     11,   21,    5, 10,  6,  0 }, {     12,   22,    4, 10,  6,  0 }, {     12,   23,    4, 10,  6,  0 }, {     12,   24,    3, 10,  6,  0 }, {     12,   25,    3, 10,  6,  0 },
        {     13,   26,    2, 10,  6,  0 }, {     13,   27,    2, 10,  6,  0 }, {     13,   28,    1, 10,  6,  0 }, {     14,   29,    1, 10,  6,  0 }, {     14,   30,    0, 10,  6,  0 },
        {     14,   31,    0, 10,  6,  0 }, {     15,   32,   -1, 10,  6,  0 }, {     15,   33,   -1, 10,  6,  0 }, {     16,   34,   -2, 11,  6,  0 }, {     16,   35,   -2, 11,  6,  0 },
        {     16,   36,   -3, 11,  6,  0 }, {     17,   37,   -3, 11,  6,  0 }, {     17,   38,   -4, 11,  6,  0 }, {     18,   39,   -4, 11,  6,  0 }, {     18,   40,   -5, 11,  6,  0 },
        {     19,   41,   -5, 11,  6,  0 }, {     19,   42,   -6, 11,  6,  0 }, {     20,   43,   -6, 11,  6,  0 }, {     20,   44,   -7, 11,  6,  0 }, {     21,   45,   -7, 11,  6,  0 },
        {     22,   46,   -8, 11,  6,  0 }, {     22,   47,   -8, 11,  6,  0 }, {     23,   48,   -9, 11,  6,  0 }, {     24,   49,   -9, 12,  6,  0 }, {     24,   50,  -10, 12,  6,  0 },
        {     25,   51,  -10, 12,  6,  0 }, {     26,   52,  -11, 12,  6,  0 }, {     26,   53,  -11, 12,  6,  0 }, {     27,   54,  -12, 12,  6,  0 }, {     28,   55,  -12, 12,  6,  0 },
        {     29,   56,  -13, 12,  6,  0 }, {     30,   57,  -13, 12,  6,  0 }, {     30,   58,  -14, 12,  6,  0 }, {     31,   59,  -14, 12,  6,  0 }, {     32,   60,  -15, 12,  6,  0 },
        {     33,   61,  -15, 12,  6,  0 }, {     34,   62,  -16, 12,  6,  0 }, {     35,   63,  -16, 13,  6,  0 }, {     36,   64,  -17, 13,  6,  0 }, {     37,   65,  -18, 13,  6,  0 },
        {     38,   66,  -18, 13,  6,  0 }, {     39,   66,  -19, 13,  6,  0 }, {     40,   67,  -19, 13,  6,  0 }, {     41,   68,  -20, 13,  6,  0 }, {     42,   69,  -20, 13,  6,  0 },
        {     43,   70,  -21, 13,  6,  0 }, {     44,   70,  -21, 13,  6,  0 }, {     45,   71,  -22, 13,  6,  0 }, {     46,   72,  -22, 13,  6,  0 }, {     47,   72,  -23, 13,  6,  0 },
        {     48,   73,  -23, 14,  6,  0 }, {     49,   74,  -24, 14,  6,  0 }, {     50,   74,  -24, 14,  6,  0 }, {     51,   75,  -25, 14,  6,  0 }, {     52,   76,  -25, 14,  6,  0 },
        {     53,   76,  -26, 14,  6,  0 }, {     54,   77,  -26, 14,  6,  0 }, {     55,   77,  -27, 14,  6,  0 }, {     56,   78,  -27, 14,  6,  0 }, {     57,   78,  -28, 14,  6,  0 },
        {     58,   79,  -28, 14,  6,  0 }, {     59,   79,  -29, 14,  6,  0 }, {     60,   80,  -29, 14,  6,  0 }, {     61,   80,  -30, 14,  6,  0 }, {     62,   80,  -30, 14,  6,  0 },
        {     63,   81,  -31, 15,  6,  0 }, {     64,   81,  -31, 15,  6,  0 }, {     65,   82,  -32, 15,  6,  0 }, {     66,   82,  -32, 15,  6,  0 }, {     67,   82,  -33, 15,  6,  0 },
        {     68,   83,  -33, 15,  6,  0 }, {     69,   83,  -34, 15,  6,  0 }, {     70,   83,  -34, 15,  6,  0 }, {     71,   84,  -35, 15,  6,  0 }, {     72,   84,  -35, 15,  6,  0 },
        {     73,   84,  -36, 15,  6,  0 }, {     74,   84,  -36, 15,  6,  0 }, {     75,   85,  -37, 15,  6,  0 }, {     76,   85,  -37, 15,  6,  0 }, {     77,   85,  -38, 15,  6,  0 },
        {     78,   85,  -38, 15,  6,  0 }, {     79,   86,  -39, 16,  6,  0 }, {     80,   86,  -39, 16,  6,  0 }, {     81,   86,  -40, 16,  6,  0 }, {     82,   86,  -40, 16,  6,  0 },
        {     83,   86,  -41, 16,  6,  0 }, {     84,   86,  -41, 16,  6,  0 }, {     85,   86,  -42, 16,  6,  0 }, {     86,   87,  -42, 16,  6,  0 }, {     87,   87,  -43, 16,  6,  0 },
        {     88,   87,  -43, 16,  6,  0 }, {     89,   87,  -44, 16,  6,  0 }, {     90,   87,  -44, 16,  6,  0 }, {     91,   87,  -45, 16,  6,  0 }, {     92,   87,  -45, 16,  6,  0 },
        {     93,   87,  -46, 16,  6,  0 }, {     94,   87,  -46, 16,  6,  0 }, {     95,   87,  -47, 16,  6,  0 }, {     96,   87,  -47, 17,  6,  0 }, {     96,   86,  -48, 17,  6,  0 },
        {     96,   85,  -48, 17,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegDown2, {
        {      1,   23,   15, 16,  6,  0 }, {      2,   23,   14, 17,  6,  0 }, {      3,   23,   14, 17,  6,  0 }, {      4,   23,   13, 17,  6,  0 }, {      5,   23,   13, 17,  6,  0 },
        {      6,   23,   12, 17,  6,  0 }, {      7,   23,   12, 17,  6,  0 }, {      8,   23,   11, 17,  6,  0 }, {      9,   23,   11, 17,  6,  0 }, {     10,   23,   10, 17,  6,  0 },
        {     11,   22,   10, 17,  6,  0 }, {     12,   22,    9, 17,  6,  0 }, {     13,   22,    9, 17,  6,  0 }, {     14,   22,    8, 17,  6,  0 }, {     15,   22,    8, 17,  6,  0 },
        {     16,   22,    7, 17,  6,  0 }, {     17,   22,    7, 17,  6,  0 }, {     18,   21,    6, 18,  6,  0 }, {     19,   21,    6, 18,  6,  0 }, {     20,   21,    5, 18,  6,  0 },
        {     21,   21,    5, 18,  6,  0 }, {     22,   20,    4, 18,  6,  0 }, {     23,   20,    4, 18,  6,  0 }, {     24,   20,    3, 18,  6,  0 }, {     25,   20,    3, 18,  6,  0 },
        {     26,   19,    2, 18,  6,  0 }, {     27,   19,    2, 18,  6,  0 }, {     28,   19,    1, 18,  6,  0 }, {     29,   18,    1, 18,  6,  0 }, {     30,   18,    0, 18,  6,  0 },
        {     31,   18,    0, 18,  6,  0 }, {     32,   17,   -1, 18,  6,  0 }, {     33,   17,   -1, 18,  6,  0 }, {     34,   16,   -2, 19,  6,  0 }, {     35,   16,   -2, 19,  6,  0 },
        {     36,   16,   -3, 19,  6,  0 }, {     37,   15,   -3, 19,  6,  0 }, {     38,   15,   -4, 19,  6,  0 }, {     39,   14,   -4, 19,  6,  0 }, {     40,   14,   -5, 19,  6,  0 },
        {     41,   13,   -5, 19,  6,  0 }, {     42,   13,   -6, 19,  6,  0 }, {     43,   12,   -6, 19,  6,  0 }, {     44,   12,   -7, 19,  6,  0 }, {     45,   11,   -7, 19,  6,  0 },
        {     46,   10,   -8, 19,  6,  0 }, {     47,   10,   -8, 19,  6,  0 }, {     48,    9,   -9, 19,  6,  0 }, {     49,    8,   -9, 20,  6,  0 }, {     50,    8,  -10, 20,  6,  0 },
        {     51,    7,  -10, 20,  6,  0 }, {     52,    6,  -11, 20,  6,  0 }, {     53,    6,  -11, 20,  6,  0 }, {     54,    5,  -12, 20,  6,  0 }, {     55,    4,  -12, 20,  6,  0 },
        {     56,    3,  -13, 20,  6,  0 }, {     57,    2,  -13, 20,  6,  0 }, {     58,    2,  -14, 20,  6,  0 }, {     59,    1,  -14, 20,  6,  0 }, {     60,    0,  -15, 20,  6,  0 },
        {     61,   -1,  -15, 20,  6,  0 }, {     62,   -2,  -16, 20,  6,  0 }, {     63,   -3,  -16, 21,  6,  0 }, {     64,   -4,  -17, 21,  6,  0 }, {     65,   -5,  -18, 21,  6,  0 },
        {     66,   -6,  -18, 21,  6,  0 }, {     66,   -7,  -19, 21,  6,  0 }, {     67,   -8,  -19, 21,  6,  0 }, {     68,   -9,  -20, 21,  6,  0 }, {     69,  -10,  -20, 21,  6,  0 },
        {     70,  -11,  -21, 21,  6,  0 }, {     70,  -12,  -21, 21,  6,  0 }, {     71,  -13,  -22, 21,  6,  0 }, {     72,  -14,  -22, 21,  6,  0 }, {     72,  -15,  -23, 21,  6,  0 },
        {     73,  -16,  -23, 22,  6,  0 }, {     74,  -17,  -24, 22,  6,  0 }, {     74,  -18,  -24, 22,  6,  0 }, {     75,  -19,  -25, 22,  6,  0 }, {     76,  -20,  -25, 22,  6,  0 },
        {     76,  -21,  -26, 22,  6,  0 }, {     77,  -22,  -26, 22,  6,  0 }, {     77,  -23,  -27, 22,  6,  0 }, {     78,  -24,  -27, 22,  6,  0 }, {     78,  -25,  -28, 22,  6,  0 },
        {     79,  -26,  -28, 22,  6,  0 }, {     79,  -27,  -29, 22,  6,  0 }, {     80,  -28,  -29, 22,  6,  0 }, {     80,  -29,  -30, 22,  6,  0 }, {     80,  -30,  -30, 22,  6,  0 },
        {     81,  -31,  -31, 23,  6,  0 }, {     81,  -32,  -31, 23,  6,  0 }, {     82,  -33,  -32, 23,  6,  0 }, {     82,  -34,  -32, 23,  6,  0 }, {     82,  -35,  -33, 23,  6,  0 },
        {     83,  -36,  -33, 23,  6,  0 }, {     83,  -37,  -34, 23,  6,  0 }, {     83,  -38,  -34, 23,  6,  0 }, {     84,  -39,  -35, 23,  6,  0 }, {     84,  -40,  -35, 23,  6,  0 },
        {     84,  -41,  -36, 23,  6,  0 }, {     84,  -42,  -36, 23,  6,  0 }, {     85,  -43,  -37, 23,  6,  0 }, {     85,  -44,  -37, 23,  6,  0 }, {     85,  -45,  -38, 23,  6,  0 },
        {     85,  -46,  -38, 23,  6,  0 }, {     86,  -47,  -39, 24,  6,  0 }, {     86,  -48,  -39, 24,  6,  0 }, {     86,  -49,  -40, 24,  6,  0 }, {     86,  -50,  -40, 24,  6,  0 },
        {     86,  -51,  -41, 24,  6,  0 }, {     86,  -52,  -41, 24,  6,  0 }, {     86,  -53,  -42, 24,  6,  0 }, {     87,  -54,  -42, 24,  6,  0 }, {     87,  -55,  -43, 24,  6,  0 },
        {     87,  -56,  -43, 24,  6,  0 }, {     87,  -57,  -44, 24,  6,  0 }, {     87,  -58,  -44, 24,  6,  0 }, {     87,  -59,  -45, 24,  6,  0 }, {     87,  -60,  -45, 24,  6,  0 },
        {     87,  -61,  -46, 24,  6,  0 }, {     87,  -62,  -46, 24,  6,  0 }, {     87,  -63,  -47, 24,  6,  0 }, {     87,  -64,  -47, 25,  6,  0 }, {     86,  -64,  -48, 25,  6,  0 },
        {     85,  -64,  -48, 25,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegDown3, {
        {     23,   31,   15, 24,  6,  0 }, {     23,   30,   14, 25,  6,  0 }, {     23,   29,   14, 25,  6,  0 }, {     23,   28,   13, 25,  6,  0 }, {     23,   27,   13, 25,  6,  0 },
        {     23,   26,   12, 25,  6,  0 }, {     23,   25,   12, 25,  6,  0 }, {     23,   24,   11, 25,  6,  0 }, {     23,   23,   11, 25,  6,  0 }, {     23,   22,   10, 25,  6,  0 },
        {     22,   21,   10, 25,  6,  0 }, {     22,   20,    9, 25,  6,  0 }, {     22,   19,    9, 25,  6,  0 }, {     22,   18,    8, 25,  6,  0 }, {     22,   17,    8, 25,  6,  0 },
        {     22,   16,    7, 25,  6,  0 }, {     22,   15,    7, 25,  6,  0 }, {     21,   14,    6, 26,  6,  0 }, {     21,   13,    6, 26,  6,  0 }, {     21,   12,    5, 26,  6,  0 },
        {     21,   11,    5, 26,  6,  0 }, {     20,   10,    4, 26,  6,  0 }, {     20,    9,    4, 26,  6,  0 }, {     20,    8,    3, 26,  6,  0 }, {     20,    7,    3, 26,  6,  0 },
        {     19,    6,    2, 26,  6,  0 }, {     19,    5,    2, 26,  6,  0 }, {     19,    4,    1, 26,  6,  0 }, {     18,    3,    1, 26,  6,  0 }, {     18,    2,    0, 26,  6,  0 },
        {     18,    1,    0, 26,  6,  0 }, {     17,    0,   -1, 26,  6,  0 }, {     17,   -1,   -1, 26,  6,  0 }, {     16,   -2,   -2, 27,  6,  0 }, {     16,   -3,   -2, 27,  6,  0 },
        {     16,   -4,   -3, 27,  6,  0 }, {     15,   -5,   -3, 27,  6,  0 }, {     15,   -6,   -4, 27,  6,  0 }, {     14,   -7,   -4, 27,  6,  0 }, {     14,   -8,   -5, 27,  6,  0 },
        {     13,   -9,   -5, 27,  6,  0 }, {     13,  -10,   -6, 27,  6,  0 }, {     12,  -11,   -6, 27,  6,  0 }, {     12,  -12,   -7, 27,  6,  0 }, {     11,  -13,   -7, 27,  6,  0 },
        {     10,  -14,   -8, 27,  6,  0 }, {     10,  -15,   -8, 27,  6,  0 }, {      9,  -16,   -9, 27,  6,  0 }, {      8,  -17,   -9, 28,  6,  0 }, {      8,  -18,  -10, 28,  6,  0 },
        {      7,  -19,  -10, 28,  6,  0 }, {      6,  -20,  -11, 28,  6,  0 }, {      6,  -21,  -11, 28,  6,  0 }, {      5,  -22,  -12, 28,  6,  0 }, {      4,  -23,  -12, 28,  6,  0 },
        {      3,  -24,  -13, 28,  6,  0 }, {      2,  -25,  -13, 28,  6,  0 }, {      2,  -26,  -14, 28,  6,  0 }, {      1,  -27,  -14, 28,  6,  0 }, {      0,  -28,  -15, 28,  6,  0 },
        {     -1,  -29,  -15, 28,  6,  0 }, {     -2,  -30,  -16, 28,  6,  0 }, {     -3,  -31,  -16, 29,  6,  0 }, {     -4,  -32,  -17, 29,  6,  0 }, {     -5,  -33,  -18, 29,  6,  0 },
        {     -6,  -34,  -18, 29,  6,  0 }, {     -7,  -34,  -19, 29,  6,  0 }, {     -8,  -35,  -19, 29,  6,  0 }, {     -9,  -36,  -20, 29,  6,  0 }, {    -10,  -37,  -20, 29,  6,  0 },
        {    -11,  -38,  -21, 29,  6,  0 }, {    -12,  -38,  -21, 29,  6,  0 }, {    -13,  -39,  -22, 29,  6,  0 }, {    -14,  -40,  -22, 29,  6,  0 }, {    -15,  -40,  -23, 29,  6,  0 },
        {    -16,  -41,  -23, 30,  6,  0 }, {    -17,  -42,  -24, 30,  6,  0 }, {    -18,  -42,  -24, 30,  6,  0 }, {    -19,  -43,  -25, 30,  6,  0 }, {    -20,  -44,  -25, 30,  6,  0 },
        {    -21,  -44,  -26, 30,  6,  0 }, {    -22,  -45,  -26, 30,  6,  0 }, {    -23,  -45,  -27, 30,  6,  0 }, {    -24,  -46,  -27, 30,  6,  0 }, {    -25,  -46,  -28, 30,  6,  0 },
        {    -26,  -47,  -28, 30,  6,  0 }, {    -27,  -47,  -29, 30,  6,  0 }, {    -28,  -48,  -29, 30,  6,  0 }, {    -29,  -48,  -30, 30,  6,  0 }, {    -30,  -48,  -30, 30,  6,  0 },
        {    -31,  -49,  -31, 31,  6,  0 }, {    -32,  -49,  -31, 31,  6,  0 }, {    -33,  -50,  -32, 31,  6,  0 }, {    -34,  -50,  -32, 31,  6,  0 }, {    -35,  -50,  -33, 31,  6,  0 },
        {    -36,  -51,  -33, 31,  6,  0 }, {    -37,  -51,  -34, 31,  6,  0 }, {    -38,  -51,  -34, 31,  6,  0 }, {    -39,  -52,  -35, 31,  6,  0 }, {    -40,  -52,  -35, 31,  6,  0 },
        {    -41,  -52,  -36, 31,  6,  0 }, {    -42,  -52,  -36, 31,  6,  0 }, {    -43,  -53,  -37, 31,  6,  0 }, {    -44,  -53,  -37, 31,  6,  0 }, {    -45,  -53,  -38, 31,  6,  0 },
        {    -46,  -53,  -38, 31,  6,  0 }, {    -47,  -54,  -39,  0,  6,  0 }, {    -48,  -54,  -39,  0,  6,  0 }, {    -49,  -54,  -40,  0,  6,  0 }, {    -50,  -54,  -40,  0,  6,  0 },
        {    -51,  -54,  -41,  0,  6,  0 }, {    -52,  -54,  -41,  0,  6,  0 }, {    -53,  -54,  -42,  0,  6,  0 }, {    -54,  -55,  -42,  0,  6,  0 }, {    -55,  -55,  -43,  0,  6,  0 },
        {    -56,  -55,  -43,  0,  6,  0 }, {    -57,  -55,  -44,  0,  6,  0 }, {    -58,  -55,  -44,  0,  6,  0 }, {    -59,  -55,  -45,  0,  6,  0 }, {    -60,  -55,  -45,  0,  6,  0 },
        {    -61,  -55,  -46,  0,  6,  0 }, {    -62,  -55,  -46,  0,  6,  0 }, {    -63,  -55,  -47,  0,  6,  0 }, {    -64,  -55,  -47,  1,  6,  0 }, {    -64,  -54,  -48,  1,  6,  0 },
        {    -64,  -53,  -48,  1,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftSBend0, {
        {     32,    9,    0,  0,  0,  0 }, {     31,    9,    0,  0,  0,  0 }, {     30,    9,    0,  0,  0,  0 }, {     29,    9,    0,  0,  0,  0 }, {     28,    9,    0,  0,  0,  0 },
        {     27,    9,    0,  0,  0,  0 }, {     26,    9,    0,  0,  0,  0 }, {     25,    9,    0,  0,  0,  0 }, {     24,    9,    0, 31,  0,  0 }, {     23,    8,    0, 31,  0,  0 },
        {     22,    8,    0, 31,  0,  0 }, {     21,    8,    0, 31,  0,  0 }, {     20,    8,    0, 31,  0,  0 }, {     19,    8,    0, 31,  0,  0 }, {     18,    8,    0, 31,  0,  0 },
        {     17,    7,    0, 31,  0,  0 }, {     16,    7,    0, 31,  0,  0 }, {     15,    7,    0, 31,  0,  0 }, {     14,    7,    0, 31,  0,  0 }, {     13,    6,    0, 31,  0,  0 },
        {     12,    6,    0, 30,  0,  0 }, {     11,    6,    0, 30,  0,  0 }, {     10,    5,    0, 30,  0,  0 }, {      9,    5,    0, 30,  0,  0 }, {      8,    5,    0, 30,  0,  0 },
        {      7,    4,    0, 30,  0,  0 }, {      6,    4,    0, 30,  0,  0 }, {      5,    4,    0, 30,  0,  0 }, {      4,    3,    0, 30,  0,  0 }, {      3,    3,    0, 30,  0,  0 },
        {      2,    2,    0, 30,  0,  0 }, {      1,    2,    0, 30,  0,  0 }, {      0,    1,    0, 30,  0,  0 }, {     -1,    1,    0, 30,  0,  0 }, {     -2,    0,    0, 29,  0,  0 },
        {     -3,    0,    0, 29,  0,  0 }, {     -4,   -1,    0, 29,  0,  0 }, {     -5,   -1,    0, 29,  0,  0 }, {     -6,   -2,    0, 29,  0,  0 }, {     -7,   -3,    0, 29,  0,  0 },
        {     -8,   -3,    0, 29,  0,  0 }, {     -9,   -4,    0, 29,  0,  0 }, {    -10,   -5,    0, 29,  0,  0 }, {    -11,   -5,    0, 29,  0,  0 }, {    -12,   -6,    0, 29,  0,  0 },
        {    -13,   -7,    0, 29,  0,  0 }, {    -14,   -7,    0, 29,  0,  0 }, {    -15,   -8,    0, 29,  0,  0 }, {    -16,   -9,    0, 29,  0,  0 }, {    -17,   -9,    0, 29,  0,  0 },
        {    -18,  -10,    0, 29,  0,  0 }, {    -19,  -11,    0, 29,  0,  0 }, {    -20,  -11,    0, 29,  0,  0 }, {    -21,  -12,    0, 29,  0,  0 }, {    -22,  -12,    0, 29,  0,  0 },
        {    -23,  -13,    0, 30,  0,  0 }, {    -24,  -13,    0, 30,  0,  0 }, {    -25,  -14,    0, 30,  0,  0 }, {    -26,  -14,    0, 30,  0,  0 }, {    -27,  -15,    0, 30,  0,  0 },
        {    -28,  -15,    0, 30,  0,  0 }, {    -29,  -16,    0, 30,  0,  0 }, {    -30,  -16,    0, 30,  0,  0 }, {    -31,  -17,    0, 30,  0,  0 }, {    -32,  -17,    0, 30,  0,  0 },
        {    -33,  -17,    0, 30,  0,  0 }, {    -34,  -18,    0, 30,  0,  0 }, {    -35,  -18,    0, 30,  0,  0 }, {    -36,  -19,    0, 30,  0,  0 }, {    -37,  -19,    0, 30,  0,  0 },
        {    -38,  -19,    0, 30,  0,  0 }, {    -39,  -20,    0, 31,  0,  0 }, {    -40,  -20,    0, 31,  0,  0 }, {    -41,  -20,    0, 31,  0,  0 }, {    -42,  -20,    0, 31,  0,  0 },
        {    -43,  -21,    0, 31,  0,  0 }, {    -44,  -21,    0, 31,  0,  0 }, {    -45,  -21,    0, 31,  0,  0 }, {    -46,  -21,    0, 31,  0,  0 }, {    -47,  -22,    0, 31,  0,  0 },
        {    -48,  -22,    0, 31,  0,  0 }, {    -49,  -22,    0, 31,  0,  0 }, {    -50,  -22,    0, 31,  0,  0 }, {    -51,  -22,    0, 31,  0,  0 }, {    -52,  -22,    0, 31,  0,  0 },
        {    -53,  -22,    0, 31,  0,  0 }, {    -54,  -23,    0, 31,  0,  0 }, {    -55,  -23,    0,  0,  0,  0 }, {    -56,  -23,    0,  0,  0,  0 }, {    -57,  -23,    0,  0,  0,  0 },
        {    -58,  -23,    0,  0,  0,  0 }, {    -59,  -23,    0,  0,  0,  0 }, {    -60,  -23,    0,  0,  0,  0 }, {    -61,  -23,    0,  0,  0,  0 }, {    -62,  -23,    0,  0,  0,  0 },
        {    -63,  -23,    0,  0,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftSBend1, {
        {      9,    0,    0,  8,  0,  0 }, {      9,    1,    0,  8,  0,  0 }, {      9,    2,    0,  8,  0,  0 }, {      9,    3,    0,  8,  0,  0 }, {      9,    4,    0,  8,  0,  0 },
        {      9,    5,    0,  8,  0,  0 }, {      9,    6,    0,  8,  0,  0 }, {      9,    7,    0,  8,  0,  0 }, {      9,    8,    0,  7,  0,  0 }, {      8,    9,    0,  7,  0,  0 },
        {      8,   10,    0,  7,  0,  0 }, {      8,   11,    0,  7,  0,  0 }, {      8,   12,    0,  7,  0,  0 }, {      8,   13,    0,  7,  0,  0 }, {      8,   14,    0,  7,  0,  0 },
        {      7,   15,    0,  7,  0,  0 }, {      7,   16,    0,  7,  0,  0 }, {      7,   17,    0,  7,  0,  0 }, {      7,   18,    0,  7,  0,  0 }, {      6,   19,    0,  7,  0,  0 },
        {      6,   20,    0,  6,  0,  0 }, {      6,   21,    0,  6,  0,  0 }, {      5,   22,    0,  6,  0,  0 }, {      5,   23,    0,  6,  0,  0 }, {      5,   24,    0,  6,  0,  0 },
        {      4,   25,    0,  6,  0,  0 }, {      4,   26,    0,  6,  0,  0 }, {      4,   27,    0,  6,  0,  0 }, {      3,   28,    0,  6,  0,  0 }, {      3,   29,    0,  6,  0,  0 },
        {      2,   30,    0,  6,  0,  0 }, {      2,   31,    0,  6,  0,  0 }, {      1,   32,    0,  6,  0,  0 }, {      1,   33,    0,  6,  0,  0 }, {      0,   34,    0,  5,  0,  0 },
        {      0,   35,    0,  5,  0,  0 }, {     -1,   36,    0,  5,  0,  0 }, {     -1,   37,    0,  5,  0,  0 }, {     -2,   38,    0,  5,  0,  0 }, {     -3,   39,    0,  5,  0,  0 },
        {     -3,   40,    0,  5,  0,  0 }, {     -4,   41,    0,  5,  0,  0 }, {     -5,   42,    0,  5,  0,  0 }, {     -5,   43,    0,  5,  0,  0 }, {     -6,   44,    0,  5,  0,  0 },
        {     -7,   45,    0,  5,  0,  0 }, {     -7,   46,    0,  5,  0,  0 }, {     -8,   47,    0,  5,  0,  0 }, {     -9,   48,    0,  5,  0,  0 }, {     -9,   49,    0,  5,  0,  0 },
        {    -10,   50,    0,  5,  0,  0 }, {    -11,   51,    0,  5,  0,  0 }, {    -11,   52,    0,  5,  0,  0 }, {    -12,   53,    0,  5,  0,  0 }, {    -12,   54,    0,  5,  0,  0 },
        {    -13,   55,    0,  6,  0,  0 }, {    -13,   56,    0,  6,  0,  0 }, {    -14,   57,    0,  6,  0,  0 }, {    -14,   58,    0,  6,  0,  0 }, {    -15,   59,    0,  6,  0,  0 },
        {    -15,   60,    0,  6,  0,  0 }, {    -16,   61,    0,  6,  0,  0 }, {    -16,   62,    0,  6,  0,  0 }, {    -17,   63,    0,  6,  0,  0 }, {    -17,   64,    0,  6,  0,  0 },
        {    -17,   65,    0,  6,  0,  0 }, {    -18,   66,    0,  6,  0,  0 }, {    -18,   67,    0,  6,  0,  0 }, {    -19,   68,    0,  6,  0,  0 }, {    -19,   69,    0,  6,  0,  0 },
        {    -19,   70,    0,  6,  0,  0 }, {    -20,   71,    0,  7,  0,  0 }, {    -20,   72,    0,  7,  0,  0 }, {    -20,   73,    0,  7,  0,  0 }, {    -20,   74,    0,  7,  0,  0 },
        {    -21,   75,    0,  7,  0,  0 }, {    -21,   76,    0,  7,  0,  0 }, {    -21,   77,    0,  7,  0,  0 }, {    -21,   78,    0,  7,  0,  0 }, {    -22,   79,    0,  7,  0,  0 },
        {    -22,   80,    0,  7,  0,  0 }, {    -22,   81,    0,  7,  0,  0 }, {    -22,   82,    0,  7,  0,  0 }, {    -22,   83,    0,  7,  0,  0 }, {    -22,   84,    0,  7,  0,  0 },
        {    -22,   85,    0,  7,  0,  0 }, {    -23,   86,    0,  7,  0,  0 }, {    -23,   87,    0,  8,  0,  0 }, {    -23,   88,    0,  8,  0,  0 }, {    -23,   89,    0,  8,  0,  0 },
        {    -23,   90,    0,  8,  0,  0 }, {    -23,   91,    0,  8,  0,  0 }, {    -23,   92,    0,  8,  0,  0 }, {    -23,   93,    0,  8,  0,  0 }, {    -23,   94,    0,  8,  0,  0 },
        {    -23,   95,    0,  8,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftSBend2, {
        {      0,   23,    0, 16,  0,  0 }, {      1,   23,    0, 16,  0,  0 }, {      2,   23,    0, 16,  0,  0 }, {      3,   23,    0, 16,  0,  0 }, {      4,   23,    0, 16,  0,  0 },
        {      5,   23,    0, 16,  0,  0 }, {      6,   23,    0, 16,  0,  0 }, {      7,   23,    0, 16,  0,  0 }, {      8,   23,    0, 15,  0,  0 }, {      9,   24,    0, 15,  0,  0 },
        {     10,   24,    0, 15,  0,  0 }, {     11,   24,    0, 15,  0,  0 }, {     12,   24,    0, 15,  0,  0 }, {     13,   24,    0, 15,  0,  0 }, {     14,   24,    0, 15,  0,  0 },
        {     15,   25,    0, 15,  0,  0 }, {     16,   25,    0, 15,  0,  0 }, {     17,   25,    0, 15,  0,  0 }, {     18,   25,    0, 15,  0,  0 }, {     19,   26,    0, 15,  0,  0 },
        {     20,   26,    0, 14,  0,  0 }, {     21,   26,    0, 14,  0,  0 }, {     22,   27,    0, 14,  0,  0 }, {     23,   27,    0, 14,  0,  0 }, {     24,   27,    0, 14,  0,  0 },
        {     25,   28,    0, 14,  0,  0 }, {     26,   28,    0, 14,  0,  0 }, {     27,   28,    0, 14,  0,  0 }, {     28,   29,    0, 14,  0,  0 }, {     29,   29,    0, 14,  0,  0 },
        {     30,   30,    0, 14,  0,  0 }, {     31,   30,    0, 14,  0,  0 }, {     32,   31,    0, 14,  0,  0 }, {     33,   31,    0, 14,  0,  0 }, {     34,   32,    0, 13,  0,  0 },
        {     35,   32,    0, 13,  0,  0 }, {     36,   33,    0, 13,  0,  0 }, {     37,   33,    0, 13,  0,  0 }, {     38,   34,    0, 13,  0,  0 }, {     39,   35,    0, 13,  0,  0 },
        {     40,   35,    0, 13,  0,  0 }, {     41,   36,    0, 13,  0,  0 }, {     42,   37,    0, 13,  0,  0 }, {     43,   37,    0, 13,  0,  0 }, {     44,   38,    0, 13,  0,  0 },
        {     45,   39,    0, 13,  0,  0 }, {     46,   39,    0, 13,  0,  0 }, {     47,   40,    0, 13,  0,  0 }, {     48,   41,    0, 13,  0,  0 }, {     49,   41,    0, 13,  0,  0 },
        {     50,   42,    0, 13,  0,  0 }, {     51,   43,    0, 13,  0,  0 }, {     52,   43,    0, 13,  0,  0 }, {     53,   44,    0, 13,  0,  0 }, {     54,   44,    0, 13,  0,  0 },
        {     55,   45,    0, 14,  0,  0 }, {     56,   45,    0, 14,  0,  0 }, {     57,   46,    0, 14,  0,  0 }, {     58,   46,    0, 14,  0,  0 }, {     59,   47,    0, 14,  0,  0 },
        {     60,   47,    0, 14,  0,  0 }, {     61,   48,    0, 14,  0,  0 }, {     62,   48,    0, 14,  0,  0 }, {     63,   49,    0, 14,  0,  0 }, {     64,   49,    0, 14,  0,  0 },
        {     65,   49,    0, 14,  0,  0 }, {     66,   50,    0, 14,  0,  0 }, {     67,   50,    0, 14,  0,  0 }, {     68,   51,    0, 14,  0,  0 }, {     69,   51,    0, 14,  0,  0 },
        {     70,   51,    0, 14,  0,  0 }, {     71,   52,    0, 15,  0,  0 }, {     72,   52,    0, 15,  0,  0 }, {     73,   52,    0, 15,  0,  0 }, {     74,   52,    0, 15,  0,  0 },
        {     75,   53,    0, 15,  0,  0 }, {     76,   53,    0, 15,  0,  0 }, {     77,   53,    0, 15,  0,  0 }, {     78,   53,    0, 15,  0,  0 }, {     79,   54,    0, 15,  0,  0 },
        {     80,   54,    0, 15,  0,  0 }, {     81,   54,    0, 15,  0,  0 }, {     82,   54,    0, 15,  0,  0 }, {     83,   54,    0, 15,  0,  0 }, {     84,   54,    0, 15,  0,  0 },
        {     85,   54,    0, 15,  0,  0 }, {     86,   55,    0, 15,  0,  0 }, {     87,   55,    0, 16,  0,  0 }, {     88,   55,    0, 16,  0,  0 }, {     89,   55,    0, 16,  0,  0 },
        {     90,   55,    0, 16,  0,  0 }, {     91,   55,    0, 16,  0,  0 }, {     92,   55,    0, 16,  0,  0 }, {     93,   55,    0, 16,  0,  0 }, {     94,   55,    0, 16,  0,  0 },
        {     95,   55,    0, 16,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftSBend3, {
        {     23,   32,    0, 24,  0,  0 }, {     23,   31,    0, 24,  0,  0 }, {     23,   30,    0, 24,  0,  0 }, {     23,   29,    0, 24,  0,  0 }, {     23,   28,    0, 24,  0,  0 },
        {     23,   27,    0, 24,  0,  0 }, {     23,   26,    0, 24,  0,  0 }, {     23,   25,    0, 24,  0,  0 }, {     23,   24,    0, 23,  0,  0 }, {     24,   23,    0, 23,  0,  0 },
        {     24,   22,    0, 23,  0,  0 }, {     24,   21,    0, 23,  0,  0 }, {     24,   20,    0, 23,  0,  0 }, {     24,   19,    0, 23,  0,  0 }, {     24,   18,    0, 23,  0,  0 },
        {     25,   17,    0, 23,  0,  0 }, {     25,   16,    0, 23,  0,  0 }, {     25,   15,    0, 23,  0,  0 }, {     25,   14,    0, 23,  0,  0 }, {     26,   13,    0, 23,  0,  0 },
        {     26,   12,    0, 22,  0,  0 }, {     26,   11,    0, 22,  0,  0 }, {     27,   10,    0, 22,  0,  0 }, {     27,    9,    0, 22,  0,  0 }, {     27,    8,    0, 22,  0,  0 },
        {     28,    7,    0, 22,  0,  0 }, {     28,    6,    0, 22,  0,  0 }, {     28,    5,    0, 22,  0,  0 }, {     29,    4,    0, 22,  0,  0 }, {     29,    3,    0, 22,  0,  0 },
        {     30,    2,    0, 22,  0,  0 }, {     30,    1,    0, 22,  0,  0 }, {     31,    0,    0, 22,  0,  0 }, {     31,   -1,    0, 22,  0,  0 }, {     32,   -2,    0, 21,  0,  0 },
        {     32,   -3,    0, 21,  0,  0 }, {     33,   -4,    0, 21,  0,  0 }, {     33,   -5,    0, 21,  0,  0 }, {     34,   -6,    0, 21,  0,  0 }, {     35,   -7,    0, 21,  0,  0 },
        {     35,   -8,    0, 21,  0,  0 }, {     36,   -9,    0, 21,  0,  0 }, {     37,  -10,    0, 21,  0,  0 }, {     37,  -11,    0, 21,  0,  0 }, {     38,  -12,    0, 21,  0,  0 },
        {     39,  -13,    0, 21,  0,  0 }, {     39,  -14,    0, 21,  0,  0 }, {     40,  -15,    0, 21,  0,  0 }, {     41,  -16,    0, 21,  0,  0 }, {     41,  -17,    0, 21,  0,  0 },
        {     42,  -18,    0, 21,  0,  0 }, {     43,  -19,    0, 21,  0,  0 }, {     43,  -20,    0, 21,  0,  0 }, {     44,  -21,    0, 21,  0,  0 }, {     44,  -22,    0, 21,  0,  0 },
        {     45,  -23,    0, 22,  0,  0 }, {     45,  -24,    0, 22,  0,  0 }, {     46,  -25,    0, 22,  0,  0 }, {     46,  -26,    0, 22,  0,  0 }, {     47,  -27,    0, 22,  0,  0 },
        {     47,  -28,    0, 22,  0,  0 }, {     48,  -29,    0, 22,  0,  0 }, {     48,  -30,    0, 22,  0,  0 }, {     49,  -31,    0, 22,  0,  0 }, {     49,  -32,    0, 22,  0,  0 },
        {     49,  -33,    0, 22,  0,  0 }, {     50,  -34,    0, 22,  0,  0 }, {     50,  -35,    0, 22,  0,  0 }, {     51,  -36,    0, 22,  0,  0 }, {     51,  -37,    0, 22,  0,  0 },
        {     51,  -38,    0, 22,  0,  0 }, {     52,  -39,    0, 23,  0,  0 }, {     52,  -40,    0, 23,  0,  0 }, {     52,  -41,    0, 23,  0,  0 }, {     52,  -42,    0, 23,  0,  0 },
        {     53,  -43,    0, 23,  0,  0 }, {     53,  -44,    0, 23,  0,  0 }, {     53,  -45,    0, 23,  0,  0 }, {     53,  -46,    0, 23,  0,  0 }, {     54,  -47,    0, 23,  0,  0 },
        {     54,  -48,    0, 23,  0,  0 }, {     54,  -49,    0, 23,  0,  0 }, {     54,  -50,    0, 23,  0,  0 }, {     54,  -51,    0, 23,  0,  0 }, {     54,  -52,    0, 23,  0,  0 },
        {     54,  -53,    0, 23,  0,  0 }, {     55,  -54,    0, 23,  0,  0 }, {     55,  -55,    0, 24,  0,  0 }, {     55,  -56,    0, 24,  0,  0 }, {     55,  -57,    0, 24,  0,  0 },
        {     55,  -58,    0, 24,  0,  0 }, {     55,  -59,    0, 24,  0,  0 }, {     55,  -60,    0, 24,  0,  0 }, {     55,  -61,    0, 24,  0,  0 }, {     55,  -62,    0, 24,  0,  0 },
        {     55,  -63,    0, 24,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightSBend0, {
        {     32,    9,    0,  0,  0,  0 }, {     31,    9,    0,  0,  0,  0 }, {     30,    9,    0,  0,  0,  0 }, {     29,    9,    0,  0,  0,  0 }, {     28,    9,    0,  0,  0,  0 },
        {     27,    9,    0,  0,  0,  0 }, {     26,    9,    0,  0,  0,  0 }, {     25,    9,    0,  0,  0,  0 }, {     24,    9,    0,  0,  0,  0 }, {     23,    9,    0,  1,  0,  0 },
        {     22,   10,    0,  1,  0,  0 }, {     21,   10,    0,  1,  0,  0 }, {     20,   10,    0,  1,  0,  0 }, {     19,   10,    0,  1,  0,  0 }, {     18,   10,    0,  1,  0,  0 },
        {     17,   10,    0,  1,  0,  0 }, {     16,   10,    0,  1,  0,  0 }, {     15,   11,    0,  1,  0,  0 }, {     14,   11,    0,  1,  0,  0 }, {     13,   11,    0,  1,  0,  0 },
        {     12,   11,    0,  1,  0,  0 }, {     11,   12,    0,  1,  0,  0 }, {     10,   12,    0,  1,  0,  0 }, {      9,   12,    0,  1,  0,  0 }, {      8,   12,    0,  1,  0,  0 },
        {      7,   13,    0,  2,  0,  0 }, {      6,   13,    0,  2,  0,  0 }, {      5,   13,    0,  2,  0,  0 }, {      4,   14,    0,  2,  0,  0 }, {      3,   14,    0,  2,  0,  0 },
        {      2,   15,    0,  2,  0,  0 }, {      1,   15,    0,  2,  0,  0 }, {      0,   15,    0,  2,  0,  0 }, {     -1,   16,    0,  2,  0,  0 }, {     -2,   16,    0,  2,  0,  0 },
        {     -3,   17,    0,  2,  0,  0 }, {     -4,   17,    0,  2,  0,  0 }, {     -5,   18,    0,  2,  0,  0 }, {     -6,   18,    0,  2,  0,  0 }, {     -7,   19,    0,  2,  0,  0 },
        {     -8,   19,    0,  3,  0,  0 }, {     -9,   20,    0,  3,  0,  0 }, {    -10,   20,    0,  3,  0,  0 }, {    -11,   21,    0,  3,  0,  0 }, {    -12,   21,    0,  3,  0,  0 },
        {    -13,   22,    0,  3,  0,  0 }, {    -14,   23,    0,  3,  0,  0 }, {    -15,   23,    0,  3,  0,  0 }, {    -16,   24,    0,  3,  0,  0 }, {    -17,   25,    0,  3,  0,  0 },
        {    -18,   25,    0,  3,  0,  0 }, {    -19,   26,    0,  3,  0,  0 }, {    -20,   27,    0,  3,  0,  0 }, {    -21,   27,    0,  3,  0,  0 }, {    -22,   28,    0,  3,  0,  0 },
        {    -23,   29,    0,  3,  0,  0 }, {    -24,   29,    0,  3,  0,  0 }, {    -25,   30,    0,  3,  0,  0 }, {    -26,   31,    0,  3,  0,  0 }, {    -27,   31,    0,  3,  0,  0 },
        {    -28,   32,    0,  3,  0,  0 }, {    -29,   32,    0,  3,  0,  0 }, {    -30,   33,    0,  2,  0,  0 }, {    -31,   33,    0,  2,  0,  0 }, {    -32,   34,    0,  2,  0,  0 },
        {    -33,   34,    0,  2,  0,  0 }, {    -34,   35,    0,  2,  0,  0 }, {    -35,   35,    0,  2,  0,  0 }, {    -36,   36,    0,  2,  0,  0 }, {    -37,   36,    0,  2,  0,  0 },
        {    -38,   36,    0,  2,  0,  0 }, {    -39,   37,    0,  2,  0,  0 }, {    -40,   37,    0,  2,  0,  0 }, {    -41,   37,    0,  2,  0,  0 }, {    -42,   38,    0,  2,  0,  0 },
        {    -43,   38,    0,  2,  0,  0 }, {    -44,   38,    0,  1,  0,  0 }, {    -45,   39,    0,  1,  0,  0 }, {    -46,   39,    0,  1,  0,  0 }, {    -47,   39,    0,  1,  0,  0 },
        {    -48,   39,    0,  1,  0,  0 }, {    -49,   40,    0,  1,  0,  0 }, {    -50,   40,    0,  1,  0,  0 }, {    -51,   40,    0,  1,  0,  0 }, {    -52,   40,    0,  1,  0,  0 },
        {    -53,   40,    0,  1,  0,  0 }, {    -54,   40,    0,  1,  0,  0 }, {    -55,   41,    0,  1,  0,  0 }, {    -56,   41,    0,  0,  0,  0 }, {    -57,   41,    0,  0,  0,  0 },
        {    -58,   41,    0,  0,  0,  0 }, {    -59,   41,    0,  0,  0,  0 }, {    -60,   41,    0,  0,  0,  0 }, {    -61,   41,    0,  0,  0,  0 }, {    -62,   41,    0,  0,  0,  0 },
        {    -63,   41,    0,  0,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightSBend1, {
        {      9,    0,    0,  8,  0,  0 }, {      9,    1,    0,  8,  0,  0 }, {      9,    2,    0,  8,  0,  0 }, {      9,    3,    0,  8,  0,  0 }, {      9,    4,    0,  8,  0,  0 },
        {      9,    5,    0,  8,  0,  0 }, {      9,    6,    0,  8,  0,  0 }, {      9,    7,    0,  8,  0,  0 }, {      9,    8,    0,  8,  0,  0 }, {      9,    9,    0,  9,  0,  0 },
        {     10,   10,    0,  9,  0,  0 }, {     10,   11,    0,  9,  0,  0 }, {     10,   12,    0,  9,  0,  0 }, {     10,   13,    0,  9,  0,  0 }, {     10,   14,    0,  9,  0,  0 },
        {     10,   15,    0,  9,  0,  0 }, {     10,   16,    0,  9,  0,  0 }, {     11,   17,    0,  9,  0,  0 }, {     11,   18,    0,  9,  0,  0 }, {     11,   19,    0,  9,  0,  0 },
        {     11,   20,    0,  9,  0,  0 }, {     12,   21,    0,  9,  0,  0 }, {     12,   22,    0,  9,  0,  0 }, {     12,   23,    0,  9,  0,  0 }, {     12,   24,    0,  9,  0,  0 },
        {     13,   25,    0, 10,  0,  0 }, {     13,   26,    0, 10,  0,  0 }, {     13,   27,    0, 10,  0,  0 }, {     14,   28,    0, 10,  0,  0 }, {     14,   29,    0, 10,  0,  0 },
        {     15,   30,    0, 10,  0,  0 }, {     15,   31,    0, 10,  0,  0 }, {     15,   32,    0, 10,  0,  0 }, {     16,   33,    0, 10,  0,  0 }, {     16,   34,    0, 10,  0,  0 },
        {     17,   35,    0, 10,  0,  0 }, {     17,   36,    0, 10,  0,  0 }, {     18,   37,    0, 10,  0,  0 }, {     18,   38,    0, 10,  0,  0 }, {     19,   39,    0, 10,  0,  0 },
        {     19,   40,    0, 11,  0,  0 }, {     20,   41,    0, 11,  0,  0 }, {     20,   42,    0, 11,  0,  0 }, {     21,   43,    0, 11,  0,  0 }, {     21,   44,    0, 11,  0,  0 },
        {     22,   45,    0, 11,  0,  0 }, {     23,   46,    0, 11,  0,  0 }, {     23,   47,    0, 11,  0,  0 }, {     24,   48,    0, 11,  0,  0 }, {     25,   49,    0, 11,  0,  0 },
        {     25,   50,    0, 11,  0,  0 }, {     26,   51,    0, 11,  0,  0 }, {     27,   52,    0, 11,  0,  0 }, {     27,   53,    0, 11,  0,  0 }, {     28,   54,    0, 11,  0,  0 },
        {     29,   55,    0, 11,  0,  0 }, {     29,   56,    0, 11,  0,  0 }, {     30,   57,    0, 11,  0,  0 }, {     31,   58,    0, 11,  0,  0 }, {     31,   59,    0, 11,  0,  0 },
        {     32,   60,    0, 11,  0,  0 }, {     32,   61,    0, 11,  0,  0 }, {     33,   62,    0, 10,  0,  0 }, {     33,   63,    0, 10,  0,  0 }, {     34,   64,    0, 10,  0,  0 },
        {     34,   65,    0, 10,  0,  0 }, {     35,   66,    0, 10,  0,  0 }, {     35,   67,    0, 10,  0,  0 }, {     36,   68,    0, 10,  0,  0 }, {     36,   69,    0, 10,  0,  0 },
        {     36,   70,    0, 10,  0,  0 }, {     37,   71,    0, 10,  0,  0 }, {     37,   72,    0, 10,  0,  0 }, {     37,   73,    0, 10,  0,  0 }, {     38,   74,    0, 10,  0,  0 },
        {     38,   75,    0, 10,  0,  0 }, {     38,   76,    0,  9,  0,  0 }, {     39,   77,    0,  9,  0,  0 }, {     39,   78,    0,  9,  0,  0 }, {     39,   79,    0,  9,  0,  0 },
        {     39,   80,    0,  9,  0,  0 }, {     40,   81,    0,  9,  0,  0 }, {     40,   82,    0,  9,  0,  0 }, {     40,   83,    0,  9,  0,  0 }, {     40,   84,    0,  9,  0,  0 },
        {     40,   85,    0,  9,  0,  0 }, {     40,   86,    0,  9,  0,  0 }, {     41,   87,    0,  9,  0,  0 }, {     41,   88,    0,  8,  0,  0 }, {     41,   89,    0,  8,  0,  0 },
        {     41,   90,    0,  8,  0,  0 }, {     41,   91,    0,  8,  0,  0 }, {     41,   92,    0,  8,  0,  0 }, {     41,   93,    0,  8,  0,  0 }, {     41,   94,    0,  8,  0,  0 },
        {     41,   95,    0,  8,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightSBend2, {
        {      0,   23,    0, 16,  0,  0 }, {      1,   23,    0, 16,  0,  0 }, {      2,   23,    0, 16,  0,  0 }, {      3,   23,    0, 16,  0,  0 }, {      4,   23,    0, 16,  0,  0 },
        {      5,   23,    0, 16,  0,  0 }, {      6,   23,    0, 16,  0,  0 }, {      7,   23,    0, 16,  0,  0 }, {      8,   23,    0, 16,  0,  0 }, {      9,   23,    0, 17,  0,  0 },
        {     10,   22,    0, 17,  0,  0 }, {     11,   22,    0, 17,  0,  0 }, {     12,   22,    0, 17,  0,  0 }, {     13,   22,    0, 17,  0,  0 }, {     14,   22,    0, 17,  0,  0 },
        {     15,   22,    0, 17,  0,  0 }, {     16,   22,    0, 17,  0,  0 }, {     17,   21,    0, 17,  0,  0 }, {     18,   21,    0, 17,  0,  0 }, {     19,   21,    0, 17,  0,  0 },
        {     20,   21,    0, 17,  0,  0 }, {     21,   20,    0, 17,  0,  0 }, {     22,   20,    0, 17,  0,  0 }, {     23,   20,    0, 17,  0,  0 }, {     24,   20,    0, 17,  0,  0 },
        {     25,   19,    0, 18,  0,  0 }, {     26,   19,    0, 18,  0,  0 }, {     27,   19,    0, 18,  0,  0 }, {     28,   18,    0, 18,  0,  0 }, {     29,   18,    0, 18,  0,  0 },
        {     30,   17,    0, 18,  0,  0 }, {     31,   17,    0, 18,  0,  0 }, {     32,   17,    0, 18,  0,  0 }, {     33,   16,    0, 18,  0,  0 }, {     34,   16,    0, 18,  0,  0 },
        {     35,   15,    0, 18,  0,  0 }, {     36,   15,    0, 18,  0,  0 }, {     37,   14,    0, 18,  0,  0 }, {     38,   14,    0, 18,  0,  0 }, {     39,   13,    0, 18,  0,  0 },
        {     40,   13,    0, 19,  0,  0 }, {     41,   12,    0, 19,  0,  0 }, {     42,   12,    0, 19,  0,  0 }, {     43,   11,    0, 19,  0,  0 }, {     44,   11,    0, 19,  0,  0 },
        {     45,   10,    0, 19,  0,  0 }, {     46,    9,    0, 19,  0,  0 }, {     47,    9,    0, 19,  0,  0 }, {     48,    8,    0, 19,  0,  0 }, {     49,    7,    0, 19,  0,  0 },
        {     50,    7,    0, 19,  0,  0 }, {     51,    6,    0, 19,  0,  0 }, {     52,    5,    0, 19,  0,  0 }, {     53,    5,    0, 19,  0,  0 }, {     54,    4,    0, 19,  0,  0 },
        {     55,    3,    0, 19,  0,  0 }, {     56,    3,    0, 19,  0,  0 }, {     57,    2,    0, 19,  0,  0 }, {     58,    1,    0, 19,  0,  0 }, {     59,    1,    0, 19,  0,  0 },
        {     60,    0,    0, 19,  0,  0 }, {     61,    0,    0, 19,  0,  0 }, {     62,   -1,    0, 18,  0,  0 }, {     63,   -1,    0, 18,  0,  0 }, {     64,   -2,    0, 18,  0,  0 },
        {     65,   -2,    0, 18,  0,  0 }, {     66,   -3,    0, 18,  0,  0 }, {     67,   -3,    0, 18,  0,  0 }, {     68,   -4,    0, 18,  0,  0 }, {     69,   -4,    0, 18,  0,  0 },
        {     70,   -4,    0, 18,  0,  0 }, {     71,   -5,    0, 18,  0,  0 }, {     72,   -5,    0, 18,  0,  0 }, {     73,   -5,    0, 18,  0,  0 }, {     74,   -6,    0, 18,  0,  0 },
        {     75,   -6,    0, 18,  0,  0 }, {     76,   -6,    0, 17,  0,  0 }, {     77,   -7,    0, 17,  0,  0 }, {     78,   -7,    0, 17,  0,  0 }, {     79,   -7,    0, 17,  0,  0 },
        {     80,   -7,    0, 17,  0,  0 }, {     81,   -8,    0, 17,  0,  0 }, {     82,   -8,    0, 17,  0,  0 }, {     83,   -8,    0, 17,  0,  0 }, {     84,   -8,    0, 17,  0,  0 },
        {     85,   -8,    0, 17,  0,  0 }, {     86,   -8,    0, 17,  0,  0 }, {     87,   -9,    0, 17,  0,  0 }, {     88,   -9,    0, 16,  0,  0 }, {     89,   -9,    0, 16,  0,  0 },
        {     90,   -9,    0, 16,  0,  0 }, {     91,   -9,    0, 16,  0,  0 }, {     92,   -9,    0, 16,  0,  0 }, {     93,   -9,    0, 16,  0,  0 }, {     94,   -9,    0, 16,  0,  0 },
        {     95,   -9,    0, 16,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightSBend3, {
        {     23,   32,    0, 24,  0,  0 }, {     23,   31,    0, 24,  0,  0 }, {     23,   30,    0, 24,  0,  0 }, {     23,   29,    0, 24,  0,  0 }, {     23,   28,    0, 24,  0,  0 },
        {     23,   27,    0, 24,  0,  0 }, {     23,   26,    0, 24,  0,  0 }, {     23,   25,    0, 24,  0,  0 }, {     23,   24,    0, 24,  0,  0 }, {     23,   23,    0, 25,  0,  0 },
        {     22,   22,    0, 25,  0,  0 }, {     22,   21,    0, 25,  0,  0 }, {     22,   20,    0, 25,  0,  0 }, {     22,   19,    0, 25,  0,  0 }, {     22,   18,    0, 25,  0,  0 },
        {     22,   17,    0, 25,  0,  0 }, {     22,   16,    0, 25,  0,  0 }, {     21,   15,    0, 25,  0,  0 }, {     21,   14,    0, 25,  0,  0 }, {     21,   13,    0, 25,  0,  0 },
        {     21,   12,    0, 25,  0,  0 }, {     20,   11,    0, 25,  0,  0 }, {     20,   10,    0, 25,  0,  0 }, {     20,    9,    0, 25,  0,  0 }, {     20,    8,    0, 25,  0,  0 },
        {     19,    7,    0, 26,  0,  0 }, {     19,    6,    0, 26,  0,  0 }, {     19,    5,    0, 26,  0,  0 }, {     18,    4,    0, 26,  0,  0 }, {     18,    3,    0, 26,  0,  0 },
        {     17,    2,    0, 26,  0,  0 }, {     17,    1,    0, 26,  0,  0 }, {     17,    0,    0, 26,  0,  0 }, {     16,   -1,    0, 26,  0,  0 }, {     16,   -2,    0, 26,  0,  0 },
        {     15,   -3,    0, 26,  0,  0 }, {     15,   -4,    0, 26,  0,  0 }, {     14,   -5,    0, 26,  0,  0 }, {     14,   -6,    0, 26,  0,  0 }, {     13,   -7,    0, 26,  0,  0 },
        {     13,   -8,    0, 27,  0,  0 }, {     12,   -9,    0, 27,  0,  0 }, {     12,  -10,    0, 27,  0,  0 }, {     11,  -11,    0, 27,  0,  0 }, {     11,  -12,    0, 27,  0,  0 },
        {     10,  -13,    0, 27,  0,  0 }, {      9,  -14,    0, 27,  0,  0 }, {      9,  -15,    0, 27,  0,  0 }, {      8,  -16,    0, 27,  0,  0 }, {      7,  -17,    0, 27,  0,  0 },
        {      7,  -18,    0, 27,  0,  0 }, {      6,  -19,    0, 27,  0,  0 }, {      5,  -20,    0, 27,  0,  0 }, {      5,  -21,    0, 27,  0,  0 }, {      4,  -22,    0, 27,  0,  0 },
        {      3,  -23,    0, 27,  0,  0 }, {      3,  -24,    0, 27,  0,  0 }, {      2,  -25,    0, 27,  0,  0 }, {      1,  -26,    0, 27,  0,  0 }, {      1,  -27,    0, 27,  0,  0 },
        {      0,  -28,    0, 27,  0,  0 }, {      0,  -29,    0, 27,  0,  0 }, {     -1,  -30,    0, 26,  0,  0 }, {     -1,  -31,    0, 26,  0,  0 }, {     -2,  -32,    0, 26,  0,  0 },
        {     -2,  -33,    0, 26,  0,  0 }, {     -3,  -34,    0, 26,  0,  0 }, {     -3,  -35,    0, 26,  0,  0 }, {     -4,  -36,    0, 26,  0,  0 }, {     -4,  -37,    0, 26,  0,  0 },
        {     -4,  -38,    0, 26,  0,  0 }, {     -5,  -39,    0, 26,  0,  0 }, {     -5,  -40,    0, 26,  0,  0 }, {     -5,  -41,    0, 26,  0,  0 }, {     -6,  -42,    0, 26,  0,  0 },
        {     -6,  -43,    0, 26,  0,  0 }, {     -6,  -44,    0, 25,  0,  0 }, {     -7,  -45,    0, 25,  0,  0 }, {     -7,  -46,    0, 25,  0,  0 }, {     -7,  -47,    0, 25,  0,  0 },
        {     -7,  -48,    0, 25,  0,  0 }, {     -8,  -49,    0, 25,  0,  0 }, {     -8,  -50,    0, 25,  0,  0 }, {     -8,  -51,    0, 25,  0,  0 }, {     -8,  -52,    0, 25,  0,  0 },
        {     -8,  -53,    0, 25,  0,  0 }, {     -8,  -54,    0, 25,  0,  0 }, {     -9,  -55,    0, 25,  0,  0 }, {     -9,  -56,    0, 24,  0,  0 }, {     -9,  -57,    0, 24,  0,  0 },
        {     -9,  -58,    0, 24,  0,  0 }, {     -9,  -59,    0, 24,  0,  0 }, {     -9,  -60,    0, 24,  0,  0 }, {     -9,  -61,    0, 24,  0,  0 }, {     -9,  -62,    0, 24,  0,  0 },
        {     -9,  -63,    0, 24,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles0, {
        {     31,    9,    0,  0,  0,  0 }, {     30,    9,    0, 31,  0,  0 }, {     29,    9,    0, 31,  0,  0 }, {     28,    9,    0, 31,  0,  0 }, {     27,    9,    0, 31,  0,  0 },
        {     26,    9,    0, 31,  0,  0 }, {     25,    9,    0, 31,  0,  0 }, {     24,    9,    0, 31,  0,  0 }, {     23,    9,    0, 30,  0,  0 }, {     22,    8,    0, 30,  0,  0 },
        {     21,    8,    0, 30,  0,  0 }, {     20,    8,    0, 30,  0,  0 }, {     19,    8,    0, 30,  0,  0 }, {     18,    7,    0, 30,  0,  0 }, {     17,    7,    0, 30,  0,  0 },
        {     16,    7,    0, 30,  0,  0 }, {     15,    6,    0, 29,  0,  0 }, {     14,    6,    0, 29,  0,  0 }, {     13,    5,    0, 29,  0,  0 }, {     12,    5,    0, 29,  0,  0 },
        {     11,    4,    0, 29,  0,  0 }, {     10,    4,    0, 29,  0,  0 }, {      9,    3,    0, 29,  0,  0 }, {      8,    2,    0, 28,  0,  0 }, {      7,    2,    0, 28,  0,  0 },
        {      6,    1,    0, 28,  0,  0 }, {      5,    0,    0, 28,  0,  0 }, {      4,   -1,    0, 28,  0,  0 }, {      3,   -2,    0, 28,  0,  0 }, {      2,   -3,    0, 27,  0,  0 },
        {      1,   -4,    0, 27,  0,  0 }, {      0,   -5,    0, 27,  0,  0 }, {     -1,   -6,    0, 27,  0,  0 }, {     -2,   -7,    0, 27,  0,  0 }, {     -2,   -8,    0, 27,  0,  0 },
        {     -3,   -9,    0, 26,  0,  0 }, {     -4,  -10,    0, 26,  0,  0 }, {     -4,  -11,    0, 26,  0,  0 }, {     -5,  -12,    0, 26,  0,  0 }, {     -5,  -13,    0, 26,  0,  0 },
        {     -6,  -14,    0, 26,  0,  0 }, {     -6,  -15,    0, 26,  0,  0 }, {     -7,  -16,    0, 25,  0,  0 }, {     -7,  -17,    0, 25,  0,  0 }, {     -7,  -18,    0, 25,  0,  0 },
        {     -8,  -19,    0, 25,  0,  0 }, {     -8,  -20,    0, 25,  0,  0 }, {     -8,  -21,    0, 25,  0,  0 }, {     -8,  -22,    0, 25,  0,  0 }, {     -9,  -23,    0, 25,  0,  0 },
        {     -9,  -24,    0, 24,  0,  0 }, {     -9,  -25,    0, 24,  0,  0 }, {     -9,  -26,    0, 24,  0,  0 }, {     -9,  -27,    0, 24,  0,  0 }, {     -9,  -28,    0, 24,  0,  0 },
        {     -9,  -29,    0, 24,  0,  0 }, {     -9,  -30,    0, 24,  0,  0 }, {     -9,  -31,    0, 24,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles1, {
        {      9,    1,    0,  8,  0,  0 }, {      9,    2,    0,  7,  0,  0 }, {      9,    3,    0,  7,  0,  0 }, {      9,    4,    0,  7,  0,  0 }, {      9,    5,    0,  7,  0,  0 },
        {      9,    6,    0,  7,  0,  0 }, {      9,    7,    0,  7,  0,  0 }, {      9,    8,    0,  7,  0,  0 }, {      9,    9,    0,  6,  0,  0 }, {      8,   10,    0,  6,  0,  0 },
        {      8,   11,    0,  6,  0,  0 }, {      8,   12,    0,  6,  0,  0 }, {      8,   13,    0,  6,  0,  0 }, {      7,   14,    0,  6,  0,  0 }, {      7,   15,    0,  6,  0,  0 },
        {      7,   16,    0,  6,  0,  0 }, {      6,   17,    0,  5,  0,  0 }, {      6,   18,    0,  5,  0,  0 }, {      5,   19,    0,  5,  0,  0 }, {      5,   20,    0,  5,  0,  0 },
        {      4,   21,    0,  5,  0,  0 }, {      4,   22,    0,  5,  0,  0 }, {      3,   23,    0,  5,  0,  0 }, {      2,   24,    0,  4,  0,  0 }, {      2,   25,    0,  4,  0,  0 },
        {      1,   26,    0,  4,  0,  0 }, {      0,   27,    0,  4,  0,  0 }, {     -1,   28,    0,  4,  0,  0 }, {     -2,   29,    0,  4,  0,  0 }, {     -3,   30,    0,  3,  0,  0 },
        {     -4,   31,    0,  3,  0,  0 }, {     -5,   32,    0,  3,  0,  0 }, {     -6,   33,    0,  3,  0,  0 }, {     -7,   34,    0,  3,  0,  0 }, {     -8,   34,    0,  3,  0,  0 },
        {     -9,   35,    0,  2,  0,  0 }, {    -10,   36,    0,  2,  0,  0 }, {    -11,   36,    0,  2,  0,  0 }, {    -12,   37,    0,  2,  0,  0 }, {    -13,   37,    0,  2,  0,  0 },
        {    -14,   38,    0,  2,  0,  0 }, {    -15,   38,    0,  2,  0,  0 }, {    -16,   39,    0,  1,  0,  0 }, {    -17,   39,    0,  1,  0,  0 }, {    -18,   39,    0,  1,  0,  0 },
        {    -19,   40,    0,  1,  0,  0 }, {    -20,   40,    0,  1,  0,  0 }, {    -21,   40,    0,  1,  0,  0 }, {    -22,   40,    0,  1,  0,  0 }, {    -23,   41,    0,  1,  0,  0 },
        {    -24,   41,    0,  0,  0,  0 }, {    -25,   41,    0,  0,  0,  0 }, {    -26,   41,    0,  0,  0,  0 }, {    -27,   41,    0,  0,  0,  0 }, {    -28,   41,    0,  0,  0,  0 },
        {    -29,   41,    0,  0,  0,  0 }, {    -30,   41,    0,  0,  0,  0 }, {    -31,   41,    0,  0,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles2, {
        {      1,   23,    0, 16,  0,  0 }, {      2,   23,    0, 15,  0,  0 }, {      3,   23,    0, 15,  0,  0 }, {      4,   23,    0, 15,  0,  0 }, {      5,   23,    0, 15,  0,  0 },
        {      6,   23,    0, 15,  0,  0 }, {      7,   23,    0, 15,  0,  0 }, {      8,   23,    0, 15,  0,  0 }, {      9,   23,    0, 14,  0,  0 }, {     10,   24,    0, 14,  0,  0 },
        {     11,   24,    0, 14,  0,  0 }, {     12,   24,    0, 14,  0,  0 }, {     13,   24,    0, 14,  0,  0 }, {     14,   25,    0, 14,  0,  0 }, {     15,   25,    0, 14,  0,  0 },
        {     16,   25,    0, 14,  0,  0 }, {     17,   26,    0, 13,  0,  0 }, {     18,   26,    0, 13,  0,  0 }, {     19,   27,    0, 13,  0,  0 }, {     20,   27,    0, 13,  0,  0 },
        {     21,   28,    0, 13,  0,  0 }, {     22,   28,    0, 13,  0,  0 }, {     23,   29,    0, 13,  0,  0 }, {     24,   30,    0, 12,  0,  0 }, {     25,   30,    0, 12,  0,  0 },
        {     26,   31,    0, 12,  0,  0 }, {     27,   32,    0, 12,  0,  0 }, {     28,   33,    0, 12,  0,  0 }, {     29,   34,    0, 12,  0,  0 }, {     30,   35,    0, 11,  0,  0 },
        {     31,   36,    0, 11,  0,  0 }, {     32,   37,    0, 11,  0,  0 }, {     33,   38,    0, 11,  0,  0 }, {     34,   39,    0, 11,  0,  0 }, {     34,   40,    0, 11,  0,  0 },
        {     35,   41,    0, 10,  0,  0 }, {     36,   42,    0, 10,  0,  0 }, {     36,   43,    0, 10,  0,  0 }, {     37,   44,    0, 10,  0,  0 }, {     37,   45,    0, 10,  0,  0 },
        {     38,   46,    0, 10,  0,  0 }, {     38,   47,    0, 10,  0,  0 }, {     39,   48,    0,  9,  0,  0 }, {     39,   49,    0,  9,  0,  0 }, {     39,   50,    0,  9,  0,  0 },
        {     40,   51,    0,  9,  0,  0 }, {     40,   52,    0,  9,  0,  0 }, {     40,   53,    0,  9,  0,  0 }, {     40,   54,    0,  9,  0,  0 }, {     41,   55,    0,  9,  0,  0 },
        {     41,   56,    0,  8,  0,  0 }, {     41,   57,    0,  8,  0,  0 }, {     41,   58,    0,  8,  0,  0 }, {     41,   59,    0,  8,  0,  0 }, {     41,   60,    0,  8,  0,  0 },
        {     41,   61,    0,  8,  0,  0 }, {     41,   62,    0,  8,  0,  0 }, {     41,   63,    0,  8,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles3, {
        {     23,   31,    0, 24,  0,  0 }, {     23,   30,    0, 23,  0,  0 }, {     23,   29,    0, 23,  0,  0 }, {     23,   28,    0, 23,  0,  0 }, {     23,   27,    0, 23,  0,  0 },
        {     23,   26,    0, 23,  0,  0 }, {     23,   25,    0, 23,  0,  0 }, {     23,   24,    0, 23,  0,  0 }, {     23,   23,    0, 22,  0,  0 }, {     24,   22,    0, 22,  0,  0 },
        {     24,   21,    0, 22,  0,  0 }, {     24,   20,    0, 22,  0,  0 }, {     24,   19,    0, 22,  0,  0 }, {     25,   18,    0, 22,  0,  0 }, {     25,   17,    0, 22,  0,  0 },
        {     25,   16,    0, 22,  0,  0 }, {     26,   15,    0, 21,  0,  0 }, {     26,   14,    0, 21,  0,  0 }, {     27,   13,    0, 21,  0,  0 }, {     27,   12,    0, 21,  0,  0 },
        {     28,   11,    0, 21,  0,  0 }, {     28,   10,    0, 21,  0,  0 }, {     29,    9,    0, 21,  0,  0 }, {     30,    8,    0, 20,  0,  0 }, {     30,    7,    0, 20,  0,  0 },
        {     31,    6,    0, 20,  0,  0 }, {     32,    5,    0, 20,  0,  0 }, {     33,    4,    0, 20,  0,  0 }, {     34,    3,    0, 20,  0,  0 }, {     35,    2,    0, 19,  0,  0 },
        {     36,    1,    0, 19,  0,  0 }, {     37,    0,    0, 19,  0,  0 }, {     38,   -1,    0, 19,  0,  0 }, {     39,   -2,    0, 19,  0,  0 }, {     40,   -2,    0, 19,  0,  0 },
        {     41,   -3,    0, 18,  0,  0 }, {     42,   -4,    0, 18,  0,  0 }, {     43,   -4,    0, 18,  0,  0 }, {     44,   -5,    0, 18,  0,  0 }, {     45,   -5,    0, 18,  0,  0 },
        {     46,   -6,    0, 18,  0,  0 }, {     47,   -6,    0, 18,  0,  0 }, {     48,   -7,    0, 17,  0,  0 }, {     49,   -7,    0, 17,  0,  0 }, {     50,   -7,    0, 17,  0,  0 },
        {     51,   -8,    0, 17,  0,  0 }, {     52,   -8,    0, 17,  0,  0 }, {     53,   -8,    0, 17,  0,  0 }, {     54,   -8,    0, 17,  0,  0 }, {     55,   -9,    0, 17,  0,  0 },
        {     56,   -9,    0, 16,  0,  0 }, {     57,   -9,    0, 16,  0,  0 }, {     58,   -9,    0, 16,  0,  0 }, {     59,   -9,    0, 16,  0,  0 }, {     60,   -9,    0, 16,  0,  0 },
        {     61,   -9,    0, 16,  0,  0 }, {     62,   -9,    0, 16,  0,  0 }, {     63,   -9,    0, 16,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles0, {
        {     31,    9,    0,  0,  0,  0 }, {     30,    9,    0,  1,  0,  0 }, {     29,    9,    0,  1,  0,  0 }, {     28,    9,    0,  1,  0,  0 }, {     27,    9,    0,  1,  0,  0 },
        {     26,    9,    0,  1,  0,  0 }, {     25,    9,    0,  1,  0,  0 }, {     24,    9,    0,  1,  0,  0 }, {     23,    9,    0,  1,  0,  0 }, {     22,    9,    0,  1,  0,  0 },
        {     21,    9,    0,  1,  0,  0 }, {     20,   10,    0,  2,  0,  0 }, {     19,   10,    0,  2,  0,  0 }, {     18,   10,    0,  2,  0,  0 }, {     17,   10,    0,  2,  0,  0 },
        {     16,   11,    0,  2,  0,  0 }, {     15,   11,    0,  2,  0,  0 }, {     14,   11,    0,  2,  0,  0 }, {     13,   12,    0,  2,  0,  0 }, {     12,   12,    0,  2,  0,  0 },
        {     11,   12,    0,  2,  0,  0 }, {     10,   13,    0,  3,  0,  0 }, {      9,   13,    0,  3,  0,  0 }, {      8,   14,    0,  3,  0,  0 }, {      7,   14,    0,  3,  0,  0 },
        {      6,   15,    0,  3,  0,  0 }, {      5,   15,    0,  3,  0,  0 }, {      4,   16,    0,  3,  0,  0 }, {      3,   16,    0,  3,  0,  0 }, {      2,   17,    0,  3,  0,  0 },
        {      1,   17,    0,  3,  0,  0 }, {      0,   18,    0,  4,  0,  0 }, {     -1,   19,    0,  4,  0,  0 }, {     -2,   20,    0,  4,  0,  0 }, {     -3,   20,    0,  4,  0,  0 },
        {     -4,   21,    0,  4,  0,  0 }, {     -5,   22,    0,  4,  0,  0 }, {     -6,   23,    0,  4,  0,  0 }, {     -7,   24,    0,  4,  0,  0 }, {     -8,   25,    0,  5,  0,  0 },
        {     -9,   26,    0,  5,  0,  0 }, {    -10,   27,    0,  5,  0,  0 }, {    -11,   28,    0,  5,  0,  0 }, {    -12,   29,    0,  5,  0,  0 }, {    -12,   30,    0,  5,  0,  0 },
        {    -13,   31,    0,  5,  0,  0 }, {    -14,   32,    0,  5,  0,  0 }, {    -15,   33,    0,  6,  0,  0 }, {    -15,   34,    0,  6,  0,  0 }, {    -16,   35,    0,  6,  0,  0 },
        {    -16,   36,    0,  6,  0,  0 }, {    -17,   37,    0,  6,  0,  0 }, {    -17,   38,    0,  6,  0,  0 }, {    -18,   39,    0,  6,  0,  0 }, {    -18,   40,    0,  6,  0,  0 },
        {    -19,   41,    0,  6,  0,  0 }, {    -19,   42,    0,  6,  0,  0 }, {    -20,   43,    0,  7,  0,  0 }, {    -20,   44,    0,  7,  0,  0 }, {    -20,   45,    0,  7,  0,  0 },
        {    -21,   46,    0,  7,  0,  0 }, {    -21,   47,    0,  7,  0,  0 }, {    -21,   48,    0,  7,  0,  0 }, {    -22,   49,    0,  7,  0,  0 }, {    -22,   50,    0,  7,  0,  0 },
        {    -22,   51,    0,  7,  0,  0 }, {    -22,   52,    0,  7,  0,  0 }, {    -23,   53,    0,  8,  0,  0 }, {    -23,   54,    0,  8,  0,  0 }, {    -23,   55,    0,  8,  0,  0 },
        {    -23,   56,    0,  8,  0,  0 }, {    -23,   57,    0,  8,  0,  0 }, {    -23,   58,    0,  8,  0,  0 }, {    -23,   59,    0,  8,  0,  0 }, {    -23,   60,    0,  8,  0,  0 },
        {    -23,   61,    0,  8,  0,  0 }, {    -23,   62,    0,  8,  0,  0 }, {    -23,   63,    0,  8,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles1, {
        {      9,    1,    0,  8,  0,  0 }, {      9,    2,    0,  9,  0,  0 }, {      9,    3,    0,  9,  0,  0 }, {      9,    4,    0,  9,  0,  0 }, {      9,    5,    0,  9,  0,  0 },
        {      9,    6,    0,  9,  0,  0 }, {      9,    7,    0,  9,  0,  0 }, {      9,    8,    0,  9,  0,  0 }, {      9,    9,    0,  9,  0,  0 }, {      9,   10,    0,  9,  0,  0 },
        {      9,   11,    0,  9,  0,  0 }, {     10,   12,    0, 10,  0,  0 }, {     10,   13,    0, 10,  0,  0 }, {     10,   14,    0, 10,  0,  0 }, {     10,   15,    0, 10,  0,  0 },
        {     11,   16,    0, 10,  0,  0 }, {     11,   17,    0, 10,  0,  0 }, {     11,   18,    0, 10,  0,  0 }, {     12,   19,    0, 10,  0,  0 }, {     12,   20,    0, 10,  0,  0 },
        {     12,   21,    0, 10,  0,  0 }, {     13,   22,    0, 11,  0,  0 }, {     13,   23,    0, 11,  0,  0 }, {     14,   24,    0, 11,  0,  0 }, {     14,   25,    0, 11,  0,  0 },
        {     15,   26,    0, 11,  0,  0 }, {     15,   27,    0, 11,  0,  0 }, {     16,   28,    0, 11,  0,  0 }, {     16,   29,    0, 11,  0,  0 }, {     17,   30,    0, 11,  0,  0 },
        {     17,   31,    0, 11,  0,  0 }, {     18,   32,    0, 12,  0,  0 }, {     19,   33,    0, 12,  0,  0 }, {     20,   34,    0, 12,  0,  0 }, {     20,   35,    0, 12,  0,  0 },
        {     21,   36,    0, 12,  0,  0 }, {     22,   37,    0, 12,  0,  0 }, {     23,   38,    0, 12,  0,  0 }, {     24,   39,    0, 12,  0,  0 }, {     25,   40,    0, 13,  0,  0 },
        {     26,   41,    0, 13,  0,  0 }, {     27,   42,    0, 13,  0,  0 }, {     28,   43,    0, 13,  0,  0 }, {     29,   44,    0, 13,  0,  0 }, {     30,   44,    0, 13,  0,  0 },
        {     31,   45,    0, 13,  0,  0 }, {     32,   46,    0, 13,  0,  0 }, {     33,   47,    0, 14,  0,  0 }, {     34,   47,    0, 14,  0,  0 }, {     35,   48,    0, 14,  0,  0 },
        {     36,   48,    0, 14,  0,  0 }, {     37,   49,    0, 14,  0,  0 }, {     38,   49,    0, 14,  0,  0 }, {     39,   50,    0, 14,  0,  0 }, {     40,   50,    0, 14,  0,  0 },
        {     41,   51,    0, 14,  0,  0 }, {     42,   51,    0, 14,  0,  0 }, {     43,   52,    0, 15,  0,  0 }, {     44,   52,    0, 15,  0,  0 }, {     45,   52,    0, 15,  0,  0 },
        {     46,   53,    0, 15,  0,  0 }, {     47,   53,    0, 15,  0,  0 }, {     48,   53,    0, 15,  0,  0 }, {     49,   54,    0, 15,  0,  0 }, {     50,   54,    0, 15,  0,  0 },
        {     51,   54,    0, 15,  0,  0 }, {     52,   54,    0, 15,  0,  0 }, {     53,   55,    0, 16,  0,  0 }, {     54,   55,    0, 16,  0,  0 }, {     55,   55,    0, 16,  0,  0 },
        {     56,   55,    0, 16,  0,  0 }, {     57,   55,    0, 16,  0,  0 }, {     58,   55,    0, 16,  0,  0 }, {     59,   55,    0, 16,  0,  0 }, {     60,   55,    0, 16,  0,  0 },
        {     61,   55,    0, 16,  0,  0 }, {     62,   55,    0, 16,  0,  0 }, {     63,   55,    0, 16,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles2, {
        {      1,   23,    0, 16,  0,  0 }, {      2,   23,    0, 17,  0,  0 }, {      3,   23,    0, 17,  0,  0 }, {      4,   23,    0, 17,  0,  0 }, {      5,   23,    0, 17,  0,  0 },
        {      6,   23,    0, 17,  0,  0 }, {      7,   23,    0, 17,  0,  0 }, {      8,   23,    0, 17,  0,  0 }, {      9,   23,    0, 17,  0,  0 }, {     10,   23,    0, 17,  0,  0 },
        {     11,   23,    0, 17,  0,  0 }, {     12,   22,    0, 18,  0,  0 }, {     13,   22,    0, 18,  0,  0 }, {     14,   22,    0, 18,  0,  0 }, {     15,   22,    0, 18,  0,  0 },
        {     16,   21,    0, 18,  0,  0 }, {     17,   21,    0, 18,  0,  0 }, {     18,   21,    0, 18,  0,  0 }, {     19,   20,    0, 18,  0,  0 }, {     20,   20,    0, 18,  0,  0 },
        {     21,   20,    0, 18,  0,  0 }, {     22,   19,    0, 19,  0,  0 }, {     23,   19,    0, 19,  0,  0 }, {     24,   18,    0, 19,  0,  0 }, {     25,   18,    0, 19,  0,  0 },
        {     26,   17,    0, 19,  0,  0 }, {     27,   17,    0, 19,  0,  0 }, {     28,   16,    0, 19,  0,  0 }, {     29,   16,    0, 19,  0,  0 }, {     30,   15,    0, 19,  0,  0 },
        {     31,   15,    0, 19,  0,  0 }, {     32,   14,    0, 20,  0,  0 }, {     33,   13,    0, 20,  0,  0 }, {     34,   12,    0, 20,  0,  0 }, {     35,   12,    0, 20,  0,  0 },
        {     36,   11,    0, 20,  0,  0 }, {     37,   10,    0, 20,  0,  0 }, {     38,    9,    0, 20,  0,  0 }, {     39,    8,    0, 20,  0,  0 }, {     40,    7,    0, 21,  0,  0 },
        {     41,    6,    0, 21,  0,  0 }, {     42,    5,    0, 21,  0,  0 }, {     43,    4,    0, 21,  0,  0 }, {     44,    3,    0, 21,  0,  0 }, {     44,    2,    0, 21,  0,  0 },
        {     45,    1,    0, 21,  0,  0 }, {     46,    0,    0, 21,  0,  0 }, {     47,   -1,    0, 22,  0,  0 }, {     47,   -2,    0, 22,  0,  0 }, {     48,   -3,    0, 22,  0,  0 },
        {     48,   -4,    0, 22,  0,  0 }, {     49,   -5,    0, 22,  0,  0 }, {     49,   -6,    0, 22,  0,  0 }, {     50,   -7,    0, 22,  0,  0 }, {     50,   -8,    0, 22,  0,  0 },
        {     51,   -9,    0, 22,  0,  0 }, {     51,  -10,    0, 22,  0,  0 }, {     52,  -11,    0, 23,  0,  0 }, {     52,  -12,    0, 23,  0,  0 }, {     52,  -13,    0, 23,  0,  0 },
        {     53,  -14,    0, 23,  0,  0 }, {     53,  -15,    0, 23,  0,  0 }, {     53,  -16,    0, 23,  0,  0 }, {     54,  -17,    0, 23,  0,  0 }, {     54,  -18,    0, 23,  0,  0 },
        {     54,  -19,    0, 23,  0,  0 }, {     54,  -20,    0, 23,  0,  0 }, {     55,  -21,    0, 24,  0,  0 }, {     55,  -22,    0, 24,  0,  0 }, {     55,  -23,    0, 24,  0,  0 },
        {     55,  -24,    0, 24,  0,  0 }, {     55,  -25,    0, 24,  0,  0 }, {     55,  -26,    0, 24,  0,  0 }, {     55,  -27,    0, 24,  0,  0 }, {     55,  -28,    0, 24,  0,  0 },
        {     55,  -29,    0, 24,  0,  0 }, {     55,  -30,    0, 24,  0,  0 }, {     55,  -31,    0, 24,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles3, {
        {     23,   31,    0, 24,  0,  0 }, {     23,   30,    0, 25,  0,  0 }, {     23,   29,    0, 25,  0,  0 }, {     23,   28,    0, 25,  0,  0 }, {     23,   27,    0, 25,  0,  0 },
        {     23,   26,    0, 25,  0,  0 }, {     23,   25,    0, 25,  0,  0 }, {     23,   24,    0, 25,  0,  0 }, {     23,   23,    0, 25,  0,  0 }, {     23,   22,    0, 25,  0,  0 },
        {     23,   21,    0, 25,  0,  0 }, {     22,   20,    0, 26,  0,  0 }, {     22,   19,    0, 26,  0,  0 }, {     22,   18,    0, 26,  0,  0 }, {     22,   17,    0, 26,  0,  0 },
        {     21,   16,    0, 26,  0,  0 }, {     21,   15,    0, 26,  0,  0 }, {     21,   14,    0, 26,  0,  0 }, {     20,   13,    0, 26,  0,  0 }, {     20,   12,    0, 26,  0,  0 },
        {     20,   11,    0, 26,  0,  0 }, {     19,   10,    0, 27,  0,  0 }, {     19,    9,    0, 27,  0,  0 }, {     18,    8,    0, 27,  0,  0 }, {     18,    7,    0, 27,  0,  0 },
        {     17,    6,    0, 27,  0,  0 }, {     17,    5,    0, 27,  0,  0 }, {     16,    4,    0, 27,  0,  0 }, {     16,    3,    0, 27,  0,  0 }, {     15,    2,    0, 27,  0,  0 },
        {     15,    1,    0, 27,  0,  0 }, {     14,    0,    0, 28,  0,  0 }, {     13,   -1,    0, 28,  0,  0 }, {     12,   -2,    0, 28,  0,  0 }, {     12,   -3,    0, 28,  0,  0 },
        {     11,   -4,    0, 28,  0,  0 }, {     10,   -5,    0, 28,  0,  0 }, {      9,   -6,    0, 28,  0,  0 }, {      8,   -7,    0, 28,  0,  0 }, {      7,   -8,    0, 29,  0,  0 },
        {      6,   -9,    0, 29,  0,  0 }, {      5,  -10,    0, 29,  0,  0 }, {      4,  -11,    0, 29,  0,  0 }, {      3,  -12,    0, 29,  0,  0 }, {      2,  -12,    0, 29,  0,  0 },
        {      1,  -13,    0, 29,  0,  0 }, {      0,  -14,    0, 29,  0,  0 }, {     -1,  -15,    0, 30,  0,  0 }, {     -2,  -15,    0, 30,  0,  0 }, {     -3,  -16,    0, 30,  0,  0 },
        {     -4,  -16,    0, 30,  0,  0 }, {     -5,  -17,    0, 30,  0,  0 }, {     -6,  -17,    0, 30,  0,  0 }, {     -7,  -18,    0, 30,  0,  0 }, {     -8,  -18,    0, 30,  0,  0 },
        {     -9,  -19,    0, 30,  0,  0 }, {    -10,  -19,    0, 30,  0,  0 }, {    -11,  -20,    0, 31,  0,  0 }, {    -12,  -20,    0, 31,  0,  0 }, {    -13,  -20,    0, 31,  0,  0 },
        {    -14,  -21,    0, 31,  0,  0 }, {    -15,  -21,    0, 31,  0,  0 }, {    -16,  -21,    0, 31,  0,  0 }, {    -17,  -22,    0, 31,  0,  0 }, {    -18,  -22,    0, 31,  0,  0 },
        {    -19,  -22,    0, 31,  0,  0 }, {    -20,  -22,    0, 31,  0,  0 }, {    -21,  -23,    0,  0,  0,  0 }, {    -22,  -23,    0,  0,  0,  0 }, {    -23,  -23,    0,  0,  0,  0 },
        {    -24,  -23,    0,  0,  0,  0 }, {    -25,  -23,    0,  0,  0,  0 }, {    -26,  -23,    0,  0,  0,  0 }, {    -27,  -23,    0,  0,  0,  0 }, {    -28,  -23,    0,  0,  0,  0 },
        {    -29,  -23,    0,  0,  0,  0 }, {    -30,  -23,    0,  0,  0,  0 }, {    -31,  -23,    0,  0,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp0, {
        {     31,    9,    0,  0,  2,  0 }, {     30,    9,    1, 31,  2,  0 }, {     29,    9,    1, 31,  2,  0 }, {     28,    9,    2, 31,  2,  0 }, {     27,    9,    2, 31,  2,  0 },
        {     26,    9,    3, 31,  2,  0 }, {     25,    9,    3, 31,  2,  0 }, {     24,    9,    4, 31,  2,  0 }, {     23,    9,    4, 30,  2,  0 }, {     22,    8,    5, 30,  2,  0 },
        {     21,    8,    5, 30,  2,  0 }, {     20,    8,    6, 30,  2,  0 }, {     19,    8,    6, 30,  2,  0 }, {     18,    7,    7, 30,  2,  0 }, {     17,    7,    7, 30,  2,  0 },
        {     16,    7,    8, 30,  2,  0 }, {     15,    6,    9, 29,  2,  0 }, {     14,    6,    9, 29,  2,  0 }, {     13,    5,   10, 29,  2,  0 }, {     12,    5,   10, 29,  2,  0 },
        {     11,    4,   11, 29,  2,  0 }, {     10,    4,   11, 29,  2,  0 }, {      9,    3,   12, 29,  2,  0 }, {      8,    2,   12, 28,  2,  0 }, {      7,    2,   13, 28,  2,  0 },
        {      6,    1,   13, 28,  2,  0 }, {      5,    0,   14, 28,  2,  0 }, {      4,   -1,   14, 28,  2,  0 }, {      3,   -2,   15, 28,  2,  0 }, {      2,   -3,   16, 27,  2,  0 },
        {      1,   -4,   16, 27,  2,  0 }, {      0,   -5,   17, 27,  2,  0 }, {     -1,   -6,   17, 27,  2,  0 }, {     -2,   -7,   18, 27,  2,  0 }, {     -2,   -8,   18, 27,  2,  0 },
        {     -3,   -9,   19, 26,  2,  0 }, {     -4,  -10,   19, 26,  2,  0 }, {     -4,  -11,   20, 26,  2,  0 }, {     -5,  -12,   20, 26,  2,  0 }, {     -5,  -13,   21, 26,  2,  0 },
        {     -6,  -14,   21, 26,  2,  0 }, {     -6,  -15,   22, 26,  2,  0 }, {     -7,  -16,   22, 25,  2,  0 }, {     -7,  -17,   23, 25,  2,  0 }, {     -7,  -18,   24, 25,  2,  0 },
        {     -8,  -19,   24, 25,  2,  0 }, {     -8,  -20,   25, 25,  2,  0 }, {     -8,  -21,   25, 25,  2,  0 }, {     -8,  -22,   26, 25,  2,  0 }, {     -9,  -23,   26, 25,  2,  0 },
        {     -9,  -24,   27, 24,  2,  0 }, {     -9,  -25,   27, 24,  2,  0 }, {     -9,  -26,   28, 24,  2,  0 }, {     -9,  -27,   28, 24,  2,  0 }, {     -9,  -28,   29, 24,  2,  0 },
        {     -9,  -29,   29, 24,  2,  0 }, {     -9,  -30,   30, 24,  2,  0 }, {     -9,  -31,   30, 24,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp1, {
        {      9,    1,    0,  8,  2,  0 }, {      9,    2,    1,  7,  2,  0 }, {      9,    3,    1,  7,  2,  0 }, {      9,    4,    2,  7,  2,  0 }, {      9,    5,    2,  7,  2,  0 },
        {      9,    6,    3,  7,  2,  0 }, {      9,    7,    3,  7,  2,  0 }, {      9,    8,    4,  7,  2,  0 }, {      9,    9,    4,  6,  2,  0 }, {      8,   10,    5,  6,  2,  0 },
        {      8,   11,    5,  6,  2,  0 }, {      8,   12,    6,  6,  2,  0 }, {      8,   13,    6,  6,  2,  0 }, {      7,   14,    7,  6,  2,  0 }, {      7,   15,    7,  6,  2,  0 },
        {      7,   16,    8,  6,  2,  0 }, {      6,   17,    9,  5,  2,  0 }, {      6,   18,    9,  5,  2,  0 }, {      5,   19,   10,  5,  2,  0 }, {      5,   20,   10,  5,  2,  0 },
        {      4,   21,   11,  5,  2,  0 }, {      4,   22,   11,  5,  2,  0 }, {      3,   23,   12,  5,  2,  0 }, {      2,   24,   12,  4,  2,  0 }, {      2,   25,   13,  4,  2,  0 },
        {      1,   26,   13,  4,  2,  0 }, {      0,   27,   14,  4,  2,  0 }, {     -1,   28,   14,  4,  2,  0 }, {     -2,   29,   15,  4,  2,  0 }, {     -3,   30,   16,  3,  2,  0 },
        {     -4,   31,   16,  3,  2,  0 }, {     -5,   32,   17,  3,  2,  0 }, {     -6,   33,   17,  3,  2,  0 }, {     -7,   34,   18,  3,  2,  0 }, {     -8,   34,   18,  3,  2,  0 },
        {     -9,   35,   19,  2,  2,  0 }, {    -10,   36,   19,  2,  2,  0 }, {    -11,   36,   20,  2,  2,  0 }, {    -12,   37,   20,  2,  2,  0 }, {    -13,   37,   21,  2,  2,  0 },
        {    -14,   38,   21,  2,  2,  0 }, {    -15,   38,   22,  2,  2,  0 }, {    -16,   39,   22,  1,  2,  0 }, {    -17,   39,   23,  1,  2,  0 }, {    -18,   39,   24,  1,  2,  0 },
        {    -19,   40,   24,  1,  2,  0 }, {    -20,   40,   25,  1,  2,  0 }, {    -21,   40,   25,  1,  2,  0 }, {    -22,   40,   26,  1,  2,  0 }, {    -23,   41,   26,  1,  2,  0 },
        {    -24,   41,   27,  0,  2,  0 }, {    -25,   41,   27,  0,  2,  0 }, {    -26,   41,   28,  0,  2,  0 }, {    -27,   41,   28,  0,  2,  0 }, {    -28,   41,   29,  0,  2,  0 },
        {    -29,   41,   29,  0,  2,  0 }, {    -30,   41,   30,  0,  2,  0 }, {    -31,   41,   30,  0,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp2, {
        {      1,   23,    0, 16,  2,  0 }, {      2,   23,    1, 15,  2,  0 }, {      3,   23,    1, 15,  2,  0 }, {      4,   23,    2, 15,  2,  0 }, {      5,   23,    2, 15,  2,  0 },
        {      6,   23,    3, 15,  2,  0 }, {      7,   23,    3, 15,  2,  0 }, {      8,   23,    4, 15,  2,  0 }, {      9,   23,    4, 14,  2,  0 }, {     10,   24,    5, 14,  2,  0 },
        {     11,   24,    5, 14,  2,  0 }, {     12,   24,    6, 14,  2,  0 }, {     13,   24,    6, 14,  2,  0 }, {     14,   25,    7, 14,  2,  0 }, {     15,   25,    7, 14,  2,  0 },
        {     16,   25,    8, 14,  2,  0 }, {     17,   26,    9, 13,  2,  0 }, {     18,   26,    9, 13,  2,  0 }, {     19,   27,   10, 13,  2,  0 }, {     20,   27,   10, 13,  2,  0 },
        {     21,   28,   11, 13,  2,  0 }, {     22,   28,   11, 13,  2,  0 }, {     23,   29,   12, 13,  2,  0 }, {     24,   30,   12, 12,  2,  0 }, {     25,   30,   13, 12,  2,  0 },
        {     26,   31,   13, 12,  2,  0 }, {     27,   32,   14, 12,  2,  0 }, {     28,   33,   14, 12,  2,  0 }, {     29,   34,   15, 12,  2,  0 }, {     30,   35,   16, 11,  2,  0 },
        {     31,   36,   16, 11,  2,  0 }, {     32,   37,   17, 11,  2,  0 }, {     33,   38,   17, 11,  2,  0 }, {     34,   39,   18, 11,  2,  0 }, {     34,   40,   18, 11,  2,  0 },
        {     35,   41,   19, 10,  2,  0 }, {     36,   42,   19, 10,  2,  0 }, {     36,   43,   20, 10,  2,  0 }, {     37,   44,   20, 10,  2,  0 }, {     37,   45,   21, 10,  2,  0 },
        {     38,   46,   21, 10,  2,  0 }, {     38,   47,   22, 10,  2,  0 }, {     39,   48,   22,  9,  2,  0 }, {     39,   49,   23,  9,  2,  0 }, {     39,   50,   24,  9,  2,  0 },
        {     40,   51,   24,  9,  2,  0 }, {     40,   52,   25,  9,  2,  0 }, {     40,   53,   25,  9,  2,  0 }, {     40,   54,   26,  9,  2,  0 }, {     41,   55,   26,  9,  2,  0 },
        {     41,   56,   27,  8,  2,  0 }, {     41,   57,   27,  8,  2,  0 }, {     41,   58,   28,  8,  2,  0 }, {     41,   59,   28,  8,  2,  0 }, {     41,   60,   29,  8,  2,  0 },
        {     41,   61,   29,  8,  2,  0 }, {     41,   62,   30,  8,  2,  0 }, {     41,   63,   30,  8,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp3, {
        {     23,   31,    0, 24,  2,  0 }, {     23,   30,    1, 23,  2,  0 }, {     23,   29,    1, 23,  2,  0 }, {     23,   28,    2, 23,  2,  0 }, {     23,   27,    2, 23,  2,  0 },
        {     23,   26,    3, 23,  2,  0 }, {     23,   25,    3, 23,  2,  0 }, {     23,   24,    4, 23,  2,  0 }, {     23,   23,    4, 22,  2,  0 }, {     24,   22,    5, 22,  2,  0 },
        {     24,   21,    5, 22,  2,  0 }, {     24,   20,    6, 22,  2,  0 }, {     24,   19,    6, 22,  2,  0 }, {     25,   18,    7, 22,  2,  0 }, {     25,   17,    7, 22,  2,  0 },
        {     25,   16,    8, 22,  2,  0 }, {     26,   15,    9, 21,  2,  0 }, {     26,   14,    9, 21,  2,  0 }, {     27,   13,   10, 21,  2,  0 }, {     27,   12,   10, 21,  2,  0 },
        {     28,   11,   11, 21,  2,  0 }, {     28,   10,   11, 21,  2,  0 }, {     29,    9,   12, 21,  2,  0 }, {     30,    8,   12, 20,  2,  0 }, {     30,    7,   13, 20,  2,  0 },
        {     31,    6,   13, 20,  2,  0 }, {     32,    5,   14, 20,  2,  0 }, {     33,    4,   14, 20,  2,  0 }, {     34,    3,   15, 20,  2,  0 }, {     35,    2,   16, 19,  2,  0 },
        {     36,    1,   16, 19,  2,  0 }, {     37,    0,   17, 19,  2,  0 }, {     38,   -1,   17, 19,  2,  0 }, {     39,   -2,   18, 19,  2,  0 }, {     40,   -2,   18, 19,  2,  0 },
        {     41,   -3,   19, 18,  2,  0 }, {     42,   -4,   19, 18,  2,  0 }, {     43,   -4,   20, 18,  2,  0 }, {     44,   -5,   20, 18,  2,  0 }, {     45,   -5,   21, 18,  2,  0 },
        {     46,   -6,   21, 18,  2,  0 }, {     47,   -6,   22, 18,  2,  0 }, {     48,   -7,   22, 17,  2,  0 }, {     49,   -7,   23, 17,  2,  0 }, {     50,   -7,   24, 17,  2,  0 },
        {     51,   -8,   24, 17,  2,  0 }, {     52,   -8,   25, 17,  2,  0 }, {     53,   -8,   25, 17,  2,  0 }, {     54,   -8,   26, 17,  2,  0 }, {     55,   -9,   26, 17,  2,  0 },
        {     56,   -9,   27, 16,  2,  0 }, {     57,   -9,   27, 16,  2,  0 }, {     58,   -9,   28, 16,  2,  0 }, {     59,   -9,   28, 16,  2,  0 }, {     60,   -9,   29, 16,  2,  0 },
        {     61,   -9,   29, 16,  2,  0 }, {     62,   -9,   30, 16,  2,  0 }, {     63,   -9,   30, 16,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegUp0, {
        {     31,    9,    0,  0,  2,  0 }, {     30,    9,    0,  1,  2,  0 }, {     29,    9,    1,  1,  2,  0 }, {     28,    9,    1,  1,  2,  0 }, {     27,    9,    2,  1,  2,  0 },
        {     26,    9,    2,  1,  2,  0 }, {     25,    9,    2,  1,  2,  0 }, {     24,    9,    3,  1,  2,  0 }, {     23,    9,    3,  1,  2,  0 }, {     22,    9,    4,  1,  2,  0 },
        {     21,    9,    4,  1,  2,  0 }, {     20,   10,    4,  2,  2,  0 }, {     19,   10,    5,  2,  2,  0 }, {     18,   10,    5,  2,  2,  0 }, {     17,   10,    6,  2,  2,  0 },
        {     16,   11,    6,  2,  2,  0 }, {     15,   11,    6,  2,  2,  0 }, {     14,   11,    7,  2,  2,  0 }, {     13,   12,    7,  2,  2,  0 }, {     12,   12,    8,  2,  2,  0 },
        {     11,   12,    8,  2,  2,  0 }, {     10,   13,    8,  3,  2,  0 }, {      9,   13,    9,  3,  2,  0 }, {      8,   14,    9,  3,  2,  0 }, {      7,   14,   10,  3,  2,  0 },
        {      6,   15,   10,  3,  2,  0 }, {      5,   15,   10,  3,  2,  0 }, {      4,   16,   11,  3,  2,  0 }, {      3,   16,   11,  3,  2,  0 }, {      2,   17,   12,  3,  2,  0 },
        {      1,   17,   12,  3,  2,  0 }, {      0,   18,   12,  4,  2,  0 }, {     -1,   19,   13,  4,  2,  0 }, {     -2,   20,   13,  4,  2,  0 }, {     -3,   20,   14,  4,  2,  0 },
        {     -4,   21,   14,  4,  2,  0 }, {     -5,   22,   14,  4,  2,  0 }, {     -6,   23,   15,  4,  2,  0 }, {     -7,   24,   15,  4,  2,  0 }, {     -8,   25,   16,  5,  2,  0 },
        {     -9,   26,   16,  5,  2,  0 }, {    -10,   27,   16,  5,  2,  0 }, {    -11,   28,   17,  5,  2,  0 }, {    -12,   29,   17,  5,  2,  0 }, {    -12,   30,   17,  5,  2,  0 },
        {    -13,   31,   18,  5,  2,  0 }, {    -14,   32,   18,  5,  2,  0 }, {    -15,   33,   19,  6,  2,  0 }, {    -15,   34,   19,  6,  2,  0 }, {    -16,   35,   19,  6,  2,  0 },
        {    -16,   36,   20,  6,  2,  0 }, {    -17,   37,   20,  6,  2,  0 }, {    -17,   38,   21,  6,  2,  0 }, {    -18,   39,   21,  6,  2,  0 }, {    -18,   40,   21,  6,  2,  0 },
        {    -19,   41,   22,  6,  2,  0 }, {    -19,   42,   22,  6,  2,  0 }, {    -20,   43,   23,  7,  2,  0 }, {    -20,   44,   23,  7,  2,  0 }, {    -20,   45,   23,  7,  2,  0 },
        {    -21,   46,   24,  7,  2,  0 }, {    -21,   47,   24,  7,  2,  0 }, {    -21,   48,   25,  7,  2,  0 }, {    -22,   49,   25,  7,  2,  0 }, {    -22,   50,   25,  7,  2,  0 },
        {    -22,   51,   26,  7,  2,  0 }, {    -22,   52,   26,  7,  2,  0 }, {    -23,   53,   27,  8,  2,  0 }, {    -23,   54,   27,  8,  2,  0 }, {    -23,   55,   27,  8,  2,  0 },
        {    -23,   56,   28,  8,  2,  0 }, {    -23,   57,   28,  8,  2,  0 }, {    -23,   58,   29,  8,  2,  0 }, {    -23,   59,   29,  8,  2,  0 }, {    -23,   60,   29,  8,  2,  0 },
        {    -23,   61,   30,  8,  2,  0 }, {    -23,   62,   30,  8,  2,  0 }, {    -23,   63,   31,  8,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegUp1, {
        {      9,    1,    0,  8,  2,  0 }, {      9,    2,    0,  9,  2,  0 }, {      9,    3,    1,  9,  2,  0 }, {      9,    4,    1,  9,  2,  0 }, {      9,    5,    2,  9,  2,  0 },
        {      9,    6,    2,  9,  2,  0 }, {      9,    7,    2,  9,  2,  0 }, {      9,    8,    3,  9,  2,  0 }, {      9,    9,    3,  9,  2,  0 }, {      9,   10,    4,  9,  2,  0 },
        {      9,   11,    4,  9,  2,  0 }, {     10,   12,    4, 10,  2,  0 }, {     10,   13,    5, 10,  2,  0 }, {     10,   14,    5, 10,  2,  0 }, {     10,   15,    6, 10,  2,  0 },
        {     11,   16,    6, 10,  2,  0 }, {     11,   17,    6, 10,  2,  0 }, {     11,   18,    7, 10,  2,  0 }, {     12,   19,    7, 10,  2,  0 }, {     12,   20,    8, 10,  2,  0 },
        {     12,   21,    8, 10,  2,  0 }, {     13,   22,    8, 11,  2,  0 }, {     13,   23,    9, 11,  2,  0 }, {     14,   24,    9, 11,  2,  0 }, {     14,   25,   10, 11,  2,  0 },
        {     15,   26,   10, 11,  2,  0 }, {     15,   27,   10, 11,  2,  0 }, {     16,   28,   11, 11,  2,  0 }, {     16,   29,   11, 11,  2,  0 }, {     17,   30,   12, 11,  2,  0 },
        {     17,   31,   12, 11,  2,  0 }, {     18,   32,   12, 12,  2,  0 }, {     19,   33,   13, 12,  2,  0 }, {     20,   34,   13, 12,  2,  0 }, {     20,   35,   14, 12,  2,  0 },
        {     21,   36,   14, 12,  2,  0 }, {     22,   37,   14, 12,  2,  0 }, {     23,   38,   15, 12,  2,  0 }, {     24,   39,   15, 12,  2,  0 }, {     25,   40,   16, 13,  2,  0 },
        {     26,   41,   16, 13,  2,  0 }, {     27,   42,   16, 13,  2,  0 }, {     28,   43,   17, 13,  2,  0 }, {     29,   44,   17, 13,  2,  0 }, {     30,   44,   17, 13,  2,  0 },
        {     31,   45,   18, 13,  2,  0 }, {     32,   46,   18, 13,  2,  0 }, {     33,   47,   19, 14,  2,  0 }, {     34,   47,   19, 14,  2,  0 }, {     35,   48,   19, 14,  2,  0 },
        {     36,   48,   20, 14,  2,  0 }, {     37,   49,   20, 14,  2,  0 }, {     38,   49,   21, 14,  2,  0 }, {     39,   50,   21, 14,  2,  0 }, {     40,   50,   21, 14,  2,  0 },
        {     41,   51,   22, 14,  2,  0 }, {     42,   51,   22, 14,  2,  0 }, {     43,   52,   23, 15,  2,  0 }, {     44,   52,   23, 15,  2,  0 }, {     45,   52,   23, 15,  2,  0 },
        {     46,   53,   24, 15,  2,  0 }, {     47,   53,   24, 15,  2,  0 }, {     48,   53,   25, 15,  2,  0 }, {     49,   54,   25, 15,  2,  0 }, {     50,   54,   25, 15,  2,  0 },
        {     51,   54,   26, 15,  2,  0 }, {     52,   54,   26, 15,  2,  0 }, {     53,   55,   27, 16,  2,  0 }, {     54,   55,   27, 16,  2,  0 }, {     55,   55,   27, 16,  2,  0 },
        {     56,   55,   28, 16,  2,  0 }, {     57,   55,   28, 16,  2,  0 }, {     58,   55,   29, 16,  2,  0 }, {     59,   55,   29, 16,  2,  0 }, {     60,   55,   29, 16,  2,  0 },
        {     61,   55,   30, 16,  2,  0 }, {     62,   55,   30, 16,  2,  0 }, {     63,   55,   31, 16,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegUp2, {
        {      1,   23,    0, 16,  2,  0 }, {      2,   23,    0, 17,  2,  0 }, {      3,   23,    1, 17,  2,  0 }, {      4,   23,    1, 17,  2,  0 }, {      5,   23,    2, 17,  2,  0 },
        {      6,   23,    2, 17,  2,  0 }, {      7,   23,    2, 17,  2,  0 }, {      8,   23,    3, 17,  2,  0 }, {      9,   23,    3, 17,  2,  0 }, {     10,   23,    4, 17,  2,  0 },
        {     11,   23,    4, 17,  2,  0 }, {     12,   22,    4, 18,  2,  0 }, {     13,   22,    5, 18,  2,  0 }, {     14,   22,    5, 18,  2,  0 }, {     15,   22,    6, 18,  2,  0 },
        {     16,   21,    6, 18,  2,  0 }, {     17,   21,    6, 18,  2,  0 }, {     18,   21,    7, 18,  2,  0 }, {     19,   20,    7, 18,  2,  0 }, {     20,   20,    8, 18,  2,  0 },
        {     21,   20,    8, 18,  2,  0 }, {     22,   19,    8, 19,  2,  0 }, {     23,   19,    9, 19,  2,  0 }, {     24,   18,    9, 19,  2,  0 }, {     25,   18,   10, 19,  2,  0 },
        {     26,   17,   10, 19,  2,  0 }, {     27,   17,   10, 19,  2,  0 }, {     28,   16,   11, 19,  2,  0 }, {     29,   16,   11, 19,  2,  0 }, {     30,   15,   12, 19,  2,  0 },
        {     31,   15,   12, 19,  2,  0 }, {     32,   14,   12, 20,  2,  0 }, {     33,   13,   13, 20,  2,  0 }, {     34,   12,   13, 20,  2,  0 }, {     35,   12,   14, 20,  2,  0 },
        {     36,   11,   14, 20,  2,  0 }, {     37,   10,   14, 20,  2,  0 }, {     38,    9,   15, 20,  2,  0 }, {     39,    8,   15, 20,  2,  0 }, {     40,    7,   16, 21,  2,  0 },
        {     41,    6,   16, 21,  2,  0 }, {     42,    5,   16, 21,  2,  0 }, {     43,    4,   17, 21,  2,  0 }, {     44,    3,   17, 21,  2,  0 }, {     44,    2,   17, 21,  2,  0 },
        {     45,    1,   18, 21,  2,  0 }, {     46,    0,   18, 21,  2,  0 }, {     47,   -1,   19, 22,  2,  0 }, {     47,   -2,   19, 22,  2,  0 }, {     48,   -3,   19, 22,  2,  0 },
        {     48,   -4,   20, 22,  2,  0 }, {     49,   -5,   20, 22,  2,  0 }, {     49,   -6,   21, 22,  2,  0 }, {     50,   -7,   21, 22,  2,  0 }, {     50,   -8,   21, 22,  2,  0 },
        {     51,   -9,   22, 22,  2,  0 }, {     51,  -10,   22, 22,  2,  0 }, {     52,  -11,   23, 23,  2,  0 }, {     52,  -12,   23, 23,  2,  0 }, {     52,  -13,   23, 23,  2,  0 },
        {     53,  -14,   24, 23,  2,  0 }, {     53,  -15,   24, 23,  2,  0 }, {     53,  -16,   25, 23,  2,  0 }, {     54,  -17,   25, 23,  2,  0 }, {     54,  -18,   25, 23,  2,  0 },
        {     54,  -19,   26, 23,  2,  0 }, {     54,  -20,   26, 23,  2,  0 }, {     55,  -21,   27, 24,  2,  0 }, {     55,  -22,   27, 24,  2,  0 }, {     55,  -23,   27, 24,  2,  0 },
        {     55,  -24,   28, 24,  2,  0 }, {     55,  -25,   28, 24,  2,  0 }, {     55,  -26,   29, 24,  2,  0 }, {     55,  -27,   29, 24,  2,  0 }, {     55,  -28,   29, 24,  2,  0 },
        {     55,  -29,   30, 24,  2,  0 }, {     55,  -30,   30, 24,  2,  0 }, {     55,  -31,   31, 24,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegUp3, {
        {     23,   31,    0, 24,  2,  0 }, {     23,   30,    0, 25,  2,  0 }, {     23,   29,    1, 25,  2,  0 }, {     23,   28,    1, 25,  2,  0 }, {     23,   27,    2, 25,  2,  0 },
        {     23,   26,    2, 25,  2,  0 }, {     23,   25,    2, 25,  2,  0 }, {     23,   24,    3, 25,  2,  0 }, {     23,   23,    3, 25,  2,  0 }, {     23,   22,    4, 25,  2,  0 },
        {     23,   21,    4, 25,  2,  0 }, {     22,   20,    4, 26,  2,  0 }, {     22,   19,    5, 26,  2,  0 }, {     22,   18,    5, 26,  2,  0 }, {     22,   17,    6, 26,  2,  0 },
        {     21,   16,    6, 26,  2,  0 }, {     21,   15,    6, 26,  2,  0 }, {     21,   14,    7, 26,  2,  0 }, {     20,   13,    7, 26,  2,  0 }, {     20,   12,    8, 26,  2,  0 },
        {     20,   11,    8, 26,  2,  0 }, {     19,   10,    8, 27,  2,  0 }, {     19,    9,    9, 27,  2,  0 }, {     18,    8,    9, 27,  2,  0 }, {     18,    7,   10, 27,  2,  0 },
        {     17,    6,   10, 27,  2,  0 }, {     17,    5,   10, 27,  2,  0 }, {     16,    4,   11, 27,  2,  0 }, {     16,    3,   11, 27,  2,  0 }, {     15,    2,   12, 27,  2,  0 },
        {     15,    1,   12, 27,  2,  0 }, {     14,    0,   12, 28,  2,  0 }, {     13,   -1,   13, 28,  2,  0 }, {     12,   -2,   13, 28,  2,  0 }, {     12,   -3,   14, 28,  2,  0 },
        {     11,   -4,   14, 28,  2,  0 }, {     10,   -5,   14, 28,  2,  0 }, {      9,   -6,   15, 28,  2,  0 }, {      8,   -7,   15, 28,  2,  0 }, {      7,   -8,   16, 29,  2,  0 },
        {      6,   -9,   16, 29,  2,  0 }, {      5,  -10,   16, 29,  2,  0 }, {      4,  -11,   17, 29,  2,  0 }, {      3,  -12,   17, 29,  2,  0 }, {      2,  -12,   17, 29,  2,  0 },
        {      1,  -13,   18, 29,  2,  0 }, {      0,  -14,   18, 29,  2,  0 }, {     -1,  -15,   19, 30,  2,  0 }, {     -2,  -15,   19, 30,  2,  0 }, {     -3,  -16,   19, 30,  2,  0 },
        {     -4,  -16,   20, 30,  2,  0 }, {     -5,  -17,   20, 30,  2,  0 }, {     -6,  -17,   21, 30,  2,  0 }, {     -7,  -18,   21, 30,  2,  0 }, {     -8,  -18,   21, 30,  2,  0 },
        {     -9,  -19,   22, 30,  2,  0 }, {    -10,  -19,   22, 30,  2,  0 }, {    -11,  -20,   23, 31,  2,  0 }, {    -12,  -20,   23, 31,  2,  0 }, {    -13,  -20,   23, 31,  2,  0 },
        {    -14,  -21,   24, 31,  2,  0 }, {    -15,  -21,   24, 31,  2,  0 }, {    -16,  -21,   25, 31,  2,  0 }, {    -17,  -22,   25, 31,  2,  0 }, {    -18,  -22,   25, 31,  2,  0 },
        {    -19,  -22,   26, 31,  2,  0 }, {    -20,  -22,   26, 31,  2,  0 }, {    -21,  -23,   27,  0,  2,  0 }, {    -22,  -23,   27,  0,  2,  0 }, {    -23,  -23,   27,  0,  2,  0 },
        {    -24,  -23,   28,  0,  2,  0 }, {    -25,  -23,   28,  0,  2,  0 }, {    -26,  -23,   29,  0,  2,  0 }, {    -27,  -23,   29,  0,  2,  0 }, {    -28,  -23,   29,  0,  2,  0 },
        {    -29,  -23,   30,  0,  2,  0 }, {    -30,  -23,   30,  0,  2,  0 }, {    -31,  -23,   31,  0,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown0, {
        {     31,    9,   15,  0,  6,  0 }, {     30,    9,   14, 31,  6,  0 }, {     29,    9,   14, 31,  6,  0 }, {     28,    9,   13, 31,  6,  0 }, {     27,    9,   13, 31,  6,  0 },
        {     26,    9,   12, 31,  6,  0 }, {     25,    9,   12, 31,  6,  0 }, {     24,    9,   11, 31,  6,  0 }, {     23,    9,   11, 30,  6,  0 }, {     22,    8,   10, 30,  6,  0 },
        {     21,    8,    9, 30,  6,  0 }, {     20,    8,    9, 30,  6,  0 }, {     19,    8,    8, 30,  6,  0 }, {     18,    7,    8, 30,  6,  0 }, {     17,    7,    7, 30,  6,  0 },
        {     16,    7,    7, 30,  6,  0 }, {     15,    6,    6, 29,  6,  0 }, {     14,    6,    6, 29,  6,  0 }, {     13,    5,    5, 29,  6,  0 }, {     12,    5,    5, 29,  6,  0 },
        {     11,    4,    4, 29,  6,  0 }, {     10,    4,    3, 29,  6,  0 }, {      9,    3,    3, 29,  6,  0 }, {      8,    2,    2, 28,  6,  0 }, {      7,    2,    2, 28,  6,  0 },
        {      6,    1,    1, 28,  6,  0 }, {      5,    0,    1, 28,  6,  0 }, {      4,   -1,    0, 28,  6,  0 }, {      3,   -2,    0, 28,  6,  0 }, {      2,   -3,   -1, 27,  6,  0 },
        {      1,   -4,   -2, 27,  6,  0 }, {      0,   -5,   -2, 27,  6,  0 }, {     -1,   -6,   -3, 27,  6,  0 }, {     -2,   -7,   -3, 27,  6,  0 }, {     -2,   -8,   -4, 27,  6,  0 },
        {     -3,   -9,   -4, 26,  6,  0 }, {     -4,  -10,   -5, 26,  6,  0 }, {     -4,  -11,   -5, 26,  6,  0 }, {     -5,  -12,   -6, 26,  6,  0 }, {     -5,  -13,   -7, 26,  6,  0 },
        {     -6,  -14,   -7, 26,  6,  0 }, {     -6,  -15,   -8, 26,  6,  0 }, {     -7,  -16,   -8, 25,  6,  0 }, {     -7,  -17,   -9, 25,  6,  0 }, {     -7,  -18,   -9, 25,  6,  0 },
        {     -8,  -19,  -10, 25,  6,  0 }, {     -8,  -20,  -10, 25,  6,  0 }, {     -8,  -21,  -11, 25,  6,  0 }, {     -8,  -22,  -11, 25,  6,  0 }, {     -9,  -23,  -12, 25,  6,  0 },
        {     -9,  -24,  -13, 24,  6,  0 }, {     -9,  -25,  -13, 24,  6,  0 }, {     -9,  -26,  -14, 24,  6,  0 }, {     -9,  -27,  -14, 24,  6,  0 }, {     -9,  -28,  -15, 24,  6,  0 },
        {     -9,  -29,  -15, 24,  6,  0 }, {     -9,  -30,  -16, 24,  6,  0 }, {     -9,  -31,  -16, 24,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown1, {
        {      9,    1,   15,  8,  6,  0 }, {      9,    2,   14,  7,  6,  0 }, {      9,    3,   14,  7,  6,  0 }, {      9,    4,   13,  7,  6,  0 }, {      9,    5,   13,  7,  6,  0 },
        {      9,    6,   12,  7,  6,  0 }, {      9,    7,   12,  7,  6,  0 }, {      9,    8,   11,  7,  6,  0 }, {      9,    9,   11,  6,  6,  0 }, {      8,   10,   10,  6,  6,  0 },
        {      8,   11,    9,  6,  6,  0 }, {      8,   12,    9,  6,  6,  0 }, {      8,   13,    8,  6,  6,  0 }, {      7,   14,    8,  6,  6,  0 }, {      7,   15,    7,  6,  6,  0 },
        {      7,   16,    7,  6,  6,  0 }, {      6,   17,    6,  5,  6,  0 }, {      6,   18,    6,  5,  6,  0 }, {      5,   19,    5,  5,  6,  0 }, {      5,   20,    5,  5,  6,  0 },
        {      4,   21,    4,  5,  6,  0 }, {      4,   22,    3,  5,  6,  0 }, {      3,   23,    3,  5,  6,  0 }, {      2,   24,    2,  4,  6,  0 }, {      2,   25,    2,  4,  6,  0 },
        {      1,   26,    1,  4,  6,  0 }, {      0,   27,    1,  4,  6,  0 }, {     -1,   28,    0,  4,  6,  0 }, {     -2,   29,    0,  4,  6,  0 }, {     -3,   30,   -1,  3,  6,  0 },
        {     -4,   31,   -2,  3,  6,  0 }, {     -5,   32,   -2,  3,  6,  0 }, {     -6,   33,   -3,  3,  6,  0 }, {     -7,   34,   -3,  3,  6,  0 }, {     -8,   34,   -4,  3,  6,  0 },
        {     -9,   35,   -4,  2,  6,  0 }, {    -10,   36,   -5,  2,  6,  0 }, {    -11,   36,   -5,  2,  6,  0 }, {    -12,   37,   -6,  2,  6,  0 }, {    -13,   37,   -7,  2,  6,  0 },
        {    -14,   38,   -7,  2,  6,  0 }, {    -15,   38,   -8,  2,  6,  0 }, {    -16,   39,   -8,  1,  6,  0 }, {    -17,   39,   -9,  1,  6,  0 }, {    -18,   39,   -9,  1,  6,  0 },
        {    -19,   40,  -10,  1,  6,  0 }, {    -20,   40,  -10,  1,  6,  0 }, {    -21,   40,  -11,  1,  6,  0 }, {    -22,   40,  -11,  1,  6,  0 }, {    -23,   41,  -12,  1,  6,  0 },
        {    -24,   41,  -13,  0,  6,  0 }, {    -25,   41,  -13,  0,  6,  0 }, {    -26,   41,  -14,  0,  6,  0 }, {    -27,   41,  -14,  0,  6,  0 }, {    -28,   41,  -15,  0,  6,  0 },
        {    -29,   41,  -15,  0,  6,  0 }, {    -30,   41,  -16,  0,  6,  0 }, {    -31,   41,  -16,  0,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown2, {
        {      1,   23,   15, 16,  6,  0 }, {      2,   23,   14, 15,  6,  0 }, {      3,   23,   14, 15,  6,  0 }, {      4,   23,   13, 15,  6,  0 }, {      5,   23,   13, 15,  6,  0 },
        {      6,   23,   12, 15,  6,  0 }, {      7,   23,   12, 15,  6,  0 }, {      8,   23,   11, 15,  6,  0 }, {      9,   23,   11, 14,  6,  0 }, {     10,   24,   10, 14,  6,  0 },
        {     11,   24,    9, 14,  6,  0 }, {     12,   24,    9, 14,  6,  0 }, {     13,   24,    8, 14,  6,  0 }, {     14,   25,    8, 14,  6,  0 }, {     15,   25,    7, 14,  6,  0 },
        {     16,   25,    7, 14,  6,  0 }, {     17,   26,    6, 13,  6,  0 }, {     18,   26,    6, 13,  6,  0 }, {     19,   27,    5, 13,  6,  0 }, {     20,   27,    5, 13,  6,  0 },
        {     21,   28,    4, 13,  6,  0 }, {     22,   28,    3, 13,  6,  0 }, {     23,   29,    3, 13,  6,  0 }, {     24,   30,    2, 12,  6,  0 }, {     25,   30,    2, 12,  6,  0 },
        {     26,   31,    1, 12,  6,  0 }, {     27,   32,    1, 12,  6,  0 }, {     28,   33,    0, 12,  6,  0 }, {     29,   34,    0, 12,  6,  0 }, {     30,   35,   -1, 11,  6,  0 },
        {     31,   36,   -2, 11,  6,  0 }, {     32,   37,   -2, 11,  6,  0 }, {     33,   38,   -3, 11,  6,  0 }, {     34,   39,   -3, 11,  6,  0 }, {     34,   40,   -4, 11,  6,  0 },
        {     35,   41,   -4, 10,  6,  0 }, {     36,   42,   -5, 10,  6,  0 }, {     36,   43,   -5, 10,  6,  0 }, {     37,   44,   -6, 10,  6,  0 }, {     37,   45,   -7, 10,  6,  0 },
        {     38,   46,   -7, 10,  6,  0 }, {     38,   47,   -8, 10,  6,  0 }, {     39,   48,   -8,  9,  6,  0 }, {     39,   49,   -9,  9,  6,  0 }, {     39,   50,   -9,  9,  6,  0 },
        {     40,   51,  -10,  9,  6,  0 }, {     40,   52,  -10,  9,  6,  0 }, {     40,   53,  -11,  9,  6,  0 }, {     40,   54,  -11,  9,  6,  0 }, {     41,   55,  -12,  9,  6,  0 },
        {     41,   56,  -13,  8,  6,  0 }, {     41,   57,  -13,  8,  6,  0 }, {     41,   58,  -14,  8,  6,  0 }, {     41,   59,  -14,  8,  6,  0 }, {     41,   60,  -15,  8,  6,  0 },
        {     41,   61,  -15,  8,  6,  0 }, {     41,   62,  -16,  8,  6,  0 }, {     41,   63,  -16,  8,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown3, {
        {     23,   31,   15, 24,  6,  0 }, {     23,   30,   14, 23,  6,  0 }, {     23,   29,   14, 23,  6,  0 }, {     23,   28,   13, 23,  6,  0 }, {     23,   27,   13, 23,  6,  0 },
        {     23,   26,   12, 23,  6,  0 }, {     23,   25,   12, 23,  6,  0 }, {     23,   24,   11, 23,  6,  0 }, {     23,   23,   11, 22,  6,  0 }, {     24,   22,   10, 22,  6,  0 },
        {     24,   21,    9, 22,  6,  0 }, {     24,   20,    9, 22,  6,  0 }, {     24,   19,    8, 22,  6,  0 }, {     25,   18,    8, 22,  6,  0 }, {     25,   17,    7, 22,  6,  0 },
        {     25,   16,    7, 22,  6,  0 }, {     26,   15,    6, 21,  6,  0 }, {     26,   14,    6, 21,  6,  0 }, {     27,   13,    5, 21,  6,  0 }, {     27,   12,    5, 21,  6,  0 },
        {     28,   11,    4, 21,  6,  0 }, {     28,   10,    3, 21,  6,  0 }, {     29,    9,    3, 21,  6,  0 }, {     30,    8,    2, 20,  6,  0 }, {     30,    7,    2, 20,  6,  0 },
        {     31,    6,    1, 20,  6,  0 }, {     32,    5,    1, 20,  6,  0 }, {     33,    4,    0, 20,  6,  0 }, {     34,    3,    0, 20,  6,  0 }, {     35,    2,   -1, 19,  6,  0 },
        {     36,    1,   -2, 19,  6,  0 }, {     37,    0,   -2, 19,  6,  0 }, {     38,   -1,   -3, 19,  6,  0 }, {     39,   -2,   -3, 19,  6,  0 }, {     40,   -2,   -4, 19,  6,  0 },
        {     41,   -3,   -4, 18,  6,  0 }, {     42,   -4,   -5, 18,  6,  0 }, {     43,   -4,   -5, 18,  6,  0 }, {     44,   -5,   -6, 18,  6,  0 }, {     45,   -5,   -7, 18,  6,  0 },
        {     46,   -6,   -7, 18,  6,  0 }, {     47,   -6,   -8, 18,  6,  0 }, {     48,   -7,   -8, 17,  6,  0 }, {     49,   -7,   -9, 17,  6,  0 }, {     50,   -7,   -9, 17,  6,  0 },
        {     51,   -8,  -10, 17,  6,  0 }, {     52,   -8,  -10, 17,  6,  0 }, {     53,   -8,  -11, 17,  6,  0 }, {     54,   -8,  -11, 17,  6,  0 }, {     55,   -9,  -12, 17,  6,  0 },
        {     56,   -9,  -13, 16,  6,  0 }, {     57,   -9,  -13, 16,  6,  0 }, {     58,   -9,  -14, 16,  6,  0 }, {     59,   -9,  -14, 16,  6,  0 }, {     60,   -9,  -15, 16,  6,  0 },
        {     61,   -9,  -15, 16,  6,  0 }, {     62,   -9,  -16, 16,  6,  0 }, {     63,   -9,  -16, 16,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegDown0, {
        {     31,    9,   15,  0,  6,  0 }, {     30,    9,   15,  1,  6,  0 }, {     29,    9,   14,  1,  6,  0 }, {     28,    9,   14,  1,  6,  0 }, {     27,    9,   13,  1,  6,  0 },
        {     26,    9,   13,  1,  6,  0 }, {     25,    9,   13,  1,  6,  0 }, {     24,    9,   12,  1,  6,  0 }, {     23,    9,   12,  1,  6,  0 }, {     22,    9,   11,  1,  6,  0 },
        {     21,    9,   11,  1,  6,  0 }, {     20,   10,   10,  2,  6,  0 }, {     19,   10,   10,  2,  6,  0 }, {     18,   10,   10,  2,  6,  0 }, {     17,   10,    9,  2,  6,  0 },
        {     16,   11,    9,  2,  6,  0 }, {     15,   11,    8,  2,  6,  0 }, {     14,   11,    8,  2,  6,  0 }, {     13,   12,    8,  2,  6,  0 }, {     12,   12,    7,  2,  6,  0 },
        {     11,   12,    7,  2,  6,  0 }, {     10,   13,    6,  3,  6,  0 }, {      9,   13,    6,  3,  6,  0 }, {      8,   14,    6,  3,  6,  0 }, {      7,   14,    5,  3,  6,  0 },
        {      6,   15,    5,  3,  6,  0 }, {      5,   15,    4,  3,  6,  0 }, {      4,   16,    4,  3,  6,  0 }, {      3,   16,    4,  3,  6,  0 }, {      2,   17,    3,  3,  6,  0 },
        {      1,   17,    3,  3,  6,  0 }, {      0,   18,    2,  4,  6,  0 }, {     -1,   19,    2,  4,  6,  0 }, {     -2,   20,    1,  4,  6,  0 }, {     -3,   20,    1,  4,  6,  0 },
        {     -4,   21,    1,  4,  6,  0 }, {     -5,   22,    0,  4,  6,  0 }, {     -6,   23,    0,  4,  6,  0 }, {     -7,   24,   -1,  4,  6,  0 }, {     -8,   25,   -1,  5,  6,  0 },
        {     -9,   26,   -1,  5,  6,  0 }, {    -10,   27,   -2,  5,  6,  0 }, {    -11,   28,   -2,  5,  6,  0 }, {    -12,   29,   -3,  5,  6,  0 }, {    -12,   30,   -3,  5,  6,  0 },
        {    -13,   31,   -3,  5,  6,  0 }, {    -14,   32,   -4,  5,  6,  0 }, {    -15,   33,   -4,  6,  6,  0 }, {    -15,   34,   -5,  6,  6,  0 }, {    -16,   35,   -5,  6,  6,  0 },
        {    -16,   36,   -6,  6,  6,  0 }, {    -17,   37,   -6,  6,  6,  0 }, {    -17,   38,   -6,  6,  6,  0 }, {    -18,   39,   -7,  6,  6,  0 }, {    -18,   40,   -7,  6,  6,  0 },
        {    -19,   41,   -8,  6,  6,  0 }, {    -19,   42,   -8,  6,  6,  0 }, {    -20,   43,   -8,  7,  6,  0 }, {    -20,   44,   -9,  7,  6,  0 }, {    -20,   45,   -9,  7,  6,  0 },
        {    -21,   46,  -10,  7,  6,  0 }, {    -21,   47,  -10,  7,  6,  0 }, {    -21,   48,  -10,  7,  6,  0 }, {    -22,   49,  -11,  7,  6,  0 }, {    -22,   50,  -11,  7,  6,  0 },
        {    -22,   51,  -12,  7,  6,  0 }, {    -22,   52,  -12,  7,  6,  0 }, {    -23,   53,  -12,  8,  6,  0 }, {    -23,   54,  -13,  8,  6,  0 }, {    -23,   55,  -13,  8,  6,  0 },
        {    -23,   56,  -14,  8,  6,  0 }, {    -23,   57,  -14,  8,  6,  0 }, {    -23,   58,  -15,  8,  6,  0 }, {    -23,   59,  -15,  8,  6,  0 }, {    -23,   60,  -15,  8,  6,  0 },
        {    -23,   61,  -16,  8,  6,  0 }, {    -23,   62,  -16,  8,  6,  0 }, {    -23,   63,  -17,  8,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegDown1, {
        {      9,    1,   15,  8,  6,  0 }, {      9,    2,   15,  9,  6,  0 }, {      9,    3,   14,  9,  6,  0 }, {      9,    4,   14,  9,  6,  0 }, {      9,    5,   13,  9,  6,  0 },
        {      9,    6,   13,  9,  6,  0 }, {      9,    7,   13,  9,  6,  0 }, {      9,    8,   12,  9,  6,  0 }, {      9,    9,   12,  9,  6,  0 }, {      9,   10,   11,  9,  6,  0 },
        {      9,   11,   11,  9,  6,  0 }, {     10,   12,   10, 10,  6,  0 }, {     10,   13,   10, 10,  6,  0 }, {     10,   14,   10, 10,  6,  0 }, {     10,   15,    9, 10,  6,  0 },
        {     11,   16,    9, 10,  6,  0 }, {     11,   17,    8, 10,  6,  0 }, {     11,   18,    8, 10,  6,  0 }, {     12,   19,    8, 10,  6,  0 }, {     12,   20,    7, 10,  6,  0 },
        {     12,   21,    7, 10,  6,  0 }, {     13,   22,    6, 11,  6,  0 }, {     13,   23,    6, 11,  6,  0 }, {     14,   24,    6, 11,  6,  0 }, {     14,   25,    5, 11,  6,  0 },
        {     15,   26,    5, 11,  6,  0 }, {     15,   27,    4, 11,  6,  0 }, {     16,   28,    4, 11,  6,  0 }, {     16,   29,    4, 11,  6,  0 }, {     17,   30,    3, 11,  6,  0 },
        {     17,   31,    3, 11,  6,  0 }, {     18,   32,    2, 12,  6,  0 }, {     19,   33,    2, 12,  6,  0 }, {     20,   34,    1, 12,  6,  0 }, {     20,   35,    1, 12,  6,  0 },
        {     21,   36,    1, 12,  6,  0 }, {     22,   37,    0, 12,  6,  0 }, {     23,   38,    0, 12,  6,  0 }, {     24,   39,   -1, 12,  6,  0 }, {     25,   40,   -1, 13,  6,  0 },
        {     26,   41,   -1, 13,  6,  0 }, {     27,   42,   -2, 13,  6,  0 }, {     28,   43,   -2, 13,  6,  0 }, {     29,   44,   -3, 13,  6,  0 }, {     30,   44,   -3, 13,  6,  0 },
        {     31,   45,   -3, 13,  6,  0 }, {     32,   46,   -4, 13,  6,  0 }, {     33,   47,   -4, 14,  6,  0 }, {     34,   47,   -5, 14,  6,  0 }, {     35,   48,   -5, 14,  6,  0 },
        {     36,   48,   -6, 14,  6,  0 }, {     37,   49,   -6, 14,  6,  0 }, {     38,   49,   -6, 14,  6,  0 }, {     39,   50,   -7, 14,  6,  0 }, {     40,   50,   -7, 14,  6,  0 },
        {     41,   51,   -8, 14,  6,  0 }, {     42,   51,   -8, 14,  6,  0 }, {     43,   52,   -8, 15,  6,  0 }, {     44,   52,   -9, 15,  6,  0 }, {     45,   52,   -9, 15,  6,  0 },
        {     46,   53,  -10, 15,  6,  0 }, {     47,   53,  -10, 15,  6,  0 }, {     48,   53,  -10, 15,  6,  0 }, {     49,   54,  -11, 15,  6,  0 }, {     50,   54,  -11, 15,  6,  0 },
        {     51,   54,  -12, 15,  6,  0 }, {     52,   54,  -12, 15,  6,  0 }, {     53,   55,  -12, 16,  6,  0 }, {     54,   55,  -13, 16,  6,  0 }, {     55,   55,  -13, 16,  6,  0 },
        {     56,   55,  -14, 16,  6,  0 }, {     57,   55,  -14, 16,  6,  0 }, {     58,   55,  -15, 16,  6,  0 }, {     59,   55,  -15, 16,  6,  0 }, {     60,   55,  -15, 16,  6,  0 },
        {     61,   55,  -16, 16,  6,  0 }, {     62,   55,  -16, 16,  6,  0 }, {     63,   55,  -17, 16,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegDown2, {
        {      1,   23,   15, 16,  6,  0 }, {      2,   23,   15, 17,  6,  0 }, {      3,   23,   14, 17,  6,  0 }, {      4,   23,   14, 17,  6,  0 }, {      5,   23,   13, 17,  6,  0 },
        {      6,   23,   13, 17,  6,  0 }, {      7,   23,   13, 17,  6,  0 }, {      8,   23,   12, 17,  6,  0 }, {      9,   23,   12, 17,  6,  0 }, {     10,   23,   11, 17,  6,  0 },
        {     11,   23,   11, 17,  6,  0 }, {     12,   22,   10, 18,  6,  0 }, {     13,   22,   10, 18,  6,  0 }, {     14,   22,   10, 18,  6,  0 }, {     15,   22,    9, 18,  6,  0 },
        {     16,   21,    9, 18,  6,  0 }, {     17,   21,    8, 18,  6,  0 }, {     18,   21,    8, 18,  6,  0 }, {     19,   20,    8, 18,  6,  0 }, {     20,   20,    7, 18,  6,  0 },
        {     21,   20,    7, 18,  6,  0 }, {     22,   19,    6, 19,  6,  0 }, {     23,   19,    6, 19,  6,  0 }, {     24,   18,    6, 19,  6,  0 }, {     25,   18,    5, 19,  6,  0 },
        {     26,   17,    5, 19,  6,  0 }, {     27,   17,    4, 19,  6,  0 }, {     28,   16,    4, 19,  6,  0 }, {     29,   16,    4, 19,  6,  0 }, {     30,   15,    3, 19,  6,  0 },
        {     31,   15,    3, 19,  6,  0 }, {     32,   14,    2, 20,  6,  0 }, {     33,   13,    2, 20,  6,  0 }, {     34,   12,    1, 20,  6,  0 }, {     35,   12,    1, 20,  6,  0 },
        {     36,   11,    1, 20,  6,  0 }, {     37,   10,    0, 20,  6,  0 }, {     38,    9,    0, 20,  6,  0 }, {     39,    8,   -1, 20,  6,  0 }, {     40,    7,   -1, 21,  6,  0 },
        {     41,    6,   -1, 21,  6,  0 }, {     42,    5,   -2, 21,  6,  0 }, {     43,    4,   -2, 21,  6,  0 }, {     44,    3,   -3, 21,  6,  0 }, {     44,    2,   -3, 21,  6,  0 },
        {     45,    1,   -3, 21,  6,  0 }, {     46,    0,   -4, 21,  6,  0 }, {     47,   -1,   -4, 22,  6,  0 }, {     47,   -2,   -5, 22,  6,  0 }, {     48,   -3,   -5, 22,  6,  0 },
        {     48,   -4,   -6, 22,  6,  0 }, {     49,   -5,   -6, 22,  6,  0 }, {     49,   -6,   -6, 22,  6,  0 }, {     50,   -7,   -7, 22,  6,  0 }, {     50,   -8,   -7, 22,  6,  0 },
        {     51,   -9,   -8, 22,  6,  0 }, {     51,  -10,   -8, 22,  6,  0 }, {     52,  -11,   -8, 23,  6,  0 }, {     52,  -12,   -9, 23,  6,  0 }, {     52,  -13,   -9, 23,  6,  0 },
        {     53,  -14,  -10, 23,  6,  0 }, {     53,  -15,  -10, 23,  6,  0 }, {     53,  -16,  -10, 23,  6,  0 }, {     54,  -17,  -11, 23,  6,  0 }, {     54,  -18,  -11, 23,  6,  0 },
        {     54,  -19,  -12, 23,  6,  0 }, {     54,  -20,  -12, 23,  6,  0 }, {     55,  -21,  -12, 24,  6,  0 }, {     55,  -22,  -13, 24,  6,  0 }, {     55,  -23,  -13, 24,  6,  0 },
        {     55,  -24,  -14, 24,  6,  0 }, {     55,  -25,  -14, 24,  6,  0 }, {     55,  -26,  -15, 24,  6,  0 }, {     55,  -27,  -15, 24,  6,  0 }, {     55,  -28,  -15, 24,  6,  0 },
        {     55,  -29,  -16, 24,  6,  0 }, {     55,  -30,  -16, 24,  6,  0 }, {     55,  -31,  -17, 24,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegDown3, {
        {     23,   31,   15, 24,  6,  0 }, {     23,   30,   15, 25,  6,  0 }, {     23,   29,   14, 25,  6,  0 }, {     23,   28,   14, 25,  6,  0 }, {     23,   27,   13, 25,  6,  0 },
        {     23,   26,   13, 25,  6,  0 }, {     23,   25,   13, 25,  6,  0 }, {     23,   24,   12, 25,  6,  0 }, {     23,   23,   12, 25,  6,  0 }, {     23,   22,   11, 25,  6,  0 },
        {     23,   21,   11, 25,  6,  0 }, {     22,   20,   10, 26,  6,  0 }, {     22,   19,   10, 26,  6,  0 }, {     22,   18,   10, 26,  6,  0 }, {     22,   17,    9, 26,  6,  0 },
        {     21,   16,    9, 26,  6,  0 }, {     21,   15,    8, 26,  6,  0 }, {     21,   14,    8, 26,  6,  0 }, {     20,   13,    8, 26,  6,  0 }, {     20,   12,    7, 26,  6,  0 },
        {     20,   11,    7, 26,  6,  0 }, {     19,   10,    6, 27,  6,  0 }, {     19,    9,    6, 27,  6,  0 }, {     18,    8,    6, 27,  6,  0 }, {     18,    7,    5, 27,  6,  0 },
        {     17,    6,    5, 27,  6,  0 }, {     17,    5,    4, 27,  6,  0 }, {     16,    4,    4, 27,  6,  0 }, {     16,    3,    4, 27,  6,  0 }, {     15,    2,    3, 27,  6,  0 },
        {     15,    1,    3, 27,  6,  0 }, {     14,    0,    2, 28,  6,  0 }, {     13,   -1,    2, 28,  6,  0 }, {     12,   -2,    1, 28,  6,  0 }, {     12,   -3,    1, 28,  6,  0 },
        {     11,   -4,    1, 28,  6,  0 }, {     10,   -5,    0, 28,  6,  0 }, {      9,   -6,    0, 28,  6,  0 }, {      8,   -7,   -1, 28,  6,  0 }, {      7,   -8,   -1, 29,  6,  0 },
        {      6,   -9,   -1, 29,  6,  0 }, {      5,  -10,   -2, 29,  6,  0 }, {      4,  -11,   -2, 29,  6,  0 }, {      3,  -12,   -3, 29,  6,  0 }, {      2,  -12,   -3, 29,  6,  0 },
        {      1,  -13,   -3, 29,  6,  0 }, {      0,  -14,   -4, 29,  6,  0 }, {     -1,  -15,   -4, 30,  6,  0 }, {     -2,  -15,   -5, 30,  6,  0 }, {     -3,  -16,   -5, 30,  6,  0 },
        {     -4,  -16,   -6, 30,  6,  0 }, {     -5,  -17,   -6, 30,  6,  0 }, {     -6,  -17,   -6, 30,  6,  0 }, {     -7,  -18,   -7, 30,  6,  0 }, {     -8,  -18,   -7, 30,  6,  0 },
        {     -9,  -19,   -8, 30,  6,  0 }, {    -10,  -19,   -8, 30,  6,  0 }, {    -11,  -20,   -8, 31,  6,  0 }, {    -12,  -20,   -9, 31,  6,  0 }, {    -13,  -20,   -9, 31,  6,  0 },
        {    -14,  -21,  -10, 31,  6,  0 }, {    -15,  -21,  -10, 31,  6,  0 }, {    -16,  -21,  -10, 31,  6,  0 }, {    -17,  -22,  -11, 31,  6,  0 }, {    -18,  -22,  -11, 31,  6,  0 },
        {    -19,  -22,  -12, 31,  6,  0 }, {    -20,  -22,  -12, 31,  6,  0 }, {    -21,  -23,  -12,  0,  6,  0 }, {    -22,  -23,  -13,  0,  6,  0 }, {    -23,  -23,  -13,  0,  6,  0 },
        {    -24,  -23,  -14,  0,  6,  0 }, {    -25,  -23,  -14,  0,  6,  0 }, {    -26,  -23,  -15,  0,  6,  0 }, {    -27,  -23,  -15,  0,  6,  0 }, {    -28,  -23,  -15,  0,  6,  0 },
        {    -29,  -23,  -16,  0,  6,  0 }, {    -30,  -23,  -16,  0,  6,  0 }, {    -31,  -23,  -17,  0,  6,  0 },
    })
}


namespace OpenRCT2::RightLane
{
    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles0, {
        {     31,   23,    0,  0,  0,  0 }, {     30,   23,    0, 31,  0,  0 }, {     29,   23,    0, 31,  0,  0 }, {     28,   23,    0, 31,  0,  0 }, {     27,   23,    0, 31,  0,  0 },
        {     26,   23,    0, 31,  0,  0 }, {     25,   23,    0, 31,  0,  0 }, {     24,   23,    0, 31,  0,  0 }, {     23,   23,    0, 31,  0,  0 }, {     22,   23,    0, 31,  0,  0 },
        {     21,   22,    0, 31,  0,  0 }, {     20,   22,    0, 31,  0,  0 }, {     19,   22,    0, 31,  0,  0 }, {     18,   22,    0, 31,  0,  0 }, {     17,   22,    0, 31,  0,  0 },
        {     16,   22,    0, 31,  0,  0 }, {     15,   22,    0, 31,  0,  0 }, {     14,   21,    0, 30,  0,  0 }, {     13,   21,    0, 30,  0,  0 }, {     12,   21,    0, 30,  0,  0 },
        {     11,   21,    0, 30,  0,  0 }, {     10,   20,    0, 30,  0,  0 }, {      9,   20,    0, 30,  0,  0 }, {      8,   20,    0, 30,  0,  0 }, {      7,   20,    0, 30,  0,  0 },
        {      6,   19,    0, 30,  0,  0 }, {      5,   19,    0, 30,  0,  0 }, {      4,   19,    0, 30,  0,  0 }, {      3,   18,    0, 30,  0,  0 }, {      2,   18,    0, 30,  0,  0 },
        {      1,   18,    0, 30,  0,  0 }, {      0,   17,    0, 30,  0,  0 }, {     -1,   17,    0, 30,  0,  0 }, {     -2,   16,    0, 29,  0,  0 }, {     -3,   16,    0, 29,  0,  0 },
        {     -4,   16,    0, 29,  0,  0 }, {     -5,   15,    0, 29,  0,  0 }, {     -6,   15,    0, 29,  0,  0 }, {     -7,   14,    0, 29,  0,  0 }, {     -8,   14,    0, 29,  0,  0 },
        {     -9,   13,    0, 29,  0,  0 }, {    -10,   13,    0, 29,  0,  0 }, {    -11,   12,    0, 29,  0,  0 }, {    -12,   12,    0, 29,  0,  0 }, {    -13,   11,    0, 29,  0,  0 },
        {    -14,   10,    0, 29,  0,  0 }, {    -15,   10,    0, 29,  0,  0 }, {    -16,    9,    0, 29,  0,  0 }, {    -17,    8,    0, 28,  0,  0 }, {    -18,    8,    0, 28,  0,  0 },
        {    -19,    7,    0, 28,  0,  0 }, {    -20,    6,    0, 28,  0,  0 }, {    -21,    6,    0, 28,  0,  0 }, {    -22,    5,    0, 28,  0,  0 }, {    -23,    4,    0, 28,  0,  0 },
        {    -24,    3,    0, 28,  0,  0 }, {    -25,    2,    0, 28,  0,  0 }, {    -26,    2,    0, 28,  0,  0 }, {    -27,    1,    0, 28,  0,  0 }, {    -28,    0,    0, 28,  0,  0 },
        {    -29,   -1,    0, 28,  0,  0 }, {    -30,   -2,    0, 28,  0,  0 }, {    -31,   -3,    0, 27,  0,  0 }, {    -32,   -4,    0, 27,  0,  0 }, {    -33,   -5,    0, 27,  0,  0 },
        {    -34,   -6,    0, 27,  0,  0 }, {    -34,   -7,    0, 27,  0,  0 }, {    -35,   -8,    0, 27,  0,  0 }, {    -36,   -9,    0, 27,  0,  0 }, {    -37,  -10,    0, 27,  0,  0 },
        {    -38,  -11,    0, 27,  0,  0 }, {    -38,  -12,    0, 27,  0,  0 }, {    -39,  -13,    0, 27,  0,  0 }, {    -40,  -14,    0, 27,  0,  0 }, {    -40,  -15,    0, 27,  0,  0 },
        {    -41,  -16,    0, 26,  0,  0 }, {    -42,  -17,    0, 26,  0,  0 }, {    -42,  -18,    0, 26,  0,  0 }, {    -43,  -19,    0, 26,  0,  0 }, {    -44,  -20,    0, 26,  0,  0 },
        {    -44,  -21,    0, 26,  0,  0 }, {    -45,  -22,    0, 26,  0,  0 }, {    -45,  -23,    0, 26,  0,  0 }, {    -46,  -24,    0, 26,  0,  0 }, {    -46,  -25,    0, 26,  0,  0 },
        {    -47,  -26,    0, 26,  0,  0 }, {    -47,  -27,    0, 26,  0,  0 }, {    -48,  -28,    0, 26,  0,  0 }, {    -48,  -29,    0, 26,  0,  0 }, {    -48,  -30,    0, 26,  0,  0 },
        {    -49,  -31,    0, 25,  0,  0 }, {    -49,  -32,    0, 25,  0,  0 }, {    -50,  -33,    0, 25,  0,  0 }, {    -50,  -34,    0, 25,  0,  0 }, {    -50,  -35,    0, 25,  0,  0 },
        {    -51,  -36,    0, 25,  0,  0 }, {    -51,  -37,    0, 25,  0,  0 }, {    -51,  -38,    0, 25,  0,  0 }, {    -52,  -39,    0, 25,  0,  0 }, {    -52,  -40,    0, 25,  0,  0 },
        {    -52,  -41,    0, 25,  0,  0 }, {    -52,  -42,    0, 25,  0,  0 }, {    -53,  -43,    0, 25,  0,  0 }, {    -53,  -44,    0, 25,  0,  0 }, {    -53,  -45,    0, 25,  0,  0 },
        {    -53,  -46,    0, 25,  0,  0 }, {    -54,  -47,    0, 24,  0,  0 }, {    -54,  -48,    0, 24,  0,  0 }, {    -54,  -49,    0, 24,  0,  0 }, {    -54,  -50,    0, 24,  0,  0 },
        {    -54,  -51,    0, 24,  0,  0 }, {    -54,  -52,    0, 24,  0,  0 }, {    -54,  -53,    0, 24,  0,  0 }, {    -55,  -54,    0, 24,  0,  0 }, {    -55,  -55,    0, 24,  0,  0 },
        {    -55,  -56,    0, 24,  0,  0 }, {    -55,  -57,    0, 24,  0,  0 }, {    -55,  -58,    0, 24,  0,  0 }, {    -55,  -59,    0, 24,  0,  0 }, {    -55,  -60,    0, 24,  0,  0 },
        {    -55,  -61,    0, 24,  0,  0 }, {    -55,  -62,    0, 24,  0,  0 }, {    -55,  -63,    0, 24,  0,  0 }, {    -55,  -64,    0, 23,  0,  0 }, {    -54,  -64,    0, 23,  0,  0 },
        {    -53,  -64,    0, 23,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles1, {
        {     23,    1,    0,  8,  0,  0 }, {     23,    2,    0,  7,  0,  0 }, {     23,    3,    0,  7,  0,  0 }, {     23,    4,    0,  7,  0,  0 }, {     23,    5,    0,  7,  0,  0 },
        {     23,    6,    0,  7,  0,  0 }, {     23,    7,    0,  7,  0,  0 }, {     23,    8,    0,  7,  0,  0 }, {     23,    9,    0,  7,  0,  0 }, {     23,   10,    0,  7,  0,  0 },
        {     22,   11,    0,  7,  0,  0 }, {     22,   12,    0,  7,  0,  0 }, {     22,   13,    0,  7,  0,  0 }, {     22,   14,    0,  7,  0,  0 }, {     22,   15,    0,  7,  0,  0 },
        {     22,   16,    0,  7,  0,  0 }, {     22,   17,    0,  7,  0,  0 }, {     21,   18,    0,  6,  0,  0 }, {     21,   19,    0,  6,  0,  0 }, {     21,   20,    0,  6,  0,  0 },
        {     21,   21,    0,  6,  0,  0 }, {     20,   22,    0,  6,  0,  0 }, {     20,   23,    0,  6,  0,  0 }, {     20,   24,    0,  6,  0,  0 }, {     20,   25,    0,  6,  0,  0 },
        {     19,   26,    0,  6,  0,  0 }, {     19,   27,    0,  6,  0,  0 }, {     19,   28,    0,  6,  0,  0 }, {     18,   29,    0,  6,  0,  0 }, {     18,   30,    0,  6,  0,  0 },
        {     18,   31,    0,  6,  0,  0 }, {     17,   32,    0,  6,  0,  0 }, {     17,   33,    0,  6,  0,  0 }, {     16,   34,    0,  5,  0,  0 }, {     16,   35,    0,  5,  0,  0 },
        {     16,   36,    0,  5,  0,  0 }, {     15,   37,    0,  5,  0,  0 }, {     15,   38,    0,  5,  0,  0 }, {     14,   39,    0,  5,  0,  0 }, {     14,   40,    0,  5,  0,  0 },
        {     13,   41,    0,  5,  0,  0 }, {     13,   42,    0,  5,  0,  0 }, {     12,   43,    0,  5,  0,  0 }, {     12,   44,    0,  5,  0,  0 }, {     11,   45,    0,  5,  0,  0 },
        {     10,   46,    0,  5,  0,  0 }, {     10,   47,    0,  5,  0,  0 }, {      9,   48,    0,  5,  0,  0 }, {      8,   49,    0,  4,  0,  0 }, {      8,   50,    0,  4,  0,  0 },
        {      7,   51,    0,  4,  0,  0 }, {      6,   52,    0,  4,  0,  0 }, {      6,   53,    0,  4,  0,  0 }, {      5,   54,    0,  4,  0,  0 }, {      4,   55,    0,  4,  0,  0 },
        {      3,   56,    0,  4,  0,  0 }, {      2,   57,    0,  4,  0,  0 }, {      2,   58,    0,  4,  0,  0 }, {      1,   59,    0,  4,  0,  0 }, {      0,   60,    0,  4,  0,  0 },
        {     -1,   61,    0,  4,  0,  0 }, {     -2,   62,    0,  4,  0,  0 }, {     -3,   63,    0,  3,  0,  0 }, {     -4,   64,    0,  3,  0,  0 }, {     -5,   65,    0,  3,  0,  0 },
        {     -6,   66,    0,  3,  0,  0 }, {     -7,   66,    0,  3,  0,  0 }, {     -8,   67,    0,  3,  0,  0 }, {     -9,   68,    0,  3,  0,  0 }, {    -10,   69,    0,  3,  0,  0 },
        {    -11,   70,    0,  3,  0,  0 }, {    -12,   70,    0,  3,  0,  0 }, {    -13,   71,    0,  3,  0,  0 }, {    -14,   72,    0,  3,  0,  0 }, {    -15,   72,    0,  3,  0,  0 },
        {    -16,   73,    0,  2,  0,  0 }, {    -17,   74,    0,  2,  0,  0 }, {    -18,   74,    0,  2,  0,  0 }, {    -19,   75,    0,  2,  0,  0 }, {    -20,   76,    0,  2,  0,  0 },
        {    -21,   76,    0,  2,  0,  0 }, {    -22,   77,    0,  2,  0,  0 }, {    -23,   77,    0,  2,  0,  0 }, {    -24,   78,    0,  2,  0,  0 }, {    -25,   78,    0,  2,  0,  0 },
        {    -26,   79,    0,  2,  0,  0 }, {    -27,   79,    0,  2,  0,  0 }, {    -28,   80,    0,  2,  0,  0 }, {    -29,   80,    0,  2,  0,  0 }, {    -30,   80,    0,  2,  0,  0 },
        {    -31,   81,    0,  1,  0,  0 }, {    -32,   81,    0,  1,  0,  0 }, {    -33,   82,    0,  1,  0,  0 }, {    -34,   82,    0,  1,  0,  0 }, {    -35,   82,    0,  1,  0,  0 },
        {    -36,   83,    0,  1,  0,  0 }, {    -37,   83,    0,  1,  0,  0 }, {    -38,   83,    0,  1,  0,  0 }, {    -39,   84,    0,  1,  0,  0 }, {    -40,   84,    0,  1,  0,  0 },
        {    -41,   84,    0,  1,  0,  0 }, {    -42,   84,    0,  1,  0,  0 }, {    -43,   85,    0,  1,  0,  0 }, {    -44,   85,    0,  1,  0,  0 }, {    -45,   85,    0,  1,  0,  0 },
        {    -46,   85,    0,  1,  0,  0 }, {    -47,   86,    0,  0,  0,  0 }, {    -48,   86,    0,  0,  0,  0 }, {    -49,   86,    0,  0,  0,  0 }, {    -50,   86,    0,  0,  0,  0 },
        {    -51,   86,    0,  0,  0,  0 }, {    -52,   86,    0,  0,  0,  0 }, {    -53,   86,    0,  0,  0,  0 }, {    -54,   87,    0,  0,  0,  0 }, {    -55,   87,    0,  0,  0,  0 },
        {    -56,   87,    0,  0,  0,  0 }, {    -57,   87,    0,  0,  0,  0 }, {    -58,   87,    0,  0,  0,  0 }, {    -59,   87,    0,  0,  0,  0 }, {    -60,   87,    0,  0,  0,  0 },
        {    -61,   87,    0,  0,  0,  0 }, {    -62,   87,    0,  0,  0,  0 }, {    -63,   87,    0,  0,  0,  0 }, {    -64,   87,    0, 31,  0,  0 }, {    -64,   86,    0, 31,  0,  0 },
        {    -64,   85,    0, 31,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles2, {
        {      1,    9,    0, 16,  0,  0 }, {      2,    9,    0, 15,  0,  0 }, {      3,    9,    0, 15,  0,  0 }, {      4,    9,    0, 15,  0,  0 }, {      5,    9,    0, 15,  0,  0 },
        {      6,    9,    0, 15,  0,  0 }, {      7,    9,    0, 15,  0,  0 }, {      8,    9,    0, 15,  0,  0 }, {      9,    9,    0, 15,  0,  0 }, {     10,    9,    0, 15,  0,  0 },
        {     11,   10,    0, 15,  0,  0 }, {     12,   10,    0, 15,  0,  0 }, {     13,   10,    0, 15,  0,  0 }, {     14,   10,    0, 15,  0,  0 }, {     15,   10,    0, 15,  0,  0 },
        {     16,   10,    0, 15,  0,  0 }, {     17,   10,    0, 15,  0,  0 }, {     18,   11,    0, 14,  0,  0 }, {     19,   11,    0, 14,  0,  0 }, {     20,   11,    0, 14,  0,  0 },
        {     21,   11,    0, 14,  0,  0 }, {     22,   12,    0, 14,  0,  0 }, {     23,   12,    0, 14,  0,  0 }, {     24,   12,    0, 14,  0,  0 }, {     25,   12,    0, 14,  0,  0 },
        {     26,   13,    0, 14,  0,  0 }, {     27,   13,    0, 14,  0,  0 }, {     28,   13,    0, 14,  0,  0 }, {     29,   14,    0, 14,  0,  0 }, {     30,   14,    0, 14,  0,  0 },
        {     31,   14,    0, 14,  0,  0 }, {     32,   15,    0, 14,  0,  0 }, {     33,   15,    0, 14,  0,  0 }, {     34,   16,    0, 13,  0,  0 }, {     35,   16,    0, 13,  0,  0 },
        {     36,   16,    0, 13,  0,  0 }, {     37,   17,    0, 13,  0,  0 }, {     38,   17,    0, 13,  0,  0 }, {     39,   18,    0, 13,  0,  0 }, {     40,   18,    0, 13,  0,  0 },
        {     41,   19,    0, 13,  0,  0 }, {     42,   19,    0, 13,  0,  0 }, {     43,   20,    0, 13,  0,  0 }, {     44,   20,    0, 13,  0,  0 }, {     45,   21,    0, 13,  0,  0 },
        {     46,   22,    0, 13,  0,  0 }, {     47,   22,    0, 13,  0,  0 }, {     48,   23,    0, 13,  0,  0 }, {     49,   24,    0, 12,  0,  0 }, {     50,   24,    0, 12,  0,  0 },
        {     51,   25,    0, 12,  0,  0 }, {     52,   26,    0, 12,  0,  0 }, {     53,   26,    0, 12,  0,  0 }, {     54,   27,    0, 12,  0,  0 }, {     55,   28,    0, 12,  0,  0 },
        {     56,   29,    0, 12,  0,  0 }, {     57,   30,    0, 12,  0,  0 }, {     58,   30,    0, 12,  0,  0 }, {     59,   31,    0, 12,  0,  0 }, {     60,   32,    0, 12,  0,  0 },
        {     61,   33,    0, 12,  0,  0 }, {     62,   34,    0, 12,  0,  0 }, {     63,   35,    0, 11,  0,  0 }, {     64,   36,    0, 11,  0,  0 }, {     65,   37,    0, 11,  0,  0 },
        {     66,   38,    0, 11,  0,  0 }, {     66,   39,    0, 11,  0,  0 }, {     67,   40,    0, 11,  0,  0 }, {     68,   41,    0, 11,  0,  0 }, {     69,   42,    0, 11,  0,  0 },
        {     70,   43,    0, 11,  0,  0 }, {     70,   44,    0, 11,  0,  0 }, {     71,   45,    0, 11,  0,  0 }, {     72,   46,    0, 11,  0,  0 }, {     72,   47,    0, 11,  0,  0 },
        {     73,   48,    0, 10,  0,  0 }, {     74,   49,    0, 10,  0,  0 }, {     74,   50,    0, 10,  0,  0 }, {     75,   51,    0, 10,  0,  0 }, {     76,   52,    0, 10,  0,  0 },
        {     76,   53,    0, 10,  0,  0 }, {     77,   54,    0, 10,  0,  0 }, {     77,   55,    0, 10,  0,  0 }, {     78,   56,    0, 10,  0,  0 }, {     78,   57,    0, 10,  0,  0 },
        {     79,   58,    0, 10,  0,  0 }, {     79,   59,    0, 10,  0,  0 }, {     80,   60,    0, 10,  0,  0 }, {     80,   61,    0, 10,  0,  0 }, {     80,   62,    0, 10,  0,  0 },
        {     81,   63,    0,  9,  0,  0 }, {     81,   64,    0,  9,  0,  0 }, {     82,   65,    0,  9,  0,  0 }, {     82,   66,    0,  9,  0,  0 }, {     82,   67,    0,  9,  0,  0 },
        {     83,   68,    0,  9,  0,  0 }, {     83,   69,    0,  9,  0,  0 }, {     83,   70,    0,  9,  0,  0 }, {     84,   71,    0,  9,  0,  0 }, {     84,   72,    0,  9,  0,  0 },
        {     84,   73,    0,  9,  0,  0 }, {     84,   74,    0,  9,  0,  0 }, {     85,   75,    0,  9,  0,  0 }, {     85,   76,    0,  9,  0,  0 }, {     85,   77,    0,  9,  0,  0 },
        {     85,   78,    0,  9,  0,  0 }, {     86,   79,    0,  8,  0,  0 }, {     86,   80,    0,  8,  0,  0 }, {     86,   81,    0,  8,  0,  0 }, {     86,   82,    0,  8,  0,  0 },
        {     86,   83,    0,  8,  0,  0 }, {     86,   84,    0,  8,  0,  0 }, {     86,   85,    0,  8,  0,  0 }, {     87,   86,    0,  8,  0,  0 }, {     87,   87,    0,  8,  0,  0 },
        {     87,   88,    0,  8,  0,  0 }, {     87,   89,    0,  8,  0,  0 }, {     87,   90,    0,  8,  0,  0 }, {     87,   91,    0,  8,  0,  0 }, {     87,   92,    0,  8,  0,  0 },
        {     87,   93,    0,  8,  0,  0 }, {     87,   94,    0,  8,  0,  0 }, {     87,   95,    0,  8,  0,  0 }, {     87,   96,    0,  7,  0,  0 }, {     86,   96,    0,  7,  0,  0 },
        {     85,   96,    0,  7,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles3, {
        {      9,   31,    0, 24,  0,  0 }, {      9,   30,    0, 23,  0,  0 }, {      9,   29,    0, 23,  0,  0 }, {      9,   28,    0, 23,  0,  0 }, {      9,   27,    0, 23,  0,  0 },
        {      9,   26,    0, 23,  0,  0 }, {      9,   25,    0, 23,  0,  0 }, {      9,   24,    0, 23,  0,  0 }, {      9,   23,    0, 23,  0,  0 }, {      9,   22,    0, 23,  0,  0 },
        {     10,   21,    0, 23,  0,  0 }, {     10,   20,    0, 23,  0,  0 }, {     10,   19,    0, 23,  0,  0 }, {     10,   18,    0, 23,  0,  0 }, {     10,   17,    0, 23,  0,  0 },
        {     10,   16,    0, 23,  0,  0 }, {     10,   15,    0, 23,  0,  0 }, {     11,   14,    0, 22,  0,  0 }, {     11,   13,    0, 22,  0,  0 }, {     11,   12,    0, 22,  0,  0 },
        {     11,   11,    0, 22,  0,  0 }, {     12,   10,    0, 22,  0,  0 }, {     12,    9,    0, 22,  0,  0 }, {     12,    8,    0, 22,  0,  0 }, {     12,    7,    0, 22,  0,  0 },
        {     13,    6,    0, 22,  0,  0 }, {     13,    5,    0, 22,  0,  0 }, {     13,    4,    0, 22,  0,  0 }, {     14,    3,    0, 22,  0,  0 }, {     14,    2,    0, 22,  0,  0 },
        {     14,    1,    0, 22,  0,  0 }, {     15,    0,    0, 22,  0,  0 }, {     15,   -1,    0, 22,  0,  0 }, {     16,   -2,    0, 21,  0,  0 }, {     16,   -3,    0, 21,  0,  0 },
        {     16,   -4,    0, 21,  0,  0 }, {     17,   -5,    0, 21,  0,  0 }, {     17,   -6,    0, 21,  0,  0 }, {     18,   -7,    0, 21,  0,  0 }, {     18,   -8,    0, 21,  0,  0 },
        {     19,   -9,    0, 21,  0,  0 }, {     19,  -10,    0, 21,  0,  0 }, {     20,  -11,    0, 21,  0,  0 }, {     20,  -12,    0, 21,  0,  0 }, {     21,  -13,    0, 21,  0,  0 },
        {     22,  -14,    0, 21,  0,  0 }, {     22,  -15,    0, 21,  0,  0 }, {     23,  -16,    0, 21,  0,  0 }, {     24,  -17,    0, 20,  0,  0 }, {     24,  -18,    0, 20,  0,  0 },
        {     25,  -19,    0, 20,  0,  0 }, {     26,  -20,    0, 20,  0,  0 }, {     26,  -21,    0, 20,  0,  0 }, {     27,  -22,    0, 20,  0,  0 }, {     28,  -23,    0, 20,  0,  0 },
        {     29,  -24,    0, 20,  0,  0 }, {     30,  -25,    0, 20,  0,  0 }, {     30,  -26,    0, 20,  0,  0 }, {     31,  -27,    0, 20,  0,  0 }, {     32,  -28,    0, 20,  0,  0 },
        {     33,  -29,    0, 20,  0,  0 }, {     34,  -30,    0, 20,  0,  0 }, {     35,  -31,    0, 19,  0,  0 }, {     36,  -32,    0, 19,  0,  0 }, {     37,  -33,    0, 19,  0,  0 },
        {     38,  -34,    0, 19,  0,  0 }, {     39,  -34,    0, 19,  0,  0 }, {     40,  -35,    0, 19,  0,  0 }, {     41,  -36,    0, 19,  0,  0 }, {     42,  -37,    0, 19,  0,  0 },
        {     43,  -38,    0, 19,  0,  0 }, {     44,  -38,    0, 19,  0,  0 }, {     45,  -39,    0, 19,  0,  0 }, {     46,  -40,    0, 19,  0,  0 }, {     47,  -40,    0, 19,  0,  0 },
        {     48,  -41,    0, 18,  0,  0 }, {     49,  -42,    0, 18,  0,  0 }, {     50,  -42,    0, 18,  0,  0 }, {     51,  -43,    0, 18,  0,  0 }, {     52,  -44,    0, 18,  0,  0 },
        {     53,  -44,    0, 18,  0,  0 }, {     54,  -45,    0, 18,  0,  0 }, {     55,  -45,    0, 18,  0,  0 }, {     56,  -46,    0, 18,  0,  0 }, {     57,  -46,    0, 18,  0,  0 },
        {     58,  -47,    0, 18,  0,  0 }, {     59,  -47,    0, 18,  0,  0 }, {     60,  -48,    0, 18,  0,  0 }, {     61,  -48,    0, 18,  0,  0 }, {     62,  -48,    0, 18,  0,  0 },
        {     63,  -49,    0, 17,  0,  0 }, {     64,  -49,    0, 17,  0,  0 }, {     65,  -50,    0, 17,  0,  0 }, {     66,  -50,    0, 17,  0,  0 }, {     67,  -50,    0, 17,  0,  0 },
        {     68,  -51,    0, 17,  0,  0 }, {     69,  -51,    0, 17,  0,  0 }, {     70,  -51,    0, 17,  0,  0 }, {     71,  -52,    0, 17,  0,  0 }, {     72,  -52,    0, 17,  0,  0 },
        {     73,  -52,    0, 17,  0,  0 }, {     74,  -52,    0, 17,  0,  0 }, {     75,  -53,    0, 17,  0,  0 }, {     76,  -53,    0, 17,  0,  0 }, {     77,  -53,    0, 17,  0,  0 },
        {     78,  -53,    0, 17,  0,  0 }, {     79,  -54,    0, 16,  0,  0 }, {     80,  -54,    0, 16,  0,  0 }, {     81,  -54,    0, 16,  0,  0 }, {     82,  -54,    0, 16,  0,  0 },
        {     83,  -54,    0, 16,  0,  0 }, {     84,  -54,    0, 16,  0,  0 }, {     85,  -54,    0, 16,  0,  0 }, {     86,  -55,    0, 16,  0,  0 }, {     87,  -55,    0, 16,  0,  0 },
        {     88,  -55,    0, 16,  0,  0 }, {     89,  -55,    0, 16,  0,  0 }, {     90,  -55,    0, 16,  0,  0 }, {     91,  -55,    0, 16,  0,  0 }, {     92,  -55,    0, 16,  0,  0 },
        {     93,  -55,    0, 16,  0,  0 }, {     94,  -55,    0, 16,  0,  0 }, {     95,  -55,    0, 16,  0,  0 }, {     96,  -55,    0, 15,  0,  0 }, {     96,  -54,    0, 15,  0,  0 },
        {     96,  -53,    0, 15,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles0, {
        {     31,   23,    0,  0,  0,  0 }, {     30,   23,    0,  1,  0,  0 }, {     29,   23,    0,  1,  0,  0 }, {     28,   23,    0,  1,  0,  0 }, {     27,   23,    0,  1,  0,  0 },
        {     26,   23,    0,  1,  0,  0 }, {     25,   23,    0,  1,  0,  0 }, {     24,   23,    0,  1,  0,  0 }, {     23,   23,    0,  1,  0,  0 }, {     22,   24,    0,  1,  0,  0 },
        {     21,   24,    0,  1,  0,  0 }, {     20,   24,    0,  1,  0,  0 }, {     19,   24,    0,  1,  0,  0 }, {     18,   24,    0,  1,  0,  0 }, {     17,   24,    0,  1,  0,  0 },
        {     16,   25,    0,  2,  0,  0 }, {     15,   25,    0,  2,  0,  0 }, {     14,   25,    0,  2,  0,  0 }, {     13,   25,    0,  2,  0,  0 }, {     12,   26,    0,  2,  0,  0 },
        {     11,   26,    0,  2,  0,  0 }, {     10,   26,    0,  2,  0,  0 }, {      9,   26,    0,  2,  0,  0 }, {      8,   27,    0,  2,  0,  0 }, {      7,   27,    0,  2,  0,  0 },
        {      6,   27,    0,  2,  0,  0 }, {      5,   28,    0,  2,  0,  0 }, {      4,   28,    0,  2,  0,  0 }, {      3,   29,    0,  3,  0,  0 }, {      2,   29,    0,  3,  0,  0 },
        {      1,   29,    0,  3,  0,  0 }, {      0,   30,    0,  3,  0,  0 }, {     -1,   30,    0,  3,  0,  0 }, {     -2,   31,    0,  3,  0,  0 }, {     -3,   31,    0,  3,  0,  0 },
        {     -4,   32,    0,  3,  0,  0 }, {     -5,   33,    0,  3,  0,  0 }, {     -6,   33,    0,  3,  0,  0 }, {     -7,   34,    0,  3,  0,  0 }, {     -8,   34,    0,  3,  0,  0 },
        {     -9,   35,    0,  3,  0,  0 }, {    -10,   36,    0,  4,  0,  0 }, {    -11,   36,    0,  4,  0,  0 }, {    -12,   37,    0,  4,  0,  0 }, {    -13,   38,    0,  4,  0,  0 },
        {    -14,   39,    0,  4,  0,  0 }, {    -15,   39,    0,  4,  0,  0 }, {    -16,   40,    0,  4,  0,  0 }, {    -17,   41,    0,  4,  0,  0 }, {    -18,   42,    0,  4,  0,  0 },
        {    -19,   43,    0,  4,  0,  0 }, {    -20,   44,    0,  4,  0,  0 }, {    -21,   45,    0,  5,  0,  0 }, {    -22,   46,    0,  5,  0,  0 }, {    -23,   47,    0,  5,  0,  0 },
        {    -24,   48,    0,  5,  0,  0 }, {    -25,   49,    0,  5,  0,  0 }, {    -25,   50,    0,  5,  0,  0 }, {    -26,   51,    0,  5,  0,  0 }, {    -27,   52,    0,  5,  0,  0 },
        {    -28,   53,    0,  5,  0,  0 }, {    -28,   54,    0,  5,  0,  0 }, {    -29,   55,    0,  6,  0,  0 }, {    -30,   56,    0,  6,  0,  0 }, {    -30,   57,    0,  6,  0,  0 },
        {    -31,   58,    0,  6,  0,  0 }, {    -31,   59,    0,  6,  0,  0 }, {    -32,   60,    0,  6,  0,  0 }, {    -33,   61,    0,  6,  0,  0 }, {    -33,   62,    0,  6,  0,  0 },
        {    -34,   63,    0,  6,  0,  0 }, {    -34,   64,    0,  6,  0,  0 }, {    -35,   65,    0,  6,  0,  0 }, {    -35,   66,    0,  6,  0,  0 }, {    -35,   67,    0,  6,  0,  0 },
        {    -36,   68,    0,  7,  0,  0 }, {    -36,   69,    0,  7,  0,  0 }, {    -37,   70,    0,  7,  0,  0 }, {    -37,   71,    0,  7,  0,  0 }, {    -37,   72,    0,  7,  0,  0 },
        {    -38,   73,    0,  7,  0,  0 }, {    -38,   74,    0,  7,  0,  0 }, {    -38,   75,    0,  7,  0,  0 }, {    -38,   76,    0,  7,  0,  0 }, {    -39,   77,    0,  7,  0,  0 },
        {    -39,   78,    0,  7,  0,  0 }, {    -39,   79,    0,  7,  0,  0 }, {    -39,   80,    0,  7,  0,  0 }, {    -40,   81,    0,  8,  0,  0 }, {    -40,   82,    0,  8,  0,  0 },
        {    -40,   83,    0,  8,  0,  0 }, {    -40,   84,    0,  8,  0,  0 }, {    -40,   85,    0,  8,  0,  0 }, {    -40,   86,    0,  8,  0,  0 }, {    -41,   87,    0,  8,  0,  0 },
        {    -41,   88,    0,  8,  0,  0 }, {    -41,   89,    0,  8,  0,  0 }, {    -41,   90,    0,  8,  0,  0 }, {    -41,   91,    0,  8,  0,  0 }, {    -41,   92,    0,  8,  0,  0 },
        {    -41,   93,    0,  8,  0,  0 }, {    -41,   94,    0,  8,  0,  0 }, {    -41,   95,    0,  8,  0,  0 }, {    -41,   96,    0,  9,  0,  0 }, {    -40,   96,    0,  9,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles1, {
        {     23,    1,    0,  8,  0,  0 }, {     23,    2,    0,  9,  0,  0 }, {     23,    3,    0,  9,  0,  0 }, {     23,    4,    0,  9,  0,  0 }, {     23,    5,    0,  9,  0,  0 },
        {     23,    6,    0,  9,  0,  0 }, {     23,    7,    0,  9,  0,  0 }, {     23,    8,    0,  9,  0,  0 }, {     23,    9,    0,  9,  0,  0 }, {     24,   10,    0,  9,  0,  0 },
        {     24,   11,    0,  9,  0,  0 }, {     24,   12,    0,  9,  0,  0 }, {     24,   13,    0,  9,  0,  0 }, {     24,   14,    0,  9,  0,  0 }, {     24,   15,    0,  9,  0,  0 },
        {     25,   16,    0, 10,  0,  0 }, {     25,   17,    0, 10,  0,  0 }, {     25,   18,    0, 10,  0,  0 }, {     25,   19,    0, 10,  0,  0 }, {     26,   20,    0, 10,  0,  0 },
        {     26,   21,    0, 10,  0,  0 }, {     26,   22,    0, 10,  0,  0 }, {     26,   23,    0, 10,  0,  0 }, {     27,   24,    0, 10,  0,  0 }, {     27,   25,    0, 10,  0,  0 },
        {     27,   26,    0, 10,  0,  0 }, {     28,   27,    0, 10,  0,  0 }, {     28,   28,    0, 10,  0,  0 }, {     29,   29,    0, 11,  0,  0 }, {     29,   30,    0, 11,  0,  0 },
        {     29,   31,    0, 11,  0,  0 }, {     30,   32,    0, 11,  0,  0 }, {     30,   33,    0, 11,  0,  0 }, {     31,   34,    0, 11,  0,  0 }, {     31,   35,    0, 11,  0,  0 },
        {     32,   36,    0, 11,  0,  0 }, {     33,   37,    0, 11,  0,  0 }, {     33,   38,    0, 11,  0,  0 }, {     34,   39,    0, 11,  0,  0 }, {     34,   40,    0, 11,  0,  0 },
        {     35,   41,    0, 11,  0,  0 }, {     36,   42,    0, 12,  0,  0 }, {     36,   43,    0, 12,  0,  0 }, {     37,   44,    0, 12,  0,  0 }, {     38,   45,    0, 12,  0,  0 },
        {     39,   46,    0, 12,  0,  0 }, {     39,   47,    0, 12,  0,  0 }, {     40,   48,    0, 12,  0,  0 }, {     41,   49,    0, 12,  0,  0 }, {     42,   50,    0, 12,  0,  0 },
        {     43,   51,    0, 12,  0,  0 }, {     44,   52,    0, 12,  0,  0 }, {     45,   53,    0, 13,  0,  0 }, {     46,   54,    0, 13,  0,  0 }, {     47,   55,    0, 13,  0,  0 },
        {     48,   56,    0, 13,  0,  0 }, {     49,   57,    0, 13,  0,  0 }, {     50,   57,    0, 13,  0,  0 }, {     51,   58,    0, 13,  0,  0 }, {     52,   59,    0, 13,  0,  0 },
        {     53,   60,    0, 13,  0,  0 }, {     54,   60,    0, 13,  0,  0 }, {     55,   61,    0, 14,  0,  0 }, {     56,   62,    0, 14,  0,  0 }, {     57,   62,    0, 14,  0,  0 },
        {     58,   63,    0, 14,  0,  0 }, {     59,   63,    0, 14,  0,  0 }, {     60,   64,    0, 14,  0,  0 }, {     61,   65,    0, 14,  0,  0 }, {     62,   65,    0, 14,  0,  0 },
        {     63,   66,    0, 14,  0,  0 }, {     64,   66,    0, 14,  0,  0 }, {     65,   67,    0, 14,  0,  0 }, {     66,   67,    0, 14,  0,  0 }, {     67,   67,    0, 14,  0,  0 },
        {     68,   68,    0, 15,  0,  0 }, {     69,   68,    0, 15,  0,  0 }, {     70,   69,    0, 15,  0,  0 }, {     71,   69,    0, 15,  0,  0 }, {     72,   69,    0, 15,  0,  0 },
        {     73,   70,    0, 15,  0,  0 }, {     74,   70,    0, 15,  0,  0 }, {     75,   70,    0, 15,  0,  0 }, {     76,   70,    0, 15,  0,  0 }, {     77,   71,    0, 15,  0,  0 },
        {     78,   71,    0, 15,  0,  0 }, {     79,   71,    0, 15,  0,  0 }, {     80,   71,    0, 15,  0,  0 }, {     81,   72,    0, 16,  0,  0 }, {     82,   72,    0, 16,  0,  0 },
        {     83,   72,    0, 16,  0,  0 }, {     84,   72,    0, 16,  0,  0 }, {     85,   72,    0, 16,  0,  0 }, {     86,   72,    0, 16,  0,  0 }, {     87,   73,    0, 16,  0,  0 },
        {     88,   73,    0, 16,  0,  0 }, {     89,   73,    0, 16,  0,  0 }, {     90,   73,    0, 16,  0,  0 }, {     91,   73,    0, 16,  0,  0 }, {     92,   73,    0, 16,  0,  0 },
        {     93,   73,    0, 16,  0,  0 }, {     94,   73,    0, 16,  0,  0 }, {     95,   73,    0, 16,  0,  0 }, {     96,   73,    0, 17,  0,  0 }, {     96,   72,    0, 17,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles2, {
        {      1,    9,    0, 16,  0,  0 }, {      2,    9,    0, 17,  0,  0 }, {      3,    9,    0, 17,  0,  0 }, {      4,    9,    0, 17,  0,  0 }, {      5,    9,    0, 17,  0,  0 },
        {      6,    9,    0, 17,  0,  0 }, {      7,    9,    0, 17,  0,  0 }, {      8,    9,    0, 17,  0,  0 }, {      9,    9,    0, 17,  0,  0 }, {     10,    8,    0, 17,  0,  0 },
        {     11,    8,    0, 17,  0,  0 }, {     12,    8,    0, 17,  0,  0 }, {     13,    8,    0, 17,  0,  0 }, {     14,    8,    0, 17,  0,  0 }, {     15,    8,    0, 17,  0,  0 },
        {     16,    7,    0, 18,  0,  0 }, {     17,    7,    0, 18,  0,  0 }, {     18,    7,    0, 18,  0,  0 }, {     19,    7,    0, 18,  0,  0 }, {     20,    6,    0, 18,  0,  0 },
        {     21,    6,    0, 18,  0,  0 }, {     22,    6,    0, 18,  0,  0 }, {     23,    6,    0, 18,  0,  0 }, {     24,    5,    0, 18,  0,  0 }, {     25,    5,    0, 18,  0,  0 },
        {     26,    5,    0, 18,  0,  0 }, {     27,    4,    0, 18,  0,  0 }, {     28,    4,    0, 18,  0,  0 }, {     29,    3,    0, 19,  0,  0 }, {     30,    3,    0, 19,  0,  0 },
        {     31,    3,    0, 19,  0,  0 }, {     32,    2,    0, 19,  0,  0 }, {     33,    2,    0, 19,  0,  0 }, {     34,    1,    0, 19,  0,  0 }, {     35,    1,    0, 19,  0,  0 },
        {     36,    0,    0, 19,  0,  0 }, {     37,   -1,    0, 19,  0,  0 }, {     38,   -1,    0, 19,  0,  0 }, {     39,   -2,    0, 19,  0,  0 }, {     40,   -2,    0, 19,  0,  0 },
        {     41,   -3,    0, 19,  0,  0 }, {     42,   -4,    0, 20,  0,  0 }, {     43,   -4,    0, 20,  0,  0 }, {     44,   -5,    0, 20,  0,  0 }, {     45,   -6,    0, 20,  0,  0 },
        {     46,   -7,    0, 20,  0,  0 }, {     47,   -7,    0, 20,  0,  0 }, {     48,   -8,    0, 20,  0,  0 }, {     49,   -9,    0, 20,  0,  0 }, {     50,  -10,    0, 20,  0,  0 },
        {     51,  -11,    0, 20,  0,  0 }, {     52,  -12,    0, 20,  0,  0 }, {     53,  -13,    0, 21,  0,  0 }, {     54,  -14,    0, 21,  0,  0 }, {     55,  -15,    0, 21,  0,  0 },
        {     56,  -16,    0, 21,  0,  0 }, {     57,  -17,    0, 21,  0,  0 }, {     57,  -18,    0, 21,  0,  0 }, {     58,  -19,    0, 21,  0,  0 }, {     59,  -20,    0, 21,  0,  0 },
        {     60,  -21,    0, 21,  0,  0 }, {     60,  -22,    0, 21,  0,  0 }, {     61,  -23,    0, 22,  0,  0 }, {     62,  -24,    0, 22,  0,  0 }, {     62,  -25,    0, 22,  0,  0 },
        {     63,  -26,    0, 22,  0,  0 }, {     63,  -27,    0, 22,  0,  0 }, {     64,  -28,    0, 22,  0,  0 }, {     65,  -29,    0, 22,  0,  0 }, {     65,  -30,    0, 22,  0,  0 },
        {     66,  -31,    0, 22,  0,  0 }, {     66,  -32,    0, 22,  0,  0 }, {     67,  -33,    0, 22,  0,  0 }, {     67,  -34,    0, 22,  0,  0 }, {     67,  -35,    0, 22,  0,  0 },
        {     68,  -36,    0, 23,  0,  0 }, {     68,  -37,    0, 23,  0,  0 }, {     69,  -38,    0, 23,  0,  0 }, {     69,  -39,    0, 23,  0,  0 }, {     69,  -40,    0, 23,  0,  0 },
        {     70,  -41,    0, 23,  0,  0 }, {     70,  -42,    0, 23,  0,  0 }, {     70,  -43,    0, 23,  0,  0 }, {     70,  -44,    0, 23,  0,  0 }, {     71,  -45,    0, 23,  0,  0 },
        {     71,  -46,    0, 23,  0,  0 }, {     71,  -47,    0, 23,  0,  0 }, {     71,  -48,    0, 23,  0,  0 }, {     72,  -49,    0, 24,  0,  0 }, {     72,  -50,    0, 24,  0,  0 },
        {     72,  -51,    0, 24,  0,  0 }, {     72,  -52,    0, 24,  0,  0 }, {     72,  -53,    0, 24,  0,  0 }, {     72,  -54,    0, 24,  0,  0 }, {     73,  -55,    0, 24,  0,  0 },
        {     73,  -56,    0, 24,  0,  0 }, {     73,  -57,    0, 24,  0,  0 }, {     73,  -58,    0, 24,  0,  0 }, {     73,  -59,    0, 24,  0,  0 }, {     73,  -60,    0, 24,  0,  0 },
        {     73,  -61,    0, 24,  0,  0 }, {     73,  -62,    0, 24,  0,  0 }, {     73,  -63,    0, 24,  0,  0 }, {     73,  -64,    0, 25,  0,  0 }, {     72,  -64,    0, 25,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles3, {
        {      9,   31,    0, 24,  0,  0 }, {      9,   30,    0, 25,  0,  0 }, {      9,   29,    0, 25,  0,  0 }, {      9,   28,    0, 25,  0,  0 }, {      9,   27,    0, 25,  0,  0 },
        {      9,   26,    0, 25,  0,  0 }, {      9,   25,    0, 25,  0,  0 }, {      9,   24,    0, 25,  0,  0 }, {      9,   23,    0, 25,  0,  0 }, {      8,   22,    0, 25,  0,  0 },
        {      8,   21,    0, 25,  0,  0 }, {      8,   20,    0, 25,  0,  0 }, {      8,   19,    0, 25,  0,  0 }, {      8,   18,    0, 25,  0,  0 }, {      8,   17,    0, 25,  0,  0 },
        {      7,   16,    0, 26,  0,  0 }, {      7,   15,    0, 26,  0,  0 }, {      7,   14,    0, 26,  0,  0 }, {      7,   13,    0, 26,  0,  0 }, {      6,   12,    0, 26,  0,  0 },
        {      6,   11,    0, 26,  0,  0 }, {      6,   10,    0, 26,  0,  0 }, {      6,    9,    0, 26,  0,  0 }, {      5,    8,    0, 26,  0,  0 }, {      5,    7,    0, 26,  0,  0 },
        {      5,    6,    0, 26,  0,  0 }, {      4,    5,    0, 26,  0,  0 }, {      4,    4,    0, 26,  0,  0 }, {      3,    3,    0, 27,  0,  0 }, {      3,    2,    0, 27,  0,  0 },
        {      3,    1,    0, 27,  0,  0 }, {      2,    0,    0, 27,  0,  0 }, {      2,   -1,    0, 27,  0,  0 }, {      1,   -2,    0, 27,  0,  0 }, {      1,   -3,    0, 27,  0,  0 },
        {      0,   -4,    0, 27,  0,  0 }, {     -1,   -5,    0, 27,  0,  0 }, {     -1,   -6,    0, 27,  0,  0 }, {     -2,   -7,    0, 27,  0,  0 }, {     -2,   -8,    0, 27,  0,  0 },
        {     -3,   -9,    0, 27,  0,  0 }, {     -4,  -10,    0, 28,  0,  0 }, {     -4,  -11,    0, 28,  0,  0 }, {     -5,  -12,    0, 28,  0,  0 }, {     -6,  -13,    0, 28,  0,  0 },
        {     -7,  -14,    0, 28,  0,  0 }, {     -7,  -15,    0, 28,  0,  0 }, {     -8,  -16,    0, 28,  0,  0 }, {     -9,  -17,    0, 28,  0,  0 }, {    -10,  -18,    0, 28,  0,  0 },
        {    -11,  -19,    0, 28,  0,  0 }, {    -12,  -20,    0, 28,  0,  0 }, {    -13,  -21,    0, 29,  0,  0 }, {    -14,  -22,    0, 29,  0,  0 }, {    -15,  -23,    0, 29,  0,  0 },
        {    -16,  -24,    0, 29,  0,  0 }, {    -17,  -25,    0, 29,  0,  0 }, {    -18,  -25,    0, 29,  0,  0 }, {    -19,  -26,    0, 29,  0,  0 }, {    -20,  -27,    0, 29,  0,  0 },
        {    -21,  -28,    0, 29,  0,  0 }, {    -22,  -28,    0, 29,  0,  0 }, {    -23,  -29,    0, 30,  0,  0 }, {    -24,  -30,    0, 30,  0,  0 }, {    -25,  -30,    0, 30,  0,  0 },
        {    -26,  -31,    0, 30,  0,  0 }, {    -27,  -31,    0, 30,  0,  0 }, {    -28,  -32,    0, 30,  0,  0 }, {    -29,  -33,    0, 30,  0,  0 }, {    -30,  -33,    0, 30,  0,  0 },
        {    -31,  -34,    0, 30,  0,  0 }, {    -32,  -34,    0, 30,  0,  0 }, {    -33,  -35,    0, 30,  0,  0 }, {    -34,  -35,    0, 30,  0,  0 }, {    -35,  -35,    0, 30,  0,  0 },
        {    -36,  -36,    0, 31,  0,  0 }, {    -37,  -36,    0, 31,  0,  0 }, {    -38,  -37,    0, 31,  0,  0 }, {    -39,  -37,    0, 31,  0,  0 }, {    -40,  -37,    0, 31,  0,  0 },
        {    -41,  -38,    0, 31,  0,  0 }, {    -42,  -38,    0, 31,  0,  0 }, {    -43,  -38,    0, 31,  0,  0 }, {    -44,  -38,    0, 31,  0,  0 }, {    -45,  -39,    0, 31,  0,  0 },
        {    -46,  -39,    0, 31,  0,  0 }, {    -47,  -39,    0, 31,  0,  0 }, {    -48,  -39,    0, 31,  0,  0 }, {    -49,  -40,    0,  0,  0,  0 }, {    -50,  -40,    0,  0,  0,  0 },
        {    -51,  -40,    0,  0,  0,  0 }, {    -52,  -40,    0,  0,  0,  0 }, {    -53,  -40,    0,  0,  0,  0 }, {    -54,  -40,    0,  0,  0,  0 }, {    -55,  -41,    0,  0,  0,  0 },
        {    -56,  -41,    0,  0,  0,  0 }, {    -57,  -41,    0,  0,  0,  0 }, {    -58,  -41,    0,  0,  0,  0 }, {    -59,  -41,    0,  0,  0,  0 }, {    -60,  -41,    0,  0,  0,  0 },
        {    -61,  -41,    0,  0,  0,  0 }, {    -62,  -41,    0,  0,  0,  0 }, {    -63,  -41,    0,  0,  0,  0 }, {    -64,  -41,    0,  1,  0,  0 }, {    -64,  -40,    0,  1,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp0, {
        {     31,   23,    0,  0,  2,  0 }, {     30,   23,    1, 31,  2,  0 }, {     29,   23,    1, 31,  2,  0 }, {     28,   23,    2, 31,  2,  0 }, {     27,   23,    2, 31,  2,  0 },
        {     26,   23,    3, 31,  2,  0 }, {     25,   23,    3, 31,  2,  0 }, {     24,   23,    4, 31,  2,  0 }, {     23,   23,    4, 31,  2,  0 }, {     22,   23,    5, 31,  2,  0 },
        {     21,   22,    5, 31,  2,  0 }, {     20,   22,    6, 31,  2,  0 }, {     19,   22,    6, 31,  2,  0 }, {     18,   22,    7, 31,  2,  0 }, {     17,   22,    7, 31,  2,  0 },
        {     16,   22,    8, 31,  2,  0 }, {     15,   22,    8, 31,  2,  0 }, {     14,   21,    9, 30,  2,  0 }, {     13,   21,    9, 30,  2,  0 }, {     12,   21,   10, 30,  2,  0 },
        {     11,   21,   10, 30,  2,  0 }, {     10,   20,   11, 30,  2,  0 }, {      9,   20,   11, 30,  2,  0 }, {      8,   20,   12, 30,  2,  0 }, {      7,   20,   12, 30,  2,  0 },
        {      6,   19,   13, 30,  2,  0 }, {      5,   19,   13, 30,  2,  0 }, {      4,   19,   14, 30,  2,  0 }, {      3,   18,   14, 30,  2,  0 }, {      2,   18,   15, 30,  2,  0 },
        {      1,   18,   15, 30,  2,  0 }, {      0,   17,   16, 30,  2,  0 }, {     -1,   17,   16, 30,  2,  0 }, {     -2,   16,   17, 29,  2,  0 }, {     -3,   16,   17, 29,  2,  0 },
        {     -4,   16,   18, 29,  2,  0 }, {     -5,   15,   18, 29,  2,  0 }, {     -6,   15,   19, 29,  2,  0 }, {     -7,   14,   19, 29,  2,  0 }, {     -8,   14,   20, 29,  2,  0 },
        {     -9,   13,   20, 29,  2,  0 }, {    -10,   13,   21, 29,  2,  0 }, {    -11,   12,   21, 29,  2,  0 }, {    -12,   12,   22, 29,  2,  0 }, {    -13,   11,   22, 29,  2,  0 },
        {    -14,   10,   23, 29,  2,  0 }, {    -15,   10,   23, 29,  2,  0 }, {    -16,    9,   24, 29,  2,  0 }, {    -17,    8,   24, 28,  2,  0 }, {    -18,    8,   25, 28,  2,  0 },
        {    -19,    7,   25, 28,  2,  0 }, {    -20,    6,   26, 28,  2,  0 }, {    -21,    6,   26, 28,  2,  0 }, {    -22,    5,   27, 28,  2,  0 }, {    -23,    4,   27, 28,  2,  0 },
        {    -24,    3,   28, 28,  2,  0 }, {    -25,    2,   28, 28,  2,  0 }, {    -26,    2,   29, 28,  2,  0 }, {    -27,    1,   29, 28,  2,  0 }, {    -28,    0,   30, 28,  2,  0 },
        {    -29,   -1,   30, 28,  2,  0 }, {    -30,   -2,   31, 28,  2,  0 }, {    -31,   -3,   31, 27,  2,  0 }, {    -32,   -4,   32, 27,  2,  0 }, {    -33,   -5,   33, 27,  2,  0 },
        {    -34,   -6,   33, 27,  2,  0 }, {    -34,   -7,   34, 27,  2,  0 }, {    -35,   -8,   34, 27,  2,  0 }, {    -36,   -9,   35, 27,  2,  0 }, {    -37,  -10,   35, 27,  2,  0 },
        {    -38,  -11,   36, 27,  2,  0 }, {    -38,  -12,   36, 27,  2,  0 }, {    -39,  -13,   37, 27,  2,  0 }, {    -40,  -14,   37, 27,  2,  0 }, {    -40,  -15,   38, 27,  2,  0 },
        {    -41,  -16,   38, 26,  2,  0 }, {    -42,  -17,   39, 26,  2,  0 }, {    -42,  -18,   39, 26,  2,  0 }, {    -43,  -19,   40, 26,  2,  0 }, {    -44,  -20,   40, 26,  2,  0 },
        {    -44,  -21,   41, 26,  2,  0 }, {    -45,  -22,   41, 26,  2,  0 }, {    -45,  -23,   42, 26,  2,  0 }, {    -46,  -24,   42, 26,  2,  0 }, {    -46,  -25,   43, 26,  2,  0 },
        {    -47,  -26,   43, 26,  2,  0 }, {    -47,  -27,   44, 26,  2,  0 }, {    -48,  -28,   44, 26,  2,  0 }, {    -48,  -29,   45, 26,  2,  0 }, {    -48,  -30,   45, 26,  2,  0 },
        {    -49,  -31,   46, 25,  2,  0 }, {    -49,  -32,   46, 25,  2,  0 }, {    -50,  -33,   47, 25,  2,  0 }, {    -50,  -34,   47, 25,  2,  0 }, {    -50,  -35,   48, 25,  2,  0 },
        {    -51,  -36,   48, 25,  2,  0 }, {    -51,  -37,   49, 25,  2,  0 }, {    -51,  -38,   49, 25,  2,  0 }, {    -52,  -39,   50, 25,  2,  0 }, {    -52,  -40,   50, 25,  2,  0 },
        {    -52,  -41,   51, 25,  2,  0 }, {    -52,  -42,   51, 25,  2,  0 }, {    -53,  -43,   52, 25,  2,  0 }, {    -53,  -44,   52, 25,  2,  0 }, {    -53,  -45,   53, 25,  2,  0 },
        {    -53,  -46,   53, 25,  2,  0 }, {    -54,  -47,   54, 24,  2,  0 }, {    -54,  -48,   54, 24,  2,  0 }, {    -54,  -49,   55, 24,  2,  0 }, {    -54,  -50,   55, 24,  2,  0 },
        {    -54,  -51,   56, 24,  2,  0 }, {    -54,  -52,   56, 24,  2,  0 }, {    -54,  -53,   57, 24,  2,  0 }, {    -55,  -54,   57, 24,  2,  0 }, {    -55,  -55,   58, 24,  2,  0 },
        {    -55,  -56,   58, 24,  2,  0 }, {    -55,  -57,   59, 24,  2,  0 }, {    -55,  -58,   59, 24,  2,  0 }, {    -55,  -59,   60, 24,  2,  0 }, {    -55,  -60,   60, 24,  2,  0 },
        {    -55,  -61,   61, 24,  2,  0 }, {    -55,  -62,   61, 24,  2,  0 }, {    -55,  -63,   62, 24,  2,  0 }, {    -55,  -64,   62, 23,  2,  0 }, {    -54,  -64,   63, 23,  2,  0 },
        {    -53,  -64,   63, 23,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp1, {
        {     23,    1,    0,  8,  2,  0 }, {     23,    2,    1,  7,  2,  0 }, {     23,    3,    1,  7,  2,  0 }, {     23,    4,    2,  7,  2,  0 }, {     23,    5,    2,  7,  2,  0 },
        {     23,    6,    3,  7,  2,  0 }, {     23,    7,    3,  7,  2,  0 }, {     23,    8,    4,  7,  2,  0 }, {     23,    9,    4,  7,  2,  0 }, {     23,   10,    5,  7,  2,  0 },
        {     22,   11,    5,  7,  2,  0 }, {     22,   12,    6,  7,  2,  0 }, {     22,   13,    6,  7,  2,  0 }, {     22,   14,    7,  7,  2,  0 }, {     22,   15,    7,  7,  2,  0 },
        {     22,   16,    8,  7,  2,  0 }, {     22,   17,    8,  7,  2,  0 }, {     21,   18,    9,  6,  2,  0 }, {     21,   19,    9,  6,  2,  0 }, {     21,   20,   10,  6,  2,  0 },
        {     21,   21,   10,  6,  2,  0 }, {     20,   22,   11,  6,  2,  0 }, {     20,   23,   11,  6,  2,  0 }, {     20,   24,   12,  6,  2,  0 }, {     20,   25,   12,  6,  2,  0 },
        {     19,   26,   13,  6,  2,  0 }, {     19,   27,   13,  6,  2,  0 }, {     19,   28,   14,  6,  2,  0 }, {     18,   29,   14,  6,  2,  0 }, {     18,   30,   15,  6,  2,  0 },
        {     18,   31,   15,  6,  2,  0 }, {     17,   32,   16,  6,  2,  0 }, {     17,   33,   16,  6,  2,  0 }, {     16,   34,   17,  5,  2,  0 }, {     16,   35,   17,  5,  2,  0 },
        {     16,   36,   18,  5,  2,  0 }, {     15,   37,   18,  5,  2,  0 }, {     15,   38,   19,  5,  2,  0 }, {     14,   39,   19,  5,  2,  0 }, {     14,   40,   20,  5,  2,  0 },
        {     13,   41,   20,  5,  2,  0 }, {     13,   42,   21,  5,  2,  0 }, {     12,   43,   21,  5,  2,  0 }, {     12,   44,   22,  5,  2,  0 }, {     11,   45,   22,  5,  2,  0 },
        {     10,   46,   23,  5,  2,  0 }, {     10,   47,   23,  5,  2,  0 }, {      9,   48,   24,  5,  2,  0 }, {      8,   49,   24,  4,  2,  0 }, {      8,   50,   25,  4,  2,  0 },
        {      7,   51,   25,  4,  2,  0 }, {      6,   52,   26,  4,  2,  0 }, {      6,   53,   26,  4,  2,  0 }, {      5,   54,   27,  4,  2,  0 }, {      4,   55,   27,  4,  2,  0 },
        {      3,   56,   28,  4,  2,  0 }, {      2,   57,   28,  4,  2,  0 }, {      2,   58,   29,  4,  2,  0 }, {      1,   59,   29,  4,  2,  0 }, {      0,   60,   30,  4,  2,  0 },
        {     -1,   61,   30,  4,  2,  0 }, {     -2,   62,   31,  4,  2,  0 }, {     -3,   63,   31,  3,  2,  0 }, {     -4,   64,   32,  3,  2,  0 }, {     -5,   65,   33,  3,  2,  0 },
        {     -6,   66,   33,  3,  2,  0 }, {     -7,   66,   34,  3,  2,  0 }, {     -8,   67,   34,  3,  2,  0 }, {     -9,   68,   35,  3,  2,  0 }, {    -10,   69,   35,  3,  2,  0 },
        {    -11,   70,   36,  3,  2,  0 }, {    -12,   70,   36,  3,  2,  0 }, {    -13,   71,   37,  3,  2,  0 }, {    -14,   72,   37,  3,  2,  0 }, {    -15,   72,   38,  3,  2,  0 },
        {    -16,   73,   38,  2,  2,  0 }, {    -17,   74,   39,  2,  2,  0 }, {    -18,   74,   39,  2,  2,  0 }, {    -19,   75,   40,  2,  2,  0 }, {    -20,   76,   40,  2,  2,  0 },
        {    -21,   76,   41,  2,  2,  0 }, {    -22,   77,   41,  2,  2,  0 }, {    -23,   77,   42,  2,  2,  0 }, {    -24,   78,   42,  2,  2,  0 }, {    -25,   78,   43,  2,  2,  0 },
        {    -26,   79,   43,  2,  2,  0 }, {    -27,   79,   44,  2,  2,  0 }, {    -28,   80,   44,  2,  2,  0 }, {    -29,   80,   45,  2,  2,  0 }, {    -30,   80,   45,  2,  2,  0 },
        {    -31,   81,   46,  1,  2,  0 }, {    -32,   81,   46,  1,  2,  0 }, {    -33,   82,   47,  1,  2,  0 }, {    -34,   82,   47,  1,  2,  0 }, {    -35,   82,   48,  1,  2,  0 },
        {    -36,   83,   48,  1,  2,  0 }, {    -37,   83,   49,  1,  2,  0 }, {    -38,   83,   49,  1,  2,  0 }, {    -39,   84,   50,  1,  2,  0 }, {    -40,   84,   50,  1,  2,  0 },
        {    -41,   84,   51,  1,  2,  0 }, {    -42,   84,   51,  1,  2,  0 }, {    -43,   85,   52,  1,  2,  0 }, {    -44,   85,   52,  1,  2,  0 }, {    -45,   85,   53,  1,  2,  0 },
        {    -46,   85,   53,  1,  2,  0 }, {    -47,   86,   54,  0,  2,  0 }, {    -48,   86,   54,  0,  2,  0 }, {    -49,   86,   55,  0,  2,  0 }, {    -50,   86,   55,  0,  2,  0 },
        {    -51,   86,   56,  0,  2,  0 }, {    -52,   86,   56,  0,  2,  0 }, {    -53,   86,   57,  0,  2,  0 }, {    -54,   87,   57,  0,  2,  0 }, {    -55,   87,   58,  0,  2,  0 },
        {    -56,   87,   58,  0,  2,  0 }, {    -57,   87,   59,  0,  2,  0 }, {    -58,   87,   59,  0,  2,  0 }, {    -59,   87,   60,  0,  2,  0 }, {    -60,   87,   60,  0,  2,  0 },
        {    -61,   87,   61,  0,  2,  0 }, {    -62,   87,   61,  0,  2,  0 }, {    -63,   87,   62,  0,  2,  0 }, {    -64,   87,   62, 31,  2,  0 }, {    -64,   86,   63, 31,  2,  0 },
        {    -64,   85,   63, 31,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp2, {
        {      1,    9,    0, 16,  2,  0 }, {      2,    9,    1, 15,  2,  0 }, {      3,    9,    1, 15,  2,  0 }, {      4,    9,    2, 15,  2,  0 }, {      5,    9,    2, 15,  2,  0 },
        {      6,    9,    3, 15,  2,  0 }, {      7,    9,    3, 15,  2,  0 }, {      8,    9,    4, 15,  2,  0 }, {      9,    9,    4, 15,  2,  0 }, {     10,    9,    5, 15,  2,  0 },
        {     11,   10,    5, 15,  2,  0 }, {     12,   10,    6, 15,  2,  0 }, {     13,   10,    6, 15,  2,  0 }, {     14,   10,    7, 15,  2,  0 }, {     15,   10,    7, 15,  2,  0 },
        {     16,   10,    8, 15,  2,  0 }, {     17,   10,    8, 15,  2,  0 }, {     18,   11,    9, 14,  2,  0 }, {     19,   11,    9, 14,  2,  0 }, {     20,   11,   10, 14,  2,  0 },
        {     21,   11,   10, 14,  2,  0 }, {     22,   12,   11, 14,  2,  0 }, {     23,   12,   11, 14,  2,  0 }, {     24,   12,   12, 14,  2,  0 }, {     25,   12,   12, 14,  2,  0 },
        {     26,   13,   13, 14,  2,  0 }, {     27,   13,   13, 14,  2,  0 }, {     28,   13,   14, 14,  2,  0 }, {     29,   14,   14, 14,  2,  0 }, {     30,   14,   15, 14,  2,  0 },
        {     31,   14,   15, 14,  2,  0 }, {     32,   15,   16, 14,  2,  0 }, {     33,   15,   16, 14,  2,  0 }, {     34,   16,   17, 13,  2,  0 }, {     35,   16,   17, 13,  2,  0 },
        {     36,   16,   18, 13,  2,  0 }, {     37,   17,   18, 13,  2,  0 }, {     38,   17,   19, 13,  2,  0 }, {     39,   18,   19, 13,  2,  0 }, {     40,   18,   20, 13,  2,  0 },
        {     41,   19,   20, 13,  2,  0 }, {     42,   19,   21, 13,  2,  0 }, {     43,   20,   21, 13,  2,  0 }, {     44,   20,   22, 13,  2,  0 }, {     45,   21,   22, 13,  2,  0 },
        {     46,   22,   23, 13,  2,  0 }, {     47,   22,   23, 13,  2,  0 }, {     48,   23,   24, 13,  2,  0 }, {     49,   24,   24, 12,  2,  0 }, {     50,   24,   25, 12,  2,  0 },
        {     51,   25,   25, 12,  2,  0 }, {     52,   26,   26, 12,  2,  0 }, {     53,   26,   26, 12,  2,  0 }, {     54,   27,   27, 12,  2,  0 }, {     55,   28,   27, 12,  2,  0 },
        {     56,   29,   28, 12,  2,  0 }, {     57,   30,   28, 12,  2,  0 }, {     58,   30,   29, 12,  2,  0 }, {     59,   31,   29, 12,  2,  0 }, {     60,   32,   30, 12,  2,  0 },
        {     61,   33,   30, 12,  2,  0 }, {     62,   34,   31, 12,  2,  0 }, {     63,   35,   31, 11,  2,  0 }, {     64,   36,   32, 11,  2,  0 }, {     65,   37,   33, 11,  2,  0 },
        {     66,   38,   33, 11,  2,  0 }, {     66,   39,   34, 11,  2,  0 }, {     67,   40,   34, 11,  2,  0 }, {     68,   41,   35, 11,  2,  0 }, {     69,   42,   35, 11,  2,  0 },
        {     70,   43,   36, 11,  2,  0 }, {     70,   44,   36, 11,  2,  0 }, {     71,   45,   37, 11,  2,  0 }, {     72,   46,   37, 11,  2,  0 }, {     72,   47,   38, 11,  2,  0 },
        {     73,   48,   38, 10,  2,  0 }, {     74,   49,   39, 10,  2,  0 }, {     74,   50,   39, 10,  2,  0 }, {     75,   51,   40, 10,  2,  0 }, {     76,   52,   40, 10,  2,  0 },
        {     76,   53,   41, 10,  2,  0 }, {     77,   54,   41, 10,  2,  0 }, {     77,   55,   42, 10,  2,  0 }, {     78,   56,   42, 10,  2,  0 }, {     78,   57,   43, 10,  2,  0 },
        {     79,   58,   43, 10,  2,  0 }, {     79,   59,   44, 10,  2,  0 }, {     80,   60,   44, 10,  2,  0 }, {     80,   61,   45, 10,  2,  0 }, {     80,   62,   45, 10,  2,  0 },
        {     81,   63,   46,  9,  2,  0 }, {     81,   64,   46,  9,  2,  0 }, {     82,   65,   47,  9,  2,  0 }, {     82,   66,   47,  9,  2,  0 }, {     82,   67,   48,  9,  2,  0 },
        {     83,   68,   48,  9,  2,  0 }, {     83,   69,   49,  9,  2,  0 }, {     83,   70,   49,  9,  2,  0 }, {     84,   71,   50,  9,  2,  0 }, {     84,   72,   50,  9,  2,  0 },
        {     84,   73,   51,  9,  2,  0 }, {     84,   74,   51,  9,  2,  0 }, {     85,   75,   52,  9,  2,  0 }, {     85,   76,   52,  9,  2,  0 }, {     85,   77,   53,  9,  2,  0 },
        {     85,   78,   53,  9,  2,  0 }, {     86,   79,   54,  8,  2,  0 }, {     86,   80,   54,  8,  2,  0 }, {     86,   81,   55,  8,  2,  0 }, {     86,   82,   55,  8,  2,  0 },
        {     86,   83,   56,  8,  2,  0 }, {     86,   84,   56,  8,  2,  0 }, {     86,   85,   57,  8,  2,  0 }, {     87,   86,   57,  8,  2,  0 }, {     87,   87,   58,  8,  2,  0 },
        {     87,   88,   58,  8,  2,  0 }, {     87,   89,   59,  8,  2,  0 }, {     87,   90,   59,  8,  2,  0 }, {     87,   91,   60,  8,  2,  0 }, {     87,   92,   60,  8,  2,  0 },
        {     87,   93,   61,  8,  2,  0 }, {     87,   94,   61,  8,  2,  0 }, {     87,   95,   62,  8,  2,  0 }, {     87,   96,   62,  7,  2,  0 }, {     86,   96,   63,  7,  2,  0 },
        {     85,   96,   63,  7,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp3, {
        {      9,   31,    0, 24,  2,  0 }, {      9,   30,    1, 23,  2,  0 }, {      9,   29,    1, 23,  2,  0 }, {      9,   28,    2, 23,  2,  0 }, {      9,   27,    2, 23,  2,  0 },
        {      9,   26,    3, 23,  2,  0 }, {      9,   25,    3, 23,  2,  0 }, {      9,   24,    4, 23,  2,  0 }, {      9,   23,    4, 23,  2,  0 }, {      9,   22,    5, 23,  2,  0 },
        {     10,   21,    5, 23,  2,  0 }, {     10,   20,    6, 23,  2,  0 }, {     10,   19,    6, 23,  2,  0 }, {     10,   18,    7, 23,  2,  0 }, {     10,   17,    7, 23,  2,  0 },
        {     10,   16,    8, 23,  2,  0 }, {     10,   15,    8, 23,  2,  0 }, {     11,   14,    9, 22,  2,  0 }, {     11,   13,    9, 22,  2,  0 }, {     11,   12,   10, 22,  2,  0 },
        {     11,   11,   10, 22,  2,  0 }, {     12,   10,   11, 22,  2,  0 }, {     12,    9,   11, 22,  2,  0 }, {     12,    8,   12, 22,  2,  0 }, {     12,    7,   12, 22,  2,  0 },
        {     13,    6,   13, 22,  2,  0 }, {     13,    5,   13, 22,  2,  0 }, {     13,    4,   14, 22,  2,  0 }, {     14,    3,   14, 22,  2,  0 }, {     14,    2,   15, 22,  2,  0 },
        {     14,    1,   15, 22,  2,  0 }, {     15,    0,   16, 22,  2,  0 }, {     15,   -1,   16, 22,  2,  0 }, {     16,   -2,   17, 21,  2,  0 }, {     16,   -3,   17, 21,  2,  0 },
        {     16,   -4,   18, 21,  2,  0 }, {     17,   -5,   18, 21,  2,  0 }, {     17,   -6,   19, 21,  2,  0 }, {     18,   -7,   19, 21,  2,  0 }, {     18,   -8,   20, 21,  2,  0 },
        {     19,   -9,   20, 21,  2,  0 }, {     19,  -10,   21, 21,  2,  0 }, {     20,  -11,   21, 21,  2,  0 }, {     20,  -12,   22, 21,  2,  0 }, {     21,  -13,   22, 21,  2,  0 },
        {     22,  -14,   23, 21,  2,  0 }, {     22,  -15,   23, 21,  2,  0 }, {     23,  -16,   24, 21,  2,  0 }, {     24,  -17,   24, 20,  2,  0 }, {     24,  -18,   25, 20,  2,  0 },
        {     25,  -19,   25, 20,  2,  0 }, {     26,  -20,   26, 20,  2,  0 }, {     26,  -21,   26, 20,  2,  0 }, {     27,  -22,   27, 20,  2,  0 }, {     28,  -23,   27, 20,  2,  0 },
        {     29,  -24,   28, 20,  2,  0 }, {     30,  -25,   28, 20,  2,  0 }, {     30,  -26,   29, 20,  2,  0 }, {     31,  -27,   29, 20,  2,  0 }, {     32,  -28,   30, 20,  2,  0 },
        {     33,  -29,   30, 20,  2,  0 }, {     34,  -30,   31, 20,  2,  0 }, {     35,  -31,   31, 19,  2,  0 }, {     36,  -32,   32, 19,  2,  0 }, {     37,  -33,   33, 19,  2,  0 },
        {     38,  -34,   33, 19,  2,  0 }, {     39,  -34,   34, 19,  2,  0 }, {     40,  -35,   34, 19,  2,  0 }, {     41,  -36,   35, 19,  2,  0 }, {     42,  -37,   35, 19,  2,  0 },
        {     43,  -38,   36, 19,  2,  0 }, {     44,  -38,   36, 19,  2,  0 }, {     45,  -39,   37, 19,  2,  0 }, {     46,  -40,   37, 19,  2,  0 }, {     47,  -40,   38, 19,  2,  0 },
        {     48,  -41,   38, 18,  2,  0 }, {     49,  -42,   39, 18,  2,  0 }, {     50,  -42,   39, 18,  2,  0 }, {     51,  -43,   40, 18,  2,  0 }, {     52,  -44,   40, 18,  2,  0 },
        {     53,  -44,   41, 18,  2,  0 }, {     54,  -45,   41, 18,  2,  0 }, {     55,  -45,   42, 18,  2,  0 }, {     56,  -46,   42, 18,  2,  0 }, {     57,  -46,   43, 18,  2,  0 },
        {     58,  -47,   43, 18,  2,  0 }, {     59,  -47,   44, 18,  2,  0 }, {     60,  -48,   44, 18,  2,  0 }, {     61,  -48,   45, 18,  2,  0 }, {     62,  -48,   45, 18,  2,  0 },
        {     63,  -49,   46, 17,  2,  0 }, {     64,  -49,   46, 17,  2,  0 }, {     65,  -50,   47, 17,  2,  0 }, {     66,  -50,   47, 17,  2,  0 }, {     67,  -50,   48, 17,  2,  0 },
        {     68,  -51,   48, 17,  2,  0 }, {     69,  -51,   49, 17,  2,  0 }, {     70,  -51,   49, 17,  2,  0 }, {     71,  -52,   50, 17,  2,  0 }, {     72,  -52,   50, 17,  2,  0 },
        {     73,  -52,   51, 17,  2,  0 }, {     74,  -52,   51, 17,  2,  0 }, {     75,  -53,   52, 17,  2,  0 }, {     76,  -53,   52, 17,  2,  0 }, {     77,  -53,   53, 17,  2,  0 },
        {     78,  -53,   53, 17,  2,  0 }, {     79,  -54,   54, 16,  2,  0 }, {     80,  -54,   54, 16,  2,  0 }, {     81,  -54,   55, 16,  2,  0 }, {     82,  -54,   55, 16,  2,  0 },
        {     83,  -54,   56, 16,  2,  0 }, {     84,  -54,   56, 16,  2,  0 }, {     85,  -54,   57, 16,  2,  0 }, {     86,  -55,   57, 16,  2,  0 }, {     87,  -55,   58, 16,  2,  0 },
        {     88,  -55,   58, 16,  2,  0 }, {     89,  -55,   59, 16,  2,  0 }, {     90,  -55,   59, 16,  2,  0 }, {     91,  -55,   60, 16,  2,  0 }, {     92,  -55,   60, 16,  2,  0 },
        {     93,  -55,   61, 16,  2,  0 }, {     94,  -55,   61, 16,  2,  0 }, {     95,  -55,   62, 16,  2,  0 }, {     96,  -55,   62, 15,  2,  0 }, {     96,  -54,   63, 15,  2,  0 },
        {     96,  -53,   63, 15,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegUp0, {
        {     31,   23,    0,  0,  2,  0 }, {     30,   23,    1,  1,  2,  0 }, {     29,   23,    1,  1,  2,  0 }, {     28,   23,    2,  1,  2,  0 }, {     27,   23,    2,  1,  2,  0 },
        {     26,   23,    3,  1,  2,  0 }, {     25,   23,    4,  1,  2,  0 }, {     24,   23,    4,  1,  2,  0 }, {     23,   23,    5,  1,  2,  0 }, {     22,   24,    5,  1,  2,  0 },
        {     21,   24,    6,  1,  2,  0 }, {     20,   24,    7,  1,  2,  0 }, {     19,   24,    7,  1,  2,  0 }, {     18,   24,    8,  1,  2,  0 }, {     17,   24,    9,  1,  2,  0 },
        {     16,   25,    9,  2,  2,  0 }, {     15,   25,   10,  2,  2,  0 }, {     14,   25,   10,  2,  2,  0 }, {     13,   25,   11,  2,  2,  0 }, {     12,   26,   12,  2,  2,  0 },
        {     11,   26,   12,  2,  2,  0 }, {     10,   26,   13,  2,  2,  0 }, {      9,   26,   13,  2,  2,  0 }, {      8,   27,   14,  2,  2,  0 }, {      7,   27,   15,  2,  2,  0 },
        {      6,   27,   15,  2,  2,  0 }, {      5,   28,   16,  2,  2,  0 }, {      4,   28,   16,  2,  2,  0 }, {      3,   29,   17,  3,  2,  0 }, {      2,   29,   18,  3,  2,  0 },
        {      1,   29,   18,  3,  2,  0 }, {      0,   30,   19,  3,  2,  0 }, {     -1,   30,   20,  3,  2,  0 }, {     -2,   31,   20,  3,  2,  0 }, {     -3,   31,   21,  3,  2,  0 },
        {     -4,   32,   21,  3,  2,  0 }, {     -5,   33,   22,  3,  2,  0 }, {     -6,   33,   23,  3,  2,  0 }, {     -7,   34,   23,  3,  2,  0 }, {     -8,   34,   24,  3,  2,  0 },
        {     -9,   35,   24,  3,  2,  0 }, {    -10,   36,   25,  4,  2,  0 }, {    -11,   36,   26,  4,  2,  0 }, {    -12,   37,   26,  4,  2,  0 }, {    -13,   38,   27,  4,  2,  0 },
        {    -14,   39,   27,  4,  2,  0 }, {    -15,   39,   28,  4,  2,  0 }, {    -16,   40,   29,  4,  2,  0 }, {    -17,   41,   29,  4,  2,  0 }, {    -18,   42,   30,  4,  2,  0 },
        {    -19,   43,   30,  4,  2,  0 }, {    -20,   44,   31,  4,  2,  0 }, {    -21,   45,   32,  5,  2,  0 }, {    -22,   46,   32,  5,  2,  0 }, {    -23,   47,   33,  5,  2,  0 },
        {    -24,   48,   34,  5,  2,  0 }, {    -25,   49,   34,  5,  2,  0 }, {    -25,   50,   35,  5,  2,  0 }, {    -26,   51,   35,  5,  2,  0 }, {    -27,   52,   36,  5,  2,  0 },
        {    -28,   53,   37,  5,  2,  0 }, {    -28,   54,   37,  5,  2,  0 }, {    -29,   55,   38,  6,  2,  0 }, {    -30,   56,   38,  6,  2,  0 }, {    -30,   57,   39,  6,  2,  0 },
        {    -31,   58,   40,  6,  2,  0 }, {    -31,   59,   40,  6,  2,  0 }, {    -32,   60,   41,  6,  2,  0 }, {    -33,   61,   41,  6,  2,  0 }, {    -33,   62,   42,  6,  2,  0 },
        {    -34,   63,   43,  6,  2,  0 }, {    -34,   64,   43,  6,  2,  0 }, {    -35,   65,   44,  6,  2,  0 }, {    -35,   66,   44,  6,  2,  0 }, {    -35,   67,   45,  6,  2,  0 },
        {    -36,   68,   46,  7,  2,  0 }, {    -36,   69,   46,  7,  2,  0 }, {    -37,   70,   47,  7,  2,  0 }, {    -37,   71,   48,  7,  2,  0 }, {    -37,   72,   48,  7,  2,  0 },
        {    -38,   73,   49,  7,  2,  0 }, {    -38,   74,   49,  7,  2,  0 }, {    -38,   75,   50,  7,  2,  0 }, {    -38,   76,   51,  7,  2,  0 }, {    -39,   77,   51,  7,  2,  0 },
        {    -39,   78,   52,  7,  2,  0 }, {    -39,   79,   52,  7,  2,  0 }, {    -39,   80,   53,  7,  2,  0 }, {    -40,   81,   54,  8,  2,  0 }, {    -40,   82,   54,  8,  2,  0 },
        {    -40,   83,   55,  8,  2,  0 }, {    -40,   84,   55,  8,  2,  0 }, {    -40,   85,   56,  8,  2,  0 }, {    -40,   86,   57,  8,  2,  0 }, {    -41,   87,   57,  8,  2,  0 },
        {    -41,   88,   58,  8,  2,  0 }, {    -41,   89,   59,  8,  2,  0 }, {    -41,   90,   59,  8,  2,  0 }, {    -41,   91,   60,  8,  2,  0 }, {    -41,   92,   60,  8,  2,  0 },
        {    -41,   93,   61,  8,  2,  0 }, {    -41,   94,   62,  8,  2,  0 }, {    -41,   95,   62,  8,  2,  0 }, {    -41,   96,   63,  9,  2,  0 }, {    -40,   96,   63,  9,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegUp1, {
        {     23,    1,    0,  8,  2,  0 }, {     23,    2,    1,  9,  2,  0 }, {     23,    3,    1,  9,  2,  0 }, {     23,    4,    2,  9,  2,  0 }, {     23,    5,    2,  9,  2,  0 },
        {     23,    6,    3,  9,  2,  0 }, {     23,    7,    4,  9,  2,  0 }, {     23,    8,    4,  9,  2,  0 }, {     23,    9,    5,  9,  2,  0 }, {     24,   10,    5,  9,  2,  0 },
        {     24,   11,    6,  9,  2,  0 }, {     24,   12,    7,  9,  2,  0 }, {     24,   13,    7,  9,  2,  0 }, {     24,   14,    8,  9,  2,  0 }, {     24,   15,    9,  9,  2,  0 },
        {     25,   16,    9, 10,  2,  0 }, {     25,   17,   10, 10,  2,  0 }, {     25,   18,   10, 10,  2,  0 }, {     25,   19,   11, 10,  2,  0 }, {     26,   20,   12, 10,  2,  0 },
        {     26,   21,   12, 10,  2,  0 }, {     26,   22,   13, 10,  2,  0 }, {     26,   23,   13, 10,  2,  0 }, {     27,   24,   14, 10,  2,  0 }, {     27,   25,   15, 10,  2,  0 },
        {     27,   26,   15, 10,  2,  0 }, {     28,   27,   16, 10,  2,  0 }, {     28,   28,   16, 10,  2,  0 }, {     29,   29,   17, 11,  2,  0 }, {     29,   30,   18, 11,  2,  0 },
        {     29,   31,   18, 11,  2,  0 }, {     30,   32,   19, 11,  2,  0 }, {     30,   33,   20, 11,  2,  0 }, {     31,   34,   20, 11,  2,  0 }, {     31,   35,   21, 11,  2,  0 },
        {     32,   36,   21, 11,  2,  0 }, {     33,   37,   22, 11,  2,  0 }, {     33,   38,   23, 11,  2,  0 }, {     34,   39,   23, 11,  2,  0 }, {     34,   40,   24, 11,  2,  0 },
        {     35,   41,   24, 11,  2,  0 }, {     36,   42,   25, 12,  2,  0 }, {     36,   43,   26, 12,  2,  0 }, {     37,   44,   26, 12,  2,  0 }, {     38,   45,   27, 12,  2,  0 },
        {     39,   46,   27, 12,  2,  0 }, {     39,   47,   28, 12,  2,  0 }, {     40,   48,   29, 12,  2,  0 }, {     41,   49,   29, 12,  2,  0 }, {     42,   50,   30, 12,  2,  0 },
        {     43,   51,   30, 12,  2,  0 }, {     44,   52,   31, 12,  2,  0 }, {     45,   53,   32, 13,  2,  0 }, {     46,   54,   32, 13,  2,  0 }, {     47,   55,   33, 13,  2,  0 },
        {     48,   56,   34, 13,  2,  0 }, {     49,   57,   34, 13,  2,  0 }, {     50,   57,   35, 13,  2,  0 }, {     51,   58,   35, 13,  2,  0 }, {     52,   59,   36, 13,  2,  0 },
        {     53,   60,   37, 13,  2,  0 }, {     54,   60,   37, 13,  2,  0 }, {     55,   61,   38, 14,  2,  0 }, {     56,   62,   38, 14,  2,  0 }, {     57,   62,   39, 14,  2,  0 },
        {     58,   63,   40, 14,  2,  0 }, {     59,   63,   40, 14,  2,  0 }, {     60,   64,   41, 14,  2,  0 }, {     61,   65,   41, 14,  2,  0 }, {     62,   65,   42, 14,  2,  0 },
        {     63,   66,   43, 14,  2,  0 }, {     64,   66,   43, 14,  2,  0 }, {     65,   67,   44, 14,  2,  0 }, {     66,   67,   44, 14,  2,  0 }, {     67,   67,   45, 14,  2,  0 },
        {     68,   68,   46, 15,  2,  0 }, {     69,   68,   46, 15,  2,  0 }, {     70,   69,   47, 15,  2,  0 }, {     71,   69,   48, 15,  2,  0 }, {     72,   69,   48, 15,  2,  0 },
        {     73,   70,   49, 15,  2,  0 }, {     74,   70,   49, 15,  2,  0 }, {     75,   70,   50, 15,  2,  0 }, {     76,   70,   51, 15,  2,  0 }, {     77,   71,   51, 15,  2,  0 },
        {     78,   71,   52, 15,  2,  0 }, {     79,   71,   52, 15,  2,  0 }, {     80,   71,   53, 15,  2,  0 }, {     81,   72,   54, 16,  2,  0 }, {     82,   72,   54, 16,  2,  0 },
        {     83,   72,   55, 16,  2,  0 }, {     84,   72,   55, 16,  2,  0 }, {     85,   72,   56, 16,  2,  0 }, {     86,   72,   57, 16,  2,  0 }, {     87,   73,   57, 16,  2,  0 },
        {     88,   73,   58, 16,  2,  0 }, {     89,   73,   59, 16,  2,  0 }, {     90,   73,   59, 16,  2,  0 }, {     91,   73,   60, 16,  2,  0 }, {     92,   73,   60, 16,  2,  0 },
        {     93,   73,   61, 16,  2,  0 }, {     94,   73,   62, 16,  2,  0 }, {     95,   73,   62, 16,  2,  0 }, {     96,   73,   63, 17,  2,  0 }, {     96,   72,   63, 17,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegUp2, {
        {      1,    9,    0, 16,  2,  0 }, {      2,    9,    1, 17,  2,  0 }, {      3,    9,    1, 17,  2,  0 }, {      4,    9,    2, 17,  2,  0 }, {      5,    9,    2, 17,  2,  0 },
        {      6,    9,    3, 17,  2,  0 }, {      7,    9,    4, 17,  2,  0 }, {      8,    9,    4, 17,  2,  0 }, {      9,    9,    5, 17,  2,  0 }, {     10,    8,    5, 17,  2,  0 },
        {     11,    8,    6, 17,  2,  0 }, {     12,    8,    7, 17,  2,  0 }, {     13,    8,    7, 17,  2,  0 }, {     14,    8,    8, 17,  2,  0 }, {     15,    8,    9, 17,  2,  0 },
        {     16,    7,    9, 18,  2,  0 }, {     17,    7,   10, 18,  2,  0 }, {     18,    7,   10, 18,  2,  0 }, {     19,    7,   11, 18,  2,  0 }, {     20,    6,   12, 18,  2,  0 },
        {     21,    6,   12, 18,  2,  0 }, {     22,    6,   13, 18,  2,  0 }, {     23,    6,   13, 18,  2,  0 }, {     24,    5,   14, 18,  2,  0 }, {     25,    5,   15, 18,  2,  0 },
        {     26,    5,   15, 18,  2,  0 }, {     27,    4,   16, 18,  2,  0 }, {     28,    4,   16, 18,  2,  0 }, {     29,    3,   17, 19,  2,  0 }, {     30,    3,   18, 19,  2,  0 },
        {     31,    3,   18, 19,  2,  0 }, {     32,    2,   19, 19,  2,  0 }, {     33,    2,   20, 19,  2,  0 }, {     34,    1,   20, 19,  2,  0 }, {     35,    1,   21, 19,  2,  0 },
        {     36,    0,   21, 19,  2,  0 }, {     37,   -1,   22, 19,  2,  0 }, {     38,   -1,   23, 19,  2,  0 }, {     39,   -2,   23, 19,  2,  0 }, {     40,   -2,   24, 19,  2,  0 },
        {     41,   -3,   24, 19,  2,  0 }, {     42,   -4,   25, 20,  2,  0 }, {     43,   -4,   26, 20,  2,  0 }, {     44,   -5,   26, 20,  2,  0 }, {     45,   -6,   27, 20,  2,  0 },
        {     46,   -7,   27, 20,  2,  0 }, {     47,   -7,   28, 20,  2,  0 }, {     48,   -8,   29, 20,  2,  0 }, {     49,   -9,   29, 20,  2,  0 }, {     50,  -10,   30, 20,  2,  0 },
        {     51,  -11,   30, 20,  2,  0 }, {     52,  -12,   31, 20,  2,  0 }, {     53,  -13,   32, 21,  2,  0 }, {     54,  -14,   32, 21,  2,  0 }, {     55,  -15,   33, 21,  2,  0 },
        {     56,  -16,   34, 21,  2,  0 }, {     57,  -17,   34, 21,  2,  0 }, {     57,  -18,   35, 21,  2,  0 }, {     58,  -19,   35, 21,  2,  0 }, {     59,  -20,   36, 21,  2,  0 },
        {     60,  -21,   37, 21,  2,  0 }, {     60,  -22,   37, 21,  2,  0 }, {     61,  -23,   38, 22,  2,  0 }, {     62,  -24,   38, 22,  2,  0 }, {     62,  -25,   39, 22,  2,  0 },
        {     63,  -26,   40, 22,  2,  0 }, {     63,  -27,   40, 22,  2,  0 }, {     64,  -28,   41, 22,  2,  0 }, {     65,  -29,   41, 22,  2,  0 }, {     65,  -30,   42, 22,  2,  0 },
        {     66,  -31,   43, 22,  2,  0 }, {     66,  -32,   43, 22,  2,  0 }, {     67,  -33,   44, 22,  2,  0 }, {     67,  -34,   44, 22,  2,  0 }, {     67,  -35,   45, 22,  2,  0 },
        {     68,  -36,   46, 23,  2,  0 }, {     68,  -37,   46, 23,  2,  0 }, {     69,  -38,   47, 23,  2,  0 }, {     69,  -39,   48, 23,  2,  0 }, {     69,  -40,   48, 23,  2,  0 },
        {     70,  -41,   49, 23,  2,  0 }, {     70,  -42,   49, 23,  2,  0 }, {     70,  -43,   50, 23,  2,  0 }, {     70,  -44,   51, 23,  2,  0 }, {     71,  -45,   51, 23,  2,  0 },
        {     71,  -46,   52, 23,  2,  0 }, {     71,  -47,   52, 23,  2,  0 }, {     71,  -48,   53, 23,  2,  0 }, {     72,  -49,   54, 24,  2,  0 }, {     72,  -50,   54, 24,  2,  0 },
        {     72,  -51,   55, 24,  2,  0 }, {     72,  -52,   55, 24,  2,  0 }, {     72,  -53,   56, 24,  2,  0 }, {     72,  -54,   57, 24,  2,  0 }, {     73,  -55,   57, 24,  2,  0 },
        {     73,  -56,   58, 24,  2,  0 }, {     73,  -57,   59, 24,  2,  0 }, {     73,  -58,   59, 24,  2,  0 }, {     73,  -59,   60, 24,  2,  0 }, {     73,  -60,   60, 24,  2,  0 },
        {     73,  -61,   61, 24,  2,  0 }, {     73,  -62,   62, 24,  2,  0 }, {     73,  -63,   62, 24,  2,  0 }, {     73,  -64,   63, 25,  2,  0 }, {     72,  -64,   63, 25,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegUp3, {
        {      9,   31,    0, 24,  2,  0 }, {      9,   30,    1, 25,  2,  0 }, {      9,   29,    1, 25,  2,  0 }, {      9,   28,    2, 25,  2,  0 }, {      9,   27,    2, 25,  2,  0 },
        {      9,   26,    3, 25,  2,  0 }, {      9,   25,    4, 25,  2,  0 }, {      9,   24,    4, 25,  2,  0 }, {      9,   23,    5, 25,  2,  0 }, {      8,   22,    5, 25,  2,  0 },
        {      8,   21,    6, 25,  2,  0 }, {      8,   20,    7, 25,  2,  0 }, {      8,   19,    7, 25,  2,  0 }, {      8,   18,    8, 25,  2,  0 }, {      8,   17,    9, 25,  2,  0 },
        {      7,   16,    9, 26,  2,  0 }, {      7,   15,   10, 26,  2,  0 }, {      7,   14,   10, 26,  2,  0 }, {      7,   13,   11, 26,  2,  0 }, {      6,   12,   12, 26,  2,  0 },
        {      6,   11,   12, 26,  2,  0 }, {      6,   10,   13, 26,  2,  0 }, {      6,    9,   13, 26,  2,  0 }, {      5,    8,   14, 26,  2,  0 }, {      5,    7,   15, 26,  2,  0 },
        {      5,    6,   15, 26,  2,  0 }, {      4,    5,   16, 26,  2,  0 }, {      4,    4,   16, 26,  2,  0 }, {      3,    3,   17, 27,  2,  0 }, {      3,    2,   18, 27,  2,  0 },
        {      3,    1,   18, 27,  2,  0 }, {      2,    0,   19, 27,  2,  0 }, {      2,   -1,   20, 27,  2,  0 }, {      1,   -2,   20, 27,  2,  0 }, {      1,   -3,   21, 27,  2,  0 },
        {      0,   -4,   21, 27,  2,  0 }, {     -1,   -5,   22, 27,  2,  0 }, {     -1,   -6,   23, 27,  2,  0 }, {     -2,   -7,   23, 27,  2,  0 }, {     -2,   -8,   24, 27,  2,  0 },
        {     -3,   -9,   24, 27,  2,  0 }, {     -4,  -10,   25, 28,  2,  0 }, {     -4,  -11,   26, 28,  2,  0 }, {     -5,  -12,   26, 28,  2,  0 }, {     -6,  -13,   27, 28,  2,  0 },
        {     -7,  -14,   27, 28,  2,  0 }, {     -7,  -15,   28, 28,  2,  0 }, {     -8,  -16,   29, 28,  2,  0 }, {     -9,  -17,   29, 28,  2,  0 }, {    -10,  -18,   30, 28,  2,  0 },
        {    -11,  -19,   30, 28,  2,  0 }, {    -12,  -20,   31, 28,  2,  0 }, {    -13,  -21,   32, 29,  2,  0 }, {    -14,  -22,   32, 29,  2,  0 }, {    -15,  -23,   33, 29,  2,  0 },
        {    -16,  -24,   34, 29,  2,  0 }, {    -17,  -25,   34, 29,  2,  0 }, {    -18,  -25,   35, 29,  2,  0 }, {    -19,  -26,   35, 29,  2,  0 }, {    -20,  -27,   36, 29,  2,  0 },
        {    -21,  -28,   37, 29,  2,  0 }, {    -22,  -28,   37, 29,  2,  0 }, {    -23,  -29,   38, 30,  2,  0 }, {    -24,  -30,   38, 30,  2,  0 }, {    -25,  -30,   39, 30,  2,  0 },
        {    -26,  -31,   40, 30,  2,  0 }, {    -27,  -31,   40, 30,  2,  0 }, {    -28,  -32,   41, 30,  2,  0 }, {    -29,  -33,   41, 30,  2,  0 }, {    -30,  -33,   42, 30,  2,  0 },
        {    -31,  -34,   43, 30,  2,  0 }, {    -32,  -34,   43, 30,  2,  0 }, {    -33,  -35,   44, 30,  2,  0 }, {    -34,  -35,   44, 30,  2,  0 }, {    -35,  -35,   45, 30,  2,  0 },
        {    -36,  -36,   46, 31,  2,  0 }, {    -37,  -36,   46, 31,  2,  0 }, {    -38,  -37,   47, 31,  2,  0 }, {    -39,  -37,   48, 31,  2,  0 }, {    -40,  -37,   48, 31,  2,  0 },
        {    -41,  -38,   49, 31,  2,  0 }, {    -42,  -38,   49, 31,  2,  0 }, {    -43,  -38,   50, 31,  2,  0 }, {    -44,  -38,   51, 31,  2,  0 }, {    -45,  -39,   51, 31,  2,  0 },
        {    -46,  -39,   52, 31,  2,  0 }, {    -47,  -39,   52, 31,  2,  0 }, {    -48,  -39,   53, 31,  2,  0 }, {    -49,  -40,   54,  0,  2,  0 }, {    -50,  -40,   54,  0,  2,  0 },
        {    -51,  -40,   55,  0,  2,  0 }, {    -52,  -40,   55,  0,  2,  0 }, {    -53,  -40,   56,  0,  2,  0 }, {    -54,  -40,   57,  0,  2,  0 }, {    -55,  -41,   57,  0,  2,  0 },
        {    -56,  -41,   58,  0,  2,  0 }, {    -57,  -41,   59,  0,  2,  0 }, {    -58,  -41,   59,  0,  2,  0 }, {    -59,  -41,   60,  0,  2,  0 }, {    -60,  -41,   60,  0,  2,  0 },
        {    -61,  -41,   61,  0,  2,  0 }, {    -62,  -41,   62,  0,  2,  0 }, {    -63,  -41,   62,  0,  2,  0 }, {    -64,  -41,   63,  1,  2,  0 }, {    -64,  -40,   63,  1,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown0, {
        {     31,   23,   15,  0,  6,  0 }, {     30,   23,   14, 31,  6,  0 }, {     29,   23,   14, 31,  6,  0 }, {     28,   23,   13, 31,  6,  0 }, {     27,   23,   13, 31,  6,  0 },
        {     26,   23,   12, 31,  6,  0 }, {     25,   23,   12, 31,  6,  0 }, {     24,   23,   11, 31,  6,  0 }, {     23,   23,   11, 31,  6,  0 }, {     22,   23,   10, 31,  6,  0 },
        {     21,   22,   10, 31,  6,  0 }, {     20,   22,    9, 31,  6,  0 }, {     19,   22,    9, 31,  6,  0 }, {     18,   22,    8, 31,  6,  0 }, {     17,   22,    8, 31,  6,  0 },
        {     16,   22,    7, 31,  6,  0 }, {     15,   22,    7, 31,  6,  0 }, {     14,   21,    6, 30,  6,  0 }, {     13,   21,    6, 30,  6,  0 }, {     12,   21,    5, 30,  6,  0 },
        {     11,   21,    5, 30,  6,  0 }, {     10,   20,    4, 30,  6,  0 }, {      9,   20,    4, 30,  6,  0 }, {      8,   20,    3, 30,  6,  0 }, {      7,   20,    3, 30,  6,  0 },
        {      6,   19,    2, 30,  6,  0 }, {      5,   19,    2, 30,  6,  0 }, {      4,   19,    1, 30,  6,  0 }, {      3,   18,    1, 30,  6,  0 }, {      2,   18,    0, 30,  6,  0 },
        {      1,   18,    0, 30,  6,  0 }, {      0,   17,   -1, 30,  6,  0 }, {     -1,   17,   -1, 30,  6,  0 }, {     -2,   16,   -2, 29,  6,  0 }, {     -3,   16,   -2, 29,  6,  0 },
        {     -4,   16,   -3, 29,  6,  0 }, {     -5,   15,   -3, 29,  6,  0 }, {     -6,   15,   -4, 29,  6,  0 }, {     -7,   14,   -4, 29,  6,  0 }, {     -8,   14,   -5, 29,  6,  0 },
        {     -9,   13,   -5, 29,  6,  0 }, {    -10,   13,   -6, 29,  6,  0 }, {    -11,   12,   -6, 29,  6,  0 }, {    -12,   12,   -7, 29,  6,  0 }, {    -13,   11,   -7, 29,  6,  0 },
        {    -14,   10,   -8, 29,  6,  0 }, {    -15,   10,   -8, 29,  6,  0 }, {    -16,    9,   -9, 29,  6,  0 }, {    -17,    8,   -9, 28,  6,  0 }, {    -18,    8,  -10, 28,  6,  0 },
        {    -19,    7,  -10, 28,  6,  0 }, {    -20,    6,  -11, 28,  6,  0 }, {    -21,    6,  -11, 28,  6,  0 }, {    -22,    5,  -12, 28,  6,  0 }, {    -23,    4,  -12, 28,  6,  0 },
        {    -24,    3,  -13, 28,  6,  0 }, {    -25,    2,  -13, 28,  6,  0 }, {    -26,    2,  -14, 28,  6,  0 }, {    -27,    1,  -14, 28,  6,  0 }, {    -28,    0,  -15, 28,  6,  0 },
        {    -29,   -1,  -15, 28,  6,  0 }, {    -30,   -2,  -16, 28,  6,  0 }, {    -31,   -3,  -16, 27,  6,  0 }, {    -32,   -4,  -17, 27,  6,  0 }, {    -33,   -5,  -18, 27,  6,  0 },
        {    -34,   -6,  -18, 27,  6,  0 }, {    -34,   -7,  -19, 27,  6,  0 }, {    -35,   -8,  -19, 27,  6,  0 }, {    -36,   -9,  -20, 27,  6,  0 }, {    -37,  -10,  -20, 27,  6,  0 },
        {    -38,  -11,  -21, 27,  6,  0 }, {    -38,  -12,  -21, 27,  6,  0 }, {    -39,  -13,  -22, 27,  6,  0 }, {    -40,  -14,  -22, 27,  6,  0 }, {    -40,  -15,  -23, 27,  6,  0 },
        {    -41,  -16,  -23, 26,  6,  0 }, {    -42,  -17,  -24, 26,  6,  0 }, {    -42,  -18,  -24, 26,  6,  0 }, {    -43,  -19,  -25, 26,  6,  0 }, {    -44,  -20,  -25, 26,  6,  0 },
        {    -44,  -21,  -26, 26,  6,  0 }, {    -45,  -22,  -26, 26,  6,  0 }, {    -45,  -23,  -27, 26,  6,  0 }, {    -46,  -24,  -27, 26,  6,  0 }, {    -46,  -25,  -28, 26,  6,  0 },
        {    -47,  -26,  -28, 26,  6,  0 }, {    -47,  -27,  -29, 26,  6,  0 }, {    -48,  -28,  -29, 26,  6,  0 }, {    -48,  -29,  -30, 26,  6,  0 }, {    -48,  -30,  -30, 26,  6,  0 },
        {    -49,  -31,  -31, 25,  6,  0 }, {    -49,  -32,  -31, 25,  6,  0 }, {    -50,  -33,  -32, 25,  6,  0 }, {    -50,  -34,  -32, 25,  6,  0 }, {    -50,  -35,  -33, 25,  6,  0 },
        {    -51,  -36,  -33, 25,  6,  0 }, {    -51,  -37,  -34, 25,  6,  0 }, {    -51,  -38,  -34, 25,  6,  0 }, {    -52,  -39,  -35, 25,  6,  0 }, {    -52,  -40,  -35, 25,  6,  0 },
        {    -52,  -41,  -36, 25,  6,  0 }, {    -52,  -42,  -36, 25,  6,  0 }, {    -53,  -43,  -37, 25,  6,  0 }, {    -53,  -44,  -37, 25,  6,  0 }, {    -53,  -45,  -38, 25,  6,  0 },
        {    -53,  -46,  -38, 25,  6,  0 }, {    -54,  -47,  -39, 24,  6,  0 }, {    -54,  -48,  -39, 24,  6,  0 }, {    -54,  -49,  -40, 24,  6,  0 }, {    -54,  -50,  -40, 24,  6,  0 },
        {    -54,  -51,  -41, 24,  6,  0 }, {    -54,  -52,  -41, 24,  6,  0 }, {    -54,  -53,  -42, 24,  6,  0 }, {    -55,  -54,  -42, 24,  6,  0 }, {    -55,  -55,  -43, 24,  6,  0 },
        {    -55,  -56,  -43, 24,  6,  0 }, {    -55,  -57,  -44, 24,  6,  0 }, {    -55,  -58,  -44, 24,  6,  0 }, {    -55,  -59,  -45, 24,  6,  0 }, {    -55,  -60,  -45, 24,  6,  0 },
        {    -55,  -61,  -46, 24,  6,  0 }, {    -55,  -62,  -46, 24,  6,  0 }, {    -55,  -63,  -47, 24,  6,  0 }, {    -55,  -64,  -47, 23,  6,  0 }, {    -54,  -64,  -48, 23,  6,  0 },
        {    -53,  -64,  -48, 23,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown1, {
        {     23,    1,   15,  8,  6,  0 }, {     23,    2,   14,  7,  6,  0 }, {     23,    3,   14,  7,  6,  0 }, {     23,    4,   13,  7,  6,  0 }, {     23,    5,   13,  7,  6,  0 },
        {     23,    6,   12,  7,  6,  0 }, {     23,    7,   12,  7,  6,  0 }, {     23,    8,   11,  7,  6,  0 }, {     23,    9,   11,  7,  6,  0 }, {     23,   10,   10,  7,  6,  0 },
        {     22,   11,   10,  7,  6,  0 }, {     22,   12,    9,  7,  6,  0 }, {     22,   13,    9,  7,  6,  0 }, {     22,   14,    8,  7,  6,  0 }, {     22,   15,    8,  7,  6,  0 },
        {     22,   16,    7,  7,  6,  0 }, {     22,   17,    7,  7,  6,  0 }, {     21,   18,    6,  6,  6,  0 }, {     21,   19,    6,  6,  6,  0 }, {     21,   20,    5,  6,  6,  0 },
        {     21,   21,    5,  6,  6,  0 }, {     20,   22,    4,  6,  6,  0 }, {     20,   23,    4,  6,  6,  0 }, {     20,   24,    3,  6,  6,  0 }, {     20,   25,    3,  6,  6,  0 },
        {     19,   26,    2,  6,  6,  0 }, {     19,   27,    2,  6,  6,  0 }, {     19,   28,    1,  6,  6,  0 }, {     18,   29,    1,  6,  6,  0 }, {     18,   30,    0,  6,  6,  0 },
        {     18,   31,    0,  6,  6,  0 }, {     17,   32,   -1,  6,  6,  0 }, {     17,   33,   -1,  6,  6,  0 }, {     16,   34,   -2,  5,  6,  0 }, {     16,   35,   -2,  5,  6,  0 },
        {     16,   36,   -3,  5,  6,  0 }, {     15,   37,   -3,  5,  6,  0 }, {     15,   38,   -4,  5,  6,  0 }, {     14,   39,   -4,  5,  6,  0 }, {     14,   40,   -5,  5,  6,  0 },
        {     13,   41,   -5,  5,  6,  0 }, {     13,   42,   -6,  5,  6,  0 }, {     12,   43,   -6,  5,  6,  0 }, {     12,   44,   -7,  5,  6,  0 }, {     11,   45,   -7,  5,  6,  0 },
        {     10,   46,   -8,  5,  6,  0 }, {     10,   47,   -8,  5,  6,  0 }, {      9,   48,   -9,  5,  6,  0 }, {      8,   49,   -9,  4,  6,  0 }, {      8,   50,  -10,  4,  6,  0 },
        {      7,   51,  -10,  4,  6,  0 }, {      6,   52,  -11,  4,  6,  0 }, {      6,   53,  -11,  4,  6,  0 }, {      5,   54,  -12,  4,  6,  0 }, {      4,   55,  -12,  4,  6,  0 },
        {      3,   56,  -13,  4,  6,  0 }, {      2,   57,  -13,  4,  6,  0 }, {      2,   58,  -14,  4,  6,  0 }, {      1,   59,  -14,  4,  6,  0 }, {      0,   60,  -15,  4,  6,  0 },
        {     -1,   61,  -15,  4,  6,  0 }, {     -2,   62,  -16,  4,  6,  0 }, {     -3,   63,  -16,  3,  6,  0 }, {     -4,   64,  -17,  3,  6,  0 }, {     -5,   65,  -18,  3,  6,  0 },
        {     -6,   66,  -18,  3,  6,  0 }, {     -7,   66,  -19,  3,  6,  0 }, {     -8,   67,  -19,  3,  6,  0 }, {     -9,   68,  -20,  3,  6,  0 }, {    -10,   69,  -20,  3,  6,  0 },
        {    -11,   70,  -21,  3,  6,  0 }, {    -12,   70,  -21,  3,  6,  0 }, {    -13,   71,  -22,  3,  6,  0 }, {    -14,   72,  -22,  3,  6,  0 }, {    -15,   72,  -23,  3,  6,  0 },
        {    -16,   73,  -23,  2,  6,  0 }, {    -17,   74,  -24,  2,  6,  0 }, {    -18,   74,  -24,  2,  6,  0 }, {    -19,   75,  -25,  2,  6,  0 }, {    -20,   76,  -25,  2,  6,  0 },
        {    -21,   76,  -26,  2,  6,  0 }, {    -22,   77,  -26,  2,  6,  0 }, {    -23,   77,  -27,  2,  6,  0 }, {    -24,   78,  -27,  2,  6,  0 }, {    -25,   78,  -28,  2,  6,  0 },
        {    -26,   79,  -28,  2,  6,  0 }, {    -27,   79,  -29,  2,  6,  0 }, {    -28,   80,  -29,  2,  6,  0 }, {    -29,   80,  -30,  2,  6,  0 }, {    -30,   80,  -30,  2,  6,  0 },
        {    -31,   81,  -31,  1,  6,  0 }, {    -32,   81,  -31,  1,  6,  0 }, {    -33,   82,  -32,  1,  6,  0 }, {    -34,   82,  -32,  1,  6,  0 }, {    -35,   82,  -33,  1,  6,  0 },
        {    -36,   83,  -33,  1,  6,  0 }, {    -37,   83,  -34,  1,  6,  0 }, {    -38,   83,  -34,  1,  6,  0 }, {    -39,   84,  -35,  1,  6,  0 }, {    -40,   84,  -35,  1,  6,  0 },
        {    -41,   84,  -36,  1,  6,  0 }, {    -42,   84,  -36,  1,  6,  0 }, {    -43,   85,  -37,  1,  6,  0 }, {    -44,   85,  -37,  1,  6,  0 }, {    -45,   85,  -38,  1,  6,  0 },
        {    -46,   85,  -38,  1,  6,  0 }, {    -47,   86,  -39,  0,  6,  0 }, {    -48,   86,  -39,  0,  6,  0 }, {    -49,   86,  -40,  0,  6,  0 }, {    -50,   86,  -40,  0,  6,  0 },
        {    -51,   86,  -41,  0,  6,  0 }, {    -52,   86,  -41,  0,  6,  0 }, {    -53,   86,  -42,  0,  6,  0 }, {    -54,   87,  -42,  0,  6,  0 }, {    -55,   87,  -43,  0,  6,  0 },
        {    -56,   87,  -43,  0,  6,  0 }, {    -57,   87,  -44,  0,  6,  0 }, {    -58,   87,  -44,  0,  6,  0 }, {    -59,   87,  -45,  0,  6,  0 }, {    -60,   87,  -45,  0,  6,  0 },
        {    -61,   87,  -46,  0,  6,  0 }, {    -62,   87,  -46,  0,  6,  0 }, {    -63,   87,  -47,  0,  6,  0 }, {    -64,   87,  -47, 31,  6,  0 }, {    -64,   86,  -48, 31,  6,  0 },
        {    -64,   85,  -48, 31,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown2, {
        {      1,    9,   15, 16,  6,  0 }, {      2,    9,   14, 15,  6,  0 }, {      3,    9,   14, 15,  6,  0 }, {      4,    9,   13, 15,  6,  0 }, {      5,    9,   13, 15,  6,  0 },
        {      6,    9,   12, 15,  6,  0 }, {      7,    9,   12, 15,  6,  0 }, {      8,    9,   11, 15,  6,  0 }, {      9,    9,   11, 15,  6,  0 }, {     10,    9,   10, 15,  6,  0 },
        {     11,   10,   10, 15,  6,  0 }, {     12,   10,    9, 15,  6,  0 }, {     13,   10,    9, 15,  6,  0 }, {     14,   10,    8, 15,  6,  0 }, {     15,   10,    8, 15,  6,  0 },
        {     16,   10,    7, 15,  6,  0 }, {     17,   10,    7, 15,  6,  0 }, {     18,   11,    6, 14,  6,  0 }, {     19,   11,    6, 14,  6,  0 }, {     20,   11,    5, 14,  6,  0 },
        {     21,   11,    5, 14,  6,  0 }, {     22,   12,    4, 14,  6,  0 }, {     23,   12,    4, 14,  6,  0 }, {     24,   12,    3, 14,  6,  0 }, {     25,   12,    3, 14,  6,  0 },
        {     26,   13,    2, 14,  6,  0 }, {     27,   13,    2, 14,  6,  0 }, {     28,   13,    1, 14,  6,  0 }, {     29,   14,    1, 14,  6,  0 }, {     30,   14,    0, 14,  6,  0 },
        {     31,   14,    0, 14,  6,  0 }, {     32,   15,   -1, 14,  6,  0 }, {     33,   15,   -1, 14,  6,  0 }, {     34,   16,   -2, 13,  6,  0 }, {     35,   16,   -2, 13,  6,  0 },
        {     36,   16,   -3, 13,  6,  0 }, {     37,   17,   -3, 13,  6,  0 }, {     38,   17,   -4, 13,  6,  0 }, {     39,   18,   -4, 13,  6,  0 }, {     40,   18,   -5, 13,  6,  0 },
        {     41,   19,   -5, 13,  6,  0 }, {     42,   19,   -6, 13,  6,  0 }, {     43,   20,   -6, 13,  6,  0 }, {     44,   20,   -7, 13,  6,  0 }, {     45,   21,   -7, 13,  6,  0 },
        {     46,   22,   -8, 13,  6,  0 }, {     47,   22,   -8, 13,  6,  0 }, {     48,   23,   -9, 13,  6,  0 }, {     49,   24,   -9, 12,  6,  0 }, {     50,   24,  -10, 12,  6,  0 },
        {     51,   25,  -10, 12,  6,  0 }, {     52,   26,  -11, 12,  6,  0 }, {     53,   26,  -11, 12,  6,  0 }, {     54,   27,  -12, 12,  6,  0 }, {     55,   28,  -12, 12,  6,  0 },
        {     56,   29,  -13, 12,  6,  0 }, {     57,   30,  -13, 12,  6,  0 }, {     58,   30,  -14, 12,  6,  0 }, {     59,   31,  -14, 12,  6,  0 }, {     60,   32,  -15, 12,  6,  0 },
        {     61,   33,  -15, 12,  6,  0 }, {     62,   34,  -16, 12,  6,  0 }, {     63,   35,  -16, 11,  6,  0 }, {     64,   36,  -17, 11,  6,  0 }, {     65,   37,  -18, 11,  6,  0 },
        {     66,   38,  -18, 11,  6,  0 }, {     66,   39,  -19, 11,  6,  0 }, {     67,   40,  -19, 11,  6,  0 }, {     68,   41,  -20, 11,  6,  0 }, {     69,   42,  -20, 11,  6,  0 },
        {     70,   43,  -21, 11,  6,  0 }, {     70,   44,  -21, 11,  6,  0 }, {     71,   45,  -22, 11,  6,  0 }, {     72,   46,  -22, 11,  6,  0 }, {     72,   47,  -23, 11,  6,  0 },
        {     73,   48,  -23, 10,  6,  0 }, {     74,   49,  -24, 10,  6,  0 }, {     74,   50,  -24, 10,  6,  0 }, {     75,   51,  -25, 10,  6,  0 }, {     76,   52,  -25, 10,  6,  0 },
        {     76,   53,  -26, 10,  6,  0 }, {     77,   54,  -26, 10,  6,  0 }, {     77,   55,  -27, 10,  6,  0 }, {     78,   56,  -27, 10,  6,  0 }, {     78,   57,  -28, 10,  6,  0 },
        {     79,   58,  -28, 10,  6,  0 }, {     79,   59,  -29, 10,  6,  0 }, {     80,   60,  -29, 10,  6,  0 }, {     80,   61,  -30, 10,  6,  0 }, {     80,   62,  -30, 10,  6,  0 },
        {     81,   63,  -31,  9,  6,  0 }, {     81,   64,  -31,  9,  6,  0 }, {     82,   65,  -32,  9,  6,  0 }, {     82,   66,  -32,  9,  6,  0 }, {     82,   67,  -33,  9,  6,  0 },
        {     83,   68,  -33,  9,  6,  0 }, {     83,   69,  -34,  9,  6,  0 }, {     83,   70,  -34,  9,  6,  0 }, {     84,   71,  -35,  9,  6,  0 }, {     84,   72,  -35,  9,  6,  0 },
        {     84,   73,  -36,  9,  6,  0 }, {     84,   74,  -36,  9,  6,  0 }, {     85,   75,  -37,  9,  6,  0 }, {     85,   76,  -37,  9,  6,  0 }, {     85,   77,  -38,  9,  6,  0 },
        {     85,   78,  -38,  9,  6,  0 }, {     86,   79,  -39,  8,  6,  0 }, {     86,   80,  -39,  8,  6,  0 }, {     86,   81,  -40,  8,  6,  0 }, {     86,   82,  -40,  8,  6,  0 },
        {     86,   83,  -41,  8,  6,  0 }, {     86,   84,  -41,  8,  6,  0 }, {     86,   85,  -42,  8,  6,  0 }, {     87,   86,  -42,  8,  6,  0 }, {     87,   87,  -43,  8,  6,  0 },
        {     87,   88,  -43,  8,  6,  0 }, {     87,   89,  -44,  8,  6,  0 }, {     87,   90,  -44,  8,  6,  0 }, {     87,   91,  -45,  8,  6,  0 }, {     87,   92,  -45,  8,  6,  0 },
        {     87,   93,  -46,  8,  6,  0 }, {     87,   94,  -46,  8,  6,  0 }, {     87,   95,  -47,  8,  6,  0 }, {     87,   96,  -47,  7,  6,  0 }, {     86,   96,  -48,  7,  6,  0 },
        {     85,   96,  -48,  7,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown3, {
        {      9,   31,   15, 24,  6,  0 }, {      9,   30,   14, 23,  6,  0 }, {      9,   29,   14, 23,  6,  0 }, {      9,   28,   13, 23,  6,  0 }, {      9,   27,   13, 23,  6,  0 },
        {      9,   26,   12, 23,  6,  0 }, {      9,   25,   12, 23,  6,  0 }, {      9,   24,   11, 23,  6,  0 }, {      9,   23,   11, 23,  6,  0 }, {      9,   22,   10, 23,  6,  0 },
        {     10,   21,   10, 23,  6,  0 }, {     10,   20,    9, 23,  6,  0 }, {     10,   19,    9, 23,  6,  0 }, {     10,   18,    8, 23,  6,  0 }, {     10,   17,    8, 23,  6,  0 },
        {     10,   16,    7, 23,  6,  0 }, {     10,   15,    7, 23,  6,  0 }, {     11,   14,    6, 22,  6,  0 }, {     11,   13,    6, 22,  6,  0 }, {     11,   12,    5, 22,  6,  0 },
        {     11,   11,    5, 22,  6,  0 }, {     12,   10,    4, 22,  6,  0 }, {     12,    9,    4, 22,  6,  0 }, {     12,    8,    3, 22,  6,  0 }, {     12,    7,    3, 22,  6,  0 },
        {     13,    6,    2, 22,  6,  0 }, {     13,    5,    2, 22,  6,  0 }, {     13,    4,    1, 22,  6,  0 }, {     14,    3,    1, 22,  6,  0 }, {     14,    2,    0, 22,  6,  0 },
        {     14,    1,    0, 22,  6,  0 }, {     15,    0,   -1, 22,  6,  0 }, {     15,   -1,   -1, 22,  6,  0 }, {     16,   -2,   -2, 21,  6,  0 }, {     16,   -3,   -2, 21,  6,  0 },
        {     16,   -4,   -3, 21,  6,  0 }, {     17,   -5,   -3, 21,  6,  0 }, {     17,   -6,   -4, 21,  6,  0 }, {     18,   -7,   -4, 21,  6,  0 }, {     18,   -8,   -5, 21,  6,  0 },
        {     19,   -9,   -5, 21,  6,  0 }, {     19,  -10,   -6, 21,  6,  0 }, {     20,  -11,   -6, 21,  6,  0 }, {     20,  -12,   -7, 21,  6,  0 }, {     21,  -13,   -7, 21,  6,  0 },
        {     22,  -14,   -8, 21,  6,  0 }, {     22,  -15,   -8, 21,  6,  0 }, {     23,  -16,   -9, 21,  6,  0 }, {     24,  -17,   -9, 20,  6,  0 }, {     24,  -18,  -10, 20,  6,  0 },
        {     25,  -19,  -10, 20,  6,  0 }, {     26,  -20,  -11, 20,  6,  0 }, {     26,  -21,  -11, 20,  6,  0 }, {     27,  -22,  -12, 20,  6,  0 }, {     28,  -23,  -12, 20,  6,  0 },
        {     29,  -24,  -13, 20,  6,  0 }, {     30,  -25,  -13, 20,  6,  0 }, {     30,  -26,  -14, 20,  6,  0 }, {     31,  -27,  -14, 20,  6,  0 }, {     32,  -28,  -15, 20,  6,  0 },
        {     33,  -29,  -15, 20,  6,  0 }, {     34,  -30,  -16, 20,  6,  0 }, {     35,  -31,  -16, 19,  6,  0 }, {     36,  -32,  -17, 19,  6,  0 }, {     37,  -33,  -18, 19,  6,  0 },
        {     38,  -34,  -18, 19,  6,  0 }, {     39,  -34,  -19, 19,  6,  0 }, {     40,  -35,  -19, 19,  6,  0 }, {     41,  -36,  -20, 19,  6,  0 }, {     42,  -37,  -20, 19,  6,  0 },
        {     43,  -38,  -21, 19,  6,  0 }, {     44,  -38,  -21, 19,  6,  0 }, {     45,  -39,  -22, 19,  6,  0 }, {     46,  -40,  -22, 19,  6,  0 }, {     47,  -40,  -23, 19,  6,  0 },
        {     48,  -41,  -23, 18,  6,  0 }, {     49,  -42,  -24, 18,  6,  0 }, {     50,  -42,  -24, 18,  6,  0 }, {     51,  -43,  -25, 18,  6,  0 }, {     52,  -44,  -25, 18,  6,  0 },
        {     53,  -44,  -26, 18,  6,  0 }, {     54,  -45,  -26, 18,  6,  0 }, {     55,  -45,  -27, 18,  6,  0 }, {     56,  -46,  -27, 18,  6,  0 }, {     57,  -46,  -28, 18,  6,  0 },
        {     58,  -47,  -28, 18,  6,  0 }, {     59,  -47,  -29, 18,  6,  0 }, {     60,  -48,  -29, 18,  6,  0 }, {     61,  -48,  -30, 18,  6,  0 }, {     62,  -48,  -30, 18,  6,  0 },
        {     63,  -49,  -31, 17,  6,  0 }, {     64,  -49,  -31, 17,  6,  0 }, {     65,  -50,  -32, 17,  6,  0 }, {     66,  -50,  -32, 17,  6,  0 }, {     67,  -50,  -33, 17,  6,  0 },
        {     68,  -51,  -33, 17,  6,  0 }, {     69,  -51,  -34, 17,  6,  0 }, {     70,  -51,  -34, 17,  6,  0 }, {     71,  -52,  -35, 17,  6,  0 }, {     72,  -52,  -35, 17,  6,  0 },
        {     73,  -52,  -36, 17,  6,  0 }, {     74,  -52,  -36, 17,  6,  0 }, {     75,  -53,  -37, 17,  6,  0 }, {     76,  -53,  -37, 17,  6,  0 }, {     77,  -53,  -38, 17,  6,  0 },
        {     78,  -53,  -38, 17,  6,  0 }, {     79,  -54,  -39, 16,  6,  0 }, {     80,  -54,  -39, 16,  6,  0 }, {     81,  -54,  -40, 16,  6,  0 }, {     82,  -54,  -40, 16,  6,  0 },
        {     83,  -54,  -41, 16,  6,  0 }, {     84,  -54,  -41, 16,  6,  0 }, {     85,  -54,  -42, 16,  6,  0 }, {     86,  -55,  -42, 16,  6,  0 }, {     87,  -55,  -43, 16,  6,  0 },
        {     88,  -55,  -43, 16,  6,  0 }, {     89,  -55,  -44, 16,  6,  0 }, {     90,  -55,  -44, 16,  6,  0 }, {     91,  -55,  -45, 16,  6,  0 }, {     92,  -55,  -45, 16,  6,  0 },
        {     93,  -55,  -46, 16,  6,  0 }, {     94,  -55,  -46, 16,  6,  0 }, {     95,  -55,  -47, 16,  6,  0 }, {     96,  -55,  -47, 15,  6,  0 }, {     96,  -54,  -48, 15,  6,  0 },
        {     96,  -53,  -48, 15,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegDown0, {
        {     31,   23,   15,  0,  6,  0 }, {     30,   23,   14,  1,  6,  0 }, {     29,   23,   14,  1,  6,  0 }, {     28,   23,   13,  1,  6,  0 }, {     27,   23,   13,  1,  6,  0 },
        {     26,   23,   12,  1,  6,  0 }, {     25,   23,   11,  1,  6,  0 }, {     24,   23,   11,  1,  6,  0 }, {     23,   23,   10,  1,  6,  0 }, {     22,   24,   10,  1,  6,  0 },
        {     21,   24,    9,  1,  6,  0 }, {     20,   24,    8,  1,  6,  0 }, {     19,   24,    8,  1,  6,  0 }, {     18,   24,    7,  1,  6,  0 }, {     17,   24,    6,  1,  6,  0 },
        {     16,   25,    6,  2,  6,  0 }, {     15,   25,    5,  2,  6,  0 }, {     14,   25,    5,  2,  6,  0 }, {     13,   25,    4,  2,  6,  0 }, {     12,   26,    3,  2,  6,  0 },
        {     11,   26,    3,  2,  6,  0 }, {     10,   26,    2,  2,  6,  0 }, {      9,   26,    2,  2,  6,  0 }, {      8,   27,    1,  2,  6,  0 }, {      7,   27,    0,  2,  6,  0 },
        {      6,   27,    0,  2,  6,  0 }, {      5,   28,   -1,  2,  6,  0 }, {      4,   28,   -1,  2,  6,  0 }, {      3,   29,   -2,  3,  6,  0 }, {      2,   29,   -3,  3,  6,  0 },
        {      1,   29,   -3,  3,  6,  0 }, {      0,   30,   -4,  3,  6,  0 }, {     -1,   30,   -5,  3,  6,  0 }, {     -2,   31,   -5,  3,  6,  0 }, {     -3,   31,   -6,  3,  6,  0 },
        {     -4,   32,   -6,  3,  6,  0 }, {     -5,   33,   -7,  3,  6,  0 }, {     -6,   33,   -8,  3,  6,  0 }, {     -7,   34,   -8,  3,  6,  0 }, {     -8,   34,   -9,  3,  6,  0 },
        {     -9,   35,   -9,  3,  6,  0 }, {    -10,   36,  -10,  4,  6,  0 }, {    -11,   36,  -11,  4,  6,  0 }, {    -12,   37,  -11,  4,  6,  0 }, {    -13,   38,  -12,  4,  6,  0 },
        {    -14,   39,  -12,  4,  6,  0 }, {    -15,   39,  -13,  4,  6,  0 }, {    -16,   40,  -14,  4,  6,  0 }, {    -17,   41,  -14,  4,  6,  0 }, {    -18,   42,  -15,  4,  6,  0 },
        {    -19,   43,  -15,  4,  6,  0 }, {    -20,   44,  -16,  4,  6,  0 }, {    -21,   45,  -17,  5,  6,  0 }, {    -22,   46,  -17,  5,  6,  0 }, {    -23,   47,  -18,  5,  6,  0 },
        {    -24,   48,  -19,  5,  6,  0 }, {    -25,   49,  -19,  5,  6,  0 }, {    -25,   50,  -20,  5,  6,  0 }, {    -26,   51,  -20,  5,  6,  0 }, {    -27,   52,  -21,  5,  6,  0 },
        {    -28,   53,  -22,  5,  6,  0 }, {    -28,   54,  -22,  5,  6,  0 }, {    -29,   55,  -23,  6,  6,  0 }, {    -30,   56,  -23,  6,  6,  0 }, {    -30,   57,  -24,  6,  6,  0 },
        {    -31,   58,  -25,  6,  6,  0 }, {    -31,   59,  -25,  6,  6,  0 }, {    -32,   60,  -26,  6,  6,  0 }, {    -33,   61,  -26,  6,  6,  0 }, {    -33,   62,  -27,  6,  6,  0 },
        {    -34,   63,  -28,  6,  6,  0 }, {    -34,   64,  -28,  6,  6,  0 }, {    -35,   65,  -29,  6,  6,  0 }, {    -35,   66,  -29,  6,  6,  0 }, {    -35,   67,  -30,  6,  6,  0 },
        {    -36,   68,  -31,  7,  6,  0 }, {    -36,   69,  -31,  7,  6,  0 }, {    -37,   70,  -32,  7,  6,  0 }, {    -37,   71,  -33,  7,  6,  0 }, {    -37,   72,  -33,  7,  6,  0 },
        {    -38,   73,  -34,  7,  6,  0 }, {    -38,   74,  -34,  7,  6,  0 }, {    -38,   75,  -35,  7,  6,  0 }, {    -38,   76,  -36,  7,  6,  0 }, {    -39,   77,  -36,  7,  6,  0 },
        {    -39,   78,  -37,  7,  6,  0 }, {    -39,   79,  -37,  7,  6,  0 }, {    -39,   80,  -38,  7,  6,  0 }, {    -40,   81,  -39,  8,  6,  0 }, {    -40,   82,  -39,  8,  6,  0 },
        {    -40,   83,  -40,  8,  6,  0 }, {    -40,   84,  -40,  8,  6,  0 }, {    -40,   85,  -41,  8,  6,  0 }, {    -40,   86,  -42,  8,  6,  0 }, {    -41,   87,  -42,  8,  6,  0 },
        {    -41,   88,  -43,  8,  6,  0 }, {    -41,   89,  -44,  8,  6,  0 }, {    -41,   90,  -44,  8,  6,  0 }, {    -41,   91,  -45,  8,  6,  0 }, {    -41,   92,  -45,  8,  6,  0 },
        {    -41,   93,  -46,  8,  6,  0 }, {    -41,   94,  -47,  8,  6,  0 }, {    -41,   95,  -47,  8,  6,  0 }, {    -41,   96,  -48,  9,  6,  0 }, {    -40,   96,  -48,  9,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegDown1, {
        {     23,    1,   15,  8,  6,  0 }, {     23,    2,   14,  9,  6,  0 }, {     23,    3,   14,  9,  6,  0 }, {     23,    4,   13,  9,  6,  0 }, {     23,    5,   13,  9,  6,  0 },
        {     23,    6,   12,  9,  6,  0 }, {     23,    7,   11,  9,  6,  0 }, {     23,    8,   11,  9,  6,  0 }, {     23,    9,   10,  9,  6,  0 }, {     24,   10,   10,  9,  6,  0 },
        {     24,   11,    9,  9,  6,  0 }, {     24,   12,    8,  9,  6,  0 }, {     24,   13,    8,  9,  6,  0 }, {     24,   14,    7,  9,  6,  0 }, {     24,   15,    6,  9,  6,  0 },
        {     25,   16,    6, 10,  6,  0 }, {     25,   17,    5, 10,  6,  0 }, {     25,   18,    5, 10,  6,  0 }, {     25,   19,    4, 10,  6,  0 }, {     26,   20,    3, 10,  6,  0 },
        {     26,   21,    3, 10,  6,  0 }, {     26,   22,    2, 10,  6,  0 }, {     26,   23,    2, 10,  6,  0 }, {     27,   24,    1, 10,  6,  0 }, {     27,   25,    0, 10,  6,  0 },
        {     27,   26,    0, 10,  6,  0 }, {     28,   27,   -1, 10,  6,  0 }, {     28,   28,   -1, 10,  6,  0 }, {     29,   29,   -2, 11,  6,  0 }, {     29,   30,   -3, 11,  6,  0 },
        {     29,   31,   -3, 11,  6,  0 }, {     30,   32,   -4, 11,  6,  0 }, {     30,   33,   -5, 11,  6,  0 }, {     31,   34,   -5, 11,  6,  0 }, {     31,   35,   -6, 11,  6,  0 },
        {     32,   36,   -6, 11,  6,  0 }, {     33,   37,   -7, 11,  6,  0 }, {     33,   38,   -8, 11,  6,  0 }, {     34,   39,   -8, 11,  6,  0 }, {     34,   40,   -9, 11,  6,  0 },
        {     35,   41,   -9, 11,  6,  0 }, {     36,   42,  -10, 12,  6,  0 }, {     36,   43,  -11, 12,  6,  0 }, {     37,   44,  -11, 12,  6,  0 }, {     38,   45,  -12, 12,  6,  0 },
        {     39,   46,  -12, 12,  6,  0 }, {     39,   47,  -13, 12,  6,  0 }, {     40,   48,  -14, 12,  6,  0 }, {     41,   49,  -14, 12,  6,  0 }, {     42,   50,  -15, 12,  6,  0 },
        {     43,   51,  -15, 12,  6,  0 }, {     44,   52,  -16, 12,  6,  0 }, {     45,   53,  -17, 13,  6,  0 }, {     46,   54,  -17, 13,  6,  0 }, {     47,   55,  -18, 13,  6,  0 },
        {     48,   56,  -19, 13,  6,  0 }, {     49,   57,  -19, 13,  6,  0 }, {     50,   57,  -20, 13,  6,  0 }, {     51,   58,  -20, 13,  6,  0 }, {     52,   59,  -21, 13,  6,  0 },
        {     53,   60,  -22, 13,  6,  0 }, {     54,   60,  -22, 13,  6,  0 }, {     55,   61,  -23, 14,  6,  0 }, {     56,   62,  -23, 14,  6,  0 }, {     57,   62,  -24, 14,  6,  0 },
        {     58,   63,  -25, 14,  6,  0 }, {     59,   63,  -25, 14,  6,  0 }, {     60,   64,  -26, 14,  6,  0 }, {     61,   65,  -26, 14,  6,  0 }, {     62,   65,  -27, 14,  6,  0 },
        {     63,   66,  -28, 14,  6,  0 }, {     64,   66,  -28, 14,  6,  0 }, {     65,   67,  -29, 14,  6,  0 }, {     66,   67,  -29, 14,  6,  0 }, {     67,   67,  -30, 14,  6,  0 },
        {     68,   68,  -31, 15,  6,  0 }, {     69,   68,  -31, 15,  6,  0 }, {     70,   69,  -32, 15,  6,  0 }, {     71,   69,  -33, 15,  6,  0 }, {     72,   69,  -33, 15,  6,  0 },
        {     73,   70,  -34, 15,  6,  0 }, {     74,   70,  -34, 15,  6,  0 }, {     75,   70,  -35, 15,  6,  0 }, {     76,   70,  -36, 15,  6,  0 }, {     77,   71,  -36, 15,  6,  0 },
        {     78,   71,  -37, 15,  6,  0 }, {     79,   71,  -37, 15,  6,  0 }, {     80,   71,  -38, 15,  6,  0 }, {     81,   72,  -39, 16,  6,  0 }, {     82,   72,  -39, 16,  6,  0 },
        {     83,   72,  -40, 16,  6,  0 }, {     84,   72,  -40, 16,  6,  0 }, {     85,   72,  -41, 16,  6,  0 }, {     86,   72,  -42, 16,  6,  0 }, {     87,   73,  -42, 16,  6,  0 },
        {     88,   73,  -43, 16,  6,  0 }, {     89,   73,  -44, 16,  6,  0 }, {     90,   73,  -44, 16,  6,  0 }, {     91,   73,  -45, 16,  6,  0 }, {     92,   73,  -45, 16,  6,  0 },
        {     93,   73,  -46, 16,  6,  0 }, {     94,   73,  -47, 16,  6,  0 }, {     95,   73,  -47, 16,  6,  0 }, {     96,   73,  -48, 17,  6,  0 }, {     96,   72,  -48, 17,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegDown2, {
        {      1,    9,   15, 16,  6,  0 }, {      2,    9,   14, 17,  6,  0 }, {      3,    9,   14, 17,  6,  0 }, {      4,    9,   13, 17,  6,  0 }, {      5,    9,   13, 17,  6,  0 },
        {      6,    9,   12, 17,  6,  0 }, {      7,    9,   11, 17,  6,  0 }, {      8,    9,   11, 17,  6,  0 }, {      9,    9,   10, 17,  6,  0 }, {     10,    8,   10, 17,  6,  0 },
        {     11,    8,    9, 17,  6,  0 }, {     12,    8,    8, 17,  6,  0 }, {     13,    8,    8, 17,  6,  0 }, {     14,    8,    7, 17,  6,  0 }, {     15,    8,    6, 17,  6,  0 },
        {     16,    7,    6, 18,  6,  0 }, {     17,    7,    5, 18,  6,  0 }, {     18,    7,    5, 18,  6,  0 }, {     19,    7,    4, 18,  6,  0 }, {     20,    6,    3, 18,  6,  0 },
        {     21,    6,    3, 18,  6,  0 }, {     22,    6,    2, 18,  6,  0 }, {     23,    6,    2, 18,  6,  0 }, {     24,    5,    1, 18,  6,  0 }, {     25,    5,    0, 18,  6,  0 },
        {     26,    5,    0, 18,  6,  0 }, {     27,    4,   -1, 18,  6,  0 }, {     28,    4,   -1, 18,  6,  0 }, {     29,    3,   -2, 19,  6,  0 }, {     30,    3,   -3, 19,  6,  0 },
        {     31,    3,   -3, 19,  6,  0 }, {     32,    2,   -4, 19,  6,  0 }, {     33,    2,   -5, 19,  6,  0 }, {     34,    1,   -5, 19,  6,  0 }, {     35,    1,   -6, 19,  6,  0 },
        {     36,    0,   -6, 19,  6,  0 }, {     37,   -1,   -7, 19,  6,  0 }, {     38,   -1,   -8, 19,  6,  0 }, {     39,   -2,   -8, 19,  6,  0 }, {     40,   -2,   -9, 19,  6,  0 },
        {     41,   -3,   -9, 19,  6,  0 }, {     42,   -4,  -10, 20,  6,  0 }, {     43,   -4,  -11, 20,  6,  0 }, {     44,   -5,  -11, 20,  6,  0 }, {     45,   -6,  -12, 20,  6,  0 },
        {     46,   -7,  -12, 20,  6,  0 }, {     47,   -7,  -13, 20,  6,  0 }, {     48,   -8,  -14, 20,  6,  0 }, {     49,   -9,  -14, 20,  6,  0 }, {     50,  -10,  -15, 20,  6,  0 },
        {     51,  -11,  -15, 20,  6,  0 }, {     52,  -12,  -16, 20,  6,  0 }, {     53,  -13,  -17, 21,  6,  0 }, {     54,  -14,  -17, 21,  6,  0 }, {     55,  -15,  -18, 21,  6,  0 },
        {     56,  -16,  -19, 21,  6,  0 }, {     57,  -17,  -19, 21,  6,  0 }, {     57,  -18,  -20, 21,  6,  0 }, {     58,  -19,  -20, 21,  6,  0 }, {     59,  -20,  -21, 21,  6,  0 },
        {     60,  -21,  -22, 21,  6,  0 }, {     60,  -22,  -22, 21,  6,  0 }, {     61,  -23,  -23, 22,  6,  0 }, {     62,  -24,  -23, 22,  6,  0 }, {     62,  -25,  -24, 22,  6,  0 },
        {     63,  -26,  -25, 22,  6,  0 }, {     63,  -27,  -25, 22,  6,  0 }, {     64,  -28,  -26, 22,  6,  0 }, {     65,  -29,  -26, 22,  6,  0 }, {     65,  -30,  -27, 22,  6,  0 },
        {     66,  -31,  -28, 22,  6,  0 }, {     66,  -32,  -28, 22,  6,  0 }, {     67,  -33,  -29, 22,  6,  0 }, {     67,  -34,  -29, 22,  6,  0 }, {     67,  -35,  -30, 22,  6,  0 },
        {     68,  -36,  -31, 23,  6,  0 }, {     68,  -37,  -31, 23,  6,  0 }, {     69,  -38,  -32, 23,  6,  0 }, {     69,  -39,  -33, 23,  6,  0 }, {     69,  -40,  -33, 23,  6,  0 },
        {     70,  -41,  -34, 23,  6,  0 }, {     70,  -42,  -34, 23,  6,  0 }, {     70,  -43,  -35, 23,  6,  0 }, {     70,  -44,  -36, 23,  6,  0 }, {     71,  -45,  -36, 23,  6,  0 },
        {     71,  -46,  -37, 23,  6,  0 }, {     71,  -47,  -37, 23,  6,  0 }, {     71,  -48,  -38, 23,  6,  0 }, {     72,  -49,  -39, 24,  6,  0 }, {     72,  -50,  -39, 24,  6,  0 },
        {     72,  -51,  -40, 24,  6,  0 }, {     72,  -52,  -40, 24,  6,  0 }, {     72,  -53,  -41, 24,  6,  0 }, {     72,  -54,  -42, 24,  6,  0 }, {     73,  -55,  -42, 24,  6,  0 },
        {     73,  -56,  -43, 24,  6,  0 }, {     73,  -57,  -44, 24,  6,  0 }, {     73,  -58,  -44, 24,  6,  0 }, {     73,  -59,  -45, 24,  6,  0 }, {     73,  -60,  -45, 24,  6,  0 },
        {     73,  -61,  -46, 24,  6,  0 }, {     73,  -62,  -47, 24,  6,  0 }, {     73,  -63,  -47, 24,  6,  0 }, {     73,  -64,  -48, 25,  6,  0 }, {     72,  -64,  -48, 25,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn5Tiles25DegDown3, {
        {      9,   31,   15, 24,  6,  0 }, {      9,   30,   14, 25,  6,  0 }, {      9,   29,   14, 25,  6,  0 }, {      9,   28,   13, 25,  6,  0 }, {      9,   27,   13, 25,  6,  0 },
        {      9,   26,   12, 25,  6,  0 }, {      9,   25,   11, 25,  6,  0 }, {      9,   24,   11, 25,  6,  0 }, {      9,   23,   10, 25,  6,  0 }, {      8,   22,   10, 25,  6,  0 },
        {      8,   21,    9, 25,  6,  0 }, {      8,   20,    8, 25,  6,  0 }, {      8,   19,    8, 25,  6,  0 }, {      8,   18,    7, 25,  6,  0 }, {      8,   17,    6, 25,  6,  0 },
        {      7,   16,    6, 26,  6,  0 }, {      7,   15,    5, 26,  6,  0 }, {      7,   14,    5, 26,  6,  0 }, {      7,   13,    4, 26,  6,  0 }, {      6,   12,    3, 26,  6,  0 },
        {      6,   11,    3, 26,  6,  0 }, {      6,   10,    2, 26,  6,  0 }, {      6,    9,    2, 26,  6,  0 }, {      5,    8,    1, 26,  6,  0 }, {      5,    7,    0, 26,  6,  0 },
        {      5,    6,    0, 26,  6,  0 }, {      4,    5,   -1, 26,  6,  0 }, {      4,    4,   -1, 26,  6,  0 }, {      3,    3,   -2, 27,  6,  0 }, {      3,    2,   -3, 27,  6,  0 },
        {      3,    1,   -3, 27,  6,  0 }, {      2,    0,   -4, 27,  6,  0 }, {      2,   -1,   -5, 27,  6,  0 }, {      1,   -2,   -5, 27,  6,  0 }, {      1,   -3,   -6, 27,  6,  0 },
        {      0,   -4,   -6, 27,  6,  0 }, {     -1,   -5,   -7, 27,  6,  0 }, {     -1,   -6,   -8, 27,  6,  0 }, {     -2,   -7,   -8, 27,  6,  0 }, {     -2,   -8,   -9, 27,  6,  0 },
        {     -3,   -9,   -9, 27,  6,  0 }, {     -4,  -10,  -10, 28,  6,  0 }, {     -4,  -11,  -11, 28,  6,  0 }, {     -5,  -12,  -11, 28,  6,  0 }, {     -6,  -13,  -12, 28,  6,  0 },
        {     -7,  -14,  -12, 28,  6,  0 }, {     -7,  -15,  -13, 28,  6,  0 }, {     -8,  -16,  -14, 28,  6,  0 }, {     -9,  -17,  -14, 28,  6,  0 }, {    -10,  -18,  -15, 28,  6,  0 },
        {    -11,  -19,  -15, 28,  6,  0 }, {    -12,  -20,  -16, 28,  6,  0 }, {    -13,  -21,  -17, 29,  6,  0 }, {    -14,  -22,  -17, 29,  6,  0 }, {    -15,  -23,  -18, 29,  6,  0 },
        {    -16,  -24,  -19, 29,  6,  0 }, {    -17,  -25,  -19, 29,  6,  0 }, {    -18,  -25,  -20, 29,  6,  0 }, {    -19,  -26,  -20, 29,  6,  0 }, {    -20,  -27,  -21, 29,  6,  0 },
        {    -21,  -28,  -22, 29,  6,  0 }, {    -22,  -28,  -22, 29,  6,  0 }, {    -23,  -29,  -23, 30,  6,  0 }, {    -24,  -30,  -23, 30,  6,  0 }, {    -25,  -30,  -24, 30,  6,  0 },
        {    -26,  -31,  -25, 30,  6,  0 }, {    -27,  -31,  -25, 30,  6,  0 }, {    -28,  -32,  -26, 30,  6,  0 }, {    -29,  -33,  -26, 30,  6,  0 }, {    -30,  -33,  -27, 30,  6,  0 },
        {    -31,  -34,  -28, 30,  6,  0 }, {    -32,  -34,  -28, 30,  6,  0 }, {    -33,  -35,  -29, 30,  6,  0 }, {    -34,  -35,  -29, 30,  6,  0 }, {    -35,  -35,  -30, 30,  6,  0 },
        {    -36,  -36,  -31, 31,  6,  0 }, {    -37,  -36,  -31, 31,  6,  0 }, {    -38,  -37,  -32, 31,  6,  0 }, {    -39,  -37,  -33, 31,  6,  0 }, {    -40,  -37,  -33, 31,  6,  0 },
        {    -41,  -38,  -34, 31,  6,  0 }, {    -42,  -38,  -34, 31,  6,  0 }, {    -43,  -38,  -35, 31,  6,  0 }, {    -44,  -38,  -36, 31,  6,  0 }, {    -45,  -39,  -36, 31,  6,  0 },
        {    -46,  -39,  -37, 31,  6,  0 }, {    -47,  -39,  -37, 31,  6,  0 }, {    -48,  -39,  -38, 31,  6,  0 }, {    -49,  -40,  -39,  0,  6,  0 }, {    -50,  -40,  -39,  0,  6,  0 },
        {    -51,  -40,  -40,  0,  6,  0 }, {    -52,  -40,  -40,  0,  6,  0 }, {    -53,  -40,  -41,  0,  6,  0 }, {    -54,  -40,  -42,  0,  6,  0 }, {    -55,  -41,  -42,  0,  6,  0 },
        {    -56,  -41,  -43,  0,  6,  0 }, {    -57,  -41,  -44,  0,  6,  0 }, {    -58,  -41,  -44,  0,  6,  0 }, {    -59,  -41,  -45,  0,  6,  0 }, {    -60,  -41,  -45,  0,  6,  0 },
        {    -61,  -41,  -46,  0,  6,  0 }, {    -62,  -41,  -47,  0,  6,  0 }, {    -63,  -41,  -47,  0,  6,  0 }, {    -64,  -41,  -48,  1,  6,  0 }, {    -64,  -40,  -48,  1,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftSBend0, {
        {     32,   23,    0,  0,  0,  0 }, {     31,   23,    0,  0,  0,  0 }, {     30,   23,    0,  0,  0,  0 }, {     29,   23,    0,  0,  0,  0 }, {     28,   23,    0,  0,  0,  0 },
        {     27,   23,    0,  0,  0,  0 }, {     26,   23,    0,  0,  0,  0 }, {     25,   23,    0,  0,  0,  0 }, {     24,   23,    0,  0,  0,  0 }, {     23,   23,    0, 31,  0,  0 },
        {     22,   22,    0, 31,  0,  0 }, {     21,   22,    0, 31,  0,  0 }, {     20,   22,    0, 31,  0,  0 }, {     19,   22,    0, 31,  0,  0 }, {     18,   22,    0, 31,  0,  0 },
        {     17,   22,    0, 31,  0,  0 }, {     16,   22,    0, 31,  0,  0 }, {     15,   21,    0, 31,  0,  0 }, {     14,   21,    0, 31,  0,  0 }, {     13,   21,    0, 31,  0,  0 },
        {     12,   21,    0, 31,  0,  0 }, {     11,   20,    0, 31,  0,  0 }, {     10,   20,    0, 31,  0,  0 }, {      9,   20,    0, 31,  0,  0 }, {      8,   20,    0, 31,  0,  0 },
        {      7,   19,    0, 30,  0,  0 }, {      6,   19,    0, 30,  0,  0 }, {      5,   19,    0, 30,  0,  0 }, {      4,   18,    0, 30,  0,  0 }, {      3,   18,    0, 30,  0,  0 },
        {      2,   17,    0, 30,  0,  0 }, {      1,   17,    0, 30,  0,  0 }, {      0,   17,    0, 30,  0,  0 }, {     -1,   16,    0, 30,  0,  0 }, {     -2,   16,    0, 30,  0,  0 },
        {     -3,   15,    0, 30,  0,  0 }, {     -4,   15,    0, 30,  0,  0 }, {     -5,   14,    0, 30,  0,  0 }, {     -6,   14,    0, 30,  0,  0 }, {     -7,   13,    0, 30,  0,  0 },
        {     -8,   13,    0, 29,  0,  0 }, {     -9,   12,    0, 29,  0,  0 }, {    -10,   12,    0, 29,  0,  0 }, {    -11,   11,    0, 29,  0,  0 }, {    -12,   11,    0, 29,  0,  0 },
        {    -13,   10,    0, 29,  0,  0 }, {    -14,    9,    0, 29,  0,  0 }, {    -15,    9,    0, 29,  0,  0 }, {    -16,    8,    0, 29,  0,  0 }, {    -17,    7,    0, 29,  0,  0 },
        {    -18,    7,    0, 29,  0,  0 }, {    -19,    6,    0, 29,  0,  0 }, {    -20,    5,    0, 29,  0,  0 }, {    -21,    5,    0, 29,  0,  0 }, {    -22,    4,    0, 29,  0,  0 },
        {    -23,    3,    0, 29,  0,  0 }, {    -24,    3,    0, 29,  0,  0 }, {    -25,    2,    0, 29,  0,  0 }, {    -26,    1,    0, 29,  0,  0 }, {    -27,    1,    0, 29,  0,  0 },
        {    -28,    0,    0, 29,  0,  0 }, {    -29,    0,    0, 29,  0,  0 }, {    -30,   -1,    0, 30,  0,  0 }, {    -31,   -1,    0, 30,  0,  0 }, {    -32,   -2,    0, 30,  0,  0 },
        {    -33,   -2,    0, 30,  0,  0 }, {    -34,   -3,    0, 30,  0,  0 }, {    -35,   -3,    0, 30,  0,  0 }, {    -36,   -4,    0, 30,  0,  0 }, {    -37,   -4,    0, 30,  0,  0 },
        {    -38,   -4,    0, 30,  0,  0 }, {    -39,   -5,    0, 30,  0,  0 }, {    -40,   -5,    0, 30,  0,  0 }, {    -41,   -5,    0, 30,  0,  0 }, {    -42,   -6,    0, 30,  0,  0 },
        {    -43,   -6,    0, 30,  0,  0 }, {    -44,   -6,    0, 31,  0,  0 }, {    -45,   -7,    0, 31,  0,  0 }, {    -46,   -7,    0, 31,  0,  0 }, {    -47,   -7,    0, 31,  0,  0 },
        {    -48,   -7,    0, 31,  0,  0 }, {    -49,   -8,    0, 31,  0,  0 }, {    -50,   -8,    0, 31,  0,  0 }, {    -51,   -8,    0, 31,  0,  0 }, {    -52,   -8,    0, 31,  0,  0 },
        {    -53,   -8,    0, 31,  0,  0 }, {    -54,   -8,    0, 31,  0,  0 }, {    -55,   -9,    0, 31,  0,  0 }, {    -56,   -9,    0,  0,  0,  0 }, {    -57,   -9,    0,  0,  0,  0 },
        {    -58,   -9,    0,  0,  0,  0 }, {    -59,   -9,    0,  0,  0,  0 }, {    -60,   -9,    0,  0,  0,  0 }, {    -61,   -9,    0,  0,  0,  0 }, {    -62,   -9,    0,  0,  0,  0 },
        {    -63,   -9,    0,  0,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftSBend1, {
        {     23,    0,    0,  8,  0,  0 }, {     23,    1,    0,  8,  0,  0 }, {     23,    2,    0,  8,  0,  0 }, {     23,    3,    0,  8,  0,  0 }, {     23,    4,    0,  8,  0,  0 },
        {     23,    5,    0,  8,  0,  0 }, {     23,    6,    0,  8,  0,  0 }, {     23,    7,    0,  8,  0,  0 }, {     23,    8,    0,  8,  0,  0 }, {     23,    9,    0,  7,  0,  0 },
        {     22,   10,    0,  7,  0,  0 }, {     22,   11,    0,  7,  0,  0 }, {     22,   12,    0,  7,  0,  0 }, {     22,   13,    0,  7,  0,  0 }, {     22,   14,    0,  7,  0,  0 },
        {     22,   15,    0,  7,  0,  0 }, {     22,   16,    0,  7,  0,  0 }, {     21,   17,    0,  7,  0,  0 }, {     21,   18,    0,  7,  0,  0 }, {     21,   19,    0,  7,  0,  0 },
        {     21,   20,    0,  7,  0,  0 }, {     20,   21,    0,  7,  0,  0 }, {     20,   22,    0,  7,  0,  0 }, {     20,   23,    0,  7,  0,  0 }, {     20,   24,    0,  7,  0,  0 },
        {     19,   25,    0,  6,  0,  0 }, {     19,   26,    0,  6,  0,  0 }, {     19,   27,    0,  6,  0,  0 }, {     18,   28,    0,  6,  0,  0 }, {     18,   29,    0,  6,  0,  0 },
        {     17,   30,    0,  6,  0,  0 }, {     17,   31,    0,  6,  0,  0 }, {     17,   32,    0,  6,  0,  0 }, {     16,   33,    0,  6,  0,  0 }, {     16,   34,    0,  6,  0,  0 },
        {     15,   35,    0,  6,  0,  0 }, {     15,   36,    0,  6,  0,  0 }, {     14,   37,    0,  6,  0,  0 }, {     14,   38,    0,  6,  0,  0 }, {     13,   39,    0,  6,  0,  0 },
        {     13,   40,    0,  5,  0,  0 }, {     12,   41,    0,  5,  0,  0 }, {     12,   42,    0,  5,  0,  0 }, {     11,   43,    0,  5,  0,  0 }, {     11,   44,    0,  5,  0,  0 },
        {     10,   45,    0,  5,  0,  0 }, {      9,   46,    0,  5,  0,  0 }, {      9,   47,    0,  5,  0,  0 }, {      8,   48,    0,  5,  0,  0 }, {      7,   49,    0,  5,  0,  0 },
        {      7,   50,    0,  5,  0,  0 }, {      6,   51,    0,  5,  0,  0 }, {      5,   52,    0,  5,  0,  0 }, {      5,   53,    0,  5,  0,  0 }, {      4,   54,    0,  5,  0,  0 },
        {      3,   55,    0,  5,  0,  0 }, {      3,   56,    0,  5,  0,  0 }, {      2,   57,    0,  5,  0,  0 }, {      1,   58,    0,  5,  0,  0 }, {      1,   59,    0,  5,  0,  0 },
        {      0,   60,    0,  5,  0,  0 }, {      0,   61,    0,  5,  0,  0 }, {     -1,   62,    0,  6,  0,  0 }, {     -1,   63,    0,  6,  0,  0 }, {     -2,   64,    0,  6,  0,  0 },
        {     -2,   65,    0,  6,  0,  0 }, {     -3,   66,    0,  6,  0,  0 }, {     -3,   67,    0,  6,  0,  0 }, {     -4,   68,    0,  6,  0,  0 }, {     -4,   69,    0,  6,  0,  0 },
        {     -4,   70,    0,  6,  0,  0 }, {     -5,   71,    0,  6,  0,  0 }, {     -5,   72,    0,  6,  0,  0 }, {     -5,   73,    0,  6,  0,  0 }, {     -6,   74,    0,  6,  0,  0 },
        {     -6,   75,    0,  6,  0,  0 }, {     -6,   76,    0,  7,  0,  0 }, {     -7,   77,    0,  7,  0,  0 }, {     -7,   78,    0,  7,  0,  0 }, {     -7,   79,    0,  7,  0,  0 },
        {     -7,   80,    0,  7,  0,  0 }, {     -8,   81,    0,  7,  0,  0 }, {     -8,   82,    0,  7,  0,  0 }, {     -8,   83,    0,  7,  0,  0 }, {     -8,   84,    0,  7,  0,  0 },
        {     -8,   85,    0,  7,  0,  0 }, {     -8,   86,    0,  7,  0,  0 }, {     -9,   87,    0,  7,  0,  0 }, {     -9,   88,    0,  8,  0,  0 }, {     -9,   89,    0,  8,  0,  0 },
        {     -9,   90,    0,  8,  0,  0 }, {     -9,   91,    0,  8,  0,  0 }, {     -9,   92,    0,  8,  0,  0 }, {     -9,   93,    0,  8,  0,  0 }, {     -9,   94,    0,  8,  0,  0 },
        {     -9,   95,    0,  8,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftSBend2, {
        {      0,    9,    0, 16,  0,  0 }, {      1,    9,    0, 16,  0,  0 }, {      2,    9,    0, 16,  0,  0 }, {      3,    9,    0, 16,  0,  0 }, {      4,    9,    0, 16,  0,  0 },
        {      5,    9,    0, 16,  0,  0 }, {      6,    9,    0, 16,  0,  0 }, {      7,    9,    0, 16,  0,  0 }, {      8,    9,    0, 16,  0,  0 }, {      9,    9,    0, 15,  0,  0 },
        {     10,   10,    0, 15,  0,  0 }, {     11,   10,    0, 15,  0,  0 }, {     12,   10,    0, 15,  0,  0 }, {     13,   10,    0, 15,  0,  0 }, {     14,   10,    0, 15,  0,  0 },
        {     15,   10,    0, 15,  0,  0 }, {     16,   10,    0, 15,  0,  0 }, {     17,   11,    0, 15,  0,  0 }, {     18,   11,    0, 15,  0,  0 }, {     19,   11,    0, 15,  0,  0 },
        {     20,   11,    0, 15,  0,  0 }, {     21,   12,    0, 15,  0,  0 }, {     22,   12,    0, 15,  0,  0 }, {     23,   12,    0, 15,  0,  0 }, {     24,   12,    0, 15,  0,  0 },
        {     25,   13,    0, 14,  0,  0 }, {     26,   13,    0, 14,  0,  0 }, {     27,   13,    0, 14,  0,  0 }, {     28,   14,    0, 14,  0,  0 }, {     29,   14,    0, 14,  0,  0 },
        {     30,   15,    0, 14,  0,  0 }, {     31,   15,    0, 14,  0,  0 }, {     32,   15,    0, 14,  0,  0 }, {     33,   16,    0, 14,  0,  0 }, {     34,   16,    0, 14,  0,  0 },
        {     35,   17,    0, 14,  0,  0 }, {     36,   17,    0, 14,  0,  0 }, {     37,   18,    0, 14,  0,  0 }, {     38,   18,    0, 14,  0,  0 }, {     39,   19,    0, 14,  0,  0 },
        {     40,   19,    0, 13,  0,  0 }, {     41,   20,    0, 13,  0,  0 }, {     42,   20,    0, 13,  0,  0 }, {     43,   21,    0, 13,  0,  0 }, {     44,   21,    0, 13,  0,  0 },
        {     45,   22,    0, 13,  0,  0 }, {     46,   23,    0, 13,  0,  0 }, {     47,   23,    0, 13,  0,  0 }, {     48,   24,    0, 13,  0,  0 }, {     49,   25,    0, 13,  0,  0 },
        {     50,   25,    0, 13,  0,  0 }, {     51,   26,    0, 13,  0,  0 }, {     52,   27,    0, 13,  0,  0 }, {     53,   27,    0, 13,  0,  0 }, {     54,   28,    0, 13,  0,  0 },
        {     55,   29,    0, 13,  0,  0 }, {     56,   29,    0, 13,  0,  0 }, {     57,   30,    0, 13,  0,  0 }, {     58,   31,    0, 13,  0,  0 }, {     59,   31,    0, 13,  0,  0 },
        {     60,   32,    0, 13,  0,  0 }, {     61,   32,    0, 13,  0,  0 }, {     62,   33,    0, 14,  0,  0 }, {     63,   33,    0, 14,  0,  0 }, {     64,   34,    0, 14,  0,  0 },
        {     65,   34,    0, 14,  0,  0 }, {     66,   35,    0, 14,  0,  0 }, {     67,   35,    0, 14,  0,  0 }, {     68,   36,    0, 14,  0,  0 }, {     69,   36,    0, 14,  0,  0 },
        {     70,   36,    0, 14,  0,  0 }, {     71,   37,    0, 14,  0,  0 }, {     72,   37,    0, 14,  0,  0 }, {     73,   37,    0, 14,  0,  0 }, {     74,   38,    0, 14,  0,  0 },
        {     75,   38,    0, 14,  0,  0 }, {     76,   38,    0, 15,  0,  0 }, {     77,   39,    0, 15,  0,  0 }, {     78,   39,    0, 15,  0,  0 }, {     79,   39,    0, 15,  0,  0 },
        {     80,   39,    0, 15,  0,  0 }, {     81,   40,    0, 15,  0,  0 }, {     82,   40,    0, 15,  0,  0 }, {     83,   40,    0, 15,  0,  0 }, {     84,   40,    0, 15,  0,  0 },
        {     85,   40,    0, 15,  0,  0 }, {     86,   40,    0, 15,  0,  0 }, {     87,   41,    0, 15,  0,  0 }, {     88,   41,    0, 16,  0,  0 }, {     89,   41,    0, 16,  0,  0 },
        {     90,   41,    0, 16,  0,  0 }, {     91,   41,    0, 16,  0,  0 }, {     92,   41,    0, 16,  0,  0 }, {     93,   41,    0, 16,  0,  0 }, {     94,   41,    0, 16,  0,  0 },
        {     95,   41,    0, 16,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftSBend3, {
        {      9,   32,    0, 24,  0,  0 }, {      9,   31,    0, 24,  0,  0 }, {      9,   30,    0, 24,  0,  0 }, {      9,   29,    0, 24,  0,  0 }, {      9,   28,    0, 24,  0,  0 },
        {      9,   27,    0, 24,  0,  0 }, {      9,   26,    0, 24,  0,  0 }, {      9,   25,    0, 24,  0,  0 }, {      9,   24,    0, 24,  0,  0 }, {      9,   23,    0, 23,  0,  0 },
        {     10,   22,    0, 23,  0,  0 }, {     10,   21,    0, 23,  0,  0 }, {     10,   20,    0, 23,  0,  0 }, {     10,   19,    0, 23,  0,  0 }, {     10,   18,    0, 23,  0,  0 },
        {     10,   17,    0, 23,  0,  0 }, {     10,   16,    0, 23,  0,  0 }, {     11,   15,    0, 23,  0,  0 }, {     11,   14,    0, 23,  0,  0 }, {     11,   13,    0, 23,  0,  0 },
        {     11,   12,    0, 23,  0,  0 }, {     12,   11,    0, 23,  0,  0 }, {     12,   10,    0, 23,  0,  0 }, {     12,    9,    0, 23,  0,  0 }, {     12,    8,    0, 23,  0,  0 },
        {     13,    7,    0, 22,  0,  0 }, {     13,    6,    0, 22,  0,  0 }, {     13,    5,    0, 22,  0,  0 }, {     14,    4,    0, 22,  0,  0 }, {     14,    3,    0, 22,  0,  0 },
        {     15,    2,    0, 22,  0,  0 }, {     15,    1,    0, 22,  0,  0 }, {     15,    0,    0, 22,  0,  0 }, {     16,   -1,    0, 22,  0,  0 }, {     16,   -2,    0, 22,  0,  0 },
        {     17,   -3,    0, 22,  0,  0 }, {     17,   -4,    0, 22,  0,  0 }, {     18,   -5,    0, 22,  0,  0 }, {     18,   -6,    0, 22,  0,  0 }, {     19,   -7,    0, 22,  0,  0 },
        {     19,   -8,    0, 21,  0,  0 }, {     20,   -9,    0, 21,  0,  0 }, {     20,  -10,    0, 21,  0,  0 }, {     21,  -11,    0, 21,  0,  0 }, {     21,  -12,    0, 21,  0,  0 },
        {     22,  -13,    0, 21,  0,  0 }, {     23,  -14,    0, 21,  0,  0 }, {     23,  -15,    0, 21,  0,  0 }, {     24,  -16,    0, 21,  0,  0 }, {     25,  -17,    0, 21,  0,  0 },
        {     25,  -18,    0, 21,  0,  0 }, {     26,  -19,    0, 21,  0,  0 }, {     27,  -20,    0, 21,  0,  0 }, {     27,  -21,    0, 21,  0,  0 }, {     28,  -22,    0, 21,  0,  0 },
        {     29,  -23,    0, 21,  0,  0 }, {     29,  -24,    0, 21,  0,  0 }, {     30,  -25,    0, 21,  0,  0 }, {     31,  -26,    0, 21,  0,  0 }, {     31,  -27,    0, 21,  0,  0 },
        {     32,  -28,    0, 21,  0,  0 }, {     32,  -29,    0, 21,  0,  0 }, {     33,  -30,    0, 22,  0,  0 }, {     33,  -31,    0, 22,  0,  0 }, {     34,  -32,    0, 22,  0,  0 },
        {     34,  -33,    0, 22,  0,  0 }, {     35,  -34,    0, 22,  0,  0 }, {     35,  -35,    0, 22,  0,  0 }, {     36,  -36,    0, 22,  0,  0 }, {     36,  -37,    0, 22,  0,  0 },
        {     36,  -38,    0, 22,  0,  0 }, {     37,  -39,    0, 22,  0,  0 }, {     37,  -40,    0, 22,  0,  0 }, {     37,  -41,    0, 22,  0,  0 }, {     38,  -42,    0, 22,  0,  0 },
        {     38,  -43,    0, 22,  0,  0 }, {     38,  -44,    0, 23,  0,  0 }, {     39,  -45,    0, 23,  0,  0 }, {     39,  -46,    0, 23,  0,  0 }, {     39,  -47,    0, 23,  0,  0 },
        {     39,  -48,    0, 23,  0,  0 }, {     40,  -49,    0, 23,  0,  0 }, {     40,  -50,    0, 23,  0,  0 }, {     40,  -51,    0, 23,  0,  0 }, {     40,  -52,    0, 23,  0,  0 },
        {     40,  -53,    0, 23,  0,  0 }, {     40,  -54,    0, 23,  0,  0 }, {     41,  -55,    0, 23,  0,  0 }, {     41,  -56,    0, 24,  0,  0 }, {     41,  -57,    0, 24,  0,  0 },
        {     41,  -58,    0, 24,  0,  0 }, {     41,  -59,    0, 24,  0,  0 }, {     41,  -60,    0, 24,  0,  0 }, {     41,  -61,    0, 24,  0,  0 }, {     41,  -62,    0, 24,  0,  0 },
        {     41,  -63,    0, 24,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightSBend0, {
        {     32,   23,    0,  0,  0,  0 }, {     31,   23,    0,  0,  0,  0 }, {     30,   23,    0,  0,  0,  0 }, {     29,   23,    0,  0,  0,  0 }, {     28,   23,    0,  0,  0,  0 },
        {     27,   23,    0,  0,  0,  0 }, {     26,   23,    0,  0,  0,  0 }, {     25,   23,    0,  0,  0,  0 }, {     24,   23,    0,  1,  0,  0 }, {     23,   24,    0,  1,  0,  0 },
        {     22,   24,    0,  1,  0,  0 }, {     21,   24,    0,  1,  0,  0 }, {     20,   24,    0,  1,  0,  0 }, {     19,   24,    0,  1,  0,  0 }, {     18,   24,    0,  1,  0,  0 },
        {     17,   25,    0,  1,  0,  0 }, {     16,   25,    0,  1,  0,  0 }, {     15,   25,    0,  1,  0,  0 }, {     14,   25,    0,  1,  0,  0 }, {     13,   26,    0,  1,  0,  0 },
        {     12,   26,    0,  2,  0,  0 }, {     11,   26,    0,  2,  0,  0 }, {     10,   27,    0,  2,  0,  0 }, {      9,   27,    0,  2,  0,  0 }, {      8,   27,    0,  2,  0,  0 },
        {      7,   28,    0,  2,  0,  0 }, {      6,   28,    0,  2,  0,  0 }, {      5,   28,    0,  2,  0,  0 }, {      4,   29,    0,  2,  0,  0 }, {      3,   29,    0,  2,  0,  0 },
        {      2,   30,    0,  2,  0,  0 }, {      1,   30,    0,  2,  0,  0 }, {      0,   31,    0,  2,  0,  0 }, {     -1,   31,    0,  2,  0,  0 }, {     -2,   32,    0,  3,  0,  0 },
        {     -3,   32,    0,  3,  0,  0 }, {     -4,   33,    0,  3,  0,  0 }, {     -5,   33,    0,  3,  0,  0 }, {     -6,   34,    0,  3,  0,  0 }, {     -7,   35,    0,  3,  0,  0 },
        {     -8,   35,    0,  3,  0,  0 }, {     -9,   36,    0,  3,  0,  0 }, {    -10,   37,    0,  3,  0,  0 }, {    -11,   37,    0,  3,  0,  0 }, {    -12,   38,    0,  3,  0,  0 },
        {    -13,   39,    0,  3,  0,  0 }, {    -14,   39,    0,  3,  0,  0 }, {    -15,   40,    0,  3,  0,  0 }, {    -16,   41,    0,  3,  0,  0 }, {    -17,   41,    0,  3,  0,  0 },
        {    -18,   42,    0,  3,  0,  0 }, {    -19,   43,    0,  3,  0,  0 }, {    -20,   43,    0,  3,  0,  0 }, {    -21,   44,    0,  3,  0,  0 }, {    -22,   44,    0,  3,  0,  0 },
        {    -23,   45,    0,  2,  0,  0 }, {    -24,   45,    0,  2,  0,  0 }, {    -25,   46,    0,  2,  0,  0 }, {    -26,   46,    0,  2,  0,  0 }, {    -27,   47,    0,  2,  0,  0 },
        {    -28,   47,    0,  2,  0,  0 }, {    -29,   48,    0,  2,  0,  0 }, {    -30,   48,    0,  2,  0,  0 }, {    -31,   49,    0,  2,  0,  0 }, {    -32,   49,    0,  2,  0,  0 },
        {    -33,   49,    0,  2,  0,  0 }, {    -34,   50,    0,  2,  0,  0 }, {    -35,   50,    0,  2,  0,  0 }, {    -36,   51,    0,  2,  0,  0 }, {    -37,   51,    0,  2,  0,  0 },
        {    -38,   51,    0,  2,  0,  0 }, {    -39,   52,    0,  1,  0,  0 }, {    -40,   52,    0,  1,  0,  0 }, {    -41,   52,    0,  1,  0,  0 }, {    -42,   52,    0,  1,  0,  0 },
        {    -43,   53,    0,  1,  0,  0 }, {    -44,   53,    0,  1,  0,  0 }, {    -45,   53,    0,  1,  0,  0 }, {    -46,   53,    0,  1,  0,  0 }, {    -47,   54,    0,  1,  0,  0 },
        {    -48,   54,    0,  1,  0,  0 }, {    -49,   54,    0,  1,  0,  0 }, {    -50,   54,    0,  1,  0,  0 }, {    -51,   54,    0,  1,  0,  0 }, {    -52,   54,    0,  1,  0,  0 },
        {    -53,   54,    0,  1,  0,  0 }, {    -54,   55,    0,  1,  0,  0 }, {    -55,   55,    0,  0,  0,  0 }, {    -56,   55,    0,  0,  0,  0 }, {    -57,   55,    0,  0,  0,  0 },
        {    -58,   55,    0,  0,  0,  0 }, {    -59,   55,    0,  0,  0,  0 }, {    -60,   55,    0,  0,  0,  0 }, {    -61,   55,    0,  0,  0,  0 }, {    -62,   55,    0,  0,  0,  0 },
        {    -63,   55,    0,  0,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightSBend1, {
        {     23,    0,    0,  8,  0,  0 }, {     23,    1,    0,  8,  0,  0 }, {     23,    2,    0,  8,  0,  0 }, {     23,    3,    0,  8,  0,  0 }, {     23,    4,    0,  8,  0,  0 },
        {     23,    5,    0,  8,  0,  0 }, {     23,    6,    0,  8,  0,  0 }, {     23,    7,    0,  8,  0,  0 }, {     23,    8,    0,  9,  0,  0 }, {     24,    9,    0,  9,  0,  0 },
        {     24,   10,    0,  9,  0,  0 }, {     24,   11,    0,  9,  0,  0 }, {     24,   12,    0,  9,  0,  0 }, {     24,   13,    0,  9,  0,  0 }, {     24,   14,    0,  9,  0,  0 },
        {     25,   15,    0,  9,  0,  0 }, {     25,   16,    0,  9,  0,  0 }, {     25,   17,    0,  9,  0,  0 }, {     25,   18,    0,  9,  0,  0 }, {     26,   19,    0,  9,  0,  0 },
        {     26,   20,    0, 10,  0,  0 }, {     26,   21,    0, 10,  0,  0 }, {     27,   22,    0, 10,  0,  0 }, {     27,   23,    0, 10,  0,  0 }, {     27,   24,    0, 10,  0,  0 },
        {     28,   25,    0, 10,  0,  0 }, {     28,   26,    0, 10,  0,  0 }, {     28,   27,    0, 10,  0,  0 }, {     29,   28,    0, 10,  0,  0 }, {     29,   29,    0, 10,  0,  0 },
        {     30,   30,    0, 10,  0,  0 }, {     30,   31,    0, 10,  0,  0 }, {     31,   32,    0, 10,  0,  0 }, {     31,   33,    0, 10,  0,  0 }, {     32,   34,    0, 11,  0,  0 },
        {     32,   35,    0, 11,  0,  0 }, {     33,   36,    0, 11,  0,  0 }, {     33,   37,    0, 11,  0,  0 }, {     34,   38,    0, 11,  0,  0 }, {     35,   39,    0, 11,  0,  0 },
        {     35,   40,    0, 11,  0,  0 }, {     36,   41,    0, 11,  0,  0 }, {     37,   42,    0, 11,  0,  0 }, {     37,   43,    0, 11,  0,  0 }, {     38,   44,    0, 11,  0,  0 },
        {     39,   45,    0, 11,  0,  0 }, {     39,   46,    0, 11,  0,  0 }, {     40,   47,    0, 11,  0,  0 }, {     41,   48,    0, 11,  0,  0 }, {     41,   49,    0, 11,  0,  0 },
        {     42,   50,    0, 11,  0,  0 }, {     43,   51,    0, 11,  0,  0 }, {     43,   52,    0, 11,  0,  0 }, {     44,   53,    0, 11,  0,  0 }, {     44,   54,    0, 11,  0,  0 },
        {     45,   55,    0, 10,  0,  0 }, {     45,   56,    0, 10,  0,  0 }, {     46,   57,    0, 10,  0,  0 }, {     46,   58,    0, 10,  0,  0 }, {     47,   59,    0, 10,  0,  0 },
        {     47,   60,    0, 10,  0,  0 }, {     48,   61,    0, 10,  0,  0 }, {     48,   62,    0, 10,  0,  0 }, {     49,   63,    0, 10,  0,  0 }, {     49,   64,    0, 10,  0,  0 },
        {     49,   65,    0, 10,  0,  0 }, {     50,   66,    0, 10,  0,  0 }, {     50,   67,    0, 10,  0,  0 }, {     51,   68,    0, 10,  0,  0 }, {     51,   69,    0, 10,  0,  0 },
        {     51,   70,    0, 10,  0,  0 }, {     52,   71,    0,  9,  0,  0 }, {     52,   72,    0,  9,  0,  0 }, {     52,   73,    0,  9,  0,  0 }, {     52,   74,    0,  9,  0,  0 },
        {     53,   75,    0,  9,  0,  0 }, {     53,   76,    0,  9,  0,  0 }, {     53,   77,    0,  9,  0,  0 }, {     53,   78,    0,  9,  0,  0 }, {     54,   79,    0,  9,  0,  0 },
        {     54,   80,    0,  9,  0,  0 }, {     54,   81,    0,  9,  0,  0 }, {     54,   82,    0,  9,  0,  0 }, {     54,   83,    0,  9,  0,  0 }, {     54,   84,    0,  9,  0,  0 },
        {     54,   85,    0,  9,  0,  0 }, {     55,   86,    0,  9,  0,  0 }, {     55,   87,    0,  8,  0,  0 }, {     55,   88,    0,  8,  0,  0 }, {     55,   89,    0,  8,  0,  0 },
        {     55,   90,    0,  8,  0,  0 }, {     55,   91,    0,  8,  0,  0 }, {     55,   92,    0,  8,  0,  0 }, {     55,   93,    0,  8,  0,  0 }, {     55,   94,    0,  8,  0,  0 },
        {     55,   95,    0,  8,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightSBend2, {
        {      0,    9,    0, 16,  0,  0 }, {      1,    9,    0, 16,  0,  0 }, {      2,    9,    0, 16,  0,  0 }, {      3,    9,    0, 16,  0,  0 }, {      4,    9,    0, 16,  0,  0 },
        {      5,    9,    0, 16,  0,  0 }, {      6,    9,    0, 16,  0,  0 }, {      7,    9,    0, 16,  0,  0 }, {      8,    9,    0, 17,  0,  0 }, {      9,    8,    0, 17,  0,  0 },
        {     10,    8,    0, 17,  0,  0 }, {     11,    8,    0, 17,  0,  0 }, {     12,    8,    0, 17,  0,  0 }, {     13,    8,    0, 17,  0,  0 }, {     14,    8,    0, 17,  0,  0 },
        {     15,    7,    0, 17,  0,  0 }, {     16,    7,    0, 17,  0,  0 }, {     17,    7,    0, 17,  0,  0 }, {     18,    7,    0, 17,  0,  0 }, {     19,    6,    0, 17,  0,  0 },
        {     20,    6,    0, 18,  0,  0 }, {     21,    6,    0, 18,  0,  0 }, {     22,    5,    0, 18,  0,  0 }, {     23,    5,    0, 18,  0,  0 }, {     24,    5,    0, 18,  0,  0 },
        {     25,    4,    0, 18,  0,  0 }, {     26,    4,    0, 18,  0,  0 }, {     27,    4,    0, 18,  0,  0 }, {     28,    3,    0, 18,  0,  0 }, {     29,    3,    0, 18,  0,  0 },
        {     30,    2,    0, 18,  0,  0 }, {     31,    2,    0, 18,  0,  0 }, {     32,    1,    0, 18,  0,  0 }, {     33,    1,    0, 18,  0,  0 }, {     34,    0,    0, 19,  0,  0 },
        {     35,    0,    0, 19,  0,  0 }, {     36,   -1,    0, 19,  0,  0 }, {     37,   -1,    0, 19,  0,  0 }, {     38,   -2,    0, 19,  0,  0 }, {     39,   -3,    0, 19,  0,  0 },
        {     40,   -3,    0, 19,  0,  0 }, {     41,   -4,    0, 19,  0,  0 }, {     42,   -5,    0, 19,  0,  0 }, {     43,   -5,    0, 19,  0,  0 }, {     44,   -6,    0, 19,  0,  0 },
        {     45,   -7,    0, 19,  0,  0 }, {     46,   -7,    0, 19,  0,  0 }, {     47,   -8,    0, 19,  0,  0 }, {     48,   -9,    0, 19,  0,  0 }, {     49,   -9,    0, 19,  0,  0 },
        {     50,  -10,    0, 19,  0,  0 }, {     51,  -11,    0, 19,  0,  0 }, {     52,  -11,    0, 19,  0,  0 }, {     53,  -12,    0, 19,  0,  0 }, {     54,  -12,    0, 19,  0,  0 },
        {     55,  -13,    0, 18,  0,  0 }, {     56,  -13,    0, 18,  0,  0 }, {     57,  -14,    0, 18,  0,  0 }, {     58,  -14,    0, 18,  0,  0 }, {     59,  -15,    0, 18,  0,  0 },
        {     60,  -15,    0, 18,  0,  0 }, {     61,  -16,    0, 18,  0,  0 }, {     62,  -16,    0, 18,  0,  0 }, {     63,  -17,    0, 18,  0,  0 }, {     64,  -17,    0, 18,  0,  0 },
        {     65,  -17,    0, 18,  0,  0 }, {     66,  -18,    0, 18,  0,  0 }, {     67,  -18,    0, 18,  0,  0 }, {     68,  -19,    0, 18,  0,  0 }, {     69,  -19,    0, 18,  0,  0 },
        {     70,  -19,    0, 18,  0,  0 }, {     71,  -20,    0, 17,  0,  0 }, {     72,  -20,    0, 17,  0,  0 }, {     73,  -20,    0, 17,  0,  0 }, {     74,  -20,    0, 17,  0,  0 },
        {     75,  -21,    0, 17,  0,  0 }, {     76,  -21,    0, 17,  0,  0 }, {     77,  -21,    0, 17,  0,  0 }, {     78,  -21,    0, 17,  0,  0 }, {     79,  -22,    0, 17,  0,  0 },
        {     80,  -22,    0, 17,  0,  0 }, {     81,  -22,    0, 17,  0,  0 }, {     82,  -22,    0, 17,  0,  0 }, {     83,  -22,    0, 17,  0,  0 }, {     84,  -22,    0, 17,  0,  0 },
        {     85,  -22,    0, 17,  0,  0 }, {     86,  -23,    0, 17,  0,  0 }, {     87,  -23,    0, 16,  0,  0 }, {     88,  -23,    0, 16,  0,  0 }, {     89,  -23,    0, 16,  0,  0 },
        {     90,  -23,    0, 16,  0,  0 }, {     91,  -23,    0, 16,  0,  0 }, {     92,  -23,    0, 16,  0,  0 }, {     93,  -23,    0, 16,  0,  0 }, {     94,  -23,    0, 16,  0,  0 },
        {     95,  -23,    0, 16,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightSBend3, {
        {      9,   32,    0, 24,  0,  0 }, {      9,   31,    0, 24,  0,  0 }, {      9,   30,    0, 24,  0,  0 }, {      9,   29,    0, 24,  0,  0 }, {      9,   28,    0, 24,  0,  0 },
        {      9,   27,    0, 24,  0,  0 }, {      9,   26,    0, 24,  0,  0 }, {      9,   25,    0, 24,  0,  0 }, {      9,   24,    0, 25,  0,  0 }, {      8,   23,    0, 25,  0,  0 },
        {      8,   22,    0, 25,  0,  0 }, {      8,   21,    0, 25,  0,  0 }, {      8,   20,    0, 25,  0,  0 }, {      8,   19,    0, 25,  0,  0 }, {      8,   18,    0, 25,  0,  0 },
        {      7,   17,    0, 25,  0,  0 }, {      7,   16,    0, 25,  0,  0 }, {      7,   15,    0, 25,  0,  0 }, {      7,   14,    0, 25,  0,  0 }, {      6,   13,    0, 25,  0,  0 },
        {      6,   12,    0, 26,  0,  0 }, {      6,   11,    0, 26,  0,  0 }, {      5,   10,    0, 26,  0,  0 }, {      5,    9,    0, 26,  0,  0 }, {      5,    8,    0, 26,  0,  0 },
        {      4,    7,    0, 26,  0,  0 }, {      4,    6,    0, 26,  0,  0 }, {      4,    5,    0, 26,  0,  0 }, {      3,    4,    0, 26,  0,  0 }, {      3,    3,    0, 26,  0,  0 },
        {      2,    2,    0, 26,  0,  0 }, {      2,    1,    0, 26,  0,  0 }, {      1,    0,    0, 26,  0,  0 }, {      1,   -1,    0, 26,  0,  0 }, {      0,   -2,    0, 27,  0,  0 },
        {      0,   -3,    0, 27,  0,  0 }, {     -1,   -4,    0, 27,  0,  0 }, {     -1,   -5,    0, 27,  0,  0 }, {     -2,   -6,    0, 27,  0,  0 }, {     -3,   -7,    0, 27,  0,  0 },
        {     -3,   -8,    0, 27,  0,  0 }, {     -4,   -9,    0, 27,  0,  0 }, {     -5,  -10,    0, 27,  0,  0 }, {     -5,  -11,    0, 27,  0,  0 }, {     -6,  -12,    0, 27,  0,  0 },
        {     -7,  -13,    0, 27,  0,  0 }, {     -7,  -14,    0, 27,  0,  0 }, {     -8,  -15,    0, 27,  0,  0 }, {     -9,  -16,    0, 27,  0,  0 }, {     -9,  -17,    0, 27,  0,  0 },
        {    -10,  -18,    0, 27,  0,  0 }, {    -11,  -19,    0, 27,  0,  0 }, {    -11,  -20,    0, 27,  0,  0 }, {    -12,  -21,    0, 27,  0,  0 }, {    -12,  -22,    0, 27,  0,  0 },
        {    -13,  -23,    0, 26,  0,  0 }, {    -13,  -24,    0, 26,  0,  0 }, {    -14,  -25,    0, 26,  0,  0 }, {    -14,  -26,    0, 26,  0,  0 }, {    -15,  -27,    0, 26,  0,  0 },
        {    -15,  -28,    0, 26,  0,  0 }, {    -16,  -29,    0, 26,  0,  0 }, {    -16,  -30,    0, 26,  0,  0 }, {    -17,  -31,    0, 26,  0,  0 }, {    -17,  -32,    0, 26,  0,  0 },
        {    -17,  -33,    0, 26,  0,  0 }, {    -18,  -34,    0, 26,  0,  0 }, {    -18,  -35,    0, 26,  0,  0 }, {    -19,  -36,    0, 26,  0,  0 }, {    -19,  -37,    0, 26,  0,  0 },
        {    -19,  -38,    0, 26,  0,  0 }, {    -20,  -39,    0, 25,  0,  0 }, {    -20,  -40,    0, 25,  0,  0 }, {    -20,  -41,    0, 25,  0,  0 }, {    -20,  -42,    0, 25,  0,  0 },
        {    -21,  -43,    0, 25,  0,  0 }, {    -21,  -44,    0, 25,  0,  0 }, {    -21,  -45,    0, 25,  0,  0 }, {    -21,  -46,    0, 25,  0,  0 }, {    -22,  -47,    0, 25,  0,  0 },
        {    -22,  -48,    0, 25,  0,  0 }, {    -22,  -49,    0, 25,  0,  0 }, {    -22,  -50,    0, 25,  0,  0 }, {    -22,  -51,    0, 25,  0,  0 }, {    -22,  -52,    0, 25,  0,  0 },
        {    -22,  -53,    0, 25,  0,  0 }, {    -23,  -54,    0, 25,  0,  0 }, {    -23,  -55,    0, 24,  0,  0 }, {    -23,  -56,    0, 24,  0,  0 }, {    -23,  -57,    0, 24,  0,  0 },
        {    -23,  -58,    0, 24,  0,  0 }, {    -23,  -59,    0, 24,  0,  0 }, {    -23,  -60,    0, 24,  0,  0 }, {    -23,  -61,    0, 24,  0,  0 }, {    -23,  -62,    0, 24,  0,  0 },
        {    -23,  -63,    0, 24,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles0, {
        {     31,   23,    0,  0,  0,  0 }, {     30,   23,    0, 31,  0,  0 }, {     29,   23,    0, 31,  0,  0 }, {     28,   23,    0, 31,  0,  0 }, {     27,   23,    0, 31,  0,  0 },
        {     26,   23,    0, 31,  0,  0 }, {     25,   23,    0, 31,  0,  0 }, {     24,   23,    0, 31,  0,  0 }, {     23,   23,    0, 31,  0,  0 }, {     22,   23,    0, 31,  0,  0 },
        {     21,   23,    0, 31,  0,  0 }, {     20,   22,    0, 30,  0,  0 }, {     19,   22,    0, 30,  0,  0 }, {     18,   22,    0, 30,  0,  0 }, {     17,   22,    0, 30,  0,  0 },
        {     16,   21,    0, 30,  0,  0 }, {     15,   21,    0, 30,  0,  0 }, {     14,   21,    0, 30,  0,  0 }, {     13,   20,    0, 30,  0,  0 }, {     12,   20,    0, 30,  0,  0 },
        {     11,   20,    0, 30,  0,  0 }, {     10,   19,    0, 29,  0,  0 }, {      9,   19,    0, 29,  0,  0 }, {      8,   18,    0, 29,  0,  0 }, {      7,   18,    0, 29,  0,  0 },
        {      6,   17,    0, 29,  0,  0 }, {      5,   17,    0, 29,  0,  0 }, {      4,   16,    0, 29,  0,  0 }, {      3,   16,    0, 29,  0,  0 }, {      2,   15,    0, 29,  0,  0 },
        {      1,   15,    0, 29,  0,  0 }, {      0,   14,    0, 28,  0,  0 }, {     -1,   13,    0, 28,  0,  0 }, {     -2,   12,    0, 28,  0,  0 }, {     -3,   12,    0, 28,  0,  0 },
        {     -4,   11,    0, 28,  0,  0 }, {     -5,   10,    0, 28,  0,  0 }, {     -6,    9,    0, 28,  0,  0 }, {     -7,    8,    0, 28,  0,  0 }, {     -8,    7,    0, 27,  0,  0 },
        {     -9,    6,    0, 27,  0,  0 }, {    -10,    5,    0, 27,  0,  0 }, {    -11,    4,    0, 27,  0,  0 }, {    -12,    3,    0, 27,  0,  0 }, {    -12,    2,    0, 27,  0,  0 },
        {    -13,    1,    0, 27,  0,  0 }, {    -14,    0,    0, 27,  0,  0 }, {    -15,   -1,    0, 26,  0,  0 }, {    -15,   -2,    0, 26,  0,  0 }, {    -16,   -3,    0, 26,  0,  0 },
        {    -16,   -4,    0, 26,  0,  0 }, {    -17,   -5,    0, 26,  0,  0 }, {    -17,   -6,    0, 26,  0,  0 }, {    -18,   -7,    0, 26,  0,  0 }, {    -18,   -8,    0, 26,  0,  0 },
        {    -19,   -9,    0, 26,  0,  0 }, {    -19,  -10,    0, 26,  0,  0 }, {    -20,  -11,    0, 25,  0,  0 }, {    -20,  -12,    0, 25,  0,  0 }, {    -20,  -13,    0, 25,  0,  0 },
        {    -21,  -14,    0, 25,  0,  0 }, {    -21,  -15,    0, 25,  0,  0 }, {    -21,  -16,    0, 25,  0,  0 }, {    -22,  -17,    0, 25,  0,  0 }, {    -22,  -18,    0, 25,  0,  0 },
        {    -22,  -19,    0, 25,  0,  0 }, {    -22,  -20,    0, 25,  0,  0 }, {    -23,  -21,    0, 24,  0,  0 }, {    -23,  -22,    0, 24,  0,  0 }, {    -23,  -23,    0, 24,  0,  0 },
        {    -23,  -24,    0, 24,  0,  0 }, {    -23,  -25,    0, 24,  0,  0 }, {    -23,  -26,    0, 24,  0,  0 }, {    -23,  -27,    0, 24,  0,  0 }, {    -23,  -28,    0, 24,  0,  0 },
        {    -23,  -29,    0, 24,  0,  0 }, {    -23,  -30,    0, 24,  0,  0 }, {    -23,  -31,    0, 24,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles1, {
        {     23,    1,    0,  8,  0,  0 }, {     23,    2,    0,  7,  0,  0 }, {     23,    3,    0,  7,  0,  0 }, {     23,    4,    0,  7,  0,  0 }, {     23,    5,    0,  7,  0,  0 },
        {     23,    6,    0,  7,  0,  0 }, {     23,    7,    0,  7,  0,  0 }, {     23,    8,    0,  7,  0,  0 }, {     23,    9,    0,  7,  0,  0 }, {     23,   10,    0,  7,  0,  0 },
        {     23,   11,    0,  7,  0,  0 }, {     22,   12,    0,  6,  0,  0 }, {     22,   13,    0,  6,  0,  0 }, {     22,   14,    0,  6,  0,  0 }, {     22,   15,    0,  6,  0,  0 },
        {     21,   16,    0,  6,  0,  0 }, {     21,   17,    0,  6,  0,  0 }, {     21,   18,    0,  6,  0,  0 }, {     20,   19,    0,  6,  0,  0 }, {     20,   20,    0,  6,  0,  0 },
        {     20,   21,    0,  6,  0,  0 }, {     19,   22,    0,  5,  0,  0 }, {     19,   23,    0,  5,  0,  0 }, {     18,   24,    0,  5,  0,  0 }, {     18,   25,    0,  5,  0,  0 },
        {     17,   26,    0,  5,  0,  0 }, {     17,   27,    0,  5,  0,  0 }, {     16,   28,    0,  5,  0,  0 }, {     16,   29,    0,  5,  0,  0 }, {     15,   30,    0,  5,  0,  0 },
        {     15,   31,    0,  5,  0,  0 }, {     14,   32,    0,  4,  0,  0 }, {     13,   33,    0,  4,  0,  0 }, {     12,   34,    0,  4,  0,  0 }, {     12,   35,    0,  4,  0,  0 },
        {     11,   36,    0,  4,  0,  0 }, {     10,   37,    0,  4,  0,  0 }, {      9,   38,    0,  4,  0,  0 }, {      8,   39,    0,  4,  0,  0 }, {      7,   40,    0,  3,  0,  0 },
        {      6,   41,    0,  3,  0,  0 }, {      5,   42,    0,  3,  0,  0 }, {      4,   43,    0,  3,  0,  0 }, {      3,   44,    0,  3,  0,  0 }, {      2,   44,    0,  3,  0,  0 },
        {      1,   45,    0,  3,  0,  0 }, {      0,   46,    0,  3,  0,  0 }, {     -1,   47,    0,  2,  0,  0 }, {     -2,   47,    0,  2,  0,  0 }, {     -3,   48,    0,  2,  0,  0 },
        {     -4,   48,    0,  2,  0,  0 }, {     -5,   49,    0,  2,  0,  0 }, {     -6,   49,    0,  2,  0,  0 }, {     -7,   50,    0,  2,  0,  0 }, {     -8,   50,    0,  2,  0,  0 },
        {     -9,   51,    0,  2,  0,  0 }, {    -10,   51,    0,  2,  0,  0 }, {    -11,   52,    0,  1,  0,  0 }, {    -12,   52,    0,  1,  0,  0 }, {    -13,   52,    0,  1,  0,  0 },
        {    -14,   53,    0,  1,  0,  0 }, {    -15,   53,    0,  1,  0,  0 }, {    -16,   53,    0,  1,  0,  0 }, {    -17,   54,    0,  1,  0,  0 }, {    -18,   54,    0,  1,  0,  0 },
        {    -19,   54,    0,  1,  0,  0 }, {    -20,   54,    0,  1,  0,  0 }, {    -21,   55,    0,  0,  0,  0 }, {    -22,   55,    0,  0,  0,  0 }, {    -23,   55,    0,  0,  0,  0 },
        {    -24,   55,    0,  0,  0,  0 }, {    -25,   55,    0,  0,  0,  0 }, {    -26,   55,    0,  0,  0,  0 }, {    -27,   55,    0,  0,  0,  0 }, {    -28,   55,    0,  0,  0,  0 },
        {    -29,   55,    0,  0,  0,  0 }, {    -30,   55,    0,  0,  0,  0 }, {    -31,   55,    0,  0,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles2, {
        {      1,    9,    0, 16,  0,  0 }, {      2,    9,    0, 15,  0,  0 }, {      3,    9,    0, 15,  0,  0 }, {      4,    9,    0, 15,  0,  0 }, {      5,    9,    0, 15,  0,  0 },
        {      6,    9,    0, 15,  0,  0 }, {      7,    9,    0, 15,  0,  0 }, {      8,    9,    0, 15,  0,  0 }, {      9,    9,    0, 15,  0,  0 }, {     10,    9,    0, 15,  0,  0 },
        {     11,    9,    0, 15,  0,  0 }, {     12,   10,    0, 14,  0,  0 }, {     13,   10,    0, 14,  0,  0 }, {     14,   10,    0, 14,  0,  0 }, {     15,   10,    0, 14,  0,  0 },
        {     16,   11,    0, 14,  0,  0 }, {     17,   11,    0, 14,  0,  0 }, {     18,   11,    0, 14,  0,  0 }, {     19,   12,    0, 14,  0,  0 }, {     20,   12,    0, 14,  0,  0 },
        {     21,   12,    0, 14,  0,  0 }, {     22,   13,    0, 13,  0,  0 }, {     23,   13,    0, 13,  0,  0 }, {     24,   14,    0, 13,  0,  0 }, {     25,   14,    0, 13,  0,  0 },
        {     26,   15,    0, 13,  0,  0 }, {     27,   15,    0, 13,  0,  0 }, {     28,   16,    0, 13,  0,  0 }, {     29,   16,    0, 13,  0,  0 }, {     30,   17,    0, 13,  0,  0 },
        {     31,   17,    0, 13,  0,  0 }, {     32,   18,    0, 12,  0,  0 }, {     33,   19,    0, 12,  0,  0 }, {     34,   20,    0, 12,  0,  0 }, {     35,   20,    0, 12,  0,  0 },
        {     36,   21,    0, 12,  0,  0 }, {     37,   22,    0, 12,  0,  0 }, {     38,   23,    0, 12,  0,  0 }, {     39,   24,    0, 12,  0,  0 }, {     40,   25,    0, 11,  0,  0 },
        {     41,   26,    0, 11,  0,  0 }, {     42,   27,    0, 11,  0,  0 }, {     43,   28,    0, 11,  0,  0 }, {     44,   29,    0, 11,  0,  0 }, {     44,   30,    0, 11,  0,  0 },
        {     45,   31,    0, 11,  0,  0 }, {     46,   32,    0, 11,  0,  0 }, {     47,   33,    0, 10,  0,  0 }, {     47,   34,    0, 10,  0,  0 }, {     48,   35,    0, 10,  0,  0 },
        {     48,   36,    0, 10,  0,  0 }, {     49,   37,    0, 10,  0,  0 }, {     49,   38,    0, 10,  0,  0 }, {     50,   39,    0, 10,  0,  0 }, {     50,   40,    0, 10,  0,  0 },
        {     51,   41,    0, 10,  0,  0 }, {     51,   42,    0, 10,  0,  0 }, {     52,   43,    0,  9,  0,  0 }, {     52,   44,    0,  9,  0,  0 }, {     52,   45,    0,  9,  0,  0 },
        {     53,   46,    0,  9,  0,  0 }, {     53,   47,    0,  9,  0,  0 }, {     53,   48,    0,  9,  0,  0 }, {     54,   49,    0,  9,  0,  0 }, {     54,   50,    0,  9,  0,  0 },
        {     54,   51,    0,  9,  0,  0 }, {     54,   52,    0,  9,  0,  0 }, {     55,   53,    0,  8,  0,  0 }, {     55,   54,    0,  8,  0,  0 }, {     55,   55,    0,  8,  0,  0 },
        {     55,   56,    0,  8,  0,  0 }, {     55,   57,    0,  8,  0,  0 }, {     55,   58,    0,  8,  0,  0 }, {     55,   59,    0,  8,  0,  0 }, {     55,   60,    0,  8,  0,  0 },
        {     55,   61,    0,  8,  0,  0 }, {     55,   62,    0,  8,  0,  0 }, {     55,   63,    0,  8,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles3, {
        {      9,   31,    0, 24,  0,  0 }, {      9,   30,    0, 23,  0,  0 }, {      9,   29,    0, 23,  0,  0 }, {      9,   28,    0, 23,  0,  0 }, {      9,   27,    0, 23,  0,  0 },
        {      9,   26,    0, 23,  0,  0 }, {      9,   25,    0, 23,  0,  0 }, {      9,   24,    0, 23,  0,  0 }, {      9,   23,    0, 23,  0,  0 }, {      9,   22,    0, 23,  0,  0 },
        {      9,   21,    0, 23,  0,  0 }, {     10,   20,    0, 22,  0,  0 }, {     10,   19,    0, 22,  0,  0 }, {     10,   18,    0, 22,  0,  0 }, {     10,   17,    0, 22,  0,  0 },
        {     11,   16,    0, 22,  0,  0 }, {     11,   15,    0, 22,  0,  0 }, {     11,   14,    0, 22,  0,  0 }, {     12,   13,    0, 22,  0,  0 }, {     12,   12,    0, 22,  0,  0 },
        {     12,   11,    0, 22,  0,  0 }, {     13,   10,    0, 21,  0,  0 }, {     13,    9,    0, 21,  0,  0 }, {     14,    8,    0, 21,  0,  0 }, {     14,    7,    0, 21,  0,  0 },
        {     15,    6,    0, 21,  0,  0 }, {     15,    5,    0, 21,  0,  0 }, {     16,    4,    0, 21,  0,  0 }, {     16,    3,    0, 21,  0,  0 }, {     17,    2,    0, 21,  0,  0 },
        {     17,    1,    0, 21,  0,  0 }, {     18,    0,    0, 20,  0,  0 }, {     19,   -1,    0, 20,  0,  0 }, {     20,   -2,    0, 20,  0,  0 }, {     20,   -3,    0, 20,  0,  0 },
        {     21,   -4,    0, 20,  0,  0 }, {     22,   -5,    0, 20,  0,  0 }, {     23,   -6,    0, 20,  0,  0 }, {     24,   -7,    0, 20,  0,  0 }, {     25,   -8,    0, 19,  0,  0 },
        {     26,   -9,    0, 19,  0,  0 }, {     27,  -10,    0, 19,  0,  0 }, {     28,  -11,    0, 19,  0,  0 }, {     29,  -12,    0, 19,  0,  0 }, {     30,  -12,    0, 19,  0,  0 },
        {     31,  -13,    0, 19,  0,  0 }, {     32,  -14,    0, 19,  0,  0 }, {     33,  -15,    0, 18,  0,  0 }, {     34,  -15,    0, 18,  0,  0 }, {     35,  -16,    0, 18,  0,  0 },
        {     36,  -16,    0, 18,  0,  0 }, {     37,  -17,    0, 18,  0,  0 }, {     38,  -17,    0, 18,  0,  0 }, {     39,  -18,    0, 18,  0,  0 }, {     40,  -18,    0, 18,  0,  0 },
        {     41,  -19,    0, 18,  0,  0 }, {     42,  -19,    0, 18,  0,  0 }, {     43,  -20,    0, 17,  0,  0 }, {     44,  -20,    0, 17,  0,  0 }, {     45,  -20,    0, 17,  0,  0 },
        {     46,  -21,    0, 17,  0,  0 }, {     47,  -21,    0, 17,  0,  0 }, {     48,  -21,    0, 17,  0,  0 }, {     49,  -22,    0, 17,  0,  0 }, {     50,  -22,    0, 17,  0,  0 },
        {     51,  -22,    0, 17,  0,  0 }, {     52,  -22,    0, 17,  0,  0 }, {     53,  -23,    0, 16,  0,  0 }, {     54,  -23,    0, 16,  0,  0 }, {     55,  -23,    0, 16,  0,  0 },
        {     56,  -23,    0, 16,  0,  0 }, {     57,  -23,    0, 16,  0,  0 }, {     58,  -23,    0, 16,  0,  0 }, {     59,  -23,    0, 16,  0,  0 }, {     60,  -23,    0, 16,  0,  0 },
        {     61,  -23,    0, 16,  0,  0 }, {     62,  -23,    0, 16,  0,  0 }, {     63,  -23,    0, 16,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles0, {
        {     31,   23,    0,  0,  0,  0 }, {     30,   23,    0,  1,  0,  0 }, {     29,   23,    0,  1,  0,  0 }, {     28,   23,    0,  1,  0,  0 }, {     27,   23,    0,  1,  0,  0 },
        {     26,   23,    0,  1,  0,  0 }, {     25,   23,    0,  1,  0,  0 }, {     24,   23,    0,  1,  0,  0 }, {     23,   23,    0,  2,  0,  0 }, {     22,   24,    0,  2,  0,  0 },
        {     21,   24,    0,  2,  0,  0 }, {     20,   24,    0,  2,  0,  0 }, {     19,   24,    0,  2,  0,  0 }, {     18,   25,    0,  2,  0,  0 }, {     17,   25,    0,  2,  0,  0 },
        {     16,   25,    0,  2,  0,  0 }, {     15,   26,    0,  3,  0,  0 }, {     14,   26,    0,  3,  0,  0 }, {     13,   27,    0,  3,  0,  0 }, {     12,   27,    0,  3,  0,  0 },
        {     11,   28,    0,  3,  0,  0 }, {     10,   28,    0,  3,  0,  0 }, {      9,   29,    0,  3,  0,  0 }, {      8,   30,    0,  4,  0,  0 }, {      7,   30,    0,  4,  0,  0 },
        {      6,   31,    0,  4,  0,  0 }, {      5,   32,    0,  4,  0,  0 }, {      4,   33,    0,  4,  0,  0 }, {      3,   34,    0,  4,  0,  0 }, {      2,   35,    0,  5,  0,  0 },
        {      1,   36,    0,  5,  0,  0 }, {      0,   37,    0,  5,  0,  0 }, {     -1,   38,    0,  5,  0,  0 }, {     -2,   39,    0,  5,  0,  0 }, {     -2,   40,    0,  5,  0,  0 },
        {     -3,   41,    0,  6,  0,  0 }, {     -4,   42,    0,  6,  0,  0 }, {     -4,   43,    0,  6,  0,  0 }, {     -5,   44,    0,  6,  0,  0 }, {     -5,   45,    0,  6,  0,  0 },
        {     -6,   46,    0,  6,  0,  0 }, {     -6,   47,    0,  6,  0,  0 }, {     -7,   48,    0,  7,  0,  0 }, {     -7,   49,    0,  7,  0,  0 }, {     -7,   50,    0,  7,  0,  0 },
        {     -8,   51,    0,  7,  0,  0 }, {     -8,   52,    0,  7,  0,  0 }, {     -8,   53,    0,  7,  0,  0 }, {     -8,   54,    0,  7,  0,  0 }, {     -9,   55,    0,  7,  0,  0 },
        {     -9,   56,    0,  8,  0,  0 }, {     -9,   57,    0,  8,  0,  0 }, {     -9,   58,    0,  8,  0,  0 }, {     -9,   59,    0,  8,  0,  0 }, {     -9,   60,    0,  8,  0,  0 },
        {     -9,   61,    0,  8,  0,  0 }, {     -9,   62,    0,  8,  0,  0 }, {     -9,   63,    0,  8,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles1, {
        {     23,    1,    0,  8,  0,  0 }, {     23,    2,    0,  9,  0,  0 }, {     23,    3,    0,  9,  0,  0 }, {     23,    4,    0,  9,  0,  0 }, {     23,    5,    0,  9,  0,  0 },
        {     23,    6,    0,  9,  0,  0 }, {     23,    7,    0,  9,  0,  0 }, {     23,    8,    0,  9,  0,  0 }, {     23,    9,    0, 10,  0,  0 }, {     24,   10,    0, 10,  0,  0 },
        {     24,   11,    0, 10,  0,  0 }, {     24,   12,    0, 10,  0,  0 }, {     24,   13,    0, 10,  0,  0 }, {     25,   14,    0, 10,  0,  0 }, {     25,   15,    0, 10,  0,  0 },
        {     25,   16,    0, 10,  0,  0 }, {     26,   17,    0, 11,  0,  0 }, {     26,   18,    0, 11,  0,  0 }, {     27,   19,    0, 11,  0,  0 }, {     27,   20,    0, 11,  0,  0 },
        {     28,   21,    0, 11,  0,  0 }, {     28,   22,    0, 11,  0,  0 }, {     29,   23,    0, 11,  0,  0 }, {     30,   24,    0, 12,  0,  0 }, {     30,   25,    0, 12,  0,  0 },
        {     31,   26,    0, 12,  0,  0 }, {     32,   27,    0, 12,  0,  0 }, {     33,   28,    0, 12,  0,  0 }, {     34,   29,    0, 12,  0,  0 }, {     35,   30,    0, 13,  0,  0 },
        {     36,   31,    0, 13,  0,  0 }, {     37,   32,    0, 13,  0,  0 }, {     38,   33,    0, 13,  0,  0 }, {     39,   34,    0, 13,  0,  0 }, {     40,   34,    0, 13,  0,  0 },
        {     41,   35,    0, 14,  0,  0 }, {     42,   36,    0, 14,  0,  0 }, {     43,   36,    0, 14,  0,  0 }, {     44,   37,    0, 14,  0,  0 }, {     45,   37,    0, 14,  0,  0 },
        {     46,   38,    0, 14,  0,  0 }, {     47,   38,    0, 14,  0,  0 }, {     48,   39,    0, 15,  0,  0 }, {     49,   39,    0, 15,  0,  0 }, {     50,   39,    0, 15,  0,  0 },
        {     51,   40,    0, 15,  0,  0 }, {     52,   40,    0, 15,  0,  0 }, {     53,   40,    0, 15,  0,  0 }, {     54,   40,    0, 15,  0,  0 }, {     55,   41,    0, 15,  0,  0 },
        {     56,   41,    0, 16,  0,  0 }, {     57,   41,    0, 16,  0,  0 }, {     58,   41,    0, 16,  0,  0 }, {     59,   41,    0, 16,  0,  0 }, {     60,   41,    0, 16,  0,  0 },
        {     61,   41,    0, 16,  0,  0 }, {     62,   41,    0, 16,  0,  0 }, {     63,   41,    0, 16,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles2, {
        {      1,    9,    0, 16,  0,  0 }, {      2,    9,    0, 17,  0,  0 }, {      3,    9,    0, 17,  0,  0 }, {      4,    9,    0, 17,  0,  0 }, {      5,    9,    0, 17,  0,  0 },
        {      6,    9,    0, 17,  0,  0 }, {      7,    9,    0, 17,  0,  0 }, {      8,    9,    0, 17,  0,  0 }, {      9,    9,    0, 18,  0,  0 }, {     10,    8,    0, 18,  0,  0 },
        {     11,    8,    0, 18,  0,  0 }, {     12,    8,    0, 18,  0,  0 }, {     13,    8,    0, 18,  0,  0 }, {     14,    7,    0, 18,  0,  0 }, {     15,    7,    0, 18,  0,  0 },
        {     16,    7,    0, 18,  0,  0 }, {     17,    6,    0, 19,  0,  0 }, {     18,    6,    0, 19,  0,  0 }, {     19,    5,    0, 19,  0,  0 }, {     20,    5,    0, 19,  0,  0 },
        {     21,    4,    0, 19,  0,  0 }, {     22,    4,    0, 19,  0,  0 }, {     23,    3,    0, 19,  0,  0 }, {     24,    2,    0, 20,  0,  0 }, {     25,    2,    0, 20,  0,  0 },
        {     26,    1,    0, 20,  0,  0 }, {     27,    0,    0, 20,  0,  0 }, {     28,   -1,    0, 20,  0,  0 }, {     29,   -2,    0, 20,  0,  0 }, {     30,   -3,    0, 21,  0,  0 },
        {     31,   -4,    0, 21,  0,  0 }, {     32,   -5,    0, 21,  0,  0 }, {     33,   -6,    0, 21,  0,  0 }, {     34,   -7,    0, 21,  0,  0 }, {     34,   -8,    0, 21,  0,  0 },
        {     35,   -9,    0, 22,  0,  0 }, {     36,  -10,    0, 22,  0,  0 }, {     36,  -11,    0, 22,  0,  0 }, {     37,  -12,    0, 22,  0,  0 }, {     37,  -13,    0, 22,  0,  0 },
        {     38,  -14,    0, 22,  0,  0 }, {     38,  -15,    0, 22,  0,  0 }, {     39,  -16,    0, 23,  0,  0 }, {     39,  -17,    0, 23,  0,  0 }, {     39,  -18,    0, 23,  0,  0 },
        {     40,  -19,    0, 23,  0,  0 }, {     40,  -20,    0, 23,  0,  0 }, {     40,  -21,    0, 23,  0,  0 }, {     40,  -22,    0, 23,  0,  0 }, {     41,  -23,    0, 23,  0,  0 },
        {     41,  -24,    0, 24,  0,  0 }, {     41,  -25,    0, 24,  0,  0 }, {     41,  -26,    0, 24,  0,  0 }, {     41,  -27,    0, 24,  0,  0 }, {     41,  -28,    0, 24,  0,  0 },
        {     41,  -29,    0, 24,  0,  0 }, {     41,  -30,    0, 24,  0,  0 }, {     41,  -31,    0, 24,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles3, {
        {      9,   31,    0, 24,  0,  0 }, {      9,   30,    0, 25,  0,  0 }, {      9,   29,    0, 25,  0,  0 }, {      9,   28,    0, 25,  0,  0 }, {      9,   27,    0, 25,  0,  0 },
        {      9,   26,    0, 25,  0,  0 }, {      9,   25,    0, 25,  0,  0 }, {      9,   24,    0, 25,  0,  0 }, {      9,   23,    0, 26,  0,  0 }, {      8,   22,    0, 26,  0,  0 },
        {      8,   21,    0, 26,  0,  0 }, {      8,   20,    0, 26,  0,  0 }, {      8,   19,    0, 26,  0,  0 }, {      7,   18,    0, 26,  0,  0 }, {      7,   17,    0, 26,  0,  0 },
        {      7,   16,    0, 26,  0,  0 }, {      6,   15,    0, 27,  0,  0 }, {      6,   14,    0, 27,  0,  0 }, {      5,   13,    0, 27,  0,  0 }, {      5,   12,    0, 27,  0,  0 },
        {      4,   11,    0, 27,  0,  0 }, {      4,   10,    0, 27,  0,  0 }, {      3,    9,    0, 27,  0,  0 }, {      2,    8,    0, 28,  0,  0 }, {      2,    7,    0, 28,  0,  0 },
        {      1,    6,    0, 28,  0,  0 }, {      0,    5,    0, 28,  0,  0 }, {     -1,    4,    0, 28,  0,  0 }, {     -2,    3,    0, 28,  0,  0 }, {     -3,    2,    0, 29,  0,  0 },
        {     -4,    1,    0, 29,  0,  0 }, {     -5,    0,    0, 29,  0,  0 }, {     -6,   -1,    0, 29,  0,  0 }, {     -7,   -2,    0, 29,  0,  0 }, {     -8,   -2,    0, 29,  0,  0 },
        {     -9,   -3,    0, 30,  0,  0 }, {    -10,   -4,    0, 30,  0,  0 }, {    -11,   -4,    0, 30,  0,  0 }, {    -12,   -5,    0, 30,  0,  0 }, {    -13,   -5,    0, 30,  0,  0 },
        {     -9,   -3,    0, 30,  0,  0 }, {    -10,   -4,    0, 30,  0,  0 }, {    -11,   -4,    0, 30,  0,  0 }, {    -12,   -5,    0, 30,  0,  0 }, {    -13,   -5,    0, 30,  0,  0 },
        {    -14,   -6,    0, 30,  0,  0 }, {    -15,   -6,    0, 30,  0,  0 }, {    -16,   -7,    0, 31,  0,  0 }, {    -17,   -7,    0, 31,  0,  0 }, {    -18,   -7,    0, 31,  0,  0 },
        {    -19,   -8,    0, 31,  0,  0 }, {    -20,   -8,    0, 31,  0,  0 }, {    -21,   -8,    0, 31,  0,  0 }, {    -22,   -8,    0, 31,  0,  0 }, {    -23,   -9,    0, 31,  0,  0 },
        {    -24,   -9,    0,  0,  0,  0 }, {    -25,   -9,    0,  0,  0,  0 }, {    -26,   -9,    0,  0,  0,  0 }, {    -27,   -9,    0,  0,  0,  0 }, {    -28,   -9,    0,  0,  0,  0 },
        {    -29,   -9,    0,  0,  0,  0 }, {    -30,   -9,    0,  0,  0,  0 }, {    -31,   -9,    0,  0,  0,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp0, {
        {     31,   23,    0,  0,  2,  0 }, {     30,   23,    0, 31,  2,  0 }, {     29,   23,    1, 31,  2,  0 }, {     28,   23,    1, 31,  2,  0 }, {     27,   23,    2, 31,  2,  0 },
        {     26,   23,    2, 31,  2,  0 }, {     25,   23,    2, 31,  2,  0 }, {     24,   23,    3, 31,  2,  0 }, {     23,   23,    3, 31,  2,  0 }, {     22,   23,    4, 31,  2,  0 },
        {     21,   23,    4, 31,  2,  0 }, {     20,   22,    4, 30,  2,  0 }, {     19,   22,    5, 30,  2,  0 }, {     18,   22,    5, 30,  2,  0 }, {     17,   22,    6, 30,  2,  0 },
        {     16,   21,    6, 30,  2,  0 }, {     15,   21,    6, 30,  2,  0 }, {     14,   21,    7, 30,  2,  0 }, {     13,   20,    7, 30,  2,  0 }, {     12,   20,    8, 30,  2,  0 },
        {     11,   20,    8, 30,  2,  0 }, {     10,   19,    8, 29,  2,  0 }, {      9,   19,    9, 29,  2,  0 }, {      8,   18,    9, 29,  2,  0 }, {      7,   18,   10, 29,  2,  0 },
        {      6,   17,   10, 29,  2,  0 }, {      5,   17,   10, 29,  2,  0 }, {      4,   16,   11, 29,  2,  0 }, {      3,   16,   11, 29,  2,  0 }, {      2,   15,   12, 29,  2,  0 },
        {      1,   15,   12, 29,  2,  0 }, {      0,   14,   12, 28,  2,  0 }, {     -1,   13,   13, 28,  2,  0 }, {     -2,   12,   13, 28,  2,  0 }, {     -3,   12,   14, 28,  2,  0 },
        {     -4,   11,   14, 28,  2,  0 }, {     -5,   10,   14, 28,  2,  0 }, {     -6,    9,   15, 28,  2,  0 }, {     -7,    8,   15, 28,  2,  0 }, {     -8,    7,   16, 27,  2,  0 },
        {     -9,    6,   16, 27,  2,  0 }, {    -10,    5,   16, 27,  2,  0 }, {    -11,    4,   17, 27,  2,  0 }, {    -12,    3,   17, 27,  2,  0 }, {    -12,    2,   17, 27,  2,  0 },
        {    -13,    1,   18, 27,  2,  0 }, {    -14,    0,   18, 27,  2,  0 }, {    -15,   -1,   19, 26,  2,  0 }, {    -15,   -2,   19, 26,  2,  0 }, {    -16,   -3,   19, 26,  2,  0 },
        {    -16,   -4,   20, 26,  2,  0 }, {    -17,   -5,   20, 26,  2,  0 }, {    -17,   -6,   21, 26,  2,  0 }, {    -18,   -7,   21, 26,  2,  0 }, {    -18,   -8,   21, 26,  2,  0 },
        {    -19,   -9,   22, 26,  2,  0 }, {    -19,  -10,   22, 26,  2,  0 }, {    -20,  -11,   23, 25,  2,  0 }, {    -20,  -12,   23, 25,  2,  0 }, {    -20,  -13,   23, 25,  2,  0 },
        {    -21,  -14,   24, 25,  2,  0 }, {    -21,  -15,   24, 25,  2,  0 }, {    -21,  -16,   25, 25,  2,  0 }, {    -22,  -17,   25, 25,  2,  0 }, {    -22,  -18,   25, 25,  2,  0 },
        {    -22,  -19,   26, 25,  2,  0 }, {    -22,  -20,   26, 25,  2,  0 }, {    -23,  -21,   27, 24,  2,  0 }, {    -23,  -22,   27, 24,  2,  0 }, {    -23,  -23,   27, 24,  2,  0 },
        {    -23,  -24,   28, 24,  2,  0 }, {    -23,  -25,   28, 24,  2,  0 }, {    -23,  -26,   29, 24,  2,  0 }, {    -23,  -27,   29, 24,  2,  0 }, {    -23,  -28,   29, 24,  2,  0 },
        {    -23,  -29,   30, 24,  2,  0 }, {    -23,  -30,   30, 24,  2,  0 }, {    -23,  -31,   31, 24,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp1, {
        {     23,    1,    0,  8,  2,  0 }, {     23,    2,    0,  7,  2,  0 }, {     23,    3,    1,  7,  2,  0 }, {     23,    4,    1,  7,  2,  0 }, {     23,    5,    2,  7,  2,  0 },
        {     23,    6,    2,  7,  2,  0 }, {     23,    7,    2,  7,  2,  0 }, {     23,    8,    3,  7,  2,  0 }, {     23,    9,    3,  7,  2,  0 }, {     23,   10,    4,  7,  2,  0 },
        {     23,   11,    4,  7,  2,  0 }, {     22,   12,    4,  6,  2,  0 }, {     22,   13,    5,  6,  2,  0 }, {     22,   14,    5,  6,  2,  0 }, {     22,   15,    6,  6,  2,  0 },
        {     21,   16,    6,  6,  2,  0 }, {     21,   17,    6,  6,  2,  0 }, {     21,   18,    7,  6,  2,  0 }, {     20,   19,    7,  6,  2,  0 }, {     20,   20,    8,  6,  2,  0 },
        {     20,   21,    8,  6,  2,  0 }, {     19,   22,    8,  5,  2,  0 }, {     19,   23,    9,  5,  2,  0 }, {     18,   24,    9,  5,  2,  0 }, {     18,   25,   10,  5,  2,  0 },
        {     17,   26,   10,  5,  2,  0 }, {     17,   27,   10,  5,  2,  0 }, {     16,   28,   11,  5,  2,  0 }, {     16,   29,   11,  5,  2,  0 }, {     15,   30,   12,  5,  2,  0 },
        {     15,   31,   12,  5,  2,  0 }, {     14,   32,   12,  4,  2,  0 }, {     13,   33,   13,  4,  2,  0 }, {     12,   34,   13,  4,  2,  0 }, {     12,   35,   14,  4,  2,  0 },
        {     11,   36,   14,  4,  2,  0 }, {     10,   37,   14,  4,  2,  0 }, {      9,   38,   15,  4,  2,  0 }, {      8,   39,   15,  4,  2,  0 }, {      7,   40,   16,  3,  2,  0 },
        {      6,   41,   16,  3,  2,  0 }, {      5,   42,   16,  3,  2,  0 }, {      4,   43,   17,  3,  2,  0 }, {      3,   44,   17,  3,  2,  0 }, {      2,   44,   17,  3,  2,  0 },
        {      1,   45,   18,  3,  2,  0 }, {      0,   46,   18,  3,  2,  0 }, {     -1,   47,   19,  2,  2,  0 }, {     -2,   47,   19,  2,  2,  0 }, {     -3,   48,   19,  2,  2,  0 },
        {     -4,   48,   20,  2,  2,  0 }, {     -5,   49,   20,  2,  2,  0 }, {     -6,   49,   21,  2,  2,  0 }, {     -7,   50,   21,  2,  2,  0 }, {     -8,   50,   21,  2,  2,  0 },
        {     -9,   51,   22,  2,  2,  0 }, {    -10,   51,   22,  2,  2,  0 }, {    -11,   52,   23,  1,  2,  0 }, {    -12,   52,   23,  1,  2,  0 }, {    -13,   52,   23,  1,  2,  0 },
        {    -14,   53,   24,  1,  2,  0 }, {    -15,   53,   24,  1,  2,  0 }, {    -16,   53,   25,  1,  2,  0 }, {    -17,   54,   25,  1,  2,  0 }, {    -18,   54,   25,  1,  2,  0 },
        {    -19,   54,   26,  1,  2,  0 }, {    -20,   54,   26,  1,  2,  0 }, {    -21,   55,   27,  0,  2,  0 }, {    -22,   55,   27,  0,  2,  0 }, {    -23,   55,   27,  0,  2,  0 },
        {    -24,   55,   28,  0,  2,  0 }, {    -25,   55,   28,  0,  2,  0 }, {    -26,   55,   29,  0,  2,  0 }, {    -27,   55,   29,  0,  2,  0 }, {    -28,   55,   29,  0,  2,  0 },
        {    -29,   55,   30,  0,  2,  0 }, {    -30,   55,   30,  0,  2,  0 }, {    -31,   55,   31,  0,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp2, {
        {      1,    9,    0, 16,  2,  0 }, {      2,    9,    0, 15,  2,  0 }, {      3,    9,    1, 15,  2,  0 }, {      4,    9,    1, 15,  2,  0 }, {      5,    9,    2, 15,  2,  0 },
        {      6,    9,    2, 15,  2,  0 }, {      7,    9,    2, 15,  2,  0 }, {      8,    9,    3, 15,  2,  0 }, {      9,    9,    3, 15,  2,  0 }, {     10,    9,    4, 15,  2,  0 },
        {     11,    9,    4, 15,  2,  0 }, {     12,   10,    4, 14,  2,  0 }, {     13,   10,    5, 14,  2,  0 }, {     14,   10,    5, 14,  2,  0 }, {     15,   10,    6, 14,  2,  0 },
        {     16,   11,    6, 14,  2,  0 }, {     17,   11,    6, 14,  2,  0 }, {     18,   11,    7, 14,  2,  0 }, {     19,   12,    7, 14,  2,  0 }, {     20,   12,    8, 14,  2,  0 },
        {     21,   12,    8, 14,  2,  0 }, {     22,   13,    8, 13,  2,  0 }, {     23,   13,    9, 13,  2,  0 }, {     24,   14,    9, 13,  2,  0 }, {     25,   14,   10, 13,  2,  0 },
        {     26,   15,   10, 13,  2,  0 }, {     27,   15,   10, 13,  2,  0 }, {     28,   16,   11, 13,  2,  0 }, {     29,   16,   11, 13,  2,  0 }, {     30,   17,   12, 13,  2,  0 },
        {     31,   17,   12, 13,  2,  0 }, {     32,   18,   12, 12,  2,  0 }, {     33,   19,   13, 12,  2,  0 }, {     34,   20,   13, 12,  2,  0 }, {     35,   20,   14, 12,  2,  0 },
        {     36,   21,   14, 12,  2,  0 }, {     37,   22,   14, 12,  2,  0 }, {     38,   23,   15, 12,  2,  0 }, {     39,   24,   15, 12,  2,  0 }, {     40,   25,   16, 11,  2,  0 },
        {     41,   26,   16, 11,  2,  0 }, {     42,   27,   16, 11,  2,  0 }, {     43,   28,   17, 11,  2,  0 }, {     44,   29,   17, 11,  2,  0 }, {     44,   30,   17, 11,  2,  0 },
        {     45,   31,   18, 11,  2,  0 }, {     46,   32,   18, 11,  2,  0 }, {     47,   33,   19, 10,  2,  0 }, {     47,   34,   19, 10,  2,  0 }, {     48,   35,   19, 10,  2,  0 },
        {     48,   36,   20, 10,  2,  0 }, {     49,   37,   20, 10,  2,  0 }, {     49,   38,   21, 10,  2,  0 }, {     50,   39,   21, 10,  2,  0 }, {     50,   40,   21, 10,  2,  0 },
        {     51,   41,   22, 10,  2,  0 }, {     51,   42,   22, 10,  2,  0 }, {     52,   43,   23,  9,  2,  0 }, {     52,   44,   23,  9,  2,  0 }, {     52,   45,   23,  9,  2,  0 },
        {     53,   46,   24,  9,  2,  0 }, {     53,   47,   24,  9,  2,  0 }, {     53,   48,   25,  9,  2,  0 }, {     54,   49,   25,  9,  2,  0 }, {     54,   50,   25,  9,  2,  0 },
        {     54,   51,   26,  9,  2,  0 }, {     54,   52,   26,  9,  2,  0 }, {     55,   53,   27,  8,  2,  0 }, {     55,   54,   27,  8,  2,  0 }, {     55,   55,   27,  8,  2,  0 },
        {     55,   56,   28,  8,  2,  0 }, {     55,   57,   28,  8,  2,  0 }, {     55,   58,   29,  8,  2,  0 }, {     55,   59,   29,  8,  2,  0 }, {     55,   60,   29,  8,  2,  0 },
        {     55,   61,   30,  8,  2,  0 }, {     55,   62,   30,  8,  2,  0 }, {     55,   63,   31,  8,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp3, {
        {      9,   31,    0, 24,  2,  0 }, {      9,   30,    0, 23,  2,  0 }, {      9,   29,    1, 23,  2,  0 }, {      9,   28,    1, 23,  2,  0 }, {      9,   27,    2, 23,  2,  0 },
        {      9,   26,    2, 23,  2,  0 }, {      9,   25,    2, 23,  2,  0 }, {      9,   24,    3, 23,  2,  0 }, {      9,   23,    3, 23,  2,  0 }, {      9,   22,    4, 23,  2,  0 },
        {      9,   21,    4, 23,  2,  0 }, {     10,   20,    4, 22,  2,  0 }, {     10,   19,    5, 22,  2,  0 }, {     10,   18,    5, 22,  2,  0 }, {     10,   17,    6, 22,  2,  0 },
        {     11,   16,    6, 22,  2,  0 }, {     11,   15,    6, 22,  2,  0 }, {     11,   14,    7, 22,  2,  0 }, {     12,   13,    7, 22,  2,  0 }, {     12,   12,    8, 22,  2,  0 },
        {     12,   11,    8, 22,  2,  0 }, {     13,   10,    8, 21,  2,  0 }, {     13,    9,    9, 21,  2,  0 }, {     14,    8,    9, 21,  2,  0 }, {     14,    7,   10, 21,  2,  0 },
        {     15,    6,   10, 21,  2,  0 }, {     15,    5,   10, 21,  2,  0 }, {     16,    4,   11, 21,  2,  0 }, {     16,    3,   11, 21,  2,  0 }, {     17,    2,   12, 21,  2,  0 },
        {     17,    1,   12, 21,  2,  0 }, {     18,    0,   12, 20,  2,  0 }, {     19,   -1,   13, 20,  2,  0 }, {     20,   -2,   13, 20,  2,  0 }, {     20,   -3,   14, 20,  2,  0 },
        {     21,   -4,   14, 20,  2,  0 }, {     22,   -5,   14, 20,  2,  0 }, {     23,   -6,   15, 20,  2,  0 }, {     24,   -7,   15, 20,  2,  0 }, {     25,   -8,   16, 19,  2,  0 },
        {     26,   -9,   16, 19,  2,  0 }, {     27,  -10,   16, 19,  2,  0 }, {     28,  -11,   17, 19,  2,  0 }, {     29,  -12,   17, 19,  2,  0 }, {     30,  -12,   17, 19,  2,  0 },
        {     31,  -13,   18, 19,  2,  0 }, {     32,  -14,   18, 19,  2,  0 }, {     33,  -15,   19, 18,  2,  0 }, {     34,  -15,   19, 18,  2,  0 }, {     35,  -16,   19, 18,  2,  0 },
        {     36,  -16,   20, 18,  2,  0 }, {     37,  -17,   20, 18,  2,  0 }, {     38,  -17,   21, 18,  2,  0 }, {     39,  -18,   21, 18,  2,  0 }, {     40,  -18,   21, 18,  2,  0 },
        {     41,  -19,   22, 18,  2,  0 }, {     42,  -19,   22, 18,  2,  0 }, {     43,  -20,   23, 17,  2,  0 }, {     44,  -20,   23, 17,  2,  0 }, {     45,  -20,   23, 17,  2,  0 },
        {     46,  -21,   24, 17,  2,  0 }, {     47,  -21,   24, 17,  2,  0 }, {     48,  -21,   25, 17,  2,  0 }, {     49,  -22,   25, 17,  2,  0 }, {     50,  -22,   25, 17,  2,  0 },
        {     51,  -22,   26, 17,  2,  0 }, {     52,  -22,   26, 17,  2,  0 }, {     53,  -23,   27, 16,  2,  0 }, {     54,  -23,   27, 16,  2,  0 }, {     55,  -23,   27, 16,  2,  0 },
        {     56,  -23,   28, 16,  2,  0 }, {     57,  -23,   28, 16,  2,  0 }, {     58,  -23,   29, 16,  2,  0 }, {     59,  -23,   29, 16,  2,  0 }, {     60,  -23,   29, 16,  2,  0 },
        {     61,  -23,   30, 16,  2,  0 }, {     62,  -23,   30, 16,  2,  0 }, {     63,  -23,   31, 16,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegUp0, {
        {     31,   23,    0,  0,  2,  0 }, {     30,   23,    1,  1,  2,  0 }, {     29,   23,    1,  1,  2,  0 }, {     28,   23,    2,  1,  2,  0 }, {     27,   23,    2,  1,  2,  0 },
        {     26,   23,    3,  1,  2,  0 }, {     25,   23,    3,  1,  2,  0 }, {     24,   23,    4,  1,  2,  0 }, {     23,   23,    4,  2,  2,  0 }, {     22,   24,    5,  2,  2,  0 },
        {     21,   24,    5,  2,  2,  0 }, {     20,   24,    6,  2,  2,  0 }, {     19,   24,    6,  2,  2,  0 }, {     18,   25,    7,  2,  2,  0 }, {     17,   25,    7,  2,  2,  0 },
        {     16,   25,    8,  2,  2,  0 }, {     15,   26,    9,  3,  2,  0 }, {     14,   26,    9,  3,  2,  0 }, {     13,   27,   10,  3,  2,  0 }, {     12,   27,   10,  3,  2,  0 },
        {     11,   28,   11,  3,  2,  0 }, {     10,   28,   11,  3,  2,  0 }, {      9,   29,   12,  3,  2,  0 }, {      8,   30,   12,  4,  2,  0 }, {      7,   30,   13,  4,  2,  0 },
        {      6,   31,   13,  4,  2,  0 }, {      5,   32,   14,  4,  2,  0 }, {      4,   33,   14,  4,  2,  0 }, {      3,   34,   15,  4,  2,  0 }, {      2,   35,   16,  5,  2,  0 },
        {      1,   36,   16,  5,  2,  0 }, {      0,   37,   17,  5,  2,  0 }, {     -1,   38,   17,  5,  2,  0 }, {     -2,   39,   18,  5,  2,  0 }, {     -2,   40,   18,  5,  2,  0 },
        {     -3,   41,   19,  6,  2,  0 }, {     -4,   42,   19,  6,  2,  0 }, {     -4,   43,   20,  6,  2,  0 }, {     -5,   44,   20,  6,  2,  0 }, {     -5,   45,   21,  6,  2,  0 },
        {     -6,   46,   21,  6,  2,  0 }, {     -6,   47,   22,  6,  2,  0 }, {     -7,   48,   22,  7,  2,  0 }, {     -7,   49,   23,  7,  2,  0 }, {     -7,   50,   24,  7,  2,  0 },
        {     -8,   51,   24,  7,  2,  0 }, {     -8,   52,   25,  7,  2,  0 }, {     -8,   53,   25,  7,  2,  0 }, {     -8,   54,   26,  7,  2,  0 }, {     -9,   55,   26,  7,  2,  0 },
        {     -9,   56,   27,  8,  2,  0 }, {     -9,   57,   27,  8,  2,  0 }, {     -9,   58,   28,  8,  2,  0 }, {     -9,   59,   28,  8,  2,  0 }, {     -9,   60,   29,  8,  2,  0 },
        {     -9,   61,   29,  8,  2,  0 }, {     -9,   62,   30,  8,  2,  0 }, {     -9,   63,   30,  8,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegUp1, {
        {     23,    1,    0,  8,  2,  0 }, {     23,    2,    1,  9,  2,  0 }, {     23,    3,    1,  9,  2,  0 }, {     23,    4,    2,  9,  2,  0 }, {     23,    5,    2,  9,  2,  0 },
        {     23,    6,    3,  9,  2,  0 }, {     23,    7,    3,  9,  2,  0 }, {     23,    8,    4,  9,  2,  0 }, {     23,    9,    4, 10,  2,  0 }, {     24,   10,    5, 10,  2,  0 },
        {     24,   11,    5, 10,  2,  0 }, {     24,   12,    6, 10,  2,  0 }, {     24,   13,    6, 10,  2,  0 }, {     25,   14,    7, 10,  2,  0 }, {     25,   15,    7, 10,  2,  0 },
        {     25,   16,    8, 10,  2,  0 }, {     26,   17,    9, 11,  2,  0 }, {     26,   18,    9, 11,  2,  0 }, {     27,   19,   10, 11,  2,  0 }, {     27,   20,   10, 11,  2,  0 },
        {     28,   21,   11, 11,  2,  0 }, {     28,   22,   11, 11,  2,  0 }, {     29,   23,   12, 11,  2,  0 }, {     30,   24,   12, 12,  2,  0 }, {     30,   25,   13, 12,  2,  0 },
        {     31,   26,   13, 12,  2,  0 }, {     32,   27,   14, 12,  2,  0 }, {     33,   28,   14, 12,  2,  0 }, {     34,   29,   15, 12,  2,  0 }, {     35,   30,   16, 13,  2,  0 },
        {     36,   31,   16, 13,  2,  0 }, {     37,   32,   17, 13,  2,  0 }, {     38,   33,   17, 13,  2,  0 }, {     39,   34,   18, 13,  2,  0 }, {     40,   34,   18, 13,  2,  0 },
        {     41,   35,   19, 14,  2,  0 }, {     42,   36,   19, 14,  2,  0 }, {     43,   36,   20, 14,  2,  0 }, {     44,   37,   20, 14,  2,  0 }, {     45,   37,   21, 14,  2,  0 },
        {     46,   38,   21, 14,  2,  0 }, {     47,   38,   22, 14,  2,  0 }, {     48,   39,   22, 15,  2,  0 }, {     49,   39,   23, 15,  2,  0 }, {     50,   39,   24, 15,  2,  0 },
        {     51,   40,   24, 15,  2,  0 }, {     52,   40,   25, 15,  2,  0 }, {     53,   40,   25, 15,  2,  0 }, {     54,   40,   26, 15,  2,  0 }, {     55,   41,   26, 15,  2,  0 },
        {     56,   41,   27, 16,  2,  0 }, {     57,   41,   27, 16,  2,  0 }, {     58,   41,   28, 16,  2,  0 }, {     59,   41,   28, 16,  2,  0 }, {     60,   41,   29, 16,  2,  0 },
        {     61,   41,   29, 16,  2,  0 }, {     62,   41,   30, 16,  2,  0 }, {     63,   41,   30, 16,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegUp2, {
        {      1,    9,    0, 16,  2,  0 }, {      2,    9,    1, 17,  2,  0 }, {      3,    9,    1, 17,  2,  0 }, {      4,    9,    2, 17,  2,  0 }, {      5,    9,    2, 17,  2,  0 },
        {      6,    9,    3, 17,  2,  0 }, {      7,    9,    3, 17,  2,  0 }, {      8,    9,    4, 17,  2,  0 }, {      9,    9,    4, 18,  2,  0 }, {     10,    8,    5, 18,  2,  0 },
        {     11,    8,    5, 18,  2,  0 }, {     12,    8,    6, 18,  2,  0 }, {     13,    8,    6, 18,  2,  0 }, {     14,    7,    7, 18,  2,  0 }, {     15,    7,    7, 18,  2,  0 },
        {     16,    7,    8, 18,  2,  0 }, {     17,    6,    9, 19,  2,  0 }, {     18,    6,    9, 19,  2,  0 }, {     19,    5,   10, 19,  2,  0 }, {     20,    5,   10, 19,  2,  0 },
        {     21,    4,   11, 19,  2,  0 }, {     22,    4,   11, 19,  2,  0 }, {     23,    3,   12, 19,  2,  0 }, {     24,    2,   12, 20,  2,  0 }, {     25,    2,   13, 20,  2,  0 },
        {     26,    1,   13, 20,  2,  0 }, {     27,    0,   14, 20,  2,  0 }, {     28,   -1,   14, 20,  2,  0 }, {     29,   -2,   15, 20,  2,  0 }, {     30,   -3,   16, 21,  2,  0 },
        {     31,   -4,   16, 21,  2,  0 }, {     32,   -5,   17, 21,  2,  0 }, {     33,   -6,   17, 21,  2,  0 }, {     34,   -7,   18, 21,  2,  0 }, {     34,   -8,   18, 21,  2,  0 },
        {     35,   -9,   19, 22,  2,  0 }, {     36,  -10,   19, 22,  2,  0 }, {     36,  -11,   20, 22,  2,  0 }, {     37,  -12,   20, 22,  2,  0 }, {     37,  -13,   21, 22,  2,  0 },
        {     38,  -14,   21, 22,  2,  0 }, {     38,  -15,   22, 22,  2,  0 }, {     39,  -16,   22, 23,  2,  0 }, {     39,  -17,   23, 23,  2,  0 }, {     39,  -18,   24, 23,  2,  0 },
        {     40,  -19,   24, 23,  2,  0 }, {     40,  -20,   25, 23,  2,  0 }, {     40,  -21,   25, 23,  2,  0 }, {     40,  -22,   26, 23,  2,  0 }, {     41,  -23,   26, 23,  2,  0 },
        {     41,  -24,   27, 24,  2,  0 }, {     41,  -25,   27, 24,  2,  0 }, {     41,  -26,   28, 24,  2,  0 }, {     41,  -27,   28, 24,  2,  0 }, {     41,  -28,   29, 24,  2,  0 },
        {     41,  -29,   29, 24,  2,  0 }, {     41,  -30,   30, 24,  2,  0 }, {     41,  -31,   30, 24,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegUp3, {
        {      9,   31,    0, 24,  2,  0 }, {      9,   30,    1, 25,  2,  0 }, {      9,   29,    1, 25,  2,  0 }, {      9,   28,    2, 25,  2,  0 }, {      9,   27,    2, 25,  2,  0 },
        {      9,   26,    3, 25,  2,  0 }, {      9,   25,    3, 25,  2,  0 }, {      9,   24,    4, 25,  2,  0 }, {      9,   23,    4, 26,  2,  0 }, {      8,   22,    5, 26,  2,  0 },
        {      8,   21,    5, 26,  2,  0 }, {      8,   20,    6, 26,  2,  0 }, {      8,   19,    6, 26,  2,  0 }, {      7,   18,    7, 26,  2,  0 }, {      7,   17,    7, 26,  2,  0 },
        {      7,   16,    8, 26,  2,  0 }, {      6,   15,    9, 27,  2,  0 }, {      6,   14,    9, 27,  2,  0 }, {      5,   13,   10, 27,  2,  0 }, {      5,   12,   10, 27,  2,  0 },
        {      4,   11,   11, 27,  2,  0 }, {      4,   10,   11, 27,  2,  0 }, {      3,    9,   12, 27,  2,  0 }, {      2,    8,   12, 28,  2,  0 }, {      2,    7,   13, 28,  2,  0 },
        {      1,    6,   13, 28,  2,  0 }, {      0,    5,   14, 28,  2,  0 }, {     -1,    4,   14, 28,  2,  0 }, {     -2,    3,   15, 28,  2,  0 }, {     -3,    2,   16, 29,  2,  0 },
        {     -4,    1,   16, 29,  2,  0 }, {     -5,    0,   17, 29,  2,  0 }, {     -6,   -1,   17, 29,  2,  0 }, {     -7,   -2,   18, 29,  2,  0 }, {     -8,   -2,   18, 29,  2,  0 },
        {     -9,   -3,   19, 30,  2,  0 }, {    -10,   -4,   19, 30,  2,  0 }, {    -11,   -4,   20, 30,  2,  0 }, {    -12,   -5,   20, 30,  2,  0 }, {    -13,   -5,   21, 30,  2,  0 },
        {    -14,   -6,   21, 30,  2,  0 }, {    -15,   -6,   22, 30,  2,  0 }, {    -16,   -7,   22, 31,  2,  0 }, {    -17,   -7,   23, 31,  2,  0 }, {    -18,   -7,   24, 31,  2,  0 },
        {    -19,   -8,   24, 31,  2,  0 }, {    -20,   -8,   25, 31,  2,  0 }, {    -21,   -8,   25, 31,  2,  0 }, {    -22,   -8,   26, 31,  2,  0 }, {    -23,   -9,   26, 31,  2,  0 },
        {    -24,   -9,   27,  0,  2,  0 }, {    -25,   -9,   27,  0,  2,  0 }, {    -26,   -9,   28,  0,  2,  0 }, {    -27,   -9,   28,  0,  2,  0 }, {    -28,   -9,   29,  0,  2,  0 },
        {    -29,   -9,   29,  0,  2,  0 }, {    -30,   -9,   30,  0,  2,  0 }, {    -31,   -9,   30,  0,  2,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown0, {
        {     31,   23,   15,  0,  6,  0 }, {     30,   23,   15, 31,  6,  0 }, {     29,   23,   14, 31,  6,  0 }, {     28,   23,   14, 31,  6,  0 }, {     27,   23,   13, 31,  6,  0 },
        {     26,   23,   13, 31,  6,  0 }, {     25,   23,   13, 31,  6,  0 }, {     24,   23,   12, 31,  6,  0 }, {     23,   23,   12, 31,  6,  0 }, {     22,   23,   11, 31,  6,  0 },
        {     21,   23,   11, 31,  6,  0 }, {     20,   22,   10, 30,  6,  0 }, {     19,   22,   10, 30,  6,  0 }, {     18,   22,   10, 30,  6,  0 }, {     17,   22,    9, 30,  6,  0 },
        {     16,   21,    9, 30,  6,  0 }, {     15,   21,    8, 30,  6,  0 }, {     14,   21,    8, 30,  6,  0 }, {     13,   20,    8, 30,  6,  0 }, {     12,   20,    7, 30,  6,  0 },
        {     11,   20,    7, 30,  6,  0 }, {     10,   19,    6, 29,  6,  0 }, {      9,   19,    6, 29,  6,  0 }, {      8,   18,    6, 29,  6,  0 }, {      7,   18,    5, 29,  6,  0 },
        {      6,   17,    5, 29,  6,  0 }, {      5,   17,    4, 29,  6,  0 }, {      4,   16,    4, 29,  6,  0 }, {      3,   16,    4, 29,  6,  0 }, {      2,   15,    3, 29,  6,  0 },
        {      1,   15,    3, 29,  6,  0 }, {      0,   14,    2, 28,  6,  0 }, {     -1,   13,    2, 28,  6,  0 }, {     -2,   12,    1, 28,  6,  0 }, {     -3,   12,    1, 28,  6,  0 },
        {     -4,   11,    1, 28,  6,  0 }, {     -5,   10,    0, 28,  6,  0 }, {     -6,    9,    0, 28,  6,  0 }, {     -7,    8,   -1, 28,  6,  0 }, {     -8,    7,   -1, 27,  6,  0 },
        {     -9,    6,   -1, 27,  6,  0 }, {    -10,    5,   -2, 27,  6,  0 }, {    -11,    4,   -2, 27,  6,  0 }, {    -12,    3,   -3, 27,  6,  0 }, {    -12,    2,   -3, 27,  6,  0 },
        {    -13,    1,   -3, 27,  6,  0 }, {    -14,    0,   -4, 27,  6,  0 }, {    -15,   -1,   -4, 26,  6,  0 }, {    -15,   -2,   -5, 26,  6,  0 }, {    -16,   -3,   -5, 26,  6,  0 },
        {    -16,   -4,   -6, 26,  6,  0 }, {    -17,   -5,   -6, 26,  6,  0 }, {    -17,   -6,   -6, 26,  6,  0 }, {    -18,   -7,   -7, 26,  6,  0 }, {    -18,   -8,   -7, 26,  6,  0 },
        {    -19,   -9,   -8, 26,  6,  0 }, {    -19,  -10,   -8, 26,  6,  0 }, {    -20,  -11,   -8, 25,  6,  0 }, {    -20,  -12,   -9, 25,  6,  0 }, {    -20,  -13,   -9, 25,  6,  0 },
        {    -21,  -14,  -10, 25,  6,  0 }, {    -21,  -15,  -10, 25,  6,  0 }, {    -21,  -16,  -10, 25,  6,  0 }, {    -22,  -17,  -11, 25,  6,  0 }, {    -22,  -18,  -11, 25,  6,  0 },
        {    -22,  -19,  -12, 25,  6,  0 }, {    -22,  -20,  -12, 25,  6,  0 }, {    -23,  -21,  -12, 24,  6,  0 }, {    -23,  -22,  -13, 24,  6,  0 }, {    -23,  -23,  -13, 24,  6,  0 },
        {    -23,  -24,  -14, 24,  6,  0 }, {    -23,  -25,  -14, 24,  6,  0 }, {    -23,  -26,  -15, 24,  6,  0 }, {    -23,  -27,  -15, 24,  6,  0 }, {    -23,  -28,  -15, 24,  6,  0 },
        {    -23,  -29,  -16, 24,  6,  0 }, {    -23,  -30,  -16, 24,  6,  0 }, {    -23,  -31,  -17, 24,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown1, {
        {     23,    1,   15,  8,  6,  0 }, {     23,    2,   15,  7,  6,  0 }, {     23,    3,   14,  7,  6,  0 }, {     23,    4,   14,  7,  6,  0 }, {     23,    5,   13,  7,  6,  0 },
        {     23,    6,   13,  7,  6,  0 }, {     23,    7,   13,  7,  6,  0 }, {     23,    8,   12,  7,  6,  0 }, {     23,    9,   12,  7,  6,  0 }, {     23,   10,   11,  7,  6,  0 },
        {     23,   11,   11,  7,  6,  0 }, {     22,   12,   10,  6,  6,  0 }, {     22,   13,   10,  6,  6,  0 }, {     22,   14,   10,  6,  6,  0 }, {     22,   15,    9,  6,  6,  0 },
        {     21,   16,    9,  6,  6,  0 }, {     21,   17,    8,  6,  6,  0 }, {     21,   18,    8,  6,  6,  0 }, {     20,   19,    8,  6,  6,  0 }, {     20,   20,    7,  6,  6,  0 },
        {     20,   21,    7,  6,  6,  0 }, {     19,   22,    6,  5,  6,  0 }, {     19,   23,    6,  5,  6,  0 }, {     18,   24,    6,  5,  6,  0 }, {     18,   25,    5,  5,  6,  0 },
        {     17,   26,    5,  5,  6,  0 }, {     17,   27,    4,  5,  6,  0 }, {     16,   28,    4,  5,  6,  0 }, {     16,   29,    4,  5,  6,  0 }, {     15,   30,    3,  5,  6,  0 },
        {     15,   31,    3,  5,  6,  0 }, {     14,   32,    2,  4,  6,  0 }, {     13,   33,    2,  4,  6,  0 }, {     12,   34,    1,  4,  6,  0 }, {     12,   35,    1,  4,  6,  0 },
        {     11,   36,    1,  4,  6,  0 }, {     10,   37,    0,  4,  6,  0 }, {      9,   38,    0,  4,  6,  0 }, {      8,   39,   -1,  4,  6,  0 }, {      7,   40,   -1,  3,  6,  0 },
        {      6,   41,   -1,  3,  6,  0 }, {      5,   42,   -2,  3,  6,  0 }, {      4,   43,   -2,  3,  6,  0 }, {      3,   44,   -3,  3,  6,  0 }, {      2,   44,   -3,  3,  6,  0 },
        {      1,   45,   -3,  3,  6,  0 }, {      0,   46,   -4,  3,  6,  0 }, {     -1,   47,   -4,  2,  6,  0 }, {     -2,   47,   -5,  2,  6,  0 }, {     -3,   48,   -5,  2,  6,  0 },
        {     -4,   48,   -6,  2,  6,  0 }, {     -5,   49,   -6,  2,  6,  0 }, {     -6,   49,   -6,  2,  6,  0 }, {     -7,   50,   -7,  2,  6,  0 }, {     -8,   50,   -7,  2,  6,  0 },
        {     -9,   51,   -8,  2,  6,  0 }, {    -10,   51,   -8,  2,  6,  0 }, {    -11,   52,   -8,  1,  6,  0 }, {    -12,   52,   -9,  1,  6,  0 }, {    -13,   52,   -9,  1,  6,  0 },
        {    -14,   53,  -10,  1,  6,  0 }, {    -15,   53,  -10,  1,  6,  0 }, {    -16,   53,  -10,  1,  6,  0 }, {    -17,   54,  -11,  1,  6,  0 }, {    -18,   54,  -11,  1,  6,  0 },
        {    -19,   54,  -12,  1,  6,  0 }, {    -20,   54,  -12,  1,  6,  0 }, {    -21,   55,  -12,  0,  6,  0 }, {    -22,   55,  -13,  0,  6,  0 }, {    -23,   55,  -13,  0,  6,  0 },
        {    -24,   55,  -14,  0,  6,  0 }, {    -25,   55,  -14,  0,  6,  0 }, {    -26,   55,  -15,  0,  6,  0 }, {    -27,   55,  -15,  0,  6,  0 }, {    -28,   55,  -15,  0,  6,  0 },
        {    -29,   55,  -16,  0,  6,  0 }, {    -30,   55,  -16,  0,  6,  0 }, {    -31,   55,  -17,  0,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown2, {
        {      1,    9,   15, 16,  6,  0 }, {      2,    9,   15, 15,  6,  0 }, {      3,    9,   14, 15,  6,  0 }, {      4,    9,   14, 15,  6,  0 }, {      5,    9,   13, 15,  6,  0 },
        {      6,    9,   13, 15,  6,  0 }, {      7,    9,   13, 15,  6,  0 }, {      8,    9,   12, 15,  6,  0 }, {      9,    9,   12, 15,  6,  0 }, {     10,    9,   11, 15,  6,  0 },
        {     11,    9,   11, 15,  6,  0 }, {     12,   10,   10, 14,  6,  0 }, {     13,   10,   10, 14,  6,  0 }, {     14,   10,   10, 14,  6,  0 }, {     15,   10,    9, 14,  6,  0 },
        {     16,   11,    9, 14,  6,  0 }, {     17,   11,    8, 14,  6,  0 }, {     18,   11,    8, 14,  6,  0 }, {     19,   12,    8, 14,  6,  0 }, {     20,   12,    7, 14,  6,  0 },
        {     21,   12,    7, 14,  6,  0 }, {     22,   13,    6, 13,  6,  0 }, {     23,   13,    6, 13,  6,  0 }, {     24,   14,    6, 13,  6,  0 }, {     25,   14,    5, 13,  6,  0 },
        {     26,   15,    5, 13,  6,  0 }, {     27,   15,    4, 13,  6,  0 }, {     28,   16,    4, 13,  6,  0 }, {     29,   16,    4, 13,  6,  0 }, {     30,   17,    3, 13,  6,  0 },
        {     31,   17,    3, 13,  6,  0 }, {     32,   18,    2, 12,  6,  0 }, {     33,   19,    2, 12,  6,  0 }, {     34,   20,    1, 12,  6,  0 }, {     35,   20,    1, 12,  6,  0 },
        {     36,   21,    1, 12,  6,  0 }, {     37,   22,    0, 12,  6,  0 }, {     38,   23,    0, 12,  6,  0 }, {     39,   24,   -1, 12,  6,  0 }, {     40,   25,   -1, 11,  6,  0 },
        {     41,   26,   -1, 11,  6,  0 }, {     42,   27,   -2, 11,  6,  0 }, {     43,   28,   -2, 11,  6,  0 }, {     44,   29,   -3, 11,  6,  0 }, {     44,   30,   -3, 11,  6,  0 },
        {     45,   31,   -3, 11,  6,  0 }, {     46,   32,   -4, 11,  6,  0 }, {     47,   33,   -4, 10,  6,  0 }, {     47,   34,   -5, 10,  6,  0 }, {     48,   35,   -5, 10,  6,  0 },
        {     48,   36,   -6, 10,  6,  0 }, {     49,   37,   -6, 10,  6,  0 }, {     49,   38,   -6, 10,  6,  0 }, {     50,   39,   -7, 10,  6,  0 }, {     50,   40,   -7, 10,  6,  0 },
        {     51,   41,   -8, 10,  6,  0 }, {     51,   42,   -8, 10,  6,  0 }, {     52,   43,   -8,  9,  6,  0 }, {     52,   44,   -9,  9,  6,  0 }, {     52,   45,   -9,  9,  6,  0 },
        {     53,   46,  -10,  9,  6,  0 }, {     53,   47,  -10,  9,  6,  0 }, {     53,   48,  -10,  9,  6,  0 }, {     54,   49,  -11,  9,  6,  0 }, {     54,   50,  -11,  9,  6,  0 },
        {     54,   51,  -12,  9,  6,  0 }, {     54,   52,  -12,  9,  6,  0 }, {     55,   53,  -12,  8,  6,  0 }, {     55,   54,  -13,  8,  6,  0 }, {     55,   55,  -13,  8,  6,  0 },
        {     55,   56,  -14,  8,  6,  0 }, {     55,   57,  -14,  8,  6,  0 }, {     55,   58,  -15,  8,  6,  0 }, {     55,   59,  -15,  8,  6,  0 }, {     55,   60,  -15,  8,  6,  0 },
        {     55,   61,  -16,  8,  6,  0 }, {     55,   62,  -16,  8,  6,  0 }, {     55,   63,  -17,  8,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown3, {
        {      9,   31,   15, 24,  6,  0 }, {      9,   30,   15, 23,  6,  0 }, {      9,   29,   14, 23,  6,  0 }, {      9,   28,   14, 23,  6,  0 }, {      9,   27,   13, 23,  6,  0 },
        {      9,   26,   13, 23,  6,  0 }, {      9,   25,   13, 23,  6,  0 }, {      9,   24,   12, 23,  6,  0 }, {      9,   23,   12, 23,  6,  0 }, {      9,   22,   11, 23,  6,  0 },
        {      9,   21,   11, 23,  6,  0 }, {     10,   20,   10, 22,  6,  0 }, {     10,   19,   10, 22,  6,  0 }, {     10,   18,   10, 22,  6,  0 }, {     10,   17,    9, 22,  6,  0 },
        {     11,   16,    9, 22,  6,  0 }, {     11,   15,    8, 22,  6,  0 }, {     11,   14,    8, 22,  6,  0 }, {     12,   13,    8, 22,  6,  0 }, {     12,   12,    7, 22,  6,  0 },
        {     12,   11,    7, 22,  6,  0 }, {     13,   10,    6, 21,  6,  0 }, {     13,    9,    6, 21,  6,  0 }, {     14,    8,    6, 21,  6,  0 }, {     14,    7,    5, 21,  6,  0 },
        {     15,    6,    5, 21,  6,  0 }, {     15,    5,    4, 21,  6,  0 }, {     16,    4,    4, 21,  6,  0 }, {     16,    3,    4, 21,  6,  0 }, {     17,    2,    3, 21,  6,  0 },
        {     17,    1,    3, 21,  6,  0 }, {     18,    0,    2, 20,  6,  0 }, {     19,   -1,    2, 20,  6,  0 }, {     20,   -2,    1, 20,  6,  0 }, {     20,   -3,    1, 20,  6,  0 },
        {     21,   -4,    1, 20,  6,  0 }, {     22,   -5,    0, 20,  6,  0 }, {     23,   -6,    0, 20,  6,  0 }, {     24,   -7,   -1, 20,  6,  0 }, {     25,   -8,   -1, 19,  6,  0 },
        {     26,   -9,   -1, 19,  6,  0 }, {     27,  -10,   -2, 19,  6,  0 }, {     28,  -11,   -2, 19,  6,  0 }, {     29,  -12,   -3, 19,  6,  0 }, {     30,  -12,   -3, 19,  6,  0 },
        {     31,  -13,   -3, 19,  6,  0 }, {     32,  -14,   -4, 19,  6,  0 }, {     33,  -15,   -4, 18,  6,  0 }, {     34,  -15,   -5, 18,  6,  0 }, {     35,  -16,   -5, 18,  6,  0 },
        {     36,  -16,   -6, 18,  6,  0 }, {     37,  -17,   -6, 18,  6,  0 }, {     38,  -17,   -6, 18,  6,  0 }, {     39,  -18,   -7, 18,  6,  0 }, {     40,  -18,   -7, 18,  6,  0 },
        {     41,  -19,   -8, 18,  6,  0 }, {     42,  -19,   -8, 18,  6,  0 }, {     43,  -20,   -8, 17,  6,  0 }, {     44,  -20,   -9, 17,  6,  0 }, {     45,  -20,   -9, 17,  6,  0 },
        {     46,  -21,  -10, 17,  6,  0 }, {     47,  -21,  -10, 17,  6,  0 }, {     48,  -21,  -10, 17,  6,  0 }, {     49,  -22,  -11, 17,  6,  0 }, {     50,  -22,  -11, 17,  6,  0 },
        {     51,  -22,  -12, 17,  6,  0 }, {     52,  -22,  -12, 17,  6,  0 }, {     53,  -23,  -12, 16,  6,  0 }, {     54,  -23,  -13, 16,  6,  0 }, {     55,  -23,  -13, 16,  6,  0 },
        {     56,  -23,  -14, 16,  6,  0 }, {     57,  -23,  -14, 16,  6,  0 }, {     58,  -23,  -15, 16,  6,  0 }, {     59,  -23,  -15, 16,  6,  0 }, {     60,  -23,  -15, 16,  6,  0 },
        {     61,  -23,  -16, 16,  6,  0 }, {     62,  -23,  -16, 16,  6,  0 }, {     63,  -23,  -17, 16,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegDown0, {
        {     31,   23,   15,  0,  6,  0 }, {     30,   23,   14,  1,  6,  0 }, {     29,   23,   14,  1,  6,  0 }, {     28,   23,   13,  1,  6,  0 }, {     27,   23,   13,  1,  6,  0 },
        {     26,   23,   12,  1,  6,  0 }, {     25,   23,   12,  1,  6,  0 }, {     24,   23,   11,  1,  6,  0 }, {     23,   23,   11,  2,  6,  0 }, {     22,   24,   10,  2,  6,  0 },
        {     21,   24,    9,  2,  6,  0 }, {     20,   24,    9,  2,  6,  0 }, {     19,   24,    8,  2,  6,  0 }, {     18,   25,    8,  2,  6,  0 }, {     17,   25,    7,  2,  6,  0 },
        {     16,   25,    7,  2,  6,  0 }, {     15,   26,    6,  3,  6,  0 }, {     14,   26,    6,  3,  6,  0 }, {     13,   27,    5,  3,  6,  0 }, {     12,   27,    5,  3,  6,  0 },
        {     11,   28,    4,  3,  6,  0 }, {     10,   28,    3,  3,  6,  0 }, {      9,   29,    3,  3,  6,  0 }, {      8,   30,    2,  4,  6,  0 }, {      7,   30,    2,  4,  6,  0 },
        {      6,   31,    1,  4,  6,  0 }, {      5,   32,    1,  4,  6,  0 }, {      4,   33,    0,  4,  6,  0 }, {      3,   34,    0,  4,  6,  0 }, {      2,   35,   -1,  5,  6,  0 },
        {      1,   36,   -2,  5,  6,  0 }, {      0,   37,   -2,  5,  6,  0 }, {     -1,   38,   -3,  5,  6,  0 }, {     -2,   39,   -3,  5,  6,  0 }, {     -2,   40,   -4,  5,  6,  0 },
        {     -3,   41,   -4,  6,  6,  0 }, {     -4,   42,   -5,  6,  6,  0 }, {     -4,   43,   -5,  6,  6,  0 }, {     -5,   44,   -6,  6,  6,  0 }, {     -5,   45,   -7,  6,  6,  0 },
        {     -6,   46,   -7,  6,  6,  0 }, {     -6,   47,   -8,  6,  6,  0 }, {     -7,   48,   -8,  7,  6,  0 }, {     -7,   49,   -9,  7,  6,  0 }, {     -7,   50,   -9,  7,  6,  0 },
        {     -8,   51,  -10,  7,  6,  0 }, {     -8,   52,  -10,  7,  6,  0 }, {     -8,   53,  -11,  7,  6,  0 }, {     -8,   54,  -11,  7,  6,  0 }, {     -9,   55,  -12,  7,  6,  0 },
        {     -9,   56,  -13,  8,  6,  0 }, {     -9,   57,  -13,  8,  6,  0 }, {     -9,   58,  -14,  8,  6,  0 }, {     -9,   59,  -14,  8,  6,  0 }, {     -9,   60,  -15,  8,  6,  0 },
        {     -9,   61,  -15,  8,  6,  0 }, {     -9,   62,  -16,  8,  6,  0 }, {     -9,   63,  -16,  8,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegDown1, {
        {     23,    1,   15,  8,  6,  0 }, {     23,    2,   14,  9,  6,  0 }, {     23,    3,   14,  9,  6,  0 }, {     23,    4,   13,  9,  6,  0 }, {     23,    5,   13,  9,  6,  0 },
        {     23,    6,   12,  9,  6,  0 }, {     23,    7,   12,  9,  6,  0 }, {     23,    8,   11,  9,  6,  0 }, {     23,    9,   11, 10,  6,  0 }, {     24,   10,   10, 10,  6,  0 },
        {     24,   11,    9, 10,  6,  0 }, {     24,   12,    9, 10,  6,  0 }, {     24,   13,    8, 10,  6,  0 }, {     25,   14,    8, 10,  6,  0 }, {     25,   15,    7, 10,  6,  0 },
        {     25,   16,    7, 10,  6,  0 }, {     26,   17,    6, 11,  6,  0 }, {     26,   18,    6, 11,  6,  0 }, {     27,   19,    5, 11,  6,  0 }, {     27,   20,    5, 11,  6,  0 },
        {     28,   21,    4, 11,  6,  0 }, {     28,   22,    3, 11,  6,  0 }, {     29,   23,    3, 11,  6,  0 }, {     30,   24,    2, 12,  6,  0 }, {     30,   25,    2, 12,  6,  0 },
        {     31,   26,    1, 12,  6,  0 }, {     32,   27,    1, 12,  6,  0 }, {     33,   28,    0, 12,  6,  0 }, {     34,   29,    0, 12,  6,  0 }, {     35,   30,   -1, 13,  6,  0 },
        {     36,   31,   -2, 13,  6,  0 }, {     37,   32,   -2, 13,  6,  0 }, {     38,   33,   -3, 13,  6,  0 }, {     39,   34,   -3, 13,  6,  0 }, {     40,   34,   -4, 13,  6,  0 },
        {     41,   35,   -4, 14,  6,  0 }, {     42,   36,   -5, 14,  6,  0 }, {     43,   36,   -5, 14,  6,  0 }, {     44,   37,   -6, 14,  6,  0 }, {     45,   37,   -7, 14,  6,  0 },
        {     46,   38,   -7, 14,  6,  0 }, {     47,   38,   -8, 14,  6,  0 }, {     48,   39,   -8, 15,  6,  0 }, {     49,   39,   -9, 15,  6,  0 }, {     50,   39,   -9, 15,  6,  0 },
        {     51,   40,  -10, 15,  6,  0 }, {     52,   40,  -10, 15,  6,  0 }, {     53,   40,  -11, 15,  6,  0 }, {     54,   40,  -11, 15,  6,  0 }, {     55,   41,  -12, 15,  6,  0 },
        {     56,   41,  -13, 16,  6,  0 }, {     57,   41,  -13, 16,  6,  0 }, {     58,   41,  -14, 16,  6,  0 }, {     59,   41,  -14, 16,  6,  0 }, {     60,   41,  -15, 16,  6,  0 },
        {     61,   41,  -15, 16,  6,  0 }, {     62,   41,  -16, 16,  6,  0 }, {     63,   41,  -16, 16,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegDown2, {
        {      1,    9,   15, 16,  6,  0 }, {      2,    9,   14, 17,  6,  0 }, {      3,    9,   14, 17,  6,  0 }, {      4,    9,   13, 17,  6,  0 }, {      5,    9,   13, 17,  6,  0 },
        {      6,    9,   12, 17,  6,  0 }, {      7,    9,   12, 17,  6,  0 }, {      8,    9,   11, 17,  6,  0 }, {      9,    9,   11, 18,  6,  0 }, {     10,    8,   10, 18,  6,  0 },
        {     11,    8,    9, 18,  6,  0 }, {     12,    8,    9, 18,  6,  0 }, {     13,    8,    8, 18,  6,  0 }, {     14,    7,    8, 18,  6,  0 }, {     15,    7,    7, 18,  6,  0 },
        {     16,    7,    7, 18,  6,  0 }, {     17,    6,    6, 19,  6,  0 }, {     18,    6,    6, 19,  6,  0 }, {     19,    5,    5, 19,  6,  0 }, {     20,    5,    5, 19,  6,  0 },
        {     21,    4,    4, 19,  6,  0 }, {     22,    4,    3, 19,  6,  0 }, {     23,    3,    3, 19,  6,  0 }, {     24,    2,    2, 20,  6,  0 }, {     25,    2,    2, 20,  6,  0 },
        {     26,    1,    1, 20,  6,  0 }, {     27,    0,    1, 20,  6,  0 }, {     28,   -1,    0, 20,  6,  0 }, {     29,   -2,    0, 20,  6,  0 }, {     30,   -3,   -1, 21,  6,  0 },
        {     31,   -4,   -2, 21,  6,  0 }, {     32,   -5,   -2, 21,  6,  0 }, {     33,   -6,   -3, 21,  6,  0 }, {     34,   -7,   -3, 21,  6,  0 }, {     34,   -8,   -4, 21,  6,  0 },
        {     35,   -9,   -4, 22,  6,  0 }, {     36,  -10,   -5, 22,  6,  0 }, {     36,  -11,   -5, 22,  6,  0 }, {     37,  -12,   -6, 22,  6,  0 }, {     37,  -13,   -7, 22,  6,  0 },
        {     38,  -14,   -7, 22,  6,  0 }, {     38,  -15,   -8, 22,  6,  0 }, {     39,  -16,   -8, 23,  6,  0 }, {     39,  -17,   -9, 23,  6,  0 }, {     39,  -18,   -9, 23,  6,  0 },
        {     40,  -19,  -10, 23,  6,  0 }, {     40,  -20,  -10, 23,  6,  0 }, {     40,  -21,  -11, 23,  6,  0 }, {     40,  -22,  -11, 23,  6,  0 }, {     41,  -23,  -12, 23,  6,  0 },
        {     41,  -24,  -13, 24,  6,  0 }, {     41,  -25,  -13, 24,  6,  0 }, {     41,  -26,  -14, 24,  6,  0 }, {     41,  -27,  -14, 24,  6,  0 }, {     41,  -28,  -15, 24,  6,  0 },
        {     41,  -29,  -15, 24,  6,  0 }, {     41,  -30,  -16, 24,  6,  0 }, {     41,  -31,  -16, 24,  6,  0 },
    })

    CREATE_VEHICLE_INFO(TrackVehicleInfoRightQuarterTurn3Tiles25DegDown3, {
        {      9,   31,   15, 24,  6,  0 }, {      9,   30,   14, 25,  6,  0 }, {      9,   29,   14, 25,  6,  0 }, {      9,   28,   13, 25,  6,  0 }, {      9,   27,   13, 25,  6,  0 },
        {      9,   26,   12, 25,  6,  0 }, {      9,   25,   12, 25,  6,  0 }, {      9,   24,   11, 25,  6,  0 }, {      9,   23,   11, 26,  6,  0 }, {      8,   22,   10, 26,  6,  0 },
        {      8,   21,    9, 26,  6,  0 }, {      8,   20,    9, 26,  6,  0 }, {      8,   19,    8, 26,  6,  0 }, {      7,   18,    8, 26,  6,  0 }, {      7,   17,    7, 26,  6,  0 },
        {      7,   16,    7, 26,  6,  0 }, {      6,   15,    6, 27,  6,  0 }, {      6,   14,    6, 27,  6,  0 }, {      5,   13,    5, 27,  6,  0 }, {      5,   12,    5, 27,  6,  0 },
        {      4,   11,    4, 27,  6,  0 }, {      4,   10,    3, 27,  6,  0 }, {      3,    9,    3, 27,  6,  0 }, {      2,    8,    2, 28,  6,  0 }, {      2,    7,    2, 28,  6,  0 },
        {      1,    6,    1, 28,  6,  0 }, {      0,    5,    1, 28,  6,  0 }, {     -1,    4,    0, 28,  6,  0 }, {     -2,    3,    0, 28,  6,  0 }, {     -3,    2,   -1, 29,  6,  0 },
        {     -4,    1,   -2, 29,  6,  0 }, {     -5,    0,   -2, 29,  6,  0 }, {     -6,   -1,   -3, 29,  6,  0 }, {     -7,   -2,   -3, 29,  6,  0 }, {     -8,   -2,   -4, 29,  6,  0 },
        {     -9,   -3,   -4, 30,  6,  0 }, {    -10,   -4,   -5, 30,  6,  0 }, {    -11,   -4,   -5, 30,  6,  0 }, {    -12,   -5,   -6, 30,  6,  0 }, {    -13,   -5,   -7, 30,  6,  0 },
        {    -14,   -6,   -7, 30,  6,  0 }, {    -15,   -6,   -8, 30,  6,  0 }, {    -16,   -7,   -8, 31,  6,  0 }, {    -17,   -7,   -9, 31,  6,  0 }, {    -18,   -7,   -9, 31,  6,  0 },
        {    -19,   -8,  -10, 31,  6,  0 }, {    -20,   -8,  -10, 31,  6,  0 }, {    -21,   -8,  -11, 31,  6,  0 }, {    -22,   -8,  -11, 31,  6,  0 }, {    -23,   -9,  -12, 31,  6,  0 },
        {    -24,   -9,  -13,  0,  6,  0 }, {    -25,   -9,  -13,  0,  6,  0 }, {    -26,   -9,  -14,  0,  6,  0 }, {    -27,   -9,  -14,  0,  6,  0 }, {    -28,   -9,  -15,  0,  6,  0 },
        {    -29,   -9,  -15,  0,  6,  0 }, {    -30,   -9,  -16,  0,  6,  0 }, {    -31,   -9,  -16,  0,  6,  0 },
    })
}

CREATE_VEHICLE_INFO(TrackVehicleInfo_000000, { { 0, 0, 0, 0, 0, 0 } })

static constexpr const VehicleInfoList *TrackVehicleInfoListDefault[] = {
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // Flat
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // EndStation
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // BeginStation
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // MiddleStation
    &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C, &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690,  // Up25
    &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554, &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8,  // Up60
    &TrackVehicleInfo_8BFC1A, &TrackVehicleInfo_8BFD3C, &TrackVehicleInfo_8BFE5E, &TrackVehicleInfo_8BFF80,  // FlatToUp25
    &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89, &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227,  // Up25ToUp60
    &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5, &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763,  // Up60ToUp25
    &TrackVehicleInfo_8C00A2, &TrackVehicleInfo_8C01C4, &TrackVehicleInfo_8C02E6, &TrackVehicleInfo_8C0408,  // Up25ToFlat
    &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4, &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18,  // Down25
    &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C, &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300,  // Down60
    &TrackVehicleInfo_8C09B2, &TrackVehicleInfo_8C0AD4, &TrackVehicleInfo_8C0BF6, &TrackVehicleInfo_8C0D18,  // FlatToDown25
    &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D, &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB,  // Down25ToDown60
    &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01, &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F,  // Down60ToDown25
    &TrackVehicleInfo_8C052A, &TrackVehicleInfo_8C064C, &TrackVehicleInfo_8C076E, &TrackVehicleInfo_8C0890,  // Down25ToFlat
    &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496, &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7,  // LeftQuarterTurn5Tiles
    &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D, &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE,  // RightQuarterTurn5Tiles
    &TrackVehicleInfo_8C3542, &TrackVehicleInfo_8C3664, &TrackVehicleInfo_8C3786, &TrackVehicleInfo_8C38A8,  // FlatToLeftBank
    &TrackVehicleInfo_8C39CA, &TrackVehicleInfo_8C3AEC, &TrackVehicleInfo_8C3C0E, &TrackVehicleInfo_8C3D30,  // FlatToRightBank
    &TrackVehicleInfo_8C3E52, &TrackVehicleInfo_8C3F74, &TrackVehicleInfo_8C4096, &TrackVehicleInfo_8C41B8,  // LeftBankToFlat
    &TrackVehicleInfo_8C42DA, &TrackVehicleInfo_8C43FC, &TrackVehicleInfo_8C451E, &TrackVehicleInfo_8C4640,  // RightBankToFlat
    &TrackVehicleInfo_8CA0B2, &TrackVehicleInfo_8CA4B6, &TrackVehicleInfo_8CA8C3, &TrackVehicleInfo_8CACC7,  // BankedLeftQuarterTurn5Tiles
    &TrackVehicleInfo_8CB0C2, &TrackVehicleInfo_8CB4BD, &TrackVehicleInfo_8CB8C1, &TrackVehicleInfo_8CBCCE,  // BankedRightQuarterTurn5Tiles
    &TrackVehicleInfo_8C4762, &TrackVehicleInfo_8C4884, &TrackVehicleInfo_8C49A6, &TrackVehicleInfo_8C4AC8,  // LeftBankToUp25
    &TrackVehicleInfo_8C4BEA, &TrackVehicleInfo_8C4D0C, &TrackVehicleInfo_8C4E2E, &TrackVehicleInfo_8C4F50,  // RightBankToUp25
    &TrackVehicleInfo_8C5072, &TrackVehicleInfo_8C51A6, &TrackVehicleInfo_8C52DA, &TrackVehicleInfo_8C540E,  // Up25ToLeftBank
    &TrackVehicleInfo_8C5542, &TrackVehicleInfo_8C5676, &TrackVehicleInfo_8C57AA, &TrackVehicleInfo_8C58DE,  // Up25ToRightBank
    &TrackVehicleInfo_8C6322, &TrackVehicleInfo_8C6444, &TrackVehicleInfo_8C6566, &TrackVehicleInfo_8C6688,  // LeftBankToDown25
    &TrackVehicleInfo_8C67AA, &TrackVehicleInfo_8C68CC, &TrackVehicleInfo_8C69EE, &TrackVehicleInfo_8C6B10,  // RightBankToDown25
    &TrackVehicleInfo_8C5A12, &TrackVehicleInfo_8C5B34, &TrackVehicleInfo_8C5C56, &TrackVehicleInfo_8C5D78,  // Down25ToLeftBank
    &TrackVehicleInfo_8C5E9A, &TrackVehicleInfo_8C5FBC, &TrackVehicleInfo_8C60DE, &TrackVehicleInfo_8C6200,  // Down25ToRightBank
    &TrackVehicleInfo_8BEA02, &TrackVehicleInfo_8BEB24, &TrackVehicleInfo_8BEC46, &TrackVehicleInfo_8BED68,  // LeftBank
    &TrackVehicleInfo_8BEE8A, &TrackVehicleInfo_8BEFAC, &TrackVehicleInfo_8BF0CE, &TrackVehicleInfo_8BF1F0,  // RightBank
    &TrackVehicleInfo_8D047E, &TrackVehicleInfo_8D0882, &TrackVehicleInfo_8D0C8F, &TrackVehicleInfo_8D1093,  // LeftQuarterTurn5TilesUp25
    &TrackVehicleInfo_8D148E, &TrackVehicleInfo_8D1889, &TrackVehicleInfo_8D1C8D, &TrackVehicleInfo_8D209A,  // RightQuarterTurn5TilesUp25
    &TrackVehicleInfo_8D249E, &TrackVehicleInfo_8D28A2, &TrackVehicleInfo_8D2CAF, &TrackVehicleInfo_8D30B3,  // LeftQuarterTurn5TilesDown25
    &TrackVehicleInfo_8D34AE, &TrackVehicleInfo_8D38A9, &TrackVehicleInfo_8D3CAD, &TrackVehicleInfo_8D40BA,  // RightQuarterTurn5TilesDown25
    &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,  // SBendLeft
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880,  // SBendRight
    &TrackVehicleInfo_8D44BE, &TrackVehicleInfo_8D4FA6, &TrackVehicleInfo_8D5A8E, &TrackVehicleInfo_8D6576,  // LeftVerticalLoop
    &TrackVehicleInfo_8D705E, &TrackVehicleInfo_8D7B46, &TrackVehicleInfo_8D862E, &TrackVehicleInfo_8D9116,  // RightVerticalLoop
    &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94, &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469,  // LeftQuarterTurn3Tiles
    &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923, &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8,  // RightQuarterTurn3Tiles
    &TrackVehicleInfo_8E005E, &TrackVehicleInfo_8E02C4, &TrackVehicleInfo_8E0533, &TrackVehicleInfo_8E0799,  // LeftBankedQuarterTurn3Tiles
    &TrackVehicleInfo_8E09F6, &TrackVehicleInfo_8E0C53, &TrackVehicleInfo_8E0EB9, &TrackVehicleInfo_8E1128,  // RightBankedQuarterTurn3Tiles
    &TrackVehicleInfo_8E26BE, &TrackVehicleInfo_8E2924, &TrackVehicleInfo_8E2B93, &TrackVehicleInfo_8E2DF9,  // LeftQuarterTurn3TilesUp25
    &TrackVehicleInfo_8E3056, &TrackVehicleInfo_8E32B3, &TrackVehicleInfo_8E3519, &TrackVehicleInfo_8E3788,  // RightQuarterTurn3TilesUp25
    &TrackVehicleInfo_8E138E, &TrackVehicleInfo_8E15F4, &TrackVehicleInfo_8E1863, &TrackVehicleInfo_8E1AC9,  // LeftQuarterTurn3TilesDown25
    &TrackVehicleInfo_8E1D26, &TrackVehicleInfo_8E1F83, &TrackVehicleInfo_8E21E9, &TrackVehicleInfo_8E2458,  // RightQuarterTurn3TilesDown25
    &TrackVehicleInfo_8E39EE, &TrackVehicleInfo_8E3AB6, &TrackVehicleInfo_8E3B87, &TrackVehicleInfo_8E3C4F,  // LeftQuarterTurn1Tile
    &TrackVehicleInfo_8E3D0E, &TrackVehicleInfo_8E3DCD, &TrackVehicleInfo_8E3E95, &TrackVehicleInfo_8E3F66,  // RightQuarterTurn1Tile
    &TrackVehicleInfo_8D9BFE, &TrackVehicleInfo_8D9F60, &TrackVehicleInfo_8DA2C2, &TrackVehicleInfo_8DA624,  // LeftTwistDownToUp
    &TrackVehicleInfo_8DA986, &TrackVehicleInfo_8DACE8, &TrackVehicleInfo_8DB04A, &TrackVehicleInfo_8DB3AC,  // RightTwistDownToUp
    &TrackVehicleInfo_8DB70E, &TrackVehicleInfo_8DBA70, &TrackVehicleInfo_8DBDD2, &TrackVehicleInfo_8DC134,  // LeftTwistUpToDown
    &TrackVehicleInfo_8DC496, &TrackVehicleInfo_8DC7F8, &TrackVehicleInfo_8DCB5A, &TrackVehicleInfo_8DCEBC,  // RightTwistUpToDown
    &TrackVehicleInfo_8E644E, &TrackVehicleInfo_8E69F9, &TrackVehicleInfo_8E6FA4, &TrackVehicleInfo_8E754F,  // HalfLoopUp
    &TrackVehicleInfo_8E7AFA, &TrackVehicleInfo_8E80A5, &TrackVehicleInfo_8E8650, &TrackVehicleInfo_8E8BFB,  // HalfLoopDown
    &TrackVehicleInfo_8EA852, &TrackVehicleInfo_8EABBD, &TrackVehicleInfo_8EAF28, &TrackVehicleInfo_8EB293,  // LeftCorkscrewUp
    &TrackVehicleInfo_8EB5FE, &TrackVehicleInfo_8EB969, &TrackVehicleInfo_8EBCD4, &TrackVehicleInfo_8EC03F,  // RightCorkscrewUp
    &TrackVehicleInfo_8EC3AA, &TrackVehicleInfo_8EC715, &TrackVehicleInfo_8ECA80, &TrackVehicleInfo_8ECDEB,  // LeftCorkscrewDown
    &TrackVehicleInfo_8ED156, &TrackVehicleInfo_8ED4C1, &TrackVehicleInfo_8ED82C, &TrackVehicleInfo_8EDB97,  // RightCorkscrewDown
    &TrackVehicleInfo_8C6C32, &TrackVehicleInfo_8C6D78, &TrackVehicleInfo_8C6EBE, &TrackVehicleInfo_8C7004,  // FlatToUp60
    &TrackVehicleInfo_8C714A, &TrackVehicleInfo_8C7290, &TrackVehicleInfo_8C73D6, &TrackVehicleInfo_8C751C,  // Up60ToFlat
    &TrackVehicleInfo_8C7662, &TrackVehicleInfo_8C77A8, &TrackVehicleInfo_8C78EE, &TrackVehicleInfo_8C7A34,  // FlatToDown60
    &TrackVehicleInfo_8C7B7A, &TrackVehicleInfo_8C7CC0, &TrackVehicleInfo_8C7E06, &TrackVehicleInfo_8C7F4C,  // Down60ToFlat
    &TrackVehicleInfo_8EFA5A, &TrackVehicleInfo_8EFDAA, &TrackVehicleInfo_8F00FA, &TrackVehicleInfo_8F044A,  // TowerBase
    &TrackVehicleInfo_8F079A, &TrackVehicleInfo_8F08BC, &TrackVehicleInfo_8F09DE, &TrackVehicleInfo_8F0B00,  // TowerSection
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // FlatCovered
    &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C, &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690,  // Up25Covered
    &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554, &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8,  // Up60Covered
    &TrackVehicleInfo_8BFC1A, &TrackVehicleInfo_8BFD3C, &TrackVehicleInfo_8BFE5E, &TrackVehicleInfo_8BFF80,  // FlatToUp25Covered
    &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89, &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227,  // Up25ToUp60Covered
    &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5, &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763,  // Up60ToUp25Covered
    &TrackVehicleInfo_8C00A2, &TrackVehicleInfo_8C01C4, &TrackVehicleInfo_8C02E6, &TrackVehicleInfo_8C0408,  // Up25ToFlatCovered
    &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4, &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18,  // Down25Covered
    &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C, &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300,  // Down60Covered
    &TrackVehicleInfo_8C09B2, &TrackVehicleInfo_8C0AD4, &TrackVehicleInfo_8C0BF6, &TrackVehicleInfo_8C0D18,  // FlatToDown25Covered
    &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D, &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB,  // Down25ToDown60Covered
    &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01, &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F,  // Down60ToDown25Covered
    &TrackVehicleInfo_8C052A, &TrackVehicleInfo_8C064C, &TrackVehicleInfo_8C076E, &TrackVehicleInfo_8C0890,  // Down25ToFlatCovered
    &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496, &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7,  // LeftQuarterTurn5TilesCovered
    &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D, &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE,  // RightQuarterTurn5TilesCovered
    &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,  // SBendLeftCovered
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880,  // SBendRightCovered
    &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94, &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469,  // LeftQuarterTurn3TilesCovered
    &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923, &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8,  // RightQuarterTurn3TilesCovered
    &TrackVehicleInfo_8F8C82, &TrackVehicleInfo_8F9143, &TrackVehicleInfo_8F9616, &TrackVehicleInfo_8F9AE9,  // LeftHalfBankedHelixUpSmall
    &TrackVehicleInfo_8F9FAA, &TrackVehicleInfo_8FA46B, &TrackVehicleInfo_8FA93E, &TrackVehicleInfo_8FAE11,  // RightHalfBankedHelixUpSmall
    &TrackVehicleInfo_8FB2D2, &TrackVehicleInfo_8FB793, &TrackVehicleInfo_8FBC66, &TrackVehicleInfo_8FC139,  // LeftHalfBankedHelixDownSmall
    &TrackVehicleInfo_8FC5FA, &TrackVehicleInfo_8FCABB, &TrackVehicleInfo_8FCF8E, &TrackVehicleInfo_8FD461,  // RightHalfBankedHelixDownSmall
    &TrackVehicleInfo_8F0C22, &TrackVehicleInfo_8F141F, &TrackVehicleInfo_8F1C2E, &TrackVehicleInfo_8F243D,  // LeftHalfBankedHelixUpLarge
    &TrackVehicleInfo_8F2C3A, &TrackVehicleInfo_8F3437, &TrackVehicleInfo_8F3C46, &TrackVehicleInfo_8F4455,  // RightHalfBankedHelixUpLarge
    &TrackVehicleInfo_8F4C52, &TrackVehicleInfo_8F544F, &TrackVehicleInfo_8F5C5E, &TrackVehicleInfo_8F646D,  // LeftHalfBankedHelixDownLarge
    &TrackVehicleInfo_8F6C6A, &TrackVehicleInfo_8F7467, &TrackVehicleInfo_8F7C76, &TrackVehicleInfo_8F8485,  // RightHalfBankedHelixDownLarge
    &TrackVehicleInfo_8E402E, &TrackVehicleInfo_8E4270, &TrackVehicleInfo_8E44B2, &TrackVehicleInfo_8E46F4,  // LeftQuarterTurn1TileUp60
    &TrackVehicleInfo_8E4936, &TrackVehicleInfo_8E4B78, &TrackVehicleInfo_8E4DBA, &TrackVehicleInfo_8E4FFC,  // RightQuarterTurn1TileUp60
    &TrackVehicleInfo_8E523E, &TrackVehicleInfo_8E5480, &TrackVehicleInfo_8E56C2, &TrackVehicleInfo_8E5904,  // LeftQuarterTurn1TileDown60
    &TrackVehicleInfo_8E5B46, &TrackVehicleInfo_8E5D88, &TrackVehicleInfo_8E5FCA, &TrackVehicleInfo_8E620C,  // RightQuarterTurn1TileDown60
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // Brakes
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // Booster
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,  // Maze
    &TrackVehicleInfo_8B0EB2, &TrackVehicleInfo_8B12B6, &TrackVehicleInfo_8B16C3, &TrackVehicleInfo_8B1AC7,  // LeftQuarterBankedHelixLargeUp
    &TrackVehicleInfo_8B1EC2, &TrackVehicleInfo_8B22BD, &TrackVehicleInfo_8B26C1, &TrackVehicleInfo_8B2ACE,  // RightQuarterBankedHelixLargeUp
    &TrackVehicleInfo_8B2ED2, &TrackVehicleInfo_8B32D6, &TrackVehicleInfo_8B36E3, &TrackVehicleInfo_8B3AE7,  // LeftQuarterBankedHelixLargeDown
    &TrackVehicleInfo_8B3EE2, &TrackVehicleInfo_8B42DD, &TrackVehicleInfo_8B46E1, &TrackVehicleInfo_8B4AEE,  // RightQuarterBankedHelixLargeDown
    &TrackVehicleInfo_8B4EF2, &TrackVehicleInfo_8B52F6, &TrackVehicleInfo_8B5703, &TrackVehicleInfo_8B5B07,  // LeftQuarterHelixLargeUp
    &TrackVehicleInfo_8B5F02, &TrackVehicleInfo_8B62FD, &TrackVehicleInfo_8B6701, &TrackVehicleInfo_8B6B0E,  // RightQuarterHelixLargeUp
    &TrackVehicleInfo_8B6F12, &TrackVehicleInfo_8B7316, &TrackVehicleInfo_8B7723, &TrackVehicleInfo_8B7B27,  // LeftQuarterHelixLargeDown
    &TrackVehicleInfo_8B7F22, &TrackVehicleInfo_8B831D, &TrackVehicleInfo_8B8721, &TrackVehicleInfo_8B8B2E,  // RightQuarterHelixLargeDown
    &TrackVehicleInfo_968C6E, &TrackVehicleInfo_968D90, &TrackVehicleInfo_968EB2, &TrackVehicleInfo_968FD4,  // Up25LeftBanked
    &TrackVehicleInfo_96957E, &TrackVehicleInfo_9696A0, &TrackVehicleInfo_9697C2, &TrackVehicleInfo_9698E4,  // Up25RightBanked
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // Waterfall
    &TrackVehicleInfo_9048E8, &TrackVehicleInfo_904A0A, &TrackVehicleInfo_904B2C, &TrackVehicleInfo_904C4E,  // Rapids
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // OnRidePhoto
    &TrackVehicleInfo_9690F6, &TrackVehicleInfo_969218, &TrackVehicleInfo_96933A, &TrackVehicleInfo_96945C,  // Down25LeftBanked
    &TrackVehicleInfo_969A06, &TrackVehicleInfo_969B28, &TrackVehicleInfo_969C4A, &TrackVehicleInfo_969D6C,  // Down25RightBanked
    &TrackVehicleInfo_904D72, &TrackVehicleInfo_905314, &TrackVehicleInfo_9058B6, &TrackVehicleInfo_905E58,  // Watersplash
    &TrackVehicleInfo_96D4AE, &TrackVehicleInfo_96D9A5, &TrackVehicleInfo_96DE9C, &TrackVehicleInfo_96E393,  // FlatToUp60LongBase
    &TrackVehicleInfo_96E88A, &TrackVehicleInfo_96ED81, &TrackVehicleInfo_96F278, &TrackVehicleInfo_96F76F,  // Up60ToFlatLongBase
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // Whirlpool
    &TrackVehicleInfo_971042, &TrackVehicleInfo_971539, &TrackVehicleInfo_971A30, &TrackVehicleInfo_971F27,  // Down60ToFlatLongBase
    &TrackVehicleInfo_96FC66, &TrackVehicleInfo_97015D, &TrackVehicleInfo_970654, &TrackVehicleInfo_970B4B,  // FlatToDown60LongBase
    &TrackVehicleInfo_97241E, &TrackVehicleInfo_9729ED, &TrackVehicleInfo_972FBC, &TrackVehicleInfo_97358B,  // CableLiftHill
    &TrackVehicleInfo_9063FA, &TrackVehicleInfo_906EAC, &TrackVehicleInfo_90795E, &TrackVehicleInfo_908410,  // ReverseFreefallSlope
    &TrackVehicleInfo_90B98A, &TrackVehicleInfo_90BC5C, &TrackVehicleInfo_90BF2E, &TrackVehicleInfo_90C200,  // ReverseFreefallVertical
    &TrackVehicleInfo_90E02A, &TrackVehicleInfo_90E14C, &TrackVehicleInfo_90E26E, &TrackVehicleInfo_90E390,  // Up90
    &TrackVehicleInfo_90E4B2, &TrackVehicleInfo_90E5D4, &TrackVehicleInfo_90E6F6, &TrackVehicleInfo_90E818,  // Down90
    &TrackVehicleInfo_90E93A, &TrackVehicleInfo_90EB34, &TrackVehicleInfo_90ED2E, &TrackVehicleInfo_90EF28,  // Up60ToUp90
    &TrackVehicleInfo_9100F2, &TrackVehicleInfo_9102EC, &TrackVehicleInfo_9104E6, &TrackVehicleInfo_9106E0,  // Down90ToDown60
    &TrackVehicleInfo_90F122, &TrackVehicleInfo_90F31C, &TrackVehicleInfo_90F516, &TrackVehicleInfo_90F710,  // Up90ToUp60
    &TrackVehicleInfo_90F90A, &TrackVehicleInfo_90FB04, &TrackVehicleInfo_90FCFE, &TrackVehicleInfo_90FEF8,  // Down60ToDown90
    &TrackVehicleInfo_8C7662, &TrackVehicleInfo_8C77A8, &TrackVehicleInfo_8C78EE, &TrackVehicleInfo_8C7A34,  // BrakeForDrop
    &TrackVehicleInfo_9108DA, &TrackVehicleInfo_910BA3, &TrackVehicleInfo_910E75, &TrackVehicleInfo_911147,  // LeftEighthToDiag
    &TrackVehicleInfo_911F58, &TrackVehicleInfo_91222A, &TrackVehicleInfo_9124FC, &TrackVehicleInfo_9127CE,  // RightEighthToDiag
    &TrackVehicleInfo_911419, &TrackVehicleInfo_9116E2, &TrackVehicleInfo_9119B4, &TrackVehicleInfo_911C86,  // LeftEighthToOrthogonal
    &TrackVehicleInfo_912AA0, &TrackVehicleInfo_912D69, &TrackVehicleInfo_91303B, &TrackVehicleInfo_91330D,  // RightEighthToOrthogonal
    &TrackVehicleInfo_9135DF, &TrackVehicleInfo_9138A8, &TrackVehicleInfo_913B7A, &TrackVehicleInfo_913E4C,  // LeftEighthBankToDiag
    &TrackVehicleInfo_914C5D, &TrackVehicleInfo_914F2F, &TrackVehicleInfo_915201, &TrackVehicleInfo_9154D3,  // RightEighthBankToDiag
    &TrackVehicleInfo_91411E, &TrackVehicleInfo_9143E7, &TrackVehicleInfo_9146B9, &TrackVehicleInfo_91498B,  // LeftEighthBankToOrthogonal
    &TrackVehicleInfo_9157A5, &TrackVehicleInfo_915A6E, &TrackVehicleInfo_915D40, &TrackVehicleInfo_916012,  // RightEighthBankToOrthogonal
    &TrackVehicleInfo_9162E6, &TrackVehicleInfo_916408, &TrackVehicleInfo_91652A, &TrackVehicleInfo_91664C,  // DiagFlat
    &TrackVehicleInfo_91676E, &TrackVehicleInfo_916890, &TrackVehicleInfo_9169B2, &TrackVehicleInfo_916AD4,  // DiagUp25
    &TrackVehicleInfo_91707E, &TrackVehicleInfo_9172C0, &TrackVehicleInfo_917502, &TrackVehicleInfo_917744,  // DiagUp60
    &TrackVehicleInfo_91828E, &TrackVehicleInfo_9183B0, &TrackVehicleInfo_9184D2, &TrackVehicleInfo_9185F4,  // DiagFlatToUp25
    &TrackVehicleInfo_9194F6, &TrackVehicleInfo_919645, &TrackVehicleInfo_919794, &TrackVehicleInfo_9198E3,  // DiagUp25ToUp60
    &TrackVehicleInfo_919A32, &TrackVehicleInfo_919B81, &TrackVehicleInfo_919CD0, &TrackVehicleInfo_919E1F,  // DiagUp60ToUp25
    &TrackVehicleInfo_918716, &TrackVehicleInfo_91884A, &TrackVehicleInfo_91897E, &TrackVehicleInfo_918AB2,  // DiagUp25ToFlat
    &TrackVehicleInfo_916BF6, &TrackVehicleInfo_916D18, &TrackVehicleInfo_916E3A, &TrackVehicleInfo_916F5C,  // DiagDown25
    &TrackVehicleInfo_917986, &TrackVehicleInfo_917BC8, &TrackVehicleInfo_917E0A, &TrackVehicleInfo_91804C,  // DiagDown60
    &TrackVehicleInfo_91906E, &TrackVehicleInfo_919190, &TrackVehicleInfo_9192B2, &TrackVehicleInfo_9193D4,  // DiagFlatToDown25
    &TrackVehicleInfo_91A4AA, &TrackVehicleInfo_91A5F9, &TrackVehicleInfo_91A748, &TrackVehicleInfo_91A897,  // DiagDown25ToDown60
    &TrackVehicleInfo_919F6E, &TrackVehicleInfo_91A0BD, &TrackVehicleInfo_91A20C, &TrackVehicleInfo_91A35B,  // DiagDown60ToDown25
    &TrackVehicleInfo_918BE6, &TrackVehicleInfo_918D08, &TrackVehicleInfo_918E2A, &TrackVehicleInfo_918F4C,  // DiagDown25ToFlat
    &TrackVehicleInfo_91A9E6, &TrackVehicleInfo_91AB2C, &TrackVehicleInfo_91AC72, &TrackVehicleInfo_91ADB8,  // DiagFlatToUp60
    &TrackVehicleInfo_91AEFE, &TrackVehicleInfo_91B044, &TrackVehicleInfo_91B18A, &TrackVehicleInfo_91B2D0,  // DiagUp60ToFlat
    &TrackVehicleInfo_91B416, &TrackVehicleInfo_91B55C, &TrackVehicleInfo_91B6A2, &TrackVehicleInfo_91B7E8,  // DiagFlatToDown60
    &TrackVehicleInfo_91B92E, &TrackVehicleInfo_91BA74, &TrackVehicleInfo_91BBBA, &TrackVehicleInfo_91BD00,  // DiagDown60ToFlat
    &TrackVehicleInfo_95787E, &TrackVehicleInfo_9579A0, &TrackVehicleInfo_957AC2, &TrackVehicleInfo_957BE4,  // DiagFlatToLeftBank
    &TrackVehicleInfo_957D06, &TrackVehicleInfo_957E28, &TrackVehicleInfo_957F4A, &TrackVehicleInfo_95806C,  // DiagFlatToRightBank
    &TrackVehicleInfo_95818E, &TrackVehicleInfo_9582B0, &TrackVehicleInfo_9583D2, &TrackVehicleInfo_9584F4,  // DiagLeftBankToFlat
    &TrackVehicleInfo_958616, &TrackVehicleInfo_958738, &TrackVehicleInfo_95885A, &TrackVehicleInfo_95897C,  // DiagRightBankToFlat
    &TrackVehicleInfo_958A9E, &TrackVehicleInfo_958BC0, &TrackVehicleInfo_958CE2, &TrackVehicleInfo_958E04,  // DiagLeftBankToUp25
    &TrackVehicleInfo_958F26, &TrackVehicleInfo_959048, &TrackVehicleInfo_95916A, &TrackVehicleInfo_95928C,  // DiagRightBankToUp25
    &TrackVehicleInfo_9593AE, &TrackVehicleInfo_9594E2, &TrackVehicleInfo_959616, &TrackVehicleInfo_95974A,  // DiagUp25ToLeftBank
    &TrackVehicleInfo_95987E, &TrackVehicleInfo_9599B2, &TrackVehicleInfo_959AE6, &TrackVehicleInfo_959C1A,  // DiagUp25ToRightBank
    &TrackVehicleInfo_95A65E, &TrackVehicleInfo_95A780, &TrackVehicleInfo_95A8A2, &TrackVehicleInfo_95A9C4,  // DiagLeftBankToDown25
    &TrackVehicleInfo_95AAE6, &TrackVehicleInfo_95AC08, &TrackVehicleInfo_95AD2A, &TrackVehicleInfo_95AE4C,  // DiagRightBankToDown25
    &TrackVehicleInfo_959D4E, &TrackVehicleInfo_959E70, &TrackVehicleInfo_959F92, &TrackVehicleInfo_95A0B4,  // DiagDown25ToLeftBank
    &TrackVehicleInfo_95A1D6, &TrackVehicleInfo_95A2F8, &TrackVehicleInfo_95A41A, &TrackVehicleInfo_95A53C,  // DiagDown25ToRightBank
    &TrackVehicleInfo_95AF6E, &TrackVehicleInfo_95B090, &TrackVehicleInfo_95B1B2, &TrackVehicleInfo_95B2D4,  // DiagLeftBank
    &TrackVehicleInfo_95B3F6, &TrackVehicleInfo_95B518, &TrackVehicleInfo_95B63A, &TrackVehicleInfo_95B75C,  // DiagRightBank
    &TrackVehicleInfo_91BE46, &TrackVehicleInfo_91C001, &TrackVehicleInfo_91C1BC, &TrackVehicleInfo_91C377,  // LogFlumeReverser
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // SpinningTunnel
    &TrackVehicleInfo_91C532, &TrackVehicleInfo_91C894, &TrackVehicleInfo_91CBF6, &TrackVehicleInfo_91CF58,  // LeftBarrelRollUpToDown
    &TrackVehicleInfo_91D2BA, &TrackVehicleInfo_91D61C, &TrackVehicleInfo_91D97E, &TrackVehicleInfo_91DCE0,  // RightBarrelRollUpToDown
    &TrackVehicleInfo_91E042, &TrackVehicleInfo_91E3A4, &TrackVehicleInfo_91E706, &TrackVehicleInfo_91EA68,  // LeftBarrelRollDownToUp
    &TrackVehicleInfo_91EDCA, &TrackVehicleInfo_91F12C, &TrackVehicleInfo_91F48E, &TrackVehicleInfo_91F7F0,  // RightBarrelRollDownToUp
    &TrackVehicleInfo_920E82, &TrackVehicleInfo_9210E8, &TrackVehicleInfo_921357, &TrackVehicleInfo_9215BD,  // LeftBankToLeftQuarterTurn3TilesUp25
    &TrackVehicleInfo_92181A, &TrackVehicleInfo_921A77, &TrackVehicleInfo_921CDD, &TrackVehicleInfo_921F4C,  // RightBankToRightQuarterTurn3TilesUp25
    &TrackVehicleInfo_91FB52, &TrackVehicleInfo_91FDB8, &TrackVehicleInfo_920027, &TrackVehicleInfo_92028D,  // LeftQuarterTurn3TilesDown25ToLeftBank
    &TrackVehicleInfo_9204EA, &TrackVehicleInfo_920747, &TrackVehicleInfo_9209AD, &TrackVehicleInfo_920C1C,  // RightQuarterTurn3TilesDown25ToRightBank
    &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C, &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690,  // PoweredLift
    &TrackVehicleInfo_9221B2, &TrackVehicleInfo_9237A6, &TrackVehicleInfo_924D9A, &TrackVehicleInfo_92638E,  // LeftLargeHalfLoopUp
    &TrackVehicleInfo_922CAC, &TrackVehicleInfo_9242A0, &TrackVehicleInfo_925894, &TrackVehicleInfo_926E88,  // RightLargeHalfLoopUp
    &TrackVehicleInfo_927982, &TrackVehicleInfo_928F76, &TrackVehicleInfo_92A56A, &TrackVehicleInfo_92BB5E,  // LeftLargeHalfLoopDown
    &TrackVehicleInfo_92847C, &TrackVehicleInfo_929A70, &TrackVehicleInfo_92B064, &TrackVehicleInfo_92C658,  // RightLargeHalfLoopDown
    &TrackVehicleInfo_8D9BFE, &TrackVehicleInfo_8D9F60, &TrackVehicleInfo_8DA2C2, &TrackVehicleInfo_8DA624,  // LeftFlyerTwistUp
    &TrackVehicleInfo_8DA986, &TrackVehicleInfo_8DACE8, &TrackVehicleInfo_8DB04A, &TrackVehicleInfo_8DB3AC,  // RightFlyerTwistUp
    &TrackVehicleInfo_8DD21E, &TrackVehicleInfo_8DD580, &TrackVehicleInfo_8DD8E2, &TrackVehicleInfo_8DDC44,  // LeftFlyerTwistDown
    &TrackVehicleInfo_8DDFA6, &TrackVehicleInfo_8DE308, &TrackVehicleInfo_8DE66A, &TrackVehicleInfo_8DE9CC,  // RightFlyerTwistDown
    &TrackVehicleInfo_8E644E, &TrackVehicleInfo_8E69F9, &TrackVehicleInfo_8E6FA4, &TrackVehicleInfo_8E754F,  // FlyerHalfLoopUninvertedUp
    &TrackVehicleInfo_8E91A6, &TrackVehicleInfo_8E9751, &TrackVehicleInfo_8E9CFC, &TrackVehicleInfo_8EA2A7,  // FlyerHalfLoopInvertedDown
    &TrackVehicleInfo_8EA852, &TrackVehicleInfo_8EABBD, &TrackVehicleInfo_8EAF28, &TrackVehicleInfo_8EB293,  // LeftFlyerCorkscrewUp
    &TrackVehicleInfo_8EB5FE, &TrackVehicleInfo_8EB969, &TrackVehicleInfo_8EBCD4, &TrackVehicleInfo_8EC03F,  // RightFlyerCorkscrewUp
    &TrackVehicleInfo_8EDF02, &TrackVehicleInfo_8EE26D, &TrackVehicleInfo_8EE5D8, &TrackVehicleInfo_8EE943,  // LeftFlyerCorkscrewDown
    &TrackVehicleInfo_8EECAE, &TrackVehicleInfo_8EF019, &TrackVehicleInfo_8EF384, &TrackVehicleInfo_8EF6EF,  // RightFlyerCorkscrewDown
    &TrackVehicleInfo_92D152, &TrackVehicleInfo_92D6F4, &TrackVehicleInfo_92DC96, &TrackVehicleInfo_92E238,  // HeartLineTransferUp
    &TrackVehicleInfo_92E7DA, &TrackVehicleInfo_92ED7C, &TrackVehicleInfo_92F31E, &TrackVehicleInfo_92F8C0,  // HeartLineTransferDown
    &TrackVehicleInfo_92FE62, &TrackVehicleInfo_930524, &TrackVehicleInfo_930BE6, &TrackVehicleInfo_9312A8,  // LeftHeartLineRoll
    &TrackVehicleInfo_93196A, &TrackVehicleInfo_93202C, &TrackVehicleInfo_9326EE, &TrackVehicleInfo_932DB0,  // RightHeartLineRoll
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,  // MinigolfHoleA
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,  // MinigolfHoleB
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,  // MinigolfHoleC
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,  // MinigolfHoleD
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,  // MinigolfHoleE
    &TrackVehicleInfo_979BD6, &TrackVehicleInfo_97A0A9, &TrackVehicleInfo_97A57C, &TrackVehicleInfo_97AA4F,  // MultiDimInvertedFlatToDown90QuarterLoop
    &TrackVehicleInfo_973B5A, &TrackVehicleInfo_97402D, &TrackVehicleInfo_974500, &TrackVehicleInfo_9749D3,  // Up90ToInvertedFlatQuarterLoop
    &TrackVehicleInfo_974EA6, &TrackVehicleInfo_975379, &TrackVehicleInfo_97584C, &TrackVehicleInfo_975D1F,  // InvertedFlatToDown90QuarterLoop
    &TrackVehicleInfo_8FDFAA, &TrackVehicleInfo_8FE210, &TrackVehicleInfo_8FE47F, &TrackVehicleInfo_8FE6E5,  // LeftCurvedLiftHill
    &TrackVehicleInfo_8FE942, &TrackVehicleInfo_8FEB9F, &TrackVehicleInfo_8FEE05, &TrackVehicleInfo_8FF074,  // RightCurvedLiftHill
    &TrackVehicleInfo_94F14E, &TrackVehicleInfo_94F810, &TrackVehicleInfo_94FED2, &TrackVehicleInfo_950594,  // LeftReverser
    &TrackVehicleInfo_950C56, &TrackVehicleInfo_951318, &TrackVehicleInfo_9519DA, &TrackVehicleInfo_95209C,  // RightReverser
    &TrackVehicleInfo_90C4D2, &TrackVehicleInfo_90C8D6, &TrackVehicleInfo_90CCDA, &TrackVehicleInfo_90D0DE,  // AirThrustTopCap
    &TrackVehicleInfo_90D4E2, &TrackVehicleInfo_90D7B4, &TrackVehicleInfo_90DA86, &TrackVehicleInfo_90DD58,  // AirThrustVerticalDown
    &TrackVehicleInfo_908EC2, &TrackVehicleInfo_909974, &TrackVehicleInfo_90A426, &TrackVehicleInfo_90AED8,  // AirThrustVerticalDownToLevel
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // BlockBrakes
    &TrackVehicleInfo_960BEE, &TrackVehicleInfo_960E54, &TrackVehicleInfo_9610C3, &TrackVehicleInfo_961329,  // LeftBankedQuarterTurn3TileUp25
    &TrackVehicleInfo_961586, &TrackVehicleInfo_9617E3, &TrackVehicleInfo_961A49, &TrackVehicleInfo_961CB8,  // RightBankedQuarterTurn3TileUp25
    &TrackVehicleInfo_95F8BE, &TrackVehicleInfo_95FB24, &TrackVehicleInfo_95FD93, &TrackVehicleInfo_95FFF9,  // LeftBankedQuarterTurn3TileDown25
    &TrackVehicleInfo_960256, &TrackVehicleInfo_9604B3, &TrackVehicleInfo_960719, &TrackVehicleInfo_960988,  // RightBankedQuarterTurn3TileDown25
    &TrackVehicleInfo_95B87E, &TrackVehicleInfo_95BC82, &TrackVehicleInfo_95C08F, &TrackVehicleInfo_95C493,  // LeftBankedQuarterTurn5TileUp25
    &TrackVehicleInfo_95C88E, &TrackVehicleInfo_95CC89, &TrackVehicleInfo_95D08D, &TrackVehicleInfo_95D49A,  // RightBankedQuarterTurn5TileUp25
    &TrackVehicleInfo_95D89E, &TrackVehicleInfo_95DCA2, &TrackVehicleInfo_95E0AF, &TrackVehicleInfo_95E4B3,  // LeftBankedQuarterTurn5TileDown25
    &TrackVehicleInfo_95E8AE, &TrackVehicleInfo_95ECA9, &TrackVehicleInfo_95F0AD, &TrackVehicleInfo_95F4BA,  // RightBankedQuarterTurn5TileDown25
    &TrackVehicleInfo_961F1E, &TrackVehicleInfo_962040, &TrackVehicleInfo_962162, &TrackVehicleInfo_962284,  // Up25ToLeftBankedUp25
    &TrackVehicleInfo_9623A6, &TrackVehicleInfo_9624C8, &TrackVehicleInfo_9625EA, &TrackVehicleInfo_96270C,  // Up25ToRightBankedUp25
    &TrackVehicleInfo_96313E, &TrackVehicleInfo_963260, &TrackVehicleInfo_963382, &TrackVehicleInfo_9634A4,  // LeftBankedUp25ToUp25
    &TrackVehicleInfo_9635C6, &TrackVehicleInfo_9636E8, &TrackVehicleInfo_96380A, &TrackVehicleInfo_96392C,  // RightBankedUp25ToUp25
    &TrackVehicleInfo_96282E, &TrackVehicleInfo_962950, &TrackVehicleInfo_962A72, &TrackVehicleInfo_962B94,  // Down25ToLeftBankedDown25
    &TrackVehicleInfo_962CB6, &TrackVehicleInfo_962DD8, &TrackVehicleInfo_962EFA, &TrackVehicleInfo_96301C,  // Down25ToRightBankedDown25
    &TrackVehicleInfo_963A4E, &TrackVehicleInfo_963B70, &TrackVehicleInfo_963C92, &TrackVehicleInfo_963DB4,  // LeftBankedDown25ToDown25
    &TrackVehicleInfo_963ED6, &TrackVehicleInfo_963FF8, &TrackVehicleInfo_96411A, &TrackVehicleInfo_96423C,  // RightBankedDown25ToDown25
    &TrackVehicleInfo_96435E, &TrackVehicleInfo_964480, &TrackVehicleInfo_9645A2, &TrackVehicleInfo_9646C4,  // LeftBankedFlatToLeftBankedUp25
    &TrackVehicleInfo_96557E, &TrackVehicleInfo_9656A0, &TrackVehicleInfo_9657C2, &TrackVehicleInfo_9658E4,  // RightBankedFlatToRightBankedUp25
    &TrackVehicleInfo_9647E6, &TrackVehicleInfo_964908, &TrackVehicleInfo_964A2A, &TrackVehicleInfo_964B4C,  // LeftBankedUp25ToLeftBankedFlat
    &TrackVehicleInfo_965A06, &TrackVehicleInfo_965B28, &TrackVehicleInfo_965C4A, &TrackVehicleInfo_965D6C,  // RightBankedUp25ToRightBankedFlat
    &TrackVehicleInfo_9650F6, &TrackVehicleInfo_965218, &TrackVehicleInfo_96533A, &TrackVehicleInfo_96545C,  // LeftBankedFlatToLeftBankedDown25
    &TrackVehicleInfo_966316, &TrackVehicleInfo_966438, &TrackVehicleInfo_96655A, &TrackVehicleInfo_96667C,  // RightBankedFlatToRightBankedDown25
    &TrackVehicleInfo_964C6E, &TrackVehicleInfo_964D90, &TrackVehicleInfo_964EB2, &TrackVehicleInfo_964FD4,  // LeftBankedDown25ToLeftBankedFlat
    &TrackVehicleInfo_965E8E, &TrackVehicleInfo_965FB0, &TrackVehicleInfo_9660D2, &TrackVehicleInfo_9661F4,  // RightBankedDown25ToRightBankedFlat
    &TrackVehicleInfo_96679E, &TrackVehicleInfo_9668C0, &TrackVehicleInfo_9669E2, &TrackVehicleInfo_966B04,  // FlatToLeftBankedUp25
    &TrackVehicleInfo_966C26, &TrackVehicleInfo_966D48, &TrackVehicleInfo_966E6A, &TrackVehicleInfo_966F8C,  // FlatToRightBankedUp25
    &TrackVehicleInfo_9670AE, &TrackVehicleInfo_9671E2, &TrackVehicleInfo_967316, &TrackVehicleInfo_96744A,  // LeftBankedUp25ToFlat
    &TrackVehicleInfo_96757E, &TrackVehicleInfo_9676B2, &TrackVehicleInfo_9677E6, &TrackVehicleInfo_96791A,  // RightBankedUp25ToFlat
    &TrackVehicleInfo_96835E, &TrackVehicleInfo_968480, &TrackVehicleInfo_9685A2, &TrackVehicleInfo_9686C4,  // FlatToLeftBankedDown25
    &TrackVehicleInfo_9687E6, &TrackVehicleInfo_968908, &TrackVehicleInfo_968A2A, &TrackVehicleInfo_968B4C,  // FlatToRightBankedDown25
    &TrackVehicleInfo_967A4E, &TrackVehicleInfo_967B70, &TrackVehicleInfo_967C92, &TrackVehicleInfo_967DB4,  // LeftBankedDown25ToFlat
    &TrackVehicleInfo_967ED6, &TrackVehicleInfo_967FF8, &TrackVehicleInfo_96811A, &TrackVehicleInfo_96823C,  // RightBankedDown25ToFlat
    &TrackVehicleInfo_969E8E, &TrackVehicleInfo_96A1F0, &TrackVehicleInfo_96A552, &TrackVehicleInfo_96A8B4,  // LeftQuarterTurn1TileUp90
    &TrackVehicleInfo_96B99E, &TrackVehicleInfo_96BD00, &TrackVehicleInfo_96C062, &TrackVehicleInfo_96C3C4,  // RightQuarterTurn1TileUp90
    &TrackVehicleInfo_96AC16, &TrackVehicleInfo_96AF78, &TrackVehicleInfo_96B2DA, &TrackVehicleInfo_96B63C,  // LeftQuarterTurn1TileDown90
    &TrackVehicleInfo_96C726, &TrackVehicleInfo_96CA88, &TrackVehicleInfo_96CDEA, &TrackVehicleInfo_96D14C,  // RightQuarterTurn1TileDown90
    &TrackVehicleInfo_9761F2, &TrackVehicleInfo_9766C5, &TrackVehicleInfo_976B98, &TrackVehicleInfo_97706B,  // MultiDimUp90ToInvertedFlatQuarterLoop
    &TrackVehicleInfo_97753E, &TrackVehicleInfo_977A11, &TrackVehicleInfo_977EE4, &TrackVehicleInfo_9783B7,  // MultiDimFlatToDown90QuarterLoop
    &TrackVehicleInfo_97888A, &TrackVehicleInfo_978D5D, &TrackVehicleInfo_979230, &TrackVehicleInfo_979703,  // MultiDimInvertedUp90ToFlatQuarterLoop
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // RotationControlToggle
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // FlatTrack1x4A
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // FlatTrack2x2
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // FlatTrack4x4
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // FlatTrack2x4
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // FlatTrack1x5
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // FlatTrack1x1A
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // FlatTrack1x4B
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // FlatTrack1x1B
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // FlatTrack1x4C
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,  // FlatTrack3x3
    &TrackVehicleInfoLeftLargeCorkscrewUp0, &TrackVehicleInfoLeftLargeCorkscrewUp1, &TrackVehicleInfoLeftLargeCorkscrewUp2, &TrackVehicleInfoLeftLargeCorkscrewUp3,
    &TrackVehicleInfoRightLargeCorkscrewUp0, &TrackVehicleInfoRightLargeCorkscrewUp1, &TrackVehicleInfoRightLargeCorkscrewUp2, &TrackVehicleInfoRightLargeCorkscrewUp3,
    &TrackVehicleInfoLeftLargeCorkscrewDown0, &TrackVehicleInfoLeftLargeCorkscrewDown1, &TrackVehicleInfoLeftLargeCorkscrewDown2, &TrackVehicleInfoLeftLargeCorkscrewDown3,
    &TrackVehicleInfoRightLargeCorkscrewDown0, &TrackVehicleInfoRightLargeCorkscrewDown1, &TrackVehicleInfoRightLargeCorkscrewDown2, &TrackVehicleInfoRightLargeCorkscrewDown3,
    &TrackVehicleInfoLeftMediumHalfLoopUp0, &TrackVehicleInfoLeftMediumHalfLoopUp1, &TrackVehicleInfoLeftMediumHalfLoopUp2, &TrackVehicleInfoLeftMediumHalfLoopUp3,
    &TrackVehicleInfoRightMediumHalfLoopUp0, &TrackVehicleInfoRightMediumHalfLoopUp1, &TrackVehicleInfoRightMediumHalfLoopUp2, &TrackVehicleInfoRightMediumHalfLoopUp3,
    &TrackVehicleInfoLeftMediumHalfLoopDown0, &TrackVehicleInfoLeftMediumHalfLoopDown1, &TrackVehicleInfoLeftMediumHalfLoopDown2, &TrackVehicleInfoLeftMediumHalfLoopDown3,
    &TrackVehicleInfoRightMediumHalfLoopDown0, &TrackVehicleInfoRightMediumHalfLoopDown1, &TrackVehicleInfoRightMediumHalfLoopDown2, &TrackVehicleInfoRightMediumHalfLoopDown3,
    &TrackVehicleInfoLeftZeroGRollUp0, &TrackVehicleInfoLeftZeroGRollUp1, &TrackVehicleInfoLeftZeroGRollUp2, &TrackVehicleInfoLeftZeroGRollUp3,
    &TrackVehicleInfoRightZeroGRollUp0, &TrackVehicleInfoRightZeroGRollUp1, &TrackVehicleInfoRightZeroGRollUp2, &TrackVehicleInfoRightZeroGRollUp3,
    &TrackVehicleInfoLeftZeroGRollDown0, &TrackVehicleInfoLeftZeroGRollDown1, &TrackVehicleInfoLeftZeroGRollDown2, &TrackVehicleInfoLeftZeroGRollDown3,
    &TrackVehicleInfoRightZeroGRollDown0, &TrackVehicleInfoRightZeroGRollDown1, &TrackVehicleInfoRightZeroGRollDown2, &TrackVehicleInfoRightZeroGRollDown3,
    &TrackVehicleInfoLeftLargeZeroGRollUp0, &TrackVehicleInfoLeftLargeZeroGRollUp1, &TrackVehicleInfoLeftLargeZeroGRollUp2, &TrackVehicleInfoLeftLargeZeroGRollUp3,
    &TrackVehicleInfoRightLargeZeroGRollUp0, &TrackVehicleInfoRightLargeZeroGRollUp1, &TrackVehicleInfoRightLargeZeroGRollUp2, &TrackVehicleInfoRightLargeZeroGRollUp3,
    &TrackVehicleInfoLeftLargeZeroGRollDown0, &TrackVehicleInfoLeftLargeZeroGRollDown1, &TrackVehicleInfoLeftLargeZeroGRollDown2, &TrackVehicleInfoLeftLargeZeroGRollDown3,
    &TrackVehicleInfoRightLargeZeroGRollDown0, &TrackVehicleInfoRightLargeZeroGRollDown1, &TrackVehicleInfoRightLargeZeroGRollDown2, &TrackVehicleInfoRightLargeZeroGRollDown3,
    &TrackVehicleInfo_9221B2, &TrackVehicleInfo_9237A6, &TrackVehicleInfo_924D9A, &TrackVehicleInfo_92638E,  // LeftFlyerLargeHalfLoopUninvertedUp
    &TrackVehicleInfo_922CAC, &TrackVehicleInfo_9242A0, &TrackVehicleInfo_925894, &TrackVehicleInfo_926E88,  // RightFlyerLargeHalfLoopUninvertedUp
    &TrackVehicleInfo_LeftFlyerLargeHalfLoopDown0, &TrackVehicleInfo_LeftFlyerLargeHalfLoopDown1, &TrackVehicleInfo_LeftFlyerLargeHalfLoopDown2, &TrackVehicleInfo_LeftFlyerLargeHalfLoopDown3,  // LeftFlyerLargeHalfLoopInvertedDown
    &TrackVehicleInfo_RightFlyerLargeHalfLoopDown0, &TrackVehicleInfo_RightFlyerLargeHalfLoopDown1, &TrackVehicleInfo_RightFlyerLargeHalfLoopDown2, &TrackVehicleInfo_RightFlyerLargeHalfLoopDown3,  // RightFlyerLargeHalfLoopInvertedDown
    &TrackVehicleInfo_9221B2, &TrackVehicleInfo_9237A6, &TrackVehicleInfo_924D9A, &TrackVehicleInfo_92638E,  // LeftFlyerLargeHalfLoopInvertedUp
    &TrackVehicleInfo_922CAC, &TrackVehicleInfo_9242A0, &TrackVehicleInfo_925894, &TrackVehicleInfo_926E88,  // RightFlyerLargeHalfLoopInvertedUp
    &TrackVehicleInfo_LeftFlyerLargeHalfLoopUninvertedDown0, &TrackVehicleInfo_LeftFlyerLargeHalfLoopUninvertedDown1, &TrackVehicleInfo_LeftFlyerLargeHalfLoopUninvertedDown2, &TrackVehicleInfo_LeftFlyerLargeHalfLoopUninvertedDown3,  // LeftFlyerLargeHalfLoopUninvertedDown
    &TrackVehicleInfo_RightFlyerLargeHalfLoopUninvertedDown0, &TrackVehicleInfo_RightFlyerLargeHalfLoopUninvertedDown1, &TrackVehicleInfo_RightFlyerLargeHalfLoopUninvertedDown2, &TrackVehicleInfo_RightFlyerLargeHalfLoopUninvertedDown3,  // RightFlyerLargeHalfLoopUninvertedDown
     &TrackVehicleInfo_8E644E, &TrackVehicleInfo_8E69F9, &TrackVehicleInfo_8E6FA4, &TrackVehicleInfo_8E754F,  // FlyerHalfLoopInvertedUp
     &TrackVehicleInfo_FlyerHalfLoopUninvertedDown0, &TrackVehicleInfo_FlyerHalfLoopUninvertedDown1, &TrackVehicleInfo_FlyerHalfLoopUninvertedDown2, &TrackVehicleInfo_FlyerHalfLoopUninvertedDown3,  // FlyerHalfLoopUninvertedDown
     &TrackVehicleInfoLeftEighthToDiagUp250, &TrackVehicleInfoLeftEighthToDiagUp251, &TrackVehicleInfoLeftEighthToDiagUp252, &TrackVehicleInfoLeftEighthToDiagUp253, // TrackElemType::LeftEighthToDiagUp25
     &TrackVehicleInfoRightEighthToDiagUp250, &TrackVehicleInfoRightEighthToDiagUp251, &TrackVehicleInfoRightEighthToDiagUp252, &TrackVehicleInfoRightEighthToDiagUp253, // TrackElemType::RightEighthToDiagUp25
     &TrackVehicleInfoLeftEighthToDiagDown250, &TrackVehicleInfoLeftEighthToDiagDown251, &TrackVehicleInfoLeftEighthToDiagDown252, &TrackVehicleInfoLeftEighthToDiagDown253, // TrackElemType::LeftEighthToDiagDown25
     &TrackVehicleInfoRightEighthToDiagDown250, &TrackVehicleInfoRightEighthToDiagDown251, &TrackVehicleInfoRightEighthToDiagDown252, &TrackVehicleInfoRightEighthToDiagDown253, // TrackElemType::RightEighthToDiagDown25
     &TrackVehicleInfoLeftEighthToOrthogonalUp250, &TrackVehicleInfoLeftEighthToOrthogonalUp251, &TrackVehicleInfoLeftEighthToOrthogonalUp252, &TrackVehicleInfoLeftEighthToOrthogonalUp253, // TrackElemType::LeftEighthToOrthogonalUp25
     &TrackVehicleInfoRightEighthToOrthogonalUp250, &TrackVehicleInfoRightEighthToOrthogonalUp251, &TrackVehicleInfoRightEighthToOrthogonalUp252, &TrackVehicleInfoRightEighthToOrthogonalUp253, // TrackElemType::RightEighthToOrthogonalUp25
     &TrackVehicleInfoLeftEighthToOrthogonalDown250, &TrackVehicleInfoLeftEighthToOrthogonalDown251, &TrackVehicleInfoLeftEighthToOrthogonalDown252, &TrackVehicleInfoLeftEighthToOrthogonalDown253, // TrackElemType::LeftEighthToOrthogonalDown25
     &TrackVehicleInfoRightEighthToOrthogonalDown250, &TrackVehicleInfoRightEighthToOrthogonalDown251, &TrackVehicleInfoRightEighthToOrthogonalDown252, &TrackVehicleInfoRightEighthToOrthogonalDown253, // TrackElemType::RightEighthToOrthogonalDown25

     &TrackVehicleInfoDiagUp25ToLeftBankedUp250, &TrackVehicleInfoDiagUp25ToLeftBankedUp251, &TrackVehicleInfoDiagUp25ToLeftBankedUp252, &TrackVehicleInfoDiagUp25ToLeftBankedUp253, // TrackElemType::DiagUp25ToLeftBankedUp25
     &TrackVehicleInfoDiagUp25ToRightBankedUp250, &TrackVehicleInfoDiagUp25ToRightBankedUp251, &TrackVehicleInfoDiagUp25ToRightBankedUp252, &TrackVehicleInfoDiagUp25ToRightBankedUp253, // TrackElemType::DiagUp25ToRightBankedUp25
     &TrackVehicleInfoDiagLeftBankedUp25ToUp250, &TrackVehicleInfoDiagLeftBankedUp25ToUp251, &TrackVehicleInfoDiagLeftBankedUp25ToUp252, &TrackVehicleInfoDiagLeftBankedUp25ToUp253, // TrackElemType::DiagLeftBankedUp25ToUp25
     &TrackVehicleInfoDiagRightBankedUp25ToUp250, &TrackVehicleInfoDiagRightBankedUp25ToUp251, &TrackVehicleInfoDiagRightBankedUp25ToUp252, &TrackVehicleInfoDiagRightBankedUp25ToUp253, // TrackElemType::DiagRightBankedUp25ToUp25
     &TrackVehicleInfoDiagDown25ToLeftBankedDown250, &TrackVehicleInfoDiagDown25ToLeftBankedDown251, &TrackVehicleInfoDiagDown25ToLeftBankedDown252, &TrackVehicleInfoDiagDown25ToLeftBankedDown253, // TrackElemType::DiagDown25ToLeftBankedDown25
     &TrackVehicleInfoDiagDown25ToRightBankedDown250, &TrackVehicleInfoDiagDown25ToRightBankedDown251, &TrackVehicleInfoDiagDown25ToRightBankedDown252, &TrackVehicleInfoDiagDown25ToRightBankedDown253, // TrackElemType::DiagDown25ToRightBankedDown25
     &TrackVehicleInfoDiagLeftBankedDown25ToDown250, &TrackVehicleInfoDiagLeftBankedDown25ToDown251, &TrackVehicleInfoDiagLeftBankedDown25ToDown252, &TrackVehicleInfoDiagLeftBankedDown25ToDown253, // TrackElemType::DiagLeftBankedDown25ToDown25
     &TrackVehicleInfoDiagRightBankedDown25ToDown250, &TrackVehicleInfoDiagRightBankedDown25ToDown251, &TrackVehicleInfoDiagRightBankedDown25ToDown252, &TrackVehicleInfoDiagRightBankedDown25ToDown253, // TrackElemType::DiagRightBankedDown25ToDown25
     &TrackVehicleInfoDiagLeftBankedFlatToLeftBankedUp250, &TrackVehicleInfoDiagLeftBankedFlatToLeftBankedUp251, &TrackVehicleInfoDiagLeftBankedFlatToLeftBankedUp252, &TrackVehicleInfoDiagLeftBankedFlatToLeftBankedUp253, // TrackElemType::DiagLeftBankedFlatToLeftBankedUp25
     &TrackVehicleInfoDiagRightBankedFlatToRightBankedUp250, &TrackVehicleInfoDiagRightBankedFlatToRightBankedUp251, &TrackVehicleInfoDiagRightBankedFlatToRightBankedUp252, &TrackVehicleInfoDiagRightBankedFlatToRightBankedUp253, // TrackElemType::DiagRightBankedFlatToRightBankedUp25
     &TrackVehicleInfoDiagLeftBankedUp25ToLeftBankedFlat0, &TrackVehicleInfoDiagLeftBankedUp25ToLeftBankedFlat1, &TrackVehicleInfoDiagLeftBankedUp25ToLeftBankedFlat2, &TrackVehicleInfoDiagLeftBankedUp25ToLeftBankedFlat3, // TrackElemType::DiagLeftBankedUp25ToLeftBankedFlat
     &TrackVehicleInfoDiagRightBankedUp25ToRightBankedFlat0, &TrackVehicleInfoDiagRightBankedUp25ToRightBankedFlat1, &TrackVehicleInfoDiagRightBankedUp25ToRightBankedFlat2, &TrackVehicleInfoDiagRightBankedUp25ToRightBankedFlat3, // TrackElemType::DiagRightBankedUp25ToRightBankedFlat
     &TrackVehicleInfoDiagLeftBankedFlatToLeftBankedDown250, &TrackVehicleInfoDiagLeftBankedFlatToLeftBankedDown251, &TrackVehicleInfoDiagLeftBankedFlatToLeftBankedDown252, &TrackVehicleInfoDiagLeftBankedFlatToLeftBankedDown253, // TrackElemType::DiagLeftBankedFlatToLeftBankedDown25
     &TrackVehicleInfoDiagRightBankedFlatToRightBankedDown250, &TrackVehicleInfoDiagRightBankedFlatToRightBankedDown251, &TrackVehicleInfoDiagRightBankedFlatToRightBankedDown252, &TrackVehicleInfoDiagRightBankedFlatToRightBankedDown253, // TrackElemType::DiagRightBankedFlatToRightBankedDown25
     &TrackVehicleInfoDiagLeftBankedDown25ToLeftBankedFlat0, &TrackVehicleInfoDiagLeftBankedDown25ToLeftBankedFlat1, &TrackVehicleInfoDiagLeftBankedDown25ToLeftBankedFlat2, &TrackVehicleInfoDiagLeftBankedDown25ToLeftBankedFlat3, // TrackElemType::DiagLeftBankedDown25ToLeftBankedFlat
     &TrackVehicleInfoDiagRightBankedDown25ToRightBankedFlat0, &TrackVehicleInfoDiagRightBankedDown25ToRightBankedFlat1, &TrackVehicleInfoDiagRightBankedDown25ToRightBankedFlat2, &TrackVehicleInfoDiagRightBankedDown25ToRightBankedFlat3, // TrackElemType::DiagRightBankedDown25ToRightBankedFlat
     &TrackVehicleInfoDiagFlatToLeftBankedUp250, &TrackVehicleInfoDiagFlatToLeftBankedUp251, &TrackVehicleInfoDiagFlatToLeftBankedUp252, &TrackVehicleInfoDiagFlatToLeftBankedUp253, // TrackElemType::DiagFlatToLeftBankedUp25
     &TrackVehicleInfoDiagFlatToRightBankedUp250, &TrackVehicleInfoDiagFlatToRightBankedUp251, &TrackVehicleInfoDiagFlatToRightBankedUp252, &TrackVehicleInfoDiagFlatToRightBankedUp253, // TrackElemType::DiagFlatToRightBankedUp25
     &TrackVehicleInfoDiagLeftBankedUp25ToFlat0, &TrackVehicleInfoDiagLeftBankedUp25ToFlat1, &TrackVehicleInfoDiagLeftBankedUp25ToFlat2, &TrackVehicleInfoDiagLeftBankedUp25ToFlat3, // TrackElemType::DiagLeftBankedUp25ToFlat
     &TrackVehicleInfoDiagRightBankedUp25ToFlat0, &TrackVehicleInfoDiagRightBankedUp25ToFlat1, &TrackVehicleInfoDiagRightBankedUp25ToFlat2, &TrackVehicleInfoDiagRightBankedUp25ToFlat3, // TrackElemType::DiagRightBankedUp25ToFlat
     &TrackVehicleInfoDiagFlatToLeftBankedDown250, &TrackVehicleInfoDiagFlatToLeftBankedDown251, &TrackVehicleInfoDiagFlatToLeftBankedDown252, &TrackVehicleInfoDiagFlatToLeftBankedDown253, // TrackElemType::DiagFlatToLeftBankedDown25
     &TrackVehicleInfoDiagFlatToRightBankedDown250, &TrackVehicleInfoDiagFlatToRightBankedDown251, &TrackVehicleInfoDiagFlatToRightBankedDown252, &TrackVehicleInfoDiagFlatToRightBankedDown253, // TrackElemType::DiagFlatToRightBankedDown25
     &TrackVehicleInfoDiagLeftBankedDown25ToFlat0, &TrackVehicleInfoDiagLeftBankedDown25ToFlat1, &TrackVehicleInfoDiagLeftBankedDown25ToFlat2, &TrackVehicleInfoDiagLeftBankedDown25ToFlat3, // TrackElemType::DiagLeftBankedDown25ToFlat
     &TrackVehicleInfoDiagRightBankedDown25ToFlat0, &TrackVehicleInfoDiagRightBankedDown25ToFlat1, &TrackVehicleInfoDiagRightBankedDown25ToFlat2, &TrackVehicleInfoDiagRightBankedDown25ToFlat3, // TrackElemType::DiagRightBankedDown25ToFlat
     &TrackVehicleInfoDiagUp25LeftBanked0, &TrackVehicleInfoDiagUp25LeftBanked1, &TrackVehicleInfoDiagUp25LeftBanked2, &TrackVehicleInfoDiagUp25LeftBanked3, // TrackElemType::DiagUp25LeftBanked
     &TrackVehicleInfoDiagUp25RightBanked0, &TrackVehicleInfoDiagUp25RightBanked1, &TrackVehicleInfoDiagUp25RightBanked2, &TrackVehicleInfoDiagUp25RightBanked3, // TrackElemType::DiagUp25RightBanked
     &TrackVehicleInfoDiagDown25LeftBanked0, &TrackVehicleInfoDiagDown25LeftBanked1, &TrackVehicleInfoDiagDown25LeftBanked2, &TrackVehicleInfoDiagDown25LeftBanked3, // TrackElemType::DiagDown25LeftBanked
     &TrackVehicleInfoDiagDown25RightBanked0, &TrackVehicleInfoDiagDown25RightBanked1, &TrackVehicleInfoDiagDown25RightBanked2, &TrackVehicleInfoDiagDown25RightBanked3, // TrackElemType::DiagDown25RightBanked

     &TrackVehicleInfoLeftEighthBankToDiagUp250, &TrackVehicleInfoLeftEighthBankToDiagUp251, &TrackVehicleInfoLeftEighthBankToDiagUp252, &TrackVehicleInfoLeftEighthBankToDiagUp253, // TrackElemType::LeftEighthBankBankToDiagUp25
     &TrackVehicleInfoRightEighthBankToDiagUp250, &TrackVehicleInfoRightEighthBankToDiagUp251, &TrackVehicleInfoRightEighthBankToDiagUp252, &TrackVehicleInfoRightEighthBankToDiagUp253, // TrackElemType::RightEighthBankBankToDiagUp25
     &TrackVehicleInfoLeftEighthBankToDiagDown250, &TrackVehicleInfoLeftEighthBankToDiagDown251, &TrackVehicleInfoLeftEighthBankToDiagDown252, &TrackVehicleInfoLeftEighthBankToDiagDown253, // TrackElemType::LeftEighthBankBankToDiagDown25
     &TrackVehicleInfoRightEighthBankToDiagDown250, &TrackVehicleInfoRightEighthBankToDiagDown251, &TrackVehicleInfoRightEighthBankToDiagDown252, &TrackVehicleInfoRightEighthBankToDiagDown253, // TrackElemType::RightEighthBankBankToDiagDown25
     &TrackVehicleInfoLeftEighthBankToOrthogonalUp250, &TrackVehicleInfoLeftEighthBankToOrthogonalUp251, &TrackVehicleInfoLeftEighthBankToOrthogonalUp252, &TrackVehicleInfoLeftEighthBankToOrthogonalUp253, // TrackElemType::LeftEighthBankBankToOrthogonalUp25
     &TrackVehicleInfoRightEighthBankToOrthogonalUp250, &TrackVehicleInfoRightEighthBankToOrthogonalUp251, &TrackVehicleInfoRightEighthBankToOrthogonalUp252, &TrackVehicleInfoRightEighthBankToOrthogonalUp253, // TrackElemType::RightEighthBankBankToOrthogonalUp25
     &TrackVehicleInfoLeftEighthBankToOrthogonalDown250, &TrackVehicleInfoLeftEighthBankToOrthogonalDown251, &TrackVehicleInfoLeftEighthBankToOrthogonalDown252, &TrackVehicleInfoLeftEighthBankToOrthogonalDown253, // TrackElemType::LeftEighthBankBankToOrthogonalDown25
     &TrackVehicleInfoRightEighthBankToOrthogonalDown250, &TrackVehicleInfoRightEighthBankToOrthogonalDown251, &TrackVehicleInfoRightEighthBankToOrthogonalDown252, &TrackVehicleInfoRightEighthBankToOrthogonalDown253, // TrackElemType::RightEighthBankBankToOrthogonalDown25
    &TrackVehicleInfo_9162E6, &TrackVehicleInfo_916408, &TrackVehicleInfo_91652A, &TrackVehicleInfo_91664C,  // DiagBrakes
    &TrackVehicleInfo_9162E6, &TrackVehicleInfo_916408, &TrackVehicleInfo_91652A, &TrackVehicleInfo_91664C,  // DiagBlockBrakes
    &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4, &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18,  // SlopedBrakes
    &TrackVehicleInfo_9162E6, &TrackVehicleInfo_916408, &TrackVehicleInfo_91652A, &TrackVehicleInfo_91664C,  // DiagBooster
    &TrackVehicleInfoDiagFlatToUp60LongBase0  , &TrackVehicleInfoDiagFlatToUp60LongBase1  , &TrackVehicleInfoDiagFlatToUp60LongBase2 , &TrackVehicleInfoDiagFlatToUp60LongBase3  ,  //TrackElemType::DiagFlatToUp60LongBase,             
    &TrackVehicleInfoDiagUp60ToFlatLongBase0  , &TrackVehicleInfoDiagUp60ToFlatLongBase1  , &TrackVehicleInfoDiagUp60ToFlatLongBase2 , &TrackVehicleInfoDiagUp60ToFlatLongBase3  ,  //TrackElemType::DiagUp60ToFlatLongBase,
    &TrackVehicleInfoDiagFlatToDown60LongBase0, &TrackVehicleInfoDiagFlatToDown60LongBase1, &TrackVehicleInfoDiagFlatToDown60LongBase2, &TrackVehicleInfoDiagFlatToDown60LongBase3,  //TrackElemType::DiagFlatToDown60LongBase,
    &TrackVehicleInfoDiagDown60ToFlatLongBase0, &TrackVehicleInfoDiagDown60ToFlatLongBase1, &TrackVehicleInfoDiagDown60ToFlatLongBase2, &TrackVehicleInfoDiagDown60ToFlatLongBase3,  //TrackElemType::DiagDown60ToFlatLongBase,

    &TrackVehicleInfoLeftEighthDiveLoopUpToOrthogonal0   , &TrackVehicleInfoLeftEighthDiveLoopUpToOrthogonal1   , &TrackVehicleInfoLeftEighthDiveLoopUpToOrthogonal2   , &TrackVehicleInfoLeftEighthDiveLoopUpToOrthogonal3   ,  //TrackElemType::LeftEighthDiveLoopUpToOrthogonal   
    &TrackVehicleInfoRightEighthDiveLoopUpToOrthogonal0  , &TrackVehicleInfoRightEighthDiveLoopUpToOrthogonal1  , &TrackVehicleInfoRightEighthDiveLoopUpToOrthogonal2  , &TrackVehicleInfoRightEighthDiveLoopUpToOrthogonal3  ,  //TrackElemType::RightEighthDiveLoopUpToOrthogonal  
    &TrackVehicleInfoLeftEighthDiveLoopDownToOrthogonal0 , &TrackVehicleInfoLeftEighthDiveLoopDownToOrthogonal1 , &TrackVehicleInfoLeftEighthDiveLoopDownToOrthogonal2 , &TrackVehicleInfoLeftEighthDiveLoopDownToOrthogonal3 ,  //TrackElemType::LeftEighthDiveLoopDownToOrthogonal 
    &TrackVehicleInfoRightEighthDiveLoopDownToOrthogonal0, &TrackVehicleInfoRightEighthDiveLoopDownToOrthogonal1, &TrackVehicleInfoRightEighthDiveLoopDownToOrthogonal2, &TrackVehicleInfoRightEighthDiveLoopDownToOrthogonal3,  //TrackElemType::RightEighthDiveLoopDownToOrthogonal
    &TrackVehicleInfo_916BF6, &TrackVehicleInfo_916D18, &TrackVehicleInfo_916E3A, &TrackVehicleInfo_916F5C,  // DiagDown25Brakes
};
static_assert(std::size(TrackVehicleInfoListDefault) == VehicleTrackSubpositionSizeDefault);

static constexpr const VehicleInfoList *TrackVehicleInfoListChairliftGoingOut[] = {
    &TrackVehicleInfo_8CDBE2, &TrackVehicleInfo_8CDD04, &TrackVehicleInfo_8CDE26, &TrackVehicleInfo_8CDF48, &TrackVehicleInfo_8CDBE2, &TrackVehicleInfo_8CDD04,
    &TrackVehicleInfo_8CDE26, &TrackVehicleInfo_8CDF48, &TrackVehicleInfo_8CDBE2, &TrackVehicleInfo_8CDD04, &TrackVehicleInfo_8CDE26, &TrackVehicleInfo_8CDF48,
    &TrackVehicleInfo_8CDBE2, &TrackVehicleInfo_8CDD04, &TrackVehicleInfo_8CDE26, &TrackVehicleInfo_8CDF48, &TrackVehicleInfo_8CFB6E, &TrackVehicleInfo_8CFC90,
    &TrackVehicleInfo_8CFDB2, &TrackVehicleInfo_8CFED4, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554, &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8,
    &TrackVehicleInfo_8CE906, &TrackVehicleInfo_8CEA28, &TrackVehicleInfo_8CEB4A, &TrackVehicleInfo_8CEC6C, &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89,
    &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5, &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763,
    &TrackVehicleInfo_8CED8E, &TrackVehicleInfo_8CEEC2, &TrackVehicleInfo_8CEFF6, &TrackVehicleInfo_8CF12A, &TrackVehicleInfo_8CFFF6, &TrackVehicleInfo_8D0118,
    &TrackVehicleInfo_8D023A, &TrackVehicleInfo_8D035C, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C, &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300,
    &TrackVehicleInfo_8CF6E6, &TrackVehicleInfo_8CF808, &TrackVehicleInfo_8CF92A, &TrackVehicleInfo_8CFA4C, &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D,
    &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01, &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F,
    &TrackVehicleInfo_8CF25E, &TrackVehicleInfo_8CF380, &TrackVehicleInfo_8CF4A2, &TrackVehicleInfo_8CF5C4, &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496,
    &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D, &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE,
    &TrackVehicleInfo_8C3542, &TrackVehicleInfo_8C3664, &TrackVehicleInfo_8C3786, &TrackVehicleInfo_8C38A8, &TrackVehicleInfo_8C39CA, &TrackVehicleInfo_8C3AEC,
    &TrackVehicleInfo_8C3C0E, &TrackVehicleInfo_8C3D30, &TrackVehicleInfo_8C3E52, &TrackVehicleInfo_8C3F74, &TrackVehicleInfo_8C4096, &TrackVehicleInfo_8C41B8,
    &TrackVehicleInfo_8C42DA, &TrackVehicleInfo_8C43FC, &TrackVehicleInfo_8C451E, &TrackVehicleInfo_8C4640, &TrackVehicleInfo_8CA0B2, &TrackVehicleInfo_8CA4B6,
    &TrackVehicleInfo_8CA8C3, &TrackVehicleInfo_8CACC7, &TrackVehicleInfo_8CB0C2, &TrackVehicleInfo_8CB4BD, &TrackVehicleInfo_8CB8C1, &TrackVehicleInfo_8CBCCE,
    &TrackVehicleInfo_8C4762, &TrackVehicleInfo_8C4884, &TrackVehicleInfo_8C49A6, &TrackVehicleInfo_8C4AC8, &TrackVehicleInfo_8C4BEA, &TrackVehicleInfo_8C4D0C,
    &TrackVehicleInfo_8C4E2E, &TrackVehicleInfo_8C4F50, &TrackVehicleInfo_8C5072, &TrackVehicleInfo_8C51A6, &TrackVehicleInfo_8C52DA, &TrackVehicleInfo_8C540E,
    &TrackVehicleInfo_8C5542, &TrackVehicleInfo_8C5676, &TrackVehicleInfo_8C57AA, &TrackVehicleInfo_8C58DE, &TrackVehicleInfo_8C6322, &TrackVehicleInfo_8C6444,
    &TrackVehicleInfo_8C6566, &TrackVehicleInfo_8C6688, &TrackVehicleInfo_8C67AA, &TrackVehicleInfo_8C68CC, &TrackVehicleInfo_8C69EE, &TrackVehicleInfo_8C6B10,
    &TrackVehicleInfo_8C5A12, &TrackVehicleInfo_8C5B34, &TrackVehicleInfo_8C5C56, &TrackVehicleInfo_8C5D78, &TrackVehicleInfo_8C5E9A, &TrackVehicleInfo_8C5FBC,
    &TrackVehicleInfo_8C60DE, &TrackVehicleInfo_8C6200, &TrackVehicleInfo_8BEA02, &TrackVehicleInfo_8BEB24, &TrackVehicleInfo_8BEC46, &TrackVehicleInfo_8BED68,
    &TrackVehicleInfo_8BEE8A, &TrackVehicleInfo_8BEFAC, &TrackVehicleInfo_8BF0CE, &TrackVehicleInfo_8BF1F0, &TrackVehicleInfo_8D047E, &TrackVehicleInfo_8D0882,
    &TrackVehicleInfo_8D0C8F, &TrackVehicleInfo_8D1093, &TrackVehicleInfo_8D148E, &TrackVehicleInfo_8D1889, &TrackVehicleInfo_8D1C8D, &TrackVehicleInfo_8D209A,
    &TrackVehicleInfo_8D249E, &TrackVehicleInfo_8D28A2, &TrackVehicleInfo_8D2CAF, &TrackVehicleInfo_8D30B3, &TrackVehicleInfo_8D34AE, &TrackVehicleInfo_8D38A9,
    &TrackVehicleInfo_8D3CAD, &TrackVehicleInfo_8D40BA, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8D44BE, &TrackVehicleInfo_8D4FA6,
    &TrackVehicleInfo_8D5A8E, &TrackVehicleInfo_8D6576, &TrackVehicleInfo_8D705E, &TrackVehicleInfo_8D7B46, &TrackVehicleInfo_8D862E, &TrackVehicleInfo_8D9116,
    &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94, &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923,
    &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8, &TrackVehicleInfo_8E005E, &TrackVehicleInfo_8E02C4, &TrackVehicleInfo_8E0533, &TrackVehicleInfo_8E0799,
    &TrackVehicleInfo_8E09F6, &TrackVehicleInfo_8E0C53, &TrackVehicleInfo_8E0EB9, &TrackVehicleInfo_8E1128, &TrackVehicleInfo_8E26BE, &TrackVehicleInfo_8E2924,
    &TrackVehicleInfo_8E2B93, &TrackVehicleInfo_8E2DF9, &TrackVehicleInfo_8E3056, &TrackVehicleInfo_8E32B3, &TrackVehicleInfo_8E3519, &TrackVehicleInfo_8E3788,
    &TrackVehicleInfo_8E138E, &TrackVehicleInfo_8E15F4, &TrackVehicleInfo_8E1863, &TrackVehicleInfo_8E1AC9, &TrackVehicleInfo_8E1D26, &TrackVehicleInfo_8E1F83,
    &TrackVehicleInfo_8E21E9, &TrackVehicleInfo_8E2458, &TrackVehicleInfo_8FD922, &TrackVehicleInfo_8FD975, &TrackVehicleInfo_8FD9D1, &TrackVehicleInfo_8FDA24,
    &TrackVehicleInfo_8FDA6E, &TrackVehicleInfo_8FDBB4, &TrackVehicleInfo_8FDD03, &TrackVehicleInfo_8FDE5B, &TrackVehicleInfo_8D9BFE, &TrackVehicleInfo_8D9F60,
    &TrackVehicleInfo_8DA2C2, &TrackVehicleInfo_8DA624, &TrackVehicleInfo_8DA986, &TrackVehicleInfo_8DACE8, &TrackVehicleInfo_8DB04A, &TrackVehicleInfo_8DB3AC,
    &TrackVehicleInfo_8DB70E, &TrackVehicleInfo_8DBA70, &TrackVehicleInfo_8DBDD2, &TrackVehicleInfo_8DC134, &TrackVehicleInfo_8DC496, &TrackVehicleInfo_8DC7F8,
    &TrackVehicleInfo_8DCB5A, &TrackVehicleInfo_8DCEBC, &TrackVehicleInfo_8E644E, &TrackVehicleInfo_8E69F9, &TrackVehicleInfo_8E6FA4, &TrackVehicleInfo_8E754F,
    &TrackVehicleInfo_8E7AFA, &TrackVehicleInfo_8E80A5, &TrackVehicleInfo_8E8650, &TrackVehicleInfo_8E8BFB, &TrackVehicleInfo_8EA852, &TrackVehicleInfo_8EABBD,
    &TrackVehicleInfo_8EAF28, &TrackVehicleInfo_8EB293, &TrackVehicleInfo_8EB5FE, &TrackVehicleInfo_8EB969, &TrackVehicleInfo_8EBCD4, &TrackVehicleInfo_8EC03F,
    &TrackVehicleInfo_8EC3AA, &TrackVehicleInfo_8EC715, &TrackVehicleInfo_8ECA80, &TrackVehicleInfo_8ECDEB, &TrackVehicleInfo_8ED156, &TrackVehicleInfo_8ED4C1,
    &TrackVehicleInfo_8ED82C, &TrackVehicleInfo_8EDB97, &TrackVehicleInfo_8C6C32, &TrackVehicleInfo_8C6D78, &TrackVehicleInfo_8C6EBE, &TrackVehicleInfo_8C7004,
    &TrackVehicleInfo_8C714A, &TrackVehicleInfo_8C7290, &TrackVehicleInfo_8C73D6, &TrackVehicleInfo_8C751C, &TrackVehicleInfo_8C7662, &TrackVehicleInfo_8C77A8,
    &TrackVehicleInfo_8C78EE, &TrackVehicleInfo_8C7A34, &TrackVehicleInfo_8C7B7A, &TrackVehicleInfo_8C7CC0, &TrackVehicleInfo_8C7E06, &TrackVehicleInfo_8C7F4C,
    &TrackVehicleInfo_8EFA5A, &TrackVehicleInfo_8EFDAA, &TrackVehicleInfo_8F00FA, &TrackVehicleInfo_8F044A, &TrackVehicleInfo_8F079A, &TrackVehicleInfo_8F08BC,
    &TrackVehicleInfo_8F09DE, &TrackVehicleInfo_8F0B00, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,
    &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C, &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554,
    &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8, &TrackVehicleInfo_8BFC1A, &TrackVehicleInfo_8BFD3C, &TrackVehicleInfo_8BFE5E, &TrackVehicleInfo_8BFF80,
    &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89, &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5,
    &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763, &TrackVehicleInfo_8C00A2, &TrackVehicleInfo_8C01C4, &TrackVehicleInfo_8C02E6, &TrackVehicleInfo_8C0408,
    &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4, &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C,
    &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300, &TrackVehicleInfo_8C09B2, &TrackVehicleInfo_8C0AD4, &TrackVehicleInfo_8C0BF6, &TrackVehicleInfo_8C0D18,
    &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D, &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01,
    &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F, &TrackVehicleInfo_8C052A, &TrackVehicleInfo_8C064C, &TrackVehicleInfo_8C076E, &TrackVehicleInfo_8C0890,
    &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496, &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D,
    &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94,
    &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923, &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8,
    &TrackVehicleInfo_8F8C82, &TrackVehicleInfo_8F9143, &TrackVehicleInfo_8F9616, &TrackVehicleInfo_8F9AE9, &TrackVehicleInfo_8F9FAA, &TrackVehicleInfo_8FA46B,
    &TrackVehicleInfo_8FA93E, &TrackVehicleInfo_8FAE11, &TrackVehicleInfo_8FB2D2, &TrackVehicleInfo_8FB793, &TrackVehicleInfo_8FBC66, &TrackVehicleInfo_8FC139,
    &TrackVehicleInfo_8FC5FA, &TrackVehicleInfo_8FCABB, &TrackVehicleInfo_8FCF8E, &TrackVehicleInfo_8FD461, &TrackVehicleInfo_8F0C22, &TrackVehicleInfo_8F141F,
    &TrackVehicleInfo_8F1C2E, &TrackVehicleInfo_8F243D, &TrackVehicleInfo_8F2C3A, &TrackVehicleInfo_8F3437, &TrackVehicleInfo_8F3C46, &TrackVehicleInfo_8F4455,
    &TrackVehicleInfo_8F4C52, &TrackVehicleInfo_8F544F, &TrackVehicleInfo_8F5C5E, &TrackVehicleInfo_8F646D, &TrackVehicleInfo_8F6C6A, &TrackVehicleInfo_8F7467,
    &TrackVehicleInfo_8F7C76, &TrackVehicleInfo_8F8485, &TrackVehicleInfo_8E402E, &TrackVehicleInfo_8E4270, &TrackVehicleInfo_8E44B2, &TrackVehicleInfo_8E46F4,
    &TrackVehicleInfo_8E4936, &TrackVehicleInfo_8E4B78, &TrackVehicleInfo_8E4DBA, &TrackVehicleInfo_8E4FFC, &TrackVehicleInfo_8E523E, &TrackVehicleInfo_8E5480,
    &TrackVehicleInfo_8E56C2, &TrackVehicleInfo_8E5904, &TrackVehicleInfo_8E5B46, &TrackVehicleInfo_8E5D88, &TrackVehicleInfo_8E5FCA, &TrackVehicleInfo_8E620C,
    &TrackVehicleInfo_8CDBE2, &TrackVehicleInfo_8CDD04, &TrackVehicleInfo_8CDE26, &TrackVehicleInfo_8CDF48, &TrackVehicleInfo_8CDBE2, &TrackVehicleInfo_8CDD04,
    &TrackVehicleInfo_8CDE26, &TrackVehicleInfo_8CDF48, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_8B0EB2, &TrackVehicleInfo_8B12B6, &TrackVehicleInfo_8B16C3, &TrackVehicleInfo_8B1AC7, &TrackVehicleInfo_8B1EC2, &TrackVehicleInfo_8B22BD,
    &TrackVehicleInfo_8B26C1, &TrackVehicleInfo_8B2ACE, &TrackVehicleInfo_8B2ED2, &TrackVehicleInfo_8B32D6, &TrackVehicleInfo_8B36E3, &TrackVehicleInfo_8B3AE7,
    &TrackVehicleInfo_8B3EE2, &TrackVehicleInfo_8B42DD, &TrackVehicleInfo_8B46E1, &TrackVehicleInfo_8B4AEE, &TrackVehicleInfo_8B4EF2, &TrackVehicleInfo_8B52F6,
    &TrackVehicleInfo_8B5703, &TrackVehicleInfo_8B5B07, &TrackVehicleInfo_8B5F02, &TrackVehicleInfo_8B62FD, &TrackVehicleInfo_8B6701, &TrackVehicleInfo_8B6B0E,
    &TrackVehicleInfo_8B6F12, &TrackVehicleInfo_8B7316, &TrackVehicleInfo_8B7723, &TrackVehicleInfo_8B7B27, &TrackVehicleInfo_8B7F22, &TrackVehicleInfo_8B831D,
    &TrackVehicleInfo_8B8721, &TrackVehicleInfo_8B8B2E, &TrackVehicleInfo_968C6E, &TrackVehicleInfo_968D90, &TrackVehicleInfo_968EB2, &TrackVehicleInfo_968FD4,
    &TrackVehicleInfo_96957E, &TrackVehicleInfo_9696A0, &TrackVehicleInfo_9697C2, &TrackVehicleInfo_9698E4, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C,
    &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_9048E8, &TrackVehicleInfo_904A0A, &TrackVehicleInfo_904B2C, &TrackVehicleInfo_904C4E,
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_9690F6, &TrackVehicleInfo_969218,
    &TrackVehicleInfo_96933A, &TrackVehicleInfo_96945C, &TrackVehicleInfo_969A06, &TrackVehicleInfo_969B28, &TrackVehicleInfo_969C4A, &TrackVehicleInfo_969D6C,
    &TrackVehicleInfo_904D72, &TrackVehicleInfo_905314, &TrackVehicleInfo_9058B6, &TrackVehicleInfo_905E58, &TrackVehicleInfo_96D4AE, &TrackVehicleInfo_96D9A5,
    &TrackVehicleInfo_96DE9C, &TrackVehicleInfo_96E393, &TrackVehicleInfo_96E88A, &TrackVehicleInfo_96ED81, &TrackVehicleInfo_96F278, &TrackVehicleInfo_96F76F,
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_971042, &TrackVehicleInfo_971539,
    &TrackVehicleInfo_971A30, &TrackVehicleInfo_971F27, &TrackVehicleInfo_96FC66, &TrackVehicleInfo_97015D, &TrackVehicleInfo_970654, &TrackVehicleInfo_970B4B,
    &TrackVehicleInfo_97241E, &TrackVehicleInfo_9729ED, &TrackVehicleInfo_972FBC, &TrackVehicleInfo_97358B, &TrackVehicleInfo_9063FA, &TrackVehicleInfo_906EAC,
    &TrackVehicleInfo_90795E, &TrackVehicleInfo_908410, &TrackVehicleInfo_90B98A, &TrackVehicleInfo_90BC5C, &TrackVehicleInfo_90BF2E, &TrackVehicleInfo_90C200,
    &TrackVehicleInfo_90E02A, &TrackVehicleInfo_90E14C, &TrackVehicleInfo_90E26E, &TrackVehicleInfo_90E390, &TrackVehicleInfo_90E4B2, &TrackVehicleInfo_90E5D4,
    &TrackVehicleInfo_90E6F6, &TrackVehicleInfo_90E818, &TrackVehicleInfo_90E93A, &TrackVehicleInfo_90EB34, &TrackVehicleInfo_90ED2E, &TrackVehicleInfo_90EF28,
    &TrackVehicleInfo_9100F2, &TrackVehicleInfo_9102EC, &TrackVehicleInfo_9104E6, &TrackVehicleInfo_9106E0, &TrackVehicleInfo_90F122, &TrackVehicleInfo_90F31C,
    &TrackVehicleInfo_90F516, &TrackVehicleInfo_90F710, &TrackVehicleInfo_90F90A, &TrackVehicleInfo_90FB04, &TrackVehicleInfo_90FCFE, &TrackVehicleInfo_90FEF8,
    &TrackVehicleInfo_8C7662, &TrackVehicleInfo_8C77A8, &TrackVehicleInfo_8C78EE, &TrackVehicleInfo_8C7A34, &TrackVehicleInfo_9108DA, &TrackVehicleInfo_910BA3,
    &TrackVehicleInfo_910E75, &TrackVehicleInfo_911147, &TrackVehicleInfo_911F58, &TrackVehicleInfo_91222A, &TrackVehicleInfo_9124FC, &TrackVehicleInfo_9127CE,
    &TrackVehicleInfo_911419, &TrackVehicleInfo_9116E2, &TrackVehicleInfo_9119B4, &TrackVehicleInfo_911C86, &TrackVehicleInfo_912AA0, &TrackVehicleInfo_912D69,
    &TrackVehicleInfo_91303B, &TrackVehicleInfo_91330D, &TrackVehicleInfo_9135DF, &TrackVehicleInfo_9138A8, &TrackVehicleInfo_913B7A, &TrackVehicleInfo_913E4C,
    &TrackVehicleInfo_914C5D, &TrackVehicleInfo_914F2F, &TrackVehicleInfo_915201, &TrackVehicleInfo_9154D3, &TrackVehicleInfo_91411E, &TrackVehicleInfo_9143E7,
    &TrackVehicleInfo_9146B9, &TrackVehicleInfo_91498B, &TrackVehicleInfo_9157A5, &TrackVehicleInfo_915A6E, &TrackVehicleInfo_915D40, &TrackVehicleInfo_916012,
    &TrackVehicleInfo_9162E6, &TrackVehicleInfo_916408, &TrackVehicleInfo_91652A, &TrackVehicleInfo_91664C, &TrackVehicleInfo_91676E, &TrackVehicleInfo_916890,
    &TrackVehicleInfo_9169B2, &TrackVehicleInfo_916AD4, &TrackVehicleInfo_91707E, &TrackVehicleInfo_9172C0, &TrackVehicleInfo_917502, &TrackVehicleInfo_917744,
    &TrackVehicleInfo_91828E, &TrackVehicleInfo_9183B0, &TrackVehicleInfo_9184D2, &TrackVehicleInfo_9185F4, &TrackVehicleInfo_9194F6, &TrackVehicleInfo_919645,
    &TrackVehicleInfo_919794, &TrackVehicleInfo_9198E3, &TrackVehicleInfo_919A32, &TrackVehicleInfo_919B81, &TrackVehicleInfo_919CD0, &TrackVehicleInfo_919E1F,
    &TrackVehicleInfo_918716, &TrackVehicleInfo_91884A, &TrackVehicleInfo_91897E, &TrackVehicleInfo_918AB2, &TrackVehicleInfo_916BF6, &TrackVehicleInfo_916D18,
    &TrackVehicleInfo_916E3A, &TrackVehicleInfo_916F5C, &TrackVehicleInfo_917986, &TrackVehicleInfo_917BC8, &TrackVehicleInfo_917E0A, &TrackVehicleInfo_91804C,
    &TrackVehicleInfo_91906E, &TrackVehicleInfo_919190, &TrackVehicleInfo_9192B2, &TrackVehicleInfo_9193D4, &TrackVehicleInfo_91A4AA, &TrackVehicleInfo_91A5F9,
    &TrackVehicleInfo_91A748, &TrackVehicleInfo_91A897, &TrackVehicleInfo_919F6E, &TrackVehicleInfo_91A0BD, &TrackVehicleInfo_91A20C, &TrackVehicleInfo_91A35B,
    &TrackVehicleInfo_918BE6, &TrackVehicleInfo_918D08, &TrackVehicleInfo_918E2A, &TrackVehicleInfo_918F4C, &TrackVehicleInfo_91A9E6, &TrackVehicleInfo_91AB2C,
    &TrackVehicleInfo_91AC72, &TrackVehicleInfo_91ADB8, &TrackVehicleInfo_91AEFE, &TrackVehicleInfo_91B044, &TrackVehicleInfo_91B18A, &TrackVehicleInfo_91B2D0,
    &TrackVehicleInfo_91B416, &TrackVehicleInfo_91B55C, &TrackVehicleInfo_91B6A2, &TrackVehicleInfo_91B7E8, &TrackVehicleInfo_91B92E, &TrackVehicleInfo_91BA74,
    &TrackVehicleInfo_91BBBA, &TrackVehicleInfo_91BD00, &TrackVehicleInfo_95787E, &TrackVehicleInfo_9579A0, &TrackVehicleInfo_957AC2, &TrackVehicleInfo_957BE4,
    &TrackVehicleInfo_957D06, &TrackVehicleInfo_957E28, &TrackVehicleInfo_957F4A, &TrackVehicleInfo_95806C, &TrackVehicleInfo_95818E, &TrackVehicleInfo_9582B0,
    &TrackVehicleInfo_9583D2, &TrackVehicleInfo_9584F4, &TrackVehicleInfo_958616, &TrackVehicleInfo_958738, &TrackVehicleInfo_95885A, &TrackVehicleInfo_95897C,
    &TrackVehicleInfo_958A9E, &TrackVehicleInfo_958BC0, &TrackVehicleInfo_958CE2, &TrackVehicleInfo_958E04, &TrackVehicleInfo_958F26, &TrackVehicleInfo_959048,
    &TrackVehicleInfo_95916A, &TrackVehicleInfo_95928C, &TrackVehicleInfo_9593AE, &TrackVehicleInfo_9594E2, &TrackVehicleInfo_959616, &TrackVehicleInfo_95974A,
    &TrackVehicleInfo_95987E, &TrackVehicleInfo_9599B2, &TrackVehicleInfo_959AE6, &TrackVehicleInfo_959C1A, &TrackVehicleInfo_95A65E, &TrackVehicleInfo_95A780,
    &TrackVehicleInfo_95A8A2, &TrackVehicleInfo_95A9C4, &TrackVehicleInfo_95AAE6, &TrackVehicleInfo_95AC08, &TrackVehicleInfo_95AD2A, &TrackVehicleInfo_95AE4C,
    &TrackVehicleInfo_959D4E, &TrackVehicleInfo_959E70, &TrackVehicleInfo_959F92, &TrackVehicleInfo_95A0B4, &TrackVehicleInfo_95A1D6, &TrackVehicleInfo_95A2F8,
    &TrackVehicleInfo_95A41A, &TrackVehicleInfo_95A53C, &TrackVehicleInfo_95AF6E, &TrackVehicleInfo_95B090, &TrackVehicleInfo_95B1B2, &TrackVehicleInfo_95B2D4,
    &TrackVehicleInfo_95B3F6, &TrackVehicleInfo_95B518, &TrackVehicleInfo_95B63A, &TrackVehicleInfo_95B75C, &TrackVehicleInfo_91BE46, &TrackVehicleInfo_91C001,
    &TrackVehicleInfo_91C1BC, &TrackVehicleInfo_91C377,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListChairliftGoingBack[] = {
    &TrackVehicleInfo_8CDE26, &TrackVehicleInfo_8CDF48, &TrackVehicleInfo_8CDBE2, &TrackVehicleInfo_8CDD04, &TrackVehicleInfo_8CDE26, &TrackVehicleInfo_8CDF48,
    &TrackVehicleInfo_8CDBE2, &TrackVehicleInfo_8CDD04, &TrackVehicleInfo_8CDE26, &TrackVehicleInfo_8CDF48, &TrackVehicleInfo_8CDBE2, &TrackVehicleInfo_8CDD04,
    &TrackVehicleInfo_8CDE26, &TrackVehicleInfo_8CDF48, &TrackVehicleInfo_8CDBE2, &TrackVehicleInfo_8CDD04, &TrackVehicleInfo_8D023A, &TrackVehicleInfo_8D035C,
    &TrackVehicleInfo_8CFFF6, &TrackVehicleInfo_8D0118, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554, &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8,
    &TrackVehicleInfo_8CF4A2, &TrackVehicleInfo_8CF5C4, &TrackVehicleInfo_8CF25E, &TrackVehicleInfo_8CF380, &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89,
    &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5, &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763,
    &TrackVehicleInfo_8CF92A, &TrackVehicleInfo_8CFA4C, &TrackVehicleInfo_8CF6E6, &TrackVehicleInfo_8CF808, &TrackVehicleInfo_8CFDB2, &TrackVehicleInfo_8CFED4,
    &TrackVehicleInfo_8CFB6E, &TrackVehicleInfo_8CFC90, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C, &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300,
    &TrackVehicleInfo_8CEFF6, &TrackVehicleInfo_8CF12A, &TrackVehicleInfo_8CED8E, &TrackVehicleInfo_8CEEC2, &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D,
    &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01, &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F,
    &TrackVehicleInfo_8CEB4A, &TrackVehicleInfo_8CEC6C, &TrackVehicleInfo_8CE906, &TrackVehicleInfo_8CEA28, &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496,
    &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D, &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE,
    &TrackVehicleInfo_8C3542, &TrackVehicleInfo_8C3664, &TrackVehicleInfo_8C3786, &TrackVehicleInfo_8C38A8, &TrackVehicleInfo_8C39CA, &TrackVehicleInfo_8C3AEC,
    &TrackVehicleInfo_8C3C0E, &TrackVehicleInfo_8C3D30, &TrackVehicleInfo_8C3E52, &TrackVehicleInfo_8C3F74, &TrackVehicleInfo_8C4096, &TrackVehicleInfo_8C41B8,
    &TrackVehicleInfo_8C42DA, &TrackVehicleInfo_8C43FC, &TrackVehicleInfo_8C451E, &TrackVehicleInfo_8C4640, &TrackVehicleInfo_8CA0B2, &TrackVehicleInfo_8CA4B6,
    &TrackVehicleInfo_8CA8C3, &TrackVehicleInfo_8CACC7, &TrackVehicleInfo_8CB0C2, &TrackVehicleInfo_8CB4BD, &TrackVehicleInfo_8CB8C1, &TrackVehicleInfo_8CBCCE,
    &TrackVehicleInfo_8C4762, &TrackVehicleInfo_8C4884, &TrackVehicleInfo_8C49A6, &TrackVehicleInfo_8C4AC8, &TrackVehicleInfo_8C4BEA, &TrackVehicleInfo_8C4D0C,
    &TrackVehicleInfo_8C4E2E, &TrackVehicleInfo_8C4F50, &TrackVehicleInfo_8C5072, &TrackVehicleInfo_8C51A6, &TrackVehicleInfo_8C52DA, &TrackVehicleInfo_8C540E,
    &TrackVehicleInfo_8C5542, &TrackVehicleInfo_8C5676, &TrackVehicleInfo_8C57AA, &TrackVehicleInfo_8C58DE, &TrackVehicleInfo_8C6322, &TrackVehicleInfo_8C6444,
    &TrackVehicleInfo_8C6566, &TrackVehicleInfo_8C6688, &TrackVehicleInfo_8C67AA, &TrackVehicleInfo_8C68CC, &TrackVehicleInfo_8C69EE, &TrackVehicleInfo_8C6B10,
    &TrackVehicleInfo_8C5A12, &TrackVehicleInfo_8C5B34, &TrackVehicleInfo_8C5C56, &TrackVehicleInfo_8C5D78, &TrackVehicleInfo_8C5E9A, &TrackVehicleInfo_8C5FBC,
    &TrackVehicleInfo_8C60DE, &TrackVehicleInfo_8C6200, &TrackVehicleInfo_8BEA02, &TrackVehicleInfo_8BEB24, &TrackVehicleInfo_8BEC46, &TrackVehicleInfo_8BED68,
    &TrackVehicleInfo_8BEE8A, &TrackVehicleInfo_8BEFAC, &TrackVehicleInfo_8BF0CE, &TrackVehicleInfo_8BF1F0, &TrackVehicleInfo_8D047E, &TrackVehicleInfo_8D0882,
    &TrackVehicleInfo_8D0C8F, &TrackVehicleInfo_8D1093, &TrackVehicleInfo_8D148E, &TrackVehicleInfo_8D1889, &TrackVehicleInfo_8D1C8D, &TrackVehicleInfo_8D209A,
    &TrackVehicleInfo_8D249E, &TrackVehicleInfo_8D28A2, &TrackVehicleInfo_8D2CAF, &TrackVehicleInfo_8D30B3, &TrackVehicleInfo_8D34AE, &TrackVehicleInfo_8D38A9,
    &TrackVehicleInfo_8D3CAD, &TrackVehicleInfo_8D40BA, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8D44BE, &TrackVehicleInfo_8D4FA6,
    &TrackVehicleInfo_8D5A8E, &TrackVehicleInfo_8D6576, &TrackVehicleInfo_8D705E, &TrackVehicleInfo_8D7B46, &TrackVehicleInfo_8D862E, &TrackVehicleInfo_8D9116,
    &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94, &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923,
    &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8, &TrackVehicleInfo_8E005E, &TrackVehicleInfo_8E02C4, &TrackVehicleInfo_8E0533, &TrackVehicleInfo_8E0799,
    &TrackVehicleInfo_8E09F6, &TrackVehicleInfo_8E0C53, &TrackVehicleInfo_8E0EB9, &TrackVehicleInfo_8E1128, &TrackVehicleInfo_8E26BE, &TrackVehicleInfo_8E2924,
    &TrackVehicleInfo_8E2B93, &TrackVehicleInfo_8E2DF9, &TrackVehicleInfo_8E3056, &TrackVehicleInfo_8E32B3, &TrackVehicleInfo_8E3519, &TrackVehicleInfo_8E3788,
    &TrackVehicleInfo_8E138E, &TrackVehicleInfo_8E15F4, &TrackVehicleInfo_8E1863, &TrackVehicleInfo_8E1AC9, &TrackVehicleInfo_8E1D26, &TrackVehicleInfo_8E1F83,
    &TrackVehicleInfo_8E21E9, &TrackVehicleInfo_8E2458, &TrackVehicleInfo_8FDBB4, &TrackVehicleInfo_8FDD03, &TrackVehicleInfo_8FDE5B, &TrackVehicleInfo_8FDA6E,
    &TrackVehicleInfo_8FDA24, &TrackVehicleInfo_8FD922, &TrackVehicleInfo_8FD975, &TrackVehicleInfo_8FD9D1, &TrackVehicleInfo_8D9BFE, &TrackVehicleInfo_8D9F60,
    &TrackVehicleInfo_8DA2C2, &TrackVehicleInfo_8DA624, &TrackVehicleInfo_8DA986, &TrackVehicleInfo_8DACE8, &TrackVehicleInfo_8DB04A, &TrackVehicleInfo_8DB3AC,
    &TrackVehicleInfo_8DB70E, &TrackVehicleInfo_8DBA70, &TrackVehicleInfo_8DBDD2, &TrackVehicleInfo_8DC134, &TrackVehicleInfo_8DC496, &TrackVehicleInfo_8DC7F8,
    &TrackVehicleInfo_8DCB5A, &TrackVehicleInfo_8DCEBC, &TrackVehicleInfo_8E644E, &TrackVehicleInfo_8E69F9, &TrackVehicleInfo_8E6FA4, &TrackVehicleInfo_8E754F,
    &TrackVehicleInfo_8E7AFA, &TrackVehicleInfo_8E80A5, &TrackVehicleInfo_8E8650, &TrackVehicleInfo_8E8BFB, &TrackVehicleInfo_8EA852, &TrackVehicleInfo_8EABBD,
    &TrackVehicleInfo_8EAF28, &TrackVehicleInfo_8EB293, &TrackVehicleInfo_8EB5FE, &TrackVehicleInfo_8EB969, &TrackVehicleInfo_8EBCD4, &TrackVehicleInfo_8EC03F,
    &TrackVehicleInfo_8EC3AA, &TrackVehicleInfo_8EC715, &TrackVehicleInfo_8ECA80, &TrackVehicleInfo_8ECDEB, &TrackVehicleInfo_8ED156, &TrackVehicleInfo_8ED4C1,
    &TrackVehicleInfo_8ED82C, &TrackVehicleInfo_8EDB97, &TrackVehicleInfo_8C6C32, &TrackVehicleInfo_8C6D78, &TrackVehicleInfo_8C6EBE, &TrackVehicleInfo_8C7004,
    &TrackVehicleInfo_8C714A, &TrackVehicleInfo_8C7290, &TrackVehicleInfo_8C73D6, &TrackVehicleInfo_8C751C, &TrackVehicleInfo_8C7662, &TrackVehicleInfo_8C77A8,
    &TrackVehicleInfo_8C78EE, &TrackVehicleInfo_8C7A34, &TrackVehicleInfo_8C7B7A, &TrackVehicleInfo_8C7CC0, &TrackVehicleInfo_8C7E06, &TrackVehicleInfo_8C7F4C,
    &TrackVehicleInfo_8EFA5A, &TrackVehicleInfo_8EFDAA, &TrackVehicleInfo_8F00FA, &TrackVehicleInfo_8F044A, &TrackVehicleInfo_8F079A, &TrackVehicleInfo_8F08BC,
    &TrackVehicleInfo_8F09DE, &TrackVehicleInfo_8F0B00, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,
    &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C, &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554,
    &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8, &TrackVehicleInfo_8BFC1A, &TrackVehicleInfo_8BFD3C, &TrackVehicleInfo_8BFE5E, &TrackVehicleInfo_8BFF80,
    &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89, &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5,
    &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763, &TrackVehicleInfo_8C00A2, &TrackVehicleInfo_8C01C4, &TrackVehicleInfo_8C02E6, &TrackVehicleInfo_8C0408,
    &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4, &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C,
    &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300, &TrackVehicleInfo_8C09B2, &TrackVehicleInfo_8C0AD4, &TrackVehicleInfo_8C0BF6, &TrackVehicleInfo_8C0D18,
    &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D, &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01,
    &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F, &TrackVehicleInfo_8C052A, &TrackVehicleInfo_8C064C, &TrackVehicleInfo_8C076E, &TrackVehicleInfo_8C0890,
    &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496, &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D,
    &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94,
    &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923, &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8,
    &TrackVehicleInfo_8F8C82, &TrackVehicleInfo_8F9143, &TrackVehicleInfo_8F9616, &TrackVehicleInfo_8F9AE9, &TrackVehicleInfo_8F9FAA, &TrackVehicleInfo_8FA46B,
    &TrackVehicleInfo_8FA93E, &TrackVehicleInfo_8FAE11, &TrackVehicleInfo_8FB2D2, &TrackVehicleInfo_8FB793, &TrackVehicleInfo_8FBC66, &TrackVehicleInfo_8FC139,
    &TrackVehicleInfo_8FC5FA, &TrackVehicleInfo_8FCABB, &TrackVehicleInfo_8FCF8E, &TrackVehicleInfo_8FD461, &TrackVehicleInfo_8F0C22, &TrackVehicleInfo_8F141F,
    &TrackVehicleInfo_8F1C2E, &TrackVehicleInfo_8F243D, &TrackVehicleInfo_8F2C3A, &TrackVehicleInfo_8F3437, &TrackVehicleInfo_8F3C46, &TrackVehicleInfo_8F4455,
    &TrackVehicleInfo_8F4C52, &TrackVehicleInfo_8F544F, &TrackVehicleInfo_8F5C5E, &TrackVehicleInfo_8F646D, &TrackVehicleInfo_8F6C6A, &TrackVehicleInfo_8F7467,
    &TrackVehicleInfo_8F7C76, &TrackVehicleInfo_8F8485, &TrackVehicleInfo_8E402E, &TrackVehicleInfo_8E4270, &TrackVehicleInfo_8E44B2, &TrackVehicleInfo_8E46F4,
    &TrackVehicleInfo_8E4936, &TrackVehicleInfo_8E4B78, &TrackVehicleInfo_8E4DBA, &TrackVehicleInfo_8E4FFC, &TrackVehicleInfo_8E523E, &TrackVehicleInfo_8E5480,
    &TrackVehicleInfo_8E56C2, &TrackVehicleInfo_8E5904, &TrackVehicleInfo_8E5B46, &TrackVehicleInfo_8E5D88, &TrackVehicleInfo_8E5FCA, &TrackVehicleInfo_8E620C,
    &TrackVehicleInfo_8CDE26, &TrackVehicleInfo_8CDF48, &TrackVehicleInfo_8CDBE2, &TrackVehicleInfo_8CDD04, &TrackVehicleInfo_8CDE26, &TrackVehicleInfo_8CDF48,
    &TrackVehicleInfo_8CDBE2, &TrackVehicleInfo_8CDD04,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListChairliftEndBullwheel[] = {
    &TrackVehicleInfo_8CE06A, &TrackVehicleInfo_8CE291, &TrackVehicleInfo_8CE4B8, &TrackVehicleInfo_8CE6DF, &TrackVehicleInfo_8CE06A, &TrackVehicleInfo_8CE291,
    &TrackVehicleInfo_8CE4B8, &TrackVehicleInfo_8CE6DF, &TrackVehicleInfo_8CE06A, &TrackVehicleInfo_8CE291, &TrackVehicleInfo_8CE4B8, &TrackVehicleInfo_8CE6DF,
    &TrackVehicleInfo_8CE06A, &TrackVehicleInfo_8CE291, &TrackVehicleInfo_8CE4B8, &TrackVehicleInfo_8CE6DF, &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C,
    &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554, &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8,
    &TrackVehicleInfo_8BFC1A, &TrackVehicleInfo_8BFD3C, &TrackVehicleInfo_8BFE5E, &TrackVehicleInfo_8BFF80, &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89,
    &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5, &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763,
    &TrackVehicleInfo_8C00A2, &TrackVehicleInfo_8C01C4, &TrackVehicleInfo_8C02E6, &TrackVehicleInfo_8C0408, &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4,
    &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C, &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300,
    &TrackVehicleInfo_8C09B2, &TrackVehicleInfo_8C0AD4, &TrackVehicleInfo_8C0BF6, &TrackVehicleInfo_8C0D18, &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D,
    &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01, &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F,
    &TrackVehicleInfo_8C052A, &TrackVehicleInfo_8C064C, &TrackVehicleInfo_8C076E, &TrackVehicleInfo_8C0890, &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496,
    &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D, &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE,
    &TrackVehicleInfo_8C3542, &TrackVehicleInfo_8C3664, &TrackVehicleInfo_8C3786, &TrackVehicleInfo_8C38A8, &TrackVehicleInfo_8C39CA, &TrackVehicleInfo_8C3AEC,
    &TrackVehicleInfo_8C3C0E, &TrackVehicleInfo_8C3D30, &TrackVehicleInfo_8C3E52, &TrackVehicleInfo_8C3F74, &TrackVehicleInfo_8C4096, &TrackVehicleInfo_8C41B8,
    &TrackVehicleInfo_8C42DA, &TrackVehicleInfo_8C43FC, &TrackVehicleInfo_8C451E, &TrackVehicleInfo_8C4640, &TrackVehicleInfo_8CA0B2, &TrackVehicleInfo_8CA4B6,
    &TrackVehicleInfo_8CA8C3, &TrackVehicleInfo_8CACC7, &TrackVehicleInfo_8CB0C2, &TrackVehicleInfo_8CB4BD, &TrackVehicleInfo_8CB8C1, &TrackVehicleInfo_8CBCCE,
    &TrackVehicleInfo_8C4762, &TrackVehicleInfo_8C4884, &TrackVehicleInfo_8C49A6, &TrackVehicleInfo_8C4AC8, &TrackVehicleInfo_8C4BEA, &TrackVehicleInfo_8C4D0C,
    &TrackVehicleInfo_8C4E2E, &TrackVehicleInfo_8C4F50, &TrackVehicleInfo_8C5072, &TrackVehicleInfo_8C51A6, &TrackVehicleInfo_8C52DA, &TrackVehicleInfo_8C540E,
    &TrackVehicleInfo_8C5542, &TrackVehicleInfo_8C5676, &TrackVehicleInfo_8C57AA, &TrackVehicleInfo_8C58DE, &TrackVehicleInfo_8C6322, &TrackVehicleInfo_8C6444,
    &TrackVehicleInfo_8C6566, &TrackVehicleInfo_8C6688, &TrackVehicleInfo_8C67AA, &TrackVehicleInfo_8C68CC, &TrackVehicleInfo_8C69EE, &TrackVehicleInfo_8C6B10,
    &TrackVehicleInfo_8C5A12, &TrackVehicleInfo_8C5B34, &TrackVehicleInfo_8C5C56, &TrackVehicleInfo_8C5D78, &TrackVehicleInfo_8C5E9A, &TrackVehicleInfo_8C5FBC,
    &TrackVehicleInfo_8C60DE, &TrackVehicleInfo_8C6200, &TrackVehicleInfo_8BEA02, &TrackVehicleInfo_8BEB24, &TrackVehicleInfo_8BEC46, &TrackVehicleInfo_8BED68,
    &TrackVehicleInfo_8BEE8A, &TrackVehicleInfo_8BEFAC, &TrackVehicleInfo_8BF0CE, &TrackVehicleInfo_8BF1F0, &TrackVehicleInfo_8D047E, &TrackVehicleInfo_8D0882,
    &TrackVehicleInfo_8D0C8F, &TrackVehicleInfo_8D1093, &TrackVehicleInfo_8D148E, &TrackVehicleInfo_8D1889, &TrackVehicleInfo_8D1C8D, &TrackVehicleInfo_8D209A,
    &TrackVehicleInfo_8D249E, &TrackVehicleInfo_8D28A2, &TrackVehicleInfo_8D2CAF, &TrackVehicleInfo_8D30B3, &TrackVehicleInfo_8D34AE, &TrackVehicleInfo_8D38A9,
    &TrackVehicleInfo_8D3CAD, &TrackVehicleInfo_8D40BA, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8D44BE, &TrackVehicleInfo_8D4FA6,
    &TrackVehicleInfo_8D5A8E, &TrackVehicleInfo_8D6576, &TrackVehicleInfo_8D705E, &TrackVehicleInfo_8D7B46, &TrackVehicleInfo_8D862E, &TrackVehicleInfo_8D9116,
    &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94, &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923,
    &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8, &TrackVehicleInfo_8E005E, &TrackVehicleInfo_8E02C4, &TrackVehicleInfo_8E0533, &TrackVehicleInfo_8E0799,
    &TrackVehicleInfo_8E09F6, &TrackVehicleInfo_8E0C53, &TrackVehicleInfo_8E0EB9, &TrackVehicleInfo_8E1128, &TrackVehicleInfo_8E26BE, &TrackVehicleInfo_8E2924,
    &TrackVehicleInfo_8E2B93, &TrackVehicleInfo_8E2DF9, &TrackVehicleInfo_8E3056, &TrackVehicleInfo_8E32B3, &TrackVehicleInfo_8E3519, &TrackVehicleInfo_8E3788,
    &TrackVehicleInfo_8E138E, &TrackVehicleInfo_8E15F4, &TrackVehicleInfo_8E1863, &TrackVehicleInfo_8E1AC9, &TrackVehicleInfo_8E1D26, &TrackVehicleInfo_8E1F83,
    &TrackVehicleInfo_8E21E9, &TrackVehicleInfo_8E2458, &TrackVehicleInfo_8E39EE, &TrackVehicleInfo_8E3AB6, &TrackVehicleInfo_8E3B87, &TrackVehicleInfo_8E3C4F,
    &TrackVehicleInfo_8E3D0E, &TrackVehicleInfo_8E3DCD, &TrackVehicleInfo_8E3E95, &TrackVehicleInfo_8E3F66, &TrackVehicleInfo_8D9BFE, &TrackVehicleInfo_8D9F60,
    &TrackVehicleInfo_8DA2C2, &TrackVehicleInfo_8DA624, &TrackVehicleInfo_8DA986, &TrackVehicleInfo_8DACE8, &TrackVehicleInfo_8DB04A, &TrackVehicleInfo_8DB3AC,
    &TrackVehicleInfo_8DB70E, &TrackVehicleInfo_8DBA70, &TrackVehicleInfo_8DBDD2, &TrackVehicleInfo_8DC134, &TrackVehicleInfo_8DC496, &TrackVehicleInfo_8DC7F8,
    &TrackVehicleInfo_8DCB5A, &TrackVehicleInfo_8DCEBC, &TrackVehicleInfo_8E644E, &TrackVehicleInfo_8E69F9, &TrackVehicleInfo_8E6FA4, &TrackVehicleInfo_8E754F,
    &TrackVehicleInfo_8E7AFA, &TrackVehicleInfo_8E80A5, &TrackVehicleInfo_8E8650, &TrackVehicleInfo_8E8BFB, &TrackVehicleInfo_8EA852, &TrackVehicleInfo_8EABBD,
    &TrackVehicleInfo_8EAF28, &TrackVehicleInfo_8EB293, &TrackVehicleInfo_8EB5FE, &TrackVehicleInfo_8EB969, &TrackVehicleInfo_8EBCD4, &TrackVehicleInfo_8EC03F,
    &TrackVehicleInfo_8EC3AA, &TrackVehicleInfo_8EC715, &TrackVehicleInfo_8ECA80, &TrackVehicleInfo_8ECDEB, &TrackVehicleInfo_8ED156, &TrackVehicleInfo_8ED4C1,
    &TrackVehicleInfo_8ED82C, &TrackVehicleInfo_8EDB97, &TrackVehicleInfo_8C6C32, &TrackVehicleInfo_8C6D78, &TrackVehicleInfo_8C6EBE, &TrackVehicleInfo_8C7004,
    &TrackVehicleInfo_8C714A, &TrackVehicleInfo_8C7290, &TrackVehicleInfo_8C73D6, &TrackVehicleInfo_8C751C, &TrackVehicleInfo_8C7662, &TrackVehicleInfo_8C77A8,
    &TrackVehicleInfo_8C78EE, &TrackVehicleInfo_8C7A34, &TrackVehicleInfo_8C7B7A, &TrackVehicleInfo_8C7CC0, &TrackVehicleInfo_8C7E06, &TrackVehicleInfo_8C7F4C,
    &TrackVehicleInfo_8EFA5A, &TrackVehicleInfo_8EFDAA, &TrackVehicleInfo_8F00FA, &TrackVehicleInfo_8F044A, &TrackVehicleInfo_8F079A, &TrackVehicleInfo_8F08BC,
    &TrackVehicleInfo_8F09DE, &TrackVehicleInfo_8F0B00, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,
    &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C, &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554,
    &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8, &TrackVehicleInfo_8BFC1A, &TrackVehicleInfo_8BFD3C, &TrackVehicleInfo_8BFE5E, &TrackVehicleInfo_8BFF80,
    &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89, &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5,
    &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763, &TrackVehicleInfo_8C00A2, &TrackVehicleInfo_8C01C4, &TrackVehicleInfo_8C02E6, &TrackVehicleInfo_8C0408,
    &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4, &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C,
    &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300, &TrackVehicleInfo_8C09B2, &TrackVehicleInfo_8C0AD4, &TrackVehicleInfo_8C0BF6, &TrackVehicleInfo_8C0D18,
    &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D, &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01,
    &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F, &TrackVehicleInfo_8C052A, &TrackVehicleInfo_8C064C, &TrackVehicleInfo_8C076E, &TrackVehicleInfo_8C0890,
    &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496, &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D,
    &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94,
    &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923, &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8,
    &TrackVehicleInfo_8F8C82, &TrackVehicleInfo_8F9143, &TrackVehicleInfo_8F9616, &TrackVehicleInfo_8F9AE9, &TrackVehicleInfo_8F9FAA, &TrackVehicleInfo_8FA46B,
    &TrackVehicleInfo_8FA93E, &TrackVehicleInfo_8FAE11, &TrackVehicleInfo_8FB2D2, &TrackVehicleInfo_8FB793, &TrackVehicleInfo_8FBC66, &TrackVehicleInfo_8FC139,
    &TrackVehicleInfo_8FC5FA, &TrackVehicleInfo_8FCABB, &TrackVehicleInfo_8FCF8E, &TrackVehicleInfo_8FD461, &TrackVehicleInfo_8F0C22, &TrackVehicleInfo_8F141F,
    &TrackVehicleInfo_8F1C2E, &TrackVehicleInfo_8F243D, &TrackVehicleInfo_8F2C3A, &TrackVehicleInfo_8F3437, &TrackVehicleInfo_8F3C46, &TrackVehicleInfo_8F4455,
    &TrackVehicleInfo_8F4C52, &TrackVehicleInfo_8F544F, &TrackVehicleInfo_8F5C5E, &TrackVehicleInfo_8F646D, &TrackVehicleInfo_8F6C6A, &TrackVehicleInfo_8F7467,
    &TrackVehicleInfo_8F7C76, &TrackVehicleInfo_8F8485, &TrackVehicleInfo_8E402E, &TrackVehicleInfo_8E4270, &TrackVehicleInfo_8E44B2, &TrackVehicleInfo_8E46F4,
    &TrackVehicleInfo_8E4936, &TrackVehicleInfo_8E4B78, &TrackVehicleInfo_8E4DBA, &TrackVehicleInfo_8E4FFC, &TrackVehicleInfo_8E523E, &TrackVehicleInfo_8E5480,
    &TrackVehicleInfo_8E56C2, &TrackVehicleInfo_8E5904, &TrackVehicleInfo_8E5B46, &TrackVehicleInfo_8E5D88, &TrackVehicleInfo_8E5FCA, &TrackVehicleInfo_8E620C,
    &TrackVehicleInfo_8CE06A, &TrackVehicleInfo_8CE291, &TrackVehicleInfo_8CE4B8, &TrackVehicleInfo_8CE6DF, &TrackVehicleInfo_8CE06A, &TrackVehicleInfo_8CE291,
    &TrackVehicleInfo_8CE4B8, &TrackVehicleInfo_8CE6DF,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListChairliftStartBullwheel[] = {
    &TrackVehicleInfo_8CE4B8, &TrackVehicleInfo_8CE6DF, &TrackVehicleInfo_8CE06A, &TrackVehicleInfo_8CE291, &TrackVehicleInfo_8CE4B8, &TrackVehicleInfo_8CE6DF,
    &TrackVehicleInfo_8CE06A, &TrackVehicleInfo_8CE291, &TrackVehicleInfo_8CE4B8, &TrackVehicleInfo_8CE6DF, &TrackVehicleInfo_8CE06A, &TrackVehicleInfo_8CE291,
    &TrackVehicleInfo_8CE4B8, &TrackVehicleInfo_8CE6DF, &TrackVehicleInfo_8CE06A, &TrackVehicleInfo_8CE291, &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C,
    &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554, &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8,
    &TrackVehicleInfo_8BFC1A, &TrackVehicleInfo_8BFD3C, &TrackVehicleInfo_8BFE5E, &TrackVehicleInfo_8BFF80, &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89,
    &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5, &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763,
    &TrackVehicleInfo_8C00A2, &TrackVehicleInfo_8C01C4, &TrackVehicleInfo_8C02E6, &TrackVehicleInfo_8C0408, &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4,
    &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C, &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300,
    &TrackVehicleInfo_8C09B2, &TrackVehicleInfo_8C0AD4, &TrackVehicleInfo_8C0BF6, &TrackVehicleInfo_8C0D18, &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D,
    &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01, &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F,
    &TrackVehicleInfo_8C052A, &TrackVehicleInfo_8C064C, &TrackVehicleInfo_8C076E, &TrackVehicleInfo_8C0890, &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496,
    &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D, &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE,
    &TrackVehicleInfo_8C3542, &TrackVehicleInfo_8C3664, &TrackVehicleInfo_8C3786, &TrackVehicleInfo_8C38A8, &TrackVehicleInfo_8C39CA, &TrackVehicleInfo_8C3AEC,
    &TrackVehicleInfo_8C3C0E, &TrackVehicleInfo_8C3D30, &TrackVehicleInfo_8C3E52, &TrackVehicleInfo_8C3F74, &TrackVehicleInfo_8C4096, &TrackVehicleInfo_8C41B8,
    &TrackVehicleInfo_8C42DA, &TrackVehicleInfo_8C43FC, &TrackVehicleInfo_8C451E, &TrackVehicleInfo_8C4640, &TrackVehicleInfo_8CA0B2, &TrackVehicleInfo_8CA4B6,
    &TrackVehicleInfo_8CA8C3, &TrackVehicleInfo_8CACC7, &TrackVehicleInfo_8CB0C2, &TrackVehicleInfo_8CB4BD, &TrackVehicleInfo_8CB8C1, &TrackVehicleInfo_8CBCCE,
    &TrackVehicleInfo_8C4762, &TrackVehicleInfo_8C4884, &TrackVehicleInfo_8C49A6, &TrackVehicleInfo_8C4AC8, &TrackVehicleInfo_8C4BEA, &TrackVehicleInfo_8C4D0C,
    &TrackVehicleInfo_8C4E2E, &TrackVehicleInfo_8C4F50, &TrackVehicleInfo_8C5072, &TrackVehicleInfo_8C51A6, &TrackVehicleInfo_8C52DA, &TrackVehicleInfo_8C540E,
    &TrackVehicleInfo_8C5542, &TrackVehicleInfo_8C5676, &TrackVehicleInfo_8C57AA, &TrackVehicleInfo_8C58DE, &TrackVehicleInfo_8C6322, &TrackVehicleInfo_8C6444,
    &TrackVehicleInfo_8C6566, &TrackVehicleInfo_8C6688, &TrackVehicleInfo_8C67AA, &TrackVehicleInfo_8C68CC, &TrackVehicleInfo_8C69EE, &TrackVehicleInfo_8C6B10,
    &TrackVehicleInfo_8C5A12, &TrackVehicleInfo_8C5B34, &TrackVehicleInfo_8C5C56, &TrackVehicleInfo_8C5D78, &TrackVehicleInfo_8C5E9A, &TrackVehicleInfo_8C5FBC,
    &TrackVehicleInfo_8C60DE, &TrackVehicleInfo_8C6200, &TrackVehicleInfo_8BEA02, &TrackVehicleInfo_8BEB24, &TrackVehicleInfo_8BEC46, &TrackVehicleInfo_8BED68,
    &TrackVehicleInfo_8BEE8A, &TrackVehicleInfo_8BEFAC, &TrackVehicleInfo_8BF0CE, &TrackVehicleInfo_8BF1F0, &TrackVehicleInfo_8D047E, &TrackVehicleInfo_8D0882,
    &TrackVehicleInfo_8D0C8F, &TrackVehicleInfo_8D1093, &TrackVehicleInfo_8D148E, &TrackVehicleInfo_8D1889, &TrackVehicleInfo_8D1C8D, &TrackVehicleInfo_8D209A,
    &TrackVehicleInfo_8D249E, &TrackVehicleInfo_8D28A2, &TrackVehicleInfo_8D2CAF, &TrackVehicleInfo_8D30B3, &TrackVehicleInfo_8D34AE, &TrackVehicleInfo_8D38A9,
    &TrackVehicleInfo_8D3CAD, &TrackVehicleInfo_8D40BA, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8D44BE, &TrackVehicleInfo_8D4FA6,
    &TrackVehicleInfo_8D5A8E, &TrackVehicleInfo_8D6576, &TrackVehicleInfo_8D705E, &TrackVehicleInfo_8D7B46, &TrackVehicleInfo_8D862E, &TrackVehicleInfo_8D9116,
    &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94, &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923,
    &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8, &TrackVehicleInfo_8E005E, &TrackVehicleInfo_8E02C4, &TrackVehicleInfo_8E0533, &TrackVehicleInfo_8E0799,
    &TrackVehicleInfo_8E09F6, &TrackVehicleInfo_8E0C53, &TrackVehicleInfo_8E0EB9, &TrackVehicleInfo_8E1128, &TrackVehicleInfo_8E26BE, &TrackVehicleInfo_8E2924,
    &TrackVehicleInfo_8E2B93, &TrackVehicleInfo_8E2DF9, &TrackVehicleInfo_8E3056, &TrackVehicleInfo_8E32B3, &TrackVehicleInfo_8E3519, &TrackVehicleInfo_8E3788,
    &TrackVehicleInfo_8E138E, &TrackVehicleInfo_8E15F4, &TrackVehicleInfo_8E1863, &TrackVehicleInfo_8E1AC9, &TrackVehicleInfo_8E1D26, &TrackVehicleInfo_8E1F83,
    &TrackVehicleInfo_8E21E9, &TrackVehicleInfo_8E2458, &TrackVehicleInfo_8E39EE, &TrackVehicleInfo_8E3AB6, &TrackVehicleInfo_8E3B87, &TrackVehicleInfo_8E3C4F,
    &TrackVehicleInfo_8E3D0E, &TrackVehicleInfo_8E3DCD, &TrackVehicleInfo_8E3E95, &TrackVehicleInfo_8E3F66, &TrackVehicleInfo_8D9BFE, &TrackVehicleInfo_8D9F60,
    &TrackVehicleInfo_8DA2C2, &TrackVehicleInfo_8DA624, &TrackVehicleInfo_8DA986, &TrackVehicleInfo_8DACE8, &TrackVehicleInfo_8DB04A, &TrackVehicleInfo_8DB3AC,
    &TrackVehicleInfo_8DB70E, &TrackVehicleInfo_8DBA70, &TrackVehicleInfo_8DBDD2, &TrackVehicleInfo_8DC134, &TrackVehicleInfo_8DC496, &TrackVehicleInfo_8DC7F8,
    &TrackVehicleInfo_8DCB5A, &TrackVehicleInfo_8DCEBC, &TrackVehicleInfo_8E644E, &TrackVehicleInfo_8E69F9, &TrackVehicleInfo_8E6FA4, &TrackVehicleInfo_8E754F,
    &TrackVehicleInfo_8E7AFA, &TrackVehicleInfo_8E80A5, &TrackVehicleInfo_8E8650, &TrackVehicleInfo_8E8BFB, &TrackVehicleInfo_8EA852, &TrackVehicleInfo_8EABBD,
    &TrackVehicleInfo_8EAF28, &TrackVehicleInfo_8EB293, &TrackVehicleInfo_8EB5FE, &TrackVehicleInfo_8EB969, &TrackVehicleInfo_8EBCD4, &TrackVehicleInfo_8EC03F,
    &TrackVehicleInfo_8EC3AA, &TrackVehicleInfo_8EC715, &TrackVehicleInfo_8ECA80, &TrackVehicleInfo_8ECDEB, &TrackVehicleInfo_8ED156, &TrackVehicleInfo_8ED4C1,
    &TrackVehicleInfo_8ED82C, &TrackVehicleInfo_8EDB97, &TrackVehicleInfo_8C6C32, &TrackVehicleInfo_8C6D78, &TrackVehicleInfo_8C6EBE, &TrackVehicleInfo_8C7004,
    &TrackVehicleInfo_8C714A, &TrackVehicleInfo_8C7290, &TrackVehicleInfo_8C73D6, &TrackVehicleInfo_8C751C, &TrackVehicleInfo_8C7662, &TrackVehicleInfo_8C77A8,
    &TrackVehicleInfo_8C78EE, &TrackVehicleInfo_8C7A34, &TrackVehicleInfo_8C7B7A, &TrackVehicleInfo_8C7CC0, &TrackVehicleInfo_8C7E06, &TrackVehicleInfo_8C7F4C,
    &TrackVehicleInfo_8EFA5A, &TrackVehicleInfo_8EFDAA, &TrackVehicleInfo_8F00FA, &TrackVehicleInfo_8F044A, &TrackVehicleInfo_8F079A, &TrackVehicleInfo_8F08BC,
    &TrackVehicleInfo_8F09DE, &TrackVehicleInfo_8F0B00, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,
    &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C, &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554,
    &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8, &TrackVehicleInfo_8BFC1A, &TrackVehicleInfo_8BFD3C, &TrackVehicleInfo_8BFE5E, &TrackVehicleInfo_8BFF80,
    &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89, &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5,
    &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763, &TrackVehicleInfo_8C00A2, &TrackVehicleInfo_8C01C4, &TrackVehicleInfo_8C02E6, &TrackVehicleInfo_8C0408,
    &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4, &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C,
    &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300, &TrackVehicleInfo_8C09B2, &TrackVehicleInfo_8C0AD4, &TrackVehicleInfo_8C0BF6, &TrackVehicleInfo_8C0D18,
    &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D, &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01,
    &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F, &TrackVehicleInfo_8C052A, &TrackVehicleInfo_8C064C, &TrackVehicleInfo_8C076E, &TrackVehicleInfo_8C0890,
    &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496, &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D,
    &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94,
    &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923, &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8,
    &TrackVehicleInfo_8F8C82, &TrackVehicleInfo_8F9143, &TrackVehicleInfo_8F9616, &TrackVehicleInfo_8F9AE9, &TrackVehicleInfo_8F9FAA, &TrackVehicleInfo_8FA46B,
    &TrackVehicleInfo_8FA93E, &TrackVehicleInfo_8FAE11, &TrackVehicleInfo_8FB2D2, &TrackVehicleInfo_8FB793, &TrackVehicleInfo_8FBC66, &TrackVehicleInfo_8FC139,
    &TrackVehicleInfo_8FC5FA, &TrackVehicleInfo_8FCABB, &TrackVehicleInfo_8FCF8E, &TrackVehicleInfo_8FD461, &TrackVehicleInfo_8F0C22, &TrackVehicleInfo_8F141F,
    &TrackVehicleInfo_8F1C2E, &TrackVehicleInfo_8F243D, &TrackVehicleInfo_8F2C3A, &TrackVehicleInfo_8F3437, &TrackVehicleInfo_8F3C46, &TrackVehicleInfo_8F4455,
    &TrackVehicleInfo_8F4C52, &TrackVehicleInfo_8F544F, &TrackVehicleInfo_8F5C5E, &TrackVehicleInfo_8F646D, &TrackVehicleInfo_8F6C6A, &TrackVehicleInfo_8F7467,
    &TrackVehicleInfo_8F7C76, &TrackVehicleInfo_8F8485, &TrackVehicleInfo_8E402E, &TrackVehicleInfo_8E4270, &TrackVehicleInfo_8E44B2, &TrackVehicleInfo_8E46F4,
    &TrackVehicleInfo_8E4936, &TrackVehicleInfo_8E4B78, &TrackVehicleInfo_8E4DBA, &TrackVehicleInfo_8E4FFC, &TrackVehicleInfo_8E523E, &TrackVehicleInfo_8E5480,
    &TrackVehicleInfo_8E56C2, &TrackVehicleInfo_8E5904, &TrackVehicleInfo_8E5B46, &TrackVehicleInfo_8E5D88, &TrackVehicleInfo_8E5FCA, &TrackVehicleInfo_8E620C,
    &TrackVehicleInfo_8CE4B8, &TrackVehicleInfo_8CE6DF, &TrackVehicleInfo_8CE06A, &TrackVehicleInfo_8CE291, &TrackVehicleInfo_8CE4B8, &TrackVehicleInfo_8CE6DF,
    &TrackVehicleInfo_8CE06A, &TrackVehicleInfo_8CE291,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListGoKartsLeftLane[] = {
    &TrackVehicleInfo_8FF2DA, &TrackVehicleInfo_8FF3FC, &TrackVehicleInfo_8FF51E, &TrackVehicleInfo_8FF640, // TrackElemType::Flat
    &TrackVehicleInfo_8FF2DA, &TrackVehicleInfo_8FF3FC, &TrackVehicleInfo_8FF51E, &TrackVehicleInfo_8FF640, // TrackElemType::EndStation
    &TrackVehicleInfo_8FF2DA, &TrackVehicleInfo_8FF3FC, &TrackVehicleInfo_8FF51E, &TrackVehicleInfo_8FF640, // TrackElemType::BeginStation
    &TrackVehicleInfo_8FF2DA, &TrackVehicleInfo_8FF3FC, &TrackVehicleInfo_8FF51E, &TrackVehicleInfo_8FF640, // TrackElemType::MiddleStation
    &TrackVehicleInfo_900E52, &TrackVehicleInfo_900F74, &TrackVehicleInfo_901096, &TrackVehicleInfo_9011B8, // TrackElemType::Up25
    &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554, &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8, // TrackElemType::Up60
    &TrackVehicleInfo_8FFBEA, &TrackVehicleInfo_8FFD0C, &TrackVehicleInfo_8FFE2E, &TrackVehicleInfo_8FFF50, // TrackElemType::FlatToUp25
    &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89, &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, // TrackElemType::Up25ToUp60
    &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5, &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763, // TrackElemType::Up60ToUp25
    &TrackVehicleInfo_900072, &TrackVehicleInfo_9001A6, &TrackVehicleInfo_9002DA, &TrackVehicleInfo_90040E, // TrackElemType::Up25ToFlat
    &TrackVehicleInfo_9012DA, &TrackVehicleInfo_9013FC, &TrackVehicleInfo_90151E, &TrackVehicleInfo_901640, // TrackElemType::Down25
    &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C, &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300, // TrackElemType::Down60
    &TrackVehicleInfo_9009CA, &TrackVehicleInfo_900AEC, &TrackVehicleInfo_900C0E, &TrackVehicleInfo_900D30, // TrackElemType::FlatToDown25
    &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D, &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, // TrackElemType::Down25ToDown60
    &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01, &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F, // TrackElemType::Down60ToDown25
    &TrackVehicleInfo_900542, &TrackVehicleInfo_900664, &TrackVehicleInfo_900786, &TrackVehicleInfo_9008A8, // TrackElemType::Down25ToFlat
    &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles0, &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles1, &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles2, &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles3, // TrackElemType::LeftQuarterTurn5Tiles
    &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles0, &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles1, &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles2, &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles3, // TrackElemType::RightQuarterTurn5Tiles
    &TrackVehicleInfo_8FF2DA, &TrackVehicleInfo_8FF3FC, &TrackVehicleInfo_8FF51E, &TrackVehicleInfo_8FF640, // TrackElemType::FlatToLeftBank
    &TrackVehicleInfo_8FF2DA, &TrackVehicleInfo_8FF3FC, &TrackVehicleInfo_8FF51E, &TrackVehicleInfo_8FF640, // TrackElemType::FlatToRightBank
    &TrackVehicleInfo_8FF2DA, &TrackVehicleInfo_8FF3FC, &TrackVehicleInfo_8FF51E, &TrackVehicleInfo_8FF640, // TrackElemType::LeftBankToFlat
    &TrackVehicleInfo_8FF2DA, &TrackVehicleInfo_8FF3FC, &TrackVehicleInfo_8FF51E, &TrackVehicleInfo_8FF640, // TrackElemType::RightBankToFlat
    &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles0, &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles1, &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles2, &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles3, // TrackElemType::BankedLeftQuarterTurn5Tiles
    &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles0, &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles1, &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles2, &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles3, // TrackElemType::BankedRightQuarterTurn5Tiles
    &TrackVehicleInfo_8FFBEA, &TrackVehicleInfo_8FFD0C, &TrackVehicleInfo_8FFE2E, &TrackVehicleInfo_8FFF50, // TrackElemType::LeftBankToUp25
    &TrackVehicleInfo_8FFBEA, &TrackVehicleInfo_8FFD0C, &TrackVehicleInfo_8FFE2E, &TrackVehicleInfo_8FFF50, // TrackElemType::RightBankToUp25
    &TrackVehicleInfo_900072, &TrackVehicleInfo_9001A6, &TrackVehicleInfo_9002DA, &TrackVehicleInfo_90040E, // TrackElemType::Up25ToLeftBank
    &TrackVehicleInfo_900072, &TrackVehicleInfo_9001A6, &TrackVehicleInfo_9002DA, &TrackVehicleInfo_90040E, // TrackElemType::Up25ToRightBank
    &TrackVehicleInfo_9009CA, &TrackVehicleInfo_900AEC, &TrackVehicleInfo_900C0E, &TrackVehicleInfo_900D30, // TrackElemType::LeftBankToDown25
    &TrackVehicleInfo_9009CA, &TrackVehicleInfo_900AEC, &TrackVehicleInfo_900C0E, &TrackVehicleInfo_900D30, // TrackElemType::RightBankToDown25
    &TrackVehicleInfo_900542, &TrackVehicleInfo_900664, &TrackVehicleInfo_900786, &TrackVehicleInfo_9008A8, // TrackElemType::Down25ToLeftBank
    &TrackVehicleInfo_900542, &TrackVehicleInfo_900664, &TrackVehicleInfo_900786, &TrackVehicleInfo_9008A8, // TrackElemType::Down25ToRightBank
    &TrackVehicleInfo_8FF2DA, &TrackVehicleInfo_8FF3FC, &TrackVehicleInfo_8FF51E, &TrackVehicleInfo_8FF640, // TrackElemType::LeftBank
    &TrackVehicleInfo_8FF2DA, &TrackVehicleInfo_8FF3FC, &TrackVehicleInfo_8FF51E, &TrackVehicleInfo_8FF640, // TrackElemType::RightBank
    &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp0, &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp1, &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp2, &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp3, // TrackElemType::LeftQuarterTurn5TilesUp25
    &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegUp0, &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegUp1, &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegUp2, &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegUp3, // TrackElemType::RightQuarterTurn5TilesUp25
    &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown0, &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown1, &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown2, &LeftLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown3, // TrackElemType::LeftQuarterTurn5TilesDown25
    &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegDown0, &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegDown1, &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegDown2, &LeftLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegDown3, // TrackElemType::RightQuarterTurn5TilesDown25
    &LeftLane::TrackVehicleInfoLeftSBend0, &LeftLane::TrackVehicleInfoLeftSBend1, &LeftLane::TrackVehicleInfoLeftSBend2, &LeftLane::TrackVehicleInfoLeftSBend3, // TrackElemType::SBendLeft
    &LeftLane::TrackVehicleInfoRightSBend0, &LeftLane::TrackVehicleInfoRightSBend1, &LeftLane::TrackVehicleInfoRightSBend2, &LeftLane::TrackVehicleInfoRightSBend3, // TrackElemType::SBendRight
    &TrackVehicleInfo_8D44BE, &TrackVehicleInfo_8D4FA6, &TrackVehicleInfo_8D5A8E, &TrackVehicleInfo_8D6576, // TrackElemType::LeftVerticalLoop
    &TrackVehicleInfo_8D705E, &TrackVehicleInfo_8D7B46, &TrackVehicleInfo_8D862E, &TrackVehicleInfo_8D9116, // TrackElemType::RightVerticalLoop
    &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles0, &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles1, &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles2, &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles3, // TrackElemType::LeftQuarterTurn3Tiles
    &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles0, &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles1, &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles2, &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles3, // TrackElemType::RightQuarterTurn3Tiles
    &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles0, &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles1, &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles2, &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles3, // TrackElemType::LeftBankedQuarterTurn3Tiles
    &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles0, &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles1, &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles2, &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles3, // TrackElemType::RightBankedQuarterTurn3Tiles
    &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp0, &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp1, &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp2, &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp3, // TrackElemType::LeftQuarterTurn3TilesUp25
    &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegUp0, &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegUp1, &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegUp2, &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegUp3, // TrackElemType::RightQuarterTurn3TilesUp25
    &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown0, &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown1, &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown2, &LeftLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown3, // TrackElemType::LeftQuarterTurn3TilesDown25
    &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegDown0, &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegDown1, &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegDown2, &LeftLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegDown3, // TrackElemType::RightQuarterTurn3TilesDown25
    &TrackVehicleInfo_901C05, &TrackVehicleInfo_901C7C, &TrackVehicleInfo_901CFC, &TrackVehicleInfo_901D73, // TrackElemType::LeftQuarterTurn1Tile
    &TrackVehicleInfo_901762, &TrackVehicleInfo_901884, &TrackVehicleInfo_9019AF, &TrackVehicleInfo_901AE3, // TrackElemType::RightQuarterTurn1Tile
};

static constexpr const VehicleInfoList *TrackVehicleInfoListGoKartsRightLane[] = {
    &TrackVehicleInfo_901DE1, &TrackVehicleInfo_901F03, &TrackVehicleInfo_902025, &TrackVehicleInfo_902147, // TrackElemType::Flat
    &TrackVehicleInfo_901DE1, &TrackVehicleInfo_901F03, &TrackVehicleInfo_902025, &TrackVehicleInfo_902147, // TrackElemType::EndStation
    &TrackVehicleInfo_901DE1, &TrackVehicleInfo_901F03, &TrackVehicleInfo_902025, &TrackVehicleInfo_902147, // TrackElemType::BeginStation
    &TrackVehicleInfo_901DE1, &TrackVehicleInfo_901F03, &TrackVehicleInfo_902025, &TrackVehicleInfo_902147, // TrackElemType::MiddleStation
    &TrackVehicleInfo_9034D1, &TrackVehicleInfo_9035F3, &TrackVehicleInfo_903715, &TrackVehicleInfo_903837, // TrackElemType::Up25
    &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554, &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8, // TrackElemType::Up60
    &TrackVehicleInfo_902269, &TrackVehicleInfo_90238B, &TrackVehicleInfo_9024AD, &TrackVehicleInfo_9025CF, // TrackElemType::FlatToUp25
    &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89, &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, // TrackElemType::Up25ToUp60
    &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5, &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763, // TrackElemType::Up60ToUp25
    &TrackVehicleInfo_9026F1, &TrackVehicleInfo_902825, &TrackVehicleInfo_902959, &TrackVehicleInfo_902A8D, // TrackElemType::Up25ToFlat
    &TrackVehicleInfo_903959, &TrackVehicleInfo_903A7B, &TrackVehicleInfo_903B9D, &TrackVehicleInfo_903CBF, // TrackElemType::Down25
    &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C, &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300, // TrackElemType::Down60
    &TrackVehicleInfo_903049, &TrackVehicleInfo_90316B, &TrackVehicleInfo_90328D, &TrackVehicleInfo_9033AF, // TrackElemType::FlatToDown25
    &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D, &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, // TrackElemType::Down25ToDown60
    &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01, &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F, // TrackElemType::Down60ToDown25
    &TrackVehicleInfo_902BC1, &TrackVehicleInfo_902CE3, &TrackVehicleInfo_902E05, &TrackVehicleInfo_902F27, // TrackElemType::Down25ToFlat
    &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles0, &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles1, &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles2, &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles3, // TrackElemType::LeftQuarterTurn5Tiles
    &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles0, &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles1, &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles2, &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles3, // TrackElemType::RightQuarterTurn5Tiles
    &TrackVehicleInfo_901DE1, &TrackVehicleInfo_901F03, &TrackVehicleInfo_902025, &TrackVehicleInfo_902147, // TrackElemType::FlatToLeftBank
    &TrackVehicleInfo_901DE1, &TrackVehicleInfo_901F03, &TrackVehicleInfo_902025, &TrackVehicleInfo_902147, // TrackElemType::FlatToRightBank
    &TrackVehicleInfo_901DE1, &TrackVehicleInfo_901F03, &TrackVehicleInfo_902025, &TrackVehicleInfo_902147, // TrackElemType::LeftBankToFlat
    &TrackVehicleInfo_901DE1, &TrackVehicleInfo_901F03, &TrackVehicleInfo_902025, &TrackVehicleInfo_902147, // TrackElemType::RightBankToFlat
    &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles0, &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles1, &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles2, &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles3, // TrackElemType::BankedLeftQuarterTurn5Tiles
    &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles0, &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles1, &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles2, &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles3, // TrackElemType::BankedRightQuarterTurn5Tiles
    &TrackVehicleInfo_902269, &TrackVehicleInfo_90238B, &TrackVehicleInfo_9024AD, &TrackVehicleInfo_9025CF, // TrackElemType::LeftBankToUp25
    &TrackVehicleInfo_902269, &TrackVehicleInfo_90238B, &TrackVehicleInfo_9024AD, &TrackVehicleInfo_9025CF, // TrackElemType::RightBankToUp25
    &TrackVehicleInfo_9026F1, &TrackVehicleInfo_902825, &TrackVehicleInfo_902959, &TrackVehicleInfo_902A8D, // TrackElemType::Up25ToLeftBank
    &TrackVehicleInfo_9026F1, &TrackVehicleInfo_902825, &TrackVehicleInfo_902959, &TrackVehicleInfo_902A8D, // TrackElemType::Up25ToRightBank
    &TrackVehicleInfo_903049, &TrackVehicleInfo_90316B, &TrackVehicleInfo_90328D, &TrackVehicleInfo_9033AF, // TrackElemType::LeftBankToDown25
    &TrackVehicleInfo_903049, &TrackVehicleInfo_90316B, &TrackVehicleInfo_90328D, &TrackVehicleInfo_9033AF, // TrackElemType::RightBankToDown25
    &TrackVehicleInfo_902BC1, &TrackVehicleInfo_902CE3, &TrackVehicleInfo_902E05, &TrackVehicleInfo_902F27, // TrackElemType::Down25ToLeftBank
    &TrackVehicleInfo_902BC1, &TrackVehicleInfo_902CE3, &TrackVehicleInfo_902E05, &TrackVehicleInfo_902F27, // TrackElemType::Down25ToRightBank
    &TrackVehicleInfo_901DE1, &TrackVehicleInfo_901F03, &TrackVehicleInfo_902025, &TrackVehicleInfo_902147, // TrackElemType::LeftBank
    &TrackVehicleInfo_901DE1, &TrackVehicleInfo_901F03, &TrackVehicleInfo_902025, &TrackVehicleInfo_902147, // TrackElemType::RightBank
    &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp0, &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp1, &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp2, &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegUp3, // TrackElemType::LeftQuarterTurn5TilesUp25
    &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegUp0, &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegUp1, &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegUp2, &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegUp3, // TrackElemType::RightQuarterTurn5TilesUp25
    &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown0, &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown1, &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown2, &RightLane::TrackVehicleInfoLeftQuarterTurn5Tiles25DegDown3, // TrackElemType::LeftQuarterTurn5TilesDown25
    &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegDown0, &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegDown1, &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegDown2, &RightLane::TrackVehicleInfoRightQuarterTurn5Tiles25DegDown3, // TrackElemType::RightQuarterTurn5TilesDown25
    &RightLane::TrackVehicleInfoLeftSBend0, &RightLane::TrackVehicleInfoLeftSBend1, &RightLane::TrackVehicleInfoLeftSBend2, &RightLane::TrackVehicleInfoLeftSBend3, // TrackElemType::SBendLeft
    &RightLane::TrackVehicleInfoRightSBend0, &RightLane::TrackVehicleInfoRightSBend1, &RightLane::TrackVehicleInfoRightSBend2, &RightLane::TrackVehicleInfoRightSBend3, // TrackElemType::SBendRight
    &TrackVehicleInfo_8D44BE, &TrackVehicleInfo_8D4FA6, &TrackVehicleInfo_8D5A8E, &TrackVehicleInfo_8D6576, // TrackElemType::LeftVerticalLoop
    &TrackVehicleInfo_8D705E, &TrackVehicleInfo_8D7B46, &TrackVehicleInfo_8D862E, &TrackVehicleInfo_8D9116, // TrackElemType::RightVerticalLoop
    &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles0, &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles1, &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles2, &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles3, // TrackElemType::LeftQuarterTurn3Tiles
    &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles0, &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles1, &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles2, &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles3, // TrackElemType::RightQuarterTurn3Tiles
    &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles0, &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles1, &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles2, &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles3, // TrackElemType::LeftBankedQuarterTurn3Tiles
    &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles0, &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles1, &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles2, &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles3, // TrackElemType::RightBankedQuarterTurn3Tiles
    &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp0, &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp1, &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp2, &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegUp3, // TrackElemType::LeftQuarterTurn3TilesUp25
    &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegUp0, &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegUp1, &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegUp2, &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegUp3, // TrackElemType::RightQuarterTurn3TilesUp25
    &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown0, &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown1, &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown2, &RightLane::TrackVehicleInfoLeftQuarterTurn3Tiles25DegDown3, // TrackElemType::LeftQuarterTurn3TilesDown25
    &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegDown0, &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegDown1, &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegDown2, &RightLane::TrackVehicleInfoRightQuarterTurn3Tiles25DegDown3, // TrackElemType::RightQuarterTurn3TilesDown25
    &TrackVehicleInfo_903DE1, &TrackVehicleInfo_903F0C, &TrackVehicleInfo_904040, &TrackVehicleInfo_904162, // TrackElemType::LeftQuarterTurn1Tile
    &TrackVehicleInfo_904284, &TrackVehicleInfo_9042F2, &TrackVehicleInfo_904369, &TrackVehicleInfo_9043E9, // TrackElemType::RightQuarterTurn1Tile
};

static constexpr const VehicleInfoList *TrackVehicleInfoListGoKartsMovingToRightLane[] = {
    &TrackVehicleInfo_8FF762, &TrackVehicleInfo_8FF884, &TrackVehicleInfo_8FF9A6, &TrackVehicleInfo_8FFAC8, &TrackVehicleInfo_8FF762, &TrackVehicleInfo_8FF884,
    &TrackVehicleInfo_8FF9A6, &TrackVehicleInfo_8FFAC8, &TrackVehicleInfo_8FF762, &TrackVehicleInfo_8FF884, &TrackVehicleInfo_8FF9A6, &TrackVehicleInfo_8FFAC8,
    &TrackVehicleInfo_8FF762, &TrackVehicleInfo_8FF884, &TrackVehicleInfo_8FF9A6, &TrackVehicleInfo_8FFAC8, &TrackVehicleInfo_900E52, &TrackVehicleInfo_900F74,
    &TrackVehicleInfo_901096, &TrackVehicleInfo_9011B8, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554, &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8,
    &TrackVehicleInfo_8FFBEA, &TrackVehicleInfo_8FFD0C, &TrackVehicleInfo_8FFE2E, &TrackVehicleInfo_8FFF50, &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89,
    &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5, &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763,
    &TrackVehicleInfo_900072, &TrackVehicleInfo_9001A6, &TrackVehicleInfo_9002DA, &TrackVehicleInfo_90040E, &TrackVehicleInfo_9012DA, &TrackVehicleInfo_9013FC,
    &TrackVehicleInfo_90151E, &TrackVehicleInfo_901640, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C, &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300,
    &TrackVehicleInfo_9009CA, &TrackVehicleInfo_900AEC, &TrackVehicleInfo_900C0E, &TrackVehicleInfo_900D30, &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D,
    &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01, &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F,
    &TrackVehicleInfo_900542, &TrackVehicleInfo_900664, &TrackVehicleInfo_900786, &TrackVehicleInfo_9008A8, &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496,
    &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D, &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE,
    &TrackVehicleInfo_8C3542, &TrackVehicleInfo_8C3664, &TrackVehicleInfo_8C3786, &TrackVehicleInfo_8C38A8, &TrackVehicleInfo_8C39CA, &TrackVehicleInfo_8C3AEC,
    &TrackVehicleInfo_8C3C0E, &TrackVehicleInfo_8C3D30, &TrackVehicleInfo_8C3E52, &TrackVehicleInfo_8C3F74, &TrackVehicleInfo_8C4096, &TrackVehicleInfo_8C41B8,
    &TrackVehicleInfo_8C42DA, &TrackVehicleInfo_8C43FC, &TrackVehicleInfo_8C451E, &TrackVehicleInfo_8C4640, &TrackVehicleInfo_8CA0B2, &TrackVehicleInfo_8CA4B6,
    &TrackVehicleInfo_8CA8C3, &TrackVehicleInfo_8CACC7, &TrackVehicleInfo_8CB0C2, &TrackVehicleInfo_8CB4BD, &TrackVehicleInfo_8CB8C1, &TrackVehicleInfo_8CBCCE,
    &TrackVehicleInfo_8C4762, &TrackVehicleInfo_8C4884, &TrackVehicleInfo_8C49A6, &TrackVehicleInfo_8C4AC8, &TrackVehicleInfo_8C4BEA, &TrackVehicleInfo_8C4D0C,
    &TrackVehicleInfo_8C4E2E, &TrackVehicleInfo_8C4F50, &TrackVehicleInfo_8C5072, &TrackVehicleInfo_8C51A6, &TrackVehicleInfo_8C52DA, &TrackVehicleInfo_8C540E,
    &TrackVehicleInfo_8C5542, &TrackVehicleInfo_8C5676, &TrackVehicleInfo_8C57AA, &TrackVehicleInfo_8C58DE, &TrackVehicleInfo_8C6322, &TrackVehicleInfo_8C6444,
    &TrackVehicleInfo_8C6566, &TrackVehicleInfo_8C6688, &TrackVehicleInfo_8C67AA, &TrackVehicleInfo_8C68CC, &TrackVehicleInfo_8C69EE, &TrackVehicleInfo_8C6B10,
    &TrackVehicleInfo_8C5A12, &TrackVehicleInfo_8C5B34, &TrackVehicleInfo_8C5C56, &TrackVehicleInfo_8C5D78, &TrackVehicleInfo_8C5E9A, &TrackVehicleInfo_8C5FBC,
    &TrackVehicleInfo_8C60DE, &TrackVehicleInfo_8C6200, &TrackVehicleInfo_8BEA02, &TrackVehicleInfo_8BEB24, &TrackVehicleInfo_8BEC46, &TrackVehicleInfo_8BED68,
    &TrackVehicleInfo_8BEE8A, &TrackVehicleInfo_8BEFAC, &TrackVehicleInfo_8BF0CE, &TrackVehicleInfo_8BF1F0, &TrackVehicleInfo_8D047E, &TrackVehicleInfo_8D0882,
    &TrackVehicleInfo_8D0C8F, &TrackVehicleInfo_8D1093, &TrackVehicleInfo_8D148E, &TrackVehicleInfo_8D1889, &TrackVehicleInfo_8D1C8D, &TrackVehicleInfo_8D209A,
    &TrackVehicleInfo_8D249E, &TrackVehicleInfo_8D28A2, &TrackVehicleInfo_8D2CAF, &TrackVehicleInfo_8D30B3, &TrackVehicleInfo_8D34AE, &TrackVehicleInfo_8D38A9,
    &TrackVehicleInfo_8D3CAD, &TrackVehicleInfo_8D40BA, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8D44BE, &TrackVehicleInfo_8D4FA6,
    &TrackVehicleInfo_8D5A8E, &TrackVehicleInfo_8D6576, &TrackVehicleInfo_8D705E, &TrackVehicleInfo_8D7B46, &TrackVehicleInfo_8D862E, &TrackVehicleInfo_8D9116,
    &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94, &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923,
    &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8, &TrackVehicleInfo_8E005E, &TrackVehicleInfo_8E02C4, &TrackVehicleInfo_8E0533, &TrackVehicleInfo_8E0799,
    &TrackVehicleInfo_8E09F6, &TrackVehicleInfo_8E0C53, &TrackVehicleInfo_8E0EB9, &TrackVehicleInfo_8E1128, &TrackVehicleInfo_8E26BE, &TrackVehicleInfo_8E2924,
    &TrackVehicleInfo_8E2B93, &TrackVehicleInfo_8E2DF9, &TrackVehicleInfo_8E3056, &TrackVehicleInfo_8E32B3, &TrackVehicleInfo_8E3519, &TrackVehicleInfo_8E3788,
    &TrackVehicleInfo_8E138E, &TrackVehicleInfo_8E15F4, &TrackVehicleInfo_8E1863, &TrackVehicleInfo_8E1AC9, &TrackVehicleInfo_8E1D26, &TrackVehicleInfo_8E1F83,
    &TrackVehicleInfo_8E21E9, &TrackVehicleInfo_8E2458, &TrackVehicleInfo_901C05, &TrackVehicleInfo_901C7C, &TrackVehicleInfo_901CFC, &TrackVehicleInfo_901D73,
    &TrackVehicleInfo_901762, &TrackVehicleInfo_901884, &TrackVehicleInfo_9019AF, &TrackVehicleInfo_901AE3,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListGoKartsMovingToLeftLane[] = {
    &TrackVehicleInfo_904460, &TrackVehicleInfo_904582, &TrackVehicleInfo_9046A4, &TrackVehicleInfo_9047C6, &TrackVehicleInfo_904460, &TrackVehicleInfo_904582,
    &TrackVehicleInfo_9046A4, &TrackVehicleInfo_9047C6, &TrackVehicleInfo_904460, &TrackVehicleInfo_904582, &TrackVehicleInfo_9046A4, &TrackVehicleInfo_9047C6,
    &TrackVehicleInfo_904460, &TrackVehicleInfo_904582, &TrackVehicleInfo_9046A4, &TrackVehicleInfo_9047C6, &TrackVehicleInfo_9034D1, &TrackVehicleInfo_9035F3,
    &TrackVehicleInfo_903715, &TrackVehicleInfo_903837, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554, &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8,
    &TrackVehicleInfo_902269, &TrackVehicleInfo_90238B, &TrackVehicleInfo_9024AD, &TrackVehicleInfo_9025CF, &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89,
    &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5, &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763,
    &TrackVehicleInfo_9026F1, &TrackVehicleInfo_902825, &TrackVehicleInfo_902959, &TrackVehicleInfo_902A8D, &TrackVehicleInfo_903959, &TrackVehicleInfo_903A7B,
    &TrackVehicleInfo_903B9D, &TrackVehicleInfo_903CBF, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C, &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300,
    &TrackVehicleInfo_903049, &TrackVehicleInfo_90316B, &TrackVehicleInfo_90328D, &TrackVehicleInfo_9033AF, &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D,
    &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01, &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F,
    &TrackVehicleInfo_902BC1, &TrackVehicleInfo_902CE3, &TrackVehicleInfo_902E05, &TrackVehicleInfo_902F27, &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496,
    &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D, &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE,
    &TrackVehicleInfo_8C3542, &TrackVehicleInfo_8C3664, &TrackVehicleInfo_8C3786, &TrackVehicleInfo_8C38A8, &TrackVehicleInfo_8C39CA, &TrackVehicleInfo_8C3AEC,
    &TrackVehicleInfo_8C3C0E, &TrackVehicleInfo_8C3D30, &TrackVehicleInfo_8C3E52, &TrackVehicleInfo_8C3F74, &TrackVehicleInfo_8C4096, &TrackVehicleInfo_8C41B8,
    &TrackVehicleInfo_8C42DA, &TrackVehicleInfo_8C43FC, &TrackVehicleInfo_8C451E, &TrackVehicleInfo_8C4640, &TrackVehicleInfo_8CA0B2, &TrackVehicleInfo_8CA4B6,
    &TrackVehicleInfo_8CA8C3, &TrackVehicleInfo_8CACC7, &TrackVehicleInfo_8CB0C2, &TrackVehicleInfo_8CB4BD, &TrackVehicleInfo_8CB8C1, &TrackVehicleInfo_8CBCCE,
    &TrackVehicleInfo_8C4762, &TrackVehicleInfo_8C4884, &TrackVehicleInfo_8C49A6, &TrackVehicleInfo_8C4AC8, &TrackVehicleInfo_8C4BEA, &TrackVehicleInfo_8C4D0C,
    &TrackVehicleInfo_8C4E2E, &TrackVehicleInfo_8C4F50, &TrackVehicleInfo_8C5072, &TrackVehicleInfo_8C51A6, &TrackVehicleInfo_8C52DA, &TrackVehicleInfo_8C540E,
    &TrackVehicleInfo_8C5542, &TrackVehicleInfo_8C5676, &TrackVehicleInfo_8C57AA, &TrackVehicleInfo_8C58DE, &TrackVehicleInfo_8C6322, &TrackVehicleInfo_8C6444,
    &TrackVehicleInfo_8C6566, &TrackVehicleInfo_8C6688, &TrackVehicleInfo_8C67AA, &TrackVehicleInfo_8C68CC, &TrackVehicleInfo_8C69EE, &TrackVehicleInfo_8C6B10,
    &TrackVehicleInfo_8C5A12, &TrackVehicleInfo_8C5B34, &TrackVehicleInfo_8C5C56, &TrackVehicleInfo_8C5D78, &TrackVehicleInfo_8C5E9A, &TrackVehicleInfo_8C5FBC,
    &TrackVehicleInfo_8C60DE, &TrackVehicleInfo_8C6200, &TrackVehicleInfo_8BEA02, &TrackVehicleInfo_8BEB24, &TrackVehicleInfo_8BEC46, &TrackVehicleInfo_8BED68,
    &TrackVehicleInfo_8BEE8A, &TrackVehicleInfo_8BEFAC, &TrackVehicleInfo_8BF0CE, &TrackVehicleInfo_8BF1F0, &TrackVehicleInfo_8D047E, &TrackVehicleInfo_8D0882,
    &TrackVehicleInfo_8D0C8F, &TrackVehicleInfo_8D1093, &TrackVehicleInfo_8D148E, &TrackVehicleInfo_8D1889, &TrackVehicleInfo_8D1C8D, &TrackVehicleInfo_8D209A,
    &TrackVehicleInfo_8D249E, &TrackVehicleInfo_8D28A2, &TrackVehicleInfo_8D2CAF, &TrackVehicleInfo_8D30B3, &TrackVehicleInfo_8D34AE, &TrackVehicleInfo_8D38A9,
    &TrackVehicleInfo_8D3CAD, &TrackVehicleInfo_8D40BA, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8D44BE, &TrackVehicleInfo_8D4FA6,
    &TrackVehicleInfo_8D5A8E, &TrackVehicleInfo_8D6576, &TrackVehicleInfo_8D705E, &TrackVehicleInfo_8D7B46, &TrackVehicleInfo_8D862E, &TrackVehicleInfo_8D9116,
    &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94, &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923,
    &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8, &TrackVehicleInfo_8E005E, &TrackVehicleInfo_8E02C4, &TrackVehicleInfo_8E0533, &TrackVehicleInfo_8E0799,
    &TrackVehicleInfo_8E09F6, &TrackVehicleInfo_8E0C53, &TrackVehicleInfo_8E0EB9, &TrackVehicleInfo_8E1128, &TrackVehicleInfo_8E26BE, &TrackVehicleInfo_8E2924,
    &TrackVehicleInfo_8E2B93, &TrackVehicleInfo_8E2DF9, &TrackVehicleInfo_8E3056, &TrackVehicleInfo_8E32B3, &TrackVehicleInfo_8E3519, &TrackVehicleInfo_8E3788,
    &TrackVehicleInfo_8E138E, &TrackVehicleInfo_8E15F4, &TrackVehicleInfo_8E1863, &TrackVehicleInfo_8E1AC9, &TrackVehicleInfo_8E1D26, &TrackVehicleInfo_8E1F83,
    &TrackVehicleInfo_8E21E9, &TrackVehicleInfo_8E2458, &TrackVehicleInfo_903DE1, &TrackVehicleInfo_903F0C, &TrackVehicleInfo_904040, &TrackVehicleInfo_904162,
    &TrackVehicleInfo_904284, &TrackVehicleInfo_9042F2, &TrackVehicleInfo_904369, &TrackVehicleInfo_9043E9,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListMiniGolfStartPathA9[] = {
    &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4,
    &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8,
    &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938D7A, &TrackVehicleInfo_938E0C,
    &TrackVehicleInfo_938E9E, &TrackVehicleInfo_938F30, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_93845A, &TrackVehicleInfo_9384EC, &TrackVehicleInfo_93857E, &TrackVehicleInfo_938610, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9386A2, &TrackVehicleInfo_938734, &TrackVehicleInfo_9387C6, &TrackVehicleInfo_938858, &TrackVehicleInfo_938FC2, &TrackVehicleInfo_939054,
    &TrackVehicleInfo_9390E6, &TrackVehicleInfo_939178, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_938B32, &TrackVehicleInfo_938BC4, &TrackVehicleInfo_938C56, &TrackVehicleInfo_938CE8, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9388EA, &TrackVehicleInfo_93897C, &TrackVehicleInfo_938A0E, &TrackVehicleInfo_938AA0, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_93920A, &TrackVehicleInfo_939293, &TrackVehicleInfo_93932E, &TrackVehicleInfo_9393C0,
    &TrackVehicleInfo_939449, &TrackVehicleInfo_9394D2, &TrackVehicleInfo_939564, &TrackVehicleInfo_9395FF, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_939691, &TrackVehicleInfo_93C082, &TrackVehicleInfo_93EA73, &TrackVehicleInfo_941464, &TrackVehicleInfo_93A46E, &TrackVehicleInfo_93CE5F,
    &TrackVehicleInfo_93F850, &TrackVehicleInfo_942241, &TrackVehicleInfo_93B2AE, &TrackVehicleInfo_93DC9F, &TrackVehicleInfo_940690, &TrackVehicleInfo_943081,
    &TrackVehicleInfo_943E56, &TrackVehicleInfo_946B14, &TrackVehicleInfo_9497D2, &TrackVehicleInfo_94C490, &TrackVehicleInfo_9454B5, &TrackVehicleInfo_948173,
    &TrackVehicleInfo_94AE31, &TrackVehicleInfo_94DAEF,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListMiniGolfBallPathA10[] = {
    &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4,
    &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8,
    &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938D7A, &TrackVehicleInfo_938E0C,
    &TrackVehicleInfo_938E9E, &TrackVehicleInfo_938F30, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_93845A, &TrackVehicleInfo_9384EC, &TrackVehicleInfo_93857E, &TrackVehicleInfo_938610, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9386A2, &TrackVehicleInfo_938734, &TrackVehicleInfo_9387C6, &TrackVehicleInfo_938858, &TrackVehicleInfo_938FC2, &TrackVehicleInfo_939054,
    &TrackVehicleInfo_9390E6, &TrackVehicleInfo_939178, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_938B32, &TrackVehicleInfo_938BC4, &TrackVehicleInfo_938C56, &TrackVehicleInfo_938CE8, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9388EA, &TrackVehicleInfo_93897C, &TrackVehicleInfo_938A0E, &TrackVehicleInfo_938AA0, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_93920A, &TrackVehicleInfo_939293, &TrackVehicleInfo_93932E, &TrackVehicleInfo_9393C0,
    &TrackVehicleInfo_939449, &TrackVehicleInfo_9394D2, &TrackVehicleInfo_939564, &TrackVehicleInfo_9395FF, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9398A6, &TrackVehicleInfo_93C297, &TrackVehicleInfo_93EC88, &TrackVehicleInfo_941679, &TrackVehicleInfo_93A68C, &TrackVehicleInfo_93D07D,
    &TrackVehicleInfo_93FA6E, &TrackVehicleInfo_94245F, &TrackVehicleInfo_93B4CC, &TrackVehicleInfo_93DEBD, &TrackVehicleInfo_9408AE, &TrackVehicleInfo_94329F,
    &TrackVehicleInfo_944104, &TrackVehicleInfo_946DC2, &TrackVehicleInfo_949A80, &TrackVehicleInfo_94C73E, &TrackVehicleInfo_945763, &TrackVehicleInfo_948421,
    &TrackVehicleInfo_94B0DF, &TrackVehicleInfo_94DD9D,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListMiniGolfPathB11[] = {
    &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4,
    &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8,
    &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938D7A, &TrackVehicleInfo_938E0C,
    &TrackVehicleInfo_938E9E, &TrackVehicleInfo_938F30, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_93845A, &TrackVehicleInfo_9384EC, &TrackVehicleInfo_93857E, &TrackVehicleInfo_938610, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9386A2, &TrackVehicleInfo_938734, &TrackVehicleInfo_9387C6, &TrackVehicleInfo_938858, &TrackVehicleInfo_938FC2, &TrackVehicleInfo_939054,
    &TrackVehicleInfo_9390E6, &TrackVehicleInfo_939178, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_938B32, &TrackVehicleInfo_938BC4, &TrackVehicleInfo_938C56, &TrackVehicleInfo_938CE8, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9388EA, &TrackVehicleInfo_93897C, &TrackVehicleInfo_938A0E, &TrackVehicleInfo_938AA0, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_93920A, &TrackVehicleInfo_939293, &TrackVehicleInfo_93932E, &TrackVehicleInfo_9393C0,
    &TrackVehicleInfo_939449, &TrackVehicleInfo_9394D2, &TrackVehicleInfo_939564, &TrackVehicleInfo_9395FF, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_939A85, &TrackVehicleInfo_93C476, &TrackVehicleInfo_93EE67, &TrackVehicleInfo_941858, &TrackVehicleInfo_93A898, &TrackVehicleInfo_93D289,
    &TrackVehicleInfo_93FC7A, &TrackVehicleInfo_94266B, &TrackVehicleInfo_93B648, &TrackVehicleInfo_93E039, &TrackVehicleInfo_940A2A, &TrackVehicleInfo_94341B,
    &TrackVehicleInfo_9443A0, &TrackVehicleInfo_94705E, &TrackVehicleInfo_949D1C, &TrackVehicleInfo_94C9DA, &TrackVehicleInfo_9459FF, &TrackVehicleInfo_9486BD,
    &TrackVehicleInfo_94B37B, &TrackVehicleInfo_94E039,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListMiniGolfBallPathB12[] = {
    &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4,
    &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8,
    &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938D7A, &TrackVehicleInfo_938E0C,
    &TrackVehicleInfo_938E9E, &TrackVehicleInfo_938F30, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_93845A, &TrackVehicleInfo_9384EC, &TrackVehicleInfo_93857E, &TrackVehicleInfo_938610, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9386A2, &TrackVehicleInfo_938734, &TrackVehicleInfo_9387C6, &TrackVehicleInfo_938858, &TrackVehicleInfo_938FC2, &TrackVehicleInfo_939054,
    &TrackVehicleInfo_9390E6, &TrackVehicleInfo_939178, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_938B32, &TrackVehicleInfo_938BC4, &TrackVehicleInfo_938C56, &TrackVehicleInfo_938CE8, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9388EA, &TrackVehicleInfo_93897C, &TrackVehicleInfo_938A0E, &TrackVehicleInfo_938AA0, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_93920A, &TrackVehicleInfo_939293, &TrackVehicleInfo_93932E, &TrackVehicleInfo_9393C0,
    &TrackVehicleInfo_939449, &TrackVehicleInfo_9394D2, &TrackVehicleInfo_939564, &TrackVehicleInfo_9395FF, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_939CD9, &TrackVehicleInfo_93C6CA, &TrackVehicleInfo_93F0BB, &TrackVehicleInfo_941AAC, &TrackVehicleInfo_93AB73, &TrackVehicleInfo_93D564,
    &TrackVehicleInfo_93FF55, &TrackVehicleInfo_942946, &TrackVehicleInfo_93B8DB, &TrackVehicleInfo_93E2CC, &TrackVehicleInfo_940CBD, &TrackVehicleInfo_9436AE,
    &TrackVehicleInfo_9446DE, &TrackVehicleInfo_94739C, &TrackVehicleInfo_94A05A, &TrackVehicleInfo_94CD18, &TrackVehicleInfo_945D3D, &TrackVehicleInfo_9489FB,
    &TrackVehicleInfo_94B6B9, &TrackVehicleInfo_94E377,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListMiniGolfPathC13[] = {
    &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4,
    &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8,
    &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938D7A, &TrackVehicleInfo_938E0C,
    &TrackVehicleInfo_938E9E, &TrackVehicleInfo_938F30, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_93845A, &TrackVehicleInfo_9384EC, &TrackVehicleInfo_93857E, &TrackVehicleInfo_938610, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9386A2, &TrackVehicleInfo_938734, &TrackVehicleInfo_9387C6, &TrackVehicleInfo_938858, &TrackVehicleInfo_938FC2, &TrackVehicleInfo_939054,
    &TrackVehicleInfo_9390E6, &TrackVehicleInfo_939178, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_938B32, &TrackVehicleInfo_938BC4, &TrackVehicleInfo_938C56, &TrackVehicleInfo_938CE8, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9388EA, &TrackVehicleInfo_93897C, &TrackVehicleInfo_938A0E, &TrackVehicleInfo_938AA0, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_93920A, &TrackVehicleInfo_939293, &TrackVehicleInfo_93932E, &TrackVehicleInfo_9393C0,
    &TrackVehicleInfo_939449, &TrackVehicleInfo_9394D2, &TrackVehicleInfo_939564, &TrackVehicleInfo_9395FF, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_939EAF, &TrackVehicleInfo_93C8A0, &TrackVehicleInfo_93F291, &TrackVehicleInfo_941C82, &TrackVehicleInfo_93ADA3, &TrackVehicleInfo_93D794,
    &TrackVehicleInfo_940185, &TrackVehicleInfo_942B76, &TrackVehicleInfo_93BAB1, &TrackVehicleInfo_93E4A2, &TrackVehicleInfo_940E93, &TrackVehicleInfo_943884,
    &TrackVehicleInfo_944AA3, &TrackVehicleInfo_947761, &TrackVehicleInfo_94A41F, &TrackVehicleInfo_94D0DD, &TrackVehicleInfo_946102, &TrackVehicleInfo_948DC0,
    &TrackVehicleInfo_94BA7E, &TrackVehicleInfo_94E73C,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListMiniGolfPathC14[] = {
    &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4,
    &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8,
    &TrackVehicleInfo_938212, &TrackVehicleInfo_9382A4, &TrackVehicleInfo_938336, &TrackVehicleInfo_9383C8, &TrackVehicleInfo_938D7A, &TrackVehicleInfo_938E0C,
    &TrackVehicleInfo_938E9E, &TrackVehicleInfo_938F30, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_93845A, &TrackVehicleInfo_9384EC, &TrackVehicleInfo_93857E, &TrackVehicleInfo_938610, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9386A2, &TrackVehicleInfo_938734, &TrackVehicleInfo_9387C6, &TrackVehicleInfo_938858, &TrackVehicleInfo_938FC2, &TrackVehicleInfo_939054,
    &TrackVehicleInfo_9390E6, &TrackVehicleInfo_939178, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_938B32, &TrackVehicleInfo_938BC4, &TrackVehicleInfo_938C56, &TrackVehicleInfo_938CE8, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_9388EA, &TrackVehicleInfo_93897C, &TrackVehicleInfo_938A0E, &TrackVehicleInfo_938AA0, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_93920A, &TrackVehicleInfo_939293, &TrackVehicleInfo_93932E, &TrackVehicleInfo_9393C0,
    &TrackVehicleInfo_939449, &TrackVehicleInfo_9394D2, &TrackVehicleInfo_939564, &TrackVehicleInfo_9395FF, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_93A1F6, &TrackVehicleInfo_93CBE7, &TrackVehicleInfo_93F5D8, &TrackVehicleInfo_941FC9, &TrackVehicleInfo_93B01B, &TrackVehicleInfo_93DA0C,
    &TrackVehicleInfo_9403FD, &TrackVehicleInfo_942DEE, &TrackVehicleInfo_93BDCB, &TrackVehicleInfo_93E7BC, &TrackVehicleInfo_9411AD, &TrackVehicleInfo_943B9E,
    &TrackVehicleInfo_944E3B, &TrackVehicleInfo_947AF9, &TrackVehicleInfo_94A7B7, &TrackVehicleInfo_94D475, &TrackVehicleInfo_94649A, &TrackVehicleInfo_949158,
    &TrackVehicleInfo_94BE16, &TrackVehicleInfo_94EAD4,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListReverserRCFrontBogie[] = {
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C,
    &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C,
    &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554, &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8,
    &TrackVehicleInfo_8BFC1A, &TrackVehicleInfo_8BFD3C, &TrackVehicleInfo_8BFE5E, &TrackVehicleInfo_8BFF80, &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89,
    &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5, &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763,
    &TrackVehicleInfo_8C00A2, &TrackVehicleInfo_8C01C4, &TrackVehicleInfo_8C02E6, &TrackVehicleInfo_8C0408, &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4,
    &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C, &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300,
    &TrackVehicleInfo_8C09B2, &TrackVehicleInfo_8C0AD4, &TrackVehicleInfo_8C0BF6, &TrackVehicleInfo_8C0D18, &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D,
    &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01, &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F,
    &TrackVehicleInfo_8C052A, &TrackVehicleInfo_8C064C, &TrackVehicleInfo_8C076E, &TrackVehicleInfo_8C0890, &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496,
    &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D, &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE,
    &TrackVehicleInfo_8C3542, &TrackVehicleInfo_8C3664, &TrackVehicleInfo_8C3786, &TrackVehicleInfo_8C38A8, &TrackVehicleInfo_8C39CA, &TrackVehicleInfo_8C3AEC,
    &TrackVehicleInfo_8C3C0E, &TrackVehicleInfo_8C3D30, &TrackVehicleInfo_8C3E52, &TrackVehicleInfo_8C3F74, &TrackVehicleInfo_8C4096, &TrackVehicleInfo_8C41B8,
    &TrackVehicleInfo_8C42DA, &TrackVehicleInfo_8C43FC, &TrackVehicleInfo_8C451E, &TrackVehicleInfo_8C4640, &TrackVehicleInfo_8CA0B2, &TrackVehicleInfo_8CA4B6,
    &TrackVehicleInfo_8CA8C3, &TrackVehicleInfo_8CACC7, &TrackVehicleInfo_8CB0C2, &TrackVehicleInfo_8CB4BD, &TrackVehicleInfo_8CB8C1, &TrackVehicleInfo_8CBCCE,
    &TrackVehicleInfo_8C4762, &TrackVehicleInfo_8C4884, &TrackVehicleInfo_8C49A6, &TrackVehicleInfo_8C4AC8, &TrackVehicleInfo_8C4BEA, &TrackVehicleInfo_8C4D0C,
    &TrackVehicleInfo_8C4E2E, &TrackVehicleInfo_8C4F50, &TrackVehicleInfo_8C5072, &TrackVehicleInfo_8C51A6, &TrackVehicleInfo_8C52DA, &TrackVehicleInfo_8C540E,
    &TrackVehicleInfo_8C5542, &TrackVehicleInfo_8C5676, &TrackVehicleInfo_8C57AA, &TrackVehicleInfo_8C58DE, &TrackVehicleInfo_8C6322, &TrackVehicleInfo_8C6444,
    &TrackVehicleInfo_8C6566, &TrackVehicleInfo_8C6688, &TrackVehicleInfo_8C67AA, &TrackVehicleInfo_8C68CC, &TrackVehicleInfo_8C69EE, &TrackVehicleInfo_8C6B10,
    &TrackVehicleInfo_8C5A12, &TrackVehicleInfo_8C5B34, &TrackVehicleInfo_8C5C56, &TrackVehicleInfo_8C5D78, &TrackVehicleInfo_8C5E9A, &TrackVehicleInfo_8C5FBC,
    &TrackVehicleInfo_8C60DE, &TrackVehicleInfo_8C6200, &TrackVehicleInfo_8BEA02, &TrackVehicleInfo_8BEB24, &TrackVehicleInfo_8BEC46, &TrackVehicleInfo_8BED68,
    &TrackVehicleInfo_8BEE8A, &TrackVehicleInfo_8BEFAC, &TrackVehicleInfo_8BF0CE, &TrackVehicleInfo_8BF1F0, &TrackVehicleInfo_8D047E, &TrackVehicleInfo_8D0882,
    &TrackVehicleInfo_8D0C8F, &TrackVehicleInfo_8D1093, &TrackVehicleInfo_8D148E, &TrackVehicleInfo_8D1889, &TrackVehicleInfo_8D1C8D, &TrackVehicleInfo_8D209A,
    &TrackVehicleInfo_8D249E, &TrackVehicleInfo_8D28A2, &TrackVehicleInfo_8D2CAF, &TrackVehicleInfo_8D30B3, &TrackVehicleInfo_8D34AE, &TrackVehicleInfo_8D38A9,
    &TrackVehicleInfo_8D3CAD, &TrackVehicleInfo_8D40BA, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8D44BE, &TrackVehicleInfo_8D4FA6,
    &TrackVehicleInfo_8D5A8E, &TrackVehicleInfo_8D6576, &TrackVehicleInfo_8D705E, &TrackVehicleInfo_8D7B46, &TrackVehicleInfo_8D862E, &TrackVehicleInfo_8D9116,
    &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94, &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923,
    &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8, &TrackVehicleInfo_8E005E, &TrackVehicleInfo_8E02C4, &TrackVehicleInfo_8E0533, &TrackVehicleInfo_8E0799,
    &TrackVehicleInfo_8E09F6, &TrackVehicleInfo_8E0C53, &TrackVehicleInfo_8E0EB9, &TrackVehicleInfo_8E1128, &TrackVehicleInfo_8E26BE, &TrackVehicleInfo_8E2924,
    &TrackVehicleInfo_8E2B93, &TrackVehicleInfo_8E2DF9, &TrackVehicleInfo_8E3056, &TrackVehicleInfo_8E32B3, &TrackVehicleInfo_8E3519, &TrackVehicleInfo_8E3788,
    &TrackVehicleInfo_8E138E, &TrackVehicleInfo_8E15F4, &TrackVehicleInfo_8E1863, &TrackVehicleInfo_8E1AC9, &TrackVehicleInfo_8E1D26, &TrackVehicleInfo_8E1F83,
    &TrackVehicleInfo_8E21E9, &TrackVehicleInfo_8E2458, &TrackVehicleInfo_8E39EE, &TrackVehicleInfo_8E3AB6, &TrackVehicleInfo_8E3B87, &TrackVehicleInfo_8E3C4F,
    &TrackVehicleInfo_8E3D0E, &TrackVehicleInfo_8E3DCD, &TrackVehicleInfo_8E3E95, &TrackVehicleInfo_8E3F66, &TrackVehicleInfo_8D9BFE, &TrackVehicleInfo_8D9F60,
    &TrackVehicleInfo_8DA2C2, &TrackVehicleInfo_8DA624, &TrackVehicleInfo_8DA986, &TrackVehicleInfo_8DACE8, &TrackVehicleInfo_8DB04A, &TrackVehicleInfo_8DB3AC,
    &TrackVehicleInfo_8DB70E, &TrackVehicleInfo_8DBA70, &TrackVehicleInfo_8DBDD2, &TrackVehicleInfo_8DC134, &TrackVehicleInfo_8DC496, &TrackVehicleInfo_8DC7F8,
    &TrackVehicleInfo_8DCB5A, &TrackVehicleInfo_8DCEBC, &TrackVehicleInfo_8E644E, &TrackVehicleInfo_8E69F9, &TrackVehicleInfo_8E6FA4, &TrackVehicleInfo_8E754F,
    &TrackVehicleInfo_8E7AFA, &TrackVehicleInfo_8E80A5, &TrackVehicleInfo_8E8650, &TrackVehicleInfo_8E8BFB, &TrackVehicleInfo_8EA852, &TrackVehicleInfo_8EABBD,
    &TrackVehicleInfo_8EAF28, &TrackVehicleInfo_8EB293, &TrackVehicleInfo_8EB5FE, &TrackVehicleInfo_8EB969, &TrackVehicleInfo_8EBCD4, &TrackVehicleInfo_8EC03F,
    &TrackVehicleInfo_8EC3AA, &TrackVehicleInfo_8EC715, &TrackVehicleInfo_8ECA80, &TrackVehicleInfo_8ECDEB, &TrackVehicleInfo_8ED156, &TrackVehicleInfo_8ED4C1,
    &TrackVehicleInfo_8ED82C, &TrackVehicleInfo_8EDB97, &TrackVehicleInfo_8C6C32, &TrackVehicleInfo_8C6D78, &TrackVehicleInfo_8C6EBE, &TrackVehicleInfo_8C7004,
    &TrackVehicleInfo_8C714A, &TrackVehicleInfo_8C7290, &TrackVehicleInfo_8C73D6, &TrackVehicleInfo_8C751C, &TrackVehicleInfo_8C7662, &TrackVehicleInfo_8C77A8,
    &TrackVehicleInfo_8C78EE, &TrackVehicleInfo_8C7A34, &TrackVehicleInfo_8C7B7A, &TrackVehicleInfo_8C7CC0, &TrackVehicleInfo_8C7E06, &TrackVehicleInfo_8C7F4C,
    &TrackVehicleInfo_8EFA5A, &TrackVehicleInfo_8EFDAA, &TrackVehicleInfo_8F00FA, &TrackVehicleInfo_8F044A, &TrackVehicleInfo_8F079A, &TrackVehicleInfo_8F08BC,
    &TrackVehicleInfo_8F09DE, &TrackVehicleInfo_8F0B00, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,
    &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C, &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554,
    &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8, &TrackVehicleInfo_8BFC1A, &TrackVehicleInfo_8BFD3C, &TrackVehicleInfo_8BFE5E, &TrackVehicleInfo_8BFF80,
    &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89, &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5,
    &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763, &TrackVehicleInfo_8C00A2, &TrackVehicleInfo_8C01C4, &TrackVehicleInfo_8C02E6, &TrackVehicleInfo_8C0408,
    &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4, &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C,
    &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300, &TrackVehicleInfo_8C09B2, &TrackVehicleInfo_8C0AD4, &TrackVehicleInfo_8C0BF6, &TrackVehicleInfo_8C0D18,
    &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D, &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01,
    &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F, &TrackVehicleInfo_8C052A, &TrackVehicleInfo_8C064C, &TrackVehicleInfo_8C076E, &TrackVehicleInfo_8C0890,
    &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496, &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D,
    &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94,
    &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923, &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8,
    &TrackVehicleInfo_8F8C82, &TrackVehicleInfo_8F9143, &TrackVehicleInfo_8F9616, &TrackVehicleInfo_8F9AE9, &TrackVehicleInfo_8F9FAA, &TrackVehicleInfo_8FA46B,
    &TrackVehicleInfo_8FA93E, &TrackVehicleInfo_8FAE11, &TrackVehicleInfo_8FB2D2, &TrackVehicleInfo_8FB793, &TrackVehicleInfo_8FBC66, &TrackVehicleInfo_8FC139,
    &TrackVehicleInfo_8FC5FA, &TrackVehicleInfo_8FCABB, &TrackVehicleInfo_8FCF8E, &TrackVehicleInfo_8FD461, &TrackVehicleInfo_8F0C22, &TrackVehicleInfo_8F141F,
    &TrackVehicleInfo_8F1C2E, &TrackVehicleInfo_8F243D, &TrackVehicleInfo_8F2C3A, &TrackVehicleInfo_8F3437, &TrackVehicleInfo_8F3C46, &TrackVehicleInfo_8F4455,
    &TrackVehicleInfo_8F4C52, &TrackVehicleInfo_8F544F, &TrackVehicleInfo_8F5C5E, &TrackVehicleInfo_8F646D, &TrackVehicleInfo_8F6C6A, &TrackVehicleInfo_8F7467,
    &TrackVehicleInfo_8F7C76, &TrackVehicleInfo_8F8485, &TrackVehicleInfo_8E402E, &TrackVehicleInfo_8E4270, &TrackVehicleInfo_8E44B2, &TrackVehicleInfo_8E46F4,
    &TrackVehicleInfo_8E4936, &TrackVehicleInfo_8E4B78, &TrackVehicleInfo_8E4DBA, &TrackVehicleInfo_8E4FFC, &TrackVehicleInfo_8E523E, &TrackVehicleInfo_8E5480,
    &TrackVehicleInfo_8E56C2, &TrackVehicleInfo_8E5904, &TrackVehicleInfo_8E5B46, &TrackVehicleInfo_8E5D88, &TrackVehicleInfo_8E5FCA, &TrackVehicleInfo_8E620C,
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C,
    &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_8B0EB2, &TrackVehicleInfo_8B12B6, &TrackVehicleInfo_8B16C3, &TrackVehicleInfo_8B1AC7, &TrackVehicleInfo_8B1EC2, &TrackVehicleInfo_8B22BD,
    &TrackVehicleInfo_8B26C1, &TrackVehicleInfo_8B2ACE, &TrackVehicleInfo_8B2ED2, &TrackVehicleInfo_8B32D6, &TrackVehicleInfo_8B36E3, &TrackVehicleInfo_8B3AE7,
    &TrackVehicleInfo_8B3EE2, &TrackVehicleInfo_8B42DD, &TrackVehicleInfo_8B46E1, &TrackVehicleInfo_8B4AEE, &TrackVehicleInfo_8B4EF2, &TrackVehicleInfo_8B52F6,
    &TrackVehicleInfo_8B5703, &TrackVehicleInfo_8B5B07, &TrackVehicleInfo_8B5F02, &TrackVehicleInfo_8B62FD, &TrackVehicleInfo_8B6701, &TrackVehicleInfo_8B6B0E,
    &TrackVehicleInfo_8B6F12, &TrackVehicleInfo_8B7316, &TrackVehicleInfo_8B7723, &TrackVehicleInfo_8B7B27, &TrackVehicleInfo_8B7F22, &TrackVehicleInfo_8B831D,
    &TrackVehicleInfo_8B8721, &TrackVehicleInfo_8B8B2E, &TrackVehicleInfo_968C6E, &TrackVehicleInfo_968D90, &TrackVehicleInfo_968EB2, &TrackVehicleInfo_968FD4,
    &TrackVehicleInfo_96957E, &TrackVehicleInfo_9696A0, &TrackVehicleInfo_9697C2, &TrackVehicleInfo_9698E4, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C,
    &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_9048E8, &TrackVehicleInfo_904A0A, &TrackVehicleInfo_904B2C, &TrackVehicleInfo_904C4E,
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_9690F6, &TrackVehicleInfo_969218,
    &TrackVehicleInfo_96933A, &TrackVehicleInfo_96945C, &TrackVehicleInfo_969A06, &TrackVehicleInfo_969B28, &TrackVehicleInfo_969C4A, &TrackVehicleInfo_969D6C,
    &TrackVehicleInfo_904D72, &TrackVehicleInfo_905314, &TrackVehicleInfo_9058B6, &TrackVehicleInfo_905E58, &TrackVehicleInfo_96D4AE, &TrackVehicleInfo_96D9A5,
    &TrackVehicleInfo_96DE9C, &TrackVehicleInfo_96E393, &TrackVehicleInfo_96E88A, &TrackVehicleInfo_96ED81, &TrackVehicleInfo_96F278, &TrackVehicleInfo_96F76F,
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_971042, &TrackVehicleInfo_971539,
    &TrackVehicleInfo_971A30, &TrackVehicleInfo_971F27, &TrackVehicleInfo_96FC66, &TrackVehicleInfo_97015D, &TrackVehicleInfo_970654, &TrackVehicleInfo_970B4B,
    &TrackVehicleInfo_97241E, &TrackVehicleInfo_9729ED, &TrackVehicleInfo_972FBC, &TrackVehicleInfo_97358B, &TrackVehicleInfo_9063FA, &TrackVehicleInfo_906EAC,
    &TrackVehicleInfo_90795E, &TrackVehicleInfo_908410, &TrackVehicleInfo_90B98A, &TrackVehicleInfo_90BC5C, &TrackVehicleInfo_90BF2E, &TrackVehicleInfo_90C200,
    &TrackVehicleInfo_90E02A, &TrackVehicleInfo_90E14C, &TrackVehicleInfo_90E26E, &TrackVehicleInfo_90E390, &TrackVehicleInfo_90E4B2, &TrackVehicleInfo_90E5D4,
    &TrackVehicleInfo_90E6F6, &TrackVehicleInfo_90E818, &TrackVehicleInfo_90E93A, &TrackVehicleInfo_90EB34, &TrackVehicleInfo_90ED2E, &TrackVehicleInfo_90EF28,
    &TrackVehicleInfo_9100F2, &TrackVehicleInfo_9102EC, &TrackVehicleInfo_9104E6, &TrackVehicleInfo_9106E0, &TrackVehicleInfo_90F122, &TrackVehicleInfo_90F31C,
    &TrackVehicleInfo_90F516, &TrackVehicleInfo_90F710, &TrackVehicleInfo_90F90A, &TrackVehicleInfo_90FB04, &TrackVehicleInfo_90FCFE, &TrackVehicleInfo_90FEF8,
    &TrackVehicleInfo_8C7662, &TrackVehicleInfo_8C77A8, &TrackVehicleInfo_8C78EE, &TrackVehicleInfo_8C7A34, &TrackVehicleInfo_9108DA, &TrackVehicleInfo_910BA3,
    &TrackVehicleInfo_910E75, &TrackVehicleInfo_911147, &TrackVehicleInfo_911F58, &TrackVehicleInfo_91222A, &TrackVehicleInfo_9124FC, &TrackVehicleInfo_9127CE,
    &TrackVehicleInfo_911419, &TrackVehicleInfo_9116E2, &TrackVehicleInfo_9119B4, &TrackVehicleInfo_911C86, &TrackVehicleInfo_912AA0, &TrackVehicleInfo_912D69,
    &TrackVehicleInfo_91303B, &TrackVehicleInfo_91330D, &TrackVehicleInfo_9135DF, &TrackVehicleInfo_9138A8, &TrackVehicleInfo_913B7A, &TrackVehicleInfo_913E4C,
    &TrackVehicleInfo_914C5D, &TrackVehicleInfo_914F2F, &TrackVehicleInfo_915201, &TrackVehicleInfo_9154D3, &TrackVehicleInfo_91411E, &TrackVehicleInfo_9143E7,
    &TrackVehicleInfo_9146B9, &TrackVehicleInfo_91498B, &TrackVehicleInfo_9157A5, &TrackVehicleInfo_915A6E, &TrackVehicleInfo_915D40, &TrackVehicleInfo_916012,
    &TrackVehicleInfo_9162E6, &TrackVehicleInfo_916408, &TrackVehicleInfo_91652A, &TrackVehicleInfo_91664C, &TrackVehicleInfo_91676E, &TrackVehicleInfo_916890,
    &TrackVehicleInfo_9169B2, &TrackVehicleInfo_916AD4, &TrackVehicleInfo_91707E, &TrackVehicleInfo_9172C0, &TrackVehicleInfo_917502, &TrackVehicleInfo_917744,
    &TrackVehicleInfo_91828E, &TrackVehicleInfo_9183B0, &TrackVehicleInfo_9184D2, &TrackVehicleInfo_9185F4, &TrackVehicleInfo_9194F6, &TrackVehicleInfo_919645,
    &TrackVehicleInfo_919794, &TrackVehicleInfo_9198E3, &TrackVehicleInfo_919A32, &TrackVehicleInfo_919B81, &TrackVehicleInfo_919CD0, &TrackVehicleInfo_919E1F,
    &TrackVehicleInfo_918716, &TrackVehicleInfo_91884A, &TrackVehicleInfo_91897E, &TrackVehicleInfo_918AB2, &TrackVehicleInfo_916BF6, &TrackVehicleInfo_916D18,
    &TrackVehicleInfo_916E3A, &TrackVehicleInfo_916F5C, &TrackVehicleInfo_917986, &TrackVehicleInfo_917BC8, &TrackVehicleInfo_917E0A, &TrackVehicleInfo_91804C,
    &TrackVehicleInfo_91906E, &TrackVehicleInfo_919190, &TrackVehicleInfo_9192B2, &TrackVehicleInfo_9193D4, &TrackVehicleInfo_91A4AA, &TrackVehicleInfo_91A5F9,
    &TrackVehicleInfo_91A748, &TrackVehicleInfo_91A897, &TrackVehicleInfo_919F6E, &TrackVehicleInfo_91A0BD, &TrackVehicleInfo_91A20C, &TrackVehicleInfo_91A35B,
    &TrackVehicleInfo_918BE6, &TrackVehicleInfo_918D08, &TrackVehicleInfo_918E2A, &TrackVehicleInfo_918F4C, &TrackVehicleInfo_91A9E6, &TrackVehicleInfo_91AB2C,
    &TrackVehicleInfo_91AC72, &TrackVehicleInfo_91ADB8, &TrackVehicleInfo_91AEFE, &TrackVehicleInfo_91B044, &TrackVehicleInfo_91B18A, &TrackVehicleInfo_91B2D0,
    &TrackVehicleInfo_91B416, &TrackVehicleInfo_91B55C, &TrackVehicleInfo_91B6A2, &TrackVehicleInfo_91B7E8, &TrackVehicleInfo_91B92E, &TrackVehicleInfo_91BA74,
    &TrackVehicleInfo_91BBBA, &TrackVehicleInfo_91BD00, &TrackVehicleInfo_95787E, &TrackVehicleInfo_9579A0, &TrackVehicleInfo_957AC2, &TrackVehicleInfo_957BE4,
    &TrackVehicleInfo_957D06, &TrackVehicleInfo_957E28, &TrackVehicleInfo_957F4A, &TrackVehicleInfo_95806C, &TrackVehicleInfo_95818E, &TrackVehicleInfo_9582B0,
    &TrackVehicleInfo_9583D2, &TrackVehicleInfo_9584F4, &TrackVehicleInfo_958616, &TrackVehicleInfo_958738, &TrackVehicleInfo_95885A, &TrackVehicleInfo_95897C,
    &TrackVehicleInfo_958A9E, &TrackVehicleInfo_958BC0, &TrackVehicleInfo_958CE2, &TrackVehicleInfo_958E04, &TrackVehicleInfo_958F26, &TrackVehicleInfo_959048,
    &TrackVehicleInfo_95916A, &TrackVehicleInfo_95928C, &TrackVehicleInfo_9593AE, &TrackVehicleInfo_9594E2, &TrackVehicleInfo_959616, &TrackVehicleInfo_95974A,
    &TrackVehicleInfo_95987E, &TrackVehicleInfo_9599B2, &TrackVehicleInfo_959AE6, &TrackVehicleInfo_959C1A, &TrackVehicleInfo_95A65E, &TrackVehicleInfo_95A780,
    &TrackVehicleInfo_95A8A2, &TrackVehicleInfo_95A9C4, &TrackVehicleInfo_95AAE6, &TrackVehicleInfo_95AC08, &TrackVehicleInfo_95AD2A, &TrackVehicleInfo_95AE4C,
    &TrackVehicleInfo_959D4E, &TrackVehicleInfo_959E70, &TrackVehicleInfo_959F92, &TrackVehicleInfo_95A0B4, &TrackVehicleInfo_95A1D6, &TrackVehicleInfo_95A2F8,
    &TrackVehicleInfo_95A41A, &TrackVehicleInfo_95A53C, &TrackVehicleInfo_95AF6E, &TrackVehicleInfo_95B090, &TrackVehicleInfo_95B1B2, &TrackVehicleInfo_95B2D4,
    &TrackVehicleInfo_95B3F6, &TrackVehicleInfo_95B518, &TrackVehicleInfo_95B63A, &TrackVehicleInfo_95B75C, &TrackVehicleInfo_91BE46, &TrackVehicleInfo_91C001,
    &TrackVehicleInfo_91C1BC, &TrackVehicleInfo_91C377, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,
    &TrackVehicleInfo_91C532, &TrackVehicleInfo_91C894, &TrackVehicleInfo_91CBF6, &TrackVehicleInfo_91CF58, &TrackVehicleInfo_91D2BA, &TrackVehicleInfo_91D61C,
    &TrackVehicleInfo_91D97E, &TrackVehicleInfo_91DCE0, &TrackVehicleInfo_91E042, &TrackVehicleInfo_91E3A4, &TrackVehicleInfo_91E706, &TrackVehicleInfo_91EA68,
    &TrackVehicleInfo_91EDCA, &TrackVehicleInfo_91F12C, &TrackVehicleInfo_91F48E, &TrackVehicleInfo_91F7F0, &TrackVehicleInfo_920E82, &TrackVehicleInfo_9210E8,
    &TrackVehicleInfo_921357, &TrackVehicleInfo_9215BD, &TrackVehicleInfo_92181A, &TrackVehicleInfo_921A77, &TrackVehicleInfo_921CDD, &TrackVehicleInfo_921F4C,
    &TrackVehicleInfo_91FB52, &TrackVehicleInfo_91FDB8, &TrackVehicleInfo_920027, &TrackVehicleInfo_92028D, &TrackVehicleInfo_9204EA, &TrackVehicleInfo_920747,
    &TrackVehicleInfo_9209AD, &TrackVehicleInfo_920C1C, &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C, &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690,
    &TrackVehicleInfo_9221B2, &TrackVehicleInfo_9237A6, &TrackVehicleInfo_924D9A, &TrackVehicleInfo_92638E, &TrackVehicleInfo_922CAC, &TrackVehicleInfo_9242A0,
    &TrackVehicleInfo_925894, &TrackVehicleInfo_926E88, &TrackVehicleInfo_927982, &TrackVehicleInfo_928F76, &TrackVehicleInfo_92A56A, &TrackVehicleInfo_92BB5E,
    &TrackVehicleInfo_92847C, &TrackVehicleInfo_929A70, &TrackVehicleInfo_92B064, &TrackVehicleInfo_92C658, &TrackVehicleInfo_8D9BFE, &TrackVehicleInfo_8D9F60,
    &TrackVehicleInfo_8DA2C2, &TrackVehicleInfo_8DA624, &TrackVehicleInfo_8DA986, &TrackVehicleInfo_8DACE8, &TrackVehicleInfo_8DB04A, &TrackVehicleInfo_8DB3AC,
    &TrackVehicleInfo_8DD21E, &TrackVehicleInfo_8DD580, &TrackVehicleInfo_8DD8E2, &TrackVehicleInfo_8DDC44, &TrackVehicleInfo_8DDFA6, &TrackVehicleInfo_8DE308,
    &TrackVehicleInfo_8DE66A, &TrackVehicleInfo_8DE9CC, &TrackVehicleInfo_8E644E, &TrackVehicleInfo_8E69F9, &TrackVehicleInfo_8E6FA4, &TrackVehicleInfo_8E754F,
    &TrackVehicleInfo_8E91A6, &TrackVehicleInfo_8E9751, &TrackVehicleInfo_8E9CFC, &TrackVehicleInfo_8EA2A7, &TrackVehicleInfo_8EA852, &TrackVehicleInfo_8EABBD,
    &TrackVehicleInfo_8EAF28, &TrackVehicleInfo_8EB293, &TrackVehicleInfo_8EB5FE, &TrackVehicleInfo_8EB969, &TrackVehicleInfo_8EBCD4, &TrackVehicleInfo_8EC03F,
    &TrackVehicleInfo_8EDF02, &TrackVehicleInfo_8EE26D, &TrackVehicleInfo_8EE5D8, &TrackVehicleInfo_8EE943, &TrackVehicleInfo_8EECAE, &TrackVehicleInfo_8EF019,
    &TrackVehicleInfo_8EF384, &TrackVehicleInfo_8EF6EF, &TrackVehicleInfo_92D152, &TrackVehicleInfo_92D6F4, &TrackVehicleInfo_92DC96, &TrackVehicleInfo_92E238,
    &TrackVehicleInfo_92E7DA, &TrackVehicleInfo_92ED7C, &TrackVehicleInfo_92F31E, &TrackVehicleInfo_92F8C0, &TrackVehicleInfo_92FE62, &TrackVehicleInfo_930524,
    &TrackVehicleInfo_930BE6, &TrackVehicleInfo_9312A8, &TrackVehicleInfo_93196A, &TrackVehicleInfo_93202C, &TrackVehicleInfo_9326EE, &TrackVehicleInfo_932DB0,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_95275E, &TrackVehicleInfo_952AC0,
    &TrackVehicleInfo_952E22, &TrackVehicleInfo_953184, &TrackVehicleInfo_9534E6, &TrackVehicleInfo_953848, &TrackVehicleInfo_953BAA, &TrackVehicleInfo_953F0C,
    &TrackVehicleInfo_90C4D2, &TrackVehicleInfo_90C8D6, &TrackVehicleInfo_90CCDA, &TrackVehicleInfo_90D0DE, &TrackVehicleInfo_90D4E2, &TrackVehicleInfo_90D7B4,
    &TrackVehicleInfo_90DA86, &TrackVehicleInfo_90DD58, &TrackVehicleInfo_908EC2, &TrackVehicleInfo_909974, &TrackVehicleInfo_90A426, &TrackVehicleInfo_90AED8,
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,
};

static constexpr const VehicleInfoList *TrackVehicleInfoListReverserRCRearBogie[] = {
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C,
    &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C,
    &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554, &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8,
    &TrackVehicleInfo_8BFC1A, &TrackVehicleInfo_8BFD3C, &TrackVehicleInfo_8BFE5E, &TrackVehicleInfo_8BFF80, &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89,
    &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5, &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763,
    &TrackVehicleInfo_8C00A2, &TrackVehicleInfo_8C01C4, &TrackVehicleInfo_8C02E6, &TrackVehicleInfo_8C0408, &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4,
    &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C, &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300,
    &TrackVehicleInfo_8C09B2, &TrackVehicleInfo_8C0AD4, &TrackVehicleInfo_8C0BF6, &TrackVehicleInfo_8C0D18, &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D,
    &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01, &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F,
    &TrackVehicleInfo_8C052A, &TrackVehicleInfo_8C064C, &TrackVehicleInfo_8C076E, &TrackVehicleInfo_8C0890, &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496,
    &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D, &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE,
    &TrackVehicleInfo_8C3542, &TrackVehicleInfo_8C3664, &TrackVehicleInfo_8C3786, &TrackVehicleInfo_8C38A8, &TrackVehicleInfo_8C39CA, &TrackVehicleInfo_8C3AEC,
    &TrackVehicleInfo_8C3C0E, &TrackVehicleInfo_8C3D30, &TrackVehicleInfo_8C3E52, &TrackVehicleInfo_8C3F74, &TrackVehicleInfo_8C4096, &TrackVehicleInfo_8C41B8,
    &TrackVehicleInfo_8C42DA, &TrackVehicleInfo_8C43FC, &TrackVehicleInfo_8C451E, &TrackVehicleInfo_8C4640, &TrackVehicleInfo_8CA0B2, &TrackVehicleInfo_8CA4B6,
    &TrackVehicleInfo_8CA8C3, &TrackVehicleInfo_8CACC7, &TrackVehicleInfo_8CB0C2, &TrackVehicleInfo_8CB4BD, &TrackVehicleInfo_8CB8C1, &TrackVehicleInfo_8CBCCE,
    &TrackVehicleInfo_8C4762, &TrackVehicleInfo_8C4884, &TrackVehicleInfo_8C49A6, &TrackVehicleInfo_8C4AC8, &TrackVehicleInfo_8C4BEA, &TrackVehicleInfo_8C4D0C,
    &TrackVehicleInfo_8C4E2E, &TrackVehicleInfo_8C4F50, &TrackVehicleInfo_8C5072, &TrackVehicleInfo_8C51A6, &TrackVehicleInfo_8C52DA, &TrackVehicleInfo_8C540E,
    &TrackVehicleInfo_8C5542, &TrackVehicleInfo_8C5676, &TrackVehicleInfo_8C57AA, &TrackVehicleInfo_8C58DE, &TrackVehicleInfo_8C6322, &TrackVehicleInfo_8C6444,
    &TrackVehicleInfo_8C6566, &TrackVehicleInfo_8C6688, &TrackVehicleInfo_8C67AA, &TrackVehicleInfo_8C68CC, &TrackVehicleInfo_8C69EE, &TrackVehicleInfo_8C6B10,
    &TrackVehicleInfo_8C5A12, &TrackVehicleInfo_8C5B34, &TrackVehicleInfo_8C5C56, &TrackVehicleInfo_8C5D78, &TrackVehicleInfo_8C5E9A, &TrackVehicleInfo_8C5FBC,
    &TrackVehicleInfo_8C60DE, &TrackVehicleInfo_8C6200, &TrackVehicleInfo_8BEA02, &TrackVehicleInfo_8BEB24, &TrackVehicleInfo_8BEC46, &TrackVehicleInfo_8BED68,
    &TrackVehicleInfo_8BEE8A, &TrackVehicleInfo_8BEFAC, &TrackVehicleInfo_8BF0CE, &TrackVehicleInfo_8BF1F0, &TrackVehicleInfo_8D047E, &TrackVehicleInfo_8D0882,
    &TrackVehicleInfo_8D0C8F, &TrackVehicleInfo_8D1093, &TrackVehicleInfo_8D148E, &TrackVehicleInfo_8D1889, &TrackVehicleInfo_8D1C8D, &TrackVehicleInfo_8D209A,
    &TrackVehicleInfo_8D249E, &TrackVehicleInfo_8D28A2, &TrackVehicleInfo_8D2CAF, &TrackVehicleInfo_8D30B3, &TrackVehicleInfo_8D34AE, &TrackVehicleInfo_8D38A9,
    &TrackVehicleInfo_8D3CAD, &TrackVehicleInfo_8D40BA, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8D44BE, &TrackVehicleInfo_8D4FA6,
    &TrackVehicleInfo_8D5A8E, &TrackVehicleInfo_8D6576, &TrackVehicleInfo_8D705E, &TrackVehicleInfo_8D7B46, &TrackVehicleInfo_8D862E, &TrackVehicleInfo_8D9116,
    &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94, &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923,
    &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8, &TrackVehicleInfo_8E005E, &TrackVehicleInfo_8E02C4, &TrackVehicleInfo_8E0533, &TrackVehicleInfo_8E0799,
    &TrackVehicleInfo_8E09F6, &TrackVehicleInfo_8E0C53, &TrackVehicleInfo_8E0EB9, &TrackVehicleInfo_8E1128, &TrackVehicleInfo_8E26BE, &TrackVehicleInfo_8E2924,
    &TrackVehicleInfo_8E2B93, &TrackVehicleInfo_8E2DF9, &TrackVehicleInfo_8E3056, &TrackVehicleInfo_8E32B3, &TrackVehicleInfo_8E3519, &TrackVehicleInfo_8E3788,
    &TrackVehicleInfo_8E138E, &TrackVehicleInfo_8E15F4, &TrackVehicleInfo_8E1863, &TrackVehicleInfo_8E1AC9, &TrackVehicleInfo_8E1D26, &TrackVehicleInfo_8E1F83,
    &TrackVehicleInfo_8E21E9, &TrackVehicleInfo_8E2458, &TrackVehicleInfo_8E39EE, &TrackVehicleInfo_8E3AB6, &TrackVehicleInfo_8E3B87, &TrackVehicleInfo_8E3C4F,
    &TrackVehicleInfo_8E3D0E, &TrackVehicleInfo_8E3DCD, &TrackVehicleInfo_8E3E95, &TrackVehicleInfo_8E3F66, &TrackVehicleInfo_8D9BFE, &TrackVehicleInfo_8D9F60,
    &TrackVehicleInfo_8DA2C2, &TrackVehicleInfo_8DA624, &TrackVehicleInfo_8DA986, &TrackVehicleInfo_8DACE8, &TrackVehicleInfo_8DB04A, &TrackVehicleInfo_8DB3AC,
    &TrackVehicleInfo_8DB70E, &TrackVehicleInfo_8DBA70, &TrackVehicleInfo_8DBDD2, &TrackVehicleInfo_8DC134, &TrackVehicleInfo_8DC496, &TrackVehicleInfo_8DC7F8,
    &TrackVehicleInfo_8DCB5A, &TrackVehicleInfo_8DCEBC, &TrackVehicleInfo_8E644E, &TrackVehicleInfo_8E69F9, &TrackVehicleInfo_8E6FA4, &TrackVehicleInfo_8E754F,
    &TrackVehicleInfo_8E7AFA, &TrackVehicleInfo_8E80A5, &TrackVehicleInfo_8E8650, &TrackVehicleInfo_8E8BFB, &TrackVehicleInfo_8EA852, &TrackVehicleInfo_8EABBD,
    &TrackVehicleInfo_8EAF28, &TrackVehicleInfo_8EB293, &TrackVehicleInfo_8EB5FE, &TrackVehicleInfo_8EB969, &TrackVehicleInfo_8EBCD4, &TrackVehicleInfo_8EC03F,
    &TrackVehicleInfo_8EC3AA, &TrackVehicleInfo_8EC715, &TrackVehicleInfo_8ECA80, &TrackVehicleInfo_8ECDEB, &TrackVehicleInfo_8ED156, &TrackVehicleInfo_8ED4C1,
    &TrackVehicleInfo_8ED82C, &TrackVehicleInfo_8EDB97, &TrackVehicleInfo_8C6C32, &TrackVehicleInfo_8C6D78, &TrackVehicleInfo_8C6EBE, &TrackVehicleInfo_8C7004,
    &TrackVehicleInfo_8C714A, &TrackVehicleInfo_8C7290, &TrackVehicleInfo_8C73D6, &TrackVehicleInfo_8C751C, &TrackVehicleInfo_8C7662, &TrackVehicleInfo_8C77A8,
    &TrackVehicleInfo_8C78EE, &TrackVehicleInfo_8C7A34, &TrackVehicleInfo_8C7B7A, &TrackVehicleInfo_8C7CC0, &TrackVehicleInfo_8C7E06, &TrackVehicleInfo_8C7F4C,
    &TrackVehicleInfo_8EFA5A, &TrackVehicleInfo_8EFDAA, &TrackVehicleInfo_8F00FA, &TrackVehicleInfo_8F044A, &TrackVehicleInfo_8F079A, &TrackVehicleInfo_8F08BC,
    &TrackVehicleInfo_8F09DE, &TrackVehicleInfo_8F0B00, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,
    &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C, &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690, &TrackVehicleInfo_8BF312, &TrackVehicleInfo_8BF554,
    &TrackVehicleInfo_8BF796, &TrackVehicleInfo_8BF9D8, &TrackVehicleInfo_8BFC1A, &TrackVehicleInfo_8BFD3C, &TrackVehicleInfo_8BFE5E, &TrackVehicleInfo_8BFF80,
    &TrackVehicleInfo_8C0E3A, &TrackVehicleInfo_8C0F89, &TrackVehicleInfo_8C10D8, &TrackVehicleInfo_8C1227, &TrackVehicleInfo_8C1376, &TrackVehicleInfo_8C14C5,
    &TrackVehicleInfo_8C1614, &TrackVehicleInfo_8C1763, &TrackVehicleInfo_8C00A2, &TrackVehicleInfo_8C01C4, &TrackVehicleInfo_8C02E6, &TrackVehicleInfo_8C0408,
    &TrackVehicleInfo_8C27B2, &TrackVehicleInfo_8C28D4, &TrackVehicleInfo_8C29F6, &TrackVehicleInfo_8C2B18, &TrackVehicleInfo_8C2C3A, &TrackVehicleInfo_8C2E7C,
    &TrackVehicleInfo_8C30BE, &TrackVehicleInfo_8C3300, &TrackVehicleInfo_8C09B2, &TrackVehicleInfo_8C0AD4, &TrackVehicleInfo_8C0BF6, &TrackVehicleInfo_8C0D18,
    &TrackVehicleInfo_8C1DEE, &TrackVehicleInfo_8C1F3D, &TrackVehicleInfo_8C208C, &TrackVehicleInfo_8C21DB, &TrackVehicleInfo_8C18B2, &TrackVehicleInfo_8C1A01,
    &TrackVehicleInfo_8C1B50, &TrackVehicleInfo_8C1C9F, &TrackVehicleInfo_8C052A, &TrackVehicleInfo_8C064C, &TrackVehicleInfo_8C076E, &TrackVehicleInfo_8C0890,
    &TrackVehicleInfo_8C8092, &TrackVehicleInfo_8C8496, &TrackVehicleInfo_8C88A3, &TrackVehicleInfo_8C8CA7, &TrackVehicleInfo_8C90A2, &TrackVehicleInfo_8C949D,
    &TrackVehicleInfo_8C98A1, &TrackVehicleInfo_8C9CAE, &TrackVehicleInfo_8CC0D2, &TrackVehicleInfo_8CC434, &TrackVehicleInfo_8CC796, &TrackVehicleInfo_8CCAF8,
    &TrackVehicleInfo_8CCE5A, &TrackVehicleInfo_8CD1BC, &TrackVehicleInfo_8CD51E, &TrackVehicleInfo_8CD880, &TrackVehicleInfo_8DED2E, &TrackVehicleInfo_8DEF94,
    &TrackVehicleInfo_8DF203, &TrackVehicleInfo_8DF469, &TrackVehicleInfo_8DF6C6, &TrackVehicleInfo_8DF923, &TrackVehicleInfo_8DFB89, &TrackVehicleInfo_8DFDF8,
    &TrackVehicleInfo_8F8C82, &TrackVehicleInfo_8F9143, &TrackVehicleInfo_8F9616, &TrackVehicleInfo_8F9AE9, &TrackVehicleInfo_8F9FAA, &TrackVehicleInfo_8FA46B,
    &TrackVehicleInfo_8FA93E, &TrackVehicleInfo_8FAE11, &TrackVehicleInfo_8FB2D2, &TrackVehicleInfo_8FB793, &TrackVehicleInfo_8FBC66, &TrackVehicleInfo_8FC139,
    &TrackVehicleInfo_8FC5FA, &TrackVehicleInfo_8FCABB, &TrackVehicleInfo_8FCF8E, &TrackVehicleInfo_8FD461, &TrackVehicleInfo_8F0C22, &TrackVehicleInfo_8F141F,
    &TrackVehicleInfo_8F1C2E, &TrackVehicleInfo_8F243D, &TrackVehicleInfo_8F2C3A, &TrackVehicleInfo_8F3437, &TrackVehicleInfo_8F3C46, &TrackVehicleInfo_8F4455,
    &TrackVehicleInfo_8F4C52, &TrackVehicleInfo_8F544F, &TrackVehicleInfo_8F5C5E, &TrackVehicleInfo_8F646D, &TrackVehicleInfo_8F6C6A, &TrackVehicleInfo_8F7467,
    &TrackVehicleInfo_8F7C76, &TrackVehicleInfo_8F8485, &TrackVehicleInfo_8E402E, &TrackVehicleInfo_8E4270, &TrackVehicleInfo_8E44B2, &TrackVehicleInfo_8E46F4,
    &TrackVehicleInfo_8E4936, &TrackVehicleInfo_8E4B78, &TrackVehicleInfo_8E4DBA, &TrackVehicleInfo_8E4FFC, &TrackVehicleInfo_8E523E, &TrackVehicleInfo_8E5480,
    &TrackVehicleInfo_8E56C2, &TrackVehicleInfo_8E5904, &TrackVehicleInfo_8E5B46, &TrackVehicleInfo_8E5D88, &TrackVehicleInfo_8E5FCA, &TrackVehicleInfo_8E620C,
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C,
    &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_8B0EB2, &TrackVehicleInfo_8B12B6, &TrackVehicleInfo_8B16C3, &TrackVehicleInfo_8B1AC7, &TrackVehicleInfo_8B1EC2, &TrackVehicleInfo_8B22BD,
    &TrackVehicleInfo_8B26C1, &TrackVehicleInfo_8B2ACE, &TrackVehicleInfo_8B2ED2, &TrackVehicleInfo_8B32D6, &TrackVehicleInfo_8B36E3, &TrackVehicleInfo_8B3AE7,
    &TrackVehicleInfo_8B3EE2, &TrackVehicleInfo_8B42DD, &TrackVehicleInfo_8B46E1, &TrackVehicleInfo_8B4AEE, &TrackVehicleInfo_8B4EF2, &TrackVehicleInfo_8B52F6,
    &TrackVehicleInfo_8B5703, &TrackVehicleInfo_8B5B07, &TrackVehicleInfo_8B5F02, &TrackVehicleInfo_8B62FD, &TrackVehicleInfo_8B6701, &TrackVehicleInfo_8B6B0E,
    &TrackVehicleInfo_8B6F12, &TrackVehicleInfo_8B7316, &TrackVehicleInfo_8B7723, &TrackVehicleInfo_8B7B27, &TrackVehicleInfo_8B7F22, &TrackVehicleInfo_8B831D,
    &TrackVehicleInfo_8B8721, &TrackVehicleInfo_8B8B2E, &TrackVehicleInfo_968C6E, &TrackVehicleInfo_968D90, &TrackVehicleInfo_968EB2, &TrackVehicleInfo_968FD4,
    &TrackVehicleInfo_96957E, &TrackVehicleInfo_9696A0, &TrackVehicleInfo_9697C2, &TrackVehicleInfo_9698E4, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C,
    &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_9048E8, &TrackVehicleInfo_904A0A, &TrackVehicleInfo_904B2C, &TrackVehicleInfo_904C4E,
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_9690F6, &TrackVehicleInfo_969218,
    &TrackVehicleInfo_96933A, &TrackVehicleInfo_96945C, &TrackVehicleInfo_969A06, &TrackVehicleInfo_969B28, &TrackVehicleInfo_969C4A, &TrackVehicleInfo_969D6C,
    &TrackVehicleInfo_904D72, &TrackVehicleInfo_905314, &TrackVehicleInfo_9058B6, &TrackVehicleInfo_905E58, &TrackVehicleInfo_96D4AE, &TrackVehicleInfo_96D9A5,
    &TrackVehicleInfo_96DE9C, &TrackVehicleInfo_96E393, &TrackVehicleInfo_96E88A, &TrackVehicleInfo_96ED81, &TrackVehicleInfo_96F278, &TrackVehicleInfo_96F76F,
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0, &TrackVehicleInfo_971042, &TrackVehicleInfo_971539,
    &TrackVehicleInfo_971A30, &TrackVehicleInfo_971F27, &TrackVehicleInfo_96FC66, &TrackVehicleInfo_97015D, &TrackVehicleInfo_970654, &TrackVehicleInfo_970B4B,
    &TrackVehicleInfo_97241E, &TrackVehicleInfo_9729ED, &TrackVehicleInfo_972FBC, &TrackVehicleInfo_97358B, &TrackVehicleInfo_9063FA, &TrackVehicleInfo_906EAC,
    &TrackVehicleInfo_90795E, &TrackVehicleInfo_908410, &TrackVehicleInfo_90B98A, &TrackVehicleInfo_90BC5C, &TrackVehicleInfo_90BF2E, &TrackVehicleInfo_90C200,
    &TrackVehicleInfo_90E02A, &TrackVehicleInfo_90E14C, &TrackVehicleInfo_90E26E, &TrackVehicleInfo_90E390, &TrackVehicleInfo_90E4B2, &TrackVehicleInfo_90E5D4,
    &TrackVehicleInfo_90E6F6, &TrackVehicleInfo_90E818, &TrackVehicleInfo_90E93A, &TrackVehicleInfo_90EB34, &TrackVehicleInfo_90ED2E, &TrackVehicleInfo_90EF28,
    &TrackVehicleInfo_9100F2, &TrackVehicleInfo_9102EC, &TrackVehicleInfo_9104E6, &TrackVehicleInfo_9106E0, &TrackVehicleInfo_90F122, &TrackVehicleInfo_90F31C,
    &TrackVehicleInfo_90F516, &TrackVehicleInfo_90F710, &TrackVehicleInfo_90F90A, &TrackVehicleInfo_90FB04, &TrackVehicleInfo_90FCFE, &TrackVehicleInfo_90FEF8,
    &TrackVehicleInfo_8C7662, &TrackVehicleInfo_8C77A8, &TrackVehicleInfo_8C78EE, &TrackVehicleInfo_8C7A34, &TrackVehicleInfo_9108DA, &TrackVehicleInfo_910BA3,
    &TrackVehicleInfo_910E75, &TrackVehicleInfo_911147, &TrackVehicleInfo_911F58, &TrackVehicleInfo_91222A, &TrackVehicleInfo_9124FC, &TrackVehicleInfo_9127CE,
    &TrackVehicleInfo_911419, &TrackVehicleInfo_9116E2, &TrackVehicleInfo_9119B4, &TrackVehicleInfo_911C86, &TrackVehicleInfo_912AA0, &TrackVehicleInfo_912D69,
    &TrackVehicleInfo_91303B, &TrackVehicleInfo_91330D, &TrackVehicleInfo_9135DF, &TrackVehicleInfo_9138A8, &TrackVehicleInfo_913B7A, &TrackVehicleInfo_913E4C,
    &TrackVehicleInfo_914C5D, &TrackVehicleInfo_914F2F, &TrackVehicleInfo_915201, &TrackVehicleInfo_9154D3, &TrackVehicleInfo_91411E, &TrackVehicleInfo_9143E7,
    &TrackVehicleInfo_9146B9, &TrackVehicleInfo_91498B, &TrackVehicleInfo_9157A5, &TrackVehicleInfo_915A6E, &TrackVehicleInfo_915D40, &TrackVehicleInfo_916012,
    &TrackVehicleInfo_9162E6, &TrackVehicleInfo_916408, &TrackVehicleInfo_91652A, &TrackVehicleInfo_91664C, &TrackVehicleInfo_91676E, &TrackVehicleInfo_916890,
    &TrackVehicleInfo_9169B2, &TrackVehicleInfo_916AD4, &TrackVehicleInfo_91707E, &TrackVehicleInfo_9172C0, &TrackVehicleInfo_917502, &TrackVehicleInfo_917744,
    &TrackVehicleInfo_91828E, &TrackVehicleInfo_9183B0, &TrackVehicleInfo_9184D2, &TrackVehicleInfo_9185F4, &TrackVehicleInfo_9194F6, &TrackVehicleInfo_919645,
    &TrackVehicleInfo_919794, &TrackVehicleInfo_9198E3, &TrackVehicleInfo_919A32, &TrackVehicleInfo_919B81, &TrackVehicleInfo_919CD0, &TrackVehicleInfo_919E1F,
    &TrackVehicleInfo_918716, &TrackVehicleInfo_91884A, &TrackVehicleInfo_91897E, &TrackVehicleInfo_918AB2, &TrackVehicleInfo_916BF6, &TrackVehicleInfo_916D18,
    &TrackVehicleInfo_916E3A, &TrackVehicleInfo_916F5C, &TrackVehicleInfo_917986, &TrackVehicleInfo_917BC8, &TrackVehicleInfo_917E0A, &TrackVehicleInfo_91804C,
    &TrackVehicleInfo_91906E, &TrackVehicleInfo_919190, &TrackVehicleInfo_9192B2, &TrackVehicleInfo_9193D4, &TrackVehicleInfo_91A4AA, &TrackVehicleInfo_91A5F9,
    &TrackVehicleInfo_91A748, &TrackVehicleInfo_91A897, &TrackVehicleInfo_919F6E, &TrackVehicleInfo_91A0BD, &TrackVehicleInfo_91A20C, &TrackVehicleInfo_91A35B,
    &TrackVehicleInfo_918BE6, &TrackVehicleInfo_918D08, &TrackVehicleInfo_918E2A, &TrackVehicleInfo_918F4C, &TrackVehicleInfo_91A9E6, &TrackVehicleInfo_91AB2C,
    &TrackVehicleInfo_91AC72, &TrackVehicleInfo_91ADB8, &TrackVehicleInfo_91AEFE, &TrackVehicleInfo_91B044, &TrackVehicleInfo_91B18A, &TrackVehicleInfo_91B2D0,
    &TrackVehicleInfo_91B416, &TrackVehicleInfo_91B55C, &TrackVehicleInfo_91B6A2, &TrackVehicleInfo_91B7E8, &TrackVehicleInfo_91B92E, &TrackVehicleInfo_91BA74,
    &TrackVehicleInfo_91BBBA, &TrackVehicleInfo_91BD00, &TrackVehicleInfo_95787E, &TrackVehicleInfo_9579A0, &TrackVehicleInfo_957AC2, &TrackVehicleInfo_957BE4,
    &TrackVehicleInfo_957D06, &TrackVehicleInfo_957E28, &TrackVehicleInfo_957F4A, &TrackVehicleInfo_95806C, &TrackVehicleInfo_95818E, &TrackVehicleInfo_9582B0,
    &TrackVehicleInfo_9583D2, &TrackVehicleInfo_9584F4, &TrackVehicleInfo_958616, &TrackVehicleInfo_958738, &TrackVehicleInfo_95885A, &TrackVehicleInfo_95897C,
    &TrackVehicleInfo_958A9E, &TrackVehicleInfo_958BC0, &TrackVehicleInfo_958CE2, &TrackVehicleInfo_958E04, &TrackVehicleInfo_958F26, &TrackVehicleInfo_959048,
    &TrackVehicleInfo_95916A, &TrackVehicleInfo_95928C, &TrackVehicleInfo_9593AE, &TrackVehicleInfo_9594E2, &TrackVehicleInfo_959616, &TrackVehicleInfo_95974A,
    &TrackVehicleInfo_95987E, &TrackVehicleInfo_9599B2, &TrackVehicleInfo_959AE6, &TrackVehicleInfo_959C1A, &TrackVehicleInfo_95A65E, &TrackVehicleInfo_95A780,
    &TrackVehicleInfo_95A8A2, &TrackVehicleInfo_95A9C4, &TrackVehicleInfo_95AAE6, &TrackVehicleInfo_95AC08, &TrackVehicleInfo_95AD2A, &TrackVehicleInfo_95AE4C,
    &TrackVehicleInfo_959D4E, &TrackVehicleInfo_959E70, &TrackVehicleInfo_959F92, &TrackVehicleInfo_95A0B4, &TrackVehicleInfo_95A1D6, &TrackVehicleInfo_95A2F8,
    &TrackVehicleInfo_95A41A, &TrackVehicleInfo_95A53C, &TrackVehicleInfo_95AF6E, &TrackVehicleInfo_95B090, &TrackVehicleInfo_95B1B2, &TrackVehicleInfo_95B2D4,
    &TrackVehicleInfo_95B3F6, &TrackVehicleInfo_95B518, &TrackVehicleInfo_95B63A, &TrackVehicleInfo_95B75C, &TrackVehicleInfo_91BE46, &TrackVehicleInfo_91C001,
    &TrackVehicleInfo_91C1BC, &TrackVehicleInfo_91C377, &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,
    &TrackVehicleInfo_91C532, &TrackVehicleInfo_91C894, &TrackVehicleInfo_91CBF6, &TrackVehicleInfo_91CF58, &TrackVehicleInfo_91D2BA, &TrackVehicleInfo_91D61C,
    &TrackVehicleInfo_91D97E, &TrackVehicleInfo_91DCE0, &TrackVehicleInfo_91E042, &TrackVehicleInfo_91E3A4, &TrackVehicleInfo_91E706, &TrackVehicleInfo_91EA68,
    &TrackVehicleInfo_91EDCA, &TrackVehicleInfo_91F12C, &TrackVehicleInfo_91F48E, &TrackVehicleInfo_91F7F0, &TrackVehicleInfo_920E82, &TrackVehicleInfo_9210E8,
    &TrackVehicleInfo_921357, &TrackVehicleInfo_9215BD, &TrackVehicleInfo_92181A, &TrackVehicleInfo_921A77, &TrackVehicleInfo_921CDD, &TrackVehicleInfo_921F4C,
    &TrackVehicleInfo_91FB52, &TrackVehicleInfo_91FDB8, &TrackVehicleInfo_920027, &TrackVehicleInfo_92028D, &TrackVehicleInfo_9204EA, &TrackVehicleInfo_920747,
    &TrackVehicleInfo_9209AD, &TrackVehicleInfo_920C1C, &TrackVehicleInfo_8C232A, &TrackVehicleInfo_8C244C, &TrackVehicleInfo_8C256E, &TrackVehicleInfo_8C2690,
    &TrackVehicleInfo_9221B2, &TrackVehicleInfo_9237A6, &TrackVehicleInfo_924D9A, &TrackVehicleInfo_92638E, &TrackVehicleInfo_922CAC, &TrackVehicleInfo_9242A0,
    &TrackVehicleInfo_925894, &TrackVehicleInfo_926E88, &TrackVehicleInfo_927982, &TrackVehicleInfo_928F76, &TrackVehicleInfo_92A56A, &TrackVehicleInfo_92BB5E,
    &TrackVehicleInfo_92847C, &TrackVehicleInfo_929A70, &TrackVehicleInfo_92B064, &TrackVehicleInfo_92C658, &TrackVehicleInfo_8D9BFE, &TrackVehicleInfo_8D9F60,
    &TrackVehicleInfo_8DA2C2, &TrackVehicleInfo_8DA624, &TrackVehicleInfo_8DA986, &TrackVehicleInfo_8DACE8, &TrackVehicleInfo_8DB04A, &TrackVehicleInfo_8DB3AC,
    &TrackVehicleInfo_8DD21E, &TrackVehicleInfo_8DD580, &TrackVehicleInfo_8DD8E2, &TrackVehicleInfo_8DDC44, &TrackVehicleInfo_8DDFA6, &TrackVehicleInfo_8DE308,
    &TrackVehicleInfo_8DE66A, &TrackVehicleInfo_8DE9CC, &TrackVehicleInfo_8E644E, &TrackVehicleInfo_8E69F9, &TrackVehicleInfo_8E6FA4, &TrackVehicleInfo_8E754F,
    &TrackVehicleInfo_8E91A6, &TrackVehicleInfo_8E9751, &TrackVehicleInfo_8E9CFC, &TrackVehicleInfo_8EA2A7, &TrackVehicleInfo_8EA852, &TrackVehicleInfo_8EABBD,
    &TrackVehicleInfo_8EAF28, &TrackVehicleInfo_8EB293, &TrackVehicleInfo_8EB5FE, &TrackVehicleInfo_8EB969, &TrackVehicleInfo_8EBCD4, &TrackVehicleInfo_8EC03F,
    &TrackVehicleInfo_8EDF02, &TrackVehicleInfo_8EE26D, &TrackVehicleInfo_8EE5D8, &TrackVehicleInfo_8EE943, &TrackVehicleInfo_8EECAE, &TrackVehicleInfo_8EF019,
    &TrackVehicleInfo_8EF384, &TrackVehicleInfo_8EF6EF, &TrackVehicleInfo_92D152, &TrackVehicleInfo_92D6F4, &TrackVehicleInfo_92DC96, &TrackVehicleInfo_92E238,
    &TrackVehicleInfo_92E7DA, &TrackVehicleInfo_92ED7C, &TrackVehicleInfo_92F31E, &TrackVehicleInfo_92F8C0, &TrackVehicleInfo_92FE62, &TrackVehicleInfo_930524,
    &TrackVehicleInfo_930BE6, &TrackVehicleInfo_9312A8, &TrackVehicleInfo_93196A, &TrackVehicleInfo_93202C, &TrackVehicleInfo_9326EE, &TrackVehicleInfo_932DB0,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000,
    &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_000000, &TrackVehicleInfo_95426E, &TrackVehicleInfo_954930,
    &TrackVehicleInfo_954FF2, &TrackVehicleInfo_9556B4, &TrackVehicleInfo_955D76, &TrackVehicleInfo_956438, &TrackVehicleInfo_956AFA, &TrackVehicleInfo_9571BC,
    &TrackVehicleInfo_90C4D2, &TrackVehicleInfo_90C8D6, &TrackVehicleInfo_90CCDA, &TrackVehicleInfo_90D0DE, &TrackVehicleInfo_90D4E2, &TrackVehicleInfo_90D7B4,
    &TrackVehicleInfo_90DA86, &TrackVehicleInfo_90DD58, &TrackVehicleInfo_908EC2, &TrackVehicleInfo_909974, &TrackVehicleInfo_90A426, &TrackVehicleInfo_90AED8,
    &TrackVehicleInfo_8BE57A, &TrackVehicleInfo_8BE69C, &TrackVehicleInfo_8BE7BE, &TrackVehicleInfo_8BE8E0,
};

// rct2: 0x008B8F30
constexpr const VehicleInfoList * const * gTrackVehicleInfo[EnumValue(VehicleTrackSubposition::Count)] = {
    TrackVehicleInfoListDefault,                  // VehicleTrackSubposition::Default
    TrackVehicleInfoListChairliftGoingOut,        // VehicleTrackSubposition::ChairliftGoingOut
    TrackVehicleInfoListChairliftGoingBack,       // VehicleTrackSubposition::ChairliftGoingBack
    TrackVehicleInfoListChairliftEndBullwheel,    // VehicleTrackSubposition::ChairliftEndBullwheel
    TrackVehicleInfoListChairliftStartBullwheel,  // VehicleTrackSubposition::ChairliftStartBullwheel
    TrackVehicleInfoListGoKartsLeftLane,          // VehicleTrackSubposition::GoKartsLeftLane
    TrackVehicleInfoListGoKartsRightLane,         // VehicleTrackSubposition::GoKartsRightLane
    TrackVehicleInfoListGoKartsMovingToRightLane, // VehicleTrackSubposition::GoKartsMovingToRightLane
    TrackVehicleInfoListGoKartsMovingToLeftLane,  // VehicleTrackSubposition::GoKartsMovingToLeftLane
    TrackVehicleInfoListMiniGolfStartPathA9,      // VehicleTrackSubposition::MiniGolfStart9, VehicleTrackSubposition::MiniGolfPathA9
    TrackVehicleInfoListMiniGolfBallPathA10,      // VehicleTrackSubposition::MiniGolfBallPathA10
    TrackVehicleInfoListMiniGolfPathB11,          // VehicleTrackSubposition::MiniGolfPathB11
    TrackVehicleInfoListMiniGolfBallPathB12,      // VehicleTrackSubposition::MiniGolfBallPathB12
    TrackVehicleInfoListMiniGolfPathC13,          // VehicleTrackSubposition::MiniGolfPathC13
    TrackVehicleInfoListMiniGolfPathC14,          // VehicleTrackSubposition::MiniGolfBallPathC14
    TrackVehicleInfoListReverserRCFrontBogie,     // VehicleTrackSubposition::ReverserRCFrontBogie
    TrackVehicleInfoListReverserRCRearBogie,      // VehicleTrackSubposition::ReverserRCRearBogie
};

// clang-format on
